diff --git a/drivers/tty/vt/selection.c b/drivers/tty/vt/selection.c
index 8967c3a..9be3363 100644
--- a/drivers/tty/vt/selection.c
+++ b/drivers/tty/vt/selection.c
@@ -221,6 +221,8 @@ static int vc_selection_store_chars(struct vc_data *vc, bool unicode)
 			}
 			obp = bp;
 		}
+		if (c > 0x80)
+			i += 2;
 	}
 	vc_sel.buf_len = bp - vc_sel.buffer;
 
diff --git a/drivers/tty/vt/vt.c b/drivers/tty/vt/vt.c
index 5c47f77..6d95968 100644
--- a/drivers/tty/vt/vt.c
+++ b/drivers/tty/vt/vt.c
@@ -300,6 +300,20 @@ static inline unsigned short *screenpos(const struct vc_data *vc, int offset,
 	return p;
 }
 
+static inline unsigned short *screenpos_utf8(const struct vc_data *vc, int offset,
+		bool viewed)
+{
+	unsigned short *p;
+
+	if (!viewed)
+		p = (unsigned short *)(vc->vc_origin + offset + vc->vc_screenbuf_size);
+	else if (!vc->vc_sw->con_screen_pos)
+		p = (unsigned short *)(vc->vc_visible_origin + offset + vc->vc_screenbuf_size);
+	else
+		p = vc->vc_sw->con_screen_pos(vc, -offset - 1);
+	return p;
+}
+
 /* Called  from the keyboard irq path.. */
 static inline void scrolldelta(int lines)
 {
@@ -586,6 +600,10 @@ static void con_scroll(struct vc_data *vc, unsigned int top,
 	}
 	scr_memmovew(dst, src, (rows - nr) * vc->vc_size_row);
 	scr_memsetw(clear, vc->vc_video_erase_char, vc->vc_size_row * nr);
+	dst += (vc->vc_screenbuf_size >> 1);
+	src += (vc->vc_screenbuf_size >> 1);
+	scr_memmovew(dst, src, (rows - nr) * vc->vc_size_row);
+	scr_memsetw(clear, 0, vc->vc_size_row * nr);
 }
 
 static void do_update_region(struct vc_data *vc, unsigned long start, int count)
@@ -754,6 +772,7 @@ void complement_pos(struct vc_data *vc, int offset)
 {
 	static int old_offset = -1;
 	static unsigned short old;
+	static unsigned short old_utf;
 	static unsigned short oldx, oldy;
 
 	WARN_CONSOLE_UNLOCKED();
@@ -762,7 +781,7 @@ void complement_pos(struct vc_data *vc, int offset)
 	    old_offset < vc->vc_screenbuf_size) {
 		scr_writew(old, screenpos(vc, old_offset, true));
 		if (con_should_update(vc))
-			vc->vc_sw->con_putc(vc, old, oldy, oldx);
+			vc->vc_sw->con_putc(vc, (old_utf << 16) | old, oldy, oldx);
 		notify_update(vc);
 	}
 
@@ -772,14 +791,17 @@ void complement_pos(struct vc_data *vc, int offset)
 	    offset < vc->vc_screenbuf_size) {
 		unsigned short new;
 		unsigned short *p;
+		unsigned short *p_utf;
 		p = screenpos(vc, offset, true);
+		p_utf = screenpos_utf8(vc, offset, true);
 		old = scr_readw(p);
+		old_utf = scr_readw(p_utf);
 		new = old ^ vc->vc_complement_mask;
 		scr_writew(new, p);
 		if (con_should_update(vc)) {
 			oldx = (offset >> 1) % vc->vc_cols;
 			oldy = (offset >> 1) / vc->vc_cols;
-			vc->vc_sw->con_putc(vc, new, oldy, oldx);
+			vc->vc_sw->con_putc(vc, (old_utf << 16) | new, oldy, oldx);
 		}
 		notify_update(vc);
 	}
@@ -1093,7 +1115,7 @@ int vc_allocate(unsigned int currcons)	/* return 0 on success */
 	    vc->vc_screenbuf_size > KMALLOC_MAX_SIZE || !vc->vc_screenbuf_size)
 		goto err_free;
 	err = -ENOMEM;
-	vc->vc_screenbuf = kzalloc(vc->vc_screenbuf_size, GFP_KERNEL);
+	vc->vc_screenbuf = kzalloc(vc->vc_screenbuf_size * 2, GFP_KERNEL);
 	if (!vc->vc_screenbuf)
 		goto err_free;
 
@@ -1147,6 +1169,7 @@ static int vc_do_resize(struct tty_struct *tty, struct vc_data *vc,
 	unsigned long old_origin, new_origin, new_scr_end, rlth, rrem, err = 0;
 	unsigned long end;
 	unsigned int old_rows, old_row_size, first_copied_row;
+	unsigned int old_screen_size;
 	unsigned int new_cols, new_rows, new_row_size, new_screen_size;
 	unsigned int user;
 	unsigned short *oldscreen, *newscreen;
@@ -1190,7 +1213,7 @@ static int vc_do_resize(struct tty_struct *tty, struct vc_data *vc,
 
 	if (new_screen_size > KMALLOC_MAX_SIZE || !new_screen_size)
 		return -EINVAL;
-	newscreen = kzalloc(new_screen_size, GFP_USER);
+	newscreen = kzalloc(new_screen_size * 2, GFP_USER);
 	if (!newscreen)
 		return -ENOMEM;
 
@@ -1207,6 +1230,7 @@ static int vc_do_resize(struct tty_struct *tty, struct vc_data *vc,
 
 	old_rows = vc->vc_rows;
 	old_row_size = vc->vc_size_row;
+	old_screen_size = old_row_size * old_rows;
 
 	err = resize_screen(vc, new_cols, new_rows, user);
 	if (err) {
@@ -1255,15 +1279,23 @@ static int vc_do_resize(struct tty_struct *tty, struct vc_data *vc,
 	while (old_origin < end) {
 		scr_memcpyw((unsigned short *) new_origin,
 			    (unsigned short *) old_origin, rlth);
-		if (rrem)
+		scr_memcpyw((unsigned short *) new_origin + (new_screen_size >> 1),
+			    (unsigned short *) old_origin + (old_screen_size >> 1), rlth);
+		if (rrem) {
 			scr_memsetw((void *)(new_origin + rlth),
 				    vc->vc_video_erase_char, rrem);
+			scr_memsetw((void *)(new_origin + rlth + (new_screen_size)),
+				    vc->vc_video_erase_char, rrem);
+		}
 		old_origin += old_row_size;
 		new_origin += new_row_size;
 	}
-	if (new_scr_end > new_origin)
+	if (new_scr_end > new_origin) {
 		scr_memsetw((void *)new_origin, vc->vc_video_erase_char,
 			    new_scr_end - new_origin);
+		scr_memsetw((void *)new_origin + (new_screen_size), vc->vc_video_erase_char,
+			    new_scr_end - new_origin);
+	}
 	oldscreen = vc->vc_screenbuf;
 	vc->vc_screenbuf = newscreen;
 	vc->vc_screenbuf_size = new_screen_size;
@@ -2545,10 +2577,431 @@ static int ucs_cmp(const void *key, const void *elt)
 static int is_double_width(uint32_t ucs)
 {
 	static const struct interval double_width[] = {
-		{ 0x1100, 0x115F }, { 0x2329, 0x232A }, { 0x2E80, 0x303E },
-		{ 0x3040, 0xA4CF }, { 0xAC00, 0xD7A3 }, { 0xF900, 0xFAFF },
-		{ 0xFE10, 0xFE19 }, { 0xFE30, 0xFE6F }, { 0xFF00, 0xFF60 },
-		{ 0xFFE0, 0xFFE6 }, { 0x20000, 0x2FFFD }, { 0x30000, 0x3FFFD }
+		{ 0x34F, 0x34F },
+		{ 0x35C, 0x362 },
+		{ 0x378, 0x379 },
+		{ 0x380, 0x383 },
+		{ 0x38B, 0x38B },
+		{ 0x38D, 0x38D },
+		{ 0x3A2, 0x3A2 },
+		{ 0x488, 0x489 },
+		{ 0x52A, 0x52B },
+		{ 0x530, 0x530 },
+		{ 0x557, 0x558 },
+		{ 0x58B, 0x58E },
+		{ 0x590, 0x590 },
+		{ 0x5C8, 0x5CF },
+		{ 0x5EB, 0x5EE },
+		{ 0x5F5, 0x608 },
+		{ 0x60B, 0x60B },
+		{ 0x60E, 0x60F },
+		{ 0x611, 0x617 },
+		{ 0x61C, 0x61C },
+		{ 0x61E, 0x61E },
+		{ 0x656, 0x656 },
+		{ 0x6AA, 0x6AA },
+		{ 0x6D6, 0x6DA },
+		{ 0x6DC, 0x6DE },
+		{ 0x6E2, 0x6E3 },
+		{ 0x6E8, 0x6ED },
+		{ 0x700, 0x74F },
+		{ 0x790, 0x790 },
+		{ 0x79D, 0x79F },
+		{ 0x7B2, 0x7BF },
+		{ 0x7FB, 0x7FC },
+		{ 0x800, 0x86F },
+		{ 0x88F, 0x89B },
+		{ 0x8CC, 0x8CD },
+		{ 0x8D4, 0x8D4 },
+		{ 0x8DA, 0x8DF },
+		{ 0x900, 0xE00 },
+		{ 0xE3B, 0xE3E },
+		{ 0xE5B, 0xE80 },
+		{ 0xE83, 0xE83 },
+		{ 0xE85, 0xE85 },
+		{ 0xE8B, 0xE8B },
+		{ 0xEA4, 0xEA4 },
+		{ 0xEA6, 0xEA6 },
+		{ 0xEBE, 0xEBF },
+		{ 0xEC5, 0xEC5 },
+		{ 0xEC7, 0xEC7 },
+		{ 0xECF, 0xECF },
+		{ 0xEDA, 0xEDB },
+		{ 0xEE0, 0xEFF },
+		{ 0xF02, 0xF03 },
+		{ 0xF16, 0xF18 },
+		{ 0xF3A, 0xF3B },
+		{ 0xF48, 0xF48 },
+		{ 0xF6D, 0xF70 },
+		{ 0xF88, 0xF88 },
+		{ 0xF98, 0xF98 },
+		{ 0xFBD, 0xFBD },
+		{ 0xFC5, 0xFCD },
+		{ 0xFD0, 0xFD0 },
+		{ 0xFD5, 0x109F },
+		{ 0x10C6, 0x10C6 },
+		{ 0x10C8, 0x10CC },
+		{ 0x10CE, 0x10CF },
+		{ 0x1100, 0x1342 },
+		{ 0x1344, 0x1360 },
+		{ 0x1362, 0x138F },
+		{ 0x1395, 0x1395 },
+		{ 0x1397, 0x1398 },
+		{ 0x139A, 0x139F },
+		{ 0x13F6, 0x13F7 },
+		{ 0x13FE, 0x13FF },
+		{ 0x1401, 0x141D },
+		{ 0x142B, 0x1432 },
+		{ 0x143A, 0x1448 },
+		{ 0x144C, 0x1465 },
+		{ 0x1467, 0x146A },
+		{ 0x14C0, 0x14CF },
+		{ 0x14D3, 0x14E9 },
+		{ 0x150C, 0x1524 },
+		{ 0x1542, 0x1547 },
+		{ 0x1553, 0x155C },
+		{ 0x155E, 0x1569 },
+		{ 0x156B, 0x157A },
+		{ 0x157E, 0x1585 },
+		{ 0x158A, 0x1596 },
+		{ 0x159B, 0x159E },
+		{ 0x15A0, 0x15A5 },
+		{ 0x15B8, 0x15ED },
+		{ 0x15EF, 0x1600 },
+		{ 0x1602, 0x1645 },
+		{ 0x1648, 0x1659 },
+		{ 0x165B, 0x166C },
+		{ 0x166F, 0x1676 },
+		{ 0x1680, 0x169F },
+		{ 0x16E0, 0x16E0 },
+		{ 0x16E2, 0x16E2 },
+		{ 0x16F9, 0x1761 },
+		{ 0x1763, 0x17BA },
+		{ 0x17BC, 0x17CA },
+		{ 0x17CC, 0x17D5 },
+		{ 0x17D7, 0x17DB },
+		{ 0x17DD, 0x17EF },
+		{ 0x17FA, 0x18B3 },
+		{ 0x18B7, 0x18B7 },
+		{ 0x18BB, 0x18BD },
+		{ 0x18C0, 0x18C2 },
+		{ 0x18C6, 0x18D3 },
+		{ 0x18E0, 0x18E8 },
+		{ 0x18EA, 0x18EA },
+		{ 0x18EC, 0x18F2 },
+		{ 0x18F6, 0x194F },
+		{ 0x196E, 0x196F },
+		{ 0x1975, 0x1982 },
+		{ 0x1984, 0x198E },
+		{ 0x1990, 0x1990 },
+		{ 0x1992, 0x1999 },
+		{ 0x199B, 0x199D },
+		{ 0x199F, 0x19A0 },
+		{ 0x19A2, 0x19A2 },
+		{ 0x19A5, 0x19A6 },
+		{ 0x19A8, 0x19AF },
+		{ 0x19B4, 0x19B6 },
+		{ 0x19BB, 0x19C0 },
+		{ 0x19C2, 0x19C5 },
+		{ 0x19C7, 0x19C7 },
+		{ 0x19CA, 0x19CF },
+		{ 0x19D5, 0x19D5 },
+		{ 0x19D7, 0x19D7 },
+		{ 0x19DA, 0x1AAF },
+		{ 0x1ACF, 0x1C4F },
+		{ 0x1C89, 0x1C8F },
+		{ 0x1CBB, 0x1CBC },
+		{ 0x1CC0, 0x1CFF },
+		{ 0x1D7A, 0x1D7A },
+		{ 0x1DCD, 0x1DCD },
+		{ 0x1DFC, 0x1DFC },
+		{ 0x1F16, 0x1F17 },
+		{ 0x1F1E, 0x1F1F },
+		{ 0x1F46, 0x1F47 },
+		{ 0x1F4E, 0x1F4F },
+		{ 0x1F58, 0x1F58 },
+		{ 0x1F5A, 0x1F5A },
+		{ 0x1F5C, 0x1F5C },
+		{ 0x1F5E, 0x1F5E },
+		{ 0x1F7E, 0x1F7F },
+		{ 0x1FB5, 0x1FB5 },
+		{ 0x1FC5, 0x1FC5 },
+		{ 0x1FD4, 0x1FD5 },
+		{ 0x1FDC, 0x1FDC },
+		{ 0x1FF0, 0x1FF1 },
+		{ 0x1FF5, 0x1FF5 },
+		{ 0x1FFF, 0x1FFF },
+		{ 0x200B, 0x200F },
+		{ 0x2028, 0x202E },
+		{ 0x2057, 0x2057 },
+		{ 0x2060, 0x206F },
+		{ 0x2072, 0x2073 },
+		{ 0x208F, 0x208F },
+		{ 0x209D, 0x209F },
+		{ 0x20B9, 0x20B9 },
+		{ 0x20C1, 0x20CF },
+		{ 0x20DD, 0x20E0 },
+		{ 0x20E2, 0x20E4 },
+		{ 0x20E7, 0x20E7 },
+		{ 0x20EA, 0x20EA },
+		{ 0x20F1, 0x20FF },
+		{ 0x210E, 0x210F },
+		{ 0x212E, 0x212E },
+		{ 0x213A, 0x213D },
+		{ 0x213F, 0x2140 },
+		{ 0x2145, 0x2149 },
+		{ 0x214C, 0x214C },
+		{ 0x214F, 0x214F },
+		{ 0x2182, 0x2182 },
+		{ 0x2188, 0x2188 },
+		{ 0x218C, 0x218F },
+		{ 0x219C, 0x219D },
+		{ 0x21F4, 0x21F4 },
+		{ 0x21F9, 0x21FC },
+		{ 0x21FF, 0x21FF },
+		{ 0x22B6, 0x22B8 },
+		{ 0x22D8, 0x22D9 },
+		{ 0x22F2, 0x22F3 },
+		{ 0x22F5, 0x22F6 },
+		{ 0x22F9, 0x22FB },
+		{ 0x22FD, 0x22FD },
+		{ 0x22FF, 0x2300 },
+		{ 0x2316, 0x2316 },
+		{ 0x231A, 0x231B },
+		{ 0x2329, 0x232A },
+		{ 0x232C, 0x2335 },
+		{ 0x237B, 0x237E },
+		{ 0x2381, 0x2394 },
+		{ 0x2397, 0x239A },
+		{ 0x23B2, 0x23B6 },
+		{ 0x23C0, 0x23CA },
+		{ 0x23CD, 0x23CE },
+		{ 0x23D4, 0x23D9 },
+		{ 0x23DB, 0x23E7 },
+		{ 0x23E9, 0x2421 },
+		{ 0x2427, 0x243F },
+		{ 0x244B, 0x24FF },
+		{ 0x25EF, 0x25EF },
+		{ 0x25FD, 0x25FE },
+		{ 0x2603, 0x2603 },
+		{ 0x2605, 0x2606 },
+		{ 0x2610, 0x2612 },
+		{ 0x2614, 0x2619 },
+		{ 0x2622, 0x2624 },
+		{ 0x262B, 0x262C },
+		{ 0x262F, 0x2637 },
+		{ 0x2648, 0x2653 },
+		{ 0x2672, 0x268F },
+		{ 0x2692, 0x26A7 },
+		{ 0x26A9, 0x26AB },
+		{ 0x26AD, 0x26B1 },
+		{ 0x26B6, 0x26B6 },
+		{ 0x26BD, 0x26E1 },
+		{ 0x26E3, 0x2767 },
+		{ 0x2776, 0x27BF },
+		{ 0x27C1, 0x27C1 },
+		{ 0x27C3, 0x27C4 },
+		{ 0x27C8, 0x27C9 },
+		{ 0x27CB, 0x27D0 },
+		{ 0x27D2, 0x27D2 },
+		{ 0x27D5, 0x27DE },
+		{ 0x27E1, 0x27E5 },
+		{ 0x27F0, 0x27FF },
+		{ 0x2900, 0x2907 },
+		{ 0x290A, 0x2911 },
+		{ 0x2914, 0x2937 },
+		{ 0x293A, 0x2948 },
+		{ 0x294A, 0x294B },
+		{ 0x294E, 0x294E },
+		{ 0x2950, 0x2950 },
+		{ 0x2952, 0x2953 },
+		{ 0x2956, 0x2957 },
+		{ 0x295A, 0x295B },
+		{ 0x295E, 0x295F },
+		{ 0x2962, 0x297B },
+		{ 0x297E, 0x297F },
+		{ 0x2993, 0x2996 },
+		{ 0x299E, 0x299E },
+		{ 0x29A8, 0x29D0 },
+		{ 0x29DA, 0x29DB },
+		{ 0x29DF, 0x29E0 },
+		{ 0x29E2, 0x29EA },
+		{ 0x29EC, 0x29ED },
+		{ 0x29F4, 0x29F4 },
+		{ 0x29FE, 0x2A0A },
+		{ 0x2A0C, 0x2A0C },
+		{ 0x2A1D, 0x2A1D },
+		{ 0x2A20, 0x2A20 },
+		{ 0x2A2D, 0x2A2E },
+		{ 0x2A33, 0x2A3B },
+		{ 0x2A4E, 0x2A65 },
+		{ 0x2A68, 0x2A69 },
+		{ 0x2A74, 0x2A76 },
+		{ 0x2A78, 0x2A8A },
+		{ 0x2A8D, 0x2A8E },
+		{ 0x2A95, 0x2ABE },
+		{ 0x2ACD, 0x2AD2 },
+		{ 0x2AD7, 0x2ADD },
+		{ 0x2ADF, 0x2AED },
+		{ 0x2AF3, 0x2AF5 },
+		{ 0x2AF7, 0x2AFD },
+		{ 0x2B00, 0x2B05 },
+		{ 0x2B08, 0x2B0C },
+		{ 0x2B0E, 0x2B1C },
+		{ 0x2B1F, 0x2B24 },
+		{ 0x2B2C, 0x2B2D },
+		{ 0x2B30, 0x2B30 },
+		{ 0x2B32, 0x2B4D },
+		{ 0x2B50, 0x2BC8 },
+		{ 0x2BCA, 0x2BFE },
+		{ 0x2C0F, 0x2C0F },
+		{ 0x2C1F, 0x2C1F },
+		{ 0x2C27, 0x2C29 },
+		{ 0x2C3F, 0x2C3F },
+		{ 0x2C4F, 0x2C4F },
+		{ 0x2C57, 0x2C59 },
+		{ 0x2CE7, 0x2CE7 },
+		{ 0x2CEA, 0x2CEA },
+		{ 0x2CEF, 0x2CEF },
+		{ 0x2CF4, 0x2CF8 },
+		{ 0x2D05, 0x2D05 },
+		{ 0x2D07, 0x2D07 },
+		{ 0x2D0A, 0x2D0A },
+		{ 0x2D0D, 0x2D0D },
+		{ 0x2D10, 0x2D10 },
+		{ 0x2D13, 0x2D14 },
+		{ 0x2D1B, 0x2D1C },
+		{ 0x2D20, 0x2D20 },
+		{ 0x2D25, 0x2D26 },
+		{ 0x2D28, 0x2D2C },
+		{ 0x2D2E, 0x2D2F },
+		{ 0x2D48, 0x2D48 },
+		{ 0x2D68, 0x2D6E },
+		{ 0x2D71, 0x2D7E },
+		{ 0x2D80, 0x2DDF },
+		{ 0x2E0E, 0x2E11 },
+		{ 0x2E13, 0x2E15 },
+		{ 0x2E3A, 0x2E3B },
+		{ 0x2E43, 0x2E43 },
+		{ 0x2E50, 0x2E51 },
+		{ 0x2E5E, 0x303E },
+		{ 0x3040, 0xA4CF },
+		{ 0xA500, 0xA63F },
+		{ 0xA64C, 0xA64D },
+		{ 0xA65E, 0xA65E },
+		{ 0xA662, 0xA667 },
+		{ 0xA66C, 0xA66E },
+		{ 0xA670, 0xA670 },
+		{ 0xA672, 0xA672 },
+		{ 0xA684, 0xA685 },
+		{ 0xA698, 0xA699 },
+		{ 0xA6F8, 0xA6FF },
+		{ 0xA728, 0xA729 },
+		{ 0xA732, 0xA73D },
+		{ 0xA74E, 0xA74F },
+		{ 0xA758, 0xA759 },
+		{ 0xA771, 0xA777 },
+		{ 0xA7C2, 0xA7C3 },
+		{ 0xA7CB, 0xA7CF },
+		{ 0xA7D2, 0xA7D2 },
+		{ 0xA7D4, 0xA7D4 },
+		{ 0xA7DA, 0xA7F1 },
+		{ 0xA7FF, 0xA827 },
+		{ 0xA82A, 0xAB2F },
+		{ 0xAB6C, 0xAB6F },
+		{ 0xABC0, 0xD7FF },
+		{ 0xF900, 0xFAFF },
+		{ 0xFB07, 0xFB12 },
+		{ 0xFB18, 0xFB1C },
+		{ 0xFB21, 0xFB28 },
+		{ 0xFB37, 0xFB37 },
+		{ 0xFB3D, 0xFB3D },
+		{ 0xFB3F, 0xFB3F },
+		{ 0xFB42, 0xFB42 },
+		{ 0xFB45, 0xFB45 },
+		{ 0xFBC3, 0xFBD2 },
+		{ 0xFC1F, 0xFC1F },
+		{ 0xFC21, 0xFC21 },
+		{ 0xFC25, 0xFC25 },
+		{ 0xFC3D, 0xFC3E },
+		{ 0xFCAD, 0xFCAF },
+		{ 0xFCB1, 0xFCB7 },
+		{ 0xFCE7, 0xFCEA },
+		{ 0xFCFB, 0xFCFE },
+		{ 0xFD17, 0xFD20 },
+		{ 0xFD2D, 0xFD32 },
+		{ 0xFD34, 0xFD39 },
+		{ 0xFD3E, 0xFE1F },
+		{ 0xFE30, 0xFE6F },
+		{ 0xFE75, 0xFE75 },
+		{ 0xFEFD, 0xFF60 },
+		{ 0xFFBF, 0xFFC1 },
+		{ 0xFFC8, 0xFFC9 },
+		{ 0xFFD0, 0xFFD1 },
+		{ 0xFFD8, 0xFFD9 },
+		{ 0xFFDD, 0xFFE7 },
+		{ 0x16FE0, 0x16FE4 },
+		{ 0x16FF0, 0x16FF1 },
+		{ 0x17000, 0x187F7 },
+		{ 0x18800, 0x18CD5 },
+		{ 0x18D00, 0x18D08 },
+		{ 0x1AFF0, 0x1AFF3 },
+		{ 0x1AFF5, 0x1AFFB },
+		{ 0x1AFFD, 0x1AFFE },
+		{ 0x1B000, 0x1B122 },
+		{ 0x1B132, 0x1B132 },
+		{ 0x1B150, 0x1B152 },
+		{ 0x1B155, 0x1B155 },
+		{ 0x1B164, 0x1B167 },
+		{ 0x1B170, 0x1B2FB },
+		{ 0x1F004, 0x1F004 },
+		{ 0x1F0CF, 0x1F0CF },
+		{ 0x1F18E, 0x1F18E },
+		{ 0x1F191, 0x1F19A },
+		{ 0x1F200, 0x1F202 },
+		{ 0x1F210, 0x1F23B },
+		{ 0x1F240, 0x1F248 },
+		{ 0x1F250, 0x1F251 },
+		{ 0x1F260, 0x1F265 },
+		{ 0x1F300, 0x1F320 },
+		{ 0x1F32D, 0x1F335 },
+		{ 0x1F337, 0x1F37C },
+		{ 0x1F37E, 0x1F393 },
+		{ 0x1F3A0, 0x1F3CA },
+		{ 0x1F3CF, 0x1F3D3 },
+		{ 0x1F3E0, 0x1F3F0 },
+		{ 0x1F3F4, 0x1F3F4 },
+		{ 0x1F3F8, 0x1F43E },
+		{ 0x1F440, 0x1F440 },
+		{ 0x1F442, 0x1F4FC },
+		{ 0x1F4FF, 0x1F53D },
+		{ 0x1F54B, 0x1F54E },
+		{ 0x1F550, 0x1F567 },
+		{ 0x1F57A, 0x1F57A },
+		{ 0x1F595, 0x1F596 },
+		{ 0x1F5A4, 0x1F5A4 },
+		{ 0x1F5FB, 0x1F64F },
+		{ 0x1F680, 0x1F6C5 },
+		{ 0x1F6CC, 0x1F6CC },
+		{ 0x1F6D0, 0x1F6D2 },
+		{ 0x1F6D5, 0x1F6D7 },
+		{ 0x1F6DC, 0x1F6DF },
+		{ 0x1F6EB, 0x1F6EC },
+		{ 0x1F6F4, 0x1F6FC },
+		{ 0x1F7E0, 0x1F7EB },
+		{ 0x1F7F0, 0x1F7F0 },
+		{ 0x1F90C, 0x1F93A },
+		{ 0x1F93C, 0x1F945 },
+		{ 0x1F947, 0x1F9FF },
+		{ 0x1FA70, 0x1FA7C },
+		{ 0x1FA80, 0x1FA88 },
+		{ 0x1FA90, 0x1FABD },
+		{ 0x1FABF, 0x1FAC5 },
+		{ 0x1FACE, 0x1FADB },
+		{ 0x1FAE0, 0x1FAE8 },
+		{ 0x1FAF0, 0x1FAF8 },
+		{ 0x20000, 0x2FFFD },
+		{ 0x30000, 0x3FFFD }
 	};
 	if (ucs < double_width[0].first ||
 	    ucs > double_width[ARRAY_SIZE(double_width) - 1].last)
@@ -2778,6 +3231,8 @@ static int vc_con_write_normal(struct vc_data *vc, int tc, int c,
 			 * end up with having question marks only.
 			 */
 			tc = c;
+		} else if (c > 0xff) {
+			tc = 0xff;
 		} else {
 			/*
 			 * Display U+FFFD. If it's not found, display an inverse
@@ -2796,7 +3251,11 @@ static int vc_con_write_normal(struct vc_data *vc, int tc, int c,
 		}
 	}
 
-	next_c = c;
+	next_c = (c <= 0xffff) ? c : 0xfffd;
+	if (width == 2 && !vc->vc_need_wrap && vc->state.x == vc->vc_cols - 1) {
+		vc->vc_need_wrap = vc->vc_decawm;
+		draw->to = vc->vc_pos + 2;
+	}
 	while (1) {
 		if (vc->vc_need_wrap || vc->vc_decim)
 			con_flush(vc, draw);
@@ -2814,6 +3273,7 @@ static int vc_con_write_normal(struct vc_data *vc, int tc, int c,
 		tc |= (vc_attr << 8) & ~himask;
 
 		scr_writew(tc, (u16 *)vc->vc_pos);
+		scr_writew(next_c, (u16 *)vc->vc_pos + (vc->vc_screenbuf_size >> 1));
 
 		if (con_should_update(vc) && draw->x < 0) {
 			draw->x = vc->state.x;
@@ -2830,6 +3290,9 @@ static int vc_con_write_normal(struct vc_data *vc, int tc, int c,
 		if (!--width)
 			break;
 
+		tc = 0xfe;
+		continue;
+
 		/* A space is printed in the second column */
 		tc = conv_uni_to_pc(vc, ' ');
 		if (tc < 0)
@@ -2880,6 +3343,8 @@ static int do_con_write(struct tty_struct *tty, const u8 *buf, int count)
 	if (con_is_fg(vc))
 		hide_cursor(vc);
 
+	vc->vc_utf = 1;
+	vc->vc_disp_ctrl = 0;
 	param.vc = vc;
 
 	while (!tty->flow.stopped && count) {
@@ -3467,7 +3932,7 @@ static int __init con_init(void)
 		tty_port_init(&vc->port);
 		visual_init(vc, currcons, 1);
 		/* Assuming vc->vc_{cols,rows,screenbuf_size} are sane here. */
-		vc->vc_screenbuf = kzalloc(vc->vc_screenbuf_size, GFP_NOWAIT);
+		vc->vc_screenbuf = kzalloc(vc->vc_screenbuf_size * 2, GFP_NOWAIT);
 		vc_init(vc, currcons || !vc->vc_sw->con_save_screen);
 	}
 	currcons = fg_console = 0;
@@ -4684,7 +5149,10 @@ u16 screen_glyph(const struct vc_data *vc, int offset)
 {
 	u16 w = scr_readw(screenpos(vc, offset, true));
 	u16 c = w & 0xff;
+	u16 c_utf = scr_readw(screenpos_utf8(vc, offset, true));
 
+	if ((c == 0xff || c == 0xfe) && c_utf)
+		return c_utf;
 	if (w & vc->vc_hi_font_mask)
 		c |= 0x100;
 	return c;
diff --git a/drivers/video/fbdev/core/bitblit.c b/drivers/video/fbdev/core/bitblit.c
index 8587c9d..599ab37 100644
--- a/drivers/video/fbdev/core/bitblit.c
+++ b/drivers/video/fbdev/core/bitblit.c
@@ -16,6 +16,7 @@
 #include <linux/fb.h>
 #include <linux/vt_kern.h>
 #include <linux/console.h>
+#include <linux/font.h>
 #include <asm/types.h>
 #include "fbcon.h"
 
@@ -43,6 +44,51 @@ static void update_attr(u8 *dst, u8 *src, int attribute,
 	}
 }
 
+u16 utf8_pos(struct vc_data *vc, const u16 *s)
+{
+	unsigned long p = (unsigned long) s;
+
+	if (p >= vc->vc_origin && p < vc->vc_scr_end)
+		return scr_readw((u16 *) (p + vc->vc_screenbuf_size));
+	else
+		return scr_readw(s + 1);
+}
+
+u8 *font_bits(struct vc_data *vc, const u16 *s, u32 cellsize, u16 charmask,
+	struct fbcon_ops *ops)
+{
+	u8 *src;
+	u16 c_utf;
+	u32 cellsize_utf = (cellsize < 64) ? 16 : 64;
+	void *fontdata;
+	char *fontname = (cellsize < 64) ? "CJK16x16" : "CJK32x32";
+	const struct font_desc *font;
+
+	fontdata = ops ? ops->fontbuffer : vc->vc_font.data;
+	src = fontdata + (scr_readw(s) & charmask) * cellsize;
+	if ((scr_readw(s) & charmask) != 0xff && (scr_readw(s) & charmask) != 0xfe)
+		return src;
+
+	/* assume current font not support unicode */
+	if (vc->vc_font.charcount < 65536) {
+		if (ops)
+			fontdata = ops->fontbuffer_utf;
+		else {
+			font = find_font(fontname);
+			fontdata = (font && font->data) ? (void *) font->data : NULL;
+		}
+	}
+	if (fontdata) {
+		c_utf = utf8_pos(vc, s);
+		if ((scr_readw(s) & charmask) == 0xff)
+			src = fontdata + (c_utf * cellsize_utf * 2);
+		else
+			src = fontdata + (c_utf * cellsize_utf * 2 + cellsize_utf);
+	}
+
+	return src;
+}
+
 static void bit_bmove(struct vc_data *vc, struct fb_info *info, int sy,
 		      int sx, int dy, int dx, int height, int width)
 {
@@ -84,8 +130,7 @@ static inline void bit_putcs_aligned(struct vc_data *vc, struct fb_info *info,
 	u8 *src;
 
 	while (cnt--) {
-		src = vc->vc_font.data + (scr_readw(s++)&
-					  charmask)*cellsize;
+		src = font_bits(vc, s++, cellsize, charmask, NULL);
 
 		if (attr) {
 			update_attr(buf, src, attr, vc);
@@ -119,8 +164,7 @@ static inline void bit_putcs_unaligned(struct vc_data *vc,
 	u8 *src;
 
 	while (cnt--) {
-		src = vc->vc_font.data + (scr_readw(s++)&
-					  charmask)*cellsize;
+		src = font_bits(vc, s++, cellsize, charmask, NULL);
 
 		if (attr) {
 			update_attr(buf, src, attr, vc);
@@ -252,7 +296,7 @@ static void bit_cursor(struct vc_data *vc, struct fb_info *info, int mode,
 
  	c = scr_readw((u16 *) vc->vc_pos);
 	attribute = get_attribute(info, c);
-	src = vc->vc_font.data + ((c & charmask) * (w * vc->vc_font.height));
+	src = font_bits(vc, (u16 *) vc->vc_pos, (w * vc->vc_font.height), charmask, NULL);
 
 	if (ops->cursor_state.image.data != src ||
 	    ops->cursor_reset) {
diff --git a/drivers/video/fbdev/core/fbcon.c b/drivers/video/fbdev/core/fbcon.c
index f157a5a..90f335d 100644
--- a/drivers/video/fbdev/core/fbcon.c
+++ b/drivers/video/fbdev/core/fbcon.c
@@ -1050,7 +1050,7 @@ static void fbcon_init(struct vc_data *vc, int init)
 
 	vc->vc_can_do_color = (fb_get_color_depth(&info->var, &info->fix)!=1);
 	vc->vc_complement_mask = vc->vc_can_do_color ? 0x7700 : 0x0800;
-	if (vc->vc_font.charcount == 256) {
+	if (vc->vc_font.charcount != 512) {
 		vc->vc_hi_font_mask = 0;
 	} else {
 		vc->vc_hi_font_mask = 0x100;
@@ -1286,10 +1286,11 @@ static void fbcon_putcs(struct vc_data *vc, const unsigned short *s,
 
 static void fbcon_putc(struct vc_data *vc, int c, int ypos, int xpos)
 {
-	unsigned short chr;
+	unsigned short sc[2];
 
-	scr_writew(c, &chr);
-	fbcon_putcs(vc, &chr, 1, ypos, xpos);
+	sc[0] = (unsigned short) c;
+	sc[1] = (unsigned short) (c >> 16);
+	fbcon_putcs(vc, sc, 1, ypos, xpos);
 }
 
 static void fbcon_clear_margins(struct vc_data *vc, int bottom_only)
@@ -1371,7 +1372,7 @@ static void fbcon_set_disp(struct fb_info *info, struct fb_var_screeninfo *var,
 	ops->var = info->var;
 	vc->vc_can_do_color = (fb_get_color_depth(&info->var, &info->fix)!=1);
 	vc->vc_complement_mask = vc->vc_can_do_color ? 0x7700 : 0x0800;
-	if (vc->vc_font.charcount == 256) {
+	if (vc->vc_font.charcount != 512) {
 		vc->vc_hi_font_mask = 0;
 	} else {
 		vc->vc_hi_font_mask = 0x100;
@@ -1594,6 +1595,8 @@ static void fbcon_redraw_blit(struct vc_data *vc, struct fb_info *info,
 			}
 
 			scr_writew(c, d);
+			scr_writew(scr_readw(s + (vc->vc_screenbuf_size >> 1)),
+				d + (vc->vc_screenbuf_size >> 1));
 			console_conditional_schedule();
 			s++;
 			d++;
@@ -1615,6 +1618,7 @@ static void fbcon_redraw_blit(struct vc_data *vc, struct fb_info *info,
 
 static void fbcon_redraw(struct vc_data *vc, int line, int count, int offset)
 {
+	u16 charmask = vc->vc_hi_font_mask ? 0x1ff : 0xff;
 	unsigned short *d = (unsigned short *)
 	    (vc->vc_origin + vc->vc_size_row * line);
 	unsigned short *s = d + offset;
@@ -1637,18 +1641,24 @@ static void fbcon_redraw(struct vc_data *vc, int line, int count, int offset)
 					start = s;
 				}
 			}
-			if (c == scr_readw(d)) {
-				if (s > start) {
-					fbcon_putcs(vc, start, s - start,
-						     line, x);
-					x += s - start + 1;
-					start = s + 1;
-				} else {
-					x++;
-					start++;
+			if (((scr_readw(s) & charmask) == 0xff || (scr_readw(s) & charmask) == 0xfe)
+				&& scr_readw(s + (vc->vc_screenbuf_size >> 1))) {
+			} else {
+				if (c == scr_readw(d)) {
+					if (s > start) {
+						fbcon_putcs(vc, start, s - start,
+							     line, x);
+						x += s - start + 1;
+						start = s + 1;
+					} else {
+						x++;
+						start++;
+					}
 				}
 			}
 			scr_writew(c, d);
+			scr_writew(scr_readw(s + (vc->vc_screenbuf_size >> 1)),
+				d + (vc->vc_screenbuf_size >> 1));
 			console_conditional_schedule();
 			s++;
 			d++;
@@ -2140,7 +2150,7 @@ static int fbcon_switch(struct vc_data *vc)
 	vc->vc_can_do_color = (fb_get_color_depth(&info->var, &info->fix)!=1);
 	vc->vc_complement_mask = vc->vc_can_do_color ? 0x7700 : 0x0800;
 
-	if (vc->vc_font.charcount > 256)
+	if (vc->vc_font.charcount == 512)
 		vc->vc_complement_mask <<= 1;
 
 	updatescrollmode(p, info, vc);
@@ -2596,6 +2606,11 @@ static void fbcon_set_palette(struct vc_data *vc, const unsigned char *table)
 
 static u16 *fbcon_screen_pos(const struct vc_data *vc, int offset)
 {
+	if (offset < 0) {
+		offset = -offset - 1;
+		return (u16 *) (vc->vc_origin + offset + (vc->vc_screenbuf_size));
+	}
+
 	return (u16 *) (vc->vc_origin + offset);
 }
 
diff --git a/drivers/video/fbdev/core/fbcon.h b/drivers/video/fbdev/core/fbcon.h
index 0eaf54a..1e38d92 100644
--- a/drivers/video/fbdev/core/fbcon.h
+++ b/drivers/video/fbdev/core/fbcon.h
@@ -82,10 +82,12 @@ struct fbcon_ops {
 	int    cur_rotate;
 	char  *cursor_data;
 	u8    *fontbuffer;
+	u8    *fontbuffer_utf;
 	u8    *fontdata;
 	u8    *cursor_src;
 	u32    cursor_size;
 	u32    fd_size;
+	u32    fd_size_utf;
 };
     /*
      *  Attribute Decoding
diff --git a/drivers/video/fbdev/core/fbcon_ccw.c b/drivers/video/fbdev/core/fbcon_ccw.c
index 2789ace..ec68dbc 100644
--- a/drivers/video/fbdev/core/fbcon_ccw.c
+++ b/drivers/video/fbdev/core/fbcon_ccw.c
@@ -18,6 +18,8 @@
 #include "fbcon.h"
 #include "fbcon_rotate.h"
 
+extern u8 *font_bits(struct vc_data *vc, const u16 *s, u32 cellsize,
+		u16 charmask, struct fbcon_ops *ops);
 /*
  * Rotation 270 degrees
  */
@@ -106,7 +108,7 @@ static inline void ccw_putcs_aligned(struct vc_data *vc, struct fb_info *info,
 	u8 *src;
 
 	while (cnt--) {
-		src = ops->fontbuffer + (scr_readw(s--) & charmask)*cellsize;
+		src = font_bits(vc, s--, cellsize, charmask, ops);
 
 		if (attr) {
 			ccw_update_attr(buf, src, attr, vc);
@@ -238,7 +240,7 @@ static void ccw_cursor(struct vc_data *vc, struct fb_info *info, int mode,
 
  	c = scr_readw((u16 *) vc->vc_pos);
 	attribute = get_attribute(info, c);
-	src = ops->fontbuffer + ((c & charmask) * (w * vc->vc_font.width));
+	src = font_bits(vc, (u16 *) vc->vc_pos, (w * vc->vc_font.width), charmask, ops);
 
 	if (ops->cursor_state.image.data != src ||
 	    ops->cursor_reset) {
diff --git a/drivers/video/fbdev/core/fbcon_cw.c b/drivers/video/fbdev/core/fbcon_cw.c
index 86a254c..565cda9 100644
--- a/drivers/video/fbdev/core/fbcon_cw.c
+++ b/drivers/video/fbdev/core/fbcon_cw.c
@@ -18,6 +18,8 @@
 #include "fbcon.h"
 #include "fbcon_rotate.h"
 
+extern u8 *font_bits(struct vc_data *vc, const u16 *s, u32 cellsize,
+		u16 charmask, struct fbcon_ops *ops);
 /*
  * Rotation 90 degrees
  */
@@ -91,7 +93,7 @@ static inline void cw_putcs_aligned(struct vc_data *vc, struct fb_info *info,
 	u8 *src;
 
 	while (cnt--) {
-		src = ops->fontbuffer + (scr_readw(s++) & charmask)*cellsize;
+		src = font_bits(vc, s++, cellsize, charmask, ops);
 
 		if (attr) {
 			cw_update_attr(buf, src, attr, vc);
@@ -221,7 +223,7 @@ static void cw_cursor(struct vc_data *vc, struct fb_info *info, int mode,
 
  	c = scr_readw((u16 *) vc->vc_pos);
 	attribute = get_attribute(info, c);
-	src = ops->fontbuffer + ((c & charmask) * (w * vc->vc_font.width));
+	src = font_bits(vc, (u16 *) vc->vc_pos, (w * vc->vc_font.width), charmask, ops);
 
 	if (ops->cursor_state.image.data != src ||
 	    ops->cursor_reset) {
diff --git a/drivers/video/fbdev/core/fbcon_rotate.c b/drivers/video/fbdev/core/fbcon_rotate.c
index ec3c883..d549b08 100644
--- a/drivers/video/fbdev/core/fbcon_rotate.c
+++ b/drivers/video/fbdev/core/fbcon_rotate.c
@@ -14,10 +14,74 @@
 #include <linux/fb.h>
 #include <linux/vt_kern.h>
 #include <linux/console.h>
+#include <linux/font.h>
 #include <asm/types.h>
 #include "fbcon.h"
 #include "fbcon_rotate.h"
 
+static int fbcon_rotate_font_utf(struct fb_info *info, struct vc_data *vc)
+{
+	struct fbcon_ops *ops = info->fbcon_par;
+	int len, err = 0;
+	int s_cellsize, d_cellsize, i;
+	const u8 *src;
+	u8 *dst;
+
+	int cellsize = ((vc->vc_font.width + 7)/8) * vc->vc_font.height;
+	char *fontname = (cellsize < 64) ? "CJK16x16" : "CJK32x32";
+	const struct font_desc *font = find_font(fontname);
+
+	if (!font || !font->data)
+		return err;
+
+	src = font->data;
+	len = font->charcount;
+	s_cellsize = ((font->width + 7)/8) * font->height;
+	d_cellsize = s_cellsize;
+
+	if (ops->fd_size_utf < d_cellsize * len) {
+		dst = kvmalloc_array(len, d_cellsize, GFP_KERNEL | __GFP_RETRY_MAYFAIL);
+
+		if (dst == NULL) {
+			err = -ENOMEM;
+			return err;
+		}
+
+		ops->fd_size_utf = d_cellsize * len;
+		kvfree(ops->fontbuffer_utf);
+		ops->fontbuffer_utf = dst;
+	}
+
+	dst = ops->fontbuffer_utf;
+	memset(dst, 0, ops->fd_size_utf);
+
+	switch (ops->rotate) {
+	case FB_ROTATE_UD:
+		for (i = len; i--; ) {
+			rotate_ud(src, dst, font->width, font->height);
+			src += s_cellsize;
+			dst += d_cellsize;
+		}
+		break;
+	case FB_ROTATE_CW:
+		for (i = len; i--; ) {
+			rotate_cw(src, dst, font->width, font->height);
+			src += s_cellsize;
+			dst += d_cellsize;
+		}
+		break;
+	case FB_ROTATE_CCW:
+		for (i = len; i--; ) {
+			rotate_ccw(src, dst, font->width, font->height);
+			src += s_cellsize;
+			dst += d_cellsize;
+		}
+		break;
+	}
+
+	return err;
+}
+
 static int fbcon_rotate_font(struct fb_info *info, struct vc_data *vc)
 {
 	struct fbcon_ops *ops = info->fbcon_par;
@@ -46,7 +110,7 @@ static int fbcon_rotate_font(struct fb_info *info, struct vc_data *vc)
 		info->fbops->fb_sync(info);
 
 	if (ops->fd_size < d_cellsize * len) {
-		dst = kmalloc_array(len, d_cellsize, GFP_KERNEL);
+		dst = kvmalloc_array(len, d_cellsize, GFP_KERNEL | __GFP_RETRY_MAYFAIL);
 
 		if (dst == NULL) {
 			err = -ENOMEM;
@@ -54,7 +118,7 @@ static int fbcon_rotate_font(struct fb_info *info, struct vc_data *vc)
 		}
 
 		ops->fd_size = d_cellsize * len;
-		kfree(ops->fontbuffer);
+		kvfree(ops->fontbuffer);
 		ops->fontbuffer = dst;
 	}
 
@@ -89,6 +153,9 @@ static int fbcon_rotate_font(struct fb_info *info, struct vc_data *vc)
 		break;
 	}
 
+	if (ops->p->userfont)
+		fbcon_rotate_font_utf(info, vc);
+
 finished:
 	return err;
 }
diff --git a/drivers/video/fbdev/core/fbcon_ud.c b/drivers/video/fbdev/core/fbcon_ud.c
index 23bc045..6e7eaa5 100644
--- a/drivers/video/fbdev/core/fbcon_ud.c
+++ b/drivers/video/fbdev/core/fbcon_ud.c
@@ -18,6 +18,8 @@
 #include "fbcon.h"
 #include "fbcon_rotate.h"
 
+extern u8 *font_bits(struct vc_data *vc, const u16 *s, u32 cellsize,
+		u16 charmask, struct fbcon_ops *ops);
 /*
  * Rotation 180 degrees
  */
@@ -93,7 +95,7 @@ static inline void ud_putcs_aligned(struct vc_data *vc, struct fb_info *info,
 	u8 *src;
 
 	while (cnt--) {
-		src = ops->fontbuffer + (scr_readw(s--) & charmask)*cellsize;
+		src = font_bits(vc, s--, cellsize, charmask, ops);
 
 		if (attr) {
 			ud_update_attr(buf, src, attr, vc);
@@ -128,7 +130,7 @@ static inline void ud_putcs_unaligned(struct vc_data *vc,
 	u8 *src;
 
 	while (cnt--) {
-		src = ops->fontbuffer + (scr_readw(s--) & charmask)*cellsize;
+		src = font_bits(vc, s--, cellsize, charmask, ops);
 
 		if (attr) {
 			ud_update_attr(buf, src, attr, vc);
@@ -269,7 +271,7 @@ static void ud_cursor(struct vc_data *vc, struct fb_info *info, int mode,
 
  	c = scr_readw((u16 *) vc->vc_pos);
 	attribute = get_attribute(info, c);
-	src = ops->fontbuffer + ((c & charmask) * (w * vc->vc_font.height));
+	src = font_bits(vc, (u16 *) vc->vc_pos, (w * vc->vc_font.height), charmask, ops);
 
 	if (ops->cursor_state.image.data != src ||
 	    ops->cursor_reset) {
diff --git a/include/linux/font.h b/include/linux/font.h
index abf1442..9b19cae 100644
--- a/include/linux/font.h
+++ b/include/linux/font.h
@@ -35,6 +35,8 @@ struct font_desc {
 #define FONT6x10_IDX	10
 #define TER16x32_IDX	11
 #define FONT6x8_IDX	12
+#define CJK16x16_IDX	13
+#define CJK32x32_IDX	14
 
 extern const struct font_desc	font_vga_8x8,
 			font_vga_8x16,
@@ -48,7 +50,9 @@ extern const struct font_desc	font_vga_8x8,
 			font_mini_4x6,
 			font_6x10,
 			font_ter_16x32,
-			font_6x8;
+			font_6x8,
+			font_cjk_16x16,
+			font_cjk_32x32;
 
 /* Find a font with a specific name */
 
diff --git a/lib/fonts/Kconfig b/lib/fonts/Kconfig
index c035fde..f6fd619 100644
--- a/lib/fonts/Kconfig
+++ b/lib/fonts/Kconfig
@@ -125,6 +125,26 @@ config FONT_6x8
 	help
 	  This font is useful for small displays (OLED).
 
+config FONT_CJK_16x16
+	bool "CJK 16x16 font" if FONTS
+	depends on FRAMEBUFFER_CONSOLE && VT_CONSOLE
+	select CONSOLE_TRANSLATIONS
+	default y if !SPARC
+	help
+	  This is a high resolution console font that covers Unicode Basic
+	  Multilingual Plane (BMP), mostly is CJK font. If you want basic Unicode
+	  support on the VT console, say Y.
+
+config FONT_CJK_32x32
+	bool "CJK 32x32 font" if FONTS
+	depends on FRAMEBUFFER_CONSOLE && VT_CONSOLE
+	select CONSOLE_TRANSLATIONS
+	default y if !SPARC
+	help
+	  This is a more higher resolution console font that covers Unicode Basic
+	  Multilingual Plane (BMP), mostly is CJK font. If you want basic Unicode
+	  support on the VT console for a high res monitor, say Y.
+
 config FONT_AUTOSELECT
 	def_bool y
 	depends on !FONT_8x8
@@ -139,6 +159,8 @@ config FONT_AUTOSELECT
 	depends on !FONT_10x18
 	depends on !FONT_TER16x32
 	depends on !FONT_6x8
+	depends on !FONT_CJK_16x16
+	depends on !FONT_CJK_32x32
 	select FONT_8x16
 
 endif # FONT_SUPPORT
diff --git a/lib/fonts/Makefile b/lib/fonts/Makefile
index e16f684..3e1091d 100644
--- a/lib/fonts/Makefile
+++ b/lib/fonts/Makefile
@@ -16,6 +16,8 @@ font-objs-$(CONFIG_FONT_MINI_4x6)  += font_mini_4x6.o
 font-objs-$(CONFIG_FONT_6x10)      += font_6x10.o
 font-objs-$(CONFIG_FONT_TER16x32)  += font_ter16x32.o
 font-objs-$(CONFIG_FONT_6x8)       += font_6x8.o
+font-objs-$(CONFIG_FONT_CJK_16x16) += font_cjk_16x16.o
+font-objs-$(CONFIG_FONT_CJK_32x32) += font_cjk_32x32.o
 
 font-objs += $(font-objs-y)
 
diff --git a/lib/fonts/font_cjk_16x16.c b/lib/fonts/font_cjk_16x16.c
new file mode 100644
index 0000000..a0c56bd
--- /dev/null
+++ b/lib/fonts/font_cjk_16x16.c
@@ -0,0 +1,27 @@
+// SPDX-License-Identifier: GPL-2.0
+/***************************************************************/
+/*                                                             */
+/* Font file modified from                                     */
+/* http://blog.chinaunix.net/u/13265/showart.php?id=1008020    */
+/* microcaicai@gmail modifiy it to use in-kernel font solution */
+/*                                                             */
+/***************************************************************/
+
+#include <linux/font.h>
+
+#define FONTDATAMAX (65536 * 32)
+
+static const struct font_data fontdata_cjk_16x16 = {
+	{ 0, 0, FONTDATAMAX, 0 }, {
+	#include "font_cjk_16x16.h"
+}};
+
+const struct font_desc font_cjk_16x16 = {
+	.idx	= CJK16x16_IDX,
+	.name	= "CJK16x16",
+	.width	= 8, /* make cursor appear 8 dot width */
+	.height	= 16,
+	.charcount	= 65536 * 2,
+	.data	= fontdata_cjk_16x16.data,
+	.pref	= 20, /* make it big enough to be chosen */
+};
diff --git a/lib/fonts/font_cjk_16x16.h b/lib/fonts/font_cjk_16x16.h
new file mode 100644
index 0000000..54e7e0d
--- /dev/null
+++ b/lib/fonts/font_cjk_16x16.h
@@ -0,0 +1,196609 @@
+/* SPDX-License-Identifier: GPL-2.0 */
+/* 0 0x0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1 0x1 */
+0x00,0x00,0x7e,0x81,0xa5,0x81,0x81,0xbd,0x99,0x81,0x81,0x7e,0x00,0x00,0x00,0x00,
+/* 2 0x2 */
+0x00,0x00,0x7e,0xff,0xdb,0xff,0xff,0xc3,0xe7,0xff,0xff,0x7e,0x00,0x00,0x00,0x00,
+/* 3 0x3 */
+0x00,0x00,0x00,0x00,0x6c,0xfe,0xfe,0xfe,0xfe,0x7c,0x38,0x10,0x00,0x00,0x00,0x00,
+/* 4 0x4 */
+0x00,0x00,0x00,0x00,0x10,0x38,0x7c,0xfe,0x7c,0x38,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 5 0x5 */
+0x00,0x00,0x00,0x18,0x3c,0x3c,0xe7,0xe7,0xe7,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 6 0x6 */
+0x00,0x00,0x00,0x18,0x3c,0x7e,0xff,0xff,0x7e,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 7 0x7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8 0x8 */
+0xff,0xff,0xff,0xff,0xff,0xff,0xe7,0xc3,0xc3,0xe7,0xff,0xff,0xff,0xff,0xff,0xff,
+/* 9 0x9 */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x66,0x42,0x42,0x66,0x3c,0x00,0x00,0x00,0x00,0x00,
+/* 10 0xa */
+0xff,0xff,0xff,0xff,0xff,0xc3,0x99,0xbd,0xbd,0x99,0xc3,0xff,0xff,0xff,0xff,0xff,
+/* 11 0xb */
+0x00,0x00,0x1e,0x0e,0x1a,0x32,0x78,0xcc,0xcc,0xcc,0xcc,0x78,0x00,0x00,0x00,0x00,
+/* 12 0xc */
+0x00,0x00,0x3c,0x66,0x66,0x66,0x66,0x3c,0x18,0x7e,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 13 0xd */
+0x00,0x00,0x3f,0x33,0x3f,0x30,0x30,0x30,0x30,0x70,0xf0,0xe0,0x00,0x00,0x00,0x00,
+/* 14 0xe */
+0x00,0x00,0x7f,0x63,0x7f,0x63,0x63,0x63,0x63,0x67,0xe7,0xe6,0xc0,0x00,0x00,0x00,
+/* 15 0xf */
+0x00,0x00,0x00,0x18,0x18,0xdb,0x3c,0xe7,0x3c,0xdb,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 16 0x10 */
+0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xfe,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 17 0x11 */
+0x00,0x02,0x06,0x0e,0x1e,0x3e,0xfe,0x3e,0x1e,0x0e,0x06,0x02,0x00,0x00,0x00,0x00,
+/* 18 0x12 */
+0x00,0x00,0x18,0x3c,0x7e,0x18,0x18,0x18,0x7e,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 19 0x13 */
+0x00,0x00,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x00,0x66,0x66,0x00,0x00,0x00,0x00,
+/* 20 0x14 */
+0x00,0x00,0x7f,0xdb,0xdb,0xdb,0x7b,0x1b,0x1b,0x1b,0x1b,0x1b,0x00,0x00,0x00,0x00,
+/* 21 0x15 */
+0x00,0x7c,0xc6,0x60,0x38,0x6c,0xc6,0xc6,0x6c,0x38,0x0c,0xc6,0x7c,0x00,0x00,0x00,
+/* 22 0x16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xfe,0xfe,0xfe,0x00,0x00,0x00,0x00,
+/* 23 0x17 */
+0x00,0x00,0x18,0x3c,0x7e,0x18,0x18,0x18,0x7e,0x3c,0x18,0x7e,0x00,0x00,0x00,0x00,
+/* 24 0x18 */
+0x00,0x00,0x18,0x3c,0x7e,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 25 0x19 */
+0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x7e,0x3c,0x18,0x00,0x00,0x00,0x00,
+/* 26 0x1a */
+0x00,0x00,0x00,0x00,0x00,0x18,0x0c,0xfe,0x0c,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 27 0x1b */
+0x00,0x00,0x00,0x00,0x00,0x30,0x60,0xfe,0x60,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 28 0x1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 29 0x1d */
+0x00,0x00,0x00,0x00,0x00,0x28,0x6c,0xfe,0x6c,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 30 0x1e */
+0x00,0x00,0x00,0x00,0x10,0x38,0x38,0x7c,0x7c,0xfe,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 31 0x1f */
+0x00,0x00,0x00,0x00,0xfe,0xfe,0x7c,0x7c,0x38,0x38,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 32 0x20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 33 0x21 "!" */
+0x00,0x00,0x18,0x3c,0x3c,0x3c,0x18,0x18,0x18,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 34 0x22 """ */
+0x00,0x66,0x66,0x66,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 35 0x23 "#" */
+0x00,0x00,0x00,0x6c,0x6c,0xfe,0x6c,0x6c,0x6c,0xfe,0x6c,0x6c,0x00,0x00,0x00,0x00,
+/* 36 0x24 "$" */
+0x18,0x18,0x7c,0xc6,0xc2,0xc0,0x7c,0x06,0x06,0x86,0xc6,0x7c,0x18,0x18,0x00,0x00,
+/* 37 0x25 "%" */
+0x00,0x00,0x00,0x00,0xc2,0xc6,0x0c,0x18,0x30,0x60,0xc6,0x86,0x00,0x00,0x00,0x00,
+/* 38 0x26 "&" */
+0x00,0x00,0x38,0x6c,0x6c,0x38,0x76,0xdc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 39 0x27 "'" */
+0x00,0x30,0x30,0x30,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40 0x28 "(" */
+0x00,0x00,0x0c,0x18,0x30,0x30,0x30,0x30,0x30,0x30,0x18,0x0c,0x00,0x00,0x00,0x00,
+/* 41 0x29 ")" */
+0x00,0x00,0x30,0x18,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x18,0x30,0x00,0x00,0x00,0x00,
+/* 42 0x2a "*" */
+0x00,0x00,0x00,0x00,0x00,0x66,0x3c,0xff,0x3c,0x66,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43 0x2b "+" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x7e,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44 0x2c "," */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x30,0x00,0x00,0x00,
+/* 45 0x2d "-" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 46 0x2e "." */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 47 0x2f "/" */
+0x00,0x00,0x00,0x00,0x02,0x06,0x0c,0x18,0x30,0x60,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 48 0x30 "0" */
+0x00,0x00,0x38,0x6c,0xc6,0xc6,0xd6,0xd6,0xc6,0xc6,0x6c,0x38,0x00,0x00,0x00,0x00,
+/* 49 0x31 "1" */
+0x00,0x00,0x18,0x38,0x78,0x18,0x18,0x18,0x18,0x18,0x18,0x7e,0x00,0x00,0x00,0x00,
+/* 50 0x32 "2" */
+0x00,0x00,0x7c,0xc6,0x06,0x0c,0x18,0x30,0x60,0xc0,0xc6,0xfe,0x00,0x00,0x00,0x00,
+/* 51 0x33 "3" */
+0x00,0x00,0x7c,0xc6,0x06,0x06,0x3c,0x06,0x06,0x06,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 52 0x34 "4" */
+0x00,0x00,0x0c,0x1c,0x3c,0x6c,0xcc,0xfe,0x0c,0x0c,0x0c,0x1e,0x00,0x00,0x00,0x00,
+/* 53 0x35 "5" */
+0x00,0x00,0xfe,0xc0,0xc0,0xc0,0xfc,0x06,0x06,0x06,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 54 0x36 "6" */
+0x00,0x00,0x38,0x60,0xc0,0xc0,0xfc,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 55 0x37 "7" */
+0x00,0x00,0xfe,0xc6,0x06,0x06,0x0c,0x18,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,
+/* 56 0x38 "8" */
+0x00,0x00,0x7c,0xc6,0xc6,0xc6,0x7c,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 57 0x39 "9" */
+0x00,0x00,0x7c,0xc6,0xc6,0xc6,0x7e,0x06,0x06,0x06,0x0c,0x78,0x00,0x00,0x00,0x00,
+/* 58 0x3a ":" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 59 0x3b ";" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x30,0x00,0x00,0x00,0x00,
+/* 60 0x3c "<" */
+0x00,0x00,0x00,0x06,0x0c,0x18,0x30,0x60,0x30,0x18,0x0c,0x06,0x00,0x00,0x00,0x00,
+/* 61 0x3d "=" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62 0x3e ">" */
+0x00,0x00,0x00,0x60,0x30,0x18,0x0c,0x06,0x0c,0x18,0x30,0x60,0x00,0x00,0x00,0x00,
+/* 63 0x3f "?" */
+0x00,0x00,0x7c,0xc6,0xc6,0x0c,0x18,0x18,0x18,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 64 0x40 "@" */
+0x00,0x00,0x00,0x7c,0xc6,0xc6,0xde,0xde,0xde,0xdc,0xc0,0x7c,0x00,0x00,0x00,0x00,
+/* 65 0x41 "A" */
+0x00,0x00,0x10,0x38,0x6c,0xc6,0xc6,0xfe,0xc6,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 66 0x42 "B" */
+0x00,0x00,0xfc,0x66,0x66,0x66,0x7c,0x66,0x66,0x66,0x66,0xfc,0x00,0x00,0x00,0x00,
+/* 67 0x43 "C" */
+0x00,0x00,0x3c,0x66,0xc2,0xc0,0xc0,0xc0,0xc0,0xc2,0x66,0x3c,0x00,0x00,0x00,0x00,
+/* 68 0x44 "D" */
+0x00,0x00,0xf8,0x6c,0x66,0x66,0x66,0x66,0x66,0x66,0x6c,0xf8,0x00,0x00,0x00,0x00,
+/* 69 0x45 "E" */
+0x00,0x00,0xfe,0x66,0x62,0x68,0x78,0x68,0x60,0x62,0x66,0xfe,0x00,0x00,0x00,0x00,
+/* 70 0x46 "F" */
+0x00,0x00,0xfe,0x66,0x62,0x68,0x78,0x68,0x60,0x60,0x60,0xf0,0x00,0x00,0x00,0x00,
+/* 71 0x47 "G" */
+0x00,0x00,0x3c,0x66,0xc2,0xc0,0xc0,0xde,0xc6,0xc6,0x66,0x3a,0x00,0x00,0x00,0x00,
+/* 72 0x48 "H" */
+0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xfe,0xc6,0xc6,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 73 0x49 "I" */
+0x00,0x00,0x3c,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 74 0x4a "J" */
+0x00,0x00,0x1e,0x0c,0x0c,0x0c,0x0c,0x0c,0xcc,0xcc,0xcc,0x78,0x00,0x00,0x00,0x00,
+/* 75 0x4b "K" */
+0x00,0x00,0xe6,0x66,0x66,0x6c,0x78,0x78,0x6c,0x66,0x66,0xe6,0x00,0x00,0x00,0x00,
+/* 76 0x4c "L" */
+0x00,0x00,0xf0,0x60,0x60,0x60,0x60,0x60,0x60,0x62,0x66,0xfe,0x00,0x00,0x00,0x00,
+/* 77 0x4d "M" */
+0x00,0x00,0xc6,0xee,0xfe,0xfe,0xd6,0xc6,0xc6,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 78 0x4e "N" */
+0x00,0x00,0xc6,0xe6,0xf6,0xfe,0xde,0xce,0xc6,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 79 0x4f "O" */
+0x00,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 80 0x50 "P" */
+0x00,0x00,0xfc,0x66,0x66,0x66,0x7c,0x60,0x60,0x60,0x60,0xf0,0x00,0x00,0x00,0x00,
+/* 81 0x51 "Q" */
+0x00,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xd6,0xde,0x7c,0x0c,0x0e,0x00,0x00,
+/* 82 0x52 "R" */
+0x00,0x00,0xfc,0x66,0x66,0x66,0x7c,0x6c,0x66,0x66,0x66,0xe6,0x00,0x00,0x00,0x00,
+/* 83 0x53 "S" */
+0x00,0x00,0x7c,0xc6,0xc6,0x60,0x38,0x0c,0x06,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 84 0x54 "T" */
+0x00,0x00,0x7e,0x7e,0x5a,0x18,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 85 0x55 "U" */
+0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 86 0x56 "V" */
+0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x6c,0x38,0x10,0x00,0x00,0x00,0x00,
+/* 87 0x57 "W" */
+0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xd6,0xd6,0xd6,0xfe,0xee,0x6c,0x00,0x00,0x00,0x00,
+/* 88 0x58 "X" */
+0x00,0x00,0xc6,0xc6,0x6c,0x7c,0x38,0x38,0x7c,0x6c,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 89 0x59 "Y" */
+0x00,0x00,0x66,0x66,0x66,0x66,0x3c,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 90 0x5a "Z" */
+0x00,0x00,0xfe,0xc6,0x86,0x0c,0x18,0x30,0x60,0xc2,0xc6,0xfe,0x00,0x00,0x00,0x00,
+/* 91 0x5b "[" */
+0x00,0x00,0x3c,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x3c,0x00,0x00,0x00,0x00,
+/* 92 0x5c "\" */
+0x00,0x00,0x00,0x80,0xc0,0xe0,0x70,0x38,0x1c,0x0e,0x06,0x02,0x00,0x00,0x00,0x00,
+/* 93 0x5d "]" */
+0x00,0x00,0x3c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x3c,0x00,0x00,0x00,0x00,
+/* 94 0x5e "^" */
+0x10,0x38,0x6c,0xc6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 95 0x5f "_" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 96 0x60 "`" */
+0x00,0x30,0x18,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 97 0x61 "a" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x0c,0x7c,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 98 0x62 "b" */
+0x00,0x00,0xe0,0x60,0x60,0x78,0x6c,0x66,0x66,0x66,0x66,0x7c,0x00,0x00,0x00,0x00,
+/* 99 0x63 "c" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0xc6,0xc0,0xc0,0xc0,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 100 0x64 "d" */
+0x00,0x00,0x1c,0x0c,0x0c,0x3c,0x6c,0xcc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 101 0x65 "e" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0xc6,0xfe,0xc0,0xc0,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 102 0x66 "f" */
+0x00,0x00,0x1c,0x36,0x32,0x30,0x78,0x30,0x30,0x30,0x30,0x78,0x00,0x00,0x00,0x00,
+/* 103 0x67 "g" */
+0x00,0x00,0x00,0x00,0x00,0x76,0xcc,0xcc,0xcc,0xcc,0xcc,0x7c,0x0c,0xcc,0x78,0x00,
+/* 104 0x68 "h" */
+0x00,0x00,0xe0,0x60,0x60,0x6c,0x76,0x66,0x66,0x66,0x66,0xe6,0x00,0x00,0x00,0x00,
+/* 105 0x69 "i" */
+0x00,0x00,0x18,0x18,0x00,0x38,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 106 0x6a "j" */
+0x00,0x00,0x06,0x06,0x00,0x0e,0x06,0x06,0x06,0x06,0x06,0x06,0x66,0x66,0x3c,0x00,
+/* 107 0x6b "k" */
+0x00,0x00,0xe0,0x60,0x60,0x66,0x6c,0x78,0x78,0x6c,0x66,0xe6,0x00,0x00,0x00,0x00,
+/* 108 0x6c "l" */
+0x00,0x00,0x38,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 109 0x6d "m" */
+0x00,0x00,0x00,0x00,0x00,0xec,0xfe,0xd6,0xd6,0xd6,0xd6,0xc6,0x00,0x00,0x00,0x00,
+/* 110 0x6e "n" */
+0x00,0x00,0x00,0x00,0x00,0xdc,0x66,0x66,0x66,0x66,0x66,0x66,0x00,0x00,0x00,0x00,
+/* 111 0x6f "o" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 112 0x70 "p" */
+0x00,0x00,0x00,0x00,0x00,0xdc,0x66,0x66,0x66,0x66,0x66,0x7c,0x60,0x60,0xf0,0x00,
+/* 113 0x71 "q" */
+0x00,0x00,0x00,0x00,0x00,0x76,0xcc,0xcc,0xcc,0xcc,0xcc,0x7c,0x0c,0x0c,0x1e,0x00,
+/* 114 0x72 "r" */
+0x00,0x00,0x00,0x00,0x00,0xdc,0x76,0x66,0x60,0x60,0x60,0xf0,0x00,0x00,0x00,0x00,
+/* 115 0x73 "s" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0xc6,0x60,0x38,0x0c,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 116 0x74 "t" */
+0x00,0x00,0x10,0x30,0x30,0xfc,0x30,0x30,0x30,0x30,0x36,0x1c,0x00,0x00,0x00,0x00,
+/* 117 0x75 "u" */
+0x00,0x00,0x00,0x00,0x00,0xcc,0xcc,0xcc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 118 0x76 "v" */
+0x00,0x00,0x00,0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xc6,0x6c,0x38,0x00,0x00,0x00,0x00,
+/* 119 0x77 "w" */
+0x00,0x00,0x00,0x00,0x00,0xc6,0xc6,0xd6,0xd6,0xd6,0xfe,0x6c,0x00,0x00,0x00,0x00,
+/* 120 0x78 "x" */
+0x00,0x00,0x00,0x00,0x00,0xc6,0x6c,0x38,0x38,0x38,0x6c,0xc6,0x00,0x00,0x00,0x00,
+/* 121 0x79 "y" */
+0x00,0x00,0x00,0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x7e,0x06,0x0c,0xf8,0x00,
+/* 122 0x7a "z" */
+0x00,0x00,0x00,0x00,0x00,0xfe,0xcc,0x18,0x30,0x60,0xc6,0xfe,0x00,0x00,0x00,0x00,
+/* 123 0x7b "{" */
+0x00,0x00,0x0e,0x18,0x18,0x18,0x70,0x18,0x18,0x18,0x18,0x0e,0x00,0x00,0x00,0x00,
+/* 124 0x7c "|" */
+0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 125 0x7d "}" */
+0x00,0x00,0x70,0x18,0x18,0x18,0x0e,0x18,0x18,0x18,0x18,0x70,0x00,0x00,0x00,0x00,
+/* 126 0x7e "~" */
+0x00,0x76,0xdc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 127 0x7f "" */
+0x00,0x00,0x00,0x00,0x10,0x38,0x6c,0xc6,0xc6,0xc6,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 128 0x80 "" */
+0x00,0x00,0x3c,0x66,0xc2,0xc0,0xc0,0xc0,0xc0,0xc2,0x66,0x3c,0x18,0x70,0x00,0x00,
+/* 129 0x81 "" */
+0x00,0x00,0xcc,0x00,0x00,0xcc,0xcc,0xcc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 130 0x82 "" */
+0x00,0x0c,0x18,0x30,0x00,0x7c,0xc6,0xfe,0xc0,0xc0,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 131 0x83 "" */
+0x00,0x10,0x38,0x6c,0x00,0x78,0x0c,0x7c,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 132 0x84 "" */
+0x00,0x00,0xcc,0x00,0x00,0x78,0x0c,0x7c,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 133 0x85 "" */
+0x00,0x60,0x30,0x18,0x00,0x78,0x0c,0x7c,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 134 0x86 "" */
+0x00,0x38,0x6c,0x38,0x00,0x78,0x0c,0x7c,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 135 0x87 "" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0xc6,0xc0,0xc0,0xc0,0xc6,0x7c,0x18,0x70,0x00,0x00,
+/* 136 0x88 "" */
+0x00,0x10,0x38,0x6c,0x00,0x7c,0xc6,0xfe,0xc0,0xc0,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 137 0x89 "" */
+0x00,0x00,0xc6,0x00,0x00,0x7c,0xc6,0xfe,0xc0,0xc0,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 138 0x8a "" */
+0x00,0x60,0x30,0x18,0x00,0x7c,0xc6,0xfe,0xc0,0xc0,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 139 0x8b "" */
+0x00,0x00,0x66,0x00,0x00,0x38,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 140 0x8c "" */
+0x00,0x18,0x3c,0x66,0x00,0x38,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 141 0x8d "" */
+0x00,0x60,0x30,0x18,0x00,0x38,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 142 0x8e "" */
+0x00,0xc6,0x00,0x10,0x38,0x6c,0xc6,0xc6,0xfe,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 143 0x8f "" */
+0x38,0x6c,0x38,0x10,0x38,0x6c,0xc6,0xfe,0xc6,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 144 0x90 "" */
+0x0c,0x18,0x00,0xfe,0x66,0x62,0x68,0x78,0x68,0x62,0x66,0xfe,0x00,0x00,0x00,0x00,
+/* 145 0x91 "" */
+0x00,0x00,0x00,0x00,0x00,0xec,0x36,0x36,0x7e,0xd8,0xd8,0x6e,0x00,0x00,0x00,0x00,
+/* 146 0x92 "" */
+0x00,0x00,0x3e,0x6c,0xcc,0xcc,0xfe,0xcc,0xcc,0xcc,0xcc,0xce,0x00,0x00,0x00,0x00,
+/* 147 0x93 "" */
+0x00,0x10,0x38,0x6c,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 148 0x94 "" */
+0x00,0x00,0xc6,0x00,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 149 0x95 "" */
+0x00,0x60,0x30,0x18,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 150 0x96 "" */
+0x00,0x30,0x78,0xcc,0x00,0xcc,0xcc,0xcc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 151 0x97 "" */
+0x00,0x60,0x30,0x18,0x00,0xcc,0xcc,0xcc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 152 0x98 "" */
+0x00,0x00,0xc6,0x00,0x00,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x7e,0x06,0x0c,0x78,0x00,
+/* 153 0x99 "" */
+0x00,0xc6,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 154 0x9a "" */
+0x00,0xc6,0x00,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 155 0x9b "" */
+0x00,0x18,0x18,0x7c,0xc6,0xc0,0xc0,0xc0,0xc6,0x7c,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 156 0x9c "" */
+0x00,0x38,0x6c,0x64,0x60,0xf0,0x60,0x60,0x60,0x60,0xe6,0xfc,0x00,0x00,0x00,0x00,
+/* 157 0x9d "" */
+0x00,0x00,0x66,0x66,0x3c,0x18,0x7e,0x18,0x7e,0x18,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 158 0x9e "" */
+0x00,0xf8,0xcc,0xcc,0xf8,0xc4,0xcc,0xde,0xcc,0xcc,0xcc,0xc6,0x00,0x00,0x00,0x00,
+/* 159 0x9f "" */
+0x00,0x0e,0x1b,0x18,0x18,0x18,0x7e,0x18,0x18,0x18,0xd8,0x70,0x00,0x00,0x00,0x00,
+/* 160 0xa0 " " */
+0x00,0x18,0x30,0x60,0x00,0x78,0x0c,0x7c,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 161 0xa1 "¡" */
+0x00,0x0c,0x18,0x30,0x00,0x38,0x18,0x18,0x18,0x18,0x18,0x3c,0x00,0x00,0x00,0x00,
+/* 162 0xa2 "¢" */
+0x00,0x18,0x30,0x60,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 163 0xa3 "£" */
+0x00,0x18,0x30,0x60,0x00,0xcc,0xcc,0xcc,0xcc,0xcc,0xcc,0x76,0x00,0x00,0x00,0x00,
+/* 164 0xa4 "¤" */
+0x00,0x00,0x76,0xdc,0x00,0xdc,0x66,0x66,0x66,0x66,0x66,0x66,0x00,0x00,0x00,0x00,
+/* 165 0xa5 "¥" */
+0x76,0xdc,0x00,0xc6,0xe6,0xf6,0xfe,0xde,0xce,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 166 0xa6 "¦" */
+0x00,0x00,0x3c,0x6c,0x6c,0x3e,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 167 0xa7 "§" */
+0x00,0x00,0x38,0x6c,0x6c,0x38,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 168 0xa8 "¨" */
+0x00,0x00,0x30,0x30,0x00,0x30,0x30,0x60,0xc0,0xc6,0xc6,0x7c,0x00,0x00,0x00,0x00,
+/* 169 0xa9 "©" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xc0,0xc0,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 170 0xaa "ª" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x06,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+/* 171 0xab "«" */
+0x00,0x60,0xe0,0x62,0x66,0x6c,0x18,0x30,0x60,0xdc,0x86,0x0c,0x18,0x3e,0x00,0x00,
+/* 172 0xac "¬" */
+0x00,0x60,0xe0,0x62,0x66,0x6c,0x18,0x30,0x66,0xce,0x9a,0x3f,0x06,0x06,0x00,0x00,
+/* 173 0xad "­" */
+0x00,0x00,0x18,0x18,0x00,0x18,0x18,0x18,0x3c,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,
+/* 174 0xae "®" */
+0x00,0x00,0x00,0x00,0x00,0x36,0x6c,0xd8,0x6c,0x36,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 175 0xaf "¯" */
+0x00,0x00,0x00,0x00,0x00,0xd8,0x6c,0x36,0x6c,0xd8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 176 0xb0 "°" */
+0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44,
+/* 177 0xb1 "±" */
+0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,
+/* 178 0xb2 "²" */
+0xdd,0x77,0xdd,0x77,0xdd,0x77,0xdd,0x77,0xdd,0x77,0xdd,0x77,0xdd,0x77,0xdd,0x77,
+/* 179 0xb3 "³" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 180 0xb4 "´" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 181 0xb5 "µ" */
+0x18,0x18,0x18,0x18,0x18,0xf8,0x18,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 182 0xb6 "¶" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xf6,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 183 0xb7 "·" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 184 0xb8 "¸" */
+0x00,0x00,0x00,0x00,0x00,0xf8,0x18,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 185 0xb9 "¹" */
+0x36,0x36,0x36,0x36,0x36,0xf6,0x06,0xf6,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 186 0xba "º" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 187 0xbb "»" */
+0x00,0x00,0x00,0x00,0x00,0xfe,0x06,0xf6,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 188 0xbc "¼" */
+0x36,0x36,0x36,0x36,0x36,0xf6,0x06,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 189 0xbd "½" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 190 0xbe "¾" */
+0x18,0x18,0x18,0x18,0x18,0xf8,0x18,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 191 0xbf "¿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 192 0xc0 "À" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 193 0xc1 "Á" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 194 0xc2 "Â" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 195 0xc3 "Ã" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 196 0xc4 "Ä" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 197 0xc5 "Å" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 198 0xc6 "Æ" */
+0x18,0x18,0x18,0x18,0x18,0x1f,0x18,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 199 0xc7 "Ç" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x37,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 200 0xc8 "È" */
+0x36,0x36,0x36,0x36,0x36,0x37,0x30,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 201 0xc9 "É" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x30,0x37,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 202 0xca "Ê" */
+0x36,0x36,0x36,0x36,0x36,0xf7,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 203 0xcb "Ë" */
+0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xf7,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 204 0xcc "Ì" */
+0x36,0x36,0x36,0x36,0x36,0x37,0x30,0x37,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 205 0xcd "Í" */
+0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 206 0xce "Î" */
+0x36,0x36,0x36,0x36,0x36,0xf7,0x00,0xf7,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 207 0xcf "Ï" */
+0x18,0x18,0x18,0x18,0x18,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 208 0xd0 "Ð" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 209 0xd1 "Ñ" */
+0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 210 0xd2 "Ò" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 211 0xd3 "Ó" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 212 0xd4 "Ô" */
+0x18,0x18,0x18,0x18,0x18,0x1f,0x18,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 213 0xd5 "Õ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x18,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 214 0xd6 "Ö" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 215 0xd7 "×" */
+0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xff,0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
+/* 216 0xd8 "Ø" */
+0x18,0x18,0x18,0x18,0x18,0xff,0x18,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 217 0xd9 "Ù" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 218 0xda "Ú" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 219 0xdb "Û" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+/* 220 0xdc "Ü" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+/* 221 0xdd "Ý" */
+0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,
+/* 222 0xde "Þ" */
+0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,
+/* 223 0xdf "ß" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 224 0xe0 "à" */
+0x00,0x00,0x00,0x00,0x00,0x76,0xdc,0xd8,0xd8,0xd8,0xdc,0x76,0x00,0x00,0x00,0x00,
+/* 225 0xe1 "á" */
+0x00,0x00,0x78,0xcc,0xcc,0xcc,0xd8,0xcc,0xc6,0xc6,0xc6,0xcc,0x00,0x00,0x00,0x00,
+/* 226 0xe2 "â" */
+0x00,0x00,0xfe,0xc6,0xc6,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,0x00,0x00,
+/* 227 0xe3 "ã" */
+0x00,0x00,0x00,0x00,0x00,0xfe,0x6c,0x6c,0x6c,0x6c,0x6c,0x6c,0x00,0x00,0x00,0x00,
+/* 228 0xe4 "ä" */
+0x00,0x00,0xfe,0xc6,0x60,0x30,0x18,0x18,0x30,0x60,0xc6,0xfe,0x00,0x00,0x00,0x00,
+/* 229 0xe5 "å" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0xd8,0xd8,0xd8,0xd8,0xd8,0x70,0x00,0x00,0x00,0x00,
+/* 230 0xe6 "æ" */
+0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x66,0x66,0x66,0x7c,0x60,0x60,0xc0,0x00,
+/* 231 0xe7 "ç" */
+0x00,0x00,0x00,0x00,0x76,0xdc,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 232 0xe8 "è" */
+0x00,0x00,0x7e,0x18,0x3c,0x66,0x66,0x66,0x66,0x3c,0x18,0x7e,0x00,0x00,0x00,0x00,
+/* 233 0xe9 "é" */
+0x00,0x00,0x38,0x6c,0xc6,0xc6,0xfe,0xc6,0xc6,0xc6,0x6c,0x38,0x00,0x00,0x00,0x00,
+/* 234 0xea "ê" */
+0x00,0x00,0x38,0x6c,0xc6,0xc6,0xc6,0x6c,0x6c,0x6c,0x6c,0xee,0x00,0x00,0x00,0x00,
+/* 235 0xeb "ë" */
+0x00,0x00,0x1e,0x30,0x18,0x0c,0x3e,0x66,0x66,0x66,0x66,0x3c,0x00,0x00,0x00,0x00,
+/* 236 0xec "ì" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0xdb,0xdb,0xdb,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 237 0xed "í" */
+0x00,0x00,0x00,0x03,0x06,0x7e,0xdb,0xdb,0xf3,0x7e,0x60,0xc0,0x00,0x00,0x00,0x00,
+/* 238 0xee "î" */
+0x00,0x00,0x1c,0x30,0x60,0x60,0x7c,0x60,0x60,0x60,0x30,0x1c,0x00,0x00,0x00,0x00,
+/* 239 0xef "ï" */
+0x00,0x00,0x00,0x7c,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0xc6,0x00,0x00,0x00,0x00,
+/* 240 0xf0 "ð" */
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0xfe,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 241 0xf1 "ñ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x7e,0x18,0x18,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+/* 242 0xf2 "ò" */
+0x00,0x00,0x00,0x30,0x18,0x0c,0x06,0x0c,0x18,0x30,0x00,0x7e,0x00,0x00,0x00,0x00,
+/* 243 0xf3 "ó" */
+0x00,0x00,0x00,0x0c,0x18,0x30,0x60,0x30,0x18,0x0c,0x00,0x7e,0x00,0x00,0x00,0x00,
+/* 244 0xf4 "ô" */
+0x00,0x00,0x0e,0x1b,0x1b,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+/* 245 0xf5 "õ" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xd8,0xd8,0xd8,0x70,0x00,0x00,0x00,
+/* 246 0xf6 "ö" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x7e,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 247 0xf7 "÷" */
+0x00,0x00,0x00,0x00,0x00,0x76,0xdc,0x00,0x76,0xdc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 248 0xf8 "ø" */
+0x00,0x38,0x6c,0x6c,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 249 0xf9 "ù" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 250 0xfa "ú" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 251 0xfb "û" */
+0x00,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0xec,0x6c,0x6c,0x3c,0x1c,0x00,0x00,0x00,0x00,
+/* 252 0xfc "ü" */
+0x00,0x6c,0x36,0x36,0x36,0x36,0x36,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 253 0xfd "ý" */
+0x00,0x3c,0x66,0x0c,0x18,0x32,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 254 0xfe "þ" */
+0x00,0x00,0x00,0x00,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x00,0x00,0x00,0x00,0x00,
+/* 255 0xff "ÿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 256 0x100 "Ā" */
+0x00,0x3c,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 257 0x101 "ā" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 258 0x102 "Ă" */
+0x42,0x42,0x3c,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 259 0x103 "ă" */
+0x00,0x42,0x42,0x3c,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 260 0x104 "Ą" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 261 0x105 "ą" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 262 0x106 "Ć" */
+0x0c,0x30,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 263 0x107 "ć" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 264 0x108 "Ĉ" */
+0x18,0x24,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 265 0x109 "ĉ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 266 0x10a "Ċ" */
+0x10,0x10,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 267 0x10b "ċ" */
+0x00,0x00,0x10,0x10,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 268 0x10c "Č" */
+0x24,0x18,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 269 0x10d "č" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 270 0x10e "Ď" */
+0x48,0x30,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 271 0x10f "ď" */
+0x00,0x00,0x00,0x16,0x12,0x12,0x54,0xb0,0x90,0x90,0x90,0x90,0xb0,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 272 0x110 "Đ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0xf2,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 273 0x111 "đ" */
+0x00,0x00,0x00,0x02,0x0f,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 274 0x112 "Ē" */
+0x00,0x3c,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 275 0x113 "ē" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 276 0x114 "Ĕ" */
+0x42,0x42,0x3c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 277 0x115 "ĕ" */
+0x00,0x00,0x42,0x42,0x3c,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 278 0x116 "Ė" */
+0x10,0x10,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 279 0x117 "ė" */
+0x00,0x00,0x10,0x10,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 280 0x118 "Ę" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 281 0x119 "ę" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 282 0x11a "Ě" */
+0x24,0x18,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 283 0x11b "ě" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 284 0x11c "Ĝ" */
+0x18,0x24,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 285 0x11d "ĝ" */
+0x00,0x00,0x18,0x24,0x00,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 286 0x11e "Ğ" */
+0x42,0x42,0x3c,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 287 0x11f "ğ" */
+0x00,0x42,0x42,0x3c,0x00,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 288 0x120 "Ġ" */
+0x10,0x10,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 289 0x121 "ġ" */
+0x00,0x00,0x10,0x10,0x00,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 290 0x122 "Ģ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 291 0x123 "ģ" */
+0x00,0x00,0x20,0x20,0x18,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 292 0x124 "Ĥ" */
+0x18,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 293 0x125 "ĥ" */
+0x30,0x48,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 294 0x126 "Ħ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0xff,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 295 0x127 "ħ" */
+0x00,0x00,0x00,0x40,0xf0,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 296 0x128 "Ĩ" */
+0x32,0x4c,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 297 0x129 "ĩ" */
+0x00,0x00,0x32,0x4c,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 298 0x12a "Ī" */
+0x00,0x3c,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 299 0x12b "ī" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 300 0x12c "Ĭ" */
+0x42,0x42,0x3c,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 301 0x12d "ĭ" */
+0x00,0x00,0x42,0x42,0x3c,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 302 0x12e "Į" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 303 0x12f "į" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 304 0x130 "İ" */
+0x08,0x08,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 305 0x131 "ı" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 306 0x132 "Ĳ" */
+0x00,0x00,0x00,0x00,0x77,0x22,0x22,0x22,0x22,0x22,0x22,0x72,0x02,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 307 0x133 "ĳ" */
+0x00,0x00,0x00,0x22,0x22,0x00,0x66,0x22,0x22,0x22,0x22,0x72,0x02,0x02,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 308 0x134 "Ĵ" */
+0x0c,0x12,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 309 0x135 "ĵ" */
+0x00,0x00,0x0c,0x12,0x00,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 310 0x136 "Ķ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 311 0x137 "ķ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 312 0x138 "ĸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x70,0x70,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 313 0x139 "Ĺ" */
+0x18,0x60,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 314 0x13a "ĺ" */
+0x0c,0x30,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 315 0x13b "Ļ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 316 0x13c "ļ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 317 0x13d "Ľ" */
+0x24,0x18,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 318 0x13e "ľ" */
+0x00,0x00,0x00,0x36,0x12,0x12,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 319 0x13f "Ŀ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x44,0x44,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 320 0x140 "ŀ" */
+0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x14,0x14,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 321 0x141 "Ł" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x48,0x50,0x60,0xc0,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 322 0x142 "ł" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x0a,0x0c,0x18,0x28,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 323 0x143 "Ń" */
+0x0c,0x30,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 324 0x144 "ń" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 325 0x145 "Ņ" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 326 0x146 "ņ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 327 0x147 "Ň" */
+0x24,0x18,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 328 0x148 "ň" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 329 0x149 "ŉ" */
+0x00,0x60,0x20,0x20,0x40,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 330 0x14a "Ŋ" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 331 0x14b "ŋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 332 0x14c "Ō" */
+0x00,0x3c,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 333 0x14d "ō" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 334 0x14e "Ŏ" */
+0x42,0x42,0x3c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 335 0x14f "ŏ" */
+0x00,0x00,0x42,0x42,0x3c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 336 0x150 "Ő" */
+0x33,0x44,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 337 0x151 "ő" */
+0x00,0x00,0x33,0x44,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 338 0x152 "Œ" */
+0x00,0x00,0x00,0x00,0x37,0x48,0x48,0x48,0x4e,0x48,0x48,0x48,0x48,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 339 0x153 "œ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x4f,0x48,0x48,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 340 0x154 "Ŕ" */
+0x0c,0x30,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 341 0x155 "ŕ" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 342 0x156 "Ŗ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 343 0x157 "ŗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 344 0x158 "Ř" */
+0x24,0x18,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 345 0x159 "ř" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 346 0x15a "Ś" */
+0x0c,0x30,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 347 0x15b "ś" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 348 0x15c "Ŝ" */
+0x18,0x24,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 349 0x15d "ŝ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 350 0x15e "Ş" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 351 0x15f "ş" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 352 0x160 "Š" */
+0x24,0x18,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 353 0x161 "š" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 354 0x162 "Ţ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 355 0x163 "ţ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 356 0x164 "Ť" */
+0x24,0x18,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 357 0x165 "ť" */
+0x00,0x00,0x06,0x02,0x22,0x24,0x20,0xf8,0x20,0x20,0x20,0x20,0x20,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 358 0x166 "Ŧ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x3e,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 359 0x167 "ŧ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x7c,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 360 0x168 "Ũ" */
+0x32,0x4c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 361 0x169 "ũ" */
+0x00,0x00,0x32,0x4c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 362 0x16a "Ū" */
+0x00,0x3c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 363 0x16b "ū" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 364 0x16c "Ŭ" */
+0x42,0x42,0x3c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 365 0x16d "ŭ" */
+0x00,0x42,0x42,0x3c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 366 0x16e "Ů" */
+0x18,0x24,0x18,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 367 0x16f "ů" */
+0x00,0x00,0x18,0x24,0x18,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 368 0x170 "Ű" */
+0x33,0x44,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 369 0x171 "ű" */
+0x00,0x00,0x33,0x44,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 370 0x172 "Ų" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 371 0x173 "ų" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 372 0x174 "Ŵ" */
+0x18,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 373 0x175 "ŵ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 374 0x176 "Ŷ" */
+0x18,0x24,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 375 0x177 "ŷ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 376 0x178 "Ÿ" */
+0x24,0x24,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 377 0x179 "Ź" */
+0x0c,0x30,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 378 0x17a "ź" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 379 0x17b "Ż" */
+0x10,0x10,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 380 0x17c "ż" */
+0x00,0x00,0x10,0x10,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 381 0x17d "Ž" */
+0x24,0x18,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 382 0x17e "ž" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 383 0x17f "ſ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 384 0x180 "ƀ" */
+0x00,0x00,0x00,0x40,0xf0,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 385 0x181 "Ɓ" */
+0x00,0x00,0x00,0x00,0x7c,0xa2,0xa2,0x22,0x3c,0x22,0x22,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 386 0x182 "Ƃ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 387 0x183 "ƃ" */
+0x00,0x00,0x00,0x7c,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 388 0x184 "Ƅ" */
+0x00,0x00,0x00,0x00,0x60,0x20,0x20,0x20,0x3c,0x22,0x22,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 389 0x185 "ƅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x20,0x20,0x3c,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 390 0x186 "Ɔ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 391 0x187 "Ƈ" */
+0x00,0x00,0x03,0x04,0x3c,0x44,0x44,0x40,0x40,0x40,0x40,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 392 0x188 "ƈ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x3c,0x44,0x40,0x40,0x40,0x40,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 393 0x189 "Ɖ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0xf2,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 394 0x18a "Ɗ" */
+0x00,0x00,0x00,0x00,0x78,0xa4,0xa2,0x22,0x22,0x22,0x22,0x22,0x24,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 395 0x18b "Ƌ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x3e,0x42,0x42,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 396 0x18c "ƌ" */
+0x00,0x00,0x00,0x3e,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 397 0x18d "ƍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x24,0x18,0x04,0x04,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 398 0x18e "Ǝ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x3e,0x02,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 399 0x18f "Ə" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x02,0x02,0x7e,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 400 0x190 "Ɛ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x38,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 401 0x191 "Ƒ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 402 0x192 "ƒ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 403 0x193 "Ɠ" */
+0x00,0x00,0x00,0x03,0x3c,0x44,0x44,0x40,0x40,0x5c,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 404 0x194 "Ɣ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 405 0x195 "ƕ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x72,0x4a,0x4a,0x4a,0x4a,0x4a,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 406 0x196 "Ɩ" */
+0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 407 0x197 "Ɨ" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x3e,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 408 0x198 "Ƙ" */
+0x00,0x00,0x00,0x00,0x46,0x4a,0x50,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 409 0x199 "ƙ" */
+0x00,0x00,0x00,0x30,0x48,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 410 0x19a "ƚ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x3e,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 411 0x19b "ƛ" */
+0x00,0x00,0x00,0x00,0x24,0x28,0x10,0x30,0x48,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 412 0x19c "Ɯ" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 413 0x19d "Ɲ" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x32,0x32,0x2a,0x2a,0x26,0x26,0x22,0x22,0xc0,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 414 0x19e "ƞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 415 0x19f "Ɵ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 416 0x1a0 "Ơ" */
+0x00,0x00,0x00,0x02,0x3a,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 417 0x1a1 "ơ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x3a,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 418 0x1a2 "Ƣ" */
+0x00,0x00,0x00,0x00,0x36,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 419 0x1a3 "ƣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 420 0x1a4 "Ƥ" */
+0x00,0x00,0x00,0x00,0x3e,0x51,0x51,0x11,0x1e,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 421 0x1a5 "ƥ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x5c,0x64,0x44,0x44,0x44,0x44,0x64,0x58,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 422 0x1a6 "Ʀ" */
+0x00,0x00,0x00,0x00,0x70,0x20,0x3c,0x22,0x22,0x3c,0x28,0x24,0x22,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 423 0x1a7 "Ƨ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x0c,0x30,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 424 0x1a8 "ƨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x0c,0x30,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 425 0x1a9 "Ʃ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x20,0x10,0x08,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 426 0x1aa "ƪ" */
+0x00,0x00,0x00,0x20,0x50,0x50,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 427 0x1ab "ƫ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 428 0x1ac "Ƭ" */
+0x00,0x00,0x00,0x00,0x3f,0x48,0x48,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 429 0x1ad "ƭ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 430 0x1ae "Ʈ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 431 0x1af "Ư" */
+0x00,0x00,0x01,0x01,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 432 0x1b0 "ư" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x46,0x44,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 433 0x1b1 "Ʊ" */
+0x00,0x00,0x00,0x00,0x42,0x24,0x24,0x42,0x42,0x42,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 434 0x1b2 "Ʋ" */
+0x00,0x00,0x00,0x00,0x4c,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 435 0x1b3 "Ƴ" */
+0x00,0x00,0x00,0x00,0x46,0x45,0x44,0x28,0x28,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 436 0x1b4 "ƴ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x44,0x44,0x44,0x44,0x44,0x24,0x1c,0x04,0x04,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 437 0x1b5 "Ƶ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x3c,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 438 0x1b6 "ƶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x3c,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 439 0x1b7 "Ʒ" */
+0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x10,0x1c,0x02,0x02,0x02,0x46,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 440 0x1b8 "Ƹ" */
+0x00,0x00,0x00,0x00,0x7e,0x20,0x10,0x08,0x38,0x40,0x40,0x40,0x62,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 441 0x1b9 "ƹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x20,0x10,0x08,0x38,0x40,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 442 0x1ba "ƺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x04,0x08,0x1c,0x02,0x02,0x3c,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 443 0x1bb "ƻ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x04,0x08,0x7e,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 444 0x1bc "Ƽ" */
+0x00,0x00,0x00,0x00,0x7e,0x20,0x20,0x20,0x3c,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 445 0x1bd "ƽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x20,0x3c,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 446 0x1be "ƾ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x18,0x04,0x04,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 447 0x1bf "ƿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x44,0x48,0x50,0x60,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 448 0x1c0 "ǀ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 449 0x1c1 "ǁ" */
+0x00,0x00,0x00,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 450 0x1c2 "ǂ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x10,0x7c,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 451 0x1c3 "ǃ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 452 0x1c4 "Ǆ" */
+0x05,0x02,0x00,0x00,0x67,0x51,0x51,0x51,0x52,0x52,0x54,0x54,0x54,0x67,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 453 0x1c5 "ǅ" */
+0x00,0x00,0x05,0x02,0x60,0x50,0x57,0x51,0x51,0x52,0x52,0x54,0x54,0x67,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 454 0x1c6 "ǆ" */
+0x00,0x00,0x05,0x12,0x10,0x10,0x37,0x51,0x51,0x52,0x52,0x54,0x54,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 455 0x1c7 "Ǉ" */
+0x00,0x00,0x00,0x00,0x47,0x41,0x41,0x41,0x41,0x41,0x41,0x49,0x49,0x76,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 456 0x1c8 "ǈ" */
+0x00,0x00,0x00,0x01,0x41,0x40,0x43,0x41,0x41,0x41,0x41,0x41,0x41,0x79,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 457 0x1c9 "ǉ" */
+0x00,0x00,0x00,0x61,0x21,0x20,0x23,0x21,0x21,0x21,0x21,0x21,0x21,0xf9,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 458 0x1ca "Ǌ" */
+0x00,0x00,0x00,0x00,0x4b,0x49,0x49,0x69,0x69,0x59,0x59,0x4d,0x4d,0x4a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 459 0x1cb "ǋ" */
+0x00,0x00,0x00,0x01,0x49,0x48,0x6b,0x69,0x69,0x59,0x59,0x59,0x49,0x49,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 460 0x1cc "ǌ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x53,0x69,0x49,0x49,0x49,0x49,0x49,0x49,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 461 0x1cd "Ǎ" */
+0x24,0x18,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 462 0x1ce "ǎ" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 463 0x1cf "Ǐ" */
+0x24,0x18,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 464 0x1d0 "ǐ" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 465 0x1d1 "Ǒ" */
+0x24,0x18,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 466 0x1d2 "ǒ" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 467 0x1d3 "Ǔ" */
+0x24,0x18,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 468 0x1d4 "ǔ" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 469 0x1d5 "Ǖ" */
+0x3c,0x00,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 470 0x1d6 "ǖ" */
+0x00,0x3c,0x00,0x24,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 471 0x1d7 "Ǘ" */
+0x0c,0x30,0x00,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 472 0x1d8 "ǘ" */
+0x0c,0x30,0x00,0x24,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 473 0x1d9 "Ǚ" */
+0x24,0x18,0x00,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 474 0x1da "ǚ" */
+0x24,0x18,0x00,0x24,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 475 0x1db "Ǜ" */
+0x30,0x0c,0x00,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 476 0x1dc "ǜ" */
+0x30,0x0c,0x00,0x24,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 477 0x1dd "ǝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x7e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 478 0x1de "Ǟ" */
+0x3c,0x00,0x24,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 479 0x1df "ǟ" */
+0x00,0x3c,0x00,0x24,0x24,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 480 0x1e0 "Ǡ" */
+0x3c,0x00,0x18,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 481 0x1e1 "ǡ" */
+0x00,0x3c,0x00,0x10,0x10,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 482 0x1e2 "Ǣ" */
+0x00,0x3c,0x00,0x00,0x1f,0x28,0x48,0x48,0x7f,0x48,0x48,0x48,0x48,0x4f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 483 0x1e3 "ǣ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x3e,0x49,0x09,0x3f,0x48,0x48,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 484 0x1e4 "Ǥ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x4f,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 485 0x1e5 "ǥ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x4f,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 486 0x1e6 "Ǧ" */
+0x24,0x18,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 487 0x1e7 "ǧ" */
+0x00,0x00,0x24,0x18,0x00,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 488 0x1e8 "Ǩ" */
+0x24,0x18,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 489 0x1e9 "ǩ" */
+0x24,0x18,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 490 0x1ea "Ǫ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 491 0x1eb "ǫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 492 0x1ec "Ǭ" */
+0x00,0x3c,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 493 0x1ed "ǭ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 494 0x1ee "Ǯ" */
+0x24,0x18,0x00,0x00,0x7e,0x04,0x08,0x10,0x1c,0x02,0x02,0x02,0x46,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 495 0x1ef "ǯ" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x3e,0x04,0x08,0x10,0x1c,0x02,0x02,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 496 0x1f0 "ǰ" */
+0x00,0x00,0x12,0x0c,0x00,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 497 0x1f1 "Ǳ" */
+0x00,0x00,0x00,0x00,0x67,0x51,0x51,0x51,0x52,0x52,0x54,0x54,0x54,0x67,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 498 0x1f2 "ǲ" */
+0x00,0x00,0x00,0x00,0x60,0x50,0x57,0x51,0x51,0x52,0x52,0x54,0x54,0x67,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 499 0x1f3 "ǳ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x37,0x51,0x51,0x52,0x52,0x54,0x54,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 500 0x1f4 "Ǵ" */
+0x0c,0x30,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 501 0x1f5 "ǵ" */
+0x00,0x00,0x0c,0x30,0x00,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 502 0x1f6 "Ƕ" */
+0x00,0x00,0x00,0x00,0x48,0x48,0x48,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 503 0x1f7 "Ƿ" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 504 0x1f8 "Ǹ" */
+0x00,0x30,0x0c,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 505 0x1f9 "ǹ" */
+0x00,0x00,0x00,0x30,0x0c,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 506 0x1fa "Ǻ" */
+0x0c,0x30,0x18,0x24,0x18,0x18,0x24,0x24,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 507 0x1fb "ǻ" */
+0x0c,0x30,0x00,0x18,0x24,0x18,0x00,0x3c,0x42,0x02,0x3e,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 508 0x1fc "Ǽ" */
+0x06,0x18,0x00,0x00,0x1f,0x28,0x48,0x48,0x7f,0x48,0x48,0x48,0x48,0x4f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 509 0x1fd "ǽ" */
+0x00,0x00,0x06,0x18,0x00,0x00,0x3e,0x49,0x09,0x3f,0x48,0x48,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 510 0x1fe "Ǿ" */
+0x0c,0x30,0x00,0x02,0x3a,0x44,0x46,0x4a,0x4a,0x52,0x52,0x62,0x22,0x5c,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 511 0x1ff "ǿ" */
+0x00,0x00,0x0c,0x30,0x00,0x02,0x3c,0x46,0x4a,0x4a,0x52,0x52,0x62,0x3c,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 512 0x200 "Ȁ" */
+0xcc,0x22,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 513 0x201 "ȁ" */
+0x00,0x00,0xcc,0x22,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 514 0x202 "Ȃ" */
+0x3c,0x42,0x42,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 515 0x203 "ȃ" */
+0x00,0x00,0x3c,0x42,0x42,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 516 0x204 "Ȅ" */
+0xcc,0x22,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 517 0x205 "ȅ" */
+0x00,0x00,0xcc,0x22,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 518 0x206 "Ȇ" */
+0x3c,0x42,0x42,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 519 0x207 "ȇ" */
+0x00,0x00,0x3c,0x42,0x42,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 520 0x208 "Ȉ" */
+0xcc,0x22,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 521 0x209 "ȉ" */
+0x00,0x00,0xcc,0x22,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 522 0x20a "Ȋ" */
+0x3c,0x42,0x42,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 523 0x20b "ȋ" */
+0x00,0x00,0x3c,0x42,0x42,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 524 0x20c "Ȍ" */
+0xcc,0x22,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 525 0x20d "ȍ" */
+0x00,0x00,0xcc,0x22,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 526 0x20e "Ȏ" */
+0x3c,0x42,0x42,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 527 0x20f "ȏ" */
+0x00,0x00,0x3c,0x42,0x42,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 528 0x210 "Ȑ" */
+0xcc,0x22,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 529 0x211 "ȑ" */
+0x00,0x00,0xcc,0x22,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 530 0x212 "Ȓ" */
+0x3c,0x42,0x42,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 531 0x213 "ȓ" */
+0x00,0x00,0x3c,0x42,0x42,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 532 0x214 "Ȕ" */
+0xcc,0x22,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 533 0x215 "ȕ" */
+0x00,0x00,0xcc,0x22,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 534 0x216 "Ȗ" */
+0x3c,0x42,0x42,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 535 0x217 "ȗ" */
+0x00,0x00,0x3c,0x42,0x42,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 536 0x218 "Ș" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 537 0x219 "ș" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 538 0x21a "Ț" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 539 0x21b "ț" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 540 0x21c "Ȝ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x0c,0x34,0x02,0x02,0x02,0x0c,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 541 0x21d "ȝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x0c,0x32,0x02,0x02,0x0c,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 542 0x21e "Ȟ" */
+0x00,0x24,0x18,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 543 0x21f "ȟ" */
+0x00,0x24,0x18,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 544 0x220 "Ƞ" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 545 0x221 "ȡ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x47,0x3b,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 546 0x222 "Ȣ" */
+0x00,0x00,0x00,0x00,0x08,0x24,0x42,0x42,0x24,0x3c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 547 0x223 "ȣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x22,0x24,0x18,0x24,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 548 0x224 "Ȥ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 549 0x225 "ȥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 550 0x226 "Ȧ" */
+0x00,0x00,0x08,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 551 0x227 "ȧ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 552 0x228 "Ȩ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 553 0x229 "ȩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 554 0x22a "Ȫ" */
+0x3c,0x00,0x24,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 555 0x22b "ȫ" */
+0x00,0x00,0x3c,0x00,0x24,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 556 0x22c "Ȭ" */
+0x3c,0x00,0x32,0x4c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 557 0x22d "ȭ" */
+0x00,0x3c,0x00,0x32,0x4c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 558 0x22e "Ȯ" */
+0x00,0x00,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 559 0x22f "ȯ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 560 0x230 "Ȱ" */
+0x3c,0x00,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 561 0x231 "ȱ" */
+0x00,0x00,0x3c,0x00,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 562 0x232 "Ȳ" */
+0x00,0x00,0x3e,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 563 0x233 "ȳ" */
+0x00,0x00,0x00,0x00,0x3c,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 564 0x234 "ȴ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0c,0x0c,0x10,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 565 0x235 "ȵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x43,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 566 0x236 "ȶ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x16,0x0e,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 567 0x237 "ȷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 568 0x238 "ȸ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x54,0xba,0x92,0x92,0x92,0x92,0xba,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 569 0x239 "ȹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xba,0x92,0x92,0x92,0x92,0xba,0x54,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 570 0x23a "Ⱥ" */
+0x00,0x00,0x00,0x02,0x1a,0x24,0x2c,0x4a,0x52,0x7e,0x62,0x42,0x42,0xc2,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 571 0x23b "Ȼ" */
+0x00,0x00,0x00,0x02,0x3c,0x46,0x4a,0x48,0x50,0x50,0x60,0x62,0x42,0x7c,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 572 0x23c "ȼ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x3c,0x4a,0x50,0x50,0x60,0x60,0x42,0x7c,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 573 0x23d "Ƚ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x78,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 574 0x23e "Ⱦ" */
+0x00,0x00,0x01,0x02,0x7f,0x0c,0x0c,0x08,0x08,0x18,0x18,0x28,0x28,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 575 0x23f "ȿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 576 0x240 "ɀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x60,0x10,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 577 0x241 "Ɂ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 578 0x242 "ɂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 579 0x243 "Ƀ" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x22,0x22,0x3c,0x22,0x7a,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 580 0x244 "Ʉ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 581 0x245 "Ʌ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x24,0x24,0x24,0x24,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 582 0x246 "Ɇ" */
+0x00,0x00,0x04,0x04,0x7e,0x48,0x48,0x50,0x7c,0x50,0x50,0x60,0x60,0x7e,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 583 0x247 "ɇ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x3c,0x46,0x4a,0x7e,0x50,0x60,0x42,0x7c,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 584 0x248 "Ɉ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x1f,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 585 0x249 "ɉ" */
+0x00,0x00,0x00,0x04,0x04,0x00,0x0c,0x04,0x04,0x1f,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 586 0x24a "Ɋ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x34,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 587 0x24b "ɋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4c,0x44,0x44,0x44,0x44,0x4c,0x34,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 588 0x24c "Ɍ" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x22,0x22,0x7c,0x28,0x24,0x24,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 589 0x24d "ɍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x70,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 590 0x24e "Ɏ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x7f,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 591 0x24f "ɏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x7f,0x22,0x12,0x0e,0x02,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 592 0x250 "ɐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x7c,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 593 0x251 "ɑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x42,0x46,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 594 0x252 "ɒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x62,0x42,0x42,0x42,0x62,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 595 0x253 "ɓ" */
+0x00,0x00,0x00,0x38,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 596 0x254 "ɔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 597 0x255 "ɕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x4c,0x52,0x3c,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 598 0x256 "ɖ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x34,0x4c,0x44,0x44,0x44,0x44,0x4c,0x34,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 599 0x257 "ɗ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x34,0x4c,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 600 0x258 "ɘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 601 0x259 "ə" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x7e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 602 0x25a "ɚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4d,0x1a,0x28,0x48,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 603 0x25b "ɛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 604 0x25c "ɜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3c,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 605 0x25d "ɝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4d,0x0a,0x30,0x08,0x08,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 606 0x25e "ɞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 607 0x25f "ɟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x04,0x04,0x1f,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 608 0x260 "ɠ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x34,0x4c,0x44,0x44,0x44,0x4c,0x34,0x04,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 609 0x261 "ɡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x42,0x46,0x3a,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 610 0x262 "ɢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x4e,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 611 0x263 "ɣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 612 0x264 "ɤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xaa,0x28,0x10,0x10,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 613 0x265 "ɥ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 614 0x266 "ɦ" */
+0x00,0x00,0x00,0x38,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 615 0x267 "ɧ" */
+0x00,0x00,0x00,0x38,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 616 0x268 "ɨ" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x18,0x08,0x08,0x3e,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 617 0x269 "ɩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 618 0x26a "ɪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 619 0x26b "ɫ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x3a,0x4c,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 620 0x26c "ɬ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x38,0x48,0x3e,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 621 0x26d "ɭ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 622 0x26e "ɮ" */
+0x00,0x00,0x00,0x30,0x10,0x10,0x1f,0x11,0x12,0x14,0x16,0x11,0x11,0x7d,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 623 0x26f "ɯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 624 0x270 "ɰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x37,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 625 0x271 "ɱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x41,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 626 0x272 "ɲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x16,0x19,0x11,0x11,0x11,0x11,0x11,0x11,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 627 0x273 "ɳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x44,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 628 0x274 "ɴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x62,0x52,0x4a,0x46,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 629 0x275 "ɵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 630 0x276 "ɶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x37,0x48,0x48,0x4e,0x48,0x48,0x48,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 631 0x277 "ɷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 632 0x278 "ɸ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x3e,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 633 0x279 "ɹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 634 0x27a "ɺ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 635 0x27b "ɻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x44,0x4c,0x34,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 636 0x27c "ɼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 637 0x27d "ɽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 638 0x27e "ɾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 639 0x27f "ɿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 640 0x280 "ʀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x48,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 641 0x281 "ʁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x44,0x48,0x7c,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 642 0x282 "ʂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x7c,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 643 0x283 "ʃ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 644 0x284 "ʄ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 645 0x285 "ʅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 646 0x286 "ʆ" */
+0x00,0x00,0x00,0x06,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x38,0x4e,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 647 0x287 "ʇ" */
+0x00,0x00,0x00,0x00,0x60,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 648 0x288 "ʈ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 649 0x289 "ʉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x7f,0x22,0x22,0x26,0x1a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 650 0x28a "ʊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x42,0x42,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 651 0x28b "ʋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xcc,0x42,0x42,0x42,0x42,0x44,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 652 0x28c "ʌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x24,0x24,0x24,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 653 0x28d "ʍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x49,0x49,0x49,0x49,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 654 0x28e "ʎ" */
+0x00,0x00,0x00,0x00,0x3c,0x40,0x40,0x58,0x64,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 655 0x28f "ʏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x14,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 656 0x290 "ʐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x08,0x08,0x10,0x10,0x20,0x20,0x7c,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 657 0x291 "ʑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x26,0x49,0x7e,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 658 0x292 "ʒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x04,0x08,0x10,0x1c,0x02,0x02,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 659 0x293 "ʓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x04,0x08,0x10,0x1c,0x02,0x02,0x32,0x4a,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 660 0x294 "ʔ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 661 0x295 "ʕ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x20,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 662 0x296 "ʖ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x04,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 663 0x297 "ʗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 664 0x298 "ʘ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x5a,0x5a,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 665 0x299 "ʙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 666 0x29a "ʚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x3a,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 667 0x29b "ʛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0x44,0x40,0x40,0x4c,0x44,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 668 0x29c "ʜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 669 0x29d "ʝ" */
+0x00,0x00,0x00,0x04,0x04,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x3e,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 670 0x29e "ʞ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x22,0x12,0x0a,0x06,0x0a,0x12,0x22,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 671 0x29f "ʟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 672 0x2a0 "ʠ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x34,0x4c,0x44,0x44,0x44,0x44,0x4c,0x34,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 673 0x2a1 "ʡ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x08,0x08,0x3e,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 674 0x2a2 "ʢ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x20,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 675 0x2a3 "ʣ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x3f,0x51,0x52,0x52,0x54,0x54,0x58,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 676 0x2a4 "ʤ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x3f,0x51,0x52,0x54,0x56,0x51,0x51,0x31,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 677 0x2a5 "ʥ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x3f,0x51,0x52,0x54,0x58,0x52,0x55,0x3e,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 678 0x2a6 "ʦ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x46,0xf9,0x48,0x44,0x42,0x41,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 679 0x2a7 "ʧ" */
+0x00,0x00,0x00,0x03,0x24,0x24,0x24,0x7c,0x24,0x24,0x24,0x24,0x24,0x1c,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 680 0x2a8 "ʨ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x46,0xf9,0x48,0x48,0x48,0x4a,0x4d,0x3e,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 681 0x2a9 "ʩ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x6e,0x51,0x51,0x51,0x51,0x51,0x51,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 682 0x2aa "ʪ" */
+0x00,0x00,0x00,0x60,0x20,0x20,0x26,0x29,0x28,0x24,0x22,0x21,0x21,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 683 0x2ab "ʫ" */
+0x00,0x00,0x00,0x60,0x20,0x20,0x3e,0x22,0x24,0x24,0x28,0x28,0x30,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 684 0x2ac "ʬ" */
+0x00,0x00,0x00,0x49,0x49,0x55,0x36,0x22,0x00,0x49,0x49,0x55,0x36,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 685 0x2ad "ʭ" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x00,0x00,0x7e,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 686 0x2ae "ʮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x24,0x24,0x24,0x24,0x24,0x2c,0x14,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 687 0x2af "ʯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x24,0x24,0x24,0x24,0x24,0x2c,0x14,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 688 0x2b0 "ʰ" */
+0x00,0x00,0x00,0x40,0x40,0x58,0x64,0x44,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 689 0x2b1 "ʱ" */
+0x00,0x00,0x00,0x38,0x44,0x40,0x58,0x64,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 690 0x2b2 "ʲ" */
+0x00,0x00,0x00,0x04,0x00,0x04,0x04,0x04,0x04,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 691 0x2b3 "ʳ" */
+0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 692 0x2b4 "ʴ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x44,0x4c,0x34,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 693 0x2b5 "ʵ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x44,0x4c,0x34,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 694 0x2b6 "ʶ" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x48,0x78,0x44,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 695 0x2b7 "ʷ" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x55,0x36,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 696 0x2b8 "ʸ" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x4c,0x34,0x04,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 697 0x2b9 "ʹ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 698 0x2ba "ʺ" */
+0x00,0x00,0x00,0x00,0x12,0x24,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 699 0x2bb "ʻ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 700 0x2bc "ʼ" */
+0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 701 0x2bd "ʽ" */
+0x00,0x00,0x00,0x00,0x18,0x10,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 702 0x2be "ʾ" */
+0x00,0x00,0x00,0x30,0x08,0x04,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 703 0x2bf "ʿ" */
+0x00,0x00,0x00,0x0c,0x10,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 704 0x2c0 "ˀ" */
+0x00,0x00,0x00,0x3c,0x42,0x02,0x1c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 705 0x2c1 "ˁ" */
+0x00,0x00,0x00,0x3c,0x42,0x40,0x38,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 706 0x2c2 "˂" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 707 0x2c3 "˃" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 708 0x2c4 "˄" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 709 0x2c5 "˅" */
+0x00,0x00,0x00,0x00,0x41,0x22,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 710 0x2c6 "ˆ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 711 0x2c7 "ˇ" */
+0x00,0x00,0x00,0x00,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 712 0x2c8 "ˈ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 713 0x2c9 "ˉ" */
+0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 714 0x2ca "ˊ" */
+0x00,0x00,0x00,0x00,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 715 0x2cb "ˋ" */
+0x00,0x00,0x00,0x00,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 716 0x2cc "ˌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 717 0x2cd "ˍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 718 0x2ce "ˎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 719 0x2cf "ˏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 720 0x2d0 "ː" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x00,0x00,0x10,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 721 0x2d1 "ˑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 722 0x2d2 "˒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x04,0x04,0x08,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 723 0x2d3 "˓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 724 0x2d4 "˔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 725 0x2d5 "˕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 726 0x2d6 "˖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 727 0x2d7 "˗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 728 0x2d8 "˘" */
+0x00,0x00,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 729 0x2d9 "˙" */
+0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 730 0x2da "˚" */
+0x00,0x00,0x18,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 731 0x2db "˛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 732 0x2dc "˜" */
+0x00,0x00,0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 733 0x2dd "˝" */
+0x00,0x00,0x33,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 734 0x2de "˞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x60,0xa2,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 735 0x2df "˟" */
+0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x24,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 736 0x2e0 "ˠ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 737 0x2e1 "ˡ" */
+0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 738 0x2e2 "ˢ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x38,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 739 0x2e3 "ˣ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x24,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 740 0x2e4 "ˤ" */
+0x00,0x00,0x00,0x3c,0x42,0x40,0x38,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 741 0x2e5 "˥" */
+0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 742 0x2e6 "˦" */
+0x00,0x00,0x00,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 743 0x2e7 "˧" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 744 0x2e8 "˨" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 745 0x2e9 "˩" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 746 0x2ea "˪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x4c,0x70,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 747 0x2eb "˫" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4c,0x70,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 748 0x2ec "ˬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 749 0x2ed "˭" */
+0x00,0x00,0x7e,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 750 0x2ee "ˮ" */
+0x00,0x00,0x00,0x00,0x66,0x22,0x22,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 751 0x2ef "˯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 752 0x2f0 "˰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 753 0x2f1 "˱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x08,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 754 0x2f2 "˲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 755 0x2f3 "˳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 756 0x2f4 "˴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 757 0x2f5 "˵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcc,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 758 0x2f6 "˶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 759 0x2f7 "˷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 760 0x2f8 "˸" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 761 0x2f9 "˹" */
+0x00,0x00,0x00,0x38,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 762 0x2fa "˺" */
+0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 763 0x2fb "˻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 764 0x2fc "˼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 765 0x2fd "˽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 766 0x2fe "˾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 767 0x2ff "˿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7e,0x20,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 768 0x300 "̀" */
+0x30,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 769 0x301 "́" */
+0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 770 0x302 "̂" */
+0x18,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 771 0x303 "̃" */
+0x00,0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 772 0x304 "̄" */
+0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 773 0x305 "̅" */
+0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 774 0x306 "̆" */
+0x00,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 775 0x307 "̇" */
+0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 776 0x308 "̈" */
+0x00,0x66,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 777 0x309 "̉" */
+0x18,0x24,0x04,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 778 0x30a "̊" */
+0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 779 0x30b "̋" */
+0x33,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 780 0x30c "̌" */
+0x00,0x42,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 781 0x30d "̍" */
+0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 782 0x30e "̎" */
+0x00,0x24,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 783 0x30f "̏" */
+0xcc,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 784 0x310 "̐" */
+0x18,0x5a,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 785 0x311 "̑" */
+0x00,0x3c,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 786 0x312 "̒" */
+0x00,0x08,0x10,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 787 0x313 "̓" */
+0x00,0x18,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 788 0x314 "̔" */
+0x00,0x18,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 789 0x315 "̕" */
+0x00,0x03,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 790 0x316 "̖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 791 0x317 "̗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 792 0x318 "̘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x38,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 793 0x319 "̙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x1c,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 794 0x31a "̚" */
+0x00,0x1e,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 795 0x31b "̛" */
+0x00,0x00,0x04,0x0a,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 796 0x31c "̜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 797 0x31d "̝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 798 0x31e "̞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 799 0x31f "̟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 800 0x320 "̠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 801 0x321 "̡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 802 0x322 "̢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 803 0x323 "̣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 804 0x324 "̤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 805 0x325 "̥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 806 0x326 "̦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 807 0x327 "̧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x18,0x04,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 808 0x328 "̨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 809 0x329 "̩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 810 0x32a "̪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 811 0x32b "̫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x6c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 812 0x32c "̬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 813 0x32d "̭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 814 0x32e "̮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 815 0x32f "̯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 816 0x330 "̰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 817 0x331 "̱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 818 0x332 "̲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 819 0x333 "̳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 820 0x334 "̴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 821 0x335 "̵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 822 0x336 "̶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 823 0x337 "̷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 824 0x338 "̸" */
+0x00,0x00,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 825 0x339 "̹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 826 0x33a "̺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 827 0x33b "̻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 828 0x33c "̼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 829 0x33d "̽" */
+0x66,0x18,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 830 0x33e "̾" */
+0x08,0x10,0x10,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 831 0x33f "̿" */
+0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 832 0x340 "̀" */
+0x00,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 833 0x341 "́" */
+0x00,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 834 0x342 "͂" */
+0x00,0x34,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 835 0x343 "̓" */
+0x00,0x18,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 836 0x344 "̈́" */
+0x10,0x10,0x54,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 837 0x345 "ͅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 838 0x346 "͆" */
+0x00,0x7e,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 839 0x347 "͇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 840 0x348 "͈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 841 0x349 "͉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 842 0x34a "͊" */
+0x08,0x3a,0x5c,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 843 0x34b "͋" */
+0x04,0x71,0x8e,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 844 0x34c "͌" */
+0x32,0x4c,0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 845 0x34d "͍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x7f,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 846 0x34e "͎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 847 0x34f "͏" */
+0xaa,0x00,0x80,0x00,0xb9,0x42,0xc2,0x42,0xb9,0x00,0x82,0x00,0x84,0x00,0x82,0x55,
+0xaa,0x01,0x00,0x01,0xc2,0x03,0xe2,0x2b,0xc4,0x01,0x40,0x01,0x20,0x01,0x40,0x55,
+/* 848 0x350 "͐" */
+0x08,0x04,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 849 0x351 "͑" */
+0x18,0x20,0x20,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 850 0x352 "͒" */
+0x3c,0x42,0x5a,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 851 0x353 "͓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 852 0x354 "͔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 853 0x355 "͕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 854 0x356 "͖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x24,0x4a,0x91,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 855 0x357 "͗" */
+0x18,0x04,0x04,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 856 0x358 "͘" */
+0x00,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 857 0x359 "͙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x38,0x7c,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 858 0x35a "͚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x6c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 859 0x35b "͛" */
+0x08,0x10,0x3e,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 860 0x35c "͜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x30,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x0c,0xf0,
+/* 861 0x35d "͝" */
+0x00,0x40,0x30,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x02,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 862 0x35e "͞" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 863 0x35f "͟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,
+/* 864 0x360 "͠" */
+0x00,0x1e,0x21,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x02,0x84,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 865 0x361 "͡" */
+0x00,0x0f,0x30,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x0c,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 866 0x362 "͢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,
+/* 867 0x363 "ͣ" */
+0x3c,0x44,0x44,0x4c,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 868 0x364 "ͤ" */
+0x38,0x44,0x78,0x40,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 869 0x365 "ͥ" */
+0x10,0x00,0x30,0x10,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 870 0x366 "ͦ" */
+0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 871 0x367 "ͧ" */
+0x44,0x44,0x44,0x44,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 872 0x368 "ͨ" */
+0x1c,0x20,0x20,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 873 0x369 "ͩ" */
+0x04,0x04,0x1c,0x24,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 874 0x36a "ͪ" */
+0x20,0x20,0x38,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 875 0x36b "ͫ" */
+0x00,0x00,0xec,0x92,0x92,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 876 0x36c "ͬ" */
+0x00,0x38,0x24,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 877 0x36d "ͭ" */
+0x20,0x78,0x20,0x20,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 878 0x36e "ͮ" */
+0x00,0x44,0x44,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 879 0x36f "ͯ" */
+0x44,0x28,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 880 0x370 "Ͱ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 881 0x371 "ͱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 882 0x372 "Ͳ" */
+0x00,0x00,0x00,0x00,0x7f,0x49,0x49,0x49,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 883 0x373 "ͳ" */
+0x00,0x00,0x00,0x00,0x7c,0x54,0x54,0x54,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 884 0x374 "ʹ" */
+0x00,0x00,0x00,0x00,0x0c,0x18,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 885 0x375 "͵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x18,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 886 0x376 "Ͷ" */
+0x00,0x00,0x00,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 887 0x377 "ͷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x4c,0x4c,0x54,0x54,0x64,0x64,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 888 0x378 "͸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 889 0x379 "͹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 890 0x37a "ͺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 891 0x37b "ͻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 892 0x37c "ͼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x58,0x58,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 893 0x37d "ͽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x1a,0x1a,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 894 0x37e ";" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x08,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 895 0x37f "Ϳ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 896 0x380 "΀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 897 0x381 "΁" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 898 0x382 "΂" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 899 0x383 "΃" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 900 0x384 "΄" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 901 0x385 "΅" */
+0x04,0x08,0x54,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 902 0x386 "Ά" */
+0x00,0x00,0x20,0x40,0x98,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 903 0x387 "·" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 904 0x388 "Έ" */
+0x00,0x00,0x20,0x40,0xbf,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 905 0x389 "Ή" */
+0x00,0x00,0x20,0x40,0xa1,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 906 0x38a "Ί" */
+0x00,0x00,0x20,0x40,0xbe,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 907 0x38b "΋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 908 0x38c "Ό" */
+0x00,0x00,0x20,0x40,0xbc,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 909 0x38d "΍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 910 0x38e "Ύ" */
+0x00,0x00,0x20,0x40,0xc1,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 911 0x38f "Ώ" */
+0x00,0x00,0x20,0x40,0xbe,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 912 0x390 "ΐ" */
+0x04,0x08,0x10,0x44,0x44,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 913 0x391 "Α" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 914 0x392 "Β" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 915 0x393 "Γ" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 916 0x394 "Δ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x22,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 917 0x395 "Ε" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 918 0x396 "Ζ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 919 0x397 "Η" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 920 0x398 "Θ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x5a,0x5a,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 921 0x399 "Ι" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 922 0x39a "Κ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 923 0x39b "Λ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x22,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 924 0x39c "Μ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 925 0x39d "Ν" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 926 0x39e "Ξ" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 927 0x39f "Ο" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 928 0x3a0 "Π" */
+0x00,0x00,0x00,0x00,0x7f,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 929 0x3a1 "Ρ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 930 0x3a2 "΢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 931 0x3a3 "Σ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x20,0x10,0x08,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 932 0x3a4 "Τ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 933 0x3a5 "Υ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 934 0x3a6 "Φ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x3e,0x49,0x49,0x49,0x49,0x3e,0x08,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 935 0x3a7 "Χ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 936 0x3a8 "Ψ" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 937 0x3a9 "Ω" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 938 0x3aa "Ϊ" */
+0x24,0x24,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 939 0x3ab "Ϋ" */
+0x24,0x24,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 940 0x3ac "ά" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 941 0x3ad "έ" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x3e,0x40,0x40,0x3c,0x40,0x40,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 942 0x3ae "ή" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 943 0x3af "ί" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 944 0x3b0 "ΰ" */
+0x04,0x08,0x10,0x44,0x44,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 945 0x3b1 "α" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 946 0x3b2 "β" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x7c,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 947 0x3b3 "γ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x22,0x22,0x14,0x14,0x14,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 948 0x3b4 "δ" */
+0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x20,0x18,0x24,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 949 0x3b5 "ε" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 950 0x3b6 "ζ" */
+0x00,0x00,0x00,0x00,0x7f,0x06,0x18,0x20,0x20,0x40,0x40,0x40,0x20,0x1c,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 951 0x3b7 "η" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 952 0x3b8 "θ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 953 0x3b9 "ι" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 954 0x3ba "κ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x24,0x28,0x30,0x30,0x28,0x24,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 955 0x3bb "λ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 956 0x3bc "μ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x66,0x59,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 957 0x3bd "ν" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x44,0x44,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 958 0x3be "ξ" */
+0x00,0x00,0x00,0x00,0x7e,0x30,0x40,0x40,0x38,0x40,0x40,0x40,0x20,0x1c,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 959 0x3bf "ο" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 960 0x3c0 "π" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 961 0x3c1 "ρ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 962 0x3c2 "ς" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x40,0x40,0x40,0x40,0x20,0x1c,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 963 0x3c3 "σ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x48,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 964 0x3c4 "τ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 965 0x3c5 "υ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 966 0x3c6 "φ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x26,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 967 0x3c7 "χ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xc1,0x21,0x12,0x14,0x18,0x28,0x48,0x44,0x84,0x83,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 968 0x3c8 "ψ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 969 0x3c9 "ω" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 970 0x3ca "ϊ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 971 0x3cb "ϋ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 972 0x3cc "ό" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 973 0x3cd "ύ" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 974 0x3ce "ώ" */
+0x00,0x04,0x08,0x10,0x00,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 975 0x3cf "Ϗ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 976 0x3d0 "ϐ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x44,0x78,0x44,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 977 0x3d1 "ϑ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x0f,0x22,0x62,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 978 0x3d2 "ϒ" */
+0x00,0x00,0x00,0x00,0x36,0x55,0x14,0x14,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 979 0x3d3 "ϓ" */
+0x00,0x00,0x20,0x40,0xb6,0x55,0x14,0x14,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 980 0x3d4 "ϔ" */
+0x00,0x36,0x36,0x00,0x36,0x55,0x14,0x14,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 981 0x3d5 "ϕ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x3e,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 982 0x3d6 "ϖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x22,0x41,0x41,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 983 0x3d7 "ϗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x2c,0x2c,0x34,0x34,0x22,0x41,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 984 0x3d8 "Ϙ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x18,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 985 0x3d9 "ϙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 986 0x3da "Ϛ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x40,0x40,0x40,0x40,0x40,0x20,0x1c,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 987 0x3db "ϛ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x1c,0x20,0x40,0x40,0x40,0x40,0x20,0x1c,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 988 0x3dc "Ϝ" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x40,0x40,0x78,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 989 0x3dd "ϝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x22,0x20,0x20,0x38,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 990 0x3de "Ϟ" */
+0x00,0x00,0x00,0x00,0x60,0x20,0x20,0x20,0x20,0x3e,0x04,0x04,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 991 0x3df "ϟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x22,0x3c,0x44,0x08,0x08,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 992 0x3e0 "Ϡ" */
+0x00,0x00,0x00,0x00,0x78,0x84,0x0c,0x12,0x22,0x06,0x0a,0x12,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 993 0x3e1 "ϡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x0c,0x14,0x22,0x06,0x0a,0x12,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 994 0x3e2 "Ϣ" */
+0x00,0x00,0x00,0x00,0x44,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x6e,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 995 0x3e3 "ϣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x92,0x92,0x92,0x92,0x92,0x92,0x6e,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 996 0x3e4 "Ϥ" */
+0x00,0x00,0x00,0x00,0x22,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 997 0x3e5 "ϥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x22,0x22,0x22,0x22,0x1e,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 998 0x3e6 "Ϧ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x41,0x41,0x41,0x41,0x41,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 999 0x3e7 "ϧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x41,0x41,0x41,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1000 0x3e8 "Ϩ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x43,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1001 0x3e9 "ϩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x04,0x08,0x10,0x20,0x40,0x43,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1002 0x3ea "Ϫ" */
+0x00,0x00,0x00,0x00,0xc3,0xa5,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x7e,0x81,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1003 0x3eb "ϫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x5a,0x18,0x18,0x18,0x24,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1004 0x3ec "Ϭ" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1005 0x3ed "ϭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x40,0x5c,0x62,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1006 0x3ee "Ϯ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1007 0x3ef "ϯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1008 0x3f0 "ϰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x2c,0x2c,0x34,0x34,0x22,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1009 0x3f1 "ϱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x7c,0x40,0x40,0x3c,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1010 0x3f2 "ϲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1011 0x3f3 "ϳ" */
+0x00,0x00,0x00,0x04,0x04,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1012 0x3f4 "ϴ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1013 0x3f5 "ϵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x40,0x78,0x40,0x40,0x20,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1014 0x3f6 "϶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x3c,0x04,0x04,0x08,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1015 0x3f7 "Ϸ" */
+0x00,0x00,0x00,0x00,0x40,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1016 0x3f8 "ϸ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1017 0x3f9 "Ϲ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1018 0x3fa "Ϻ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1019 0x3fb "ϻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x6c,0x6c,0x54,0x44,0x44,0x44,0x43,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1020 0x3fc "ϼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0xf8,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1021 0x3fd "Ͻ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1022 0x3fe "Ͼ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x58,0x58,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1023 0x3ff "Ͽ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x1a,0x1a,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1024 0x400 "Ѐ" */
+0x00,0x30,0x0c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1025 0x401 "Ё" */
+0x24,0x24,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1026 0x402 "Ђ" */
+0x00,0x00,0x00,0x00,0x7e,0x10,0x10,0x10,0x1e,0x11,0x11,0x11,0x11,0x16,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1027 0x403 "Ѓ" */
+0x0c,0x30,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1028 0x404 "Є" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x40,0x40,0x7c,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1029 0x405 "Ѕ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1030 0x406 "І" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1031 0x407 "Ї" */
+0x24,0x24,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1032 0x408 "Ј" */
+0x00,0x00,0x00,0x00,0x0e,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1033 0x409 "Љ" */
+0x00,0x00,0x00,0x00,0x78,0x48,0x48,0x48,0x4e,0x49,0x49,0x49,0x49,0x8e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1034 0x40a "Њ" */
+0x00,0x00,0x00,0x00,0x48,0x48,0x48,0x48,0x7e,0x49,0x49,0x49,0x49,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1035 0x40b "Ћ" */
+0x00,0x00,0x00,0x00,0x7e,0x10,0x10,0x10,0x1e,0x11,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1036 0x40c "Ќ" */
+0x0c,0x30,0x00,0x00,0x46,0x48,0x48,0x50,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1037 0x40d "Ѝ" */
+0x00,0x30,0x0c,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1038 0x40e "Ў" */
+0x42,0x42,0x3c,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x10,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1039 0x40f "Џ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1040 0x410 "А" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1041 0x411 "Б" */
+0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1042 0x412 "В" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1043 0x413 "Г" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1044 0x414 "Д" */
+0x00,0x00,0x00,0x00,0x0e,0x12,0x12,0x12,0x22,0x22,0x22,0x42,0x42,0xff,0x81,0x81,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1045 0x415 "Е" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1046 0x416 "Ж" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x2a,0x2a,0x1c,0x1c,0x2a,0x2a,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1047 0x417 "З" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x3c,0x04,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1048 0x418 "И" */
+0x00,0x00,0x00,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1049 0x419 "Й" */
+0x00,0x24,0x18,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1050 0x41a "К" */
+0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x50,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1051 0x41b "Л" */
+0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1052 0x41c "М" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1053 0x41d "Н" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1054 0x41e "О" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1055 0x41f "П" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1056 0x420 "Р" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1057 0x421 "С" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1058 0x422 "Т" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1059 0x423 "У" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x10,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1060 0x424 "Ф" */
+0x00,0x00,0x00,0x08,0x3e,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1061 0x425 "Х" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1062 0x426 "Ц" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7f,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1063 0x427 "Ч" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1064 0x428 "Ш" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1065 0x429 "Щ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xff,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1066 0x42a "Ъ" */
+0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x1e,0x11,0x11,0x11,0x11,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1067 0x42b "Ы" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x72,0x4a,0x4a,0x4a,0x4a,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1068 0x42c "Ь" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1069 0x42d "Э" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x3e,0x02,0x02,0x02,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1070 0x42e "Ю" */
+0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x52,0x72,0x52,0x52,0x52,0x52,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1071 0x42f "Я" */
+0x00,0x00,0x00,0x00,0x3e,0x42,0x42,0x42,0x3e,0x12,0x22,0x22,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1072 0x430 "а" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1073 0x431 "б" */
+0x00,0x00,0x02,0x1c,0x20,0x40,0x7c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1074 0x432 "в" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1075 0x433 "г" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1076 0x434 "д" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x22,0x22,0x42,0x42,0x42,0x7f,0x41,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1077 0x435 "е" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1078 0x436 "ж" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x2a,0x1c,0x1c,0x2a,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1079 0x437 "з" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3c,0x04,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1080 0x438 "и" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1081 0x439 "й" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1082 0x43a "к" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1083 0x43b "л" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1084 0x43c "м" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1085 0x43d "н" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1086 0x43e "о" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1087 0x43f "п" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1088 0x440 "р" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1089 0x441 "с" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1090 0x442 "т" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1091 0x443 "у" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x10,0x10,0x20,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1092 0x444 "ф" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x3e,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1093 0x445 "х" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x18,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1094 0x446 "ц" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7f,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1095 0x447 "ч" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1096 0x448 "ш" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1097 0x449 "щ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xff,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1098 0x44a "ъ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x1e,0x11,0x11,0x11,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1099 0x44b "ы" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x72,0x4a,0x4a,0x4a,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1100 0x44c "ь" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1101 0x44d "э" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x3e,0x02,0x02,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1102 0x44e "ю" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x72,0x52,0x52,0x52,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1103 0x44f "я" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x42,0x42,0x42,0x3e,0x12,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1104 0x450 "ѐ" */
+0x00,0x00,0x30,0x0c,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1105 0x451 "ё" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1106 0x452 "ђ" */
+0x00,0x00,0x00,0x40,0xf0,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1107 0x453 "ѓ" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1108 0x454 "є" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x40,0x7c,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1109 0x455 "ѕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1110 0x456 "і" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1111 0x457 "ї" */
+0x00,0x00,0x00,0x24,0x24,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1112 0x458 "ј" */
+0x00,0x00,0x00,0x04,0x04,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1113 0x459 "љ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x48,0x48,0x4e,0x49,0x49,0x49,0x8e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1114 0x45a "њ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x48,0x48,0x7e,0x49,0x49,0x49,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1115 0x45b "ћ" */
+0x00,0x00,0x00,0x40,0xf0,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1116 0x45c "ќ" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x46,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1117 0x45d "ѝ" */
+0x00,0x00,0x30,0x0c,0x00,0x00,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1118 0x45e "ў" */
+0x00,0x42,0x42,0x3c,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x10,0x10,0x20,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1119 0x45f "џ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1120 0x460 "Ѡ" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1121 0x461 "ѡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1122 0x462 "Ѣ" */
+0x00,0x00,0x00,0x00,0x10,0x7c,0x10,0x10,0x1e,0x11,0x11,0x11,0x11,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1123 0x463 "ѣ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x78,0x20,0x20,0x3c,0x22,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1124 0x464 "Ѥ" */
+0x00,0x00,0x00,0x00,0x46,0x49,0x50,0x50,0x7e,0x50,0x50,0x50,0x49,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1125 0x465 "ѥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x49,0x50,0x7e,0x50,0x50,0x49,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1126 0x466 "Ѧ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x36,0x2a,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1127 0x467 "ѧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x22,0x36,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1128 0x468 "Ѩ" */
+0x00,0x00,0x00,0x00,0x48,0x48,0x54,0x54,0x52,0x76,0x6a,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1129 0x469 "ѩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x54,0x52,0x76,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1130 0x46a "Ѫ" */
+0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x14,0x08,0x1c,0x2a,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1131 0x46b "ѫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x14,0x08,0x3e,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1132 0x46c "Ѭ" */
+0x00,0x00,0x00,0x00,0x5f,0x51,0x51,0x4a,0x74,0x4e,0x55,0x55,0x55,0x55,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1133 0x46d "ѭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5f,0x51,0x4a,0x74,0x4e,0x55,0x55,0x55,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1134 0x46e "Ѯ" */
+0x00,0x00,0x24,0x18,0x3c,0x42,0x02,0x02,0x3c,0x04,0x02,0x02,0x02,0x3c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1135 0x46f "ѯ" */
+0x00,0x00,0x00,0x24,0x18,0x00,0x3c,0x42,0x02,0x3c,0x04,0x02,0x02,0x3c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1136 0x470 "Ѱ" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1137 0x471 "ѱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1138 0x472 "Ѳ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1139 0x473 "ѳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1140 0x474 "Ѵ" */
+0x00,0x00,0x00,0x00,0x43,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1141 0x475 "ѵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x28,0x28,0x28,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1142 0x476 "Ѷ" */
+0x66,0x11,0x00,0x00,0x43,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1143 0x477 "ѷ" */
+0x00,0x00,0x66,0x11,0x00,0x00,0x46,0x48,0x48,0x28,0x28,0x28,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1144 0x478 "Ѹ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x59,0x59,0x59,0x55,0x56,0x54,0x54,0x24,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1145 0x479 "ѹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x29,0x59,0x59,0x55,0x56,0x54,0x54,0x24,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1146 0x47a "Ѻ" */
+0x00,0x00,0x00,0x08,0x3e,0x49,0x41,0x41,0x41,0x41,0x41,0x41,0x49,0x3e,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1147 0x47b "ѻ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x3e,0x49,0x41,0x41,0x41,0x41,0x49,0x3e,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1148 0x47c "Ѽ" */
+0x3c,0x43,0x18,0x04,0x08,0x00,0x36,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1149 0x47d "ѽ" */
+0x00,0x00,0x00,0x3c,0x43,0x18,0x04,0x08,0x00,0x36,0x41,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1150 0x47e "Ѿ" */
+0x00,0x7f,0x08,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1151 0x47f "ѿ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x00,0x49,0x49,0x49,0x49,0x49,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1152 0x480 "Ҁ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x40,0x3c,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1153 0x481 "ҁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x3c,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1154 0x482 "҂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x0c,0x44,0x2a,0x11,0x18,0x24,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1155 0x483 "҃" */
+0x00,0x08,0x78,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1156 0x484 "҄" */
+0x02,0x05,0x09,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1157 0x485 "҅" */
+0x00,0x38,0x40,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1158 0x486 "҆" */
+0x00,0x38,0x04,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1159 0x487 "҇" */
+0x00,0x30,0x4c,0x83,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1160 0x488 "҈" */
+0x00,0x00,0x01,0x02,0x10,0x28,0x00,0x00,0x40,0xa0,0x00,0x00,0x00,0x10,0x29,0x02,
+0x00,0x00,0x00,0x80,0x10,0x28,0x00,0x00,0x08,0x14,0x00,0x00,0x00,0x10,0x28,0x80,
+/* 1161 0x489 "҉" */
+0x00,0x00,0x00,0x10,0x09,0x0c,0x00,0x00,0x00,0x70,0x10,0x00,0x00,0x0c,0x08,0x10,
+0x00,0x00,0x80,0x84,0x88,0x30,0x00,0x00,0x08,0x0e,0x00,0x00,0x00,0xd8,0x88,0x84,
+/* 1162 0x48a "Ҋ" */
+0x00,0x24,0x18,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1163 0x48b "ҋ" */
+0x00,0x00,0x24,0x18,0x00,0x00,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x63,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1164 0x48c "Ҍ" */
+0x00,0x00,0x00,0x00,0x20,0x70,0x20,0x20,0x20,0x3c,0x22,0x22,0x26,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1165 0x48d "ҍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x70,0x20,0x3c,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1166 0x48e "Ҏ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x4a,0x44,0x7a,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1167 0x48f "ҏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x4a,0x64,0x5a,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1168 0x490 "Ґ" */
+0x00,0x00,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1169 0x491 "ґ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1170 0x492 "Ғ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1171 0x493 "ғ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1172 0x494 "Ҕ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x42,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1173 0x495 "ҕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1174 0x496 "Җ" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x2a,0x2a,0x1c,0x1c,0x2a,0x2a,0x49,0x49,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1175 0x497 "җ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x2a,0x1c,0x1c,0x2a,0x49,0x49,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1176 0x498 "Ҙ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x3c,0x04,0x02,0x02,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1177 0x499 "ҙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3c,0x04,0x02,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1178 0x49a "Қ" */
+0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x50,0x50,0x60,0x50,0x48,0x44,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1179 0x49b "қ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1180 0x49c "Ҝ" */
+0x00,0x00,0x00,0x00,0x43,0x44,0x54,0x54,0x78,0x54,0x54,0x54,0x42,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1181 0x49d "ҝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x43,0x54,0x54,0x78,0x54,0x54,0x42,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1182 0x49e "Ҟ" */
+0x00,0x00,0x00,0x00,0x23,0x74,0x24,0x28,0x28,0x30,0x28,0x24,0x22,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1183 0x49f "ҟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x74,0x28,0x30,0x28,0x24,0x22,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1184 0x4a0 "Ҡ" */
+0x00,0x00,0x00,0x00,0xe3,0x24,0x24,0x28,0x28,0x30,0x28,0x24,0x22,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1185 0x4a1 "ҡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xe3,0x24,0x28,0x30,0x28,0x24,0x22,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1186 0x4a2 "Ң" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1187 0x4a3 "ң" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1188 0x4a4 "Ҥ" */
+0x00,0x00,0x00,0x00,0x47,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1189 0x4a5 "ҥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x47,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1190 0x4a6 "Ҧ" */
+0x00,0x00,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4e,0x49,0x49,0x49,0x49,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1191 0x4a7 "ҧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x48,0x48,0x48,0x4e,0x49,0x49,0x49,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1192 0x4a8 "Ҩ" */
+0x00,0x00,0x00,0x20,0x4c,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x2c,0x18,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1193 0x4a9 "ҩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x4c,0x52,0x52,0x52,0x52,0x2c,0x18,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1194 0x4aa "Ҫ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1195 0x4ab "ҫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x42,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1196 0x4ac "Ҭ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0c,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1197 0x4ad "ҭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x0c,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1198 0x4ae "Ү" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1199 0x4af "ү" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x14,0x14,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1200 0x4b0 "Ұ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x3e,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1201 0x4b1 "ұ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x14,0x14,0x08,0x3e,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1202 0x4b2 "Ҳ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1203 0x4b3 "ҳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x18,0x24,0x42,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1204 0x4b4 "Ҵ" */
+0x00,0x00,0x00,0x00,0xfa,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1205 0x4b5 "ҵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfa,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1206 0x4b6 "Ҷ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x03,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1207 0x4b7 "ҷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x03,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1208 0x4b8 "Ҹ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x52,0x56,0x3a,0x12,0x12,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1209 0x4b9 "ҹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x52,0x56,0x3a,0x12,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1210 0x4ba "Һ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1211 0x4bb "һ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1212 0x4bc "Ҽ" */
+0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x52,0x3e,0x10,0x10,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1213 0x4bd "ҽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x3e,0x10,0x10,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1214 0x4be "Ҿ" */
+0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x52,0x3e,0x10,0x10,0x12,0x12,0x0c,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1215 0x4bf "ҿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x3e,0x10,0x10,0x12,0x0c,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1216 0x4c0 "Ӏ" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1217 0x4c1 "Ӂ" */
+0x41,0x41,0x3e,0x00,0x49,0x49,0x2a,0x2a,0x1c,0x1c,0x2a,0x2a,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1218 0x4c2 "ӂ" */
+0x00,0x22,0x22,0x1c,0x00,0x00,0x49,0x49,0x2a,0x1c,0x1c,0x2a,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1219 0x4c3 "Ӄ" */
+0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x50,0x60,0x7c,0x42,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1220 0x4c4 "ӄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x48,0x50,0x60,0x7c,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1221 0x4c5 "Ӆ" */
+0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1222 0x4c6 "ӆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1223 0x4c7 "Ӈ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1224 0x4c8 "ӈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1225 0x4c9 "Ӊ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1226 0x4ca "ӊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1227 0x4cb "Ӌ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x06,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1228 0x4cc "ӌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x06,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1229 0x4cd "Ӎ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1230 0x4ce "ӎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x43,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1231 0x4cf "ӏ" */
+0x00,0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1232 0x4d0 "Ӑ" */
+0x42,0x42,0x3c,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1233 0x4d1 "ӑ" */
+0x00,0x42,0x42,0x3c,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1234 0x4d2 "Ӓ" */
+0x24,0x24,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1235 0x4d3 "ӓ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1236 0x4d4 "Ӕ" */
+0x00,0x00,0x00,0x00,0x1f,0x28,0x48,0x48,0x7f,0x48,0x48,0x48,0x48,0x4f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1237 0x4d5 "ӕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x49,0x09,0x3f,0x48,0x48,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1238 0x4d6 "Ӗ" */
+0x42,0x42,0x3c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1239 0x4d7 "ӗ" */
+0x00,0x00,0x42,0x42,0x3c,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1240 0x4d8 "Ә" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x02,0x02,0x7e,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1241 0x4d9 "ә" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x7e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1242 0x4da "Ӛ" */
+0x24,0x24,0x00,0x00,0x18,0x24,0x42,0x02,0x02,0x7e,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1243 0x4db "ӛ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x3c,0x42,0x02,0x02,0x7e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1244 0x4dc "Ӝ" */
+0x24,0x24,0x00,0x00,0x49,0x49,0x2a,0x2a,0x1c,0x1c,0x2a,0x2a,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1245 0x4dd "ӝ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x49,0x49,0x2a,0x1c,0x1c,0x2a,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1246 0x4de "Ӟ" */
+0x24,0x24,0x00,0x00,0x3c,0x42,0x02,0x02,0x3c,0x04,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1247 0x4df "ӟ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x3c,0x42,0x02,0x3c,0x04,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1248 0x4e0 "Ӡ" */
+0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x10,0x1c,0x02,0x02,0x02,0x46,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1249 0x4e1 "ӡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x04,0x08,0x10,0x1c,0x02,0x02,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1250 0x4e2 "Ӣ" */
+0x00,0x3c,0x00,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1251 0x4e3 "ӣ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1252 0x4e4 "Ӥ" */
+0x24,0x24,0x00,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1253 0x4e5 "ӥ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1254 0x4e6 "Ӧ" */
+0x24,0x24,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1255 0x4e7 "ӧ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1256 0x4e8 "Ө" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1257 0x4e9 "ө" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1258 0x4ea "Ӫ" */
+0x24,0x24,0x00,0x00,0x3c,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1259 0x4eb "ӫ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x3c,0x42,0x42,0x7e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1260 0x4ec "Ӭ" */
+0x00,0x00,0x24,0x00,0x3c,0x42,0x02,0x02,0x3e,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1261 0x4ed "ӭ" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x3c,0x42,0x02,0x1e,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1262 0x4ee "Ӯ" */
+0x00,0x3e,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x10,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1263 0x4ef "ӯ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x10,0x10,0x20,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1264 0x4f0 "Ӱ" */
+0x24,0x24,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x10,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1265 0x4f1 "ӱ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x10,0x10,0x20,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1266 0x4f2 "Ӳ" */
+0x33,0x44,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x10,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1267 0x4f3 "ӳ" */
+0x00,0x00,0x33,0x44,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x10,0x10,0x20,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1268 0x4f4 "Ӵ" */
+0x24,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1269 0x4f5 "ӵ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1270 0x4f6 "Ӷ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x60,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1271 0x4f7 "ӷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x60,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1272 0x4f8 "Ӹ" */
+0x24,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x72,0x4a,0x4a,0x4a,0x4a,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1273 0x4f9 "ӹ" */
+0x00,0x00,0x24,0x24,0x00,0x00,0x42,0x42,0x42,0x72,0x4a,0x4a,0x4a,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1274 0x4fa "Ӻ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x18,0x08,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1275 0x4fb "ӻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x7c,0x10,0x10,0x10,0x18,0x08,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1276 0x4fc "Ӽ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1277 0x4fd "ӽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x18,0x24,0x42,0x42,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1278 0x4fe "Ӿ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x7e,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1279 0x4ff "ӿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x7e,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1280 0x500 "Ԁ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3e,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1281 0x501 "ԁ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1282 0x502 "Ԃ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x3c,0x44,0x44,0x45,0x45,0x45,0x4d,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1283 0x503 "ԃ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x34,0x4c,0x44,0x44,0x45,0x4d,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1284 0x504 "Ԅ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x18,0x05,0x05,0x05,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1285 0x505 "ԅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x18,0x05,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1286 0x506 "Ԇ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x18,0x04,0x04,0x04,0x04,0x03,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1287 0x507 "ԇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x18,0x04,0x04,0x03,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1288 0x508 "Ԉ" */
+0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x25,0x45,0x45,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1289 0x509 "ԉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x45,0x45,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1290 0x50a "Ԋ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x7c,0x45,0x45,0x45,0x45,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1291 0x50b "ԋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x7c,0x44,0x45,0x45,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1292 0x50c "Ԍ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1293 0x50d "ԍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x4e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1294 0x50e "Ԏ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x09,0x09,0x09,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1295 0x50f "ԏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x09,0x09,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1296 0x510 "Ԑ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x3c,0x20,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1297 0x511 "ԑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x20,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1298 0x512 "Ԓ" */
+0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x0a,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1299 0x513 "ԓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x0a,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1300 0x514 "Ԕ" */
+0x00,0x00,0x00,0x00,0x71,0x51,0x4a,0x4a,0x44,0x44,0x4a,0x4a,0x51,0x91,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1301 0x515 "ԕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x71,0x51,0x4a,0x44,0x44,0x4a,0x51,0x91,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1302 0x516 "Ԗ" */
+0x00,0x00,0x00,0x00,0xe1,0x92,0x94,0x98,0x90,0xf0,0x88,0x84,0x82,0x81,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1303 0x517 "ԗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xe2,0x94,0x98,0x98,0x94,0xe2,0x81,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1304 0x518 "Ԙ" */
+0x00,0x00,0x00,0x00,0x7f,0x88,0x88,0x88,0x7f,0x28,0x48,0x48,0x88,0x8f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1305 0x519 "ԙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x89,0x89,0x7f,0x28,0x28,0x49,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1306 0x51a "Ԛ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x5a,0x66,0x3c,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1307 0x51b "ԛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1308 0x51c "Ԝ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1309 0x51d "ԝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1310 0x51e "Ԟ" */
+0x00,0x00,0x00,0x00,0x4a,0x44,0x4a,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1311 0x51f "ԟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x48,0x54,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1312 0x520 "Ԡ" */
+0x00,0x00,0x00,0x00,0x70,0x50,0x50,0x50,0x5e,0x51,0x51,0x91,0x91,0x91,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1313 0x521 "ԡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x50,0x50,0x5e,0x51,0x51,0x91,0x91,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1314 0x522 "Ԣ" */
+0x00,0x00,0x00,0x00,0x90,0x90,0x90,0x90,0xfe,0x91,0x91,0x91,0x91,0x91,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1315 0x523 "ԣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x90,0x90,0xfe,0x91,0x91,0x91,0x91,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1316 0x524 "Ԥ" */
+0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1317 0x525 "ԥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1318 0x526 "Ԧ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1319 0x527 "ԧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1320 0x528 "Ԩ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x11,0x11,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1321 0x529 "ԩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x11,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1322 0x52a "Ԫ" */
+0x00,0x00,0x00,0x00,0x0c,0x14,0x14,0x14,0x27,0x24,0x24,0x44,0x44,0xfe,0x82,0x82,
+0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x50,0xe0,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+/* 1323 0x52b "ԫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x14,0x24,0x27,0x44,0x44,0x44,0x7e,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x48,0x50,0xe0,0x50,0x48,0x44,0x42,0x00,0x00,
+/* 1324 0x52c "Ԭ" */
+0x00,0x00,0x00,0x00,0x4c,0x4c,0x54,0x54,0x54,0x7c,0x24,0x24,0x44,0x7e,0x42,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1325 0x52d "ԭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x54,0x54,0x54,0x7c,0x24,0x24,0x24,0x7e,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1326 0x52e "Ԯ" */
+0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1327 0x52f "ԯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1328 0x530 "԰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 1329 0x531 "Ա" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x47,0x45,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1330 0x532 "Բ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x7c,0x42,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1331 0x533 "Գ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x3e,0x05,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1332 0x534 "Դ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x04,0x06,0x05,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1333 0x535 "Ե" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x7c,0x42,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1334 0x536 "Զ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x1c,0x04,0x08,0x10,0x7e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1335 0x537 "Է" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7c,0x42,0x40,0x40,0x40,0x40,0x7c,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1336 0x538 "Ը" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1337 0x539 "Թ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x4f,0x54,0x54,0x48,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1338 0x53a "Ժ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x3f,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1339 0x53b "Ի" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1340 0x53c "Լ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1341 0x53d "Խ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x79,0x49,0x49,0x49,0x49,0x49,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1342 0x53e "Ծ" */
+0x00,0x00,0x00,0x00,0x7e,0x18,0x24,0x42,0x42,0x42,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1343 0x53f "Կ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x42,0x42,0x42,0x42,0x42,0x3e,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1344 0x540 "Հ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x08,0x10,0x20,0x40,0x60,0x18,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1345 0x541 "Ձ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x1c,0x24,0x58,0x48,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1346 0x542 "Ղ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1347 0x543 "Ճ" */
+0x00,0x00,0x00,0x00,0x04,0x64,0x18,0x24,0x24,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1348 0x544 "Մ" */
+0x00,0x00,0x00,0x00,0x47,0x45,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1349 0x545 "Յ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x02,0x42,0x7c,0x42,0x02,0x02,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1350 0x546 "Ն" */
+0x00,0x00,0x00,0x00,0x40,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x11,0x11,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1351 0x547 "Շ" */
+0x00,0x00,0x00,0x40,0x3c,0x20,0x40,0x40,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1352 0x548 "Ո" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1353 0x549 "Չ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x1c,0x04,0x08,0x70,0x18,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1354 0x54a "Պ" */
+0x00,0x00,0x00,0x00,0x3e,0x49,0x49,0x49,0x49,0x09,0x09,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1355 0x54b "Ջ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x12,0x0a,0x0c,0x0c,0x08,0x10,0x7e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1356 0x54c "Ռ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x47,0x45,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1357 0x54d "Ս" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1358 0x54e "Վ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x3c,0x04,0x07,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1359 0x54f "Տ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1360 0x550 "Ր" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1361 0x551 "Ց" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x3c,0x42,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1362 0x552 "Ւ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x58,0x64,0x44,0x44,0x43,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1363 0x553 "Փ" */
+0x00,0x00,0x00,0x00,0x10,0x38,0x54,0x54,0x54,0x54,0x54,0x54,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1364 0x554 "Ք" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x1c,0x50,0x7c,0x14,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1365 0x555 "Օ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1366 0x556 "Ֆ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x48,0x38,0x0e,0x09,0x09,0x09,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1367 0x557 "՗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 1368 0x558 "՘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 1369 0x559 "ՙ" */
+0x10,0x20,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1370 0x55a "՚" */
+0x20,0x10,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1371 0x55b "՛" */
+0x08,0x18,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1372 0x55c "՜" */
+0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1373 0x55d "՝" */
+0x20,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1374 0x55e "՞" */
+0x38,0x44,0x54,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1375 0x55f "՟" */
+0x30,0x50,0x40,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1376 0x560 "ՠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1377 0x561 "ա" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1378 0x562 "բ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x42,0x40,0x7e,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1379 0x563 "գ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x3f,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1380 0x564 "դ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x47,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1381 0x565 "ե" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7e,0x40,0x42,0x42,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1382 0x566 "զ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4c,0x44,0x44,0x44,0x44,0x3c,0x04,0x04,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1383 0x567 "է" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x38,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1384 0x568 "ը" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x40,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1385 0x569 "թ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x4f,0x54,0x54,0x48,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1386 0x56a "ժ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x3f,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1387 0x56b "ի" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1388 0x56c "լ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1389 0x56d "խ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x79,0x49,0x49,0x49,0x49,0x46,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1390 0x56e "ծ" */
+0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x3f,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1391 0x56f "կ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x1e,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1392 0x570 "հ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1393 0x571 "ձ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x08,0x3e,0x42,0x42,0x42,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1394 0x572 "ղ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1395 0x573 "ճ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x7f,0x11,0x11,0x11,0x11,0x13,0x0d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1396 0x574 "մ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x44,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1397 0x575 "յ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1398 0x576 "ն" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1399 0x577 "շ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1400 0x578 "ո" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1401 0x579 "չ" */
+0x00,0x00,0x00,0x00,0x10,0x20,0x10,0x08,0x08,0x10,0x10,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1402 0x57a "պ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x37,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1403 0x57b "ջ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x24,0x14,0x18,0x18,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1404 0x57c "ռ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x47,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1405 0x57d "ս" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1406 0x57e "վ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x4c,0x34,0x04,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1407 0x57f "տ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4a,0x4d,0x49,0x49,0x49,0x49,0x59,0x29,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1408 0x580 "ր" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1409 0x581 "ց" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x42,0x46,0x3a,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1410 0x582 "ւ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1411 0x583 "փ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x4a,0x4d,0x49,0x49,0x49,0x49,0x59,0x29,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1412 0x584 "ք" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x1c,0x10,0x3c,0x10,0x10,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1413 0x585 "օ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1414 0x586 "ֆ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x48,0x38,0x0e,0x09,0x09,0x09,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1415 0x587 "և" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x44,0x44,0x44,0x44,0x44,0x3b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1416 0x588 "ֈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x04,0x04,0x04,0x1e,0x04,0x04,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1417 0x589 "։" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1418 0x58a "֊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1419 0x58b "֋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 1420 0x58c "֌" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 1421 0x58d "֍" */
+0x00,0x00,0x00,0x0d,0x12,0x12,0x29,0x27,0x27,0x1b,0x23,0x24,0x18,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x30,0x48,0x88,0xb0,0xc8,0xc8,0x28,0x90,0x90,0x60,0x00,0x00,
+/* 1422 0x58e "֎" */
+0x00,0x00,0x00,0x07,0x18,0x24,0x23,0x1b,0x27,0x27,0x29,0x12,0x12,0x0d,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x90,0x28,0xc8,0xc8,0xb0,0x88,0x48,0x30,0xc0,0x00,0x00,
+/* 1423 0x58f "֏" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x04,0x1f,0x04,0x1f,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1424 0x590 "֐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 1425 0x591 "֑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x70,0x88,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1426 0x592 "֒" */
+0x00,0x18,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1427 0x593 "֓" */
+0x0c,0x30,0x0c,0x30,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1428 0x594 "֔" */
+0x00,0x18,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1429 0x595 "֕" */
+0x00,0x2c,0x20,0x2c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1430 0x596 "֖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1431 0x597 "֗" */
+0x08,0x1c,0x3e,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1432 0x598 "֘" */
+0x00,0x24,0x52,0x4a,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1433 0x599 "֙" */
+0x00,0xc0,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1434 0x59a "֚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1435 0x59b "֛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd0,0xd0,0x10,0xe0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1436 0x59c "֜" */
+0x00,0x0c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1437 0x59d "֝" */
+0x00,0x03,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1438 0x59e "֞" */
+0x00,0x36,0x48,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1439 0x59f "֟" */
+0x00,0x42,0xa5,0x42,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1440 0x5a0 "֠" */
+0x00,0x02,0x05,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1441 0x5a1 "֡" */
+0x00,0x50,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1442 0x5a2 "֢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x70,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1443 0x5a3 "֣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xe0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1444 0x5a4 "֤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1445 0x5a5 "֥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1446 0x5a6 "֦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0xd8,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1447 0x5a7 "֧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x60,0x10,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1448 0x5a8 "֨" */
+0x00,0xc0,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1449 0x5a9 "֩" */
+0x00,0x40,0xa0,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1450 0x5aa "֪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1451 0x5ab "֫" */
+0x00,0x10,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1452 0x5ac "֬" */
+0x00,0x04,0x04,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1453 0x5ad "֭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1454 0x5ae "֮" */
+0x00,0x48,0xa8,0xa8,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1455 0x5af "֯" */
+0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1456 0x5b0 "ְ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1457 0x5b1 "ֱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x00,0x12,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1458 0x5b2 "ֲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x00,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1459 0x5b3 "ֳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x10,0x12,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1460 0x5b4 "ִ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1461 0x5b5 "ֵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1462 0x5b6 "ֶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x00,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1463 0x5b7 "ַ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1464 0x5b8 "ָ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1465 0x5b9 "ֹ" */
+0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1466 0x5ba "ֺ" */
+0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1467 0x5bb "ֻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x08,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1468 0x5bc "ּ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1469 0x5bd "ֽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1470 0x5be "־" */
+0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1471 0x5bf "ֿ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1472 0x5c0 "׀" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1473 0x5c1 "ׁ" */
+0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1474 0x5c2 "ׂ" */
+0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1475 0x5c3 "׃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x08,0x00,0x00,0x08,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1476 0x5c4 "ׄ" */
+0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1477 0x5c5 "ׅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1478 0x5c6 "׆" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1479 0x5c7 "ׇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1480 0x5c8 "׈" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 1481 0x5c9 "׉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 1482 0x5ca "׊" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 1483 0x5cb "׋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 1484 0x5cc "׌" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 1485 0x5cd "׍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 1486 0x5ce "׎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 1487 0x5cf "׏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 1488 0x5d0 "א" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x12,0x2c,0x48,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1489 0x5d1 "ב" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1490 0x5d2 "ג" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x08,0x08,0x04,0x0c,0x14,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1491 0x5d3 "ד" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1492 0x5d4 "ה" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1493 0x5d5 "ו" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1494 0x5d6 "ז" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x0c,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1495 0x5d7 "ח" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1496 0x5d8 "ט" */
+0x00,0x00,0x00,0x00,0x00,0x46,0x4a,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1497 0x5d9 "י" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1498 0x5da "ך" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1499 0x5db "כ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1500 0x5dc "ל" */
+0x00,0x00,0x00,0x20,0x20,0x3e,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1501 0x5dd "ם" */
+0x00,0x00,0x00,0x00,0x00,0xfe,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1502 0x5de "מ" */
+0x00,0x00,0x00,0x00,0x00,0x4e,0x31,0x21,0x41,0x41,0x41,0x41,0x41,0x47,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1503 0x5df "ן" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1504 0x5e0 "נ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1505 0x5e1 "ס" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1506 0x5e2 "ע" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1507 0x5e3 "ף" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x72,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1508 0x5e4 "פ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x72,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1509 0x5e5 "ץ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x24,0x28,0x30,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1510 0x5e6 "צ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x08,0x04,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1511 0x5e7 "ק" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x22,0x22,0x24,0x24,0x28,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1512 0x5e8 "ר" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1513 0x5e9 "ש" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1514 0x5ea "ת" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1515 0x5eb "׫" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 1516 0x5ec "׬" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 1517 0x5ed "׭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 1518 0x5ee "׮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 1519 0x5ef "ׯ" */
+0x00,0x38,0x08,0x08,0x08,0x77,0x11,0x11,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1520 0x5f0 "װ" */
+0x00,0x00,0x00,0x00,0x00,0x77,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1521 0x5f1 "ױ" */
+0x00,0x00,0x00,0x00,0x00,0x77,0x11,0x11,0x11,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1522 0x5f2 "ײ" */
+0x00,0x00,0x00,0x00,0x00,0x77,0x11,0x11,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1523 0x5f3 "׳" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1524 0x5f4 "״" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x24,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1525 0x5f5 "׵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 1526 0x5f6 "׶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 1527 0x5f7 "׷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 1528 0x5f8 "׸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 1529 0x5f9 "׹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 1530 0x5fa "׺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 1531 0x5fb "׻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 1532 0x5fc "׼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 1533 0x5fd "׽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 1534 0x5fe "׾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 1535 0x5ff "׿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 1536 0x600 "؀" */
+0x55,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x3f,0x80,0x00,0xaa,
+0x55,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x04,0x09,0x08,0xfd,0x00,0x01,0xaa,
+/* 1537 0x601 "؁" */
+0x55,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x2a,0xaa,0x35,0x80,0x00,0xaa,
+0x55,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x04,0x0d,0x0c,0xf5,0x00,0x01,0xaa,
+/* 1538 0x602 "؂" */
+0x55,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x8e,0x0e,0x87,0x00,0x80,0x00,0xaa,
+0x55,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x19,0xe0,0x01,0x00,0x01,0xaa,
+/* 1539 0x603 "؃" */
+0x55,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x81,0x01,0x9e,0x00,0x80,0x00,0xaa,
+0x55,0x00,0x01,0x00,0x01,0x00,0x19,0x24,0x45,0x44,0x49,0xf0,0x01,0x00,0x01,0xaa,
+/* 1540 0x604 "؄" */
+0x55,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x01,0x82,0x02,0xbf,0x00,0xaa,
+0x55,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x95,0x7c,0x01,0x00,0x01,0xaa,
+/* 1541 0x605 "؅" */
+0x55,0x80,0x00,0x88,0x16,0xa1,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0xaa,
+0x55,0x00,0x01,0x04,0x19,0xe0,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0xaa,
+/* 1542 0x606 "؆" */
+0x00,0x00,0x70,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0xa8,0xa8,0xd0,0x80,0x80,0x80,0x00,0x70,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 1543 0x607 "؇" */
+0x00,0x00,0x70,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x01,0x01,0x01,0x00,
+0x20,0x40,0x80,0xa0,0x40,0x90,0x60,0x00,0x70,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 1544 0x608 "؈" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x32,0x04,0x04,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x64,0x98,0xb0,0x50,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 1545 0x609 "؉" */
+0x00,0x00,0x00,0x04,0x04,0x28,0x08,0x10,0x10,0x20,0x20,0x44,0x50,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1546 0x60a "؊" */
+0x00,0x00,0x00,0x04,0x04,0x28,0x08,0x10,0x10,0x20,0x21,0x44,0x50,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1547 0x60b "؋" */
+0x00,0x00,0x06,0x06,0x00,0x01,0x00,0x00,0x01,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xe0,0x20,0xc0,0x10,0x08,0x08,0x00,0x00,0x00,0x00,
+/* 1548 0x60c "،" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1549 0x60d "؍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x18,0x20,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1550 0x60e "؎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0xf8,0x00,0x00,0x00,
+/* 1551 0x60f "؏" */
+0x00,0x00,0x00,0x06,0x08,0x08,0x06,0x08,0x13,0x14,0x18,0x09,0x16,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 1552 0x610 "ؐ" */
+0x00,0x06,0x09,0x39,0x16,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1553 0x611 "ؑ" */
+0x00,0x00,0x04,0x07,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x60,0x80,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1554 0x612 "ؒ" */
+0x00,0x1f,0x02,0x04,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x88,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1555 0x613 "ؓ" */
+0x10,0x06,0x49,0x7e,0x50,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1556 0x614 "ؔ" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x08,0xc8,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1557 0x615 "ؕ" */
+0x00,0x04,0x05,0x06,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1558 0x616 "ؖ" */
+0x05,0x05,0x05,0x0d,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1559 0x617 "ؗ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1560 0x618 "ؘ" */
+0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1561 0x619 "ؙ" */
+0x18,0x1c,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1562 0x61a "ؚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1563 0x61b "؛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x18,0x00,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1564 0x61c "؜" */
+0xaa,0x00,0x80,0x00,0xb2,0x4a,0xfa,0x4a,0xcb,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x22,0x37,0x2a,0x23,0xa2,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 1565 0x61d "؝" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x40,0x20,0x10,0x16,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1566 0x61e "؞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x40,0x00,0x00,
+/* 1567 0x61f "؟" */
+0x00,0x00,0x00,0x3e,0x41,0x40,0x20,0x10,0x08,0x08,0x00,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1568 0x620 "ؠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x48,0x44,0x38,0x10,0x28,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1569 0x621 "ء" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x3c,0x10,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1570 0x622 "آ" */
+0x00,0x01,0x3e,0x40,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1571 0x623 "أ" */
+0x18,0x20,0x18,0x20,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1572 0x624 "ؤ" */
+0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1573 0x625 "إ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x0c,0x10,0x0c,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1574 0x626 "ئ" */
+0x00,0x00,0x00,0x00,0x18,0x20,0x18,0x20,0x00,0x46,0x48,0x48,0x46,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1575 0x627 "ا" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1576 0x628 "ب" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1577 0x629 "ة" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1578 0x62a "ت" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1579 0x62b "ث" */
+0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1580 0x62c "ج" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1581 0x62d "ح" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1582 0x62e "خ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1583 0x62f "د" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1584 0x630 "ذ" */
+0x00,0x00,0x00,0x00,0x20,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1585 0x631 "ر" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1586 0x632 "ز" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1587 0x633 "س" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1588 0x634 "ش" */
+0x00,0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1589 0x635 "ص" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x19,0x4e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1590 0x636 "ض" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x06,0x19,0x4e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1591 0x637 "ط" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1592 0x638 "ظ" */
+0x00,0x00,0x00,0x20,0x24,0x20,0x20,0x2c,0x32,0x22,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1593 0x639 "ع" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1594 0x63a "غ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1595 0x63b "ػ" */
+0x00,0x00,0x50,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1596 0x63c "ؼ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x28,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1597 0x63d "ؽ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1598 0x63e "ؾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1599 0x63f "ؿ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x50,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1600 0x640 "ـ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1601 0x641 "ف" */
+0x00,0x00,0x00,0x08,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1602 0x642 "ق" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1603 0x643 "ك" */
+0x00,0x00,0x00,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1604 0x644 "ل" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1605 0x645 "م" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x06,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1606 0x646 "ن" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1607 0x647 "ه" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1608 0x648 "و" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1609 0x649 "ى" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1610 0x64a "ي" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4a,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1611 0x64b "ً" */
+0x0c,0x30,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1612 0x64c "ٌ" */
+0x0c,0x0c,0x64,0x28,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1613 0x64d "ٍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x30,0x0c,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1614 0x64e "َ" */
+0x00,0x00,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1615 0x64f "ُ" */
+0x0c,0x0e,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1616 0x650 "ِ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1617 0x651 "ّ" */
+0x00,0x00,0x00,0x04,0x14,0x58,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1618 0x652 "ْ" */
+0x18,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1619 0x653 "ٓ" */
+0x00,0x01,0x3e,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1620 0x654 "ٔ" */
+0x18,0x20,0x18,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1621 0x655 "ٕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x18,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1622 0x656 "ٖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x20,
+/* 1623 0x657 "ٗ" */
+0x04,0x08,0x10,0x70,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1624 0x658 "٘" */
+0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1625 0x659 "ٙ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1626 0x65a "ٚ" */
+0x00,0x44,0x28,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1627 0x65b "ٛ" */
+0x00,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1628 0x65c "ٜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1629 0x65d "ٝ" */
+0x30,0x70,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1630 0x65e "ٞ" */
+0x24,0x08,0x10,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1631 0x65f "ٟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x08,0x26,0x58,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1632 0x660 "٠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1633 0x661 "١" */
+0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1634 0x662 "٢" */
+0x00,0x00,0x00,0x22,0x24,0x18,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1635 0x663 "٣" */
+0x00,0x00,0x00,0x49,0x52,0x3c,0x20,0x10,0x10,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1636 0x664 "٤" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x18,0x20,0x40,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1637 0x665 "٥" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x42,0x42,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1638 0x666 "٦" */
+0x00,0x00,0x00,0x40,0x3c,0x04,0x04,0x02,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1639 0x667 "٧" */
+0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1640 0x668 "٨" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x41,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1641 0x669 "٩" */
+0x00,0x00,0x00,0x18,0x24,0x44,0x4c,0x34,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1642 0x66a "٪" */
+0x00,0x00,0x04,0x04,0x48,0x48,0x10,0x10,0x24,0x24,0x40,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1643 0x66b "٫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1644 0x66c "٬" */
+0x00,0x00,0x00,0x18,0x18,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1645 0x66d "٭" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x7f,0x1c,0x36,0x22,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1646 0x66e "ٮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1647 0x66f "ٯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1648 0x670 "ٰ" */
+0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1649 0x671 "ٱ" */
+0x04,0x0a,0x1e,0x20,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1650 0x672 "ٲ" */
+0x06,0x08,0x26,0x58,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1651 0x673 "ٳ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x06,0x08,0x26,0x58,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1652 0x674 "ٴ" */
+0x00,0x00,0x00,0x1c,0x20,0x3c,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1653 0x675 "ٵ" */
+0x00,0x00,0x00,0x46,0x48,0x46,0x48,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1654 0x676 "ٶ" */
+0x00,0x00,0x00,0x03,0x04,0x03,0x04,0x10,0x28,0x28,0x38,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1655 0x677 "ٷ" */
+0x00,0x00,0x30,0x33,0x14,0x23,0x44,0x10,0x28,0x28,0x38,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1656 0x678 "ٸ" */
+0x00,0x00,0x00,0x06,0x08,0x06,0x08,0x00,0x08,0x54,0x50,0x48,0x44,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1657 0x679 "ٹ" */
+0x00,0x00,0x20,0x20,0x38,0x38,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1658 0x67a "ٺ" */
+0x00,0x00,0x10,0x00,0x10,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1659 0x67b "ٻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1660 0x67c "ټ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x04,0x22,0x42,0x3c,0x08,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1661 0x67d "ٽ" */
+0x00,0x00,0x28,0x00,0x10,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1662 0x67e "پ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1663 0x67f "ٿ" */
+0x00,0x00,0x28,0x00,0x28,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1664 0x680 "ڀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x14,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1665 0x681 "ځ" */
+0x00,0x00,0x00,0x18,0x20,0x18,0x20,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1666 0x682 "ڂ" */
+0x00,0x00,0x00,0x10,0x00,0x10,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1667 0x683 "ڃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x54,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1668 0x684 "ڄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x48,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1669 0x685 "څ" */
+0x00,0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1670 0x686 "چ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x40,0x54,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1671 0x687 "ڇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x40,0x54,0x40,0x54,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1672 0x688 "ڈ" */
+0x00,0x20,0x20,0x38,0x38,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1673 0x689 "ډ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x08,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1674 0x68a "ڊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1675 0x68b "ڋ" */
+0x00,0x20,0x20,0x38,0x38,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1676 0x68c "ڌ" */
+0x00,0x00,0x00,0x28,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1677 0x68d "ڍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1678 0x68e "ڎ" */
+0x00,0x00,0x10,0x00,0x28,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1679 0x68f "ڏ" */
+0x00,0x00,0x28,0x00,0x10,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1680 0x690 "ڐ" */
+0x00,0x00,0x28,0x00,0x28,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1681 0x691 "ڑ" */
+0x00,0x00,0x08,0x08,0x0e,0x0e,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1682 0x692 "ڒ" */
+0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1683 0x693 "ړ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x4c,0x3a,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1684 0x694 "ڔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x32,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1685 0x695 "ڕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x04,0x08,0x48,0x35,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1686 0x696 "ږ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x12,0x04,0x48,0x32,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1687 0x697 "ڗ" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1688 0x698 "ژ" */
+0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1689 0x699 "ڙ" */
+0x00,0x00,0x00,0x12,0x00,0x12,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1690 0x69a "ښ" */
+0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x01,0x15,0x15,0x5e,0x48,0x4a,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1691 0x69b "ڛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x15,0x15,0x5e,0x50,0x55,0x20,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1692 0x69c "ڜ" */
+0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x01,0x15,0x15,0x5e,0x50,0x55,0x20,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1693 0x69d "ڝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x19,0x4e,0x50,0x55,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1694 0x69e "ڞ" */
+0x00,0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x06,0x19,0x4e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1695 0x69f "ڟ" */
+0x00,0x00,0x00,0x24,0x20,0x2a,0x20,0x2c,0x32,0x22,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1696 0x6a0 "ڠ" */
+0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1697 0x6a1 "ڡ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1698 0x6a2 "ڢ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1699 0x6a3 "ڣ" */
+0x00,0x00,0x04,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1700 0x6a4 "ڤ" */
+0x00,0x08,0x00,0x12,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1701 0x6a5 "ڥ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x24,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1702 0x6a6 "ڦ" */
+0x00,0x0a,0x00,0x0a,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1703 0x6a7 "ڧ" */
+0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1704 0x6a8 "ڨ" */
+0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1705 0x6a9 "ک" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1706 0x6aa "ڪ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x07,0x40,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x18,0x60,0x80,0x00,0x00,0xfc,0x02,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 1707 0x6ab "ګ" */
+0x00,0x00,0x00,0x04,0x0c,0x1a,0x24,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1708 0x6ac "ڬ" */
+0x00,0x08,0x00,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1709 0x6ad "ڭ" */
+0x10,0x00,0x28,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1710 0x6ae "ڮ" */
+0x00,0x00,0x00,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1711 0x6af "گ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1712 0x6b0 "ڰ" */
+0x00,0x08,0x10,0x24,0x4c,0x1a,0x24,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1713 0x6b1 "ڱ" */
+0x00,0x50,0x06,0x18,0x62,0x0c,0x30,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1714 0x6b2 "ڲ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1715 0x6b3 "ڳ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x10,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1716 0x6b4 "ڴ" */
+0x40,0x00,0xa6,0x18,0x62,0x0c,0x30,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1717 0x6b5 "ڵ" */
+0x00,0x11,0x0a,0x04,0x00,0x02,0x02,0x02,0x02,0x22,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1718 0x6b6 "ڶ" */
+0x00,0x02,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1719 0x6b7 "ڷ" */
+0x04,0x00,0x09,0x00,0x02,0x02,0x02,0x02,0x02,0x22,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1720 0x6b8 "ڸ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x42,0x3c,0x00,0x14,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1721 0x6b9 "ڹ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1722 0x6ba "ں" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1723 0x6bb "ڻ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1724 0x6bc "ڼ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x3c,0x0a,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1725 0x6bd "ڽ" */
+0x00,0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1726 0x6be "ھ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2c,0x2a,0x1a,0x24,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1727 0x6bf "ڿ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x7e,0x20,0x40,0x54,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1728 0x6c0 "ۀ" */
+0x00,0x18,0x20,0x18,0x20,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1729 0x6c1 "ہ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2f,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1730 0x6c2 "ۂ" */
+0x00,0x00,0x00,0x00,0x18,0x20,0x18,0x20,0x00,0x10,0x2f,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1731 0x6c3 "ۃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x00,0x10,0x2f,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1732 0x6c4 "ۄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0e,0x22,0x52,0x24,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1733 0x6c5 "ۅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x3c,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1734 0x6c6 "ۆ" */
+0x00,0x00,0x00,0x22,0x14,0x08,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1735 0x6c7 "ۇ" */
+0x00,0x00,0x18,0x18,0x08,0x10,0x20,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1736 0x6c8 "ۈ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1737 0x6c9 "ۉ" */
+0x00,0x00,0x00,0x08,0x14,0x22,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1738 0x6ca "ۊ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1739 0x6cb "ۋ" */
+0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1740 0x6cc "ی" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1741 0x6cd "ۍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x2a,0x68,0xa4,0x22,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1742 0x6ce "ێ" */
+0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1743 0x6cf "ۏ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1744 0x6d0 "ې" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x48,0x44,0x38,0x00,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1745 0x6d1 "ۑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x48,0x44,0x38,0x00,0x28,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1746 0x6d2 "ے" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1747 0x6d3 "ۓ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x30,0x40,0x08,0x14,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1748 0x6d4 "۔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1749 0x6d5 "ە" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1750 0x6d6 "ۖ" */
+0x02,0x02,0x0f,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x5c,0xfc,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1751 0x6d7 "ۗ" */
+0x02,0x02,0x0f,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x48,0x20,0xe0,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1752 0x6d8 "ۘ" */
+0x00,0x00,0x00,0x01,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0xa0,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1753 0x6d9 "ۙ" */
+0x08,0x04,0x03,0x01,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1754 0x6da "ۚ" */
+0x1f,0x04,0x09,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x00,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1755 0x6db "ۛ" */
+0x40,0x00,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1756 0x6dc "ۜ" */
+0x00,0x01,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x28,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1757 0x6dd "۝" */
+0x00,0x00,0x01,0x06,0x0b,0x0c,0x10,0x10,0x10,0x0c,0x0b,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x30,0xe8,0x18,0x04,0x04,0x04,0x18,0xe8,0x30,0xc0,0x00,0x00,0x00,
+/* 1758 0x6de "۞" */
+0x00,0x00,0x01,0x1f,0x14,0x18,0x11,0x32,0x52,0x32,0x11,0x18,0x14,0x1f,0x01,0x00,
+0x00,0x80,0x40,0xfc,0x14,0x0c,0xc4,0x26,0x25,0x26,0xc4,0x0c,0x14,0xfc,0x40,0x80,
+/* 1759 0x6df "۟" */
+0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1760 0x6e0 "۠" */
+0x18,0x24,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1761 0x6e1 "ۡ" */
+0x7e,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1762 0x6e2 "ۢ" */
+0x01,0x03,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1763 0x6e3 "ۣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x09,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0xf8,0x00,0x00,
+/* 1764 0x6e4 "ۤ" */
+0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1765 0x6e5 "ۥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0e,0x02,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1766 0x6e6 "ۦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1767 0x6e7 "ۧ" */
+0x00,0x10,0x20,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1768 0x6e8 "ۨ" */
+0x00,0x00,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x20,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1769 0x6e9 "۩" */
+0x00,0x00,0x01,0x02,0x05,0x0a,0x15,0x2a,0x15,0x15,0x15,0x15,0x14,0x17,0x30,0x7f,
+0x00,0x80,0x40,0xa0,0x50,0xa8,0x54,0x2a,0x54,0x54,0x54,0xd4,0x14,0xf4,0x06,0xff,
+/* 1770 0x6ea "۪" */
+0x01,0x02,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1771 0x6eb "۫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,
+/* 1772 0x6ec "۬" */
+0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1773 0x6ed "ۭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,
+/* 1774 0x6ee "ۮ" */
+0x00,0x00,0x08,0x14,0x22,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1775 0x6ef "ۯ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x11,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1776 0x6f0 "۰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1777 0x6f1 "۱" */
+0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1778 0x6f2 "۲" */
+0x00,0x00,0x00,0x22,0x24,0x18,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1779 0x6f3 "۳" */
+0x00,0x00,0x00,0x49,0x52,0x3c,0x20,0x10,0x10,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1780 0x6f4 "۴" */
+0x00,0x00,0x00,0x18,0x24,0x60,0x72,0x2c,0x20,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1781 0x6f5 "۵" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x49,0x55,0x63,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1782 0x6f6 "۶" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x20,0x20,0x18,0x06,0x18,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1783 0x6f7 "۷" */
+0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1784 0x6f8 "۸" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x41,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1785 0x6f9 "۹" */
+0x00,0x00,0x00,0x18,0x24,0x44,0x4c,0x34,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1786 0x6fa "ۺ" */
+0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x01,0x15,0x15,0x5e,0x48,0x4a,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1787 0x6fb "ۻ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x06,0x19,0x4e,0x48,0x4a,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1788 0x6fc "ۼ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x48,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1789 0x6fd "۽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x3c,0x10,0x20,0x00,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1790 0x6fe "۾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x12,0x2e,0x20,0x4a,0x0a,0x0a,0x0a,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1791 0x6ff "ۿ" */
+0x00,0x00,0x00,0x10,0x28,0x44,0x10,0x2c,0x2a,0x1a,0x24,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1792 0x700 "܀" */
+0x00,0x00,0x00,0x00,0x01,0x03,0x01,0x08,0x1c,0x08,0x01,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x20,0x70,0x20,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 1793 0x701 "܁" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1794 0x702 "܂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1795 0x703 "܃" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1796 0x704 "܄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1797 0x705 "܅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1798 0x706 "܆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1799 0x707 "܇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1800 0x708 "܈" */
+0x00,0x00,0x60,0x60,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1801 0x709 "܉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x06,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1802 0x70a "܊" */
+0x00,0x24,0x24,0x7e,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1803 0x70b "܋" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1804 0x70c "܌" */
+0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x24,0x1c,0x1c,0x3c,0x00,0x00,
+/* 1805 0x70d "܍" */
+0x00,0x01,0x01,0x19,0x19,0x01,0x01,0x7f,0x7f,0x01,0x01,0x19,0x19,0x01,0x01,0x00,
+0x00,0x80,0x80,0x98,0x98,0x80,0x80,0xfe,0xfe,0x80,0x80,0x98,0x98,0x80,0x80,0x00,
+/* 1806 0x70e "܎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 1807 0x70f "܏" */
+0xaa,0x00,0xb1,0x3f,0xb1,0x00,0x80,0x00,0xb3,0x44,0xa7,0x14,0xe4,0x00,0x80,0x55,
+0xaa,0x01,0x8c,0xfd,0x8c,0x01,0x00,0x01,0x22,0xb7,0xaa,0xa3,0xa2,0x01,0x00,0x55,
+/* 1808 0x710 "ܐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0xff,0xc6,0xc3,0xc1,0xc0,0x40,0x00,0x00,0x00,
+0x00,0x00,0x07,0x07,0x0e,0x3c,0xf8,0xc0,0x00,0x00,0xc0,0xf0,0x70,0x00,0x00,0x00,
+/* 1809 0x711 "ܑ" */
+0x02,0x0c,0x78,0x50,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1810 0x712 "ܒ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x0f,0x07,0x00,0x60,0x60,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x08,0x08,0x08,0xf8,0xf0,0x00,0x00,0x00,
+/* 1811 0x713 "ܓ" */
+0x00,0x06,0x07,0x03,0x01,0x01,0x70,0x7c,0x0f,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0x60,0x30,0xf0,0xf8,0x1c,0x06,0x00,0x00,0x00,
+/* 1812 0x714 "ܔ" */
+0x00,0x06,0x07,0x03,0x01,0x01,0x73,0x7e,0x0f,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0x60,0x30,0xf0,0xf8,0x1c,0x06,0x00,0x00,0x00,
+/* 1813 0x715 "ܕ" */
+0x00,0x00,0x00,0x3f,0x3e,0x0e,0x06,0x06,0x06,0x06,0x26,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1814 0x716 "ܖ" */
+0x00,0x00,0x00,0x3f,0x3e,0x0e,0x06,0x06,0x06,0x06,0x06,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1815 0x717 "ܗ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x3f,0x60,0x40,0x40,0x41,0x61,0x32,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0xfc,0x84,0x82,0x82,0x02,0x06,0x0c,0x00,0x00,0x00,
+/* 1816 0x718 "ܘ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x0c,0x18,0x10,0x10,0x10,0x19,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x20,0x30,0x10,0x98,0x98,0x00,0x00,0x00,
+/* 1817 0x719 "ܙ" */
+0x00,0x00,0x00,0x0c,0x0e,0x0e,0x06,0x06,0x06,0x06,0x06,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1818 0x71a "ܚ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x01,0x01,0x00,0x40,0x60,0x3f,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x06,0x02,0x82,0x82,0x84,0xfc,0x78,0x00,0x00,
+/* 1819 0x71b "ܛ" */
+0x00,0x0c,0x0e,0x06,0x03,0x01,0x01,0x60,0x7f,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xfc,0x42,0x42,0x42,0x24,0x18,0x00,
+/* 1820 0x71c "ܜ" */
+0x00,0x0c,0x0e,0x06,0x03,0x01,0x01,0x60,0x7f,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xfc,0x42,0x5a,0x5a,0x24,0x18,0x00,
+/* 1821 0x71d "ܝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x18,0x0c,0x0c,0x0c,0x18,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1822 0x71e "ܞ" */
+0x00,0x02,0x00,0x05,0x00,0x1d,0x3f,0x62,0x42,0x42,0x44,0x64,0x24,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xe0,0x20,0x24,0x22,0x12,0x12,0x0c,0x80,0x00,0x00,
+/* 1823 0x71f "ܟ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x1c,0x04,0x07,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x70,0x98,0x98,0x88,0x0c,0x04,0x04,0x02,0x02,0x01,
+/* 1824 0x720 "ܠ" */
+0x00,0x00,0x0e,0x0e,0x06,0x03,0x01,0x00,0x00,0x30,0x30,0x3f,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x30,0x30,0xf0,0xf0,0x00,0x00,0x00,
+/* 1825 0x721 "ܡ" */
+0x00,0x00,0x00,0x70,0x7e,0x1f,0x03,0x03,0x03,0x03,0x03,0x06,0x0c,0x18,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0xfc,0x04,0x04,0x04,0xfc,0xf8,0x00,0x00,0x00,0x00,
+/* 1826 0x722 "ܢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x3e,0x3f,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xf0,0x18,0x04,0x02,0x00,
+/* 1827 0x723 "ܣ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x66,0x43,0x41,0x61,0x31,0x1f,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xcc,0x84,0x84,0x88,0xf0,0xe0,0x00,0x00,0x00,
+/* 1828 0x724 "ܤ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x66,0x43,0x41,0x61,0x31,0x1f,0x0f,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xcc,0x84,0x84,0x88,0xf0,0xe0,0x80,0x80,0x00,
+/* 1829 0x725 "ܥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x01,0x60,0x60,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0xfe,0xfe,0x00,0x00,0x00,
+/* 1830 0x726 "ܦ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x60,0x60,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x30,0x10,0x18,0xe8,0x0c,0x04,0xfe,0xfe,0x00,0x00,0x00,
+/* 1831 0x727 "ܧ" */
+0x00,0x00,0x00,0x00,0x0f,0x18,0x10,0x30,0x2f,0x60,0x40,0xff,0xff,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x0c,0x0c,0xfc,0xf8,0x00,0x00,0x00,
+/* 1832 0x728 "ܨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x1f,0x10,0x0c,0x03,0x00,0x00,0x00,0xff,0x00,
+0x00,0x00,0x00,0x00,0x10,0x38,0xfc,0xfc,0x00,0x00,0xc0,0x30,0x18,0x38,0xf0,0x00,
+/* 1833 0x729 "ܩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x02,0x02,0x02,0x13,0x17,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x08,0x04,0x04,0xfc,0xfc,0x00,0x00,0x00,
+/* 1834 0x72a "ܪ" */
+0x02,0x00,0x00,0x3f,0x3e,0x0e,0x06,0x06,0x06,0x06,0x06,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1835 0x72b "ܫ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0f,0x0f,0x07,0x03,0x61,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0xf0,0xf0,0xe0,0xc0,0x86,0xfe,0xfe,0x00,0x00,0x00,
+/* 1836 0x72c "ܬ" */
+0x00,0x60,0x70,0x30,0x08,0x05,0x06,0x06,0x0a,0x11,0x20,0x3f,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0x10,0x10,0x08,0x08,0x8c,0x8c,0x0c,0x00,0x00,0x00,
+/* 1837 0x72d "ܭ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x00,0x00,0x60,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x20,0x60,0xc0,0x80,0xfc,0xfe,0x02,0x02,0x02,0xfe,0xfc,0x00,0x00,0x00,
+/* 1838 0x72e "ܮ" */
+0x00,0x03,0x01,0x19,0x1f,0x0c,0x02,0x01,0x60,0x7c,0x3f,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x40,0xe0,0xf8,0x1c,0x06,0x02,0x00,
+/* 1839 0x72f "ܯ" */
+0x00,0x00,0x00,0x3f,0x3e,0x0e,0x06,0x06,0x06,0x06,0x46,0x06,0x12,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1840 0x730 "ܰ" */
+0x3e,0x24,0x28,0x30,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1841 0x731 "ܱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1842 0x732 "ܲ" */
+0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1843 0x733 "ܳ" */
+0x18,0x24,0x24,0x18,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1844 0x734 "ܴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x18,0x24,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1845 0x735 "ܵ" */
+0x00,0x08,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1846 0x736 "ܶ" */
+0x18,0x04,0x0a,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1847 0x737 "ܷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x28,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1848 0x738 "ܸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1849 0x739 "ܹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1850 0x73a "ܺ" */
+0x7c,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1851 0x73b "ܻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1852 0x73c "ܼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1853 0x73d "ܽ" */
+0x01,0x02,0x05,0x08,0x12,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1854 0x73e "ܾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x09,0x04,0x02,0x01,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x90,0x20,0x40,0x80,0x00,
+/* 1855 0x73f "ܿ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1856 0x740 "݀" */
+0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1857 0x741 "݁" */
+0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1858 0x742 "݂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1859 0x743 "݃" */
+0x00,0x10,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1860 0x744 "݄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1861 0x745 "݅" */
+0x00,0x10,0x00,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1862 0x746 "݆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1863 0x747 "݇" */
+0x00,0x00,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1864 0x748 "݈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1865 0x749 "݉" */
+0x01,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0xd0,0xe8,0x74,0xba,0x5c,0x2c,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1866 0x74a "݊" */
+0x54,0x10,0x7c,0x10,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1867 0x74b "݋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 1868 0x74c "݌" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 1869 0x74d "ݍ" */
+0x00,0x18,0x18,0x18,0x0c,0x0c,0x04,0x04,0x06,0x06,0x02,0x02,0x03,0x01,0x01,0x00,
+0x00,0x18,0x18,0x18,0x30,0x30,0x20,0x60,0x60,0x60,0xc0,0xc0,0xc0,0x80,0x80,0x00,
+/* 1870 0x74e "ݎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x0c,0x06,0xe6,0xfc,0x30,0x10,0x08,0x08,0x04,0xfe,0xfe,0x00,0x00,0x00,
+/* 1871 0x74f "ݏ" */
+0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x7f,0x3f,0x00,0x00,0x00,
+0x00,0x80,0x80,0xc0,0x2c,0x32,0x12,0x1c,0x08,0x08,0x04,0xfe,0xfe,0x00,0x00,0x00,
+/* 1872 0x750 "ݐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1873 0x751 "ݑ" */
+0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1874 0x752 "ݒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x08,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1875 0x753 "ݓ" */
+0x00,0x00,0x00,0x00,0x08,0x20,0x00,0x04,0x22,0x42,0x3c,0x00,0x08,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1876 0x754 "ݔ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1877 0x755 "ݕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x08,0x14,0x22,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1878 0x756 "ݖ" */
+0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1879 0x757 "ݗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1880 0x758 "ݘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x24,0x40,0x4a,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1881 0x759 "ݙ" */
+0x20,0x20,0x28,0x34,0x78,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x10,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1882 0x75a "ݚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x08,0x14,0x22,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1883 0x75b "ݛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x1f,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1884 0x75c "ݜ" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x14,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1885 0x75d "ݝ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1886 0x75e "ݞ" */
+0x00,0x00,0x00,0x28,0x00,0x10,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1887 0x75f "ݟ" */
+0x00,0x00,0x00,0x10,0x00,0x10,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1888 0x760 "ݠ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1889 0x761 "ݡ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x04,0x00,0x0a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1890 0x762 "ݢ" */
+0x00,0x00,0x00,0x04,0x88,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1891 0x763 "ݣ" */
+0x00,0x40,0x00,0xa4,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1892 0x764 "ݤ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x08,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1893 0x765 "ݥ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x1c,0x06,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1894 0x766 "ݦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x06,0x1e,0x20,0x28,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1895 0x767 "ݧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1896 0x768 "ݨ" */
+0x20,0x20,0x28,0x34,0x78,0x00,0x20,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1897 0x769 "ݩ" */
+0x00,0x00,0x44,0x28,0x10,0x00,0x20,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1898 0x76a "ݪ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x1e,0x04,0x24,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1899 0x76b "ݫ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x10,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1900 0x76c "ݬ" */
+0x00,0x00,0x00,0x18,0x20,0x18,0x20,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1901 0x76d "ݭ" */
+0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x00,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1902 0x76e "ݮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x28,0x4c,0x4a,0x5c,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1903 0x76f "ݯ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x28,0x4c,0x4a,0x5c,0x40,0x54,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1904 0x770 "ݰ" */
+0x00,0x20,0x20,0x28,0x34,0x78,0x00,0x14,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1905 0x771 "ݱ" */
+0x20,0x20,0x28,0x34,0x78,0x00,0x10,0x40,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1906 0x772 "ݲ" */
+0x00,0x00,0x10,0x10,0x14,0x1a,0x3c,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1907 0x773 "ݳ" */
+0x28,0x28,0x30,0x20,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1908 0x774 "ݴ" */
+0x2a,0x2a,0x34,0x20,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1909 0x775 "ݵ" */
+0x00,0x00,0x00,0x14,0x14,0x18,0x10,0x10,0x10,0x46,0x48,0x48,0x46,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1910 0x776 "ݶ" */
+0x00,0x00,0x00,0x15,0x15,0x1a,0x10,0x10,0x10,0x46,0x48,0x48,0x46,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1911 0x777 "ݷ" */
+0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x46,0x42,0x3c,0x00,0x08,0x16,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1912 0x778 "ݸ" */
+0x00,0x00,0x50,0x50,0x60,0x40,0x40,0x4c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1913 0x779 "ݹ" */
+0x00,0x00,0x54,0x54,0x68,0x40,0x40,0x4c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1914 0x77a "ݺ" */
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x60,0x40,0x48,0x54,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1915 0x77b "ݻ" */
+0x00,0x00,0x00,0x00,0x00,0x54,0x54,0x68,0x40,0x48,0x54,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1916 0x77c "ݼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x24,0x4b,0x48,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1917 0x77d "ݽ" */
+0x00,0x00,0x00,0x08,0x16,0x10,0x10,0x10,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1918 0x77e "ݾ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x00,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1919 0x77f "ݿ" */
+0x00,0x00,0x28,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1920 0x780 "ހ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1921 0x781 "ށ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x1c,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1922 0x782 "ނ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x34,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1923 0x783 "ރ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x08,0x14,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1924 0x784 "ބ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1925 0x785 "ޅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x24,0x38,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1926 0x786 "ކ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x48,0x50,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1927 0x787 "އ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x12,0x22,0xc2,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1928 0x788 "ވ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x08,0x10,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1929 0x789 "މ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x24,0x08,0x10,0x60,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1930 0x78a "ފ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x04,0x08,0x04,0x08,0x10,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1931 0x78b "ދ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x02,0x1c,0x20,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1932 0x78c "ތ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x2c,0x40,0x20,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1933 0x78d "ލ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x3c,0x08,0x10,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1934 0x78e "ގ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x08,0x70,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1935 0x78f "ޏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x34,0x20,0x40,0x40,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1936 0x790 "ސ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x3f,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1937 0x791 "ޑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x60,0x18,0x60,0x18,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1938 0x792 "ޒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x10,0x28,0x40,0x40,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1939 0x793 "ޓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x38,0x40,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1940 0x794 "ޔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x16,0x1a,0x22,0xc0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1941 0x795 "ޕ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x04,0x08,0x04,0x08,0x12,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1942 0x796 "ޖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x04,0x38,0x40,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1943 0x797 "ޗ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x0c,0x12,0x2c,0x40,0x20,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1944 0x798 "ޘ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x11,0x0c,0x12,0x2c,0x40,0x20,0xc0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1945 0x799 "ޙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x64,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1946 0x79a "ޚ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x04,0x08,0x10,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1947 0x79b "ޛ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x02,0x04,0x02,0x1c,0x20,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1948 0x79c "ޜ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x08,0x14,0x20,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1949 0x79d "ޝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x30,0x3f,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x20,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1950 0x79e "ޞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x3f,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xf8,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 1951 0x79f "ޟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x3f,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1952 0x7a0 "ޠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x2c,0x40,0x28,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1953 0x7a1 "ޡ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x0c,0x12,0x2c,0x40,0x20,0xc0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1954 0x7a2 "ޢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x12,0x22,0xc2,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1955 0x7a3 "ޣ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x06,0x0a,0x32,0xc2,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1956 0x7a4 "ޤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x0c,0x10,0x08,0x70,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1957 0x7a5 "ޥ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x08,0x14,0x14,0x08,0x10,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1958 0x7a6 "ަ" */
+0x00,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1959 0x7a7 "ާ" */
+0x00,0x12,0x24,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1960 0x7a8 "ި" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1961 0x7a9 "ީ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x24,0x48,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1962 0x7aa "ު" */
+0x00,0x30,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1963 0x7ab "ޫ" */
+0x00,0x66,0x11,0x22,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1964 0x7ac "ެ" */
+0x00,0x08,0x10,0x20,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1965 0x7ad "ޭ" */
+0x00,0x22,0x44,0x88,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1966 0x7ae "ޮ" */
+0x00,0x62,0x14,0x28,0x46,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1967 0x7af "ޯ" */
+0x1c,0x24,0x48,0x40,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1968 0x7b0 "ް" */
+0x00,0x18,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1969 0x7b1 "ޱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x10,0x20,0x40,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1970 0x7b2 "޲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 1971 0x7b3 "޳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 1972 0x7b4 "޴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 1973 0x7b5 "޵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 1974 0x7b6 "޶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 1975 0x7b7 "޷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 1976 0x7b8 "޸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 1977 0x7b9 "޹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 1978 0x7ba "޺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 1979 0x7bb "޻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 1980 0x7bc "޼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 1981 0x7bd "޽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 1982 0x7be "޾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 1983 0x7bf "޿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 1984 0x7c0 "߀" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x42,0x42,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1985 0x7c1 "߁" */
+0x00,0x00,0x00,0x00,0x18,0x14,0x12,0x10,0x10,0x10,0x10,0x10,0x10,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1986 0x7c2 "߂" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x3e,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1987 0x7c3 "߃" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1988 0x7c4 "߄" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x3c,0x20,0x20,0x20,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1989 0x7c5 "߅" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x38,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1990 0x7c6 "߆" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1991 0x7c7 "߇" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x60,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1992 0x7c8 "߈" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7e,0x44,0x48,0x50,0x60,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1993 0x7c9 "߉" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1994 0x7ca "ߊ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1995 0x7cb "ߋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1996 0x7cc "ߌ" */
+0x00,0x00,0x00,0x00,0x82,0x44,0x28,0x28,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1997 0x7cd "ߍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1998 0x7ce "ߎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 1999 0x7cf "ߏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2000 0x7d0 "ߐ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2001 0x7d1 "ߑ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x20,0x18,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2002 0x7d2 "ߒ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x1e,0x0a,0x12,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2003 0x7d3 "ߓ" */
+0x00,0x00,0x00,0x00,0x3c,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2004 0x7d4 "ߔ" */
+0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2005 0x7d5 "ߕ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x78,0x44,0x44,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2006 0x7d6 "ߖ" */
+0x00,0x00,0x00,0x00,0x3e,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2007 0x7d7 "ߗ" */
+0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2008 0x7d8 "ߘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x52,0x52,0x52,0x52,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2009 0x7d9 "ߙ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x3e,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2010 0x7da "ߚ" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0x24,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2011 0x7db "ߛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2012 0x7dc "ߜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2013 0x7dd "ߝ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x0a,0x0c,0x78,0x48,0x48,0x48,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2014 0x7de "ߞ" */
+0x00,0x00,0x00,0x00,0x04,0x24,0x24,0x3c,0x24,0x24,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2015 0x7df "ߟ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x3e,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2016 0x7e0 "ߠ" */
+0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2017 0x7e1 "ߡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2018 0x7e2 "ߢ" */
+0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x38,0x44,0x44,0x38,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2019 0x7e3 "ߣ" */
+0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2020 0x7e4 "ߤ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x3c,0x24,0x24,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2021 0x7e5 "ߥ" */
+0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x04,0x3c,0x24,0x24,0x24,0x24,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2022 0x7e6 "ߦ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x38,0x44,0x44,0x38,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2023 0x7e7 "ߧ" */
+0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x38,0x44,0x44,0x38,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2024 0x7e8 "ߨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x70,0x12,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2025 0x7e9 "ߩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x74,0x1a,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2026 0x7ea "ߪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2027 0x7eb "߫" */
+0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2028 0x7ec "߬" */
+0x12,0x2c,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2029 0x7ed "߭" */
+0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2030 0x7ee "߮" */
+0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2031 0x7ef "߯" */
+0x08,0x04,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2032 0x7f0 "߰" */
+0x48,0x34,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2033 0x7f1 "߱" */
+0x10,0x20,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2034 0x7f2 "߲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2035 0x7f3 "߳" */
+0x00,0x00,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2036 0x7f4 "ߴ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2037 0x7f5 "ߵ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x20,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2038 0x7f6 "߶" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1e,0x04,0x08,0x10,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2039 0x7f7 "߷" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x2a,0x22,0x41,0x55,0x41,0x2a,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2040 0x7f8 "߸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2041 0x7f9 "߹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x18,0x18,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2042 0x7fa "ߺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2043 0x7fb "߻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2044 0x7fc "߼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2045 0x7fd "߽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2046 0x7fe "߾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x52,0x52,0x52,0x7e,0x10,0x7c,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2047 0x7ff "߿" */
+0x00,0x00,0x00,0x00,0x40,0xf0,0x40,0x40,0x78,0x44,0x44,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2048 0x800 "ࠀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0xa0,0x40,0x24,0x28,0x30,0x20,0x40,0x00,0x00,
+/* 2049 0x801 "ࠁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0f,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xe0,0x10,0x10,0x08,0xf8,0x00,0x00,
+/* 2050 0x802 "ࠂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xc0,0x40,0x40,0x20,0x10,0x20,0xc0,0x00,0x00,
+/* 2051 0x803 "ࠃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x20,0x10,0xf0,0x08,0x08,0x10,0x20,0x00,0x00,
+/* 2052 0x804 "ࠄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x09,0x02,0x04,0x05,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xc0,0xc0,0x40,0x60,0x90,0x20,0x40,0x00,0x00,
+/* 2053 0x805 "ࠅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x09,0x03,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x00,0x00,0xe0,0x10,0x20,0x00,0x00,
+/* 2054 0x806 "ࠆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x1c,0x13,0x10,0x10,0x10,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x60,0x90,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 2055 0x807 "ࠇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x09,0x32,0x0c,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0xc0,0x40,0x60,0x90,0x10,0x20,0x00,0x00,
+/* 2056 0x808 "ࠈ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x09,0x11,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0xa0,0xa0,0x40,0x40,0x80,0x00,0x00,
+/* 2057 0x809 "ࠉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x90,0x90,0x90,0x20,0x20,0x20,0x00,0x00,
+/* 2058 0x80a "ࠊ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0x1f,0x00,0x00,0x00,0x02,0x07,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0xf0,0x10,0x10,0x10,0x10,0x90,0xf0,0x00,0x00,
+/* 2059 0x80b "ࠋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x18,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x10,0x30,0xf0,0x00,0x00,
+/* 2060 0x80c "ࠌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1d,0x1f,0x20,0x00,0x08,0x1e,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x88,0xd8,0xf8,0x08,0x08,0x10,0x10,0xf0,0x00,0x00,
+/* 2061 0x80d "ࠍ" */
+0x00,0x00,0x04,0x04,0x04,0x08,0x08,0x0f,0x00,0x00,0x00,0x02,0x07,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0xf0,0x00,0x00,
+/* 2062 0x80e "ࠎ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x0a,0x19,0x00,0x00,0x08,0x1f,0x01,0x02,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x78,0x90,0xa0,0x60,0x00,0x00,0x80,0x00,
+/* 2063 0x80f "ࠏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x40,0x40,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 2064 0x810 "ࠐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x02,0x07,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0xf0,0x00,0x00,
+/* 2065 0x811 "ࠑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x14,0x1c,0x14,0x05,0x19,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x90,0x90,0x90,0x20,0x20,0x20,0x00,0x00,
+/* 2066 0x812 "ࠒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x06,0x09,0x00,0x00,0x01,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xa0,0x40,0x80,0x00,0x80,0x00,
+/* 2067 0x813 "ࠓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0xf0,0x08,0x08,0x10,0x20,0x00,0x00,
+/* 2068 0x814 "ࠔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1d,0x1f,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x88,0xd8,0xf8,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2069 0x815 "ࠕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x24,0x28,0x30,0x20,0x40,0x00,0x00,
+/* 2070 0x816 "ࠖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x28,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2071 0x817 "ࠗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x12,0x14,0x16,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2072 0x818 "࠘" */
+0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2073 0x819 "࠙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2074 0x81a "ࠚ" */
+0x00,0x07,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2075 0x81b "ࠛ" */
+0x00,0x07,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2076 0x81c "ࠜ" */
+0x00,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2077 0x81d "ࠝ" */
+0x00,0x44,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2078 0x81e "ࠞ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2079 0x81f "ࠟ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2080 0x820 "ࠠ" */
+0x00,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2081 0x821 "ࠡ" */
+0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2082 0x822 "ࠢ" */
+0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2083 0x823 "ࠣ" */
+0x00,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2084 0x824 "ࠤ" */
+0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2085 0x825 "ࠥ" */
+0x00,0x08,0x08,0x10,0x10,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2086 0x826 "ࠦ" */
+0x00,0x10,0x10,0x28,0x28,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2087 0x827 "ࠧ" */
+0x00,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2088 0x828 "ࠨ" */
+0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2089 0x829 "ࠩ" */
+0x00,0x03,0x0c,0x30,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2090 0x82a "ࠪ" */
+0x00,0x02,0x04,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2091 0x82b "ࠫ" */
+0x00,0x10,0x10,0x28,0x28,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2092 0x82c "ࠬ" */
+0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2093 0x82d "࠭" */
+0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2094 0x82e "࠮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2095 0x82f "࠯" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2096 0x830 "࠰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2097 0x831 "࠱" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2098 0x832 "࠲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2099 0x833 "࠳" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x30,0x10,0x08,0x04,0x02,0x02,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2100 0x834 "࠴" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x30,0x10,0x08,0x04,0x02,0x02,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 2101 0x835 "࠵" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 2102 0x836 "࠶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x06,0x07,0x00,0x00,0x00,
+0x00,0x00,0x30,0x30,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,
+/* 2103 0x837 "࠷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x7e,0x60,0x20,0x90,0x08,0x04,0x04,0x08,0x00,0x00,0x00,
+/* 2104 0x838 "࠸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0xe6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2105 0x839 "࠹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0xe0,0x00,0x06,0x06,0x00,0x00,0x00,0x00,
+/* 2106 0x83a "࠺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0xe6,0x00,0x00,0x00,0x06,0xe6,0x00,0x00,0x00,0x00,
+/* 2107 0x83b "࠻" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x00,
+/* 2108 0x83c "࠼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2109 0x83d "࠽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x11,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x18,0x18,0x00,0x00,0x98,0x98,0x00,0x00,0x00,
+/* 2110 0x83e "࠾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2111 0x83f "࠿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2112 0x840 "ࡀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2113 0x841 "ࡁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x84,0x04,0x04,0xf8,0x40,0x20,0xfe,0x00,0x00,0x00,0x00,
+/* 2114 0x842 "ࡂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x60,0x00,0x80,0x40,0x30,0xfc,0x00,0x00,0x00,0x00,
+/* 2115 0x843 "ࡃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x14,0x24,0x44,0x7c,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,
+/* 2116 0x844 "ࡄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x54,0xf8,0x00,0x00,0x00,0x00,
+/* 2117 0x845 "ࡅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2118 0x846 "ࡆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2119 0x847 "ࡇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0xfc,0x00,0x00,0x00,0x00,
+/* 2120 0x848 "ࡈ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x40,0x40,0xa0,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2121 0x849 "ࡉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2122 0x84a "ࡊ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x09,0x09,0x04,0x04,0x04,0x04,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0xe0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2123 0x84b "ࡋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,
+/* 2124 0x84c "ࡌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x84,0x04,0x04,0xfc,0x44,0x24,0xc4,0x00,0x00,0x00,0x00,
+/* 2125 0x84d "ࡍ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2126 0x84e "ࡎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x84,0x44,0xf8,0x00,0x00,0x00,0x00,
+/* 2127 0x84f "ࡏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0xf8,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,
+/* 2128 0x850 "ࡐ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x09,0x08,0x04,0x04,0x04,0x04,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x60,0xa0,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2129 0x851 "ࡑ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x2a,0x2a,0x3e,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2130 0x852 "ࡒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x84,0x04,0x04,0xfc,0x44,0x24,0xf8,0x00,0x00,0x00,0x00,
+/* 2131 0x853 "ࡓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x84,0x04,0x04,0xfc,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,
+/* 2132 0x854 "ࡔ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0d,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x58,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 2133 0x855 "ࡕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x84,0x7c,0x24,0x24,0xc4,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2134 0x856 "ࡖ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2135 0x857 "ࡗ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x20,0x20,0x1f,0x00,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0xa0,0xa0,0x9c,0x84,0x88,0x90,0x20,0xc0,0x00,0x00,
+/* 2136 0x858 "ࡘ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 2137 0x859 "࡙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x00,
+/* 2138 0x85a "࡚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 2139 0x85b "࡛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,
+/* 2140 0x85c "࡜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2141 0x85d "࡝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2142 0x85e "࡞" */
+0x00,0x00,0x00,0x01,0x06,0x08,0x09,0x12,0x12,0x09,0x08,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x90,0x48,0x48,0x90,0x10,0x60,0x80,0x00,0x00,0x00,
+/* 2143 0x85f "࡟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2144 0x860 "ࡠ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0a,0x06,0x00,0x00,0x00,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0xe0,0x20,0x10,0x10,0xf0,0x00,0x00,
+/* 2145 0x861 "ࡡ" */
+0x00,0x00,0x00,0x00,0x1e,0x29,0x29,0x10,0x00,0x1f,0x20,0x40,0x40,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x88,0x70,0x00,0xf8,0x24,0x18,
+/* 2146 0x862 "ࡢ" */
+0x00,0x00,0x00,0x00,0x18,0x26,0x29,0x10,0x00,0x01,0x02,0x21,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x84,0x6a,0x12,0xac,0x40,0xa0,0x10,0xf0,0x00,0x00,
+/* 2147 0x863 "ࡣ" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x84,0x44,0x38,0x00,0x00,
+/* 2148 0x864 "ࡤ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0a,0x06,0x00,0x01,0x00,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xd0,0x20,0xe0,0x10,0x10,0xf0,0x00,0x00,
+/* 2149 0x865 "ࡥ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x00,0x00,0x00,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0xe0,0x20,0x10,0x10,0xf0,0x00,0x00,
+/* 2150 0x866 "ࡦ" */
+0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x03,0x04,0x04,0x03,0x00,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0xf0,0x00,0x00,0xf0,0x08,0x08,0xf0,0x00,0x00,
+/* 2151 0x867 "ࡧ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2152 0x868 "ࡨ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x22,0x24,0x28,0x30,0x20,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0xf8,0x00,0x00,
+/* 2153 0x869 "ࡩ" */
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0xf8,0x40,0x80,
+/* 2154 0x86a "ࡪ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x09,0x0a,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x50,0x20,0x50,0x90,0x08,0x08,0xf0,0x00,0x00,
+/* 2155 0x86b "࡫" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2156 0x86c "࡬" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2157 0x86d "࡭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2158 0x86e "࡮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2159 0x86f "࡯" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2160 0x870 "ࡰ" */
+0x00,0x00,0x06,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2161 0x871 "ࡱ" */
+0x00,0x00,0x0c,0x30,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2162 0x872 "ࡲ" */
+0x00,0x00,0x00,0x20,0x20,0x2c,0x30,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2163 0x873 "ࡳ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x0c,0x34,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2164 0x874 "ࡴ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0e,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2165 0x875 "ࡵ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x2c,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2166 0x876 "ࡶ" */
+0x00,0x1c,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2167 0x877 "ࡷ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x1c,0x1c,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2168 0x878 "ࡸ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x38,0x38,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2169 0x879 "ࡹ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1c,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2170 0x87a "ࡺ" */
+0x00,0x08,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2171 0x87b "ࡻ" */
+0x00,0x20,0x0c,0x30,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2172 0x87c "ࡼ" */
+0x00,0x20,0x00,0x20,0x20,0x2c,0x30,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2173 0x87d "ࡽ" */
+0x00,0x20,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x2c,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2174 0x87e "ࡾ" */
+0x00,0x00,0x06,0x18,0x10,0x10,0x30,0x50,0x30,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2175 0x87f "ࡿ" */
+0x00,0x00,0x00,0x10,0x10,0x36,0x58,0x30,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2176 0x880 "ࢀ" */
+0x00,0x00,0x00,0x10,0x10,0x30,0x50,0x30,0x10,0x16,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2177 0x881 "ࢁ" */
+0x00,0x00,0x00,0x20,0x20,0x2c,0x30,0x3c,0x30,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2178 0x882 "ࢂ" */
+0x00,0x00,0x00,0x04,0x04,0x1c,0x24,0x3c,0x14,0x24,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2179 0x883 "ࢃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x3c,0xff,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2180 0x884 "ࢄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0xff,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2181 0x885 "ࢅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2182 0x886 "ࢆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x78,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2183 0x887 "ࢇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2184 0x888 "࢈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2185 0x889 "ࢉ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2186 0x88a "ࢊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x24,0x4a,0x51,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2187 0x88b "ࢋ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0x7c,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2188 0x88c "ࢌ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0x7c,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2189 0x88d "ࢍ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2190 0x88e "ࢎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0f,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2191 0x88f "࢏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2192 0x890 "࢐" */
+0x55,0x80,0x00,0x80,0x3f,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0xaa,
+0x55,0x00,0xe1,0x98,0xfd,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0xaa,
+/* 2193 0x891 "࢑" */
+0x55,0x80,0x07,0x99,0x3f,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0xaa,
+0x55,0x00,0x01,0x00,0xfd,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0xaa,
+/* 2194 0x892 "࢒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2195 0x893 "࢓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2196 0x894 "࢔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2197 0x895 "࢕" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2198 0x896 "࢖" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2199 0x897 "ࢗ" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2200 0x898 "࢘" */
+0x00,0x02,0x18,0x22,0x3b,0x42,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x22,0x22,0x72,0x0a,0xf2,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2201 0x899 "࢙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x74,0x44,0x43,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x52,0x02,0xfa,0xc2,
+/* 2202 0x89a "࢚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x52,0x02,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x92,0xaa,0xda,
+/* 2203 0x89b "࢛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x1f,0x90,0x66,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x42,0xbe,0x80,
+/* 2204 0x89c "࢜" */
+0x00,0x01,0x7e,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2205 0x89d "࢝" */
+0x9c,0xa0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2206 0x89e "࢞" */
+0x7f,0x80,0x3f,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2207 0x89f "࢟" */
+0x78,0x81,0x3e,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2208 0x8a0 "ࢠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x22,0x14,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2209 0x8a1 "ࢡ" */
+0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x04,0x22,0x42,0x3c,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2210 0x8a2 "ࢢ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x20,0x00,0x7e,0x10,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2211 0x8a3 "ࢣ" */
+0x00,0x00,0x00,0x20,0x22,0x28,0x20,0x2c,0x32,0x22,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2212 0x8a4 "ࢤ" */
+0x00,0x10,0x00,0x28,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2213 0x8a5 "ࢥ" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2214 0x8a6 "ࢦ" */
+0x00,0x00,0x00,0x04,0x04,0x1f,0x04,0x1f,0x04,0x24,0x44,0x44,0x48,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2215 0x8a7 "ࢧ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x1c,0x06,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2216 0x8a8 "ࢨ" */
+0x00,0x00,0x00,0x00,0x18,0x20,0x18,0x20,0x04,0x4a,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2217 0x8a9 "ࢩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x04,0x4a,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2218 0x8aa "ࢪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x34,0x48,0x34,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2219 0x8ab "ࢫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0e,0x22,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2220 0x8ac "ࢬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x6e,0x40,0x4a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2221 0x8ad "ࢭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2222 0x8ae "ࢮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x28,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2223 0x8af "ࢯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x19,0x4e,0x48,0x30,0x04,0x20,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2224 0x8b0 "ࢰ" */
+0x00,0x00,0x08,0x10,0x24,0x48,0x50,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2225 0x8b1 "ࢱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x1e,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2226 0x8b2 "ࢲ" */
+0x00,0x00,0x10,0x28,0x44,0x00,0x10,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2227 0x8b3 "ࢳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x54,0x40,0x48,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2228 0x8b4 "ࢴ" */
+0x00,0x00,0x00,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2229 0x8b5 "ࢵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2230 0x8b6 "ࢶ" */
+0x00,0x00,0x18,0x04,0x1c,0x10,0x10,0x04,0x22,0x42,0x3c,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2231 0x8b7 "ࢷ" */
+0x00,0x00,0x18,0x04,0x1c,0x10,0x10,0x04,0x22,0x42,0x3c,0x00,0x24,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2232 0x8b8 "ࢸ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x22,0x9d,0x41,0x3e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2233 0x8b9 "ࢹ" */
+0x00,0x20,0x00,0x08,0x04,0x44,0x48,0x30,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2234 0x8ba "ࢺ" */
+0x00,0x20,0x00,0x08,0x04,0x44,0x48,0x30,0x04,0x4a,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2235 0x8bb "ࢻ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2236 0x8bc "ࢼ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2237 0x8bd "ࢽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2238 0x8be "ࢾ" */
+0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x04,0x22,0x42,0x3c,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2239 0x8bf "ࢿ" */
+0x00,0x44,0x28,0x10,0x00,0x14,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2240 0x8c0 "ࣀ" */
+0x22,0x14,0x48,0x40,0x50,0x68,0xf0,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2241 0x8c1 "ࣁ" */
+0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x7e,0x20,0x40,0x54,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2242 0x8c2 "ࣂ" */
+0x00,0x88,0x50,0x24,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2243 0x8c3 "ࣃ" */
+0x00,0x10,0x00,0x24,0x00,0x08,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2244 0x8c4 "ࣄ" */
+0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2245 0x8c5 "ࣅ" */
+0x00,0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x7e,0x10,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2246 0x8c6 "ࣆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x48,0x40,0x54,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2247 0x8c7 "ࣇ" */
+0x40,0x40,0x50,0x6a,0xf2,0x02,0x02,0x02,0x02,0x22,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2248 0x8c8 "ࣈ" */
+0x20,0x48,0x30,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2249 0x8c9 "ࣉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x48,0x46,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2250 0x8ca "࣊" */
+0x06,0x48,0x46,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2251 0x8cb "࣋" */
+0x10,0x20,0x40,0x7f,0x00,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2252 0x8cc "࣌" */
+0x00,0x11,0x2f,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2253 0x8cd "࣍" */
+0x00,0x04,0x05,0x06,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2254 0x8ce "࣎" */
+0x18,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2255 0x8cf "࣏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2256 0x8d0 "࣐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2257 0x8d1 "࣑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2258 0x8d2 "࣒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x5a,0x5a,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2259 0x8d3 "࣓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0e,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2260 0x8d4 "ࣔ" */
+0x72,0x52,0x3c,0x41,0x40,0x39,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0a,0x0a,0x4a,0x72,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2261 0x8d5 "ࣕ" */
+0x00,0x00,0x00,0x00,0x06,0x19,0x4e,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2262 0x8d6 "ࣖ" */
+0x00,0x10,0x28,0x20,0x18,0x20,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2263 0x8d7 "ࣗ" */
+0x00,0x24,0x00,0x0c,0x0a,0x46,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2264 0x8d8 "ࣘ" */
+0x00,0x20,0x00,0x08,0x24,0x48,0x32,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2265 0x8d9 "ࣙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x08,0x24,0x49,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2266 0x8da "ࣚ" */
+0x02,0x0b,0x6d,0x01,0x15,0x2e,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0a,0x2a,0x6a,0x0a,0x4a,0xb2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2267 0x8db "ࣛ" */
+0xa8,0x08,0x4a,0xa9,0x56,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x05,0x05,0x05,0x55,0x69,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2268 0x8dc "ࣜ" */
+0x00,0x48,0x14,0x8b,0x75,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x05,0x15,0xc5,0x55,0xe9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2269 0x8dd "ࣝ" */
+0x00,0x03,0x94,0x4a,0x01,0x49,0xb6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x00,0x00,0x00,0x02,0xaa,0xd4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2270 0x8de "ࣞ" */
+0x00,0x00,0x00,0x02,0x00,0x11,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0x40,0x10,0x28,0x98,0x48,0xb0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2271 0x8df "ࣟ" */
+0x00,0x01,0x28,0x42,0x05,0x22,0x5d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x00,0x40,0xa4,0x6a,0x26,0xc2,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2272 0x8e0 "࣠" */
+0x00,0x20,0x52,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2273 0x8e1 "࣡" */
+0x00,0x02,0x05,0x15,0xee,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2274 0x8e2 "࣢" */
+0x08,0x14,0x22,0x22,0x41,0x49,0x36,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2275 0x8e3 "ࣣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x4c,0x30,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2276 0x8e4 "ࣤ" */
+0x00,0x04,0x02,0x0c,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2277 0x8e5 "ࣥ" */
+0x0c,0x0e,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2278 0x8e6 "ࣦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x0c,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2279 0x8e7 "ࣧ" */
+0x00,0x22,0x11,0x66,0x88,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2280 0x8e8 "ࣨ" */
+0x1c,0x22,0x22,0x55,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2281 0x8e9 "ࣩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x11,0x66,0x88,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2282 0x8ea "࣪" */
+0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2283 0x8eb "࣫" */
+0x00,0x00,0x04,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2284 0x8ec "࣬" */
+0x00,0x1a,0x24,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2285 0x8ed "࣭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2286 0x8ee "࣮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2287 0x8ef "࣯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x48,0x34,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2288 0x8f0 "ࣰ" */
+0x06,0x18,0x00,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2289 0x8f1 "ࣱ" */
+0x66,0x77,0x22,0x44,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2290 0x8f2 "ࣲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x00,0x18,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2291 0x8f3 "ࣳ" */
+0x00,0x04,0x0a,0x0e,0x02,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2292 0x8f4 "ࣴ" */
+0x00,0x34,0x48,0x54,0x24,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2293 0x8f5 "ࣵ" */
+0x20,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2294 0x8f6 "ࣶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2295 0x8f7 "ࣷ" */
+0x20,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2296 0x8f8 "ࣸ" */
+0x10,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2297 0x8f9 "ࣹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2298 0x8fa "ࣺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2299 0x8fb "ࣻ" */
+0x48,0x24,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2300 0x8fc "ࣼ" */
+0x24,0x92,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2301 0x8fd "ࣽ" */
+0x08,0x24,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2302 0x8fe "ࣾ" */
+0x0c,0x2e,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2303 0x8ff "ࣿ" */
+0x00,0x1c,0x02,0x02,0x04,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2304 0x900 "ऀ" */
+0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2305 0x901 "ँ" */
+0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2306 0x902 "ं" */
+0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2307 0x903 "ः" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x00,
+/* 2308 0x904 "ऄ" */
+0x01,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0xfc,0x02,0xcf,0x22,0x12,0x12,0x62,0x12,0x1e,0x12,0x22,0xc2,0x00,0x00,0x00,
+/* 2309 0x905 "अ" */
+0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xcf,0x22,0x12,0x12,0x62,0x12,0x1e,0x12,0x22,0xc2,0x00,0x00,0x00,
+/* 2310 0x906 "आ" */
+0x00,0x00,0x00,0x0e,0x11,0x00,0x00,0x03,0x20,0x20,0x10,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x7f,0x14,0x94,0x94,0x14,0x94,0xf4,0x94,0x14,0x14,0x00,0x00,0x00,
+/* 2311 0x907 "इ" */
+0x00,0x00,0x00,0x3f,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0xc0,0x00,0x00,0xc0,0x20,0x10,0x90,0xe0,0x40,0x20,0x10,
+/* 2312 0x908 "ई" */
+0x00,0x01,0x00,0x3f,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x01,0x01,0x00,0x00,0x00,
+0xe0,0x10,0x80,0xff,0x40,0xc0,0x00,0x00,0xc0,0x20,0x10,0x90,0xe0,0x40,0x20,0x10,
+/* 2313 0x909 "उ" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x08,0x08,0x30,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2314 0x90a "ऊ" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x10,0x10,0x08,0x08,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x20,0x20,0xcc,0x32,0x22,0x22,0x42,0x84,0x00,0x00,0x00,
+/* 2315 0x90b "ऋ" */
+0x00,0x00,0x00,0x7f,0x00,0x1e,0x21,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x98,0xf8,0x90,0x88,0x90,0xa0,0xa4,0x98,0x00,0x00,0x00,
+/* 2316 0x90c "ऌ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x1c,0x22,0x21,0x20,0x10,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0x20,0x70,0x88,0x08,0x10,0x20,0x20,0x18,0x00,0x00,0x00,
+/* 2317 0x90d "ऍ" */
+0x01,0x00,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0xe0,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 2318 0x90e "ऎ" */
+0x04,0x03,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0xff,0x10,0x10,0x10,0x10,0x10,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 2319 0x90f "ए" */
+0x00,0x00,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 2320 0x910 "ऐ" */
+0x07,0x00,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x10,0xff,0x10,0x10,0x10,0x10,0x10,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 2321 0x911 "ऑ" */
+0x01,0x00,0x00,0x0e,0x11,0x00,0x00,0x03,0x20,0x20,0x10,0x11,0x0e,0x00,0x00,0x00,
+0x10,0xe0,0x00,0x7f,0x14,0x94,0x94,0x14,0x94,0xf4,0x94,0x14,0x14,0x00,0x00,0x00,
+/* 2322 0x912 "ऒ" */
+0x08,0x07,0x00,0x0e,0x11,0x00,0x00,0x03,0x20,0x20,0x10,0x11,0x0e,0x00,0x00,0x00,
+0x00,0xf8,0x04,0x7f,0x14,0x94,0x94,0x14,0x94,0xf4,0x94,0x14,0x14,0x00,0x00,0x00,
+/* 2323 0x913 "ओ" */
+0x07,0x00,0x00,0x0e,0x11,0x00,0x00,0x03,0x20,0x20,0x10,0x11,0x0e,0x00,0x00,0x00,
+0xf0,0x08,0x04,0x7f,0x14,0x94,0x94,0x14,0x94,0xf4,0x94,0x14,0x14,0x00,0x00,0x00,
+/* 2324 0x914 "औ" */
+0x01,0x00,0x00,0x0e,0x11,0x00,0x00,0x03,0x20,0x20,0x10,0x11,0x0e,0x00,0x00,0x00,
+0xf8,0x04,0xfc,0x3f,0x14,0x94,0x94,0x14,0x94,0xf4,0x94,0x14,0x14,0x00,0x00,0x00,
+/* 2325 0x915 "क" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x0e,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0xb0,0xc8,0x88,0x88,0x90,0x80,0x80,0x00,0x00,0x00,
+/* 2326 0x916 "ख" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x09,0x1a,0x1a,0x11,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0xd0,0x30,0x30,0xd0,0x10,0x30,0xd0,0x00,0x00,0x00,
+/* 2327 0x917 "ग" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x0a,0x06,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2328 0x918 "घ" */
+0x00,0x00,0x00,0xff,0x08,0x06,0x01,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x88,0x08,0x08,0x18,0xe8,0x08,0x08,0x00,0x00,0x00,
+/* 2329 0x919 "ङ" */
+0x00,0x00,0x00,0xff,0x00,0x03,0x04,0x04,0x13,0x10,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0x00,0x18,0x98,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 2330 0x91a "च" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x0f,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0xf8,0x18,0x68,0x88,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2331 0x91b "छ" */
+0x00,0x00,0x00,0xff,0x00,0x06,0x08,0x08,0x06,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x60,0x90,0x50,0x20,0x30,0x48,0x48,0x88,0x10,0x00,0x00,
+/* 2332 0x91c "ज" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x78,0x48,0x48,0x88,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2333 0x91d "झ" */
+0x00,0x00,0x00,0xff,0x01,0x07,0x08,0x08,0x07,0x01,0x01,0x0e,0x0c,0x02,0x01,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2334 0x91e "ञ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x13,0x10,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0xc8,0x28,0x28,0x38,0x28,0x48,0x88,0x00,0x00,0x00,
+/* 2335 0x91f "ट" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0x00,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2336 0x920 "ठ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2337 0x921 "ड" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x01,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0xe0,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 2338 0x922 "ढ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x60,0x90,0x90,0x50,0xe0,0x00,0x00,0x00,
+/* 2339 0x923 "ण" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x90,0x90,0x90,0x90,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2340 0x924 "त" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2341 0x925 "थ" */
+0x00,0x00,0x00,0x0c,0x12,0x11,0x09,0x01,0x02,0x0c,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x3f,0x08,0x08,0x08,0x08,0x08,0x18,0x28,0x48,0x88,0x00,0x00,0x00,
+/* 2342 0x926 "द" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0x00,0x30,0x30,0xe0,0x10,0x08,0x00,
+/* 2343 0x927 "ध" */
+0x00,0x00,0x00,0x0c,0x12,0x14,0x08,0x0c,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0xe8,0x08,0x00,0x00,0x00,
+/* 2344 0x928 "न" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2345 0x929 "ऩ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0xc8,0xc0,0x00,0x00,
+/* 2346 0x92a "प" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2347 0x92b "फ" */
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0x40,0x70,0xc8,0x48,0x48,0x48,0x50,0x00,0x00,0x00,
+/* 2348 0x92c "ब" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x0c,0x0a,0x09,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0xd0,0x30,0x30,0x50,0x90,0x10,0x10,0x00,0x00,0x00,
+/* 2349 0x92d "भ" */
+0x00,0x00,0x00,0x0c,0x12,0x0e,0x02,0x02,0x07,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2350 0x92e "म" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x0f,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2351 0x92f "य" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x0c,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x30,0xd0,0x10,0x10,0x00,0x00,0x00,
+/* 2352 0x930 "र" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x06,0x06,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 2353 0x931 "ऱ" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x06,0x06,0x01,0x00,0x00,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 2354 0x932 "ल" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x06,0x09,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x38,0x48,0x88,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2355 0x933 "ळ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x0c,0x12,0x10,0x11,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0x20,0x70,0x88,0x88,0x08,0x88,0x48,0x30,0x00,0x00,0x00,
+/* 2356 0x934 "ऴ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x0c,0x12,0x10,0x11,0x12,0x12,0x0c,0x01,0x01,0x00,
+0x00,0x00,0x00,0xff,0x20,0x20,0x70,0x88,0x88,0x08,0x88,0x48,0x30,0x80,0x80,0x00,
+/* 2357 0x935 "व" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0xd0,0x30,0x30,0x50,0x90,0x10,0x10,0x00,0x00,0x00,
+/* 2358 0x936 "श" */
+0x00,0x00,0x00,0xff,0x06,0x09,0x09,0x07,0x01,0x01,0x0e,0x0d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x00,0x00,0x00,
+/* 2359 0x937 "ष" */
+0x00,0x00,0x00,0xff,0x0c,0x0a,0x09,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xb0,0x50,0x90,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2360 0x938 "स" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x0f,0x0c,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2361 0x939 "ह" */
+0x00,0x00,0x00,0x3f,0x00,0x03,0x04,0x04,0x03,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0xc0,0x00,0x00,0x80,0x40,0x40,0x00,0x00,0x80,0x00,0x00,
+/* 2362 0x93a "ऺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2363 0x93b "ऻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x02,0x02,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2364 0x93c "़" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,
+/* 2365 0x93d "ऽ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x10,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2366 0x93e "ा" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2367 0x93f "ि" */
+0x3f,0x40,0x40,0xf0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+0xc0,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2368 0x940 "ी" */
+0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xfc,0x02,0x02,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2369 0x941 "ु" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xe0,
+/* 2370 0x942 "ू" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,
+/* 2371 0x943 "ृ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x70,
+/* 2372 0x944 "ॄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x70,0x80,0x78,
+/* 2373 0x945 "ॅ" */
+0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2374 0x946 "ॆ" */
+0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2375 0x947 "े" */
+0x1e,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2376 0x948 "ै" */
+0x07,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2377 0x949 "ॉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x11,0x09,0x06,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2378 0x94a "ॊ" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x02,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2379 0x94b "ो" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x04,0x02,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2380 0x94c "ौ" */
+0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x7c,0xfa,0x06,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2381 0x94d "्" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,
+/* 2382 0x94e "ॎ" */
+0x00,0x00,0x00,0xf0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2383 0x94f "ॏ" */
+0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x7c,0xfa,0x06,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2384 0x950 "ॐ" */
+0x00,0x00,0x00,0x1c,0x22,0x01,0x01,0x06,0x41,0x41,0x21,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x18,0x18,0x42,0x3c,0x00,0x00,0x0c,0x12,0x92,0x6c,0x00,0x00,0x00,0x00,0x00,
+/* 2385 0x951 "॑" */
+0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2386 0x952 "॒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,
+/* 2387 0x953 "॓" */
+0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2388 0x954 "॔" */
+0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2389 0x955 "ॕ" */
+0x02,0x01,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2390 0x956 "ॖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,
+/* 2391 0x957 "ॗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x09,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x90,0xe0,
+/* 2392 0x958 "क़" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x0e,0x11,0x11,0x0e,0x00,0x0c,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0xb0,0xc8,0x88,0x88,0x90,0x80,0x80,0x00,0x00,0x00,
+/* 2393 0x959 "ख़" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x09,0x1a,0x1a,0x11,0x08,0x04,0x03,0x00,0x03,0x03,
+0x00,0x00,0x00,0xff,0x10,0x10,0xd0,0x30,0x30,0xd0,0x10,0x30,0xd0,0x00,0x00,0x00,
+/* 2394 0x95a "ग़" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x0a,0x06,0x02,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x80,0x00,0x00,
+/* 2395 0x95b "ज़" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x04,0x03,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x78,0x48,0x48,0x88,0x08,0x08,0x88,0x80,0x00,0x00,
+/* 2396 0x95c "ड़" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x01,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0xe0,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0xc0,0xc0,
+/* 2397 0x95d "ढ़" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x01,0x01,
+0x00,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x60,0x90,0x90,0x50,0xe0,0x00,0x80,0x80,
+/* 2398 0x95e "फ़" */
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0x40,0x70,0xc8,0x48,0x48,0x48,0x50,0x00,0x00,0x00,
+/* 2399 0x95f "य़" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x0c,0x08,0x08,0x07,0x00,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x30,0xd0,0x10,0x10,0x00,0x00,0x00,
+/* 2400 0x960 "ॠ" */
+0x00,0x00,0x00,0x7f,0x00,0x1e,0x21,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x8c,0xfc,0x88,0x98,0xa0,0x98,0xa2,0x9c,0x00,0x00,0x00,
+/* 2401 0x961 "ॡ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x1c,0x22,0x21,0x20,0x10,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0x20,0x70,0x88,0x08,0x30,0x40,0x30,0x44,0x38,0x00,0x00,
+/* 2402 0x962 "ॢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x18,
+/* 2403 0x963 "ॣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x11,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x70,0x94,0x18,0x0e,
+/* 2404 0x964 "।" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 2405 0x965 "॥" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 2406 0x966 "०" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2407 0x967 "१" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x80,0x40,0x00,0x00,
+/* 2408 0x968 "२" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x03,0x03,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x80,0x40,0x20,0x00,
+/* 2409 0x969 "३" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x01,0x00,0x00,0x06,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x20,0x20,0x20,0xc0,0x00,0x80,0x00,
+/* 2410 0x96a "४" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 2411 0x96b "५" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,
+/* 2412 0x96c "६" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x04,0x03,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x80,0x00,0x00,0x60,0xe0,0x80,0x00,0x00,
+/* 2413 0x96d "७" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x09,0x09,0x08,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x30,0xd0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2414 0x96e "८" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2415 0x96f "९" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 2416 0x970 "॰" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2417 0x971 "ॱ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2418 0x972 "ॲ" */
+0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x42,0x22,0x1c,0xcf,0x22,0x12,0x12,0x62,0x12,0x1e,0x12,0x22,0xc2,0x00,0x00,0x00,
+/* 2419 0x973 "ॳ" */
+0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x02,0x02,0xcf,0x22,0x12,0x12,0x62,0x12,0x1e,0x12,0x22,0xc2,0x00,0x00,0x00,
+/* 2420 0x974 "ॴ" */
+0x00,0x00,0x00,0x07,0x08,0x00,0x00,0x01,0x10,0x10,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x02,0x02,0x3f,0x8a,0x4a,0x4a,0x8a,0x4a,0x7a,0x4a,0x8a,0x0a,0x00,0x00,0x00,
+/* 2421 0x975 "ॵ" */
+0x01,0x00,0x00,0x07,0x08,0x00,0x00,0x01,0x10,0x10,0x08,0x08,0x07,0x00,0x00,0x00,
+0x20,0x9c,0x72,0x0f,0x8a,0x4a,0x4a,0x8a,0x4a,0x7a,0x4a,0x8a,0x0a,0x00,0x00,0x00,
+/* 2422 0x976 "ॶ" */
+0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xcf,0x22,0x12,0x12,0x62,0x12,0x1e,0x12,0x22,0xc2,0x00,0x84,0x78,
+/* 2423 0x977 "ॷ" */
+0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x00,0x02,0x01,
+0x00,0x00,0x00,0xcf,0x22,0x12,0x12,0x62,0x12,0x1e,0x12,0x22,0xc2,0x90,0x64,0xf8,
+/* 2424 0x978 "ॸ" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x0f,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2425 0x979 "ॹ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x04,0x03,0x00,0x18,0x18,0x03,0x03,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x78,0x48,0x48,0x88,0x08,0x68,0x68,0x00,0x00,0x00,
+/* 2426 0x97a "ॺ" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x03,0x0c,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x90,0x50,0x30,0xd0,0x10,0x10,0x00,0x00,0x00,
+/* 2427 0x97b "ॻ" */
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x0a,0x06,0x02,0x00,0x00,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,
+/* 2428 0x97c "ॼ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x04,0x03,0x00,0x00,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x78,0x48,0x48,0x88,0x08,0x08,0xf8,0x00,0x00,0x00,
+/* 2429 0x97d "ॽ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 2430 0x97e "ॾ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x01,0x04,0x04,0x02,0x01,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0xe0,0x00,0x00,0xe0,0x10,0x10,0xe0,0xf8,0x00,0x00,0x00,
+/* 2431 0x97f "ॿ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x0c,0x0a,0x09,0x07,0x00,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x10,0xd0,0x30,0x30,0x50,0x90,0x10,0xf0,0x00,0x00,0x00,
+/* 2432 0x980 "ঀ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x18,0x00,
+/* 2433 0x981 "ঁ" */
+0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2434 0x982 "ং" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x00,0x04,0x02,0x01,0x01,0x00,0x00,
+/* 2435 0x983 "ঃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x00,0x02,0x05,0x05,0x02,0x00,0x00,
+/* 2436 0x984 "঄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2437 0x985 "অ" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x12,0x12,0x10,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x88,0x48,0x28,0x28,0x28,0x28,0x58,0x88,0x00,0x00,0x00,
+/* 2438 0x986 "আ" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x12,0x12,0x10,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x0a,0x8a,0x4a,0x2a,0x2a,0x2a,0x2a,0x5a,0x8a,0x00,0x00,0x00,
+/* 2439 0x987 "ই" */
+0x02,0x01,0x00,0x3f,0x00,0x03,0x04,0x04,0x00,0x00,0x07,0x03,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x08,0xff,0x00,0xc0,0x20,0x10,0x10,0x60,0x80,0x00,0xc0,0x30,0x00,0x00,
+/* 2440 0x988 "ঈ" */
+0x02,0x01,0x00,0x3f,0x00,0x06,0x09,0x08,0x01,0x02,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x08,0xff,0x00,0x18,0x20,0xe0,0x40,0x40,0x40,0x20,0x18,0x00,0x00,0x00,
+/* 2441 0x989 "উ" */
+0x02,0x01,0x00,0x3f,0x00,0x00,0x08,0x08,0x08,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0xf0,0x08,0xff,0x40,0x40,0x58,0x68,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2442 0x98a "ঊ" */
+0x02,0x01,0x00,0x3f,0x00,0x00,0x0a,0x0a,0x0a,0x09,0x05,0x04,0x03,0x00,0x00,0x00,
+0x00,0xf0,0x08,0xff,0x40,0x40,0x58,0x68,0x08,0x08,0x08,0xf0,0xe0,0x00,0x00,0x00,
+/* 2443 0x98b "ঋ" */
+0x00,0x00,0x00,0x00,0x10,0x24,0x1a,0x01,0x0e,0x30,0x0e,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x2f,0x28,0x28,0x68,0xa8,0x68,0x38,0x28,0xa8,0x68,0x00,0x00,0x00,
+/* 2444 0x98c "ঌ" */
+0x00,0x00,0x00,0x03,0x04,0x02,0x01,0x00,0x07,0x08,0x08,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x50,0x50,0x60,0x80,0x00,0x00,
+/* 2445 0x98d "঍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2446 0x98e "঎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2447 0x98f "এ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x12,0x11,0x10,0x10,0x10,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x10,0xd0,0x30,0x10,0x00,0x00,0x00,
+/* 2448 0x990 "ঐ" */
+0x02,0x01,0x00,0x00,0x01,0x02,0x12,0x11,0x10,0x10,0x10,0x09,0x06,0x00,0x00,0x00,
+0x00,0xf0,0x08,0xe4,0x14,0x14,0x18,0x10,0x10,0x10,0xd0,0x30,0x10,0x00,0x00,0x00,
+/* 2449 0x991 "঑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2450 0x992 "঒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2451 0x993 "ও" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x08,0x08,0x30,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2452 0x994 "ঔ" */
+0x00,0x01,0x00,0x01,0x02,0x10,0x10,0x10,0x08,0x08,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x88,0x48,0x28,0x28,0xc8,0x30,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2453 0x995 "ক" */
+0x00,0x00,0x00,0xff,0x00,0x01,0x02,0x0c,0x10,0x0c,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0xe0,0x50,0x48,0x48,0x48,0x50,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 2454 0x996 "খ" */
+0x00,0x00,0x00,0x08,0x07,0x00,0x00,0x01,0x06,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x8f,0x48,0x48,0x48,0x88,0x08,0x08,0xc8,0x28,0x18,0x00,0x00,0x00,
+/* 2455 0x997 "গ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x0f,0x00,0x00,0x01,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xcf,0x28,0x18,0x08,0x88,0x88,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2456 0x998 "ঘ" */
+0x00,0x00,0x00,0xff,0x04,0x08,0x08,0x06,0x01,0x06,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xe8,0x18,0x00,0x00,0x00,
+/* 2457 0x999 "ঙ" */
+0x00,0x00,0x00,0x04,0x04,0x02,0x01,0x11,0x11,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x90,0xe0,0x00,0x30,0xe8,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2458 0x99a "চ" */
+0x00,0x00,0x00,0xff,0x08,0x0c,0x0c,0x0b,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0xe0,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2459 0x99b "ছ" */
+0x00,0x00,0x00,0xff,0x08,0x0e,0x09,0x09,0x06,0x00,0x0f,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0xc0,0x20,0x20,0x40,0x80,0x00,0xc0,0x30,0x00,0x00,
+/* 2460 0x99c "জ" */
+0x00,0x00,0x00,0xff,0x01,0x11,0x11,0x11,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x40,0x20,0x18,0xc8,0x50,0x50,0x50,0x88,0x00,0x00,0x00,
+/* 2461 0x99d "ঝ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x06,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xef,0x68,0xa8,0x28,0x28,0x28,0x28,0x28,0xb8,0x68,0x00,0x00,0x00,
+/* 2462 0x99e "ঞ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x00,0x10,0x10,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xb0,0xc8,0x88,0x90,0x88,0xc8,0xb0,0x80,0x00,0x00,0x00,
+/* 2463 0x99f "ট" */
+0x02,0x01,0x00,0xff,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x00,0x00,0x00,
+0x00,0xf0,0x08,0xff,0x00,0x00,0x00,0x00,0x30,0x30,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2464 0x9a0 "ঠ" */
+0x01,0x02,0x01,0xff,0x00,0x00,0x01,0x09,0x16,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x80,0x00,0x00,0xff,0xc0,0xa0,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2465 0x9a1 "ড" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x08,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0x58,0x68,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2466 0x9a2 "ঢ" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x30,0x30,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2467 0x9a3 "ণ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0e,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0f,0xc8,0x28,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2468 0x9a4 "ত" */
+0x00,0x00,0x00,0xff,0x00,0x08,0x09,0x09,0x08,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2469 0x9a5 "থ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x00,0x01,0x06,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x8f,0x48,0x48,0x48,0x88,0x08,0x08,0xc8,0x28,0x18,0x00,0x00,0x00,
+/* 2470 0x9a6 "দ" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x30,0xd0,0x10,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 2471 0x9a7 "ধ" */
+0x00,0x00,0x00,0x02,0x04,0x04,0x03,0x06,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0f,0x18,0x68,0x88,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2472 0x9a8 "ন" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x03,0x04,0x08,0x0e,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0xc8,0x28,0x18,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2473 0x9a9 "঩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2474 0x9aa "প" */
+0x00,0x00,0x00,0x07,0x08,0x18,0x04,0x02,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xcf,0x28,0x18,0x18,0x68,0x88,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2475 0x9ab "ফ" */
+0x00,0x00,0x00,0xff,0x08,0x04,0x02,0x01,0x02,0x0c,0x18,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x10,0x28,0x28,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 2476 0x9ac "ব" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x06,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x18,0x68,0x88,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2477 0x9ad "ভ" */
+0x00,0x00,0x00,0xff,0x00,0x01,0x0b,0x0a,0x09,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x80,0x90,0x28,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2478 0x9ae "ম" */
+0x00,0x00,0x00,0xff,0x00,0x0c,0x02,0x01,0x01,0x03,0x05,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2479 0x9af "য" */
+0x00,0x00,0x00,0xff,0x08,0x04,0x02,0x01,0x02,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2480 0x9b0 "র" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x06,0x18,0x06,0x01,0x00,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0xff,0x18,0x68,0x88,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2481 0x9b1 "঱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2482 0x9b2 "ল" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x06,0x09,0x08,0x08,0x08,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x38,0x48,0x88,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2483 0x9b3 "঳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2484 0x9b4 "঴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2485 0x9b5 "঵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2486 0x9b6 "শ" */
+0x00,0x00,0x00,0xf0,0x0a,0x05,0x0d,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x6f,0x98,0x08,0x88,0x88,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2487 0x9b7 "ষ" */
+0x00,0x00,0x00,0xff,0x08,0x04,0x02,0x01,0x02,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x88,0x68,0x18,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2488 0x9b8 "স" */
+0x00,0x00,0x00,0xff,0x06,0x09,0x00,0x00,0x00,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x88,0xb8,0x48,0x88,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2489 0x9b9 "হ" */
+0x00,0x00,0x00,0xff,0x00,0x07,0x0e,0x06,0x00,0x00,0x07,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0xc0,0x20,0x10,0x10,0x60,0x80,0x00,0xc0,0x30,0x00,0x00,
+/* 2490 0x9ba "঺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2491 0x9bb "঻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2492 0x9bc "়" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,
+/* 2493 0x9bd "ঽ" */
+0x00,0x00,0x00,0x0c,0x03,0x03,0x03,0x00,0x00,0x00,0x07,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x60,0x80,0x00,0xc0,0x30,0x00,0x00,
+/* 2494 0x9be "া" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0b,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2495 0x9bf "ি" */
+0x3f,0x40,0x40,0xe0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+0xf0,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2496 0x9c0 "ী" */
+0x0f,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xfc,0x02,0xfa,0x07,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2497 0x9c1 "ু" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xe8,0x10,0xe8,
+/* 2498 0x9c2 "ূ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x8c,0x73,
+/* 2499 0x9c3 "ৃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x08,
+/* 2500 0x9c4 "ৄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x02,0x01,0x04,0x08,0x10,0x08,
+/* 2501 0x9c5 "৅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2502 0x9c6 "৆" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2503 0x9c7 "ে" */
+0x00,0x00,0x00,0xf0,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0xe0,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2504 0x9c8 "ৈ" */
+0x80,0x60,0x10,0xf0,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0xe0,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2505 0x9c9 "৉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2506 0x9ca "৊" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2507 0x9cb "ো" */
+0x00,0x00,0x00,0xf0,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0xe0,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0b,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2508 0x9cc "ৌ" */
+0x01,0x00,0x00,0xf0,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0xe0,0x60,0x00,0x00,0x00,
+0x00,0xfc,0x02,0x0b,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2509 0x9cd "্" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,
+/* 2510 0x9ce "ৎ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x05,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0xe0,0x10,0x10,0x00,0x00,0x00,
+/* 2511 0x9cf "৏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2512 0x9d0 "৐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2513 0x9d1 "৑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2514 0x9d2 "৒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2515 0x9d3 "৓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2516 0x9d4 "৔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2517 0x9d5 "৕" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2518 0x9d6 "৖" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2519 0x9d7 "ৗ" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x02,0x0b,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 2520 0x9d8 "৘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2521 0x9d9 "৙" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2522 0x9da "৚" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2523 0x9db "৛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2524 0x9dc "ড়" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x08,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0x58,0x68,0x08,0x08,0x08,0x10,0xe0,0x00,0xc0,0xc0,
+/* 2525 0x9dd "ঢ়" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x30,0x30,0x20,0xc0,0x00,0x60,0x60,0x00,
+/* 2526 0x9de "৞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2527 0x9df "য়" */
+0x00,0x00,0x00,0xff,0x08,0x04,0x02,0x01,0x02,0x0c,0x03,0x00,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2528 0x9e0 "ৠ" */
+0x00,0x00,0x00,0x00,0x10,0x24,0x1a,0x01,0x06,0x18,0x06,0x01,0x02,0x04,0x02,0x01,
+0x00,0x00,0x00,0x2f,0x28,0x28,0x68,0xa8,0x68,0x38,0x28,0xa8,0x68,0x00,0x00,0x00,
+/* 2529 0x9e1 "ৡ" */
+0x00,0x00,0x00,0x03,0x04,0x02,0x01,0x00,0x07,0x08,0x08,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x50,0x60,0x90,0x08,0x68,0x98,
+/* 2530 0x9e2 "ৢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x34,0x4c,
+/* 2531 0x9e3 "ৣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x03,0x05,0x00,0x08,0x04,0x34,0x4c,
+/* 2532 0x9e4 "৤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2533 0x9e5 "৥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2534 0x9e6 "০" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2535 0x9e7 "১" */
+0x00,0x00,0x00,0x00,0x08,0x06,0x01,0x00,0x00,0x00,0x00,0x06,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x08,0x08,0x70,0x80,0x00,0x00,0x00,
+/* 2536 0x9e8 "২" */
+0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x07,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x60,0x80,0x00,0xc0,0x20,0x10,0x00,
+/* 2537 0x9e9 "৩" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x12,0x12,0x11,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0xc8,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2538 0x9ea "৪" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 2539 0x9eb "৫" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x80,0x80,0x50,0x20,0xc0,0x00,0x00,0x00,
+/* 2540 0x9ec "৬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x58,0x68,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 2541 0x9ed "৭" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x60,0xa0,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 2542 0x9ee "৮" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0b,0x0c,0x08,0x08,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2543 0x9ef "৯" */
+0x00,0x00,0x00,0x02,0x04,0x04,0x02,0x01,0x00,0x07,0x08,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x50,0x60,0x00,0x00,0x00,
+/* 2544 0x9f0 "ৰ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x06,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x18,0x68,0x88,0xc8,0x28,0x18,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2545 0x9f1 "ৱ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x06,0x18,0x06,0x01,0x0c,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0xff,0x18,0x68,0x88,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 2546 0x9f2 "৲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 2547 0x9f3 "৳" */
+0x00,0x00,0x00,0x06,0x09,0x01,0x03,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x60,0x50,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2548 0x9f4 "৴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2549 0x9f5 "৵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x0c,0x01,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x90,0xa0,0x40,0x80,0x00,0x00,0x00,
+/* 2550 0x9f6 "৶" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x0c,0x00,0x00,0x01,0x0e,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x88,0x90,0x90,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2551 0x9f7 "৷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 2552 0x9f8 "৸" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x08,0x00,
+/* 2553 0x9f9 "৹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2554 0x9fa "৺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x90,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2555 0x9fb "৻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 2556 0x9fc "ৼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x90,0xa0,0x20,0x40,0x80,0x20,0x10,0x08,0x00,
+/* 2557 0x9fd "৽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2558 0x9fe "৾" */
+0x03,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0xc0,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2559 0x9ff "৿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2560 0xa00 "਀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2561 0xa01 "ਁ" */
+0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xa0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2562 0xa02 "ਂ" */
+0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2563 0xa03 "ਃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x02,0x00,0x02,0x05,0x02,0x00,0x00,0x00,
+/* 2564 0xa04 "਄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2565 0xa05 "ਅ" */
+0x00,0x00,0x00,0x00,0xc0,0x20,0x13,0x14,0x38,0x30,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x07,0x04,0x04,0x9c,0x64,0xc4,0xc4,0x84,0x04,0x00,0x00,0x00,
+/* 2566 0xa06 "ਆ" */
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x16,0x39,0x33,0x23,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3f,0x24,0x24,0x64,0xa0,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 2567 0xa07 "ਇ" */
+0x3c,0x42,0x42,0x40,0xff,0x44,0x44,0x42,0x41,0x42,0x44,0x42,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x04,0x04,0x04,0xfc,0x00,0x00,0x04,0xf8,0x00,0x00,0x00,
+/* 2568 0xa08 "ਈ" */
+0x00,0x00,0x00,0x00,0xff,0x40,0x40,0x20,0x1f,0x20,0x40,0x20,0x1f,0x00,0x00,0x00,
+0x78,0x84,0x84,0x04,0xfe,0x44,0x44,0x44,0xc4,0x04,0x04,0x44,0x84,0x00,0x00,0x00,
+/* 2569 0xa09 "ਉ" */
+0x07,0x08,0x10,0x20,0xff,0x20,0x20,0x20,0x3f,0x10,0x08,0x04,0x03,0x00,0x08,0x07,
+0xc0,0x20,0x10,0x08,0xff,0x08,0x08,0x10,0xe0,0x10,0x10,0x20,0xc0,0x00,0x10,0xe0,
+/* 2570 0xa0a "ਊ" */
+0x07,0x08,0x10,0x20,0xff,0x20,0x20,0x3f,0x10,0x08,0x04,0x03,0x08,0x07,0x08,0x07,
+0xc0,0x20,0x10,0x08,0xff,0x08,0x10,0xe0,0x10,0x10,0x20,0xc0,0x10,0xe0,0x10,0xe0,
+/* 2571 0xa0b "਋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2572 0xa0c "਌" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2573 0xa0d "਍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2574 0xa0e "਎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2575 0xa0f "ਏ" */
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x08,0x07,0x08,0x10,0x08,0x07,0x00,0x00,0x00,
+0xc0,0x20,0x10,0x10,0xff,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,
+/* 2576 0xa10 "ਐ" */
+0x00,0x00,0x00,0x00,0xc0,0x20,0x13,0x14,0x38,0x30,0x20,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x08,0xf4,0x0c,0x1f,0x04,0x04,0x9c,0x64,0xc4,0xc4,0x84,0x04,0x04,0x00,0x00,
+/* 2577 0xa11 "਑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2578 0xa12 "਒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2579 0xa13 "ਓ" */
+0x07,0x08,0x10,0x20,0xff,0x20,0x20,0x20,0x3f,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0xf0,0x00,0x00,0x00,0xff,0x08,0x08,0x10,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2580 0xa14 "ਔ" */
+0x02,0x01,0x00,0x00,0xc0,0x20,0x13,0x14,0x38,0x30,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x48,0x48,0x1f,0x04,0x04,0x9c,0x64,0xc4,0xc4,0x84,0x04,0x04,0x00,0x00,
+/* 2581 0xa15 "ਕ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xa0,0x60,0x60,0x90,0x10,0x10,0x00,0x00,
+/* 2582 0xa16 "ਖ" */
+0x00,0x00,0x00,0x00,0xf0,0x10,0x08,0x0f,0x10,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0xf0,0x10,0x10,0x30,0xd0,0x10,0x10,0x00,0x00,
+/* 2583 0xa17 "ਗ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x1f,0x20,0x20,0x10,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x10,0x10,0x00,0x00,
+/* 2584 0xa18 "ਘ" */
+0x00,0x00,0x00,0x00,0xf1,0x11,0x09,0x09,0x11,0x21,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x30,0xd0,0x10,0x00,0x00,0x00,
+/* 2585 0xa19 "ਙ" */
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x1f,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xc0,0x20,0xa0,0x40,0xa0,0x10,0x00,0x00,0x00,
+/* 2586 0xa1a "ਚ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x18,0x1f,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 2587 0xa1b "ਛ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x1f,0x20,0x1f,0x21,0x21,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x00,0xf0,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 2588 0xa1c "ਜ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x18,0x1f,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2589 0xa1d "ਝ" */
+0x00,0x00,0x00,0x00,0xff,0x0c,0x02,0x0f,0x10,0x26,0x07,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x30,0x40,0xe0,0x10,0x08,0xf0,0x00,0x80,0x40,0x00,0x00,
+/* 2590 0xa1e "ਞ" */
+0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x1f,0x20,0x20,0x1f,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 2591 0xa1f "ਟ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x02,0x04,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x40,0x40,0xc0,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,
+/* 2592 0xa20 "ਠ" */
+0x00,0x00,0x00,0x00,0xff,0x01,0x01,0x02,0x04,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 2593 0xa21 "ਡ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x00,0x00,0x1f,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x08,0x08,0xf0,0x10,0x10,0x08,0x88,0x70,0xc0,0x00,0x00,
+/* 2594 0xa22 "ਢ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x18,0x1f,0x08,0x08,0x09,0x0a,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x00,0x00,0xe0,0x10,0x20,0xc0,0x00,
+/* 2595 0xa23 "ਣ" */
+0x00,0x00,0x00,0x00,0xff,0x01,0x00,0x00,0x0f,0x10,0x20,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x00,0xc0,0x60,0x50,0xc0,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 2596 0xa24 "ਤ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x07,0x00,0x20,0x30,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xa0,0xe0,0x30,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 2597 0xa25 "ਥ" */
+0x00,0x00,0x00,0x00,0xff,0x10,0x08,0x0f,0x10,0x30,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x10,0x10,0x30,0xd0,0x10,0x10,0x00,0x00,
+/* 2598 0xa26 "ਦ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x30,0x3f,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x20,0xe0,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 2599 0xa27 "ਧ" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x04,0x04,0x08,0x10,0x08,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x90,0x10,0x00,0x00,
+/* 2600 0xa28 "ਨ" */
+0x00,0x00,0x00,0x00,0xff,0x01,0x01,0x02,0x04,0x08,0x10,0x10,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x20,0x00,0x00,0x00,
+/* 2601 0xa29 "਩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2602 0xa2a "ਪ" */
+0x00,0x00,0x00,0x00,0xf8,0x08,0x04,0x04,0x08,0x10,0x08,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x90,0x10,0x00,0x00,
+/* 2603 0xa2b "ਫ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x1f,0x20,0x20,0x21,0x12,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x00,0x00,0xe0,0x10,0x20,0xc0,0x00,0x00,
+/* 2604 0xa2c "ਬ" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x04,0x07,0x08,0x10,0x08,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x10,0x10,0x10,0x70,0x90,0x10,0x00,0x00,
+/* 2605 0xa2d "ਭ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x03,0x04,0x03,0x00,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xd0,0x30,0xc8,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 2606 0xa2e "ਮ" */
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x0f,0x18,0x18,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x90,0x90,0x00,0x00,
+/* 2607 0xa2f "ਯ" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x04,0x04,0x08,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x90,0x90,0x90,0x90,0x10,0x00,0x00,
+/* 2608 0xa30 "ਰ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x08,0x08,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 2609 0xa31 "਱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2610 0xa32 "ਲ" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x04,0x0a,0x11,0x10,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x40,0xa0,0x10,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 2611 0xa33 "ਲ਼" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x04,0x0a,0x11,0x10,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x40,0xa0,0x10,0x10,0x20,0x4c,0x0c,0x00,0x00,
+/* 2612 0xa34 "਴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2613 0xa35 "ਵ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x1f,0x20,0x30,0x0f,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x00,0x00,0xf0,0x00,0xe0,0x00,0x00,0x00,
+/* 2614 0xa36 "ਸ਼" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x0f,0x18,0x18,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x90,0x90,0x00,0x00,
+/* 2615 0xa37 "਷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2616 0xa38 "ਸ" */
+0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x0f,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 2617 0xa39 "ਹ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x08,0x08,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 2618 0xa3a "਺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2619 0xa3b "਻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2620 0xa3c "਼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,
+/* 2621 0xa3d "਽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2622 0xa3e "ਾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2623 0xa3f "ਿ" */
+0x78,0x84,0x84,0x84,0xe0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2624 0xa40 "ੀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x78,0x84,0x84,0x84,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+/* 2625 0xa41 "ੁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,
+/* 2626 0xa42 "ੂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x20,0xc0,
+/* 2627 0xa43 "੃" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2628 0xa44 "੄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2629 0xa45 "੅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2630 0xa46 "੆" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2631 0xa47 "ੇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2632 0xa48 "ੈ" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2633 0xa49 "੉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2634 0xa4a "੊" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2635 0xa4b "ੋ" */
+0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2636 0xa4c "ੌ" */
+0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x48,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2637 0xa4d "੍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x02,
+/* 2638 0xa4e "੎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2639 0xa4f "੏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2640 0xa50 "੐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2641 0xa51 "ੑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x06,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
+/* 2642 0xa52 "੒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2643 0xa53 "੓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2644 0xa54 "੔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2645 0xa55 "੕" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2646 0xa56 "੖" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2647 0xa57 "੗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2648 0xa58 "੘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2649 0xa59 "ਖ਼" */
+0x00,0x00,0x00,0x00,0xf8,0x08,0x04,0x07,0x08,0x10,0x08,0x06,0x01,0x18,0x18,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0xf0,0x10,0x10,0x10,0x70,0x90,0x10,0x00,0x00,
+/* 2650 0xa5a "ਗ਼" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x0f,0x10,0x10,0x10,0x08,0x04,0x03,0x18,0x18,
+0x00,0x00,0x00,0x00,0xff,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x10,0x00,0x00,
+/* 2651 0xa5b "ਜ਼" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x18,0x1f,0x08,0x08,0x08,0x08,0x09,0x01,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x90,0x80,0x00,
+/* 2652 0xa5c "ੜ" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x07,0x00,0x00,0x10,0x08,0x07,0x04,0x02,
+0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x20,0xe0,0x10,0x10,0x20,0x40,0xc0,0x20,0x10,
+/* 2653 0xa5d "੝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2654 0xa5e "ਫ਼" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x1f,0x20,0x20,0x21,0x12,0x0c,0x63,0x60,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0xf0,0x00,0x00,0xe0,0x10,0x20,0xc0,0x00,0x00,
+/* 2655 0xa5f "੟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2656 0xa60 "੠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2657 0xa61 "੡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2658 0xa62 "੢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2659 0xa63 "੣" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2660 0xa64 "੤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2661 0xa65 "੥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2662 0xa66 "੦" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2663 0xa67 "੧" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x30,0x00,0x00,
+/* 2664 0xa68 "੨" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 2665 0xa69 "੩" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x1f,0x00,0x00,0x30,0x3f,0x08,0x04,0x02,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x40,0x80,0x40,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2666 0xa6a "੪" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x04,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x40,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 2667 0xa6b "੫" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x08,0x10,0x20,0x10,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x00,0x00,
+/* 2668 0xa6c "੬" */
+0x00,0x01,0x01,0x00,0x03,0x04,0x08,0x04,0x03,0x04,0x08,0x04,0x03,0x00,0x00,0x00,
+0xe0,0x00,0x00,0xc0,0xf0,0x30,0x00,0x00,0xf0,0x00,0x00,0x08,0xf0,0x00,0x00,0x00,
+/* 2669 0xa6d "੭" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x06,0x00,0x00,0x00,0x03,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2670 0xa6e "੮" */
+0x00,0x00,0x00,0x30,0x3f,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,
+/* 2671 0xa6f "੯" */
+0x00,0x00,0x00,0x30,0x3f,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x60,0x80,0x80,0x60,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,
+/* 2672 0xa70 "ੰ" */
+0x03,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2673 0xa71 "ੱ" */
+0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2674 0xa72 "ੲ" */
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x08,0x07,0x08,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x10,0x10,0x10,0xf0,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 2675 0xa73 "ੳ" */
+0x07,0x08,0x10,0x20,0xff,0x20,0x20,0x20,0x3f,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0xe0,0x10,0x08,0x08,0xff,0x08,0x08,0x10,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2676 0xa74 "ੴ" */
+0x00,0x00,0x18,0x24,0x25,0x1d,0x0b,0x14,0x28,0x28,0x28,0x24,0x12,0x09,0x00,0x00,
+0x00,0x00,0x04,0xf8,0x0c,0x92,0x42,0x82,0x0c,0x02,0x02,0x04,0x08,0xf0,0x00,0x00,
+/* 2677 0xa75 "ੵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,
+/* 2678 0xa76 "੶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x03,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2679 0xa77 "੷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2680 0xa78 "੸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2681 0xa79 "੹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2682 0xa7a "੺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2683 0xa7b "੻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2684 0xa7c "੼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2685 0xa7d "੽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2686 0xa7e "੾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2687 0xa7f "੿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2688 0xa80 "઀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2689 0xa81 "ઁ" */
+0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xa0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2690 0xa82 "ં" */
+0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2691 0xa83 "ઃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x00,
+/* 2692 0xa84 "઄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2693 0xa85 "અ" */
+0x00,0x00,0x00,0x00,0x78,0x04,0x04,0x38,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xf8,0x48,0x88,0x0a,0x04,0x00,0x00,0x00,0x00,
+/* 2694 0xa86 "આ" */
+0x00,0x00,0x00,0x00,0xf0,0x08,0x09,0x71,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0xe2,0xa2,0x22,0x2a,0x11,0x00,0x00,0x00,0x00,
+/* 2695 0xa87 "ઇ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x18,0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2696 0xa88 "ઈ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x06,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x30,0x48,0x48,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2697 0xa89 "ઉ" */
+0x00,0x03,0x04,0x08,0x09,0x08,0x08,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x10,0xc0,0x20,0x20,0x20,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2698 0xa8a "ઊ" */
+0x00,0x0f,0x10,0x20,0x27,0x20,0x20,0x20,0x23,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x90,0x90,0x90,0x10,0x90,0x94,0x08,0x00,0x00,0x00,0x00,
+/* 2699 0xa8b "ઋ" */
+0x00,0x00,0x00,0x00,0x39,0x05,0x03,0x01,0x03,0x05,0x09,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x18,0xe4,0x02,0x42,0x84,0x00,0x00,0x00,0x00,
+/* 2700 0xa8c "ઌ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x70,0x88,0x84,0x18,0x20,0x20,0x1c,0x00,0x00,0x00,0x00,
+/* 2701 0xa8d "ઍ" */
+0x00,0x00,0x00,0x00,0x78,0x04,0x04,0x38,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x40,0x20,0x18,0x00,0x08,0x08,0x88,0xf8,0x48,0x88,0x0a,0x04,0x00,0x00,0x00,0x00,
+/* 2702 0xa8e "઎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2703 0xa8f "એ" */
+0x00,0x00,0x00,0x00,0x78,0x04,0x04,0x38,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x60,0x10,0x08,0x08,0x08,0x88,0xf8,0x48,0x88,0x0a,0x04,0x00,0x00,0x00,0x00,
+/* 2704 0xa90 "ઐ" */
+0x00,0x00,0x00,0x00,0x78,0x04,0x04,0x38,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x18,0xf8,0x08,0x08,0x08,0x88,0xf8,0x48,0x88,0x0a,0x04,0x00,0x00,0x00,0x00,
+/* 2705 0xa91 "ઑ" */
+0x00,0x00,0x00,0x00,0xf0,0x08,0x09,0x71,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x10,0x08,0x06,0x00,0x22,0x22,0x22,0xe2,0xa2,0x22,0x2a,0x11,0x00,0x00,0x00,0x00,
+/* 2706 0xa92 "઒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2707 0xa93 "ઓ" */
+0x00,0x00,0x00,0x00,0xf0,0x08,0x09,0x71,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x18,0x04,0x02,0x22,0x22,0x22,0xe2,0xa2,0x22,0x2a,0x11,0x00,0x00,0x00,0x00,
+/* 2708 0xa94 "ઔ" */
+0x00,0x00,0x00,0x00,0xf0,0x08,0x09,0x71,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x38,0x06,0x3e,0x02,0x22,0x22,0x22,0xe2,0xa2,0x22,0x2a,0x11,0x00,0x00,0x00,0x00,
+/* 2709 0xa95 "ક" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x01,0x02,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x40,0x80,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2710 0xa96 "ખ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x12,0x13,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xc0,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2711 0xa97 "ગ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x01,0x01,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 2712 0xa98 "ઘ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0x10,0x10,0x30,0x54,0x88,0x00,0x00,0x00,0x00,
+/* 2713 0xa99 "ઙ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x02,0x21,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2714 0xa9a "ચ" */
+0x00,0x00,0x00,0x00,0x3c,0x02,0x02,0x1c,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x30,0x50,0x94,0x08,0x00,0x00,0x00,0x00,
+/* 2715 0xa9b "છ" */
+0x00,0x00,0x00,0x00,0x1c,0x21,0x21,0x21,0x18,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xa0,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2716 0xa9c "જ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x28,0x48,0x49,0x31,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2717 0xa9d "ઝ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x01,0x01,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xe0,0x10,0x10,0x10,0x60,0x00,0x00,0x00,0x00,
+/* 2718 0xa9e "ઞ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x01,0x01,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xe0,0x20,0x20,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 2719 0xa9f "ટ" */
+0x00,0x00,0x00,0x00,0x38,0x04,0x04,0x18,0x20,0x40,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2720 0xaa0 "ઠ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2721 0xaa1 "ડ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x02,0x21,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2722 0xaa2 "ઢ" */
+0x00,0x00,0x00,0x00,0x1c,0x02,0x0c,0x10,0x21,0x21,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 2723 0xaa3 "ણ" */
+0x00,0x00,0x00,0x00,0x4c,0x52,0x41,0x41,0x52,0x4c,0x40,0x40,0x20,0x10,0x08,0x10,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2724 0xaa4 "ત" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2725 0xaa5 "થ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x0a,0x04,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0xc0,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2726 0xaa6 "દ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2727 0xaa7 "ધ" */
+0x00,0x06,0x08,0x08,0x06,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2728 0xaa8 "ન" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 2729 0xaa9 "઩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2730 0xaaa "પ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xc0,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2731 0xaab "ફ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x01,0x02,0x18,0x1f,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x40,0x80,0x80,0x40,0x40,0x80,0x00,0x00,0x80,0x00,
+/* 2732 0xaac "બ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xf8,0x08,0x08,0x0a,0x04,0x00,0x00,0x00,0x00,
+/* 2733 0xaad "ભ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x88,0xf8,0x08,0x08,0x0a,0x04,0x00,0x00,0x00,0x00,
+/* 2734 0xaae "મ" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xe0,0x20,0x20,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 2735 0xaaf "ય" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x04,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x60,0xa0,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 2736 0xab0 "ર" */
+0x00,0x00,0x00,0x00,0x1e,0x01,0x01,0x0e,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 2737 0xab1 "઱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2738 0xab2 "લ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x20,0x27,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 2739 0xab3 "ળ" */
+0x00,0x00,0x00,0x00,0x00,0x21,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x50,0x20,0x00,0x00,0x00,
+/* 2740 0xab4 "઴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2741 0xab5 "વ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0xc0,0x40,0xc0,0x40,0x40,0x50,0x20,0x00,0x00,0x00,
+/* 2742 0xab6 "શ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0c,0x04,0x18,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 2743 0xab7 "ષ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xc0,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2744 0xab8 "સ" */
+0x00,0x00,0x00,0x00,0x3c,0x02,0x03,0x1c,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0x20,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 2745 0xab9 "હ" */
+0x00,0x00,0x00,0x00,0x21,0x22,0x21,0x20,0x24,0x23,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2746 0xaba "઺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2747 0xabb "઻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2748 0xabc "઼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,
+/* 2749 0xabd "ઽ" */
+0x00,0x00,0x00,0x00,0x38,0x40,0x40,0x30,0x08,0x04,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2750 0xabe "ા" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+/* 2751 0xabf "િ" */
+0x60,0x90,0x88,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xa0,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2752 0xac0 "ી" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x24,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+/* 2753 0xac1 "ુ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0xe0,
+/* 2754 0xac2 "ૂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x90,
+/* 2755 0xac3 "ૃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0xc0,
+/* 2756 0xac4 "ૄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x00,0xc0,
+/* 2757 0xac5 "ૅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0x08,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2758 0xac6 "૆" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2759 0xac7 "ે" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x18,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2760 0xac8 "ૈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x06,0x3e,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2761 0xac9 "ૉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x10,0x0c,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+/* 2762 0xaca "૊" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2763 0xacb "ો" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+/* 2764 0xacc "ૌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x04,0x34,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+/* 2765 0xacd "્" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,
+/* 2766 0xace "૎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2767 0xacf "૏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2768 0xad0 "ૐ" */
+0x00,0x00,0x00,0x00,0x3c,0x02,0x02,0x0c,0x18,0x04,0x43,0x42,0x3c,0x00,0x00,0x00,
+0x30,0x30,0x00,0x84,0x78,0x00,0x0c,0x12,0x32,0x4c,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2769 0xad1 "૑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2770 0xad2 "૒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2771 0xad3 "૓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2772 0xad4 "૔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2773 0xad5 "૕" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2774 0xad6 "૖" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2775 0xad7 "૗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2776 0xad8 "૘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2777 0xad9 "૙" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2778 0xada "૚" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2779 0xadb "૛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2780 0xadc "૜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2781 0xadd "૝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2782 0xade "૞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2783 0xadf "૟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2784 0xae0 "ૠ" */
+0x00,0x00,0x00,0x00,0x72,0x0a,0x06,0x02,0x07,0x0a,0x12,0x21,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x30,0xdc,0x10,0x92,0x0c,0x00,0x00,0x00,0x00,
+/* 2785 0xae1 "ૡ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x70,0x88,0x84,0x18,0x20,0x20,0x1c,0x20,0x20,0x1c,0x00,
+/* 2786 0xae2 "ૢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x20,0x18,
+/* 2787 0xae3 "ૣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x24,0x1a,0x0c,
+/* 2788 0xae4 "૤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2789 0xae5 "૥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2790 0xae6 "૦" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 2791 0xae7 "૧" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x30,0x00,0x00,
+/* 2792 0xae8 "૨" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x0c,0x0f,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 2793 0xae9 "૩" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x03,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0xc0,0x20,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2794 0xaea "૪" */
+0x00,0x00,0x00,0x00,0x1c,0x02,0x01,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0xc0,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 2795 0xaeb "૫" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xc0,0x40,0x40,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 2796 0xaec "૬" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x08,0x07,0x04,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0xf0,0x08,0x08,0x70,
+/* 2797 0xaed "૭" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x09,0x06,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x60,0x90,0x10,0x10,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 2798 0xaee "૮" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 2799 0xaef "૯" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x21,0x22,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 2800 0xaf0 "૰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2801 0xaf1 "૱" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x02,0x1c,0x02,0x01,0x32,0x3c,0x08,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,
+/* 2802 0xaf2 "૲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2803 0xaf3 "૳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2804 0xaf4 "૴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2805 0xaf5 "૵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2806 0xaf6 "૶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2807 0xaf7 "૷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2808 0xaf8 "૸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2809 0xaf9 "ૹ" */
+0x00,0x00,0x00,0x00,0x1f,0x28,0x24,0x24,0x18,0x00,0x05,0x11,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x82,0x44,0x28,0x30,0x50,0x90,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 2810 0xafa "ૺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2811 0xafb "ૻ" */
+0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x88,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2812 0xafc "ૼ" */
+0x00,0x01,0x01,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2813 0xafd "૽" */
+0x01,0x01,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2814 0xafe "૾" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2815 0xaff "૿" */
+0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2816 0xb00 "଀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2817 0xb01 "ଁ" */
+0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xa0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2818 0xb02 "ଂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2819 0xb03 "ଃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x05,0x05,0x02,0x00,0x00,0x00,0x00,
+/* 2820 0xb04 "଄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2821 0xb05 "ଅ" */
+0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x22,0x04,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2822 0xb06 "ଆ" */
+0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x22,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x14,0x14,0x34,0xd4,0x00,0x00,0x00,0x00,
+/* 2823 0xb07 "ଇ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x40,0x4a,0x35,0x15,0x0a,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 2824 0xb08 "ଈ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x3e,0x40,0x4a,0x35,0x15,0x0a,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 2825 0xb09 "ଉ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x41,0x52,0x26,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 2826 0xb0a "ଊ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x41,0x52,0x26,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x20,0x10,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 2827 0xb0b "ଋ" */
+0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x20,0x2c,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x40,0x20,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 2828 0xb0c "ଌ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x01,0x02,0x04,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2829 0xb0d "଍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2830 0xb0e "଎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2831 0xb0f "ଏ" */
+0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x42,0x22,0x12,0x0a,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2832 0xb10 "ଐ" */
+0x00,0x01,0x02,0x00,0x01,0x03,0x05,0x21,0x11,0x09,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x10,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 2833 0xb11 "଑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2834 0xb12 "଒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2835 0xb13 "ଓ" */
+0x00,0x00,0x00,0x00,0x04,0x09,0x08,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2836 0xb14 "ଔ" */
+0x00,0x00,0x01,0x00,0x13,0x24,0x20,0x20,0x23,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x08,0x08,0x10,0x90,0x90,0xf0,0x10,0x90,0x90,0x10,0x00,0x00,0x00,0x00,
+/* 2837 0xb15 "କ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x40,0x49,0x36,0x16,0x0a,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x80,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 2838 0xb16 "ଖ" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x09,0x08,0x08,0x07,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x30,0xd0,0x10,0x10,0x90,0x10,0x00,0x00,0x00,0x00,
+/* 2839 0xb17 "ଗ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x07,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x90,0x10,0x00,0x00,0x00,0x00,
+/* 2840 0xb18 "ଘ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0a,0x0c,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2841 0xb19 "ଙ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x41,0x52,0x26,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x70,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2842 0xb1a "ଚ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x07,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2843 0xb1b "ଛ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0b,0x04,0x17,0x0a,0x05,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x80,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2844 0xb1c "ଜ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x0a,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0x60,0xa0,0xa0,0x20,0x00,0x00,0x00,0x00,
+/* 2845 0xb1d "ଝ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x10,0x16,0x09,0x09,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xa0,0x90,0x10,0xe0,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 2846 0xb1e "ଞ" */
+0x00,0x00,0x00,0x00,0x13,0x24,0x20,0x1f,0x13,0x24,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x10,0xe0,0x60,0x90,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 2847 0xb1f "ଟ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x07,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2848 0xb20 "ଠ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2849 0xb21 "ଡ" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x10,0x14,0x09,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0x90,0xa0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2850 0xb22 "ଢ" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x10,0x14,0x09,0x0a,0x07,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2851 0xb23 "ଣ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0a,0x11,0x1c,0x02,0x02,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 2852 0xb24 "ତ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x40,0x53,0x23,0x23,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2853 0xb25 "ଥ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x0e,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2854 0xb26 "ଦ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x41,0x53,0x23,0x23,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2855 0xb27 "ଧ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x90,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2856 0xb28 "ନ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x27,0x19,0x0d,0x0d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2857 0xb29 "଩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2858 0xb2a "ପ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x12,0x0c,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2859 0xb2b "ଫ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x48,0x30,0x20,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0xc8,0xc8,0xb0,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2860 0xb2c "ବ" */
+0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x2e,0x31,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2861 0xb2d "ଭ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x45,0x55,0x23,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 2862 0xb2e "ମ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x12,0x0c,0x10,0x60,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 2863 0xb2f "ଯ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x12,0x0c,0x18,0x68,0x67,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2864 0xb30 "ର" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x07,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xa0,0x10,0x00,0x00,0x00,0x00,
+/* 2865 0xb31 "଱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2866 0xb32 "ଲ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x5b,0x24,0x24,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0xa0,0xa0,0x90,0x00,0x00,0x00,0x00,
+/* 2867 0xb33 "ଳ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x5b,0x24,0x24,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2868 0xb34 "଴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2869 0xb35 "ଵ" */
+0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x2e,0x31,0x15,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2870 0xb36 "ଶ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0c,0x12,0x10,0x0e,0x09,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 2871 0xb37 "ଷ" */
+0x00,0x00,0x00,0x00,0x07,0x0c,0x12,0x13,0x0c,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x90,0x50,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2872 0xb38 "ସ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x21,0x26,0x1e,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x10,0x90,0x70,0x00,0x00,0x00,0x00,
+/* 2873 0xb39 "ହ" */
+0x00,0x00,0x00,0x00,0x0f,0x30,0x40,0x41,0x53,0x23,0x23,0x1d,0x08,0x06,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,
+/* 2874 0xb3a "଺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2875 0xb3b "଻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2876 0xb3c "଼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,
+/* 2877 0xb3d "ଽ" */
+0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x30,0x0c,0x30,0x40,0x30,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2878 0xb3e "ା" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2879 0xb3f "ି" */
+0x07,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2880 0xb40 "ୀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2881 0xb41 "ୁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xa0,0xc0,0xb0,
+/* 2882 0xb42 "ୂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xb0,
+/* 2883 0xb43 "ୃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x20,0xc0,
+/* 2884 0xb44 "ୄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x06,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x20,0xc0,
+/* 2885 0xb45 "୅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2886 0xb46 "୆" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2887 0xb47 "େ" */
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2888 0xb48 "ୈ" */
+0x01,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x60,0x00,0x00,0x00,
+0x00,0xf8,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2889 0xb49 "୉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2890 0xb4a "୊" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2891 0xb4b "ୋ" */
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2892 0xb4c "ୌ" */
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x60,0x00,0x00,0x00,
+0x00,0x78,0x84,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2893 0xb4d "୍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,
+/* 2894 0xb4e "୎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2895 0xb4f "୏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2896 0xb50 "୐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2897 0xb51 "୑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2898 0xb52 "୒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2899 0xb53 "୓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 2900 0xb54 "୔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2901 0xb55 "୕" */
+0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2902 0xb56 "ୖ" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2903 0xb57 "ୗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x78,0x84,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 2904 0xb58 "୘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2905 0xb59 "୙" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2906 0xb5a "୚" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2907 0xb5b "୛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2908 0xb5c "ଡ଼" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x10,0x14,0x09,0x08,0x07,0x00,0x03,0x03,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0x90,0xa0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2909 0xb5d "ଢ଼" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x10,0x14,0x09,0x0a,0x07,0x02,0x01,0x0c,0x0c,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2910 0xb5e "୞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2911 0xb5f "ୟ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x12,0x0c,0x18,0x68,0x67,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x10,0x30,0x48,0x9c,0x00,0x00,0x00,0x00,
+/* 2912 0xb60 "ୠ" */
+0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x20,0x2c,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0x20,0xc0,0x20,0xc0,0x20,0x10,0x00,0x00,0x00,
+/* 2913 0xb61 "ୡ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x01,0x02,0x04,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0xc0,0x20,0xc0,0x80,0x40,0x20,0x00,
+/* 2914 0xb62 "ୢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x98,0x24,0xf8,
+/* 2915 0xb63 "ୣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x58,0xa4,0x38,0xd0,
+/* 2916 0xb64 "୤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2917 0xb65 "୥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2918 0xb66 "୦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x10,0x10,0x10,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x10,0x10,0x10,0x40,0x80,0x00,0x00,0x00,
+/* 2919 0xb67 "୧" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0a,0x0a,0x09,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xe0,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,
+/* 2920 0xb68 "୨" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x07,0x00,0x00,0x00,0x03,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x50,0x50,0x90,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2921 0xb69 "୩" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x21,0x29,0x25,0x19,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 2922 0xb6a "୪" */
+0x00,0x00,0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0xc0,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 2923 0xb6b "୫" */
+0x00,0x00,0x00,0x00,0x01,0x12,0x0a,0x06,0x01,0x02,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x80,0x60,0x50,0x48,0x80,0x00,0x00,0x00,
+/* 2924 0xb6c "୬" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x03,0x00,0x08,0x07,0x00,0x00,0x03,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x90,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2925 0xb6d "୭" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x0a,0x0a,0x07,0x00,0x00,0x03,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x90,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2926 0xb6e "୮" */
+0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2927 0xb6f "୯" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2928 0xb70 "୰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x41,0x22,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2929 0xb71 "ୱ" */
+0x00,0x00,0x00,0x00,0x09,0x12,0x10,0x08,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0xe0,0x10,0xf0,0x10,0x30,0xd0,0x00,0x00,0x00,0x00,
+/* 2930 0xb72 "୲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2931 0xb73 "୳" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2932 0xb74 "୴" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x26,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x60,0xa0,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 2933 0xb75 "୵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2934 0xb76 "୶" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x2a,0x2b,0x12,0x04,0x08,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2935 0xb77 "୷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x49,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2936 0xb78 "୸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2937 0xb79 "୹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 2938 0xb7a "୺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 2939 0xb7b "୻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2940 0xb7c "୼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2941 0xb7d "୽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2942 0xb7e "୾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 2943 0xb7f "୿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 2944 0xb80 "஀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2945 0xb81 "஁" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2946 0xb82 "ஂ" */
+0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 2947 0xb83 "ஃ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 2948 0xb84 "஄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 2949 0xb85 "அ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x1f,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x90,0x90,0x90,0xf0,0x90,0x10,0x00,0x00,0x00,0x00,
+/* 2950 0xb86 "ஆ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x26,0x1a,0x02,0x7f,0x82,0x7c,0x01,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0xe0,0x50,0x50,0x50,0x10,0xe0,0x00,
+/* 2951 0xb87 "இ" */
+0x00,0x00,0x0f,0x10,0x23,0x24,0x24,0x13,0x08,0x1f,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x90,0x90,0x50,0x40,0x80,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 2952 0xb88 "ஈ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x16,0x16,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0xb0,0xb0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 2953 0xb89 "உ" */
+0x00,0x00,0x00,0x00,0x3c,0x4a,0x49,0x31,0x02,0x3c,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 2954 0xb8a "ஊ" */
+0x00,0x00,0x00,0x00,0x70,0x98,0x99,0x6a,0x09,0x70,0x80,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xd0,0x50,0x50,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 2955 0xb8b "஋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2956 0xb8c "஌" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2957 0xb8d "஍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2958 0xb8e "எ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 2959 0xb8f "ஏ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 2960 0xb90 "ஐ" */
+0x00,0x00,0x00,0x00,0x3e,0x71,0x49,0x49,0x31,0x00,0x3f,0x40,0x40,0x42,0x42,0x3d,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x10,0x10,0xe0,
+/* 2961 0xb91 "஑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2962 0xb92 "ஒ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x71,0x4a,0x4a,0x32,0x02,0x11,0x10,0x0f,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xd0,0x50,0x90,0x60,0x00,0xe0,0x40,0x80,
+/* 2963 0xb93 "ஓ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x71,0x4a,0x4a,0x32,0x02,0x31,0x48,0x3f,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xd0,0x50,0x90,0x60,0x00,0xe0,0x40,0x80,
+/* 2964 0xb94 "ஔ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0x81,0xcd,0xb5,0xb9,0x56,0x10,0x8f,0x82,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0xa8,0x68,0x28,0x00,0x00,0x00,0x00,0x00,
+/* 2965 0xb95 "க" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0xe0,0x90,0x90,0x20,0x00,0x00,0x00,0x00,
+/* 2966 0xb96 "஖" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2967 0xb97 "஗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2968 0xb98 "஘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 2969 0xb99 "ங" */
+0x00,0x00,0x00,0x00,0x7e,0x48,0x4f,0x48,0x48,0x41,0x42,0x4f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0xf0,0x00,0x00,0x00,0x00,
+/* 2970 0xb9a "ச" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0xe0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 2971 0xb9b "஛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2972 0xb9c "ஜ" */
+0x00,0x00,0x00,0x00,0x3e,0x71,0x49,0x49,0x31,0x00,0x3f,0x40,0x40,0x41,0x42,0x3c,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0xe0,0x10,0x10,0x60,
+/* 2973 0xb9d "஝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2974 0xb9e "ஞ" */
+0x00,0x00,0x00,0x00,0x27,0x48,0x90,0x9c,0xa2,0xa2,0xa2,0x9c,0x80,0x40,0x3f,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0xa0,0xd0,0x90,0x90,0x90,0x10,0x20,0xc0,0x00,
+/* 2975 0xb9f "ட" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 2976 0xba0 "஠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 2977 0xba1 "஡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 2978 0xba2 "஢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 2979 0xba3 "ண" */
+0x00,0x00,0x00,0x00,0x3b,0x44,0x8a,0xca,0xaa,0xaa,0x44,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xbf,0x48,0xa8,0xa8,0xa8,0xa8,0x48,0x08,0x00,0x00,0x00,0x00,
+/* 2980 0xba4 "த" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x3f,0x40,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0xe0,0x90,0x90,0x10,0x10,0x20,0xc0,0x00,
+/* 2981 0xba5 "஥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 2982 0xba6 "஦" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 2983 0xba7 "஧" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 2984 0xba8 "ந" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x3f,0x40,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0x80,0xe0,0x90,0x90,0x10,0x20,0xc0,0x00,
+/* 2985 0xba9 "ன" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x42,0x72,0x4a,0x4a,0x31,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x90,0x90,0x90,0x90,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 2986 0xbaa "ப" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,0x00,0x00,
+/* 2987 0xbab "஫" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 2988 0xbac "஬" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 2989 0xbad "஭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 2990 0xbae "ம" */
+0x00,0x00,0x00,0x00,0x21,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 2991 0xbaf "ய" */
+0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x12,0x16,0x1b,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x00,
+/* 2992 0xbb0 "ர" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x01,0x02,
+0x00,0x00,0x00,0x00,0xf0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 2993 0xbb1 "ற" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x0f,0x10,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x10,0x10,0xe0,0x00,
+/* 2994 0xbb2 "ல" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x71,0x49,0x49,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 2995 0xbb3 "ள" */
+0x00,0x00,0x00,0x00,0x1c,0x23,0x41,0x41,0x71,0x49,0x49,0x31,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 2996 0xbb4 "ழ" */
+0x00,0x00,0x00,0x00,0x21,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x02,0x23,0x20,0x1f,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0xc0,0x80,0x00,
+/* 2997 0xbb5 "வ" */
+0x00,0x00,0x00,0x00,0x1c,0x23,0x40,0x40,0x70,0x48,0x49,0x33,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x90,0x90,0x90,0x90,0x10,0xf0,0x00,0x00,0x00,0x00,
+/* 2998 0xbb6 "ஶ" */
+0x00,0x00,0x00,0x00,0x47,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,
+/* 2999 0xbb7 "ஷ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x71,0x49,0x4a,0x33,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x28,0x10,0x28,0x48,0xf0,0x80,0x00,0x00,0x00,
+/* 3000 0xbb8 "ஸ" */
+0x00,0x00,0x00,0x00,0x1d,0x22,0x42,0x42,0x72,0x4a,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x48,0x48,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3001 0xbb9 "ஹ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0xe2,0x92,0x94,0x67,0x00,0x00,0x3f,0x40,
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x04,0x04,0xf8,0x00,
+/* 3002 0xbba "஺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3003 0xbbb "஻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3004 0xbbc "஼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3005 0xbbd "஽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3006 0xbbe "ா" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0x00,
+/* 3007 0xbbf "ி" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x1c,0x22,0x22,0x12,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,0x00,
+/* 3008 0xbc0 "ீ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0xc0,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3009 0xbc1 "ு" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1e,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3010 0xbc2 "ூ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x06,0x09,0x1d,0x0b,0x05,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3011 0xbc3 "௃" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3012 0xbc4 "௄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3013 0xbc5 "௅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3014 0xbc6 "ெ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x84,0xe4,0x94,0x94,0x64,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3015 0xbc7 "ே" */
+0x00,0x00,0x00,0x00,0x30,0x48,0xb0,0x80,0x80,0xb0,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3016 0xbc8 "ை" */
+0x00,0x00,0x00,0x00,0x3d,0x42,0x87,0x85,0xe5,0x95,0x92,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 3017 0xbc9 "௉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3018 0xbca "ொ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x84,0xe4,0x94,0x94,0x64,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0x00,
+/* 3019 0xbcb "ோ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0xb0,0x80,0x80,0xb0,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0x00,
+/* 3020 0xbcc "ௌ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x84,0xe4,0x94,0x94,0x64,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x2a,0x4a,0xca,0xaa,0xaa,0xaa,0x4a,0x00,0x00,0x00,0x00,
+/* 3021 0xbcd "்" */
+0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3022 0xbce "௎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3023 0xbcf "௏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3024 0xbd0 "ௐ" */
+0x00,0x00,0x00,0x0f,0x30,0x40,0x80,0x80,0xe0,0x90,0x94,0x61,0x1a,0x27,0x20,0x1f,
+0x00,0x00,0x00,0xf0,0x0c,0x02,0x01,0x01,0x1d,0x25,0x29,0x26,0xa0,0x9e,0x04,0xf8,
+/* 3025 0xbd1 "௑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3026 0xbd2 "௒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3027 0xbd3 "௓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3028 0xbd4 "௔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3029 0xbd5 "௕" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3030 0xbd6 "௖" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3031 0xbd7 "ௗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x2a,0x4a,0xca,0xaa,0xaa,0xaa,0x4a,0x00,0x00,0x00,0x00,
+/* 3032 0xbd8 "௘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3033 0xbd9 "௙" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3034 0xbda "௚" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3035 0xbdb "௛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3036 0xbdc "௜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3037 0xbdd "௝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3038 0xbde "௞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3039 0xbdf "௟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3040 0xbe0 "௠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3041 0xbe1 "௡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3042 0xbe2 "௢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3043 0xbe3 "௣" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3044 0xbe4 "௤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3045 0xbe5 "௥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3046 0xbe6 "௦" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3047 0xbe7 "௧" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0xe0,0x90,0x90,0x20,0x00,0x00,0x00,0x00,
+/* 3048 0xbe8 "௨" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x22,0x3c,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 3049 0xbe9 "௩" */
+0x00,0x00,0x00,0x00,0x3f,0x22,0x22,0x22,0x23,0x22,0x20,0x23,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0xc0,0x20,0x20,0x40,0xfc,0x00,0x00,0x00,0x00,
+/* 3050 0xbea "௪" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe4,0x84,0x84,0x84,0xfc,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3051 0xbeb "௫" */
+0x00,0x00,0x00,0x00,0x13,0x22,0x42,0x42,0x42,0x42,0x42,0x42,0x40,0x20,0x1f,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x38,0x24,0x24,0x04,0x08,0xf0,0x00,
+/* 3052 0xbec "௬" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0xfe,0xa4,0xa4,0x24,0x00,0x00,0x00,0x00,
+/* 3053 0xbed "௭" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 3054 0xbee "௮" */
+0x00,0x00,0x00,0x0e,0x11,0x10,0x08,0x06,0x3f,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x50,0x50,0xf0,0x50,0x90,0x10,0x00,0x00,0x00,0x00,
+/* 3055 0xbef "௯" */
+0x00,0x00,0x00,0x00,0x0f,0x09,0x09,0x09,0x3f,0x41,0x41,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x1c,0xe2,0x32,0x2a,0x12,0x00,0x00,0x00,0x00,
+/* 3056 0xbf0 "௰" */
+0x00,0x03,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3057 0xbf1 "௱" */
+0x00,0x00,0x00,0x00,0x1b,0x26,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 3058 0xbf2 "௲" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x3f,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x80,0x80,0x80,0xfc,0x90,0x90,0x78,0x54,0x34,0x04,0x78,
+/* 3059 0xbf3 "௳" */
+0x00,0x00,0x00,0x00,0x1c,0x23,0x40,0x40,0x70,0x48,0x49,0x33,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 3060 0xbf4 "௴" */
+0x00,0x00,0x00,0x00,0x21,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,0x00,0x00,
+0x70,0xc8,0xae,0xc0,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3061 0xbf5 "௵" */
+0x00,0x00,0x3f,0x40,0x9c,0xa2,0xa1,0xa1,0xb1,0xa9,0xaa,0x93,0x80,0x40,0x3f,0x00,
+0x00,0x00,0xfc,0x02,0x3a,0x52,0x54,0x55,0x52,0x58,0x54,0xd4,0x04,0x08,0xf0,0x00,
+/* 3062 0xbf6 "௶" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x07,0x08,0x07,
+0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xe4,0x24,0xfc,0x20,0xc0,
+/* 3063 0xbf7 "௷" */
+0x00,0x00,0x00,0x00,0x0f,0x12,0x22,0x32,0x4a,0x4b,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x60,0x90,0xc8,0xa8,0x4e,0x00,0x00,0x00,0x00,
+/* 3064 0xbf8 "௸" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x80,0x83,0xe4,0x94,0x94,0x63,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x85,0xc5,0xa2,0x95,0xa5,0x3e,0x08,0x10,0x00,0x00,
+/* 3065 0xbf9 "௹" */
+0x0e,0x11,0x3c,0x52,0x4c,0x47,0x48,0x48,0x48,0x48,0x48,0x48,0x40,0x20,0x1f,0x00,
+0x00,0x00,0x80,0xf0,0x00,0xe0,0x40,0x40,0x40,0x70,0x48,0x48,0x08,0x10,0xe0,0x00,
+/* 3066 0xbfa "௺" */
+0x00,0x00,0x00,0x01,0x01,0x0f,0x11,0x11,0x11,0x11,0x11,0x11,0x00,0x00,0x1f,0x20,
+0x38,0x44,0xf2,0x4b,0x30,0x80,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x80,0x00,
+/* 3067 0xbfb "௻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3068 0xbfc "௼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3069 0xbfd "௽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3070 0xbfe "௾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3071 0xbff "௿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3072 0xc00 "ఀ" */
+0x00,0x01,0x09,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3073 0xc01 "ఁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+/* 3074 0xc02 "ం" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3075 0xc03 "ః" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x00,0x02,0x05,0x05,0x02,0x00,0x00,0x00,
+/* 3076 0xc04 "ఄ" */
+0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3077 0xc05 "అ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x2c,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x48,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3078 0xc06 "ఆ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x2c,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0xf0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3079 0xc07 "ఇ" */
+0x00,0x00,0x00,0x00,0x3b,0x44,0x44,0x00,0x1e,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x00,0x00,
+/* 3080 0xc08 "ఈ" */
+0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x3c,0x42,0x7f,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x20,0xe0,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3081 0xc09 "ఉ" */
+0x00,0x00,0x01,0x01,0x0f,0x10,0x20,0x7f,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x00,0xf8,0x00,0x60,0x90,0xe0,0x00,0x00,0x00,0x00,
+/* 3082 0xc0a "ఊ" */
+0x00,0x00,0x05,0x05,0x1f,0x20,0x40,0xff,0x80,0x80,0x45,0x3b,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x44,0x08,0xf8,0x14,0x88,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3083 0xc0b "ఋ" */
+0x00,0x00,0x00,0x00,0x64,0x92,0x12,0x22,0x42,0x82,0x92,0x6d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x48,0x48,0x48,0x48,0x48,0x48,0xb0,0x00,0x00,0x00,0x00,
+/* 3084 0xc0c "ఌ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3085 0xc0d "఍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3086 0xc0e "ఎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3087 0xc0f "ఏ" */
+0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x00,0x00,0x0e,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3088 0xc10 "ఐ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x00,0x00,0x0e,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3089 0xc11 "఑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3090 0xc12 "ఒ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x04,0x08,0x10,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3091 0xc13 "ఓ" */
+0x00,0x06,0x09,0x04,0x0c,0x12,0x12,0x04,0x08,0x10,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3092 0xc14 "ఔ" */
+0x00,0x3f,0x01,0x3e,0x0c,0x12,0x12,0x04,0x08,0x10,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3093 0xc15 "క" */
+0x00,0x00,0x02,0x01,0x01,0x02,0x02,0x01,0x00,0x00,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x80,0x40,0x00,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3094 0xc16 "ఖ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x34,0x04,0x04,0x34,0x4c,0x37,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3095 0xc17 "గ" */
+0x00,0x00,0x00,0x00,0x08,0x05,0x02,0x05,0x05,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 3096 0xc18 "ఘ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x49,0x30,0x00,0x30,0x4c,0x37,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x48,0x48,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3097 0xc19 "ఙ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x13,0x04,0x08,0x10,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xf0,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3098 0xc1a "చ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x78,0x09,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x20,0xc0,0xa0,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3099 0xc1b "ఛ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x78,0x09,0x13,0x0d,0x01,0x00,0x00,0x00,
+0x00,0x00,0x10,0x20,0xc0,0xa0,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3100 0xc1c "జ" */
+0x00,0x00,0x00,0x00,0x0c,0x13,0x12,0x04,0x08,0x10,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0xc0,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3101 0xc1d "ఝ" */
+0x00,0x00,0x21,0x12,0x0c,0x12,0x12,0x12,0x12,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x90,0x48,0x48,0x48,0x48,0x48,0xe8,0x50,0x40,0x00,0x00,0x00,
+/* 3102 0xc1e "ఞ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x00,0x00,0x1d,0x22,0x1d,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xa0,0xf0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3103 0xc1f "ట" */
+0x00,0x00,0x10,0x10,0x18,0x24,0x58,0x40,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3104 0xc20 "ఠ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x07,0x08,0x10,0x12,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3105 0xc21 "డ" */
+0x00,0x00,0x08,0x04,0x0f,0x12,0x21,0x40,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x80,0x00,0x60,0x90,0xe0,0x00,0x00,0x00,0x00,
+/* 3106 0xc22 "ఢ" */
+0x00,0x00,0x08,0x04,0x0f,0x12,0x21,0x40,0x40,0x40,0x22,0x1f,0x02,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x80,0x00,0x60,0x90,0xe0,0x00,0x00,0x00,0x00,
+/* 3107 0xc23 "ణ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x20,0x18,0x20,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x08,0x08,0x08,0x38,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3108 0xc24 "త" */
+0x00,0x01,0x00,0x00,0x0c,0x12,0x2c,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x08,0x10,0xa0,0x40,0x60,0x90,0x68,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3109 0xc25 "థ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x07,0x08,0x12,0x10,0x12,0x0f,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3110 0xc26 "ద" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x07,0x08,0x10,0x10,0x12,0x0d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3111 0xc27 "ధ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x07,0x08,0x10,0x10,0x12,0x0f,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3112 0xc28 "న" */
+0x00,0x01,0x1a,0x1c,0x03,0x00,0x00,0x00,0x18,0x24,0x22,0x11,0x00,0x00,0x00,0x00,
+0x80,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3113 0xc29 "఩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3114 0xc2a "ప" */
+0x00,0x00,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x0e,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3115 0xc2b "ఫ" */
+0x00,0x00,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x0e,0x13,0x0d,0x01,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3116 0xc2c "బ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x10,0x20,0x21,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3117 0xc2d "భ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x10,0x20,0x21,0x12,0x0c,0x01,0x00,0x00,0x00,
+0x00,0x04,0x08,0xd0,0xe0,0x20,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3118 0xc2e "మ" */
+0x00,0x00,0x01,0x06,0x07,0x00,0x00,0x00,0x00,0x38,0x4c,0x33,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0x30,0x88,0x48,0x48,0x48,0x48,0xc8,0x30,0x00,0x00,0x00,0x00,
+/* 3119 0xc2f "య" */
+0x00,0x00,0x0d,0x02,0x01,0x00,0x30,0x48,0x48,0x48,0x4c,0x33,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0x30,0x88,0x48,0x48,0x48,0x48,0xc8,0x30,0x00,0x00,0x00,0x00,
+/* 3120 0xc30 "ర" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x07,0x08,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3121 0xc31 "ఱ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x2f,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x88,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3122 0xc32 "ల" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x64,0x58,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3123 0xc33 "ళ" */
+0x00,0x00,0x01,0x01,0x00,0x18,0x24,0x2c,0x10,0x0f,0x09,0x06,0x00,0x00,0x00,0x00,
+0x08,0x10,0xa0,0xc0,0x40,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3124 0xc34 "ఴ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x65,0x58,0x40,0x42,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x30,0xd0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3125 0xc35 "వ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x0e,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x40,0xe0,0x90,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3126 0xc36 "శ" */
+0x00,0x00,0x00,0x01,0x07,0x06,0x00,0x0e,0x11,0x13,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x40,0x80,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3127 0xc37 "ష" */
+0x00,0x00,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x0e,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x10,0x08,0x04,0x00,
+/* 3128 0xc38 "స" */
+0x00,0x00,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x0e,0x13,0x10,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3129 0xc39 "హ" */
+0x04,0x08,0x50,0x20,0x07,0x02,0x01,0x00,0x00,0x38,0x4c,0x33,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x28,0x10,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3130 0xc3a "఺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3131 0xc3b "఻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3132 0xc3c "఼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,
+/* 3133 0xc3d "ఽ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3134 0xc3e "ా" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3135 0xc3f "ి" */
+0x01,0x02,0x01,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3136 0xc40 "ీ" */
+0x04,0x09,0x06,0x01,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3137 0xc41 "ు" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x01,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3138 0xc42 "ూ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x25,0x12,0x08,0x04,0x02,0x12,0x0c,0x00,0x00,0x00,0x00,
+/* 3139 0xc43 "ృ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x01,0x01,0x05,0x0b,0x06,0x00,0x00,0x00,0x00,
+/* 3140 0xc44 "ౄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1f,0x11,0x08,0x04,0x02,0x0a,0x16,0x0c,0x00,0x00,0x00,0x00,
+/* 3141 0xc45 "౅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3142 0xc46 "ె" */
+0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3143 0xc47 "ే" */
+0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x60,0x80,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3144 0xc48 "ై" */
+0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0f,
+0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,
+/* 3145 0xc49 "౉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3146 0xc4a "ొ" */
+0x00,0x37,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3147 0xc4b "ో" */
+0x00,0x00,0x37,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0xe0,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3148 0xc4c "ౌ" */
+0x00,0x3f,0x04,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3149 0xc4d "్" */
+0x0f,0x10,0x0c,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3150 0xc4e "౎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3151 0xc4f "౏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3152 0xc50 "౐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3153 0xc51 "౑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3154 0xc52 "౒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3155 0xc53 "౓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3156 0xc54 "౔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3157 0xc55 "ౕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x60,0x90,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3158 0xc56 "ౖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,
+/* 3159 0xc57 "౗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3160 0xc58 "ౘ" */
+0x01,0x02,0x7f,0x00,0x01,0x01,0x00,0x00,0x78,0x09,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x80,0x90,0x20,0xc0,0xa0,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3161 0xc59 "ౙ" */
+0x00,0x00,0x1f,0x00,0x0c,0x13,0x12,0x04,0x08,0x10,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x40,0xa0,0xe0,0x00,0x40,0x20,0xc0,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3162 0xc5a "ౚ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x1f,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xf0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3163 0xc5b "౛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3164 0xc5c "౜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3165 0xc5d "ౝ" */
+0x00,0x00,0x00,0x1f,0x20,0x20,0x1f,0x20,0x20,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x00,
+/* 3166 0xc5e "౞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3167 0xc5f "౟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3168 0xc60 "ౠ" */
+0x00,0x00,0x00,0x00,0x49,0xa4,0x24,0x24,0x44,0x84,0xa4,0x5b,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0x95,0x92,0x90,0x90,0x90,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3169 0xc61 "ౡ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0xa5,0xa2,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3170 0xc62 "ౢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x28,0x28,0x10,
+/* 3171 0xc63 "ౣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xb4,0xa8,0x40,
+/* 3172 0xc64 "౤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3173 0xc65 "౥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3174 0xc66 "౦" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3175 0xc67 "౧" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0x40,0x00,0x00,0x00,0x00,
+/* 3176 0xc68 "౨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x48,0x88,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3177 0xc69 "౩" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x00,0x00,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3178 0xc6a "౪" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3179 0xc6b "౫" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0xc8,0x30,0x30,0x48,0x88,0x10,0x00,0x00,0x00,0x00,
+/* 3180 0xc6c "౬" */
+0x00,0x00,0x00,0x00,0x38,0x40,0x40,0x3f,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3181 0xc6d "౭" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x88,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3182 0xc6e "౮" */
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x40,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3183 0xc6f "౯" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x3f,0x40,0x40,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3184 0xc70 "౰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3185 0xc71 "౱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3186 0xc72 "౲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3187 0xc73 "౳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3188 0xc74 "౴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3189 0xc75 "౵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3190 0xc76 "౶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3191 0xc77 "౷" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x24,0x25,0x14,0x12,0x09,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0xc8,0x28,0x28,0x48,0x90,0x20,0xc0,0x00,0x00,0x00,
+/* 3192 0xc78 "౸" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0xc0,0x20,0x10,0x60,0x80,0x00,0x00,
+/* 3193 0xc79 "౹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 3194 0xc7a "౺" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 3195 0xc7b "౻" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 3196 0xc7c "౼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3197 0xc7d "౽" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x01,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3198 0xc7e "౾" */
+0x00,0x00,0x00,0x07,0x00,0x03,0x04,0x03,0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3199 0xc7f "౿" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x16,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3200 0xc80 "ಀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3201 0xc81 "ಁ" */
+0x09,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3202 0xc82 "ಂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3203 0xc83 "ಃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x00,0x02,0x05,0x05,0x02,0x00,0x00,0x00,
+/* 3204 0xc84 "಄" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x49,0x48,0x24,0x23,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0xc8,0x24,0x24,0x44,0x88,0x10,0xe0,0x00,0x00,
+/* 3205 0xc85 "ಅ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x2c,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x48,0xe8,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3206 0xc86 "ಆ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x2c,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x28,0xf0,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3207 0xc87 "ಇ" */
+0x00,0x00,0x00,0x00,0x3b,0x44,0x44,0x00,0x1e,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x00,0x00,
+/* 3208 0xc88 "ಈ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x3c,0x42,0x7f,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x60,0xe0,0x20,0x40,0x00,0x00,0x00,0x00,
+/* 3209 0xc89 "ಉ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0xa9,0xc9,0x89,0x89,0x49,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3210 0xc8a "ಊ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0xa9,0xc9,0x89,0x89,0x49,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x26,0x2a,0x2a,0xc4,0x00,0x00,0x00,0x00,
+/* 3211 0xc8b "ಋ" */
+0x00,0x00,0x00,0x00,0x67,0x90,0x68,0x08,0x08,0x68,0x94,0x63,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x90,0x88,0x44,0x44,0x44,0x44,0xa4,0x18,0x00,0x00,0x00,0x00,
+/* 3212 0xc8c "ಌ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3213 0xc8d "಍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3214 0xc8e "ಎ" */
+0x00,0x00,0x00,0x00,0x3e,0x01,0x00,0x00,0x20,0x51,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3215 0xc8f "ಏ" */
+0x00,0x00,0x00,0x20,0x10,0x09,0x06,0x00,0x20,0x51,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3216 0xc90 "ಐ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x00,0x20,0x51,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x08,0x08,0x08,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3217 0xc91 "಑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3218 0xc92 "ಒ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x10,0x20,0x41,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3219 0xc93 "ಓ" */
+0x00,0x00,0x18,0x20,0x30,0x48,0x48,0x10,0x20,0x41,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3220 0xc94 "ಔ" */
+0x7f,0x02,0x02,0x7c,0x31,0x48,0x48,0x10,0x20,0x41,0x42,0x3c,0x00,0x00,0x00,0x00,
+0xe0,0x10,0x10,0x90,0x20,0xc0,0x00,0x20,0x10,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3221 0xc95 "ಕ" */
+0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x1f,0x08,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0xc0,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3222 0xc96 "ಖ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x01,0x0f,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x88,0x84,0x04,0x04,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 3223 0xc97 "ಗ" */
+0x00,0x00,0x00,0x00,0x3f,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x10,0xe0,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 3224 0xc98 "ಘ" */
+0x00,0x00,0x07,0x00,0xff,0x00,0x02,0x60,0x90,0x62,0x27,0x1a,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x20,0x10,0x08,0x28,0x30,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3225 0xc99 "ಙ" */
+0x00,0x00,0x00,0x00,0x33,0x4c,0x48,0x11,0x20,0x41,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x30,0x00,0x10,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3226 0xc9a "ಚ" */
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x20,0x40,0x84,0x8a,0x71,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0x08,0xf0,0x80,0x40,0xe0,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3227 0xc9b "ಛ" */
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0xe0,0x80,0x84,0x8e,0x75,0x04,0x00,0x00,0x00,
+0x00,0x00,0x30,0x08,0xf0,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3228 0xc9c "ಜ" */
+0x00,0x00,0x00,0x00,0x31,0x48,0x4f,0x10,0x20,0x42,0x45,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3229 0xc9d "ಝ" */
+0x00,0x0e,0x01,0x3e,0x1c,0x22,0x22,0x22,0x22,0x22,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x48,0x48,0x48,0x48,0x48,0xe8,0x50,0x40,0x00,0x00,0x00,
+/* 3230 0xc9e "ಞ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x00,0x00,0x1d,0x22,0x1d,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3231 0xc9f "ಟ" */
+0x00,0x00,0x00,0x00,0x10,0x18,0x24,0x58,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xc0,0x20,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3232 0xca0 "ಠ" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x07,0x08,0x10,0x12,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3233 0xca1 "ಡ" */
+0x00,0x00,0x00,0x03,0x00,0x7f,0x21,0x40,0x40,0x42,0x25,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0xc0,0x20,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3234 0xca2 "ಢ" */
+0x00,0x00,0x00,0x03,0x00,0x7f,0x21,0x40,0x40,0x42,0x27,0x1a,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0xc0,0x20,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3235 0xca3 "ಣ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x40,0x20,0x41,0x41,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x88,0x48,0x50,0xe0,0x00,0x00,0x00,0x00,
+/* 3236 0xca4 "ತ" */
+0x00,0x00,0x01,0x00,0x0f,0x00,0x00,0x10,0x11,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0xc0,0x20,0x10,0xd0,0x20,0xd0,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3237 0xca5 "ಥ" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x07,0x08,0x12,0x10,0x12,0x0f,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3238 0xca6 "ದ" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x07,0x08,0x10,0x10,0x12,0x0d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3239 0xca7 "ಧ" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x07,0x08,0x10,0x10,0x12,0x0f,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3240 0xca8 "ನ" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x18,0x24,0x22,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0xe0,0x40,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3241 0xca9 "಩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3242 0xcaa "ಪ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x20,0x51,0x50,0x61,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0xe0,0x00,0x20,0x10,0x08,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3243 0xcab "ಫ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x20,0x51,0x50,0x61,0x42,0x3d,0x01,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0xe0,0x00,0x20,0x10,0x08,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3244 0xcac "ಬ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x10,0x20,0x21,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3245 0xcad "ಭ" */
+0x00,0x00,0x00,0x00,0x31,0x48,0x08,0x10,0x20,0x21,0x12,0x0d,0x01,0x00,0x00,0x00,
+0x00,0x00,0x70,0x08,0xf0,0x40,0x20,0x10,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3246 0xcae "ಮ" */
+0x00,0x00,0x03,0x00,0x3f,0x00,0x40,0xa0,0xa0,0xc4,0x8a,0x71,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x80,0x00,0x90,0x48,0x48,0x48,0x48,0xb0,0x00,0x00,0x00,0x00,
+/* 3247 0xcaf "ಯ" */
+0x00,0x00,0x00,0x00,0x00,0x33,0x48,0x84,0x84,0x84,0x8a,0x71,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0xc0,0x90,0x48,0x48,0x48,0x48,0xb0,0x00,0x00,0x00,0x00,
+/* 3248 0xcb0 "ರ" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x07,0x08,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3249 0xcb1 "ಱ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x3f,0x20,0x21,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x98,0xf8,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3250 0xcb2 "ಲ" */
+0x00,0x00,0x00,0x00,0x01,0x30,0x48,0x70,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3251 0xcb3 "ಳ" */
+0x00,0x00,0x00,0x00,0x01,0x30,0x48,0x70,0x40,0x40,0x20,0x1f,0x09,0x06,0x00,0x00,
+0x00,0x00,0x60,0x10,0xe0,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3252 0xcb4 "಴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3253 0xcb5 "ವ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x20,0x50,0x50,0x61,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0x08,0xf0,0x20,0x10,0x08,0x08,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 3254 0xcb6 "ಶ" */
+0x00,0x00,0x01,0x00,0x7f,0x30,0x48,0x44,0x24,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0xc0,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3255 0xcb7 "ಷ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x20,0x51,0x50,0x61,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0xc0,0x00,0x20,0x10,0x08,0x28,0x98,0x74,0x00,0x00,0x00,0x00,
+/* 3256 0xcb8 "ಸ" */
+0x00,0x00,0x01,0x00,0x0f,0x00,0x04,0x00,0x0e,0x11,0x20,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x80,0x00,0x20,0x10,0x10,0x10,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3257 0xcb9 "ಹ" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x02,0x05,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0xe0,0x80,0xa0,0xd0,0x88,0x88,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3258 0xcba "಺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3259 0xcbb "಻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3260 0xcbc "಼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,
+/* 3261 0xcbd "ಽ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x04,0x03,0x00,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3262 0xcbe "ಾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1c,0x02,0x01,0x01,0x05,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,
+/* 3263 0xcbf "ಿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x1c,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3264 0xcc0 "ೀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x1c,0x08,0x32,0x05,0x05,0x06,0x04,0x04,0x04,0x04,0x02,0x00,0x00,0x00,
+/* 3265 0xcc1 "ು" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x01,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3266 0xcc2 "ೂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x0b,0x0b,0x0b,0x08,0x08,0x30,0x00,0x00,
+/* 3267 0xcc3 "ೃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x0d,0x0d,0x06,
+/* 3268 0xcc4 "ೄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x7e,0x21,0x15,0x16,0x10,0x0c,0x02,0x01,0x0d,0x0d,0x06,
+/* 3269 0xcc5 "೅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3270 0xcc6 "ೆ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3271 0xcc7 "ೇ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x04,0xf8,0x02,0x05,0x05,0x06,0x04,0x04,0x04,0x04,0x02,0x00,0x00,0x00,
+/* 3272 0xcc8 "ೈ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x04,0xf8,0x00,0x00,0x00,0x00,0x04,0x02,0x04,0x02,0x01,0x0d,0x0d,0x06,
+/* 3273 0xcc9 "೉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3274 0xcca "ೊ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x04,0xf8,0x00,0x06,0x09,0x09,0x0b,0x0b,0x0b,0x08,0x08,0x30,0x00,0x00,
+/* 3275 0xccb "ೋ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x63,0x93,0x12,0xe2,0x01,0x07,0x09,0x09,0x0b,0x0b,0x0b,0x08,0x08,0x30,0x00,0x00,
+/* 3276 0xccc "ೌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xfc,0x12,0xe2,0x01,0x01,0x01,0x01,0x05,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,
+/* 3277 0xccd "್" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x03,0x04,0xfe,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3278 0xcce "೎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3279 0xccf "೏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3280 0xcd0 "೐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3281 0xcd1 "೑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3282 0xcd2 "೒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3283 0xcd3 "೓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3284 0xcd4 "೔" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3285 0xcd5 "ೕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x06,0x04,0x04,0x04,0x04,0x02,0x00,0x00,0x00,
+/* 3286 0xcd6 "ೖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x04,0x02,0x01,0x0d,0x0d,0x06,
+/* 3287 0xcd7 "೗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3288 0xcd8 "೘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3289 0xcd9 "೙" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3290 0xcda "೚" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3291 0xcdb "೛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3292 0xcdc "೜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3293 0xcdd "ೝ" */
+0x00,0x00,0x00,0x1f,0x20,0x20,0x1f,0x20,0x20,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x00,
+/* 3294 0xcde "ೞ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x32,0x2c,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x98,0x68,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3295 0xcdf "೟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3296 0xce0 "ೠ" */
+0x00,0x00,0x00,0x00,0x0f,0x62,0x91,0x71,0x11,0x71,0x99,0x66,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x80,0x0e,0x11,0x11,0x13,0x15,0x95,0x62,0x00,0x00,0x00,0x00,
+/* 3297 0xce1 "ೡ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x40,0x88,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3298 0xce2 "ೢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x18,
+/* 3299 0xce3 "ೣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x12,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x4c,0x50,0x3c,
+/* 3300 0xce4 "೤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3301 0xce5 "೥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3302 0xce6 "೦" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3303 0xce7 "೧" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0x40,0x00,0x00,0x00,0x00,
+/* 3304 0xce8 "೨" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x30,0xd0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3305 0xce9 "೩" */
+0x00,0x00,0x00,0x00,0x0f,0x12,0x12,0x0c,0x0e,0x11,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x48,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3306 0xcea "೪" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x0e,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3307 0xceb "೫" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x23,0x10,0x07,0x19,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0xf8,0xe0,0x10,0x10,0x60,0x00,0x00,0x00,0x00,
+/* 3308 0xcec "೬" */
+0x00,0x00,0x00,0x10,0x08,0x3e,0x49,0x49,0x46,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3309 0xced "೭" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 3310 0xcee "೮" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x11,0x1e,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3311 0xcef "೯" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x0f,0x10,0x10,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3312 0xcf0 "೰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3313 0xcf1 "ೱ" */
+0xaa,0x00,0x80,0x1f,0x88,0x04,0x82,0x01,0x82,0x04,0x88,0x1f,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0xf1,0x20,0x41,0x80,0x01,0x80,0x41,0x20,0xf1,0x00,0x01,0x00,0x55,
+/* 3314 0xcf2 "ೲ" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0x9c,0x22,0xa2,0x22,0x9c,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x70,0x89,0x88,0x89,0x70,0x01,0x00,0x01,0x00,0x55,
+/* 3315 0xcf3 "ೳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3316 0xcf4 "೴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3317 0xcf5 "೵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3318 0xcf6 "೶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3319 0xcf7 "೷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3320 0xcf8 "೸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3321 0xcf9 "೹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3322 0xcfa "೺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3323 0xcfb "೻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3324 0xcfc "೼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3325 0xcfd "೽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3326 0xcfe "೾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3327 0xcff "೿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3328 0xd00 "ഀ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3329 0xd01 "ഁ" */
+0x00,0x01,0x09,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3330 0xd02 "ം" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3331 0xd03 "ഃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x00,0x02,0x05,0x05,0x02,0x00,0x00,0x00,
+/* 3332 0xd04 "ഄ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x11,0x11,0x11,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3333 0xd05 "അ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x7c,0xa2,0xbc,0xa2,0xa2,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x84,0x9c,0xa4,0xa4,0x98,0x00,0x00,0x00,0x00,
+/* 3334 0xd06 "ആ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x7c,0xa2,0xbc,0xa2,0xa2,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x32,0x4d,0x8d,0x95,0xa5,0xa5,0xa5,0x99,0x01,0x3e,0x00,0x00,
+/* 3335 0xd07 "ഇ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x42,0x72,0x4a,0x4a,0x32,0x00,0x3f,0x40,0x3f,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0xe0,
+/* 3336 0xd08 "ഈ" */
+0x00,0x00,0x00,0x00,0x74,0x8a,0x8a,0x8a,0xca,0xaa,0xaa,0x42,0x02,0x7c,0x80,0x7c,
+0x00,0x00,0x00,0x00,0x50,0xa8,0xa8,0xa8,0x08,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 3337 0xd09 "ഉ" */
+0x00,0x00,0x00,0x00,0x0f,0x12,0x12,0x0c,0x00,0x0f,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 3338 0xd0a "ഊ" */
+0x00,0x00,0x00,0x00,0x1c,0x2a,0x2a,0x12,0x02,0x1c,0x20,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0xa8,0xa8,0xa8,0x08,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 3339 0xd0b "ഋ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x1c,0x10,0x08,0x07,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x70,0x10,0x20,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3340 0xd0c "ഌ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x39,0x25,0x25,0x19,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x28,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3341 0xd0d "഍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3342 0xd0e "എ" */
+0x00,0x00,0x00,0x01,0x71,0x89,0x89,0x5f,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x08,0x28,0x28,0x28,0xe8,0x28,0x28,0x28,0xc0,0x00,0x00,0x00,0x00,
+/* 3343 0xd0f "ഏ" */
+0x00,0x00,0x01,0x02,0x72,0x8a,0x8a,0x5f,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0x88,0x88,0x88,0x90,0x88,0x88,0x88,0x30,0x00,0x00,0x00,0x00,
+/* 3344 0xd10 "ഐ" */
+0x00,0x00,0x00,0x00,0x73,0xac,0xac,0x4a,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0e,0x11,0x95,0x55,0x55,0xfd,0x15,0x15,0x15,0x08,0x00,0x00,0x00,0x00,
+/* 3345 0xd11 "഑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3346 0xd12 "ഒ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x3c,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x20,0x10,0x60,0x00,0x00,0x00,0x00,
+/* 3347 0xd13 "ഓ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x21,0x20,0x20,0x31,0x28,0x13,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x84,0x84,0x04,0xa4,0x18,0x00,0x00,0x00,0x00,
+/* 3348 0xd14 "ഔ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x41,0x41,0x62,0x51,0x26,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x54,0x04,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 3349 0xd15 "ക" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x1f,0x24,0x24,0x24,0x1b,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0xf0,0x48,0x48,0x48,0x90,0x00,0x00,0x00,0x00,
+/* 3350 0xd16 "ഖ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x40,0x40,0x70,0x48,0x48,0x31,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x84,0x44,0x44,0x44,0x84,0xfc,0x00,0x00,0x00,0x00,
+/* 3351 0xd17 "ഗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x08,0x70,0x00,0x00,0x00,0x00,
+/* 3352 0xd18 "ഘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x2f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x72,0x8a,0x8a,0x8a,0x8a,0xfa,0x82,0xfe,0x00,0x00,0x00,0x00,
+/* 3353 0xd19 "ങ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x42,0x72,0x4a,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x70,0x08,0x08,0x70,0x00,0x00,0x00,0x00,
+/* 3354 0xd1a "ച" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x02,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3355 0xd1b "ഛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x02,0x04,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x84,0x8c,0x94,0x54,0xc8,0x00,0x00,0x00,0x00,
+/* 3356 0xd1c "ജ" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x71,0x49,0x30,0x3f,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x20,0xf0,0xc8,0x30,0x00,0x00,0x00,0x00,
+/* 3357 0xd1d "ഝ" */
+0x00,0x00,0x00,0x00,0x3c,0x5e,0xa5,0xa5,0x99,0x81,0x41,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x24,0x22,0x22,0x22,0x22,0x22,0x24,0xd8,0x00,0x00,0x00,0x00,
+/* 3358 0xd1e "ഞ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x42,0x72,0x4a,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x38,0x54,0x94,0x94,0x94,0x94,0x60,0x00,0x00,0x00,0x00,
+/* 3359 0xd1f "ട" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3360 0xd20 "ഠ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3361 0xd21 "ഡ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x22,0x22,0x22,0x12,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x44,0x44,0x44,0x44,0x44,0x48,0xb0,0x00,0x00,0x00,
+/* 3362 0xd22 "ഢ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x24,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa8,0xa8,0xa8,0x98,0x90,0x60,0x00,0x00,0x00,
+/* 3363 0xd23 "ണ" */
+0x00,0x00,0x00,0x00,0x19,0x26,0x42,0x42,0x42,0x72,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x48,0x48,0x48,0x48,0x50,0x00,0x00,0x00,0x00,
+/* 3364 0xd24 "ത" */
+0x00,0x00,0x00,0x00,0x0c,0x13,0x22,0x24,0x24,0x24,0x22,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x84,0x44,0x24,0x24,0x44,0x88,0x00,0x00,0x00,0x00,
+/* 3365 0xd25 "ഥ" */
+0x00,0x00,0x00,0x00,0x40,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3366 0xd26 "ദ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x11,0x10,0x10,0x12,0x09,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3367 0xd27 "ധ" */
+0x00,0x00,0x00,0x00,0x09,0x11,0x21,0x21,0x21,0x21,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3368 0xd28 "ന" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x21,0x21,0x21,0x21,0x11,0x09,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 3369 0xd29 "ഩ" */
+0x00,0x00,0x00,0x00,0x0c,0x13,0x21,0x39,0x25,0x25,0x25,0x19,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 3370 0xd2a "പ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x2f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3371 0xd2b "ഫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x2f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0xf8,0x00,0x00,0x00,0x00,
+/* 3372 0xd2c "ബ" */
+0x00,0x00,0x00,0x00,0x19,0x26,0x42,0x42,0x42,0x72,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x48,0x48,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0x00,
+/* 3373 0xd2d "ഭ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x11,0x12,0x11,0x10,0x0b,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3374 0xd2e "മ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x10,0x10,0x11,0x12,0x1c,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x88,0x88,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3375 0xd2f "യ" */
+0x00,0x00,0x00,0x00,0x11,0x2a,0x24,0x24,0x24,0x22,0x13,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x44,0x24,0x24,0x44,0x84,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 3376 0xd30 "ര" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x21,0x21,0x21,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xa0,0x10,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3377 0xd31 "റ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 3378 0xd32 "ല" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x3f,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3379 0xd33 "ള" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x38,0x24,0x18,0x00,0x0f,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x20,0x20,0x20,0xc0,0x00,0xf0,0x00,0x00,
+/* 3380 0xd34 "ഴ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x09,0x07,0x01,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3381 0xd35 "വ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x40,0x40,0x40,0x40,0x41,0x23,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x88,0x88,0x88,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3382 0xd36 "ശ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x21,0x21,0x21,0x21,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x1c,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 3383 0xd37 "ഷ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x38,0x44,0x44,0x2f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0xa8,0xc8,0x88,0x88,0x88,0x88,0xf8,0x00,0x00,0x00,0x00,
+/* 3384 0xd38 "സ" */
+0x00,0x00,0x00,0x00,0x36,0x49,0x88,0x88,0x88,0x88,0x88,0x48,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0x88,0x88,0x88,0x88,0x90,0xe0,0x00,0x00,0x00,0x00,
+/* 3385 0xd39 "ഹ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x72,0x8a,0x89,0x5f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 3386 0xd3a "ഺ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3387 0xd3b "഻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3388 0xd3c "഼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3389 0xd3d "ഽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x00,0x00,
+0x00,0x10,0x28,0x28,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 3390 0xd3e "ാ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x01,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3391 0xd3f "ി" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x06,0x09,0x09,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+/* 3392 0xd40 "ീ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x06,0x09,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+/* 3393 0xd41 "ു" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x02,0x04,0x04,0x0a,0x04,0x00,0x00,0x00,
+/* 3394 0xd42 "ൂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x02,0x04,0x04,0x0a,0x15,0x11,0x0e,0x00,
+/* 3395 0xd43 "ൃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x01,0x01,0x1f,0x21,0x1e,
+/* 3396 0xd44 "ൄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x01,0x01,0xdd,0x25,0xfe,
+/* 3397 0xd45 "൅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3398 0xd46 "െ" */
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0xc8,0xa8,0xa8,0x48,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3399 0xd47 "േ" */
+0x00,0x00,0x00,0x00,0x60,0x90,0xe0,0x80,0x80,0xe0,0x90,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3400 0xd48 "ൈ" */
+0x00,0x00,0x00,0x00,0xd8,0xb4,0xb4,0xb4,0x90,0x90,0xd8,0xd8,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3401 0xd49 "൉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3402 0xd4a "ൊ" */
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0xc8,0xa8,0xa8,0x48,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x01,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3403 0xd4b "ോ" */
+0x00,0x00,0x00,0x00,0x60,0x90,0xe0,0x80,0x80,0xe0,0x90,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x01,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3404 0xd4c "ൌ" */
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0xc8,0xa8,0xa8,0x48,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0a,0x15,0x15,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3405 0xd4d "്" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x12,0x21,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3406 0xd4e "ൎ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3407 0xd4f "൏" */
+0x00,0x00,0x00,0x00,0x26,0x49,0x50,0x5c,0x52,0x52,0x52,0x4c,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x88,0x88,0x88,0x88,0x88,0x88,0x10,0xe0,0x00,0x00,
+/* 3408 0xd50 "൐" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3409 0xd51 "൑" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3410 0xd52 "൒" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3411 0xd53 "൓" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3412 0xd54 "ൔ" */
+0x00,0x00,0x00,0x10,0x16,0x09,0x14,0x12,0x11,0x12,0x1c,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0xc0,0x30,0xf8,0x00,0x00,0x00,0x00,
+/* 3413 0xd55 "ൕ" */
+0x00,0x00,0x00,0x11,0x2a,0x24,0x24,0x24,0x22,0x13,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x28,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 3414 0xd56 "ൖ" */
+0x00,0x00,0x18,0x24,0x04,0x45,0x49,0x39,0x0f,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3415 0xd57 "ൗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0a,0x15,0x15,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3416 0xd58 "൘" */
+0x00,0x00,0x00,0x00,0x0a,0x12,0x22,0x22,0x22,0x22,0x12,0x0d,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0x48,0x48,0x48,0x48,0x48,0x48,0x50,0xa0,0x00,0x00,0x00,0x00,
+/* 3417 0xd59 "൙" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x47,0x49,0x49,0x26,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3418 0xd5a "൚" */
+0x00,0x00,0x00,0x00,0x0d,0x12,0x22,0x22,0x22,0x22,0x12,0x0a,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x48,0x28,0x28,0x28,0x28,0x48,0xf8,0x00,0x00,0x00,0x00,
+/* 3419 0xd5b "൛" */
+0x00,0x00,0x00,0x00,0x7f,0x42,0x44,0x44,0x44,0x44,0x42,0x41,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3420 0xd5c "൜" */
+0x00,0x00,0x00,0x00,0x11,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x24,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x20,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 3421 0xd5d "൝" */
+0x00,0x00,0x00,0x00,0x04,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x51,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x48,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x10,0x00,0x00,0x00,0x00,
+/* 3422 0xd5e "൞" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x4f,0x52,0x52,0x4c,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xa8,0xa8,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3423 0xd5f "ൟ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x4a,0xaa,0xaa,0x49,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x24,0x2a,0x2a,0x24,0xc0,0x00,0x00,0x00,0x00,
+/* 3424 0xd60 "ൠ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x58,0x40,0x20,0x1f,0x20,0x24,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x68,0x08,0x10,0xe0,0x10,0x90,0x10,0xe0,0x00,0x00,
+/* 3425 0xd61 "ൡ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x42,0x72,0x4a,0x4a,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x38,0x54,0x94,0x94,0x94,0x94,0x64,0x04,0x48,0x30,0x00,
+/* 3426 0xd62 "ൢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x39,0x25,0x19,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x38,0x48,0x30,
+/* 3427 0xd63 "ൣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x39,0x25,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x38,0x48,0x38,0xf0,
+/* 3428 0xd64 "൤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3429 0xd65 "൥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3430 0xd66 "൦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 3431 0xd67 "൧" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x1f,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,
+/* 3432 0xd68 "൨" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x40,0x40,0x40,0x40,0x41,0x23,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 3433 0xd69 "൩" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x44,0x44,0x44,0x44,0x44,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,
+/* 3434 0xd6a "൪" */
+0x00,0x00,0x00,0x00,0x06,0x01,0x01,0x07,0x09,0x11,0x11,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3435 0xd6b "൫" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x12,0x12,0x12,0x12,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x88,0x48,0x88,0x48,0x48,0x50,0x80,0x00,0x00,0x00,
+/* 3436 0xd6c "൬" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x44,0x44,0x44,0x44,0x44,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0xa4,0x42,0x42,0x42,0x42,0x42,0x42,0x04,0x08,0x10,0x00,
+/* 3437 0xd6d "൭" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x1e,0x11,0x0e,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,
+/* 3438 0xd6e "൮" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x40,0x40,0x40,0x40,0x41,0x23,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x88,0x88,0x88,0x08,0xf8,0x08,0x08,0x70,0x00,
+/* 3439 0xd6f "൯" */
+0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x1b,0x24,0x44,0x44,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3440 0xd70 "൰" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x03,0x02,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x44,0x44,0x44,0x44,0x44,0x48,0xb0,0x00,0x00,0x00,
+/* 3441 0xd71 "൱" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x21,0x21,0x21,0x11,0x00,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 3442 0xd72 "൲" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x44,0x44,0x45,0x45,0x44,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x84,0x4a,0x2a,0xfe,0x20,0x20,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 3443 0xd73 "൳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x1c,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3444 0xd74 "൴" */
+0x00,0x01,0x00,0x00,0x0f,0x10,0x20,0x20,0x38,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x10,0xd0,0x20,0x50,0x90,0x90,0x90,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3445 0xd75 "൵" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x39,0x25,0x25,0x19,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x08,0x68,0x90,0x28,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3446 0xd76 "൶" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x72,0x8a,0x8b,0x5f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x48,0x28,0x28,0x28,0x48,0x88,0xf8,0x00,0x00,0x00,0x00,
+/* 3447 0xd77 "൷" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x64,0x94,0x94,0x9e,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xca,0x8a,0x9c,0xa8,0xa8,0xa8,0x90,0x00,0x00,0x00,0x00,
+/* 3448 0xd78 "൸" */
+0x00,0x00,0x00,0x00,0x08,0x55,0x55,0x55,0x55,0x55,0x55,0xa2,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xbe,0x49,0x45,0x45,0x45,0x45,0x49,0x5f,0x00,0x00,0x00,0x00,
+/* 3449 0xd79 "൹" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x44,0x44,0x45,0x45,0x44,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xfe,0x20,0x20,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 3450 0xd7a "ൺ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x44,0x44,0x64,0x54,0x54,0x24,0x00,0x00,0x00,0x00,
+0x00,0x30,0x48,0x04,0x74,0x88,0x98,0xa8,0xa8,0xa8,0xa8,0x90,0x00,0x00,0x00,0x00,
+/* 3451 0xd7b "ൻ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x21,0x21,0x11,0x09,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x08,0x68,0x90,0x28,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3452 0xd7c "ർ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x04,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x10,0xd0,0x20,0x50,0x90,0x90,0x90,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3453 0xd7d "ൽ" */
+0x00,0x00,0x00,0x00,0x1c,0x23,0x45,0x49,0x49,0x49,0x49,0x26,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x08,0xe8,0x10,0x28,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3454 0xd7e "ൾ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x21,0x21,0x21,0x21,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x08,0x68,0x90,0x28,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3455 0xd7f "ൿ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x08,0x3f,0x48,0x48,0x48,0x37,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x20,0x20,0xa0,0xa0,0xf8,0xa4,0xa4,0x98,0x00,0x00,0x00,0x00,0x00,
+/* 3456 0xd80 "඀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3457 0xd81 "ඁ" */
+0x09,0x09,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x90,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3458 0xd82 "ං" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3459 0xd83 "ඃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,
+/* 3460 0xd84 "඄" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3461 0xd85 "අ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x0f,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0xa8,0x68,0xf0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,
+/* 3462 0xd86 "ආ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x03,0x7f,0x81,0x81,0x41,0x3f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0xd8,0x64,0x42,0x82,0x02,0x02,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 3463 0xd87 "ඇ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x01,0x3f,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xa0,0xbe,0xc2,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x83,
+/* 3464 0xd88 "ඈ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x01,0x3f,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xa0,0xbe,0xc4,0x88,0x9e,0x82,0x84,0x84,0x84,0x84,0x83,
+/* 3465 0xd89 "ඉ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x12,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x10,0x60,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3466 0xd8a "ඊ" */
+0x08,0x15,0x09,0x02,0x04,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x50,0x20,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3467 0xd8b "උ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xe0,0x00,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3468 0xd8c "ඌ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x00,0x3f,0x40,0x40,0x40,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x2c,0x2a,0x92,0x82,0x12,0x4c,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3469 0xd8d "ඍ" */
+0x00,0x00,0x00,0x00,0x61,0x92,0x0a,0x7b,0x80,0x84,0x8a,0x71,0x80,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x26,0xe9,0x21,0x27,0x49,0x86,0x01,0x00,0x00,0x00,
+/* 3470 0xd8e "ඎ" */
+0x00,0x00,0x00,0x00,0x42,0xa5,0x14,0x77,0x80,0x88,0x95,0x62,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0xad,0x89,0x9b,0x2d,0x12,0x00,0x00,0x00,0x00,
+/* 3471 0xd8f "ඏ" */
+0x00,0x00,0x00,0x00,0x1c,0x2a,0x42,0x4e,0x50,0x48,0x27,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x54,0x42,0x72,0x0a,0x12,0xe4,0x08,0xf0,0x00,0x00,0x00,
+/* 3472 0xd90 "ඐ" */
+0x00,0x00,0x00,0x00,0x71,0xaa,0x8a,0xbb,0xa0,0xa0,0x9f,0x40,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x36,0xb5,0xa9,0xa1,0x29,0x46,0x80,0x00,0x00,0x00,
+/* 3473 0xd91 "එ" */
+0x03,0x04,0x03,0x00,0x0c,0x02,0x3e,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x80,0x80,0x80,0x80,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3474 0xd92 "ඒ" */
+0x03,0x04,0x03,0x00,0x0c,0x02,0x3e,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0xb8,0xa4,0xb8,0xa0,0xa0,0x60,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3475 0xd93 "ඓ" */
+0x00,0x00,0x00,0x00,0x00,0x70,0x89,0x84,0xb3,0xb9,0x88,0x70,0x00,0x00,0x00,0x00,
+0x1c,0x24,0x1c,0x04,0x64,0x12,0xf1,0x81,0x01,0x01,0x82,0x7c,0x00,0x00,0x00,0x00,
+/* 3476 0xd94 "ඔ" */
+0x00,0x00,0x00,0x3f,0x40,0x01,0x61,0x50,0x4f,0x40,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xc8,0xa4,0x24,0xc4,0x04,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 3477 0xd95 "ඕ" */
+0x00,0x7f,0x20,0x3f,0x40,0x01,0x61,0x50,0x4f,0x40,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0xf0,0x10,0xc8,0xa4,0x24,0xc4,0x04,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 3478 0xd96 "ඖ" */
+0x00,0x00,0x00,0x7f,0x80,0x0e,0x0d,0xc1,0xbe,0x80,0x88,0x77,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x6c,0x6a,0x52,0x42,0x92,0x0c,0x07,0x00,0x00,0x00,
+/* 3479 0xd97 "඗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3480 0xd98 "඘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3481 0xd99 "඙" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3482 0xd9a "ක" */
+0x00,0x00,0x00,0x00,0x60,0x93,0x8c,0x0f,0x10,0x20,0x44,0xbb,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0xc8,0x28,0x28,0x48,0x90,0x00,0x00,0x00,0x00,
+/* 3483 0xd9b "ඛ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x0f,0x10,0x20,0x20,0x2c,0x1c,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x88,0x48,0x48,0x90,0xe0,0x00,0x00,0x00,0x00,
+/* 3484 0xd9c "ග" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x48,0x8e,0x82,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3485 0xd9d "ඝ" */
+0x00,0x00,0x00,0x00,0x30,0x49,0x05,0x7d,0x10,0x20,0x27,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3486 0xd9e "ඞ" */
+0x00,0x00,0x3f,0x40,0x1c,0x1a,0x02,0x3e,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3487 0xd9f "ඟ" */
+0x00,0x00,0x00,0x00,0x1c,0x2a,0x42,0x4e,0x50,0x48,0x27,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x42,0x72,0x12,0x22,0xc4,0x88,0x00,0x00,0x00,0x00,
+/* 3488 0xda0 "ච" */
+0x00,0x00,0x1f,0x20,0x0c,0x02,0x3e,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3489 0xda1 "ඡ" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x3e,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0xb0,0xc8,0x78,0x4c,0x32,0x02,0x04,0xf8,0x00,0x00,0x00,0x00,
+/* 3490 0xda2 "ජ" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x3e,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x08,0x10,0x20,0x20,0x70,0xa8,0xa8,0x70,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3491 0xda3 "ඣ" */
+0x00,0x00,0x00,0x00,0xe0,0x90,0x27,0x78,0x86,0x81,0xc9,0xb6,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x70,0x88,0x04,0xc2,0x22,0x42,0x82,0x92,0x6c,0x00,0x00,0x00,0x00,
+/* 3492 0xda4 "ඤ" */
+0x00,0x00,0x00,0x00,0x39,0x56,0x84,0x98,0xa6,0xc1,0xc9,0xb6,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x28,0x04,0x7c,0x80,0x80,0x44,0x38,0x08,0x10,0x10,0x0c,
+/* 3493 0xda5 "ඥ" */
+0x00,0x00,0x00,0x00,0x38,0x54,0x84,0x99,0xa1,0xc2,0xc4,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x54,0x82,0xbe,0xe0,0x40,0x4c,0x34,0x04,0x08,0x08,0x06,
+/* 3494 0xda6 "ඦ" */
+0x00,0x00,0x00,0x00,0x1d,0x2a,0x42,0x4c,0x50,0x60,0x60,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x04,0x08,0x10,0x90,0x38,0x54,0x54,0x38,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3495 0xda7 "ට" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x00,0x1c,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 3496 0xda8 "ඨ" */
+0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x20,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0xc0,0x40,0xc0,0x40,0x40,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3497 0xda9 "ඩ" */
+0x00,0x00,0x1f,0x20,0x0c,0x02,0x3e,0x10,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3498 0xdaa "ඪ" */
+0x01,0x02,0x01,0x00,0x18,0x04,0x7c,0x20,0x40,0x40,0x22,0x1d,0x00,0x00,0x00,0x00,
+0xc0,0x40,0xc0,0x40,0x40,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3499 0xdab "ණ" */
+0x00,0x00,0x00,0x01,0x1e,0x26,0x39,0x35,0x39,0x41,0x82,0xfc,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0x0c,0x52,0xb2,0x52,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 3500 0xdac "ඬ" */
+0x00,0x00,0x1f,0x20,0x07,0x0a,0x10,0x13,0x14,0x18,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x10,0x88,0x88,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3501 0xdad "ත" */
+0x00,0x00,0x00,0x00,0x60,0x93,0x8c,0x0f,0x10,0x20,0x40,0xbf,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0xc8,0x28,0x28,0x48,0x90,0x00,0x00,0x00,0x00,
+/* 3502 0xdae "ථ" */
+0x01,0x02,0x01,0x00,0x10,0x20,0x40,0x40,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0xc0,0x40,0xc0,0x40,0x40,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3503 0xdaf "ද" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x07,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xe0,0x00,0x30,0xd0,0x10,0x20,0x20,0x18,
+/* 3504 0xdb0 "ධ" */
+0x00,0x00,0x0f,0x10,0x20,0x00,0x0c,0x10,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3505 0xdb1 "න" */
+0x00,0x00,0x00,0x00,0x61,0x92,0x8c,0x0f,0x10,0x20,0x41,0xbe,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x04,0x04,0x84,0x84,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 3506 0xdb2 "඲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3507 0xdb3 "ඳ" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x08,0x0b,0x0c,0x0c,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xe0,0x00,0x00,0x20,0xc0,0x40,0x80,0x80,0x60,
+/* 3508 0xdb4 "ප" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x03,0x0c,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x68,0x18,0x04,0x18,0xe0,0x00,0x00,0x00,0x00,
+/* 3509 0xdb5 "ඵ" */
+0x00,0x00,0x01,0x00,0x00,0x06,0x01,0x03,0x0c,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x20,0xe0,0x20,0x20,0x10,0x08,0x08,0x04,0x18,0xe0,0x00,0x00,0x00,0x00,
+/* 3510 0xdb6 "බ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x0f,0x10,0x20,0x20,0x2c,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x88,0x48,0x48,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3511 0xdb7 "භ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x05,0x7d,0x10,0x20,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x04,0xc4,0x44,0x84,0x08,0x10,0x00,0x00,0x00,0x00,
+/* 3512 0xdb8 "ම" */
+0x00,0x00,0x00,0x1f,0x20,0x01,0x1a,0x1a,0x16,0x13,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xc8,0x28,0xa8,0x28,0xc8,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3513 0xdb9 "ඹ" */
+0x00,0x00,0x00,0x1f,0x20,0x01,0x1b,0x1b,0x17,0x10,0x09,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xc8,0x28,0xe8,0xe8,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 3514 0xdba "ය" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x10,0x20,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3515 0xdbb "ර" */
+0x00,0x01,0x01,0x02,0x04,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 3516 0xdbc "඼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3517 0xdbd "ල" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x27,0x22,0x21,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x48,0x88,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3518 0xdbe "඾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3519 0xdbf "඿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3520 0xdc0 "ව" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x46,0x41,0x0f,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3521 0xdc1 "ශ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x48,0x8e,0x82,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 3522 0xdc2 "ෂ" */
+0x00,0x00,0x00,0x0c,0x02,0x0e,0x10,0x23,0x24,0x23,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0xe0,0x20,0x50,0x90,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3523 0xdc3 "ස" */
+0x00,0x00,0x00,0x00,0x30,0x49,0x05,0x7d,0x10,0x20,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3524 0xdc4 "හ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x05,0x1d,0x10,0x20,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x04,0xc4,0x44,0x84,0x08,0x10,0x00,0x00,0x00,0x00,
+/* 3525 0xdc5 "ළ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x1f,0x18,0x17,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xe0,0x0a,0xf2,0x04,0xf8,0x00,0x00,0x00,0x00,
+/* 3526 0xdc6 "ෆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x10,0x60,0x00,0x00,0x00,0x00,
+/* 3527 0xdc7 "෇" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3528 0xdc8 "෈" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3529 0xdc9 "෉" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3530 0xdca "්" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0e,0x09,0x0e,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3531 0xdcb "෋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3532 0xdcc "෌" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3533 0xdcd "෍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3534 0xdce "෎" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3535 0xdcf "ා" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3536 0xdd0 "ැ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+/* 3537 0xdd1 "ෑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x02,0x04,0x02,0x04,0x04,0x04,0x03,0x00,0x00,
+/* 3538 0xdd2 "ි" */
+0x07,0x08,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3539 0xdd3 "ී" */
+0x07,0x08,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3540 0xdd4 "ු" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xf0,
+/* 3541 0xdd5 "෕" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3542 0xdd6 "ූ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xd0,0x30,
+/* 3543 0xdd7 "෗" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3544 0xdd8 "ෘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x07,0x09,0x06,0x01,0x00,0x00,0x00,
+/* 3545 0xdd9 "ෙ" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x90,0x80,0xe0,0xe0,0xe0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3546 0xdda "ේ" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x90,0x80,0xe0,0xe0,0xe0,0x00,0x00,0x00,0x00,
+0x0e,0x09,0x0e,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3547 0xddb "ෛ" */
+0x00,0x00,0x00,0x00,0x48,0xb4,0x90,0x90,0x90,0xfc,0xfc,0xfc,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3548 0xddc "ො" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x90,0x80,0xe0,0xe0,0xe0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3549 0xddd "ෝ" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x90,0x80,0xe0,0xe0,0xe0,0x00,0x00,0x00,0x00,
+0x0e,0x09,0x0e,0x08,0x08,0x08,0x0e,0x09,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3550 0xdde "ෞ" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x90,0x80,0xe0,0xe0,0xe0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x0a,0x0d,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3551 0xddf "ෟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x0a,0x0d,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 3552 0xde0 "෠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3553 0xde1 "෡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3554 0xde2 "෢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3555 0xde3 "෣" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3556 0xde4 "෤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3557 0xde5 "෥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3558 0xde6 "෦" */
+0x00,0x00,0x07,0x08,0x10,0x10,0x0f,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0xe0,0x90,0x90,0xe0,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 3559 0xde7 "෧" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x47,0x49,0x49,0x46,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x50,0x50,0x50,0x90,0x10,0x00,0x00,0x00,0x00,
+/* 3560 0xde8 "෨" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x4f,0x52,0x52,0x4c,0x21,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x8c,0x52,0x22,0xa2,0xa2,0xa2,0x24,0x28,0x00,0x00,0x00,0x00,
+/* 3561 0xde9 "෩" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x9c,0xaa,0xaa,0x92,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x2c,0x52,0x92,0x92,0x92,0x92,0xa2,0xac,0x00,0x00,0x00,0x00,
+/* 3562 0xdea "෪" */
+0x00,0x00,0x08,0x1c,0x2a,0x32,0x04,0x18,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x08,0x10,0x20,0x70,0xa8,0x98,0x40,0x30,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 3563 0xdeb "෫" */
+0x00,0x01,0x03,0x05,0x06,0x00,0x03,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x10,0x60,0x80,0x80,0x80,0x70,0x00,0x00,
+/* 3564 0xdec "෬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x2c,0x22,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x7c,0x8a,0x92,0x60,0x00,0x00,0x00,0x00,
+/* 3565 0xded "෭" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x40,0x40,0x40,0x80,0x80,0x84,0x84,0x78,0x00,0x00,
+/* 3566 0xdee "෮" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x09,0x12,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x40,0x80,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 3567 0xdef "෯" */
+0x07,0x08,0x08,0x04,0x1f,0x20,0x4f,0x52,0x52,0x4c,0x21,0x1e,0x00,0x00,0x00,0x00,
+0xe0,0x90,0x60,0x00,0x8c,0x52,0x22,0xa2,0xa2,0xa2,0x24,0x28,0x00,0x00,0x00,0x00,
+/* 3568 0xdf0 "෰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3569 0xdf1 "෱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3570 0xdf2 "ෲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x2d,0x09,0x1b,0x2d,0x12,0x00,0x00,0x00,0x00,
+/* 3571 0xdf3 "ෳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x0a,0x0d,0x01,0x05,0x0b,0x06,0x00,0x00,0x00,0x00,
+/* 3572 0xdf4 "෴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x4a,0x55,0x25,0x50,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0xa4,0x54,0x48,0x14,0x06,0x00,0x00,0x00,0x00,
+/* 3573 0xdf5 "෵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3574 0xdf6 "෶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3575 0xdf7 "෷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3576 0xdf8 "෸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3577 0xdf9 "෹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3578 0xdfa "෺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3579 0xdfb "෻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3580 0xdfc "෼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3581 0xdfd "෽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3582 0xdfe "෾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3583 0xdff "෿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3584 0xe00 "฀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3585 0xe01 "ก" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3586 0xe02 "ข" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x64,0x24,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3587 0xe03 "ฃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x52,0x72,0x12,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3588 0xe04 "ค" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5a,0x7a,0x62,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3589 0xe05 "ฅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x42,0x5a,0x7a,0x62,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3590 0xe06 "ฆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x52,0x72,0x12,0x22,0x22,0x22,0x72,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3591 0xe07 "ง" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x04,0x04,0x44,0x24,0x14,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3592 0xe08 "จ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x1a,0x1a,0x0a,0x0a,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3593 0xe09 "ฉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x64,0x64,0x24,0x2e,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3594 0xe0a "ช" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x32,0x34,0x12,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3595 0xe0b "ซ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x52,0x74,0x12,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3596 0xe0c "ฌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x39,0x45,0x25,0x45,0x45,0x45,0x6f,0x6d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3597 0xe0d "ญ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x2a,0x4a,0x4a,0x4a,0x6e,0x62,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3598 0xe0e "ฎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x66,0x7a,0x16,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3599 0xe0f "ฏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x6a,0x6e,0x1a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3600 0xe10 "ฐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x1c,0x02,0x1a,0x1a,0x06,0x02,0x2a,0x16,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3601 0xe11 "ฑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x7a,0x12,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3602 0xe12 "ฒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x29,0x55,0x45,0x75,0x75,0x55,0x6f,0x4d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3603 0xe13 "ณ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x2a,0x4a,0x4a,0x4a,0x6f,0x6b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3604 0xe14 "ด" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5a,0x5a,0x4a,0x72,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3605 0xe15 "ต" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x42,0x5a,0x5a,0x4a,0x72,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3606 0xe16 "ถ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x32,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3607 0xe17 "ท" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x6a,0x32,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3608 0xe18 "ธ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x78,0x24,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3609 0xe19 "น" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x64,0x24,0x44,0x44,0x44,0x4e,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3610 0xe1a "บ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x32,0x12,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3611 0xe1b "ป" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x32,0x32,0x12,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3612 0xe1c "ผ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x69,0x69,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3613 0xe1d "ฝ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x69,0x69,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3614 0xe1e "พ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x69,0x69,0x29,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3615 0xe1f "ฟ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x69,0x69,0x29,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3616 0xe20 "ภ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x62,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3617 0xe21 "ม" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x62,0x22,0x22,0x22,0x22,0x72,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3618 0xe22 "ย" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x62,0x42,0x32,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3619 0xe23 "ร" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x78,0x04,0x04,0x04,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3620 0xe24 "ฤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x32,0x32,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3621 0xe25 "ล" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x1a,0x26,0x22,0x32,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3622 0xe26 "ฦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x62,0x22,0x22,0x22,0x62,0x62,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3623 0xe27 "ว" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x04,0x04,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3624 0xe28 "ศ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3c,0x42,0x5a,0x7a,0x62,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3625 0xe29 "ษ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x62,0x22,0x2a,0x2f,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3626 0xe2a "ส" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x3c,0x42,0x02,0x1a,0x26,0x22,0x32,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3627 0xe2b "ห" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x24,0x2a,0x32,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3628 0xe2c "ฬ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x6a,0x69,0x29,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3629 0xe2d "อ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x62,0x62,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3630 0xe2e "ฮ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x3c,0x7a,0x02,0x62,0x62,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3631 0xe2f "ฯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x74,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3632 0xe30 "ะ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x38,0x00,0x34,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3633 0xe31 "ั" */
+0x00,0x00,0x00,0x31,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3634 0xe32 "า" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3635 0xe33 "ำ" */
+0x00,0x00,0x00,0x60,0x60,0x00,0x1c,0x22,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3636 0xe34 "ิ" */
+0x00,0x00,0x00,0x3c,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3637 0xe35 "ี" */
+0x00,0x00,0x00,0x3a,0x46,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3638 0xe36 "ึ" */
+0x00,0x00,0x00,0x3e,0x46,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3639 0xe37 "ื" */
+0x00,0x00,0x00,0x3a,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3640 0xe38 "ุ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3641 0xe39 "ู" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3642 0xe3a "ฺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3643 0xe3b "฻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3644 0xe3c "฼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3645 0xe3d "฽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3646 0xe3e "฾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3647 0xe3f "฿" */
+0x00,0x00,0x00,0x00,0x08,0x7c,0x2a,0x2a,0x2a,0x3c,0x2a,0x2a,0x2a,0x7c,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3648 0xe40 "เ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3649 0xe41 "แ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3650 0xe42 "โ" */
+0x00,0x00,0x00,0x3e,0x41,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3651 0xe43 "ใ" */
+0x00,0x00,0x00,0x38,0x44,0x54,0x34,0x04,0x04,0x04,0x04,0x04,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3652 0xe44 "ไ" */
+0x00,0x00,0x00,0x6c,0x14,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3653 0xe45 "ๅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3654 0xe46 "ๆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x72,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3655 0xe47 "็" */
+0x02,0x3c,0x40,0x54,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3656 0xe48 "่" */
+0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3657 0xe49 "้" */
+0x18,0x09,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3658 0xe4a "๊" */
+0x28,0x55,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3659 0xe4b "๋" */
+0x04,0x0e,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3660 0xe4c "์" */
+0x01,0x0e,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3661 0xe4d "ํ" */
+0x00,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3662 0xe4e "๎" */
+0x03,0x04,0x06,0x08,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3663 0xe4f "๏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x5a,0x5a,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3664 0xe50 "๐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3665 0xe51 "๑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5a,0x3a,0x02,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3666 0xe52 "๒" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,0x56,0x52,0x5a,0x5a,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3667 0xe53 "๓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x4a,0x4a,0x42,0x72,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3668 0xe54 "๔" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3c,0x40,0x40,0x4c,0x4c,0x48,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3669 0xe55 "๕" */
+0x00,0x00,0x00,0x00,0x00,0x1a,0x16,0x3c,0x40,0x40,0x4c,0x4c,0x48,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3670 0xe56 "๖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x2c,0x12,0x02,0x02,0x32,0x32,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3671 0xe57 "๗" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x2a,0x5a,0x4a,0x4a,0x4a,0x6a,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3672 0xe58 "๘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x3c,0x40,0x40,0x46,0x56,0x52,0x6e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3673 0xe59 "๙" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x1a,0x34,0x50,0x48,0x48,0x64,0x64,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3674 0xe5a "๚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6d,0x75,0x05,0x05,0x05,0x05,0x05,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3675 0xe5b "๛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x40,0x40,0x40,0x42,0x25,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xa2,0x52,0x0c,0x00,0x00,
+/* 3676 0xe5c "๜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3677 0xe5d "๝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3678 0xe5e "๞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3679 0xe5f "๟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3680 0xe60 "๠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3681 0xe61 "๡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3682 0xe62 "๢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3683 0xe63 "๣" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3684 0xe64 "๤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3685 0xe65 "๥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3686 0xe66 "๦" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3687 0xe67 "๧" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3688 0xe68 "๨" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3689 0xe69 "๩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3690 0xe6a "๪" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3691 0xe6b "๫" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3692 0xe6c "๬" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3693 0xe6d "๭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3694 0xe6e "๮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3695 0xe6f "๯" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3696 0xe70 "๰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3697 0xe71 "๱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3698 0xe72 "๲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3699 0xe73 "๳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3700 0xe74 "๴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3701 0xe75 "๵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3702 0xe76 "๶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3703 0xe77 "๷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3704 0xe78 "๸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3705 0xe79 "๹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3706 0xe7a "๺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3707 0xe7b "๻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3708 0xe7c "๼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3709 0xe7d "๽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3710 0xe7e "๾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3711 0xe7f "๿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3712 0xe80 "຀" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3713 0xe81 "ກ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x22,0x22,0x22,0x22,0x22,0x22,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3714 0xe82 "ຂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x04,0x18,0x20,0x4c,0x52,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3715 0xe83 "຃" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3716 0xe84 "ຄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x32,0x42,0x42,0x42,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3717 0xe85 "຅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3718 0xe86 "ຆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x52,0xaa,0x8a,0x12,0x22,0x4a,0x4a,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3719 0xe87 "ງ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x2c,0x14,0x04,0x04,0x04,0x04,0x04,0x04,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3720 0xe88 "ຈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x1a,0x26,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3721 0xe89 "ຉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x62,0x22,0x22,0x22,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3722 0xe8a "ຊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x64,0x08,0x10,0x20,0x4c,0x72,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3723 0xe8b "຋" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3724 0xe8c "ຌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x62,0x04,0x18,0x20,0x4c,0x72,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3725 0xe8d "ຍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x42,0x42,0x32,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3726 0xe8e "ຎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x92,0x92,0x52,0x92,0x92,0x92,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3727 0xe8f "ຏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x42,0x42,0x32,0x42,0x42,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3728 0xe90 "ຐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x22,0x52,0x22,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3729 0xe91 "ຑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xa4,0xea,0xaa,0x2a,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3730 0xe92 "ຒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x52,0xaa,0xaa,0x8a,0x8a,0x8a,0x8a,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3731 0xe93 "ຓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3732 0xe94 "ດ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x52,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3733 0xe95 "ຕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x5a,0x42,0x42,0x42,0x42,0x42,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3734 0xe96 "ຖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x22,0x22,0x22,0x22,0x22,0x22,0x32,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3735 0xe97 "ທ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x52,0x52,0x52,0x52,0x52,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3736 0xe98 "ຘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x7c,0x02,0x62,0x42,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3737 0xe99 "ນ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x52,0x22,0x22,0x22,0x22,0x22,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3738 0xe9a "ບ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x52,0x22,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3739 0xe9b "ປ" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x22,0x52,0x22,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3740 0xe9c "ຜ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x66,0x86,0x82,0x82,0x82,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3741 0xe9d "ຝ" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x62,0x82,0x82,0x82,0x82,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3742 0xe9e "ພ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0xa2,0x42,0x82,0x82,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3743 0xe9f "ຟ" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x42,0xa2,0x42,0x82,0x82,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3744 0xea0 "ຠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x52,0x12,0x12,0x12,0x12,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3745 0xea1 "ມ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3746 0xea2 "ຢ" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x32,0x42,0x42,0x22,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3747 0xea3 "ຣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x02,0x62,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3748 0xea4 "຤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3749 0xea5 "ລ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x32,0x4a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3750 0xea6 "຦" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3751 0xea7 "ວ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3752 0xea8 "ຨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x55,0x5e,0x44,0x34,0x44,0x44,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3753 0xea9 "ຩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x54,0x24,0x44,0x55,0x5e,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3754 0xeaa "ສ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x44,0x46,0x7a,0x02,0x32,0x4a,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3755 0xeab "ຫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x96,0x49,0x49,0x49,0x49,0x49,0x49,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3756 0xeac "ຬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x40,0x3c,0x42,0x42,0x52,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3757 0xead "ອ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x46,0x3a,0x02,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3758 0xeae "ຮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x40,0x3c,0x02,0x62,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3759 0xeaf "ຯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x26,0x1a,0x02,0x04,0x04,0x08,0x08,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3760 0xeb0 "ະ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x52,0x3c,0x00,0x22,0x52,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3761 0xeb1 "ັ" */
+0x00,0x00,0x00,0x62,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3762 0xeb2 "າ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x14,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3763 0xeb3 "ຳ" */
+0x00,0x00,0x40,0xa0,0x40,0x00,0x0c,0x12,0x0a,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3764 0xeb4 "ິ" */
+0x00,0x00,0x00,0x38,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3765 0xeb5 "ີ" */
+0x00,0x00,0x00,0x3c,0x46,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3766 0xeb6 "ຶ" */
+0x00,0x00,0x00,0x38,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3767 0xeb7 "ື" */
+0x00,0x00,0x00,0x3c,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3768 0xeb8 "ຸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3769 0xeb9 "ູ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3770 0xeba "຺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3771 0xebb "ົ" */
+0x00,0x00,0x00,0x7c,0x62,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3772 0xebc "ຼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3773 0xebd "ຽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x24,0x18,0x04,0x04,0x04,0x04,0x64,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3774 0xebe "຾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3775 0xebf "຿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3776 0xec0 "ເ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3777 0xec1 "ແ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x88,0x88,0x88,0x88,0x88,0xcc,0xcc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3778 0xec2 "ໂ" */
+0x00,0x00,0x30,0x4c,0x22,0x18,0x04,0x04,0x04,0x04,0x04,0x04,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3779 0xec3 "ໃ" */
+0x00,0x00,0x38,0x44,0x54,0x34,0x04,0x04,0x04,0x04,0x04,0x04,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3780 0xec4 "ໄ" */
+0x00,0x00,0x80,0x4c,0x34,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3781 0xec5 "໅" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3782 0xec6 "ໆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x52,0x52,0x22,0x02,0x02,0x02,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3783 0xec7 "໇" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3784 0xec8 "່" */
+0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3785 0xec9 "້" */
+0x32,0x14,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3786 0xeca "໊" */
+0x29,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3787 0xecb "໋" */
+0x08,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3788 0xecc "໌" */
+0x02,0x1c,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3789 0xecd "ໍ" */
+0x00,0x00,0x08,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3790 0xece "໎" */
+0x00,0x0a,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3791 0xecf "໏" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3792 0xed0 "໐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3793 0xed1 "໑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5a,0x3a,0x02,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3794 0xed2 "໒" */
+0x00,0x00,0x04,0x04,0x04,0x08,0x10,0x20,0x40,0x40,0x40,0x46,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3795 0xed3 "໓" */
+0x00,0x00,0x10,0x28,0x14,0x0a,0x44,0x22,0x22,0x22,0x22,0x22,0x22,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3796 0xed4 "໔" */
+0x00,0x00,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x4c,0x4c,0x48,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3797 0xed5 "໕" */
+0x00,0x00,0x02,0x0a,0x14,0x08,0x10,0x20,0x40,0x40,0x4c,0x4c,0x48,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3798 0xed6 "໖" */
+0x00,0x00,0x10,0x28,0x14,0x0a,0x24,0x42,0x42,0x42,0x52,0x52,0x52,0x2c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3799 0xed7 "໗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x22,0x22,0x22,0x22,0x22,0x22,0x62,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3800 0xed8 "໘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x52,0x52,0x42,0x42,0x26,0x0a,0x14,0x2c,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3801 0xed9 "໙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3802 0xeda "໚" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3803 0xedb "໛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3804 0xedc "ໜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x99,0x55,0x55,0x55,0x55,0x55,0x55,0x26,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3805 0xedd "ໝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x99,0x55,0x55,0x55,0x55,0x55,0x5d,0x2e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3806 0xede "ໞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xb8,0x44,0x44,0x44,0x55,0x5e,0x44,0xc4,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3807 0xedf "ໟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x84,0x84,0x64,0x95,0x9e,0x84,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3808 0xee0 "໠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3809 0xee1 "໡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3810 0xee2 "໢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3811 0xee3 "໣" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3812 0xee4 "໤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3813 0xee5 "໥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3814 0xee6 "໦" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3815 0xee7 "໧" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3816 0xee8 "໨" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3817 0xee9 "໩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3818 0xeea "໪" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3819 0xeeb "໫" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3820 0xeec "໬" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3821 0xeed "໭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3822 0xeee "໮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3823 0xeef "໯" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3824 0xef0 "໰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3825 0xef1 "໱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 3826 0xef2 "໲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 3827 0xef3 "໳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 3828 0xef4 "໴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 3829 0xef5 "໵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 3830 0xef6 "໶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 3831 0xef7 "໷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 3832 0xef8 "໸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3833 0xef9 "໹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 3834 0xefa "໺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 3835 0xefb "໻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 3836 0xefc "໼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 3837 0xefd "໽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3838 0xefe "໾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3839 0xeff "໿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3840 0xf00 "ༀ" */
+0x18,0x67,0x1c,0x5d,0x49,0x55,0x53,0x4b,0x39,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3841 0xf01 "༁" */
+0x00,0x00,0x00,0x5c,0x48,0x54,0x52,0x4a,0x39,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3842 0xf02 "༂" */
+0x10,0x10,0x18,0x44,0xba,0x7c,0x78,0x84,0x88,0x9c,0x22,0x02,0x06,0x61,0x12,0x0c,
+0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 3843 0xf03 "༃" */
+0x10,0x10,0x18,0x44,0xba,0x7c,0x78,0x84,0x88,0x9c,0x22,0x02,0x06,0x61,0x12,0x0c,
+0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x78,0x00,0x30,0x48,0x48,0x30,0x00,0x00,
+/* 3844 0xf04 "༄" */
+0x00,0x00,0x00,0x00,0x06,0xc1,0x31,0x4e,0x31,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3845 0xf05 "༅" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x62,0x1c,0x62,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3846 0xf06 "༆" */
+0x00,0x00,0x00,0x00,0x06,0xc1,0x31,0x4e,0x31,0x0e,0x00,0x0c,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3847 0xf07 "༇" */
+0x00,0x00,0x00,0x00,0x08,0x15,0xc4,0x39,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3848 0xf08 "༈" */
+0x00,0x00,0x32,0x4c,0x00,0x6c,0x10,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3849 0xf09 "༉" */
+0x00,0x00,0x00,0x1e,0x21,0x01,0x02,0x0e,0x11,0x0e,0x11,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3850 0xf0a "༊" */
+0x00,0x0f,0x30,0x4e,0x51,0x41,0x42,0x4e,0x51,0x4e,0x51,0x40,0x31,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3851 0xf0b "་" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3852 0xf0c "༌" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3853 0xf0d "།" */
+0x00,0x00,0x00,0x18,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3854 0xf0e "༎" */
+0x00,0x00,0x00,0x36,0x36,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3855 0xf0f "༏" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3856 0xf10 "༐" */
+0x00,0x00,0x00,0x18,0x00,0x18,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3857 0xf11 "༑" */
+0x00,0x00,0x00,0x66,0x00,0x18,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3858 0xf12 "༒" */
+0x08,0x14,0x49,0x3e,0x00,0x77,0x00,0x1a,0x2c,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3859 0xf13 "༓" */
+0x00,0x00,0x00,0x00,0x18,0x00,0x18,0xa5,0xa5,0x18,0x00,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3860 0xf14 "༔" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x3c,0x00,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3861 0xf15 "༕" */
+0x00,0xff,0xe7,0x81,0xa5,0x81,0xff,0xb1,0x8d,0xe3,0x13,0x09,0x05,0x03,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3862 0xf16 "༖" */
+0x00,0x7f,0x7f,0x60,0x7f,0x7f,0x01,0x7f,0x7f,0x00,0x7f,0x00,0x7f,0x40,0x7f,0x00,
+0x02,0x82,0x82,0x02,0xfe,0xfe,0x82,0x82,0x82,0x02,0xfe,0x82,0xfe,0x02,0xfe,0x02,
+/* 3863 0xf17 "༗" */
+0x00,0x00,0x04,0x22,0x12,0x12,0x13,0x57,0x58,0x58,0x57,0x50,0x37,0x18,0x10,0x00,
+0x11,0x89,0x49,0x4a,0x52,0x94,0xfc,0x14,0x14,0x24,0xc4,0x08,0xf0,0x00,0x00,0x00,
+/* 3864 0xf18 "༘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x09,0x06,
+0x00,0x00,0x00,0x00,0x02,0x01,0x19,0x25,0x26,0x18,0x90,0x60,0x40,0x80,0x00,0x00,
+/* 3865 0xf19 "༙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3866 0xf1a "༚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3867 0xf1b "༛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x55,0x55,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3868 0xf1c "༜" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x08,0x22,0x55,0x55,0x22,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3869 0xf1d "༝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x08,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3870 0xf1e "༞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x22,0x55,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3871 0xf1f "༟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x25,0x52,0x25,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3872 0xf20 "༠" */
+0x00,0x00,0x00,0x0e,0x11,0x21,0x21,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3873 0xf21 "༡" */
+0x00,0x00,0x00,0x06,0x0b,0x11,0x01,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3874 0xf22 "༢" */
+0x00,0x00,0x00,0x1e,0x21,0x01,0x02,0x0e,0x11,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3875 0xf23 "༣" */
+0x00,0x00,0x00,0x1e,0x21,0x02,0x0e,0x01,0x02,0x1e,0x21,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3876 0xf24 "༤" */
+0x00,0x00,0x00,0x00,0x12,0x2c,0x40,0x41,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3877 0xf25 "༥" */
+0x00,0x00,0x00,0x22,0x44,0x44,0x3c,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3878 0xf26 "༦" */
+0x00,0x00,0x00,0x40,0x44,0x28,0x27,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3879 0xf27 "༧" */
+0x00,0x00,0x00,0x01,0x01,0x31,0x4a,0x12,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3880 0xf28 "༨" */
+0x00,0x00,0x00,0x08,0x10,0x20,0x70,0x08,0x04,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3881 0xf29 "༩" */
+0x00,0x00,0x00,0x1c,0x22,0x24,0x49,0x4e,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3882 0xf2a "༪" */
+0x00,0x00,0x00,0x0c,0x16,0x22,0x0f,0x74,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3883 0xf2b "༫" */
+0x00,0x00,0x00,0x3c,0x42,0x0f,0x74,0x1c,0x22,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3884 0xf2c "༬" */
+0x00,0x00,0x00,0x3c,0x42,0x04,0x1f,0x72,0x04,0x3c,0x42,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3885 0xf2d "༭" */
+0x00,0x00,0x00,0x00,0x12,0x2c,0x46,0x49,0x7e,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3886 0xf2e "༮" */
+0x00,0x00,0x00,0x22,0x4e,0x55,0x3c,0x44,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3887 0xf2f "༯" */
+0x00,0x00,0x00,0x40,0x45,0x2a,0x27,0x19,0x11,0x2e,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3888 0xf30 "༰" */
+0x00,0x00,0x00,0x01,0x01,0x31,0x4f,0x72,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3889 0xf31 "༱" */
+0x00,0x00,0x00,0x08,0x10,0x20,0x72,0x0d,0x34,0x42,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3890 0xf32 "༲" */
+0x00,0x00,0x03,0x1d,0x2a,0x34,0x69,0x4e,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3891 0xf33 "༳" */
+0x00,0x00,0x00,0x1d,0x22,0x46,0x4a,0x54,0x38,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3892 0xf34 "༴" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x10,0x1c,0x04,0x10,0x1c,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3893 0xf35 "༵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x55,0x2a,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3894 0xf36 "༶" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x66,0x66,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3895 0xf37 "༷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3896 0xf38 "༸" */
+0x33,0x4a,0x52,0x5c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3897 0xf39 "༹" */
+0x07,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3898 0xf3a "༺" */
+0x00,0x00,0x00,0x00,0x09,0x14,0xc4,0x38,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x90,0x28,0x90,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3899 0xf3b "༻" */
+0x00,0x00,0x00,0x02,0x05,0x12,0x28,0x12,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x46,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3900 0xf3c "༼" */
+0x00,0x00,0x02,0x02,0x04,0x08,0x08,0x18,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3901 0xf3d "༽" */
+0x00,0x00,0x20,0x20,0x10,0x08,0x08,0x0c,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3902 0xf3e "༾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x02,0x02,0x02,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3903 0xf3f "༿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3904 0xf40 "ཀ" */
+0x00,0x00,0x00,0x3f,0x15,0x65,0x05,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3905 0xf41 "ཁ" */
+0x00,0x00,0x00,0x3f,0x49,0x4d,0x4b,0x41,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3906 0xf42 "ག" */
+0x00,0x00,0x00,0x3f,0x49,0x69,0x59,0x09,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3907 0xf43 "གྷ" */
+0x00,0x00,0x00,0x3f,0x49,0x69,0x59,0x09,0x1f,0x20,0x4e,0x31,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3908 0xf44 "ང" */
+0x00,0x00,0x00,0x1e,0x20,0x40,0x78,0x44,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3909 0xf45 "ཅ" */
+0x00,0x00,0x00,0x3e,0x08,0x08,0x4e,0x31,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3910 0xf46 "ཆ" */
+0x00,0x00,0x00,0x3e,0x08,0x08,0x3e,0x49,0x49,0x36,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3911 0xf47 "ཇ" */
+0x00,0x00,0x00,0x1e,0x20,0x3c,0x40,0x7c,0x42,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3912 0xf48 "཈" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3913 0xf49 "ཉ" */
+0x00,0x00,0x00,0x38,0x44,0x4e,0x11,0x11,0x01,0x01,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3914 0xf4a "ཊ" */
+0x00,0x00,0x00,0x7f,0x01,0x3d,0x43,0x41,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3915 0xf4b "ཋ" */
+0x00,0x00,0x00,0x3f,0x21,0x3a,0x2c,0x22,0x2f,0x30,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3916 0xf4c "ཌ" */
+0x00,0x00,0x00,0x3c,0x02,0x01,0x1f,0x21,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3917 0xf4d "ཌྷ" */
+0x00,0x00,0x00,0x3c,0x02,0x01,0x1f,0x20,0x5e,0x60,0x4e,0x31,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3918 0xf4e "ཎ" */
+0x00,0x00,0x00,0x3f,0x08,0x1c,0x12,0x32,0x2c,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3919 0xf4f "ཏ" */
+0x00,0x00,0x00,0x7f,0x40,0x5e,0x61,0x41,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3920 0xf50 "ཐ" */
+0x00,0x00,0x00,0x3f,0x21,0x17,0x0d,0x11,0x3d,0x03,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3921 0xf51 "ད" */
+0x00,0x00,0x00,0x1e,0x20,0x40,0x7c,0x42,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3922 0xf52 "དྷ" */
+0x00,0x00,0x00,0x1e,0x20,0x40,0x7c,0x42,0x1f,0x20,0x4e,0x31,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3923 0xf53 "ན" */
+0x00,0x00,0x00,0x3f,0x04,0x0e,0x12,0x13,0x0d,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3924 0xf54 "པ" */
+0x00,0x00,0x00,0x33,0x21,0x41,0x7d,0x43,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3925 0xf55 "ཕ" */
+0x00,0x00,0x00,0x33,0x23,0x45,0x7d,0x43,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3926 0xf56 "བ" */
+0x00,0x00,0x00,0x1f,0x21,0x41,0x7d,0x43,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3927 0xf57 "བྷ" */
+0x00,0x00,0x00,0x1f,0x21,0x41,0x7d,0x43,0x1f,0x20,0x4e,0x31,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3928 0xf58 "མ" */
+0x00,0x00,0x00,0x7d,0x09,0x31,0x4d,0x4b,0x31,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3929 0xf59 "ཙ" */
+0x00,0x01,0x01,0x3e,0x08,0x08,0x4e,0x31,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3930 0xf5a "ཚ" */
+0x00,0x01,0x01,0x3e,0x08,0x08,0x3e,0x49,0x49,0x36,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3931 0xf5b "ཛ" */
+0x00,0x01,0x01,0x1e,0x20,0x38,0x40,0x7c,0x42,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3932 0xf5c "ཛྷ" */
+0x00,0x01,0x01,0x1e,0x20,0x38,0x40,0x7c,0x42,0x1f,0x20,0x4e,0x31,0x11,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3933 0xf5d "ཝ" */
+0x00,0x00,0x00,0x31,0x49,0x4f,0x09,0x11,0x1d,0x13,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3934 0xf5e "ཞ" */
+0x00,0x00,0x00,0x1c,0x22,0x4c,0x52,0x53,0x4d,0x21,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3935 0xf5f "ཟ" */
+0x00,0x00,0x00,0x3f,0x01,0x1f,0x01,0x3d,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3936 0xf60 "འ" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x48,0x1c,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3937 0xf61 "ཡ" */
+0x00,0x00,0x00,0x6b,0x49,0x49,0x49,0x35,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3938 0xf62 "ར" */
+0x00,0x00,0x00,0x3e,0x08,0x1c,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3939 0xf63 "ལ" */
+0x00,0x00,0x00,0x39,0x45,0x49,0x0d,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3940 0xf64 "ཤ" */
+0x00,0x00,0x00,0x0f,0x11,0x11,0x4f,0x31,0x11,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3941 0xf65 "ཥ" */
+0x00,0x00,0x00,0x3c,0x22,0x22,0x3d,0x23,0x22,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3942 0xf66 "ས" */
+0x00,0x00,0x00,0x7b,0x11,0x29,0x65,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3943 0xf67 "ཧ" */
+0x00,0x00,0x00,0x1e,0x20,0x4e,0x31,0x11,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3944 0xf68 "ཨ" */
+0x00,0x00,0x00,0x5d,0x49,0x55,0x53,0x4b,0x31,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3945 0xf69 "ཀྵ" */
+0x00,0x00,0x00,0x3f,0x15,0x65,0x05,0x01,0x39,0x25,0x24,0x3d,0x22,0x24,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3946 0xf6a "ཪ" */
+0x00,0x00,0x00,0x7c,0x08,0x38,0x44,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3947 0xf6b "ཫ" */
+0x00,0x00,0x00,0x7e,0x54,0x53,0x50,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3948 0xf6c "ཬ" */
+0x00,0x00,0x00,0x1f,0x08,0x0e,0x11,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3949 0xf6d "཭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 3950 0xf6e "཮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 3951 0xf6f "཯" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 3952 0xf70 "཰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 3953 0xf71 "ཱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3954 0xf72 "ི" */
+0x70,0x48,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3955 0xf73 "ཱི" */
+0x70,0x48,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x42,0x42,0x04,0x1c,0x22,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3956 0xf74 "ུ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x24,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3957 0xf75 "ཱུ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x42,0x42,0x04,0x0c,0x42,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3958 0xf76 "ྲྀ" */
+0x70,0x48,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x72,0x0a,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3959 0xf77 "ཷ" */
+0x70,0x48,0x04,0x00,0x00,0x00,0x00,0x02,0x7a,0x06,0x3f,0x42,0x04,0x1c,0x22,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3960 0xf78 "ླྀ" */
+0x70,0x48,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x52,0x5e,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3961 0xf79 "ཹ" */
+0x70,0x48,0x04,0x00,0x00,0x00,0x00,0x32,0x5e,0x02,0x3f,0x42,0x04,0x1c,0x22,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3962 0xf7a "ེ" */
+0xe0,0x18,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3963 0xf7b "ཻ" */
+0xcc,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3964 0xf7c "ོ" */
+0xcf,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3965 0xf7d "ཽ" */
+0x45,0xee,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3966 0xf7e "ཾ" */
+0x10,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3967 0xf7f "ཿ" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3968 0xf80 "ྀ" */
+0x1c,0x24,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3969 0xf81 "ཱྀ" */
+0x1c,0x24,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x42,0x42,0x04,0x1c,0x22,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3970 0xf82 "ྂ" */
+0x08,0x08,0x0c,0x22,0x5d,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3971 0xf83 "ྃ" */
+0x08,0x14,0x49,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3972 0xf84 "྄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x06,0x02,0x03,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3973 0xf85 "྅" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x08,0x1c,0x12,0x12,0x0a,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3974 0xf86 "྆" */
+0x10,0x10,0x10,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3975 0xf87 "྇" */
+0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3976 0xf88 "ྈ" */
+0x00,0x3f,0x0a,0x04,0x0a,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3977 0xf89 "ྉ" */
+0x00,0x36,0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3978 0xf8a "ྊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0xaa,0xaa,0xaa,0xba,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3979 0xf8b "ྋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x3a,0x4a,0x4a,0x2e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3980 0xf8c "ྌ" */
+0x00,0x49,0x36,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3981 0xf8d "ྍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x22,0x14,0x08,0x14,0x22,0x7f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3982 0xf8e "ྎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3983 0xf8f "ྏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x36,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3984 0xf90 "ྐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x15,0x25,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3985 0xf91 "ྑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x49,0x4d,0x4b,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3986 0xf92 "ྒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x49,0x79,0x09,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3987 0xf93 "ྒྷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x49,0x79,0x01,0x1e,0x20,0x4e,0x31,0x11,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3988 0xf94 "ྔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x7c,0x42,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3989 0xf95 "ྕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x4e,0x31,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3990 0xf96 "ྖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x3e,0x49,0x36,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3991 0xf97 "ྗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x38,0x40,0x7e,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3992 0xf98 "྘" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 3993 0xf99 "ྙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x0e,0x11,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3994 0xf9a "ྚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x01,0x3d,0x43,0x41,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3995 0xf9b "ྛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x44,0x78,0x44,0x7e,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3996 0xf9c "ྜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x02,0x1f,0x21,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3997 0xf9d "ྜྷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x02,0x1f,0x20,0x7e,0x51,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3998 0xf9e "ྞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x08,0x1c,0x32,0x4c,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 3999 0xf9f "ྟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x5e,0x61,0x41,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4000 0xfa0 "ྠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x11,0x0f,0x11,0x3f,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4001 0xfa1 "ྡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x7c,0x42,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4002 0xfa2 "ྡྷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x7c,0x42,0x1f,0x20,0x4e,0x31,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4003 0xfa3 "ྣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x08,0x1c,0x26,0x19,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4004 0xfa4 "ྤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x21,0x7d,0x03,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4005 0xfa5 "ྥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x49,0x7d,0x03,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4006 0xfa6 "ྦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x21,0x7d,0x03,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4007 0xfa7 "ྦྷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x21,0x7d,0x03,0x1f,0x20,0x4e,0x31,0x11,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4008 0xfa8 "ྨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x79,0x31,0x4d,0x33,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4009 0xfa9 "ྩ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x0a,0x09,0x4c,0x32,0x12,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4010 0xfaa "ྪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x09,0x3e,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4011 0xfab "ྫ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x39,0x41,0x7c,0x42,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4012 0xfac "ྫྷ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x39,0x41,0x7c,0x42,0x1e,0x20,0x4e,0x31,0x11,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4013 0xfad "ྭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x05,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4014 0xfae "ྮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x4c,0x53,0x4d,0x21,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4015 0xfaf "ྯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x01,0x1f,0x01,0x3f,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4016 0xfb0 "ྰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x48,0x1c,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4017 0xfb1 "ྱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x12,0x1c,0x09,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4018 0xfb2 "ྲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x39,0x45,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4019 0xfb3 "ླ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0x45,0x49,0x1d,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4020 0xfb4 "ྴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x2f,0x11,0x09,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4021 0xfb5 "ྵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x24,0x3d,0x22,0x24,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4022 0xfb6 "ྶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x29,0x45,0x63,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4023 0xfb7 "ྷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x4e,0x31,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4024 0xfb8 "ྸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5d,0x49,0x55,0x53,0x31,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4025 0xfb9 "ྐྵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x15,0x65,0x05,0x39,0x24,0x3d,0x22,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4026 0xfba "ྺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x49,0x4f,0x09,0x1d,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4027 0xfbb "ྻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6b,0x49,0x49,0x35,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4028 0xfbc "ྼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x1c,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4029 0xfbd "྽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 4030 0xfbe "྾" */
+0x00,0x00,0x00,0x00,0x00,0x41,0x22,0x14,0x08,0x14,0x22,0x41,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4031 0xfbf "྿" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x22,0x14,0x49,0x14,0x22,0x49,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4032 0xfc0 "࿀" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4033 0xfc1 "࿁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4034 0xfc2 "࿂" */
+0x00,0x00,0x00,0x00,0x1c,0x02,0x1a,0x24,0x24,0x58,0x40,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4035 0xfc3 "࿃" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x55,0x49,0x2a,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4036 0xfc4 "࿄" */
+0x00,0x00,0x00,0x6b,0x14,0x08,0x1c,0x22,0x22,0x22,0x3e,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4037 0xfc5 "࿅" */
+0x0d,0x02,0x01,0x03,0x0c,0x19,0x14,0x22,0x21,0x15,0x11,0x0d,0x03,0x01,0x02,0x0d,
+0x60,0x80,0x00,0x80,0x60,0x30,0x50,0x88,0x08,0x50,0x10,0x60,0x80,0x00,0x80,0x60,
+/* 4038 0xfc6 "࿆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x45,0x2a,0x2a,0x12,0x0f,0x15,0x25,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xa8,0xa8,0x90,0xe0,0x50,0x48,
+/* 4039 0xfc7 "࿇" */
+0x0d,0x02,0x01,0x03,0x8c,0x99,0x54,0xa2,0xa1,0x55,0x91,0x8d,0x03,0x01,0x02,0x0d,
+0x60,0x80,0x00,0x80,0x62,0x32,0x54,0x8a,0x0a,0x54,0x12,0x62,0x80,0x00,0x80,0x60,
+/* 4040 0xfc8 "࿈" */
+0x00,0x0d,0x02,0x01,0x3f,0x24,0x12,0x12,0x09,0x09,0x04,0x04,0x02,0x02,0x01,0x00,
+0x00,0x60,0x80,0x00,0xf8,0x48,0x90,0x90,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,
+/* 4041 0xfc9 "࿉" */
+0x00,0x00,0x03,0x04,0x09,0x14,0x13,0x28,0x27,0x20,0x20,0x10,0x18,0x07,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x50,0x90,0x28,0xc8,0x08,0x08,0x10,0x30,0xc0,0x00,0x00,
+/* 4042 0xfca "࿊" */
+0x00,0x07,0x08,0x30,0x20,0x40,0x9e,0xa1,0xc1,0xc9,0xc0,0x40,0x20,0x30,0x08,0x07,
+0x00,0xc0,0x20,0x18,0x08,0x04,0x06,0x26,0x06,0x0a,0xf2,0x04,0x08,0x18,0x20,0xc0,
+/* 4043 0xfcb "࿋" */
+0x00,0x07,0x08,0x30,0x3c,0x42,0x81,0x91,0x81,0x81,0x82,0x42,0x22,0x32,0x09,0x07,
+0x00,0xc0,0x20,0x18,0x0c,0x4c,0x0a,0x12,0xe2,0x02,0x02,0x44,0x08,0x18,0x20,0xc0,
+/* 4044 0xfcc "࿌" */
+0x00,0x07,0x08,0x30,0x21,0x7c,0x82,0x81,0x89,0x83,0x84,0x48,0x29,0x38,0x08,0x07,
+0x00,0xc0,0x20,0x38,0x28,0x24,0x42,0x82,0x22,0x02,0x82,0x7c,0x08,0x18,0x20,0xc0,
+/* 4045 0xfcd "࿍" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 4046 0xfce "࿎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x52,0x25,0x52,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4047 0xfcf "࿏" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x08,0x14,0x00,0x55,0x22,0x55,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4048 0xfd0 "࿐" */
+0x00,0x00,0x1f,0x20,0x40,0x0f,0x10,0x00,0x01,0x07,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x44,0x38,0x80,0x80,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4049 0xfd1 "࿑" */
+0x00,0x3c,0x42,0x02,0x04,0x1c,0x22,0x1c,0x22,0x18,0x24,0x04,0x08,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4050 0xfd2 "࿒" */
+0x00,0x00,0x00,0x00,0x7c,0x38,0x10,0x00,0x00,0x00,0x7c,0x38,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4051 0xfd3 "࿓" */
+0x00,0x00,0x00,0x00,0x06,0xc1,0x31,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4052 0xfd4 "࿔" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x62,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4053 0xfd5 "࿕" */
+0x00,0x00,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+/* 4054 0xfd6 "࿖" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 4055 0xfd7 "࿗" */
+0x00,0x00,0x41,0x41,0x41,0x49,0x41,0x41,0x7f,0x01,0x01,0x09,0x01,0x01,0x7f,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x20,0x00,0x00,0xfc,0x04,0x04,0x24,0x04,0x04,0x04,0x00,
+/* 4056 0xfd8 "࿘" */
+0x00,0x00,0x7f,0x01,0x01,0x09,0x01,0x01,0x7f,0x41,0x41,0x49,0x41,0x41,0x41,0x00,
+0x00,0x00,0x04,0x04,0x04,0x24,0x04,0x04,0xfc,0x00,0x00,0x20,0x00,0x00,0xfc,0x00,
+/* 4057 0xfd9 "࿙" */
+0x00,0x00,0x00,0x40,0x60,0x40,0x00,0x10,0x18,0x10,0x00,0x02,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x02,0x00,0x10,0x38,0x00,0x00,0x00,
+/* 4058 0xfda "࿚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x60,0x40,0x00,0x08,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x06,0x02,0x00,0x08,0x18,0x08,0x00,0x40,0xe0,0x00,0x00,0x00,
+/* 4059 0xfdb "࿛" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 4060 0xfdc "࿜" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 4061 0xfdd "࿝" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 4062 0xfde "࿞" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4063 0xfdf "࿟" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4064 0xfe0 "࿠" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 4065 0xfe1 "࿡" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 4066 0xfe2 "࿢" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 4067 0xfe3 "࿣" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 4068 0xfe4 "࿤" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 4069 0xfe5 "࿥" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 4070 0xfe6 "࿦" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 4071 0xfe7 "࿧" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4072 0xfe8 "࿨" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 4073 0xfe9 "࿩" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 4074 0xfea "࿪" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 4075 0xfeb "࿫" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 4076 0xfec "࿬" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 4077 0xfed "࿭" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 4078 0xfee "࿮" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4079 0xfef "࿯" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4080 0xff0 "࿰" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 4081 0xff1 "࿱" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 4082 0xff2 "࿲" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 4083 0xff3 "࿳" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 4084 0xff4 "࿴" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 4085 0xff5 "࿵" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 4086 0xff6 "࿶" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 4087 0xff7 "࿷" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4088 0xff8 "࿸" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 4089 0xff9 "࿹" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 4090 0xffa "࿺" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 4091 0xffb "࿻" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 4092 0xffc "࿼" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 4093 0xffd "࿽" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 4094 0xffe "࿾" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4095 0xfff "࿿" */
+0x00,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4096 0x1000 "က" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x42,0x0c,0x00,0x00,0x00,0x00,
+/* 4097 0x1001 "ခ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0xf2,0x0a,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4098 0x1002 "ဂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x02,0x84,0x48,0x00,0x00,0x00,0x00,
+/* 4099 0x1003 "ဃ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x42,0x21,0x21,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4100 0x1004 "င" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x00,0x00,0x00,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4101 0x1005 "စ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x42,0x42,0x42,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4102 0x1006 "ဆ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x03,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0xa1,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4103 0x1007 "ဇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x14,0x0a,0x00,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 4104 0x1008 "ဈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x71,0x89,0x45,0x45,0x45,0x89,0x79,0x09,0x09,0x05,0x02,
+/* 4105 0x1009 "ဉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x01,0x01,0xfe,
+/* 4106 0x100a "ည" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x02,0x03,0x02,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0x21,0x21,0x52,0x8c,0x00,0x01,0x01,0xfe,
+/* 4107 0x100b "ဋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x00,0x00,0x84,0x7c,0x04,0xf8,0x80,0x78,0x0e,
+/* 4108 0x100c "ဌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x00,0x00,0x00,0x84,0x7c,0x04,0xc4,0x04,0xf8,
+/* 4109 0x100d "ဍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x84,0xf8,0x80,0x7c,0x04,0x04,0x06,
+/* 4110 0x100e "ဎ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x44,0x82,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4111 0x100f "ဏ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x76,0x89,0x51,0x51,0x51,0x8a,0xf8,0x00,0x00,0x00,0x00,
+/* 4112 0x1010 "တ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 4113 0x1011 "ထ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4114 0x1012 "ဒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x30,0x08,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 4115 0x1013 "ဓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x7a,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4116 0x1014 "န" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0xc2,0x22,0xfc,0x20,0x20,0x00,0x00,
+/* 4117 0x1015 "ပ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x84,0x02,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4118 0x1016 "ဖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x58,0x94,0x12,0x12,0x0a,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4119 0x1017 "ဗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x84,0x7a,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4120 0x1018 "ဘ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 4121 0x1019 "မ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x84,0x02,0x02,0x7a,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4122 0x101a "ယ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x42,0x21,0x21,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4123 0x101b "ရ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0xc4,0x24,0x14,0xf4,0x04,0x04,0x04,0x07,
+/* 4124 0x101c "လ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0x21,0x21,0x12,0x8c,0x00,0x00,0x00,0x00,
+/* 4125 0x101d "ဝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4126 0x101e "သ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0x21,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4127 0x101f "ဟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x21,0x21,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 4128 0x1020 "ဠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x00,0x00,0x84,0x7c,0x04,0xf8,0x80,0x84,0x78,
+/* 4129 0x1021 "အ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x9c,0x62,0x43,0x85,0x49,0x4a,0x8c,0x00,0x00,0x00,0x00,
+/* 4130 0x1022 "ဢ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x42,0x0c,0x00,0x00,0x00,0x00,
+/* 4131 0x1023 "ဣ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x00,0x01,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x02,0x00,0xdc,0x22,0x24,0x07,
+/* 4132 0x1024 "ဤ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x00,0x00,0x07,0x08,0x07,
+0x06,0x09,0x08,0x04,0x02,0x99,0x65,0x25,0x25,0x25,0x45,0x05,0x05,0xe5,0x05,0xf9,
+/* 4133 0x1025 "ဥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x08,0xf0,0x00,0x00,0x04,0xf8,
+/* 4134 0x1026 "ဦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,
+0x70,0x88,0xa8,0xd8,0x70,0x00,0xf8,0x08,0x04,0x04,0x08,0xf0,0x00,0x00,0x04,0xf8,
+/* 4135 0x1027 "ဧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x78,0x00,0x78,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4136 0x1028 "ဨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x32,0x4a,0x0a,0x12,0x0c,0x00,0x02,0x02,0x84,0x78,
+/* 4137 0x1029 "ဩ" */
+0x3f,0x40,0x40,0x40,0x40,0x47,0x48,0x40,0x40,0x40,0x48,0x47,0x40,0x40,0x40,0x3f,
+0xfe,0x01,0x01,0x00,0x00,0x1c,0x82,0x41,0x41,0x41,0xa3,0x1d,0x01,0x01,0x01,0xfe,
+/* 4138 0x102a "ဪ" */
+0x07,0x08,0x08,0x08,0x08,0x0b,0x28,0x48,0x88,0xb8,0xd8,0x6b,0x08,0x08,0x08,0x07,
+0xc6,0x29,0x28,0x04,0x00,0x36,0x89,0x89,0x89,0x89,0x9a,0x68,0x08,0x08,0x08,0xf0,
+/* 4139 0x102b "ါ" */
+0x0f,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4140 0x102c "ာ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 4141 0x102d "ိ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4142 0x102e "ီ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x88,0xa8,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4143 0x102f "ု" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
+/* 4144 0x1030 "ူ" */
+0x00,0x00,0x00,0x00,0x00,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
+/* 4145 0x1031 "ေ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x40,0x70,0x50,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4146 0x1032 "ဲ" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4147 0x1033 "ဳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0xa8,0xd8,0xa8,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4148 0x1034 "ဴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4149 0x1035 "ဵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x80,0xb8,0xc8,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4150 0x1036 "ံ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x02,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4151 0x1037 "့" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x10,
+/* 4152 0x1038 "း" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4153 0x1039 "္" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x70,0x20,
+/* 4154 0x103a "်" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x12,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4155 0x103b "ျ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x84,0x84,0x64,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4156 0x103c "ြ" */
+0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,
+0xfc,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xf8,
+/* 4157 0x103d "ွ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x1c,
+/* 4158 0x103e "ှ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x60,0x00,
+/* 4159 0x103f "ဿ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x24,0x92,0x49,0x49,0x49,0xda,0x24,0x00,0x00,0x00,0x00,
+/* 4160 0x1040 "၀" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,0x08,0x08,0x10,0x60,0x00,0x00,0x00,0x00,
+/* 4161 0x1041 "၁" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 4162 0x1042 "၂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 4163 0x1043 "၃" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x80,0x40,0x20,
+/* 4164 0x1044 "၄" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x01,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x20,0xc0,0x80,0x00,0x00,0x00,
+/* 4165 0x1045 "၅" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x0a,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,
+/* 4166 0x1046 "၆" */
+0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x00,0x00,0x60,0x80,0x80,0x70,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 4167 0x1047 "၇" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x80,
+/* 4168 0x1048 "၈" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x0a,0x09,0x09,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 4169 0x1049 "၉" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x70,0x80,0x80,0x60,0x00,0x00,0x10,0xe0,
+/* 4170 0x104a "၊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4171 0x104b "။" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 4172 0x104c "၌" */
+0x01,0x02,0x02,0x01,0x00,0x03,0x04,0x00,0x00,0x04,0x07,0x04,0x03,0x00,0x04,0x03,
+0x80,0x40,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0xe0,0x20,0x20,0xc0,
+/* 4173 0x104d "၍" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x1e,0x11,0x08,0x07,0x00,0x06,0x08,0x07,
+0x00,0x18,0x24,0x20,0x10,0x88,0x48,0x28,0x28,0x28,0xa8,0xa8,0x28,0x28,0x08,0xf0,
+/* 4174 0x104e "၎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x00,0x00,0x00,0x84,0x7c,0x04,0x04,0x04,0x04,
+/* 4175 0x104f "၏" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x2f,0x20,0x2f,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x18,0x24,0x20,0x10,0x08,0x64,0x94,0x14,0x14,0x14,0x94,0x14,0x00,0x00,0x00,0x00,
+/* 4176 0x1050 "ၐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x32,0x02,0x84,0x48,0x00,0x00,0x00,0x00,
+/* 4177 0x1051 "ၑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x84,0x02,0x32,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4178 0x1052 "ၒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x88,0x04,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4179 0x1053 "ၓ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x86,0x48,0x84,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4180 0x1054 "ၔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x42,0x3e,0x00,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4181 0x1055 "ၕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x42,0x3e,0x00,0x92,0x6c,0x00,0x00,0x00,0x00,
+/* 4182 0x1056 "ၖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4183 0x1057 "ၗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 4184 0x1058 "ၘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x50,0x64,0x38,
+/* 4185 0x1059 "ၙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xa0,0xca,0x74,
+/* 4186 0x105a "ၚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x00,0x00,0x84,0x78,0x20,0x50,0x10,0x20,0x10,
+/* 4187 0x105b "ၛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe2,0x12,0x2a,0x16,0x02,0x12,0xf2,0x12,0x12,0x0a,0x04,
+/* 4188 0x105c "ၜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x32,0x4a,0x32,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4189 0x105d "ၝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x84,0x02,0x02,0x7a,0x86,0x7a,0x02,0xc2,0x02,0xfc,
+/* 4190 0x105e "ၞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x54,0x30,
+/* 4191 0x105f "ၟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x44,0x38,
+/* 4192 0x1060 "ၠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x78,
+/* 4193 0x1061 "ၡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0xe2,0x12,0x8a,0x7a,0x02,0x0a,0x0a,0x1a,
+/* 4194 0x1062 "ၢ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4195 0x1063 "ၣ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x07,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4196 0x1064 "ၤ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 4197 0x1065 "ၥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4198 0x1066 "ၦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x84,0x02,0x02,0x02,0x84,0x78,0x00,0x10,0x10,0x30,
+/* 4199 0x1067 "ၧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4200 0x1068 "ၨ" */
+0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4201 0x1069 "ၩ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4202 0x106a "ၪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4203 0x106b "ၫ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4204 0x106c "ၬ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4205 0x106d "ၭ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4206 0x106e "ၮ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xb6,0x49,0x29,0x29,0x49,0x52,0x00,0x00,0x00,0x00,0x00,
+/* 4207 0x106f "ၯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x21,0x21,0x21,0x42,0x8c,0x00,0x08,0x08,0x18,
+/* 4208 0x1070 "ၰ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x42,0x21,0x21,0x21,0x52,0x8c,0x00,0x08,0x08,0x18,
+/* 4209 0x1071 "ၱ" */
+0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x88,0x54,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4210 0x1072 "ၲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0x40,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4211 0x1073 "ၳ" */
+0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x50,0x88,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4212 0x1074 "ၴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4213 0x1075 "ၵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x82,0x44,0x88,0x00,0x00,0x00,0x00,
+/* 4214 0x1076 "ၶ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x02,0xfa,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4215 0x1077 "ၷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x0a,0x0a,0x8a,0x44,0x80,0x00,0x00,0x00,0x00,
+/* 4216 0x1078 "ၸ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x12,0x8c,0x00,0x00,0x00,0x00,
+/* 4217 0x1079 "ၹ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x06,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0xa1,0x92,0x8c,0x00,0x00,0x00,0x00,
+/* 4218 0x107a "ၺ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0x21,0x21,0x32,0xac,0x20,0x20,0x20,0x38,
+/* 4219 0x107b "ၻ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x23,0x25,0x29,0x4a,0x8c,0x00,0x00,0x00,0x00,
+/* 4220 0x107c "ၼ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x20,0x20,0xfc,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4221 0x107d "ၽ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x20,0x20,0x2e,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4222 0x107e "ၾ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x20,0x20,0x2e,0x52,0x8c,0x00,0x08,0x08,0x18,
+/* 4223 0x107f "ၿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x68,0xa4,0x22,0x22,0x42,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4224 0x1080 "ႀ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x03,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0x21,0xa1,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 4225 0x1081 "ႁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x02,0x02,0x22,0xa4,0x60,0x20,0x20,0x20,0xe0,
+/* 4226 0x1082 "ႂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x48,0x30,
+/* 4227 0x1083 "ႃ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
+/* 4228 0x1084 "ႄ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x30,0x40,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4229 0x1085 "ႅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x88,0x40,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4230 0x1086 "ႆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x50,0x30,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4231 0x1087 "ႇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 4232 0x1088 "ႈ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x01,0x02,0x01,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 4233 0x1089 "ႉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4234 0x108a "ႊ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x03,0x00,0x02,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4235 0x108b "ႋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4236 0x108c "ႌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4237 0x108d "ႍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 4238 0x108e "ႎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x7a,0x02,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 4239 0x108f "ႏ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x01,0x02,0x03,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4240 0x1090 "႐" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 4241 0x1091 "႑" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x05,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4242 0x1092 "႒" */
+0x00,0x00,0x00,0x00,0x00,0x05,0x06,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4243 0x1093 "႓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x03,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 4244 0x1094 "႔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xa0,0xc0,0x00,0x00,0x00,0x00,
+/* 4245 0x1095 "႕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xe0,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 4246 0x1096 "႖" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0xe0,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 4247 0x1097 "႗" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x01,0x02,0x04,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x40,0x80,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 4248 0x1098 "႘" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x40,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 4249 0x1099 "႙" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x02,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x40,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 4250 0x109a "ႚ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4251 0x109b "ႛ" */
+0x00,0x01,0x02,0x01,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4252 0x109c "ႜ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x05,0x02,0x00,0x03,0x05,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 4253 0x109d "ႝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x1c,0x22,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4254 0x109e "႞" */
+0x00,0x01,0x02,0x01,0x00,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
+/* 4255 0x109f "႟" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x10,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x20,0x10,0x08,0x04,0x84,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,
+/* 4256 0x10a0 "Ⴀ" */
+0x00,0x00,0x00,0x80,0xfe,0x22,0x40,0x80,0x80,0x80,0x80,0x82,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4257 0x10a1 "Ⴁ" */
+0x00,0x00,0x00,0x00,0x68,0x88,0x88,0x88,0x98,0x68,0x08,0x08,0x08,0x0e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4258 0x10a2 "Ⴂ" */
+0x00,0x00,0x00,0x00,0xf8,0x88,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x0e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4259 0x10a3 "Ⴃ" */
+0x00,0x00,0x00,0x00,0x80,0xfe,0x12,0x10,0x38,0x44,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4260 0x10a4 "Ⴄ" */
+0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4261 0x10a5 "Ⴅ" */
+0x00,0x00,0x00,0x00,0xf8,0x88,0x88,0x08,0x0e,0x0a,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4262 0x10a6 "Ⴆ" */
+0x00,0x00,0x00,0x00,0x80,0xe0,0x20,0x20,0x20,0x2c,0x32,0x22,0x22,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4263 0x10a7 "Ⴇ" */
+0x00,0x00,0x00,0x00,0x30,0x50,0x90,0x90,0x9e,0x92,0x90,0x90,0x50,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4264 0x10a8 "Ⴈ" */
+0x00,0x00,0x00,0x40,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4265 0x10a9 "Ⴉ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x58,0x64,0x44,0x44,0x4c,0x34,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4266 0x10aa "Ⴊ" */
+0x00,0x00,0x00,0x00,0x00,0xe0,0xa0,0x20,0x20,0x2c,0x32,0x22,0x22,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4267 0x10ab "Ⴋ" */
+0x00,0x00,0x00,0x80,0xf8,0x08,0x08,0x08,0x7e,0x8a,0x8a,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4268 0x10ac "Ⴌ" */
+0x00,0x00,0x00,0x04,0x7c,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4269 0x10ad "Ⴍ" */
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x8a,0x8a,0x74,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4270 0x10ae "Ⴎ" */
+0x00,0x00,0x00,0x80,0xe2,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4271 0x10af "Ⴏ" */
+0x00,0x00,0x00,0x40,0x7a,0x12,0x22,0x22,0x26,0x1a,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4272 0x10b0 "Ⴐ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x14,0x1a,0x12,0x92,0x90,0x90,0x90,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4273 0x10b1 "Ⴑ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x48,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4274 0x10b2 "Ⴒ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x7e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4275 0x10b3 "Ⴓ" */
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x8c,0x8a,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4276 0x10b4 "Ⴔ" */
+0x00,0x00,0x00,0x00,0x7c,0x92,0x92,0x92,0x7c,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4277 0x10b5 "Ⴕ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x50,0x7c,0x14,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4278 0x10b6 "Ⴖ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4279 0x10b7 "Ⴗ" */
+0x00,0x00,0x00,0x00,0x24,0x44,0x44,0x44,0x44,0x44,0x4c,0x34,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4280 0x10b8 "Ⴘ" */
+0x00,0x00,0x00,0x00,0x34,0x44,0x44,0x44,0x4c,0x34,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4281 0x10b9 "Ⴙ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4282 0x10ba "Ⴚ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x40,0x40,0x40,0x40,0x42,0x22,0x1c,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4283 0x10bb "Ⴛ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x3e,0x4a,0x4a,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4284 0x10bc "Ⴜ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x78,0x44,0x48,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4285 0x10bd "Ⴝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x20,0x10,0x08,0x04,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4286 0x10be "Ⴞ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x7c,0x40,0x40,0x40,0x7c,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4287 0x10bf "Ⴟ" */
+0x00,0x00,0x00,0x80,0xfe,0x22,0x22,0x14,0x14,0x08,0x14,0x14,0x22,0x22,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4288 0x10c0 "Ⴠ" */
+0x00,0x00,0x00,0x00,0xf0,0x90,0x90,0x10,0x10,0x10,0x12,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4289 0x10c1 "Ⴡ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x78,0x44,0x46,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4290 0x10c2 "Ⴢ" */
+0x00,0x00,0x00,0x40,0x78,0x44,0x02,0x02,0x02,0x02,0x02,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4291 0x10c3 "Ⴣ" */
+0x00,0x00,0x00,0x00,0x34,0x44,0x44,0x44,0x4c,0x34,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4292 0x10c4 "Ⴤ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0x82,0x82,0x44,0x28,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4293 0x10c5 "Ⴥ" */
+0x00,0x00,0x00,0x00,0x1c,0x12,0x12,0x1c,0x10,0x7c,0x94,0x96,0x90,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4294 0x10c6 "჆" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 4295 0x10c7 "Ⴧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x04,0x08,0x10,0x20,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4296 0x10c8 "჈" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 4297 0x10c9 "჉" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 4298 0x10ca "჊" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 4299 0x10cb "჋" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 4300 0x10cc "჌" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 4301 0x10cd "Ⴭ" */
+0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x08,0x10,0x10,0x20,0x20,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4302 0x10ce "჎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4303 0x10cf "჏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4304 0x10d0 "ა" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x0c,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4305 0x10d1 "ბ" */
+0x00,0x00,0x00,0x00,0x20,0x30,0x10,0x10,0x3c,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4306 0x10d2 "გ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x08,0x08,0x3c,0x42,0x42,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4307 0x10d3 "დ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x52,0x52,0x52,0x52,0x4c,0x20,0x1c,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4308 0x10d4 "ე" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x02,0x02,0x02,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4309 0x10d5 "ვ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x1c,0x02,0x02,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4310 0x10d6 "ზ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x54,0x38,0x1c,0x12,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4311 0x10d7 "თ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4312 0x10d8 "ი" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4313 0x10d9 "კ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x02,0x02,0x1c,0x02,0x02,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4314 0x10da "ლ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x55,0x55,0x55,0x41,0x42,0x40,0x3e,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4315 0x10db "მ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x3e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4316 0x10dc "ნ" */
+0x00,0x00,0x00,0x00,0x02,0x3c,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4317 0x10dd "ო" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x54,0x54,0x44,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4318 0x10de "პ" */
+0x00,0x00,0x00,0x00,0x20,0x18,0x04,0x02,0x02,0x1c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4319 0x10df "ჟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x52,0x52,0x22,0x02,0x22,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4320 0x10e0 "რ" */
+0x00,0x00,0x00,0x00,0x04,0x38,0x40,0x68,0x54,0x54,0x54,0x54,0x44,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4321 0x10e1 "ს" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x48,0x50,0x48,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4322 0x10e2 "ტ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x3c,0x66,0x66,0x5a,0x42,0x42,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4323 0x10e3 "უ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x12,0x12,0x02,0x02,0x02,0x22,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4324 0x10e4 "ფ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4a,0x4a,0x4a,0x4a,0x34,0x02,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4325 0x10e5 "ქ" */
+0x00,0x00,0x00,0x00,0x04,0x0c,0x04,0x04,0x04,0x1c,0x24,0x04,0x04,0x04,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4326 0x10e6 "ღ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x54,0x44,0x48,0x40,0x38,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4327 0x10e7 "ყ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x42,0x42,0x42,0x26,0x1a,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4328 0x10e8 "შ" */
+0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x04,0x04,0x1c,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4329 0x10e9 "ჩ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x78,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4330 0x10ea "ც" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x42,0x42,0x42,0x5c,0x42,0x42,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4331 0x10eb "ძ" */
+0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x02,0x3e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4332 0x10ec "წ" */
+0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x40,0x40,0x7c,0x44,0x44,0x28,0x28,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4333 0x10ed "ჭ" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x08,0x08,0x19,0x26,0x1d,0x04,0x04,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4334 0x10ee "ხ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x48,0x50,0x78,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4335 0x10ef "ჯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x18,0x24,0x42,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4336 0x10f0 "ჰ" */
+0x00,0x00,0x10,0x0c,0x02,0x12,0x0c,0x02,0x12,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4337 0x10f1 "ჱ" */
+0x00,0x00,0x50,0x4c,0x42,0x52,0x4c,0x42,0x52,0x4c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4338 0x10f2 "ჲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x24,0x18,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4339 0x10f3 "ჳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x04,0x08,0x1c,0x02,0x02,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4340 0x10f4 "ჴ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x0c,0x02,0x02,0x02,0x1c,0x02,0x02,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4341 0x10f5 "ჵ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x3e,0x04,0x3e,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4342 0x10f6 "ჶ" */
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x10,0x38,0x54,0x54,0x38,0x10,0x10,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4343 0x10f7 "ჷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x04,0x08,0x10,0x20,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4344 0x10f8 "ჸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x42,0x42,0x42,0x64,0x58,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4345 0x10f9 "ჹ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x3c,0x10,0x10,0x12,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4346 0x10fa "ჺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x30,0x0c,0x1c,0x22,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4347 0x10fb "჻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x06,0x06,0x00,0x60,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4348 0x10fc "ჼ" */
+0x00,0x00,0x02,0x1c,0x20,0x20,0x3c,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4349 0x10fd "ჽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x20,0x10,0x08,0x04,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4350 0x10fe "ჾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x22,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4351 0x10ff "ჿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4352 0x1100 "ᄀ" */
+0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x18,0x60,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4353 0x1101 "ᄁ" */
+0x00,0x00,0x00,0x7b,0x08,0x08,0x08,0x08,0x11,0x11,0x22,0x44,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4354 0x1102 "ᄂ" */
+0x00,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4355 0x1103 "ᄃ" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4356 0x1104 "ᄄ" */
+0x00,0x3b,0x22,0x22,0x22,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4357 0x1105 "ᄅ" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4358 0x1106 "ᄆ" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4359 0x1107 "ᄇ" */
+0x00,0x20,0x20,0x3f,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4360 0x1108 "ᄈ" */
+0x00,0x2a,0x2a,0x3b,0x2a,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4361 0x1109 "ᄉ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4362 0x110a "ᄊ" */
+0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4363 0x110b "ᄋ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4364 0x110c "ᄌ" */
+0x00,0x3f,0x01,0x02,0x0d,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4365 0x110d "ᄍ" */
+0x00,0x00,0x3b,0x08,0x15,0x22,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4366 0x110e "ᄎ" */
+0x0e,0x00,0x3f,0x02,0x0d,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4367 0x110f "ᄏ" */
+0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4368 0x1110 "ᄐ" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4369 0x1111 "ᄑ" */
+0x00,0x7f,0x12,0x12,0x12,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4370 0x1112 "ᄒ" */
+0x00,0x0e,0x00,0x3f,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4371 0x1113 "ᄓ" */
+0x00,0x21,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x04,0x04,0x84,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4372 0x1114 "ᄔ" */
+0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4373 0x1115 "ᄕ" */
+0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4374 0x1116 "ᄖ" */
+0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4375 0x1117 "ᄗ" */
+0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4376 0x1118 "ᄘ" */
+0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4377 0x1119 "ᄙ" */
+0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4378 0x111a "ᄚ" */
+0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4379 0x111b "ᄛ" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x1f,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0xf8,0x00,0xf8,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 4380 0x111c "ᄜ" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4381 0x111d "ᄝ" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 4382 0x111e "ᄞ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4383 0x111f "ᄟ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4384 0x1120 "ᄠ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4385 0x1121 "ᄡ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4386 0x1122 "ᄢ" */
+0x00,0x48,0x48,0x78,0x49,0x7a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x9e,0x82,0x82,0x42,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4387 0x1123 "ᄣ" */
+0x00,0x48,0x48,0x78,0x49,0x7a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x8e,0x88,0x88,0x48,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4388 0x1124 "ᄤ" */
+0x00,0x49,0x49,0x79,0x4a,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x24,0x24,0x3c,0xa4,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4389 0x1125 "ᄥ" */
+0x00,0x48,0x48,0x78,0x49,0x7a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x88,0x88,0x88,0x54,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4390 0x1126 "ᄦ" */
+0x00,0x49,0x49,0x79,0x4a,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3e,0x04,0x08,0x94,0x62,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4391 0x1127 "ᄧ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x08,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4392 0x1128 "ᄨ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x00,0x7c,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4393 0x1129 "ᄩ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4394 0x112a "ᄪ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x28,0x28,0x28,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4395 0x112b "ᄫ" */
+0x00,0x08,0x0f,0x08,0x0f,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0xf8,0x08,0xf8,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4396 0x112c "ᄬ" */
+0x00,0x22,0x3e,0x22,0x3e,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x7c,0x44,0x7c,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4397 0x112d "ᄭ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4398 0x112e "ᄮ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4399 0x112f "ᄯ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4400 0x1130 "ᄰ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4401 0x1131 "ᄱ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4402 0x1132 "ᄲ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4403 0x1133 "ᄳ" */
+0x00,0x11,0x11,0x11,0x29,0x45,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x2e,0x22,0xe2,0x22,0xe2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4404 0x1134 "ᄴ" */
+0x00,0x08,0x08,0x08,0x15,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x88,0x88,0x88,0x54,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4405 0x1135 "ᄵ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4406 0x1136 "ᄶ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x08,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4407 0x1137 "ᄷ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x00,0x7c,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4408 0x1138 "ᄸ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4409 0x1139 "ᄹ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4410 0x113a "ᄺ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x28,0x28,0x28,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4411 0x113b "ᄻ" */
+0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4412 0x113c "ᄼ" */
+0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x80,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4413 0x113d "ᄽ" */
+0x00,0x01,0x01,0x02,0x04,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x20,0xa0,0x50,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4414 0x113e "ᄾ" */
+0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4415 0x113f "ᄿ" */
+0x00,0x04,0x04,0x05,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x40,0x30,0x8c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4416 0x1140 "ᅀ" */
+0x00,0x02,0x05,0x08,0x10,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4417 0x1141 "ᅁ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4418 0x1142 "ᅂ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3c,0x20,0x20,0x20,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4419 0x1143 "ᅃ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4420 0x1144 "ᅄ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x24,0x24,0x3c,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4421 0x1145 "ᅅ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x08,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4422 0x1146 "ᅆ" */
+0x00,0x38,0x44,0x44,0x45,0x39,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x50,0x88,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4423 0x1147 "ᅇ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4424 0x1148 "ᅈ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x08,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4425 0x1149 "ᅉ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x00,0x7c,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4426 0x114a "ᅊ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3c,0x20,0x3c,0x20,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4427 0x114b "ᅋ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x28,0x28,0x28,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4428 0x114c "ᅌ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4429 0x114d "ᅍ" */
+0x00,0x3e,0x04,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4430 0x114e "ᅎ" */
+0x00,0x3f,0x00,0x03,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0xc0,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4431 0x114f "ᅏ" */
+0x00,0x00,0x1f,0x01,0x02,0x0c,0x31,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x20,0xa0,0x50,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4432 0x1150 "ᅐ" */
+0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x60,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4433 0x1151 "ᅑ" */
+0x00,0x00,0x3f,0x08,0x14,0x23,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x40,0xa0,0x10,0x8c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4434 0x1152 "ᅒ" */
+0x1c,0x00,0x3e,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4435 0x1153 "ᅓ" */
+0x18,0x00,0x3e,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4436 0x1154 "ᅔ" */
+0x07,0x00,0x1f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x00,0xc0,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4437 0x1155 "ᅕ" */
+0x0e,0x00,0x3f,0x02,0x0d,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4438 0x1156 "ᅖ" */
+0x00,0x3e,0x14,0x14,0x14,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4439 0x1157 "ᅗ" */
+0x00,0x1f,0x04,0x1f,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x20,0xf8,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4440 0x1158 "ᅘ" */
+0x00,0x18,0x7e,0x1c,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0xfc,0x70,0x88,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4441 0x1159 "ᅙ" */
+0x1f,0x01,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4442 0x115a "ᅚ" */
+0x00,0x3e,0x02,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4443 0x115b "ᅛ" */
+0x00,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4444 0x115c "ᅜ" */
+0x00,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x08,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4445 0x115d "ᅝ" */
+0x00,0x10,0x11,0x10,0x10,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x70,0xfc,0x70,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4446 0x115e "ᅞ" */
+0x00,0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4447 0x115f "ᅟ" */
+0xaa,0x00,0x80,0x22,0xa2,0x3e,0xa2,0x22,0x80,0x03,0x82,0x03,0x82,0x02,0x80,0x55,
+0xaa,0x01,0x00,0x39,0x40,0x41,0x40,0x39,0x00,0xe1,0x00,0x81,0x00,0x01,0x00,0x55,
+/* 4448 0x1160 "ᅠ" */
+0xaa,0x00,0x80,0x22,0xa2,0x3e,0xa2,0x22,0x80,0x03,0x82,0x03,0x82,0x02,0x80,0x55,
+0xaa,0x01,0x00,0x79,0x10,0x11,0x50,0x21,0x00,0xe1,0x00,0x81,0x00,0x01,0x00,0x55,
+/* 4449 0x1161 "ᅡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4450 0x1162 "ᅢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4451 0x1163 "ᅣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x1e,0x10,0x1e,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4452 0x1164 "ᅤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x12,0x12,0x12,0x1e,0x12,0x1e,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4453 0x1165 "ᅥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x70,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4454 0x1166 "ᅦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4455 0x1167 "ᅧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x70,0x10,0x70,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4456 0x1168 "ᅨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x12,0x12,0x12,0x72,0x12,0x72,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4457 0x1169 "ᅩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 4458 0x116a "ᅪ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x1e,0x10,0x10,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4459 0x116b "ᅫ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0xf2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4460 0x116c "ᅬ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4461 0x116d "ᅭ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4462 0x116e "ᅮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4463 0x116f "ᅯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x10,0xf0,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 4464 0x1170 "ᅰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x12,0x12,0x12,0x12,0x12,0x12,0x92,0x12,0xf2,0x12,0x00,0x00,0x00,0x00,0x00,
+/* 4465 0x1171 "ᅱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 4466 0x1172 "ᅲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4467 0x1173 "ᅳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4468 0x1174 "ᅴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x00,0x00,
+/* 4469 0x1175 "ᅵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4470 0x1176 "ᅶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x38,0xa0,0xa0,0xf8,0x00,0x00,0x00,0x00,
+/* 4471 0x1177 "ᅷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x1c,0x10,0x10,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4472 0x1178 "ᅸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x0e,0x08,0x0e,0x88,0x88,0xfe,0x00,0x00,0x00,0x00,
+/* 4473 0x1179 "ᅹ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x08,0x0e,0x08,0x0e,0x48,0x48,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4474 0x117a "ᅺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x38,0x08,0x08,0x88,0x88,0xfe,0x00,0x00,0x00,0x00,
+/* 4475 0x117b "ᅻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x04,0x04,0x04,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4476 0x117c "ᅼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4477 0x117d "ᅽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x38,0x08,0x38,0x88,0x88,0xfe,0x00,0x00,0x00,0x00,
+/* 4478 0x117e "ᅾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x08,0x08,0x38,0x08,0x38,0x08,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4479 0x117f "ᅿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0xfe,0x82,0x8e,0x02,0x00,0x00,0x00,0x00,0x00,
+/* 4480 0x1180 "ᆀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0xf2,0x12,0x00,0x00,0x00,
+/* 4481 0x1181 "ᆁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0xf2,0x12,0x00,0x00,0x00,
+/* 4482 0x1182 "ᆂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xfe,0x80,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 4483 0x1183 "ᆃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xfe,0x00,0xfe,0x80,0x80,0x00,0x00,0x00,
+/* 4484 0x1184 "ᆄ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x1e,0x10,0x10,0xfe,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4485 0x1185 "ᆅ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xa4,0xa4,0xa4,0xbc,0xa4,0xfc,0xa4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4486 0x1186 "ᆆ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x02,0x0e,0x02,0x0e,0x82,0x82,0xfe,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4487 0x1187 "ᆇ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0xfe,0x80,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4488 0x1188 "ᆈ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x02,0x02,0x02,0x42,0x42,0xfe,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4489 0x1189 "ᆉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 4490 0x118a "ᆊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x12,0x12,0x12,0xfe,0x12,0x12,0x12,0x00,0x00,0x00,0x00,0x00,
+/* 4491 0x118b "ᆋ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x02,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x08,0x08,0x08,0xc8,0x08,0x78,0x08,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4492 0x118c "ᆌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0xea,0x0a,0x3a,0x0a,0x3a,0x0a,0x00,0x00,0x00,
+/* 4493 0x118d "ᆍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x80,0xfe,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4494 0x118e "ᆎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x08,0x08,0x08,0x08,0x08,0xfe,0x48,0x48,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 4495 0x118f "ᆏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x21,0x2f,0x01,0x00,0x00,0x00,0x00,0x00,
+/* 4496 0x1190 "ᆐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0a,0x0a,0x0a,0x0a,0x0a,0xfa,0x8a,0xba,0x0a,0x00,0x00,0x00,0x00,0x00,
+/* 4497 0x1191 "ᆑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0xfe,0x42,0x4e,0x02,0x0e,0x02,0x00,0x00,0x00,
+/* 4498 0x1192 "ᆒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0a,0x0a,0x0a,0x0a,0x0a,0xfa,0x8a,0xba,0x0a,0x3a,0x0a,0x00,0x00,0x00,
+/* 4499 0x1193 "ᆓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x20,0xfe,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4500 0x1194 "ᆔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0xff,0x21,0x21,0x01,0x00,0x00,0x00,0x00,0x00,
+/* 4501 0x1195 "ᆕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4502 0x1196 "ᆖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4503 0x1197 "ᆗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0xfe,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4504 0x1198 "ᆘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x48,0x48,0x48,0x4e,0x48,0x48,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4505 0x1199 "ᆙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x48,0x48,0x4e,0x48,0x4e,0x48,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4506 0x119a "ᆚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x84,0xfe,0x00,0x00,0x00,0x00,
+/* 4507 0x119b "ᆛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4508 0x119c "ᆜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x04,0x04,0x04,0x04,0x04,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4509 0x119d "ᆝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 4510 0x119e "ᆞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 4511 0x119f "ᆟ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x70,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4512 0x11a0 "ᆠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4513 0x11a1 "ᆡ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4514 0x11a2 "ᆢ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4515 0x11a3 "ᆣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x38,0x20,0x20,0xf8,0x00,0x00,0x00,0x00,
+/* 4516 0x11a4 "ᆤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x0e,0x08,0x0e,0x08,0x08,0xfe,0x80,0x80,0x00,0x00,
+/* 4517 0x11a5 "ᆥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x28,0x28,0x2e,0xe8,0x28,0xee,0x28,0x28,0x28,0x00,0x00,0x00,
+/* 4518 0x11a6 "ᆦ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x1e,0x10,0x10,0xfe,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4519 0x11a7 "ᆧ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x24,0x24,0x24,0x3c,0x24,0xfc,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4520 0x11a8 "ᆨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 4521 0x11a9 "ᆩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 4522 0x11aa "ᆪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,
+/* 4523 0x11ab "ᆫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 4524 0x11ac "ᆬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0x50,0x88,0x00,0x00,
+/* 4525 0x11ad "ᆭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,
+/* 4526 0x11ae "ᆮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x04,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 4527 0x11af "ᆯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0xf0,0x00,0xf0,0x00,0x00,
+/* 4528 0x11b0 "ᆰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x01,0x0f,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 4529 0x11b1 "ᆱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x1e,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x90,0x90,0x90,0xf0,0x00,0x00,
+/* 4530 0x11b2 "ᆲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x1e,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x90,0xf0,0x90,0xf0,0x00,0x00,
+/* 4531 0x11b3 "ᆳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x1e,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x50,0x88,0x00,0x00,
+/* 4532 0x11b4 "ᆴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x1e,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x80,0xf0,0x80,0xf0,0x00,0x00,
+/* 4533 0x11b5 "ᆵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x1e,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x50,0x50,0x50,0xf8,0x00,0x00,
+/* 4534 0x11b6 "ᆶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x03,0x1e,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xf8,0x60,0x90,0x60,0x00,0x00,
+/* 4535 0x11b7 "ᆷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x04,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 4536 0x11b8 "ᆸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x07,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0xf0,0x00,0x00,
+/* 4537 0x11b9 "ᆹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x1e,0x12,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x50,0x88,0x00,0x00,
+/* 4538 0x11ba "ᆺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xc0,0x20,0x10,0x00,0x00,
+/* 4539 0x11bb "ᆻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x03,0x0c,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xa0,0x50,0x88,0x00,0x00,
+/* 4540 0x11bc "ᆼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 4541 0x11bd "ᆽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x80,0x80,0x40,0x20,0x00,0x00,
+/* 4542 0x11be "ᆾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x07,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xf8,0x40,0xa0,0x18,0x00,
+/* 4543 0x11bf "ᆿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0xf0,0x10,0x10,0x00,0x00,
+/* 4544 0x11c0 "ᇀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x07,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 4545 0x11c1 "ᇁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x40,0x40,0x40,0xf0,0x00,0x00,
+/* 4546 0x11c2 "ᇂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x07,0x00,0x01,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0xf0,0x00,0xc0,0x20,0xc0,0x00,0x00,
+/* 4547 0x11c3 "ᇃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,
+/* 4548 0x11c4 "ᇄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x09,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9e,0x82,0x82,0x42,0x22,0x00,0x00,0x00,
+/* 4549 0x11c5 "ᇅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x84,0x00,0x00,
+/* 4550 0x11c6 "ᇆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4551 0x11c7 "ᇇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x50,0x88,0x00,0x00,
+/* 4552 0x11c8 "ᇈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x82,0xfe,0x00,0x00,
+/* 4553 0x11c9 "ᇉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x7c,0x40,0x7c,0x00,0x00,
+/* 4554 0x11ca "ᇊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 4555 0x11cb "ᇋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,
+/* 4556 0x11cc "ᇌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x08,0x78,0x40,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0x44,0x44,0x4a,0x51,0x00,0x00,
+/* 4557 0x11cd "ᇍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4558 0x11ce "ᇎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4559 0x11cf "ᇏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf7,0x14,0xf4,0x84,0xf7,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0x3f,0x0c,0x12,0x8c,0x00,0x00,
+/* 4560 0x11d0 "ᇐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,
+/* 4561 0x11d1 "ᇑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x0a,0x7a,0x42,0x7b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xde,0x42,0x42,0x42,0xc2,0x00,0x00,
+/* 4562 0x11d2 "ᇒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x0a,0x7a,0x42,0x7b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0x44,0x44,0x4a,0xd1,0x00,0x00,
+/* 4563 0x11d3 "ᇓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7a,0x0a,0x7b,0x42,0x7b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0xc4,0x4a,0xd1,0x00,0x00,
+/* 4564 0x11d4 "ᇔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf4,0x14,0xf7,0x84,0xf7,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0xbf,0x8c,0x92,0x8c,0x00,0x00,
+/* 4565 0x11d5 "ᇕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x78,0x48,0x78,0x30,0x48,0x30,0x00,0x00,
+/* 4566 0x11d6 "ᇖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x78,0x41,0x7a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x88,0x88,0x54,0x22,0x00,0x00,
+/* 4567 0x11d7 "ᇗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x3c,0x21,0x3d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x88,0x04,0xfc,0x00,0x00,
+/* 4568 0x11d8 "ᇘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,
+/* 4569 0x11d9 "ᇙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xfe,0x38,0x44,0x38,0x00,0x00,
+/* 4570 0x11da "ᇚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 4571 0x11db "ᇛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,
+/* 4572 0x11dc "ᇜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,
+/* 4573 0x11dd "ᇝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x11,0x11,0x11,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,
+/* 4574 0x11de "ᇞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0xaa,0x11,0x00,0x00,
+/* 4575 0x11df "ᇟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x82,0xfe,0x00,0x00,
+/* 4576 0x11e0 "ᇠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0xfe,0x08,0x34,0xc2,0x00,0x00,
+/* 4577 0x11e1 "ᇡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xfe,0x38,0x44,0x38,0x00,0x00,
+/* 4578 0x11e2 "ᇢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x0f,0x00,0x03,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0xe0,0x00,0x80,0x40,0x80,0x00,0x00,
+/* 4579 0x11e3 "ᇣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,
+/* 4580 0x11e4 "ᇤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x28,0x28,0x28,0x7c,0x00,0x00,
+/* 4581 0x11e5 "ᇥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xfe,0x38,0x44,0x38,0x00,0x00,
+/* 4582 0x11e6 "ᇦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x07,0x04,0x07,0x01,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xf0,0x10,0xf0,0xc0,0x20,0xc0,0x00,0x00,
+/* 4583 0x11e7 "ᇧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 4584 0x11e8 "ᇨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4585 0x11e9 "ᇩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x14,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0xf8,0x80,0xf8,0x00,0x00,
+/* 4586 0x11ea "ᇪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,
+/* 4587 0x11eb "ᇫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x00,0x00,
+/* 4588 0x11ec "ᇬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 4589 0x11ed "ᇭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdc,0x44,0x44,0x44,0x44,0x00,0x00,
+/* 4590 0x11ee "ᇮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+/* 4591 0x11ef "ᇯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,
+/* 4592 0x11f0 "ᇰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 4593 0x11f1 "ᇱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x50,0x88,0x00,0x00,
+/* 4594 0x11f2 "ᇲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x45,0x39,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x88,0x04,0xfc,0x00,0x00,
+/* 4595 0x11f3 "ᇳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x14,0x14,0x14,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,
+/* 4596 0x11f4 "ᇴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x02,0x0f,0x03,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x40,0xf0,0xc0,0x20,0xc0,0x00,0x00,
+/* 4597 0x11f5 "ᇵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x7f,0x1c,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4598 0x11f6 "ᇶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x7f,0x1c,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,
+/* 4599 0x11f7 "ᇷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x7f,0x1c,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,
+/* 4600 0x11f8 "ᇸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x7f,0x1c,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,
+/* 4601 0x11f9 "ᇹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0f,0x03,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xe0,0x80,0x40,0x80,0x00,0x00,
+/* 4602 0x11fa "ᇺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4603 0x11fb "ᇻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,
+/* 4604 0x11fc "ᇼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0xfe,0x08,0x34,0xc2,0x00,0x00,
+/* 4605 0x11fd "ᇽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,
+/* 4606 0x11fe "ᇾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xfe,0x38,0x44,0x38,0x00,0x00,
+/* 4607 0x11ff "ᇿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 4608 0x1200 "ሀ" */
+0x00,0x00,0x00,0x01,0x30,0x30,0x30,0x30,0x30,0x30,0x31,0x31,0x1f,0x0e,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4609 0x1201 "ሁ" */
+0x00,0x00,0x00,0x01,0x30,0x30,0x30,0x30,0x30,0x30,0x31,0x31,0x1f,0x0e,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xfc,0xcc,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4610 0x1202 "ሂ" */
+0x00,0x00,0x06,0x0c,0x0c,0x0c,0x0c,0x07,0x03,0x00,0x01,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0x60,0x60,0x60,0x60,0xc0,0xc0,0xc0,0x80,0x00,0x30,0xf0,0x00,0x00,
+/* 4611 0x1203 "ሃ" */
+0x00,0x00,0x06,0x0c,0x0c,0x0c,0x0c,0x07,0x03,0x00,0x01,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0x60,0x60,0x60,0x60,0xc0,0xc0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4612 0x1204 "ሄ" */
+0x00,0x00,0x06,0x0c,0x0c,0x0c,0x0c,0x07,0x03,0x00,0x01,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0x60,0x60,0x60,0x60,0xc0,0xc0,0xc0,0xc0,0x40,0x20,0xe0,0x00,0x00,
+/* 4613 0x1205 "ህ" */
+0x00,0x00,0x00,0x18,0x18,0x1c,0x0e,0x06,0x0c,0x0c,0x0c,0x0c,0x07,0x03,0x00,0x00,
+0x00,0x00,0x00,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x60,0xe0,0xc0,0x00,0x00,
+/* 4614 0x1206 "ሆ" */
+0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0x30,0x30,0x31,0x31,0x1f,0x0e,0x00,0x00,
+0x00,0x00,0x00,0xf0,0xc8,0xd8,0xe0,0xc0,0xc0,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4615 0x1207 "ሇ" */
+0x00,0x00,0x00,0x00,0x0c,0x0c,0x0c,0x6c,0x7c,0x6c,0x0c,0x0c,0x07,0x03,0x00,0x00,
+0x00,0x00,0x00,0x3c,0x32,0x36,0x38,0x30,0x30,0x30,0x60,0x60,0xc0,0x80,0x00,0x00,
+/* 4616 0x1208 "ለ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4617 0x1209 "ሉ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x1e,0x1f,0x33,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf8,0x98,0x80,0x80,0x00,0x00,
+/* 4618 0x120a "ሊ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x1e,0x1f,0x33,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4619 0x120b "ላ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x07,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4620 0x120c "ሌ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x1e,0x1f,0x33,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 4621 0x120d "ል" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x07,0x0c,0x0c,0x18,0x18,0x1e,0x1b,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4622 0x120e "ሎ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x1e,0x1f,0x33,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xac,0xb8,0x80,0x80,0x00,0x00,
+/* 4623 0x120f "ሏ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x07,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x03,0x07,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0xfc,0x0e,
+/* 4624 0x1210 "ሐ" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x07,0x0d,0x0d,0x19,0x19,0x19,0x19,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xe0,0xb0,0xb0,0x98,0x98,0x98,0x98,0x00,0x00,
+/* 4625 0x1211 "ሑ" */
+0x00,0x00,0x06,0x06,0x06,0x06,0x06,0x1f,0x36,0x36,0x66,0x66,0x66,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x7e,0x66,0x60,0x60,0x00,0x00,
+/* 4626 0x1212 "ሒ" */
+0x00,0x00,0x06,0x06,0x06,0x06,0x06,0x1f,0x36,0x36,0x66,0x66,0x66,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x60,0x60,0x66,0x7e,0x00,0x00,
+/* 4627 0x1213 "ሓ" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x07,0x0d,0x0d,0x19,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xe0,0xb0,0xb0,0x98,0x18,0x18,0x18,0x00,0x00,
+/* 4628 0x1214 "ሔ" */
+0x00,0x00,0x06,0x06,0x06,0x06,0x06,0x1f,0x36,0x36,0x66,0x66,0x66,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x40,0x78,0x4c,0x78,0x00,0x00,
+/* 4629 0x1215 "ሕ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x07,0x0d,0x0d,0x19,0x19,0x19,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xe0,0xb0,0xb0,0x98,0x98,0x98,0x98,0x00,0x00,
+/* 4630 0x1216 "ሖ" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x07,0x0d,0x0d,0x19,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xe0,0xb0,0xb0,0x98,0x00,0x00,0x00,0x00,0x00,
+/* 4631 0x1217 "ሗ" */
+0x00,0x03,0x03,0x03,0x03,0x03,0x0f,0x1b,0x1b,0x33,0x00,0x00,0x00,0x01,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x60,0x60,0x30,0x30,0x30,0x30,0xfe,0x87,0x00,
+/* 4632 0x1218 "መ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x1f,0x11,0x31,0x23,0x26,0x3c,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0x24,0x64,0x44,0x4c,0x78,0x70,0x00,0x00,0x00,
+/* 4633 0x1219 "ሙ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x7f,0x44,0xc5,0x8d,0x99,0xf1,0xf1,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x90,0x9e,0x12,0x32,0xe0,0xc0,0x00,0x00,0x00,
+/* 4634 0x121a "ሚ" */
+0x00,0x00,0x1f,0x3f,0x62,0x42,0x45,0x7d,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0xf8,0x88,0x88,0x08,0xf8,0xf8,0x10,0x10,0x20,0x26,0x3e,0x00,0x00,
+/* 4635 0x121b "ማ" */
+0x00,0x00,0x0f,0x1f,0x31,0x21,0x22,0x3e,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0xfc,0x44,0x44,0x84,0xfc,0x7c,0x08,0x08,0x10,0x10,0x10,0x00,0x00,
+/* 4636 0x121c "ሜ" */
+0x00,0x00,0x1f,0x3f,0x62,0x42,0x45,0x7d,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0xf8,0x88,0x88,0x08,0xf8,0xf8,0x10,0x10,0x3c,0x26,0x3c,0x00,0x00,
+/* 4637 0x121d "ም" */
+0x00,0x00,0x1f,0x1f,0x32,0x22,0x22,0x22,0x3e,0x1e,0x02,0x06,0x0c,0x18,0x00,0x00,
+0x00,0x00,0xf0,0xf8,0x88,0x88,0x88,0xf8,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4638 0x121e "ሞ" */
+0x00,0x00,0x1f,0x1f,0x32,0x22,0x22,0x22,0x3e,0x1e,0x02,0x02,0x02,0x03,0x00,0x00,
+0x00,0x00,0xf0,0xf8,0x88,0x88,0x88,0xf8,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4639 0x121f "ሟ" */
+0x00,0x00,0x1f,0x3f,0x62,0x42,0x45,0x7d,0x38,0x00,0x00,0x00,0x00,0x00,0x01,0x03,
+0x00,0x00,0xf8,0xf8,0x88,0x88,0x08,0xf8,0xf8,0x10,0x10,0x30,0x20,0x20,0xf8,0x0c,
+/* 4640 0x1220 "ሠ" */
+0x00,0x00,0x00,0x00,0x09,0x19,0x19,0x19,0x19,0x19,0x19,0x0d,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x98,0x98,0x98,0x98,0x98,0xb0,0xf0,0x80,0x80,0x00,0x00,0x00,
+/* 4641 0x1221 "ሡ" */
+0x00,0x00,0x00,0x00,0x26,0x66,0x66,0x66,0x66,0x66,0x67,0x36,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 4642 0x1222 "ሢ" */
+0x00,0x00,0x66,0x66,0x66,0x66,0x66,0x76,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x66,0x7e,0x00,0x00,
+/* 4643 0x1223 "ሣ" */
+0x00,0x00,0x19,0x19,0x19,0x19,0x19,0x1d,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x90,0x98,0x98,0x98,0x98,0xb8,0xf8,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+/* 4644 0x1224 "ሤ" */
+0x00,0x00,0x33,0x33,0x33,0x33,0x33,0x3b,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x30,0x30,0x30,0x30,0x70,0xf0,0x30,0x30,0x38,0x64,0x78,0x00,0x00,
+/* 4645 0x1225 "ሥ" */
+0x00,0x00,0x19,0x19,0x19,0x19,0x19,0x1d,0x1f,0x1c,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x90,0x98,0x98,0x98,0x98,0xb8,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4646 0x1226 "ሦ" */
+0x00,0x00,0x19,0x19,0x19,0x19,0x19,0x1d,0x0f,0x03,0x03,0x07,0x0e,0x0c,0x00,0x00,
+0x00,0x00,0x98,0x98,0x98,0x98,0x98,0xb8,0xf0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4647 0x1227 "ሧ" */
+0x00,0x66,0x66,0x66,0x66,0x66,0x76,0x3f,0x00,0x00,0x00,0x00,0x00,0x03,0x07,0x00,
+0x00,0x40,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0xfc,0x0e,0x00,
+/* 4648 0x1228 "ረ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x07,0x0e,0x1c,0x18,0x18,0x1c,0x0f,0x07,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xe0,0xe0,0x00,0x00,
+/* 4649 0x1229 "ሩ" */
+0x00,0x00,0x03,0x03,0x07,0x0e,0x1c,0x18,0x30,0x38,0x1f,0x0f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x80,0x80,0x00,0x00,
+/* 4650 0x122a "ሪ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x07,0x0e,0x1c,0x18,0x18,0x1c,0x0f,0x07,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x60,0x70,0x30,0xe0,0xc0,0x00,0x00,
+/* 4651 0x122b "ራ" */
+0x00,0x00,0x03,0x03,0x03,0x06,0x0e,0x1c,0x38,0x30,0x30,0x39,0x1f,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xf8,0x98,0x80,0x00,0x00,0x00,
+/* 4652 0x122c "ሬ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x07,0x0e,0x1c,0x18,0x18,0x1c,0x0f,0x07,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x98,0xf0,0x00,0x00,
+/* 4653 0x122d "ር" */
+0x00,0x00,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0xe0,0x60,0x00,0x00,0x00,0x00,0x00,0x60,0xe0,0xc0,0x00,0x00,
+/* 4654 0x122e "ሮ" */
+0x00,0x00,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x98,0xf0,0x00,0x00,0x00,0x00,0x00,0x60,0xe0,0xc0,0x00,0x00,
+/* 4655 0x122f "ሯ" */
+0x00,0x00,0x30,0x1c,0x03,0x03,0x06,0x0e,0x1c,0x38,0x30,0x30,0x39,0x1f,0x0f,0x00,
+0x00,0x00,0x30,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xf8,0x98,0x80,0x00,0x00,
+/* 4656 0x1230 "ሰ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4657 0x1231 "ሱ" */
+0x00,0x00,0x04,0x04,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf8,0x98,0x80,0x80,0x80,0x00,0x00,
+/* 4658 0x1232 "ሲ" */
+0x00,0x00,0x04,0x04,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4659 0x1233 "ሳ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4660 0x1234 "ሴ" */
+0x00,0x00,0x02,0x02,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xe0,0xd0,0xc8,0xf8,0x00,0x00,
+/* 4661 0x1235 "ስ" */
+0x00,0x00,0x00,0x03,0x01,0x01,0x03,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4662 0x1236 "ሶ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 4663 0x1237 "ሷ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x01,0x03,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xf8,0x0c,
+/* 4664 0x1238 "ሸ" */
+0x00,0x00,0x30,0x1f,0x02,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4665 0x1239 "ሹ" */
+0x00,0x00,0x30,0x1f,0x02,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xfc,0xcc,0xcc,0xc0,0xc0,0x00,0x00,
+/* 4666 0x123a "ሺ" */
+0x00,0x00,0x30,0x1f,0x02,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4667 0x123b "ሻ" */
+0x00,0x00,0x18,0x0f,0x01,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0xe0,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4668 0x123c "ሼ" */
+0x00,0x00,0x30,0x1f,0x02,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4669 0x123d "ሽ" */
+0x00,0x00,0x18,0x0f,0x01,0x01,0x03,0x03,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x80,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4670 0x123e "ሾ" */
+0x00,0x00,0x18,0x0f,0x01,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x30,0xe0,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 4671 0x123f "ሿ" */
+0x00,0x00,0x30,0x1f,0x02,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x03,0x06,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf0,0x18,
+/* 4672 0x1240 "ቀ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4673 0x1241 "ቁ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0xf0,0x30,0x00,0x00,0x00,
+/* 4674 0x1242 "ቂ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0x00,0x30,0xf0,0x00,0x00,
+/* 4675 0x1243 "ቃ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x03,0x06,0x0c,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4676 0x1244 "ቄ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0xe0,0x30,0xe0,0x00,0x00,
+/* 4677 0x1245 "ቅ" */
+0x00,0x00,0x06,0x06,0x07,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0x00,0x00,
+/* 4678 0x1246 "ቆ" */
+0x00,0x00,0x01,0x02,0x02,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x60,0xc0,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4679 0x1247 "ቇ" */
+0x00,0x00,0x01,0x02,0x02,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x33,0x3f,0x30,0x00,
+0x00,0x00,0xc0,0x60,0xc0,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4680 0x1248 "ቈ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0xf8,0xac,0xb8,0x80,0x00,0x00,
+/* 4681 0x1249 "቉" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 4682 0x124a "ቊ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x36,0x66,0x66,0x3f,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x6c,0x6c,0xfc,0x07,0x03,0x00,0x00,0x00,0x00,0x00,
+/* 4683 0x124b "ቋ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x80,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0x80,0xe0,0x30,
+/* 4684 0x124c "ቌ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x80,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0xf0,0x98,0xf0,0x00,
+/* 4685 0x124d "ቍ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x36,0x66,0x66,0x3f,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x18,0x18,0xfe,0x66,0x60,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4686 0x124e "቎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4687 0x124f "቏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4688 0x1250 "ቐ" */
+0x00,0x00,0x0c,0x07,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xe0,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0x00,0x00,
+/* 4689 0x1251 "ቑ" */
+0x00,0x00,0x18,0x0f,0x03,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0xf0,0x30,0x00,0x00,
+/* 4690 0x1252 "ቒ" */
+0x00,0x00,0x18,0x0f,0x03,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0x30,0xf0,0x00,0x00,
+/* 4691 0x1253 "ቓ" */
+0x00,0x00,0x0c,0x07,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x03,0x06,0x00,0x00,
+0x00,0x00,0x30,0xe0,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 4692 0x1254 "ቔ" */
+0x00,0x00,0x18,0x0f,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0xe0,0x30,0xe0,0x00,0x00,
+/* 4693 0x1255 "ቕ" */
+0x00,0x00,0x30,0x1f,0x06,0x07,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x00,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x00,0x00,
+/* 4694 0x1256 "ቖ" */
+0x00,0x00,0x0c,0x07,0x01,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x18,0xf0,0x20,0x60,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x00,0x00,
+/* 4695 0x1257 "቗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4696 0x1258 "ቘ" */
+0x00,0x00,0x18,0x0f,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0xe0,0x30,0x30,0x60,0x80,0xf0,0x58,0x70,0x00,0x00,0x00,
+/* 4697 0x1259 "቙" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 4698 0x125a "ቚ" */
+0x00,0x00,0x30,0x1f,0x06,0x06,0x0f,0x36,0x66,0x66,0x3f,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x00,0x00,0xc0,0x6c,0x6c,0xfc,0x07,0x03,0x00,0x00,0x00,0x00,
+/* 4699 0x125b "ቛ" */
+0x00,0x00,0x0c,0x07,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x30,0xe0,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0xe0,0x30,
+/* 4700 0x125c "ቜ" */
+0x00,0x00,0x0c,0x07,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x30,0xe0,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0xf0,0x98,0xf0,0x00,
+/* 4701 0x125d "ቝ" */
+0x00,0x00,0x30,0x1f,0x06,0x06,0x0f,0x36,0x66,0x66,0x3f,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x18,0x18,0xfe,0x66,0x60,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4702 0x125e "቞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4703 0x125f "቟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4704 0x1260 "በ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4705 0x1261 "ቡ" */
+0x00,0x00,0x00,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf8,0x98,0x98,0x80,0x80,0x80,0x00,0x00,
+/* 4706 0x1262 "ቢ" */
+0x00,0x00,0x00,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4707 0x1263 "ባ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4708 0x1264 "ቤ" */
+0x00,0x00,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4709 0x1265 "ብ" */
+0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x03,0x3f,0x33,0x33,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0xf0,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+/* 4710 0x1266 "ቦ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4711 0x1267 "ቧ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,0x01,0x03,
+0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xf8,0x0c,
+/* 4712 0x1268 "ቨ" */
+0x00,0x00,0x30,0x1f,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4713 0x1269 "ቩ" */
+0x00,0x00,0x30,0x1f,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xfc,0xcc,0xcc,0xc0,0xc0,0x00,0x00,
+/* 4714 0x126a "ቪ" */
+0x00,0x00,0x30,0x1f,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4715 0x126b "ቫ" */
+0x00,0x00,0x30,0x1f,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4716 0x126c "ቬ" */
+0x00,0x00,0x60,0x3f,0x00,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 4717 0x126d "ቭ" */
+0x00,0x00,0x0c,0x07,0x00,0x01,0x03,0x06,0x06,0x7e,0x66,0x66,0x06,0x06,0x00,0x00,
+0x00,0x00,0x18,0xf0,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4718 0x126e "ቮ" */
+0x00,0x00,0x30,0x1f,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,0x00,0x00,
+/* 4719 0x126f "ቯ" */
+0x00,0x00,0x30,0x1f,0x00,0x07,0x0f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x03,0x06,
+0x00,0x00,0x60,0xc0,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf0,0x18,
+/* 4720 0x1270 "ተ" */
+0x00,0x00,0x07,0x03,0x03,0x03,0x3f,0x7f,0x63,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4721 0x1271 "ቱ" */
+0x00,0x00,0x07,0x03,0x03,0x03,0x3f,0x7f,0x63,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x18,0x00,0xf0,0x30,0x00,0x00,0x00,0x00,
+/* 4722 0x1272 "ቲ" */
+0x00,0x00,0x07,0x03,0x03,0x03,0x3f,0x7f,0x63,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x18,0x00,0x00,0x00,0x30,0xf0,0x00,0x00,
+/* 4723 0x1273 "ታ" */
+0x00,0x00,0x07,0x03,0x03,0x03,0x3f,0x7f,0x63,0x03,0x03,0x07,0x0e,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4724 0x1274 "ቴ" */
+0x00,0x00,0x07,0x03,0x03,0x03,0x3f,0x7f,0x63,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf8,0x18,0x00,0x00,0xe0,0x30,0xe0,0x00,0x00,
+/* 4725 0x1275 "ት" */
+0x00,0x00,0x06,0x07,0x03,0x01,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4726 0x1276 "ቶ" */
+0x00,0x00,0x03,0x03,0x01,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xe0,0x20,0x60,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4727 0x1277 "ቷ" */
+0x00,0x00,0x03,0x01,0x01,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x80,0x80,0x80,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x80,0x80,0xe0,0x30,
+/* 4728 0x1278 "ቸ" */
+0x00,0x00,0x18,0x1f,0x3f,0x31,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x18,0xf8,0xfc,0x8c,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4729 0x1279 "ቹ" */
+0x00,0x00,0x18,0x1f,0x3f,0x31,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x18,0xf8,0xfc,0x8c,0x80,0xf8,0xfc,0x8c,0x80,0xf8,0x98,0x80,0x00,0x00,
+/* 4730 0x127a "ቺ" */
+0x00,0x00,0x18,0x1f,0x3f,0x31,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x18,0xf8,0xfc,0x8c,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4731 0x127b "ቻ" */
+0x00,0x00,0x30,0x3f,0x7f,0x63,0x03,0x3f,0x7f,0x63,0x03,0x07,0x0e,0x1c,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x18,0x00,0xf0,0xf8,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4732 0x127c "ቼ" */
+0x00,0x00,0x30,0x3f,0x7f,0x63,0x03,0x3f,0x7f,0x63,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x18,0x00,0xf0,0xf8,0x18,0x00,0xe0,0x30,0xe0,0x00,0x00,
+/* 4733 0x127d "ች" */
+0x00,0x00,0x30,0x3f,0x7f,0x66,0x07,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0xe0,0x60,0x00,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x00,0x00,
+/* 4734 0x127e "ቾ" */
+0x00,0x00,0x0c,0x1f,0x1a,0x02,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xf8,0x58,0x40,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4735 0x127f "ቿ" */
+0x00,0x00,0x18,0x1f,0x3f,0x31,0x01,0x1f,0x3f,0x31,0x01,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x18,0xf8,0xfc,0x8c,0x80,0xf8,0xfc,0x8c,0x80,0x80,0x80,0x80,0xe0,0x30,
+/* 4736 0x1280 "ኀ" */
+0x00,0x00,0x01,0x01,0x01,0x1f,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4737 0x1281 "ኁ" */
+0x00,0x00,0x03,0x03,0x03,0x3f,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4738 0x1282 "ኂ" */
+0x00,0x00,0x03,0x03,0x03,0x3f,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4739 0x1283 "ኃ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x0c,0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xf0,0x30,0x30,0x30,0xe0,0x80,0x00,0x00,0x00,0x00,
+/* 4740 0x1284 "ኄ" */
+0x00,0x00,0x03,0x03,0x03,0x3f,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4741 0x1285 "ኅ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x06,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xf0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4742 0x1286 "ኆ" */
+0x00,0x00,0x01,0x03,0x06,0x3e,0x36,0x06,0x07,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0xe4,0x38,0x00,0x00,0x00,0xe0,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4743 0x1287 "ኇ" */
+0x00,0x00,0x01,0x03,0x06,0x3e,0x36,0x06,0x07,0x03,0x00,0x00,0x06,0x07,0x06,0x00,
+0x00,0x00,0xf8,0xe4,0x38,0x00,0x00,0x00,0xe0,0xe0,0x60,0x60,0x60,0xe0,0x00,0x00,
+/* 4744 0x1288 "ኈ" */
+0x00,0x00,0x06,0x06,0x06,0x7e,0x67,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xac,0xb8,0x80,0x80,0x80,0x00,0x00,
+/* 4745 0x1289 "኉" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 4746 0x128a "ኊ" */
+0x00,0x00,0x06,0x06,0x06,0x7e,0x67,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x98,0x98,0xf8,0x8e,0x86,0x80,0x80,0x00,0x00,
+/* 4747 0x128b "ኋ" */
+0x00,0x00,0x01,0x01,0x01,0x1f,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,
+0x00,0x00,0x80,0x80,0x80,0x80,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xf8,0x0c,
+/* 4748 0x128c "ኌ" */
+0x00,0x00,0x03,0x03,0x03,0x3f,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,
+/* 4749 0x128d "ኍ" */
+0x00,0x00,0x06,0x06,0x06,0x7e,0x67,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0xb0,0xfc,0x8c,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4750 0x128e "኎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4751 0x128f "኏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4752 0x1290 "ነ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4753 0x1291 "ኑ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0x80,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 4754 0x1292 "ኒ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x0f,0x03,0x03,0x03,0x03,0x06,0x06,0x06,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x60,0xe0,0x00,0x00,
+/* 4755 0x1293 "ና" */
+0x00,0x00,0x07,0x0f,0x18,0x30,0x38,0x1f,0x03,0x01,0x01,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0xc0,0xe0,0x60,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4756 0x1294 "ኔ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0x80,0x80,0xc0,0x20,0x60,0xc0,0x00,0x00,
+/* 4757 0x1295 "ን" */
+0x00,0x00,0x3f,0x3f,0x31,0x03,0x07,0x00,0x01,0x03,0x03,0x06,0x06,0x0c,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x80,0x00,0xc0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4758 0x1296 "ኖ" */
+0x00,0x00,0x07,0x0f,0x18,0x30,0x38,0x1f,0x03,0x01,0x01,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0xf0,0xc8,0x58,0x30,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4759 0x1297 "ኗ" */
+0x00,0x00,0x00,0x07,0x0f,0x18,0x30,0x38,0x1f,0x03,0x01,0x01,0x03,0x03,0x0f,0x18,
+0x00,0x00,0x00,0xc0,0xe0,0x60,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0xc0,0x60,
+/* 4760 0x1298 "ኘ" */
+0x00,0x00,0x0c,0x1f,0x11,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0xf8,0x88,0x80,0xe0,0x70,0x60,0x60,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4761 0x1299 "ኙ" */
+0x00,0x00,0x18,0x3f,0x23,0x03,0x03,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x60,0xf0,0x10,0x00,0xc0,0xe0,0xc0,0xf8,0x98,0x80,0x80,0x80,0x00,0x00,
+/* 4762 0x129a "ኚ" */
+0x00,0x00,0x18,0x3f,0x23,0x03,0x03,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x60,0xf0,0x10,0x00,0xc0,0xe0,0xc0,0xc0,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4763 0x129b "ኛ" */
+0x00,0x0c,0x1f,0x11,0x07,0x0f,0x18,0x30,0x38,0x1f,0x03,0x01,0x03,0x03,0x00,0x00,
+0x00,0x30,0xf8,0x88,0xc0,0xe0,0x60,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4764 0x129c "ኜ" */
+0x00,0x00,0x18,0x3f,0x23,0x03,0x03,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x60,0xf0,0x10,0x00,0xc0,0xe0,0xc0,0xc0,0xe0,0x90,0xb0,0xe0,0x00,0x00,
+/* 4765 0x129d "ኝ" */
+0x00,0x30,0x7f,0x46,0x1f,0x3f,0x31,0x03,0x07,0x00,0x01,0x03,0x03,0x03,0x00,0x00,
+0x00,0xc0,0xe0,0x20,0xc0,0x80,0x80,0x00,0xc0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4766 0x129e "ኞ" */
+0x00,0x0c,0x1f,0x11,0x07,0x0f,0x18,0x30,0x38,0x1f,0x03,0x01,0x03,0x03,0x00,0x00,
+0x00,0x60,0xf0,0x10,0xf0,0xc8,0x58,0x30,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 4767 0x129f "ኟ" */
+0x00,0x0c,0x1f,0x11,0x07,0x0f,0x18,0x30,0x38,0x1f,0x03,0x01,0x03,0x03,0x0f,0x18,
+0x00,0x30,0xf8,0x88,0xc0,0xe0,0x60,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0xc0,0x60,
+/* 4768 0x12a0 "አ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x03,0x03,0x06,0x0e,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4769 0x12a1 "ኡ" */
+0x00,0x00,0x18,0x18,0x18,0x1e,0x06,0x0e,0x0f,0x1b,0x39,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xf8,0x98,0x80,0x80,0x00,0x00,
+/* 4770 0x12a2 "ኢ" */
+0x00,0x00,0x18,0x18,0x18,0x1e,0x06,0x0e,0x0f,0x1b,0x39,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4771 0x12a3 "ኣ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x03,0x06,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4772 0x12a4 "ኤ" */
+0x00,0x00,0x18,0x18,0x18,0x1e,0x06,0x0e,0x0f,0x1b,0x39,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 4773 0x12a5 "እ" */
+0x00,0x00,0x0c,0x0c,0x0e,0x06,0x03,0x03,0x07,0x0e,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4774 0x12a6 "ኦ" */
+0x00,0x00,0x06,0x06,0x06,0x07,0x01,0x03,0x06,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xe0,0x60,0x60,0x60,0x00,0x00,0x00,0x00,
+/* 4775 0x12a7 "ኧ" */
+0x00,0x18,0x1f,0x36,0x06,0x07,0x01,0x03,0x03,0x06,0x0e,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0xc0,0xc0,0x60,0x00,0x80,0x80,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4776 0x12a8 "ከ" */
+0x00,0x00,0x00,0x18,0x19,0x1f,0x1e,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4777 0x12a9 "ኩ" */
+0x00,0x00,0x00,0x60,0x67,0x7f,0x78,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4778 0x12aa "ኪ" */
+0x00,0x00,0x00,0x60,0x67,0x7f,0x78,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4779 0x12ab "ካ" */
+0x00,0x00,0x00,0x18,0x19,0x1f,0x1e,0x06,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4780 0x12ac "ኬ" */
+0x00,0x00,0x00,0x60,0x67,0x7f,0x78,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4781 0x12ad "ክ" */
+0x00,0x00,0x00,0x18,0x19,0x1b,0x1e,0x0c,0x0e,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4782 0x12ae "ኮ" */
+0x00,0x00,0x00,0x18,0x19,0x1f,0x1e,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 4783 0x12af "ኯ" */
+0x00,0x00,0x00,0x0c,0x0c,0x0f,0x0f,0x03,0x33,0x3f,0x33,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 4784 0x12b0 "ኰ" */
+0x00,0x00,0x00,0x60,0x66,0x7f,0x79,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xac,0xb8,0x80,0x80,0x80,0x00,0x00,
+/* 4785 0x12b1 "኱" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 4786 0x12b2 "ኲ" */
+0x00,0x00,0x00,0x60,0x66,0x7f,0x79,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x98,0x98,0xf8,0x8e,0x86,0x80,0x80,0x00,0x00,
+/* 4787 0x12b3 "ኳ" */
+0x00,0x00,0x00,0x18,0x19,0x1f,0x1e,0x06,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0xfc,0x86,
+/* 4788 0x12b4 "ኴ" */
+0x00,0x00,0x00,0x60,0x67,0x7f,0x78,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x03,0x06,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,
+/* 4789 0x12b5 "ኵ" */
+0x00,0x00,0x00,0x60,0x66,0x7f,0x79,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x30,0xfc,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4790 0x12b6 "኶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 4791 0x12b7 "኷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4792 0x12b8 "ኸ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0d,0x0f,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4793 0x12b9 "ኹ" */
+0x00,0x00,0xc3,0x7e,0x18,0x1b,0x1f,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x7e,0x66,0x60,0x60,0x60,0x00,0x00,
+/* 4794 0x12ba "ኺ" */
+0x00,0x00,0xc3,0x7e,0x18,0x1b,0x1f,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0x60,0x66,0x7e,0x00,0x00,
+/* 4795 0x12bb "ኻ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0d,0x0f,0x06,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4796 0x12bc "ኼ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0d,0x0f,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x3e,0x33,0x3e,0x00,0x00,
+/* 4797 0x12bd "ኽ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0e,0x0f,0x03,0x03,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xe0,0xf0,0x18,0x98,0x98,0x98,0x98,0x98,0x98,0x00,0x00,
+/* 4798 0x12be "ኾ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0d,0x0f,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xc0,0xe0,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 4799 0x12bf "኿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4800 0x12c0 "ዀ" */
+0x00,0x00,0xc3,0x7e,0x18,0x1b,0x1f,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x7e,0x6b,0x6e,0x60,0x60,0x60,0x00,0x00,
+/* 4801 0x12c1 "዁" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 4802 0x12c2 "ዂ" */
+0x00,0x00,0xc3,0x7e,0x18,0x1b,0x1f,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xcc,0xcc,0xfc,0xc7,0xc3,0xc0,0xc0,0x00,0x00,
+/* 4803 0x12c3 "ዃ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0d,0x0f,0x06,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x80,0x00,0x00,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0xfc,0x86,
+/* 4804 0x12c4 "ዄ" */
+0x00,0x00,0x61,0x3f,0x0c,0x0d,0x0f,0x06,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x80,0x00,0x00,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x3e,0x33,0xfe,0x80,
+/* 4805 0x12c5 "ዅ" */
+0x00,0x00,0xc3,0x7e,0x18,0x1b,0x1f,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x8c,0xff,0x63,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4806 0x12c6 "዆" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 4807 0x12c7 "዇" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4808 0x12c8 "ወ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x1d,0x31,0x31,0x33,0x33,0x3b,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0xb8,0x98,0x98,0x18,0x30,0x70,0xc0,0x00,0x00,0x00,
+/* 4809 0x12c9 "ዉ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x76,0xc6,0xc6,0xcc,0xcc,0xed,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xe0,0x60,0x60,0x60,0xe0,0xc6,0xfc,0x0c,0x00,0x00,
+/* 4810 0x12ca "ዊ" */
+0x00,0x00,0x0f,0x1d,0x31,0x31,0x33,0x3b,0x1f,0x03,0x03,0x07,0x06,0x07,0x00,0x00,
+0x00,0x00,0xf0,0xb8,0x98,0x98,0x18,0xb0,0xe0,0x00,0x00,0x00,0x60,0xe0,0x00,0x00,
+/* 4811 0x12cb "ዋ" */
+0x00,0x00,0x0f,0x1d,0x31,0x31,0x33,0x3b,0x1f,0x03,0x03,0x03,0x03,0x07,0x00,0x00,
+0x00,0x00,0xf0,0xb8,0x98,0x98,0x18,0xb0,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4812 0x12cc "ዌ" */
+0x00,0x00,0x0f,0x1d,0x31,0x31,0x33,0x3b,0x1f,0x03,0x03,0x07,0x06,0x07,0x00,0x00,
+0x00,0x00,0xf0,0xb8,0x98,0x98,0x18,0xb0,0xe0,0x00,0x00,0x80,0x60,0xc0,0x00,0x00,
+/* 4813 0x12cd "ው" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x76,0xc6,0xc6,0xcc,0xcc,0xed,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xe0,0x60,0x7e,0x66,0xc2,0xc0,0x00,0x00,0x00,0x00,
+/* 4814 0x12ce "ዎ" */
+0x00,0x00,0x0f,0x1d,0x31,0x31,0x33,0x3b,0x1f,0x03,0x06,0x0c,0x18,0x18,0x00,0x00,
+0x00,0x00,0xf0,0xb8,0x98,0x98,0x18,0xb0,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4815 0x12cf "ዏ" */
+0x00,0x00,0x03,0x07,0x6c,0x7c,0x6c,0x0e,0x07,0x00,0x01,0x03,0x06,0x06,0x00,0x00,
+0x00,0x00,0xfc,0x6e,0x66,0x66,0xc6,0xec,0xf8,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4816 0x12d0 "ዐ" */
+0x00,0x00,0x00,0x01,0x06,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x07,0x06,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0xf0,0x00,0x00,0x00,
+/* 4817 0x12d1 "ዑ" */
+0x00,0x00,0x00,0x07,0x18,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x1f,0x18,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0x00,0x00,0x00,
+/* 4818 0x12d2 "ዒ" */
+0x00,0x00,0x00,0x1f,0x31,0x61,0x61,0x61,0x3f,0x00,0x00,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xc0,0xc0,0xc0,0x80,0x98,0xf8,0x00,0x00,
+/* 4819 0x12d3 "ዓ" */
+0x00,0x00,0x00,0x07,0x0c,0x18,0x18,0x18,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x60,0x60,0x60,0x60,0xf0,0x30,0x30,0x30,0x60,0x60,0x00,0x00,
+/* 4820 0x12d4 "ዔ" */
+0x00,0x00,0x00,0x1f,0x31,0x61,0x61,0x61,0x3f,0x00,0x00,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xc0,0xc0,0xc0,0xf0,0x98,0xf0,0x00,0x00,
+/* 4821 0x12d5 "ዕ" */
+0x00,0x01,0x01,0x01,0x07,0x0e,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x07,0x06,0x00,0x00,
+0x00,0x80,0x80,0x80,0xe0,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0xf0,0x00,0x00,0x00,
+/* 4822 0x12d6 "ዖ" */
+0x00,0x00,0x03,0x06,0x0c,0x0c,0x0c,0x0e,0x07,0x03,0x07,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0xc0,0x60,0x30,0x30,0x30,0x70,0xe0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4823 0x12d7 "዗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4824 0x12d8 "ዘ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x60,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4825 0x12d9 "ዙ" */
+0x00,0x00,0x31,0x31,0x31,0x31,0x31,0x3f,0x3f,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xf8,0x98,0x98,0x80,0x80,0x00,0x00,
+/* 4826 0x12da "ዚ" */
+0x00,0x00,0x31,0x31,0x31,0x31,0x31,0x3f,0x3f,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4827 0x12db "ዛ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4828 0x12dc "ዜ" */
+0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4829 0x12dd "ዝ" */
+0x00,0x00,0x1c,0x36,0x36,0x06,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x30,0x30,0x30,0x30,0x30,0xf0,0xf0,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4830 0x12de "ዞ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 4831 0x12df "ዟ" */
+0x00,0x00,0x0c,0x0c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x00,0x00,0x00,0x01,0x03,
+0x00,0x00,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0xf8,0x0c,
+/* 4832 0x12e0 "ዠ" */
+0x00,0x00,0x1c,0x36,0x36,0x06,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x38,0x6c,0x6c,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4833 0x12e1 "ዡ" */
+0x00,0x00,0x38,0x6c,0x6c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x70,0xd8,0xd8,0xc0,0xc0,0xc0,0xc0,0xfc,0xcc,0xcc,0xc0,0xc0,0x00,0x00,
+/* 4834 0x12e2 "ዢ" */
+0x00,0x00,0x38,0x6c,0x6c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x70,0xd8,0xd8,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4835 0x12e3 "ዣ" */
+0x00,0x00,0x1c,0x36,0x36,0x06,0x07,0x07,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x38,0x6c,0x6c,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4836 0x12e4 "ዤ" */
+0x00,0x00,0x38,0x6c,0x6c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x70,0xd8,0xd8,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4837 0x12e5 "ዥ" */
+0x00,0x61,0x3f,0x0c,0x1c,0x36,0x36,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x80,0x00,0x00,0x38,0x6c,0x6c,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4838 0x12e6 "ዦ" */
+0x00,0x00,0x1c,0x36,0x36,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x38,0x6c,0x6c,0x60,0xe0,0xe0,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 4839 0x12e7 "ዧ" */
+0x00,0x00,0x1c,0x36,0x36,0x06,0x07,0x07,0x06,0x06,0x06,0x00,0x00,0x00,0x01,0x03,
+0x00,0x00,0x38,0x6c,0x6c,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0xf8,0x0c,
+/* 4840 0x12e8 "የ" */
+0x00,0x00,0x03,0x06,0x0c,0x0c,0x0c,0x0c,0x0e,0x07,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4841 0x12e9 "ዩ" */
+0x00,0x00,0x03,0x06,0x0c,0x0c,0x0c,0x0c,0x0e,0x07,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0xc0,0x80,0x00,0xf0,0x30,0x00,0x00,0x00,
+/* 4842 0x12ea "ዪ" */
+0x00,0x00,0x07,0x0d,0x18,0x18,0x18,0x18,0x1d,0x0f,0x06,0x07,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x80,0x00,0x60,0xf8,0x18,0x00,0x00,0x00,
+/* 4843 0x12eb "ያ" */
+0x00,0x00,0x01,0x03,0x06,0x06,0x06,0x06,0x07,0x03,0x01,0x00,0x01,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x60,0x30,0x30,0x30,0x60,0xc0,0x80,0xc0,0x60,0xc0,0x80,0x00,0x00,
+/* 4844 0x12ec "ዬ" */
+0x00,0x00,0x07,0x0d,0x18,0x18,0x18,0x18,0x1d,0x0f,0x06,0x07,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x80,0x00,0xf0,0x98,0xf0,0x00,0x00,0x00,
+/* 4845 0x12ed "ይ" */
+0x00,0x00,0x00,0x07,0x0c,0x18,0x18,0x18,0x0d,0x0f,0x07,0x03,0x3e,0x70,0x60,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x80,0x30,0x30,0xe0,0x00,0x00,0x00,0x00,
+/* 4846 0x12ee "ዮ" */
+0x00,0x00,0x0e,0x1b,0x31,0x31,0x31,0x31,0x3b,0x1e,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xf8,0x98,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4847 0x12ef "ዯ" */
+0x00,0x00,0x03,0x06,0x0c,0x0c,0x0c,0x0c,0x6e,0x7f,0x63,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x60,0x7e,0x66,0x60,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4848 0x12f0 "ደ" */
+0x00,0x00,0x03,0x07,0x0c,0x0c,0x0c,0x0f,0x06,0x03,0x03,0x01,0x1f,0x18,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x40,0x40,0xc0,0x80,0x00,0x00,0x00,0x80,0xf8,0x18,0x00,0x00,
+/* 4849 0x12f1 "ዱ" */
+0x00,0x00,0x07,0x0f,0x18,0x19,0x1f,0x0c,0x06,0x1f,0x30,0x30,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0xc0,0xc0,0xfc,0x8c,0x80,0x00,0x00,
+/* 4850 0x12f2 "ዲ" */
+0x00,0x00,0x07,0x0f,0x18,0x19,0x1f,0x0c,0x06,0x1f,0x30,0x30,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0xc0,0xc0,0xc0,0x98,0xf8,0x00,0x00,
+/* 4851 0x12f3 "ዳ" */
+0x00,0x00,0x01,0x03,0x06,0x06,0x07,0x03,0x01,0x0f,0x0c,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xe0,0x20,0x60,0xc0,0x00,0x80,0xf0,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4852 0x12f4 "ዴ" */
+0x00,0x00,0x07,0x0f,0x18,0x18,0x19,0x1f,0x0c,0x06,0x06,0x03,0x3f,0x30,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0xf0,0x98,0xf0,0x00,0x00,
+/* 4853 0x12f5 "ድ" */
+0x00,0x00,0x07,0x0f,0x18,0x18,0x19,0x1f,0x0c,0x06,0x06,0x03,0x3f,0x30,0x00,0x00,
+0x00,0x00,0x00,0x80,0xf8,0x98,0x80,0x00,0x00,0x00,0x00,0x00,0xf0,0x30,0x00,0x00,
+/* 4854 0x12f6 "ዶ" */
+0x00,0x00,0x01,0x03,0x06,0x06,0x07,0x03,0x07,0x0c,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0xc0,0xe0,0x20,0x60,0xc0,0x80,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4855 0x12f7 "ዷ" */
+0x00,0x00,0x01,0x03,0x06,0x06,0x07,0x03,0x01,0x0f,0x0c,0x0c,0x00,0x00,0x00,0x01,
+0x00,0x00,0xc0,0xe0,0x20,0x60,0xc0,0x00,0x80,0xf0,0x30,0x30,0x30,0x30,0xfc,0x86,
+/* 4856 0x12f8 "ዸ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0f,0x06,0x03,0x01,0x0f,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x40,0xc0,0x80,0x00,0x00,0x80,0xf0,0x30,0x00,0x00,
+/* 4857 0x12f9 "ዹ" */
+0x00,0x00,0x02,0x02,0x07,0x0f,0x18,0x19,0x1f,0x0c,0x1f,0x30,0x31,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0xc0,0xfc,0x8c,0x80,0x00,0x00,
+/* 4858 0x12fa "ዺ" */
+0x00,0x00,0x02,0x02,0x07,0x0f,0x18,0x19,0x1f,0x0c,0x1f,0x30,0x31,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0xc0,0xc0,0x98,0xf8,0x00,0x00,
+/* 4859 0x12fb "ዻ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0f,0x06,0x1f,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x40,0xc0,0x80,0x00,0xe0,0x60,0x60,0x60,0x00,0x00,
+/* 4860 0x12fc "ዼ" */
+0x00,0x00,0x04,0x04,0x0e,0x1f,0x31,0x33,0x3e,0x18,0x0c,0x06,0x3f,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x98,0xf0,0x00,0x00,
+/* 4861 0x12fd "ዽ" */
+0x00,0x00,0x02,0x02,0x07,0x0f,0x18,0x19,0x1f,0x0c,0x06,0x03,0x1f,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xf8,0x98,0x00,0x00,0x00,0x00,0xe0,0x60,0x00,0x00,
+/* 4862 0x12fe "ዾ" */
+0x00,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x0f,0x07,0x0c,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x40,0xc0,0x80,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 4863 0x12ff "ዿ" */
+0x00,0x00,0x01,0x03,0x06,0x06,0x07,0x03,0x01,0x0f,0x0c,0x0c,0x00,0x00,0x00,0x01,
+0x80,0x80,0xc0,0xe0,0x20,0x60,0xc0,0x00,0x80,0xf0,0x30,0x30,0x30,0x30,0xfc,0x86,
+/* 4864 0x1300 "ጀ" */
+0x00,0x30,0x1f,0x03,0x07,0x0c,0x0c,0x0c,0x07,0x06,0x07,0x03,0x1f,0x18,0x00,0x00,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0x40,0xc0,0x80,0x00,0x00,0x00,0xe0,0x60,0x00,0x00,
+/* 4865 0x1301 "ጁ" */
+0x00,0x60,0x3f,0x06,0x0f,0x19,0x19,0x0f,0x06,0x1f,0x30,0x30,0x01,0x01,0x00,0x00,
+0x00,0x60,0xc0,0x00,0x00,0x80,0x80,0x00,0x00,0xc0,0xc0,0xfc,0x8c,0x80,0x00,0x00,
+/* 4866 0x1302 "ጂ" */
+0x00,0x60,0x3f,0x06,0x0f,0x19,0x19,0x0f,0x06,0x1f,0x30,0x30,0x01,0x01,0x00,0x00,
+0x00,0x60,0xc0,0x00,0x00,0x80,0x80,0x00,0x00,0xc0,0xc0,0xc0,0x98,0xf8,0x00,0x00,
+/* 4867 0x1303 "ጃ" */
+0x00,0x30,0x1f,0x03,0x07,0x0c,0x0c,0x07,0x03,0x1f,0x18,0x18,0x00,0x00,0x00,0x00,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0xc0,0x80,0x00,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4868 0x1304 "ጄ" */
+0x00,0x60,0x3f,0x06,0x0f,0x19,0x18,0x19,0x0f,0x0c,0x0e,0x07,0x3f,0x30,0x00,0x00,
+0x00,0x60,0xc0,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0xf0,0x98,0xf0,0x00,0x00,
+/* 4869 0x1305 "ጅ" */
+0x00,0x30,0x1f,0x03,0x07,0x0c,0x0c,0x0c,0x07,0x06,0x07,0x03,0x1f,0x18,0x00,0x00,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0x7c,0xcc,0x80,0x00,0x00,0x00,0xe0,0x60,0x00,0x00,
+/* 4870 0x1306 "ጆ" */
+0x00,0x30,0x1f,0x03,0x07,0x0c,0x0c,0x07,0x07,0x0c,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0xc0,0x80,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4871 0x1307 "ጇ" */
+0x00,0x30,0x1f,0x03,0x07,0x0c,0x0c,0x07,0x03,0x1f,0x18,0x18,0x00,0x00,0x03,0x07,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0xc0,0x80,0x00,0xe0,0x60,0x60,0x60,0x60,0xfc,0x0e,
+/* 4872 0x1308 "ገ" */
+0x00,0x00,0x00,0x0f,0x18,0x18,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4873 0x1309 "ጉ" */
+0x00,0x00,0x00,0x1f,0x31,0x31,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xf8,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 4874 0x130a "ጊ" */
+0x00,0x00,0x00,0x0f,0x18,0x18,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4875 0x130b "ጋ" */
+0x00,0x00,0x00,0x07,0x0f,0x0c,0x00,0x00,0x00,0x00,0x01,0x07,0x0e,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x80,0xe0,0x60,0x60,0x60,0x60,0xc0,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 4876 0x130c "ጌ" */
+0x00,0x00,0x00,0x0f,0x18,0x18,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 4877 0x130d "ግ" */
+0x00,0x00,0x00,0x0f,0x19,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0xb0,0x30,0x30,0x30,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4878 0x130e "ጎ" */
+0x00,0x00,0x01,0x01,0x01,0x07,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x60,0x60,0x60,0x40,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4879 0x130f "ጏ" */
+0x00,0x00,0x01,0x01,0x01,0x07,0x0c,0x0c,0x00,0x00,0x00,0x00,0x0c,0x0f,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x60,0x60,0x60,0x40,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4880 0x1310 "ጐ" */
+0x00,0x00,0x00,0x1f,0x31,0x31,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf8,0xac,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 4881 0x1311 "጑" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 4882 0x1312 "ጒ" */
+0x00,0x00,0x00,0x1f,0x31,0x31,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xb0,0xb0,0xf0,0x1c,0x0c,0x00,0x00,0x00,0x00,
+/* 4883 0x1313 "ጓ" */
+0x00,0x00,0x00,0x07,0x0c,0x0c,0x00,0x07,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4884 0x1314 "ጔ" */
+0x00,0x00,0x00,0x0f,0x18,0x18,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x07,0x0c,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x80,0x80,0xf0,0x98,0xf0,0x00,
+/* 4885 0x1315 "ጕ" */
+0x00,0x00,0x00,0x1f,0x31,0x31,0x01,0x01,0x01,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0xb0,0xfc,0x8c,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4886 0x1316 "጖" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 4887 0x1317 "጗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 4888 0x1318 "ጘ" */
+0x00,0x00,0x0c,0x07,0x00,0x07,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0xe0,0x00,0xc0,0x60,0x60,0x60,0x40,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4889 0x1319 "ጙ" */
+0x00,0x00,0x30,0x1f,0x00,0x1f,0x31,0x31,0x01,0x01,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0xf8,0x18,0x00,0x00,0x00,0x00,
+/* 4890 0x131a "ጚ" */
+0x00,0x00,0x18,0x0f,0x00,0x0f,0x18,0x18,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x80,0xc0,0xc0,0xc0,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4891 0x131b "ጛ" */
+0x00,0x00,0x0c,0x07,0x00,0x03,0x07,0x04,0x00,0x00,0x00,0x03,0x07,0x0e,0x00,0x00,
+0x00,0x00,0x30,0xe0,0x00,0xc0,0xf0,0x30,0x30,0x30,0xe0,0xc0,0x00,0x00,0x00,0x00,
+/* 4892 0x131c "ጜ" */
+0x00,0x00,0x18,0x0f,0x00,0x0f,0x18,0x18,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x80,0xc0,0xc0,0xc0,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 4893 0x131d "ጝ" */
+0x00,0x00,0x18,0x0f,0x00,0x0f,0x19,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0xe0,0xb0,0x30,0x30,0x20,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4894 0x131e "ጞ" */
+0x00,0x00,0x0c,0x07,0x01,0x07,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0xc0,0x00,0xc0,0x60,0x60,0x60,0x40,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4895 0x131f "ጟ" */
+0x00,0x00,0x18,0x0f,0x02,0x0f,0x18,0x18,0x00,0x00,0x01,0x01,0x01,0x0f,0x0c,0x00,
+0x00,0x00,0x60,0xc0,0x00,0x80,0xc0,0xc0,0xc0,0x80,0x80,0x80,0x80,0xf0,0x30,0x00,
+/* 4896 0x1320 "ጠ" */
+0x00,0x00,0x00,0x00,0x07,0x0d,0x0d,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x60,0x60,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4897 0x1321 "ጡ" */
+0x00,0x00,0x00,0x00,0x1f,0x35,0x35,0x64,0x64,0x64,0x64,0x64,0x64,0x64,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4898 0x1322 "ጢ" */
+0x00,0x00,0x00,0x00,0x1f,0x35,0x35,0x64,0x64,0x64,0x64,0x64,0x64,0x64,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4899 0x1323 "ጣ" */
+0x00,0x00,0x00,0x07,0x0d,0x0d,0x19,0x19,0x19,0x19,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x60,0x60,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 4900 0x1324 "ጤ" */
+0x00,0x00,0x00,0x1f,0x35,0x35,0x64,0x64,0x64,0x64,0x64,0x64,0x64,0x64,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4901 0x1325 "ጥ" */
+0x00,0x00,0x00,0x0f,0x1f,0x13,0x33,0x33,0x31,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xe0,0xf0,0x30,0x18,0x98,0x98,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4902 0x1326 "ጦ" */
+0x00,0x00,0x00,0x07,0x0d,0x0d,0x19,0x19,0x19,0x19,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x60,0x60,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4903 0x1327 "ጧ" */
+0x00,0x00,0x00,0x07,0x0d,0x0d,0x19,0x19,0x19,0x19,0x00,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x00,0xc0,0x60,0x60,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0xfc,0x86,
+/* 4904 0x1328 "ጨ" */
+0x00,0x00,0x00,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x30,0x30,0x30,0x38,0xb6,0xb2,0xbe,0x00,0x00,
+/* 4905 0x1329 "ጩ" */
+0x00,0x00,0x00,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x30,0x3f,0x33,0x38,0xb4,0xb2,0xbe,0x00,0x00,
+/* 4906 0x132a "ጪ" */
+0x00,0x00,0x00,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x30,0x30,0x30,0x30,0xb0,0xb3,0xbf,0x00,0x00,
+/* 4907 0x132b "ጫ" */
+0x00,0x00,0x0f,0x1f,0x31,0x61,0x71,0x69,0x65,0x7d,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0xf0,0x18,0x18,0x98,0x58,0x58,0xd8,0x18,0x34,0x32,0x3e,0x00,0x00,
+/* 4908 0x132c "ጬ" */
+0x00,0x00,0x00,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x3f,0x39,0x37,0x30,0xbc,0xb2,0xbe,0x00,0x00,
+/* 4909 0x132d "ጭ" */
+0x00,0x00,0x00,0x1f,0x7f,0xc6,0xe6,0x97,0xf3,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xe0,0x30,0x38,0x24,0x3c,0x00,0x80,0x40,0x20,0xe0,0x00,0x00,
+/* 4910 0x132e "ጮ" */
+0x00,0x00,0x0f,0x1f,0x1a,0x32,0x23,0x62,0x62,0x63,0x70,0x68,0x64,0x7c,0x00,0x00,
+0x00,0x00,0xe0,0xf0,0x18,0x18,0x18,0x94,0x52,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4911 0x132f "ጯ" */
+0x00,0x00,0x00,0x0f,0x1f,0x31,0x61,0x71,0x69,0x65,0x7d,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x00,0xe0,0xf0,0x18,0x18,0x98,0x58,0x58,0xd8,0x18,0x30,0x30,0xfc,0x86,
+/* 4912 0x1330 "ጰ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x06,0x06,0x03,0x07,0x0e,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xc0,0x60,0x60,0xc0,0xe0,0x70,0x30,0x30,0x30,0x00,0x00,
+/* 4913 0x1331 "ጱ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xfc,0xcc,0xc0,0x00,0x00,
+/* 4914 0x1332 "ጲ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4915 0x1333 "ጳ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x06,0x03,0x07,0x0e,0x0c,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xc0,0x60,0xc0,0xe0,0x70,0x70,0x30,0x30,0x30,0x00,0x00,
+/* 4916 0x1334 "ጴ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 4917 0x1335 "ጵ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x98,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4918 0x1336 "ጶ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x06,0x03,0x07,0x0e,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xc0,0x60,0xc0,0xe0,0x70,0x30,0x30,0x00,0x00,0x00,0x00,
+/* 4919 0x1337 "ጷ" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x00,0x00,0x01,0x03,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0xc0,0xc0,0xe0,0x60,0x60,0x60,0xf8,0x0c,
+/* 4920 0x1338 "ጸ" */
+0x00,0x00,0x00,0x00,0x01,0x03,0x06,0x06,0x03,0x07,0x0e,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0xc0,0xe0,0x70,0x30,0x30,0x30,0x00,0x00,
+/* 4921 0x1339 "ጹ" */
+0x00,0x00,0x00,0x00,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xfc,0xcc,0xc0,0x00,0x00,
+/* 4922 0x133a "ጺ" */
+0x00,0x00,0x00,0x00,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 4923 0x133b "ጻ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x80,0xc0,0xc0,0xe0,0x60,0x60,0x60,0x00,0x00,
+/* 4924 0x133c "ጼ" */
+0x00,0x00,0x00,0x00,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xf0,0xd8,0xf0,0x00,0x00,
+/* 4925 0x133d "ጽ" */
+0x00,0x00,0x00,0x00,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x98,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 4926 0x133e "ጾ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x80,0xc0,0xe0,0x60,0x60,0x00,0x00,0x00,0x00,
+/* 4927 0x133f "ጿ" */
+0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x00,0x00,0x01,0x03,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x80,0xc0,0xc0,0xe0,0x60,0x60,0x60,0xf8,0x0c,
+/* 4928 0x1340 "ፀ" */
+0x00,0x00,0x00,0x01,0x06,0x0c,0x0c,0x0c,0x0f,0x0c,0x0c,0x0c,0x07,0x06,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x30,0x30,0x30,0x30,0xf0,0x30,0x30,0x30,0xf0,0x00,0x00,0x00,
+/* 4929 0x1341 "ፁ" */
+0x00,0x00,0x00,0x07,0x18,0x30,0x30,0x30,0x3f,0x30,0x30,0x30,0x1f,0x18,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0x00,0x00,0x00,
+/* 4930 0x1342 "ፂ" */
+0x00,0x00,0x7e,0xc3,0xc3,0xff,0xc3,0xc3,0x7f,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xf0,0x00,0x00,
+/* 4931 0x1343 "ፃ" */
+0x00,0x00,0x7e,0xc3,0xc3,0xff,0xc3,0xc3,0x7f,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4932 0x1344 "ፄ" */
+0x00,0x00,0x7e,0xc3,0xc3,0xff,0xc3,0xc3,0x7f,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x30,0xe0,0x00,0x00,
+/* 4933 0x1345 "ፅ" */
+0x00,0x01,0x01,0x01,0x07,0x0e,0x0c,0x0c,0x0f,0x0c,0x0c,0x0c,0x07,0x06,0x00,0x00,
+0x00,0x80,0x80,0x80,0xe0,0x30,0x30,0x30,0xf0,0x30,0x30,0x30,0xf0,0x00,0x00,0x00,
+/* 4934 0x1346 "ፆ" */
+0x00,0x00,0x03,0x06,0x0c,0x0f,0x0c,0x0e,0x07,0x03,0x07,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0xc0,0x60,0x30,0xf0,0x30,0x70,0xe0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4935 0x1347 "ፇ" */
+0x00,0x00,0x01,0x03,0x36,0x3f,0x36,0x07,0x03,0x01,0x03,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0xe0,0x30,0x18,0xf8,0x18,0x38,0xf0,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4936 0x1348 "ፈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x06,0x0f,0x19,0x18,0x0f,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x40,0xc0,0x80,0x00,0x00,0x00,0x80,0x88,0xf8,0xe8,0x00,0x00,
+/* 4937 0x1349 "ፉ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x06,0x0c,0x1f,0x19,0x19,0x1f,0x03,0x06,0x06,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x10,0xf0,0xc0,0x00,0x00,0x00,
+/* 4938 0x134a "ፊ" */
+0x00,0x00,0x00,0x01,0x00,0x01,0x03,0x06,0x0c,0x1e,0x33,0x31,0x1f,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x30,0x10,0x30,0xe0,0x80,0x00,0x00,
+/* 4939 0x134b "ፋ" */
+0x00,0x00,0x00,0x00,0x02,0x03,0x06,0x04,0x0c,0x1c,0x36,0x33,0x1f,0x03,0x03,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xf0,0x10,0x00,0x00,
+/* 4940 0x134c "ፌ" */
+0x00,0x00,0x01,0x00,0x01,0x03,0x06,0x0c,0x1e,0x33,0x31,0x1f,0x07,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x30,0xe8,0xc8,0x70,0x00,0x00,
+/* 4941 0x134d "ፍ" */
+0x00,0x00,0x00,0x00,0x0f,0x19,0x10,0x30,0x30,0x3e,0x33,0x37,0x1b,0x03,0x03,0x03,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x00,0x00,0x00,0xc0,0x40,0x00,0x00,0x00,0x00,
+/* 4942 0x134e "ፎ" */
+0x00,0x00,0x00,0x07,0x0f,0x18,0x30,0x30,0x30,0x3c,0x3a,0x31,0x1b,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x90,0xf0,0x00,0x00,0x00,0x00,0x00,0x30,0x60,0xe0,0x00,0x00,
+/* 4943 0x134f "ፏ" */
+0x00,0x00,0x00,0x02,0x03,0x06,0x04,0x0c,0x1c,0x36,0x33,0x1f,0x03,0x03,0x0f,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xf0,0x10,0x00,0xc0,0x60,
+/* 4944 0x1350 "ፐ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4945 0x1351 "ፑ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0xf8,0x98,0x80,0x80,0x80,0x00,0x00,
+/* 4946 0x1352 "ፒ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x98,0xf8,0x00,0x00,
+/* 4947 0x1353 "ፓ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x03,0x06,0x0c,0x08,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4948 0x1354 "ፔ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 4949 0x1355 "ፕ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 4950 0x1356 "ፖ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x03,0x03,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4951 0x1357 "ፗ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x1c,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xf0,0x38,
+/* 4952 0x1358 "ፘ" */
+0x00,0x18,0x0f,0x01,0x01,0x01,0x03,0x07,0x0e,0x1c,0x18,0x18,0x1c,0x0f,0x07,0x00,
+0x00,0x18,0xf0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x60,0x70,0x30,0xe0,0xc0,0x00,
+/* 4953 0x1359 "ፙ" */
+0x1c,0x07,0x01,0x0f,0x1f,0x31,0x21,0x22,0x3e,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x1c,0xf0,0xc0,0xfc,0xfc,0x44,0x44,0x84,0xfc,0x7c,0x08,0x08,0x10,0x10,0x10,0x00,
+/* 4954 0x135a "ፚ" */
+0x00,0x18,0x0f,0x01,0x00,0x01,0x03,0x06,0x0c,0x1e,0x33,0x31,0x1f,0x0f,0x00,0x00,
+0x00,0x18,0xf0,0x80,0x80,0x80,0x00,0x00,0x00,0x30,0x10,0x30,0xe0,0x80,0x00,0x00,
+/* 4955 0x135b "፛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 4956 0x135c "፜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 4957 0x135d "፝" */
+0x19,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x98,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4958 0x135e "፞" */
+0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4959 0x135f "፟" */
+0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4960 0x1360 "፠" */
+0x00,0x00,0x00,0x01,0x09,0x04,0x02,0x19,0x19,0x02,0x04,0x09,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x90,0x20,0x40,0x98,0x98,0x40,0x20,0x90,0x80,0x00,0x00,0x00,
+/* 4961 0x1361 "፡" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4962 0x1362 "።" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 4963 0x1363 "፣" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x01,0x01,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0x80,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 4964 0x1364 "፤" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x01,0x01,0x00,0x01,0x01,0x00,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0x80,0x00,0x80,0x80,0x00,0xe0,0x00,0x00,0x00,
+/* 4965 0x1365 "፥" */
+0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x1f,0x00,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4966 0x1366 "፦" */
+0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x03,0x00,0x06,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4967 0x1367 "፧" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x01,0x01,0x00,0x00,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 4968 0x1368 "፨" */
+0x00,0x00,0x00,0x01,0x01,0x0c,0x0c,0x01,0x01,0x0c,0x0c,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x30,0x30,0x80,0x80,0x30,0x30,0x80,0x80,0x00,0x00,0x00,
+/* 4969 0x1369 "፩" */
+0x00,0x00,0x18,0x0f,0x00,0x01,0x01,0x03,0x07,0x0c,0x0c,0x07,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x30,0xe0,0x00,0x80,0x80,0x00,0xc0,0x60,0x60,0xc0,0x00,0xe0,0x30,0x00,
+/* 4970 0x136a "፪" */
+0x00,0x00,0x0c,0x07,0x00,0x01,0x03,0x06,0x07,0x06,0x07,0x03,0x01,0x07,0x0c,0x00,
+0x00,0x00,0x18,0xf0,0x00,0xc0,0x60,0x60,0xc0,0x00,0xc0,0x60,0xc0,0xf0,0x18,0x00,
+/* 4971 0x136b "፫" */
+0x00,0x00,0x00,0x0c,0x07,0x00,0x07,0x06,0x06,0x06,0x06,0x06,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x00,0x30,0xe0,0x00,0xe0,0x60,0x00,0x00,0x00,0x00,0x00,0xe0,0x30,0x00,
+/* 4972 0x136c "፬" */
+0x00,0x00,0x00,0x0c,0x07,0x00,0x03,0x06,0x06,0x06,0x06,0x03,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x00,0x30,0xe0,0x00,0xc0,0x60,0x60,0x60,0x60,0xc0,0x00,0xe0,0x30,0x00,
+/* 4973 0x136d "፭" */
+0x00,0x00,0x18,0x0f,0x00,0x03,0x03,0x07,0x0e,0x0c,0x0c,0x07,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x30,0xe0,0x00,0x00,0x00,0xe0,0x60,0x00,0x60,0xe0,0x00,0xe0,0x30,0x00,
+/* 4974 0x136e "፮" */
+0x00,0x18,0x0f,0x00,0x07,0x0f,0x0c,0x00,0x01,0x01,0x03,0x03,0x00,0x0f,0x18,0x00,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0xc0,0xc0,0x80,0xc0,0x60,0xc0,0x00,0xe0,0x30,0x00,
+/* 4975 0x136f "፯" */
+0x00,0x18,0x0f,0x00,0x07,0x0f,0x0c,0x00,0x01,0x01,0x03,0x03,0x00,0x0f,0x18,0x00,
+0x00,0x30,0xe0,0x00,0x80,0xc0,0xc0,0xc0,0x80,0x00,0x20,0xe0,0x00,0xe0,0x30,0x00,
+/* 4976 0x1370 "፰" */
+0x00,0x00,0x18,0x0f,0x00,0x0f,0x0d,0x01,0x01,0x01,0x0f,0x0c,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x18,0xf0,0x00,0xf0,0xb0,0x80,0x80,0x80,0xf0,0x30,0x00,0xf0,0x18,0x00,
+/* 4977 0x1371 "፱" */
+0x00,0x00,0x0c,0x07,0x00,0x00,0x06,0x06,0x07,0x06,0x06,0x03,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x30,0xe0,0x00,0x00,0x60,0x60,0xe0,0x60,0x40,0x80,0x00,0xe0,0x30,0x00,
+/* 4978 0x1372 "፲" */
+0x00,0x00,0x00,0x0c,0x07,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x00,0x30,0xe0,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0xe0,0x30,0x00,
+/* 4979 0x1373 "፳" */
+0x00,0x00,0x00,0x18,0x0f,0x00,0x07,0x05,0x01,0x03,0x06,0x06,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x00,0x18,0xf0,0x00,0xe0,0xa0,0x80,0xc0,0x60,0x60,0x00,0xf0,0x18,0x00,
+/* 4980 0x1374 "፴" */
+0x00,0x00,0x00,0x18,0x0f,0x00,0x05,0x0d,0x0d,0x0d,0x0d,0x07,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x00,0x18,0xf0,0x00,0xe0,0xb0,0xb0,0xb0,0xb0,0x30,0x00,0xf0,0x18,0x00,
+/* 4981 0x1375 "፵" */
+0x00,0x00,0x18,0x0f,0x00,0x0d,0x0d,0x0d,0x07,0x00,0x00,0x00,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x18,0xf0,0x00,0xb0,0xb0,0xb0,0xf0,0x30,0x30,0x30,0x00,0xf0,0x18,0x00,
+/* 4982 0x1376 "፶" */
+0x00,0x00,0x0c,0x07,0x00,0x03,0x06,0x03,0x00,0x00,0x00,0x00,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x30,0xe0,0x00,0xe0,0x60,0xe0,0x60,0xc0,0xc0,0xc0,0x00,0xe0,0x30,0x00,
+/* 4983 0x1377 "፷" */
+0x00,0x00,0x18,0x0f,0x00,0x0f,0x0d,0x01,0x01,0x00,0x0f,0x0c,0x00,0x0f,0x18,0x00,
+0x00,0x00,0x18,0xf0,0x00,0xf0,0xb0,0x80,0xc0,0xc0,0xf0,0x30,0x00,0xf0,0x18,0x00,
+/* 4984 0x1378 "፸" */
+0x00,0x00,0x00,0x0c,0x07,0x00,0x03,0x06,0x06,0x06,0x06,0x03,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x00,0x30,0xe0,0x00,0xe0,0xb0,0xe0,0x00,0x60,0xe0,0x00,0xe0,0x30,0x00,
+/* 4985 0x1379 "፹" */
+0x00,0x00,0x00,0x30,0x1f,0x00,0x1f,0x16,0x06,0x06,0x06,0x06,0x00,0x1f,0x30,0x00,
+0x00,0x00,0x00,0x18,0xf0,0x00,0xf0,0xd0,0xc0,0xc0,0xc0,0xc0,0x00,0xf0,0x18,0x00,
+/* 4986 0x137a "፺" */
+0x00,0x18,0x0f,0x00,0x07,0x06,0x01,0x01,0x00,0x01,0x01,0x01,0x00,0x0f,0x18,0x00,
+0x00,0x30,0xe0,0x00,0xc0,0xc0,0x80,0xc0,0xc0,0x80,0x80,0x80,0x00,0xe0,0x30,0x00,
+/* 4987 0x137b "፻" */
+0x00,0x00,0x0c,0x07,0x00,0x03,0x06,0x07,0x06,0x03,0x03,0x03,0x00,0x07,0x0c,0x00,
+0x00,0x00,0x30,0xe0,0x00,0xc0,0x60,0xc0,0x00,0x00,0x00,0x00,0x00,0xe0,0x30,0x00,
+/* 4988 0x137c "፼" */
+0x00,0x00,0x30,0x1f,0x00,0x1e,0x33,0x3e,0x30,0x18,0x18,0x18,0x00,0x1f,0x30,0x00,
+0x00,0x00,0x0c,0xf8,0x00,0x78,0xcc,0xf8,0xc0,0x60,0x60,0x60,0x00,0xf8,0x0c,0x00,
+/* 4989 0x137d "፽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 4990 0x137e "፾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 4991 0x137f "፿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 4992 0x1380 "ᎀ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x7f,0x44,0xc5,0x8d,0x99,0xf1,0xf1,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x90,0x9f,0x15,0x37,0xe0,0xc0,0x00,0x00,0x00,
+/* 4993 0x1381 "ᎁ" */
+0x00,0x00,0x3f,0x7f,0xc5,0x85,0x8a,0xfb,0x71,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0xe0,0x2c,0x3c,0x2f,0xe3,0xe0,0x40,0x40,0x80,0x98,0xf8,0x00,0x00,
+/* 4994 0x1382 "ᎂ" */
+0x00,0x00,0x1f,0x3f,0x62,0x42,0x45,0x7d,0x38,0x00,0x00,0x00,0x00,0x03,0x03,0x00,
+0x00,0x00,0xf8,0xf8,0x88,0x88,0x08,0xf8,0xf8,0x10,0x10,0x3c,0x24,0xfc,0x00,0x00,
+/* 4995 0x1383 "ᎃ" */
+0x00,0x00,0x3f,0x7f,0xc5,0x85,0x8a,0xfb,0x71,0x10,0x10,0x30,0x20,0x20,0x00,0x00,
+0x00,0x00,0xe0,0xe0,0x3e,0x2a,0x2e,0xe0,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 4996 0x1384 "ᎄ" */
+0x00,0x00,0x00,0x00,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xa8,0xb8,0x80,0x80,0x80,0x00,0x00,
+/* 4997 0x1385 "ᎅ" */
+0x00,0x00,0x00,0x00,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xb0,0xb0,0xfc,0x8c,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 4998 0x1386 "ᎆ" */
+0x00,0x00,0x00,0x00,0x0e,0x1f,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x31,0x06,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xe0,0xa0,0xe0,0x00,0x00,
+/* 4999 0x1387 "ᎇ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x0c,0x7c,0x6c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x60,0x7e,0x6a,0x6e,0x60,0x60,0x60,0x00,0x00,
+/* 5000 0x1388 "ᎈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x06,0x0f,0x19,0x18,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x40,0xfc,0x94,0x1c,0x00,0x00,0xb0,0xf0,0x30,0x00,0x00,0x00,
+/* 5001 0x1389 "ᎉ" */
+0x00,0x00,0x00,0x01,0x00,0x01,0x03,0x06,0x0c,0x1e,0x33,0x31,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0xb0,0xf0,0x3c,0x0c,0x00,0x00,0x60,0xe0,0x60,0x00,0x00,0x00,
+/* 5002 0x138a "ᎊ" */
+0x00,0x00,0x00,0x03,0x01,0x03,0x06,0x0c,0x1e,0x11,0x13,0x0f,0x06,0x0c,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xa8,0x38,0x00,0x00,0x00,0x00,
+/* 5003 0x138b "ᎋ" */
+0x00,0x00,0x00,0x00,0x0f,0x19,0x10,0x30,0x37,0x33,0x33,0x33,0x1f,0x03,0x03,0x03,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x00,0xf0,0x50,0x70,0x00,0xe0,0x60,0x00,0x00,
+/* 5004 0x138c "ᎌ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0xf8,0xac,0xb8,0x80,0x80,0x80,0x00,0x00,
+/* 5005 0x138d "ᎍ" */
+0x00,0x00,0x18,0x1f,0x3f,0x33,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0x60,0xe0,0xf0,0x30,0x00,0x00,0x60,0xe0,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 5006 0x138e "ᎎ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x0c,0x0c,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0xf0,0x98,0xf0,0x00,0x00,
+/* 5007 0x138f "ᎏ" */
+0x00,0x00,0x18,0x1f,0x3f,0x33,0x03,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x60,0xe0,0xf0,0x30,0x00,0x00,0xf8,0xac,0xb8,0x80,0x80,0x80,0x00,0x00,
+/* 5008 0x1390 "᎐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5009 0x1391 "᎑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5010 0x1392 "᎒" */
+0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5011 0x1393 "᎓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5012 0x1394 "᎔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5013 0x1395 "᎕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x38,0xf0,0x00,0x00,0x00,
+/* 5014 0x1396 "᎖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x06,0x0e,0x1c,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5015 0x1397 "᎗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 5016 0x1398 "᎘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x48,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 5017 0x1399 "᎙" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x60,0x66,0x7e,0x66,0x60,0x60,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5018 0x139a "᎚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 5019 0x139b "᎛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 5020 0x139c "᎜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 5021 0x139d "᎝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5022 0x139e "᎞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5023 0x139f "᎟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 5024 0x13a0 "Ꭰ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5025 0x13a1 "Ꭱ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x44,0x78,0x50,0x48,0x44,0x43,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5026 0x13a2 "Ꭲ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5027 0x13a3 "Ꭳ" */
+0x00,0x00,0x00,0x00,0x1c,0x08,0x14,0x12,0x21,0x51,0x51,0x51,0x55,0x26,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5028 0x13a4 "Ꭴ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x4b,0x49,0x4e,0x48,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5029 0x13a5 "Ꭵ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5030 0x13a6 "Ꭶ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x20,0x7f,0x04,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5031 0x13a7 "Ꭷ" */
+0x00,0x00,0x00,0x00,0x1c,0x02,0x22,0x52,0x52,0x52,0x62,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5032 0x13a8 "Ꭸ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x4c,0x54,0x76,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5033 0x13a9 "Ꭹ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5034 0x13aa "Ꭺ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5035 0x13ab "Ꭻ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5036 0x13ac "Ꭼ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5037 0x13ad "Ꭽ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x48,0xa8,0xbb,0x49,0x0a,0x0a,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5038 0x13ae "Ꭾ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x42,0x7c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5039 0x13af "Ꭿ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x3e,0x22,0x22,0xaa,0xcc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5040 0x13b0 "Ꮀ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5041 0x13b1 "Ꮁ" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5042 0x13b2 "Ꮂ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x48,0x30,0xb7,0xb2,0xb4,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5043 0x13b3 "Ꮃ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5044 0x13b4 "Ꮄ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x08,0x38,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5045 0x13b5 "Ꮅ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x52,0x4c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5046 0x13b6 "Ꮆ" */
+0x00,0x00,0x00,0x00,0x1e,0x20,0x40,0x40,0x48,0x4c,0x4a,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5047 0x13b7 "Ꮇ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5048 0x13b8 "Ꮈ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x72,0x1e,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5049 0x13b9 "Ꮉ" */
+0x00,0x00,0x00,0x00,0x18,0x0a,0x15,0x20,0x3c,0x52,0x52,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5050 0x13ba "Ꮊ" */
+0x00,0x00,0x00,0x00,0x32,0x4a,0x4a,0x4a,0x4e,0x4a,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5051 0x13bb "Ꮋ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5052 0x13bc "Ꮌ" */
+0x00,0x00,0x00,0x00,0x38,0x10,0x38,0x44,0x02,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5053 0x13bd "Ꮍ" */
+0x00,0x00,0x00,0x00,0x47,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0xe2,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5054 0x13be "Ꮎ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5055 0x13bf "Ꮏ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0xf0,0x40,0x40,0x40,0x40,0x4e,0x44,0x3c,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5056 0x13c0 "Ꮐ" */
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x80,0x80,0x9e,0x84,0x84,0x84,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5057 0x13c1 "Ꮑ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x12,0x22,0x22,0xa2,0xa2,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5058 0x13c2 "Ꮒ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5059 0x13c3 "Ꮓ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5060 0x13c4 "Ꮔ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0xe4,0x04,0xe4,0x44,0x3c,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5061 0x13c5 "Ꮕ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x4a,0x4d,0x49,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5062 0x13c6 "Ꮖ" */
+0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5063 0x13c7 "Ꮗ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x02,0x42,0x4a,0x4a,0x4a,0x4a,0x4a,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5064 0x13c8 "Ꮘ" */
+0x00,0x00,0x00,0x00,0x66,0x19,0x19,0x29,0x2a,0x48,0x48,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5065 0x13c9 "Ꮙ" */
+0x00,0x00,0x00,0x00,0xa3,0xa5,0x66,0x24,0x24,0x14,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5066 0x13ca "Ꮚ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x02,0x9a,0xa2,0xa2,0xa2,0xa2,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5067 0x13cb "Ꮛ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x3c,0x40,0x44,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5068 0x13cc "Ꮜ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5069 0x13cd "Ꮝ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x02,0x02,0x1a,0xd2,0xb2,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5070 0x13ce "Ꮞ" */
+0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0x44,0x44,0x7e,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5071 0x13cf "Ꮟ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5072 0x13d0 "Ꮠ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x0b,0x5d,0x68,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5073 0x13d1 "Ꮡ" */
+0x00,0x00,0x00,0x00,0x64,0x9a,0xe2,0x44,0x80,0x98,0x84,0x84,0x84,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5074 0x13d2 "Ꮢ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x44,0x58,0x48,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5075 0x13d3 "Ꮣ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5076 0x13d4 "Ꮤ" */
+0x00,0x00,0x00,0x00,0xaa,0xaa,0xaa,0x92,0xb2,0xb2,0xca,0xca,0x86,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5077 0x13d5 "Ꮥ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x47,0x40,0x20,0x1f,0x04,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5078 0x13d6 "Ꮦ" */
+0x00,0x00,0x00,0x00,0xf0,0x90,0x10,0x10,0x10,0x10,0x12,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5079 0x13d7 "Ꮧ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x06,0x0a,0x12,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5080 0x13d8 "Ꮨ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x06,0x0a,0x12,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5081 0x13d9 "Ꮩ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5082 0x13da "Ꮪ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5083 0x13db "Ꮫ" */
+0x00,0x00,0x00,0x00,0x36,0x49,0x42,0x60,0x50,0x48,0x48,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5084 0x13dc "Ꮬ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x24,0x22,0x55,0x55,0x55,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5085 0x13dd "Ꮭ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5086 0x13de "Ꮮ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5087 0x13df "Ꮯ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5088 0x13e0 "Ꮰ" */
+0x00,0x00,0x00,0x00,0x04,0x44,0xa4,0xa4,0x7e,0x24,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5089 0x13e1 "Ꮱ" */
+0x00,0x00,0x00,0x00,0x66,0x99,0x99,0x9a,0x28,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5090 0x13e2 "Ꮲ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5091 0x13e3 "Ꮳ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x47,0x40,0x40,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5092 0x13e4 "Ꮴ" */
+0x00,0x00,0x00,0x00,0xf1,0x91,0x12,0x12,0x14,0x14,0x14,0x18,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5093 0x13e5 "Ꮵ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x43,0x4d,0x74,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5094 0x13e6 "Ꮶ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5095 0x13e7 "Ꮷ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x1e,0x22,0x42,0x42,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5096 0x13e8 "Ꮸ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x4a,0x45,0x40,0x40,0x45,0x4a,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5097 0x13e9 "Ꮹ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x40,0x40,0x4e,0x44,0x44,0x3b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5098 0x13ea "Ꮺ" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x55,0x53,0x51,0x31,0x19,0x99,0x95,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5099 0x13eb "Ꮻ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x72,0x52,0x5e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5100 0x13ec "Ꮼ" */
+0x00,0x00,0x00,0x00,0x32,0x49,0x49,0x49,0x71,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5101 0x13ed "Ꮽ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x0a,0x06,0x02,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5102 0x13ee "Ꮾ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5103 0x13ef "Ꮿ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x01,0x01,0x5d,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5104 0x13f0 "Ᏸ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x3c,0x22,0x22,0x62,0x32,0x2c,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5105 0x13f1 "Ᏹ" */
+0x00,0x00,0x00,0x00,0x0e,0x04,0x0e,0x11,0x11,0x21,0x21,0x29,0xa9,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5106 0x13f2 "Ᏺ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5107 0x13f3 "Ᏻ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x4a,0x45,0x40,0x40,0x4e,0x44,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5108 0x13f4 "Ᏼ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5109 0x13f5 "Ᏽ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x20,0x20,0x40,0x4e,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5110 0x13f6 "᏶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 5111 0x13f7 "᏷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 5112 0x13f8 "ᏸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x3c,0x22,0x62,0x32,0x2c,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5113 0x13f9 "ᏹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x04,0x0e,0x11,0x11,0x21,0xa9,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5114 0x13fa "ᏺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x5c,0x62,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5115 0x13fb "ᏻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x4a,0x45,0x40,0x40,0x4e,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5116 0x13fc "ᏼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5117 0x13fd "ᏽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x20,0x40,0x4e,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5118 0x13fe "᏾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5119 0x13ff "᏿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 5120 0x1400 "᐀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5121 0x1401 "ᐁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5122 0x1402 "ᐂ" */
+0x00,0x01,0x02,0x02,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x80,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5123 0x1403 "ᐃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5124 0x1404 "ᐄ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5125 0x1405 "ᐅ" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5126 0x1406 "ᐆ" */
+0x0c,0x0c,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5127 0x1407 "ᐇ" */
+0x0c,0x0c,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0xc0,0xc0,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5128 0x1408 "ᐈ" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x0a,0x0a,0x0a,0x0a,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5129 0x1409 "ᐉ" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x0b,0x0b,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5130 0x140a "ᐊ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5131 0x140b "ᐋ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x60,0x60,0x00,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5132 0x140c "ᐌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x20,0x10,0x08,0x64,0x62,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5133 0x140d "ᐍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x04,0x08,0x10,0x26,0x46,0x80,0x00,0x00,
+/* 5134 0x140e "ᐎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x62,0x64,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5135 0x140f "ᐏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x46,0x26,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5136 0x1410 "ᐐ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x62,0x64,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5137 0x1411 "ᐑ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x46,0x26,0x10,0x08,0x04,0x02,0xfe,0x00,0x00,
+/* 5138 0x1412 "ᐒ" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x68,0x68,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5139 0x1413 "ᐓ" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x2c,0x2c,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5140 0x1414 "ᐔ" */
+0x0c,0x0c,0x00,0x0c,0x0a,0x09,0x08,0x08,0x68,0x68,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5141 0x1415 "ᐕ" */
+0x0c,0x0c,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x2c,0x2c,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5142 0x1416 "ᐖ" */
+0x00,0x01,0x01,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,
+0x00,0x80,0x80,0x00,0x30,0x30,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5143 0x1417 "ᐗ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x68,0x68,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5144 0x1418 "ᐘ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0xa0,0x20,0x20,0x20,0x2c,0x2c,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5145 0x1419 "ᐙ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x68,0x68,0x04,0x02,0x01,0x00,0x00,0x00,
+0x60,0x60,0x00,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5146 0x141a "ᐚ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x60,0x60,0x00,0x60,0xa0,0x20,0x20,0x20,0x2c,0x2c,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5147 0x141b "ᐛ" */
+0x00,0x03,0x03,0x00,0x18,0x19,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,
+/* 5148 0x141c "ᐜ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5149 0x141d "ᐝ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5150 0x141e "ᐞ" */
+0x00,0x00,0x00,0x10,0x10,0x28,0x28,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5151 0x141f "ᐟ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5152 0x1420 "ᐠ" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5153 0x1421 "ᐡ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5154 0x1422 "ᐢ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5155 0x1423 "ᐣ" */
+0x00,0x00,0x00,0x00,0x78,0x04,0x04,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5156 0x1424 "ᐤ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5157 0x1425 "ᐥ" */
+0x00,0x00,0x00,0x00,0x09,0x12,0x24,0x48,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5158 0x1426 "ᐦ" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5159 0x1427 "ᐧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5160 0x1428 "ᐨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5161 0x1429 "ᐩ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5162 0x142a "ᐪ" */
+0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5163 0x142b "ᐫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x80,0x40,0x20,0x10,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xf4,0x12,0x22,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5164 0x142c "ᐬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x08,0x84,0x44,0x20,0x10,0x08,0xf8,0x00,0x00,
+/* 5165 0x142d "ᐭ" */
+0x00,0x00,0x00,0x18,0x14,0x12,0x11,0x10,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x00,
+0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x88,0x48,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 5166 0x142e "ᐮ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x20,0x10,0x08,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0xa0,0xa0,0x90,0x90,0x88,0x88,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 5167 0x142f "ᐯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5168 0x1430 "ᐰ" */
+0x00,0x01,0x02,0x02,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,0x00,
+/* 5169 0x1431 "ᐱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,0x00,
+/* 5170 0x1432 "ᐲ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,0x00,
+/* 5171 0x1433 "ᐳ" */
+0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5172 0x1434 "ᐴ" */
+0x60,0x60,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5173 0x1435 "ᐵ" */
+0x66,0x66,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5174 0x1436 "ᐶ" */
+0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x24,0x22,0x22,0x24,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5175 0x1437 "ᐷ" */
+0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x32,0x32,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5176 0x1438 "ᐸ" */
+0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x20,0x10,0x08,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5177 0x1439 "ᐹ" */
+0x06,0x06,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x20,0x10,0x08,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5178 0x143a "ᐺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x64,0x62,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5179 0x143b "ᐻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x26,0x46,0x80,0x00,0x00,
+/* 5180 0x143c "ᐼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x62,0x64,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5181 0x143d "ᐽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x46,0x26,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5182 0x143e "ᐾ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x62,0x64,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5183 0x143f "ᐿ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x46,0x26,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5184 0x1440 "ᑀ" */
+0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5185 0x1441 "ᑁ" */
+0x00,0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x2c,0x2c,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5186 0x1442 "ᑂ" */
+0x01,0x01,0x00,0x01,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,0x00,0x01,0x00,
+0x80,0x80,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5187 0x1443 "ᑃ" */
+0x06,0x06,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x2c,0x2c,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5188 0x1444 "ᑄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x1a,0x1a,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,
+/* 5189 0x1445 "ᑅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x0c,0x0c,0x00,0x00,0x80,0x40,0x20,0x00,
+/* 5190 0x1446 "ᑆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x1a,0x1a,0x01,0x00,0x00,0x00,0x00,0x00,
+0x30,0x30,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,
+/* 5191 0x1447 "ᑇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x60,0x60,0x00,0x20,0x40,0x80,0x00,0x00,0x0c,0x0c,0x00,0x00,0x80,0x40,0x20,0x00,
+/* 5192 0x1448 "ᑈ" */
+0x00,0x01,0x01,0x00,0x0c,0x0c,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,
+/* 5193 0x1449 "ᑉ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5194 0x144a "ᑊ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5195 0x144b "ᑋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x38,0x24,0x24,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5196 0x144c "ᑌ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5197 0x144d "ᑍ" */
+0x01,0x02,0x02,0x01,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x80,0x40,0x40,0x80,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5198 0x144e "ᑎ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5199 0x144f "ᑏ" */
+0x00,0x00,0x01,0x01,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5200 0x1450 "ᑐ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5201 0x1451 "ᑑ" */
+0x00,0x03,0x03,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5202 0x1452 "ᑒ" */
+0x00,0x0c,0x0c,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0xc0,0xc0,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5203 0x1453 "ᑓ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x88,0x88,0x88,0x88,0x08,0x10,0xe0,0x00,0x00,
+/* 5204 0x1454 "ᑔ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x88,0x88,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5205 0x1455 "ᑕ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 5206 0x1456 "ᑖ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x60,0x60,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 5207 0x1457 "ᑗ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x68,0x68,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0xf0,0x00,0x00,
+/* 5208 0x1458 "ᑘ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x2c,0x2c,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 5209 0x1459 "ᑙ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x68,0x68,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 5210 0x145a "ᑚ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x2c,0x2c,0x20,0x20,0x20,0x00,0x00,
+/* 5211 0x145b "ᑛ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x68,0x68,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 5212 0x145c "ᑜ" */
+0x00,0x00,0x06,0x06,0x00,0x1f,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x2c,0x2c,0x20,0x20,0x20,0x00,0x00,
+/* 5213 0x145d "ᑝ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0xf0,0x00,
+/* 5214 0x145e "ᑞ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x2c,0x2c,0x20,0x20,0x40,0x80,0x00,
+/* 5215 0x145f "ᑟ" */
+0x00,0x00,0x01,0x01,0x00,0x07,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x80,0x80,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0xf0,0x00,
+/* 5216 0x1460 "ᑠ" */
+0x00,0x00,0x0c,0x0c,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x2c,0x2c,0x20,0x20,0x40,0x80,0x00,
+/* 5217 0x1461 "ᑡ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x34,0x34,0x04,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 5218 0x1462 "ᑢ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0xe0,0x00,
+/* 5219 0x1463 "ᑣ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x68,0x68,0x08,0x08,0x04,0x03,0x00,
+0x00,0x00,0x60,0x60,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,
+/* 5220 0x1464 "ᑤ" */
+0x00,0x00,0x03,0x03,0x00,0x1f,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0xc0,0x00,
+/* 5221 0x1465 "ᑥ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x68,0x68,0x08,0x08,0x68,0x68,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,
+/* 5222 0x1466 "ᑦ" */
+0x00,0x00,0x00,0x00,0x3c,0x40,0x40,0x40,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5223 0x1467 "ᑧ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5224 0x1468 "ᑨ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc4,0x24,0x14,0x14,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 5225 0x1469 "ᑩ" */
+0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x48,0x28,0x28,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 5226 0x146a "ᑪ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe8,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 5227 0x146b "ᑫ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5228 0x146c "ᑬ" */
+0x18,0x24,0x24,0x18,0x00,0x38,0x44,0x44,0x44,0x78,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5229 0x146d "ᑭ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x78,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5230 0x146e "ᑮ" */
+0x00,0x00,0x30,0x30,0x00,0x38,0x44,0x44,0x44,0x78,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5231 0x146f "ᑯ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x3c,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5232 0x1470 "ᑰ" */
+0x00,0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x04,0x3c,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5233 0x1471 "ᑱ" */
+0x00,0x00,0x36,0x36,0x00,0x04,0x04,0x04,0x04,0x3c,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5234 0x1472 "ᑲ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x78,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5235 0x1473 "ᑳ" */
+0x00,0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x40,0x78,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5236 0x1474 "ᑴ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1e,0x02,0x62,0x62,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5237 0x1475 "ᑵ" */
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x78,0x0b,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5238 0x1476 "ᑶ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x1e,0xd0,0xd0,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5239 0x1477 "ᑷ" */
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0xf0,0x86,0x86,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5240 0x1478 "ᑸ" */
+0x00,0x00,0x0c,0x0c,0x00,0x0e,0x11,0x11,0x11,0x1e,0xd0,0xd0,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5241 0x1479 "ᑹ" */
+0x00,0x00,0x60,0x60,0x00,0x70,0x88,0x88,0x88,0xf0,0x86,0x86,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5242 0x147a "ᑺ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x61,0x61,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5243 0x147b "ᑻ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x0b,0x0b,0x78,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5244 0x147c "ᑼ" */
+0x00,0x00,0x03,0x03,0x00,0x01,0x01,0x61,0x61,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5245 0x147d "ᑽ" */
+0x00,0x00,0x18,0x18,0x00,0x08,0x08,0x0b,0x0b,0x78,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5246 0x147e "ᑾ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xd0,0xde,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5247 0x147f "ᑿ" */
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x86,0x86,0xf0,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5248 0x1480 "ᒀ" */
+0x00,0x00,0x18,0x18,0x00,0x10,0x10,0x10,0xd0,0xde,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5249 0x1481 "ᒁ" */
+0x00,0x00,0xc0,0xc0,0x00,0x80,0x80,0x86,0x86,0xf0,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5250 0x1482 "ᒂ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0xd0,0x1e,0xd1,0xd1,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5251 0x1483 "ᒃ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x38,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5252 0x1484 "ᒄ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x1c,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5253 0x1485 "ᒅ" */
+0x00,0x00,0x00,0x00,0x00,0x72,0x8a,0x8a,0x8a,0x78,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5254 0x1486 "ᒆ" */
+0x00,0x00,0x00,0x00,0x00,0x72,0x8a,0x8a,0x8a,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5255 0x1487 "ᒇ" */
+0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x0a,0x0a,0x78,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5256 0x1488 "ᒈ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x78,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5257 0x1489 "ᒉ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5258 0x148a "ᒊ" */
+0x30,0x48,0x48,0x30,0x00,0x38,0x44,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5259 0x148b "ᒋ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5260 0x148c "ᒌ" */
+0x00,0x00,0x30,0x30,0x00,0x38,0x44,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5261 0x148d "ᒍ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5262 0x148e "ᒎ" */
+0x00,0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5263 0x148f "ᒏ" */
+0x00,0x00,0x36,0x36,0x00,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5264 0x1490 "ᒐ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5265 0x1491 "ᒑ" */
+0x00,0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5266 0x1492 "ᒒ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x02,0xc2,0xc2,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5267 0x1493 "ᒓ" */
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x8b,0x0b,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5268 0x1494 "ᒔ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0xd1,0xd0,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5269 0x1495 "ᒕ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x40,0x46,0x46,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5270 0x1496 "ᒖ" */
+0x00,0x00,0x0c,0x0c,0x00,0x0e,0x11,0x11,0xd1,0xd0,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5271 0x1497 "ᒗ" */
+0x00,0x00,0x30,0x30,0x00,0x38,0x44,0x44,0x44,0x40,0x46,0x46,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5272 0x1498 "ᒘ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xc2,0xc2,0x02,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5273 0x1499 "ᒙ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0b,0x0b,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5274 0x149a "ᒚ" */
+0x00,0x00,0x06,0x06,0x00,0x02,0x02,0xc2,0xc2,0x02,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5275 0x149b "ᒛ" */
+0x00,0x00,0x18,0x18,0x00,0x08,0x08,0x0b,0x0b,0x08,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5276 0x149c "ᒜ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xd0,0xd0,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5277 0x149d "ᒝ" */
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x86,0x86,0x80,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5278 0x149e "ᒞ" */
+0x00,0x00,0x18,0x18,0x00,0x10,0x10,0x10,0xd0,0xd0,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5279 0x149f "ᒟ" */
+0x00,0x00,0xc0,0xc0,0x00,0x80,0x80,0x86,0x86,0x80,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5280 0x14a0 "ᒠ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xd0,0xd0,0x11,0xd1,0xd1,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5281 0x14a1 "ᒡ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5282 0x14a2 "ᒢ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5283 0x14a3 "ᒣ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5284 0x14a4 "ᒤ" */
+0x30,0x48,0x48,0x30,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5285 0x14a5 "ᒥ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5286 0x14a6 "ᒦ" */
+0x00,0x00,0x30,0x30,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5287 0x14a7 "ᒧ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5288 0x14a8 "ᒨ" */
+0x00,0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5289 0x14a9 "ᒩ" */
+0x00,0x00,0x36,0x36,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5290 0x14aa "ᒪ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5291 0x14ab "ᒫ" */
+0x00,0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5292 0x14ac "ᒬ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x01,0x01,0x61,0x61,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5293 0x14ad "ᒭ" */
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x0b,0x0b,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5294 0x14ae "ᒮ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0xd0,0xd0,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5295 0x14af "ᒯ" */
+0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0x86,0x86,0x80,0x80,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5296 0x14b0 "ᒰ" */
+0x00,0x00,0x0c,0x0c,0x00,0x1f,0x10,0x10,0xd0,0xd0,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5297 0x14b1 "ᒱ" */
+0x00,0x00,0x30,0x30,0x00,0x7c,0x40,0x40,0x46,0x46,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5298 0x14b2 "ᒲ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x61,0x61,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5299 0x14b3 "ᒳ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0b,0x0b,0x08,0x08,0x08,0xf8,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5300 0x14b4 "ᒴ" */
+0x00,0x00,0x06,0x06,0x00,0x02,0x02,0x02,0xc2,0xc2,0x02,0x02,0x02,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5301 0x14b5 "ᒵ" */
+0x00,0x00,0x18,0x18,0x00,0x08,0x08,0x08,0x0b,0x0b,0x08,0x08,0x08,0xf8,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5302 0x14b6 "ᒶ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xd0,0xd0,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5303 0x14b7 "ᒷ" */
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x86,0x86,0x80,0x80,0x80,0xf8,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5304 0x14b8 "ᒸ" */
+0x00,0x00,0x18,0x18,0x00,0x10,0x10,0x10,0xd0,0xd0,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5305 0x14b9 "ᒹ" */
+0x00,0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x46,0x46,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5306 0x14ba "ᒺ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0xd0,0x10,0xd0,0xd0,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5307 0x14bb "ᒻ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5308 0x14bc "ᒼ" */
+0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5309 0x14bd "ᒽ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5310 0x14be "ᒾ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x08,0x10,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5311 0x14bf "ᒿ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5312 0x14c0 "ᓀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5313 0x14c1 "ᓁ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x00,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5314 0x14c2 "ᓂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5315 0x14c3 "ᓃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5316 0x14c4 "ᓄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5317 0x14c5 "ᓅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5318 0x14c6 "ᓆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5319 0x14c7 "ᓇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5320 0x14c8 "ᓈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf8,0x00,0x00,
+/* 5321 0x14c9 "ᓉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x30,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x44,0x44,0x44,0x38,0x00,0x00,
+/* 5322 0x14ca "ᓊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x2c,0x2c,0x20,0xc0,0x00,0x00,
+/* 5323 0x14cb "ᓋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x34,0x34,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0xfc,0x00,0x00,
+/* 5324 0x14cc "ᓌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0xf0,0x00,0x00,
+/* 5325 0x14cd "ᓍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x03,0x04,0x34,0x34,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0xfc,0x00,0x00,
+/* 5326 0x14ce "ᓎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x0e,0x11,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0xf0,0x00,0x00,
+/* 5327 0x14cf "ᓏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x19,0x19,0x00,0x0e,0x11,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5328 0x14d0 "ᓐ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5329 0x14d1 "ᓑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5330 0x14d2 "ᓒ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5331 0x14d3 "ᓓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5332 0x14d4 "ᓔ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x0f,0x10,0x10,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5333 0x14d5 "ᓕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5334 0x14d6 "ᓖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x0f,0x10,0x10,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5335 0x14d7 "ᓗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5336 0x14d8 "ᓘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5337 0x14d9 "ᓙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5338 0x14da "ᓚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5339 0x14db "ᓛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 5340 0x14dc "ᓜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x30,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x04,0x38,0x00,0x00,
+/* 5341 0x14dd "ᓝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x2c,0x2c,0x20,0xc0,0x00,0x00,
+/* 5342 0x14de "ᓞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 5343 0x14df "ᓟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x0c,0x0c,0x00,0x00,0x00,0x00,
+/* 5344 0x14e0 "ᓠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0xfc,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 5345 0x14e1 "ᓡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x1f,0x20,0x20,0x20,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x0c,0x0c,0x00,0x00,0x00,0x00,
+/* 5346 0x14e2 "ᓢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5347 0x14e3 "ᓣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x2c,0x2c,0x20,0xc0,0x00,0x00,
+/* 5348 0x14e4 "ᓤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5349 0x14e5 "ᓥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0xc0,0x2c,0x2c,0x20,0xc0,0x00,0x00,
+/* 5350 0x14e6 "ᓦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 5351 0x14e7 "ᓧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0xf8,0x00,0x00,
+/* 5352 0x14e8 "ᓨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 5353 0x14e9 "ᓩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x0e,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0xf0,0x00,0x00,
+/* 5354 0x14ea "ᓪ" */
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5355 0x14eb "ᓫ" */
+0x00,0x00,0x00,0x00,0x0c,0x30,0x0c,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5356 0x14ec "ᓬ" */
+0x00,0x00,0x00,0x06,0x18,0x60,0x30,0x0c,0x02,0x0c,0x30,0x60,0x18,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5357 0x14ed "ᓭ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x20,0x1c,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5358 0x14ee "ᓮ" */
+0x0c,0x12,0x12,0x0c,0x00,0x04,0x04,0x04,0x08,0x70,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5359 0x14ef "ᓯ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x08,0x70,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5360 0x14f0 "ᓰ" */
+0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x04,0x04,0x08,0x70,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5361 0x14f1 "ᓱ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x1c,0x20,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5362 0x14f2 "ᓲ" */
+0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x1c,0x20,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5363 0x14f3 "ᓳ" */
+0x00,0x66,0x66,0x00,0x04,0x04,0x04,0x1c,0x20,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5364 0x14f4 "ᓴ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x70,0x08,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5365 0x14f5 "ᓵ" */
+0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x70,0x08,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5366 0x14f6 "ᓶ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x10,0xce,0xc2,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5367 0x14f7 "ᓷ" */
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x86,0x86,0x40,0x38,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5368 0x14f8 "ᓸ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0xc2,0xc2,0x04,0x38,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5369 0x14f9 "ᓹ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x10,0xe6,0x86,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5370 0x14fa "ᓺ" */
+0x00,0x06,0x06,0x00,0x02,0x02,0x02,0xc2,0xc2,0x04,0x38,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5371 0x14fb "ᓻ" */
+0x00,0x18,0x18,0x00,0x08,0x08,0x08,0x08,0x08,0x10,0xe6,0x86,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5372 0x14fc "ᓼ" */
+0x00,0x00,0x00,0x00,0x02,0x62,0x62,0x0e,0x10,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5373 0x14fd "ᓽ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x1c,0x20,0x46,0x46,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5374 0x14fe "ᓾ" */
+0x00,0x06,0x06,0x00,0x02,0x62,0x62,0x0e,0x10,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5375 0x14ff "ᓿ" */
+0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x1c,0x20,0x46,0x46,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5376 0x1500 "ᔀ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x70,0x08,0xc4,0xc4,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5377 0x1501 "ᔁ" */
+0x00,0x00,0x00,0x00,0x80,0x80,0x86,0xe6,0x10,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5378 0x1502 "ᔂ" */
+0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x70,0x08,0xc4,0xc4,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5379 0x1503 "ᔃ" */
+0x00,0xc0,0xc0,0x00,0x80,0x80,0x86,0xe6,0x10,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5380 0x1504 "ᔄ" */
+0x00,0x00,0x00,0x00,0x10,0xd0,0xd0,0x1c,0x02,0xc1,0xc1,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5381 0x1505 "ᔅ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x30,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5382 0x1506 "ᔆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x10,0x08,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5383 0x1507 "ᔇ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x18,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5384 0x1508 "ᔈ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5385 0x1509 "ᔉ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x38,0x04,0x1c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5386 0x150a "ᔊ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x1c,0x20,0x38,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5387 0x150b "ᔋ" */
+0x00,0x30,0x30,0x00,0x20,0x20,0x30,0x08,0x08,0x08,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5388 0x150c "ᔌ" */
+0x00,0x18,0x18,0x00,0x10,0x10,0x18,0x04,0x04,0x04,0x00,0x0c,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x08,0x04,0x00,
+/* 5389 0x150d "ᔍ" */
+0x00,0x60,0x60,0x00,0x40,0x41,0x62,0x12,0x12,0x12,0x02,0x32,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 5390 0x150e "ᔎ" */
+0x00,0x00,0x18,0x18,0x00,0x10,0x10,0x18,0x04,0x04,0x04,0x00,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5391 0x150f "ᔏ" */
+0x00,0x00,0x18,0x18,0x00,0x10,0x10,0x18,0x04,0x04,0x04,0x00,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5392 0x1510 "ᔐ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5393 0x1511 "ᔑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5394 0x1512 "ᔒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x00,0xe0,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5395 0x1513 "ᔓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x11,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 5396 0x1514 "ᔔ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x0c,0x12,0x11,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x60,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 5397 0x1515 "ᔕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0x11,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x10,0x60,0x00,0x00,
+/* 5398 0x1516 "ᔖ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x0c,0x10,0x11,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x60,0x90,0x10,0x10,0x60,0x00,0x00,
+/* 5399 0x1517 "ᔗ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x00,0x30,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5400 0x1518 "ᔘ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x02,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 5401 0x1519 "ᔙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 5402 0x151a "ᔚ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 5403 0x151b "ᔛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x60,0x60,0x00,0x70,0x88,0x88,0x88,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 5404 0x151c "ᔜ" */
+0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x02,0x02,0x02,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0xc0,0x20,0x20,0x20,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 5405 0x151d "ᔝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x34,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x84,0x44,0x24,0x18,0x00,0x00,
+/* 5406 0x151e "ᔞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x22,0x21,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcc,0x2c,0x20,0x20,0xc0,0x00,0x00,
+/* 5407 0x151f "ᔟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x34,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x18,0x84,0x44,0x24,0x18,0x00,0x00,
+/* 5408 0x1520 "ᔠ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x18,0x24,0x22,0x21,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcc,0x2c,0x20,0x20,0xc0,0x00,0x00,
+/* 5409 0x1521 "ᔡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x34,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x84,0x44,0x24,0x18,0x00,0x00,
+/* 5410 0x1522 "ᔢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x21,0x22,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcc,0x2c,0x20,0x20,0xc0,0x00,0x00,
+/* 5411 0x1523 "ᔣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x34,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x18,0x24,0x44,0x84,0x18,0x00,0x00,
+/* 5412 0x1524 "ᔤ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x0c,0x10,0x11,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x96,0x10,0x10,0x60,0x00,0x00,
+/* 5413 0x1525 "ᔥ" */
+0x00,0x00,0x00,0x00,0x48,0x54,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5414 0x1526 "ᔦ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x7c,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5415 0x1527 "ᔧ" */
+0x18,0x24,0x24,0x18,0x40,0x20,0x10,0x08,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5416 0x1528 "ᔨ" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5417 0x1529 "ᔩ" */
+0x00,0x60,0x60,0x00,0x40,0x20,0x10,0x08,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5418 0x152a "ᔪ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x7c,0x20,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5419 0x152b "ᔫ" */
+0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x04,0x04,0x7c,0x20,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5420 0x152c "ᔬ" */
+0x00,0x66,0x66,0x00,0x04,0x04,0x04,0x04,0x04,0x7c,0x20,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5421 0x152d "ᔭ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x7c,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5422 0x152e "ᔮ" */
+0x00,0x60,0x60,0x00,0x40,0x40,0x40,0x40,0x40,0x7c,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5423 0x152f "ᔯ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0xc8,0xd0,0x3e,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5424 0x1530 "ᔰ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x23,0x43,0xf8,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5425 0x1531 "ᔱ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x04,0xc2,0xdf,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5426 0x1532 "ᔲ" */
+0x00,0x00,0x00,0x00,0x80,0x40,0x26,0x16,0xf8,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5427 0x1533 "ᔳ" */
+0x00,0x18,0x18,0x00,0x10,0x08,0x04,0xc2,0xdf,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5428 0x1534 "ᔴ" */
+0x00,0xc0,0xc0,0x00,0x80,0x40,0x26,0x16,0xf8,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5429 0x1535 "ᔵ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x3e,0xd0,0xc8,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5430 0x1536 "ᔶ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xfb,0x43,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5431 0x1537 "ᔷ" */
+0x00,0x06,0x06,0x00,0x02,0x02,0x02,0x02,0x02,0x3e,0xd0,0xc8,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5432 0x1538 "ᔸ" */
+0x00,0x18,0x18,0x00,0x08,0x08,0x08,0x08,0x08,0xfb,0x43,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5433 0x1539 "ᔹ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0xdf,0xc2,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5434 0x153a "ᔺ" */
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xf8,0x16,0x26,0x40,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5435 0x153b "ᔻ" */
+0x00,0x18,0x18,0x00,0x10,0x10,0x10,0x10,0x10,0xdf,0xc2,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5436 0x153c "ᔼ" */
+0x00,0xc0,0xc0,0x00,0x80,0x80,0x80,0x80,0x80,0xf8,0x16,0x26,0x40,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5437 0x153d "ᔽ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0xd0,0x10,0x1f,0xc2,0xc4,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5438 0x153e "ᔾ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x3c,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5439 0x153f "ᔿ" */
+0x00,0x00,0x00,0x00,0x28,0x28,0x54,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5440 0x1540 "ᕀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5441 0x1541 "ᕁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5442 0x1542 "ᕂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 5443 0x1543 "ᕃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5444 0x1544 "ᕄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 5445 0x1545 "ᕅ" */
+0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x0f,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x00,0x00,
+/* 5446 0x1546 "ᕆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x00,0x00,
+/* 5447 0x1547 "ᕇ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x0f,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x00,0x00,
+/* 5448 0x1548 "ᕈ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x02,0x7c,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5449 0x1549 "ᕉ" */
+0x00,0x00,0x30,0x30,0x00,0x7c,0x02,0x02,0x02,0x02,0x7c,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5450 0x154a "ᕊ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7c,0x02,0x02,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5451 0x154b "ᕋ" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5452 0x154c "ᕌ" */
+0x00,0x00,0x18,0x18,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5453 0x154d "ᕍ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x3e,0x40,0x40,0x40,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5454 0x154e "ᕎ" */
+0x00,0x00,0x0c,0x0c,0x00,0x1f,0x20,0x20,0x20,0x20,0x1f,0xc1,0xc1,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5455 0x154f "ᕏ" */
+0x00,0x00,0x30,0x30,0x00,0x7c,0x80,0x80,0x83,0x83,0x7c,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5456 0x1550 "ᕐ" */
+0x00,0x00,0x00,0x00,0x18,0x20,0x20,0x18,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5457 0x1551 "ᕑ" */
+0x00,0x00,0x00,0x00,0x30,0x0c,0x30,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5458 0x1552 "ᕒ" */
+0x00,0x00,0x00,0x60,0x18,0x06,0x0c,0x30,0x40,0x30,0x0c,0x06,0x18,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5459 0x1553 "ᕓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5460 0x1554 "ᕔ" */
+0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x01,0x02,0x04,0x08,0x18,0x24,0x24,0x18,0x00,
+0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5461 0x1555 "ᕕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x18,0x24,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5462 0x1556 "ᕖ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x04,0x08,0x18,0x24,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 5463 0x1557 "ᕗ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5464 0x1558 "ᕘ" */
+0x00,0x06,0x06,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5465 0x1559 "ᕙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,
+/* 5466 0x155a "ᕚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x60,0x60,0x00,0x60,0x90,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,
+/* 5467 0x155b "ᕛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x32,0x32,0x01,0x00,0x00,0x00,0x00,
+0x00,0x18,0x18,0x00,0x18,0x24,0x64,0x98,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,
+/* 5468 0x155c "ᕜ" */
+0x00,0x01,0x01,0x00,0x01,0x02,0x06,0x09,0x10,0x20,0x20,0x10,0x08,0x04,0x02,0x01,
+0x00,0x80,0x80,0x00,0x80,0x40,0x40,0x80,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 5469 0x155d "ᕝ" */
+0x00,0x00,0x00,0x0c,0x12,0x2c,0x40,0x20,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5470 0x155e "ᕞ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1c,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5471 0x155f "ᕟ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x38,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5472 0x1560 "ᕠ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x1c,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5473 0x1561 "ᕡ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x38,0x48,0x48,0x30,0x00,0x00,
+/* 5474 0x1562 "ᕢ" */
+0x00,0x00,0x01,0x01,0x00,0x07,0x08,0x10,0x10,0x10,0x1c,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5475 0x1563 "ᕣ" */
+0x00,0x00,0x01,0x01,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0xe0,0x10,0x08,0x08,0x08,0x38,0x48,0x48,0x30,0x00,0x00,
+/* 5476 0x1564 "ᕤ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5477 0x1565 "ᕥ" */
+0x00,0x01,0x01,0x00,0x07,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x80,0x80,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5478 0x1566 "ᕦ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 5479 0x1567 "ᕧ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0xc0,0xc0,0x00,0xf0,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 5480 0x1568 "ᕨ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x34,0x34,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x60,0x60,0x00,0xf8,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 5481 0x1569 "ᕩ" */
+0x00,0x03,0x03,0x00,0x0f,0x11,0x21,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x0c,0x0c,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 5482 0x156a "ᕪ" */
+0x00,0x00,0x00,0x00,0x1c,0x2a,0x2a,0x24,0x20,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5483 0x156b "ᕫ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5484 0x156c "ᕬ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x11,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 5485 0x156d "ᕭ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5486 0x156e "ᕮ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 5487 0x156f "ᕯ" */
+0x00,0x00,0x00,0x00,0x08,0x2a,0x1c,0x08,0x1c,0x2a,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x54,0x38,0x10,0x38,0x54,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 5488 0x1570 "ᕰ" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x13,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x90,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5489 0x1571 "ᕱ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x13,0x14,0x14,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x90,0x50,0x50,0x50,0x50,0x00,0x00,
+/* 5490 0x1572 "ᕲ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x1e,0x01,0x01,0x01,0x1e,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5491 0x1573 "ᕳ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x78,0x80,0x80,0x80,0x78,0x00,0xf8,0x00,0x00,
+/* 5492 0x1574 "ᕴ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 5493 0x1575 "ᕵ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,0x12,0x0a,0x06,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5494 0x1576 "ᕶ" */
+0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x02,0x02,0x03,0x12,0x0a,0x06,0x02,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5495 0x1577 "ᕷ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5496 0x1578 "ᕸ" */
+0x00,0x00,0x03,0x03,0x00,0x01,0x01,0x01,0x01,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5497 0x1579 "ᕹ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x12,0x03,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 5498 0x157a "ᕺ" */
+0x00,0x00,0x03,0x03,0x00,0x02,0x06,0x0a,0x12,0x03,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 5499 0x157b "ᕻ" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x1c,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5500 0x157c "ᕼ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5501 0x157d "ᕽ" */
+0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5502 0x157e "ᕾ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0x48,0x30,0x00,0x70,0x88,0x88,0x88,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 5503 0x157f "ᕿ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 5504 0x1580 "ᖀ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0x60,0x00,0x70,0x88,0x88,0x88,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 5505 0x1581 "ᖁ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x78,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5506 0x1582 "ᖂ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x18,0x18,0x00,0x08,0x08,0x08,0x08,0x78,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5507 0x1583 "ᖃ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5508 0x1584 "ᖄ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x00,0x80,0x80,0x80,0x80,0xf0,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 5509 0x1585 "ᖅ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x08,0x08,0x06,0x02,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x70,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 5510 0x1586 "ᖆ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x05,0x05,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5511 0x1587 "ᖇ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x1e,0x14,0x14,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5512 0x1588 "ᖈ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x05,0x05,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5513 0x1589 "ᖉ" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x14,0x14,0x1e,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5514 0x158a "ᖊ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 5515 0x158b "ᖋ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x12,0x0a,0x06,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5516 0x158c "ᖌ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5517 0x158d "ᖍ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x12,0x02,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 5518 0x158e "ᖎ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x0c,0x12,0x12,0x0c,0x00,0x1c,0x22,0x22,0x22,0xa0,0xa0,0x20,0x20,0x20,0x00,0x00,
+/* 5519 0x158f "ᖏ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0xa0,0xa0,0x20,0x20,0x20,0x00,0x00,
+/* 5520 0x1590 "ᖐ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x18,0x18,0x00,0x1c,0x22,0x22,0x22,0xa0,0xa0,0x20,0x20,0x20,0x00,0x00,
+/* 5521 0x1591 "ᖑ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x82,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5522 0x1592 "ᖒ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x06,0x06,0x00,0x02,0x02,0x02,0x02,0x82,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5523 0x1593 "ᖓ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xa0,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5524 0x1594 "ᖔ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0x30,0x00,0x20,0x20,0x20,0x20,0xa0,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5525 0x1595 "ᖕ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x90,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 5526 0x1596 "ᖖ" */
+0x00,0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0xe0,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 5527 0x1597 "ᖗ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x4a,0x4a,0x32,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5528 0x1598 "ᖘ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x52,0x52,0x4c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5529 0x1599 "ᖙ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x32,0x4a,0x4a,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5530 0x159a "ᖚ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x4c,0x52,0x52,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5531 0x159b "ᖛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x1f,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5532 0x159c "ᖜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5533 0x159d "ᖝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5534 0x159e "ᖞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x0e,0x11,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5535 0x159f "ᖟ" */
+0x00,0x00,0x00,0x3f,0x00,0x30,0x48,0x48,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5536 0x15a0 "ᖠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5537 0x15a1 "ᖡ" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x20,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5538 0x15a2 "ᖢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 5539 0x15a3 "ᖣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xc0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 5540 0x15a4 "ᖤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x20,0x40,0x80,0x00,0x00,
+/* 5541 0x15a5 "ᖥ" */
+0x00,0x00,0x00,0x06,0x06,0x00,0x0e,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x20,0x40,0x80,0x00,0x00,
+/* 5542 0x15a6 "ᖦ" */
+0x00,0x00,0x00,0x00,0x30,0x40,0x40,0x3c,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5543 0x15a7 "ᖧ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x7c,0x04,0x3e,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5544 0x15a8 "ᖨ" */
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x3e,0x20,0x7c,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5545 0x15a9 "ᖩ" */
+0x00,0x60,0x60,0x00,0x20,0x10,0x08,0x04,0x3e,0x20,0x7c,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5546 0x15aa "ᖪ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x3e,0x04,0x7c,0x20,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5547 0x15ab "ᖫ" */
+0x00,0x0c,0x0c,0x00,0x04,0x04,0x04,0x3e,0x04,0x7c,0x20,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5548 0x15ac "ᖬ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x7c,0x20,0x3e,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5549 0x15ad "ᖭ" */
+0x00,0x30,0x30,0x00,0x20,0x20,0x20,0x7c,0x20,0x3e,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5550 0x15ae "ᖮ" */
+0x00,0x00,0x00,0x00,0x20,0x78,0x20,0x3c,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5551 0x15af "ᖯ" */
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xbc,0xc2,0x82,0x82,0xc2,0xbc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5552 0x15b0 "ᖰ" */
+0x00,0x00,0x00,0x00,0x00,0xbc,0xfe,0xfe,0xfe,0xfe,0xbc,0x80,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5553 0x15b1 "ᖱ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x7a,0xfe,0xfe,0xfe,0xfe,0x7a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5554 0x15b2 "ᖲ" */
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xbc,0xfe,0xfe,0xfe,0xfe,0xbc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5555 0x15b3 "ᖳ" */
+0x00,0x00,0x00,0x00,0x00,0x7a,0xfe,0xfe,0xfe,0xfe,0x7a,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5556 0x15b4 "ᖴ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5557 0x15b5 "ᖵ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5558 0x15b6 "ᖶ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5559 0x15b7 "ᖷ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5560 0x15b8 "ᖸ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x0a,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5561 0x15b9 "ᖹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x70,0x00,0x00,
+/* 5562 0x15ba "ᖺ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0a,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x00,0x00,
+/* 5563 0x15bb "ᖻ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 5564 0x15bc "ᖼ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5565 0x15bd "ᖽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x30,0x00,0x00,
+/* 5566 0x15be "ᖾ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,
+/* 5567 0x15bf "ᖿ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 5568 0x15c0 "ᗀ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x90,0x90,0x50,0x50,0x50,0x30,0x00,0x00,
+/* 5569 0x15c1 "ᗁ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x12,0x12,0x14,0x14,0x14,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5570 0x15c2 "ᗂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x50,0x50,0x50,0x90,0x90,0x10,0x10,0x10,0x00,0x00,
+/* 5571 0x15c3 "ᗃ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x14,0x14,0x14,0x12,0x12,0x11,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5572 0x15c4 "ᗄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x0f,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0xf0,0x20,0x40,0x80,0x00,0x00,
+/* 5573 0x15c5 "ᗅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x0f,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x08,0x04,0x02,0x00,0x00,
+/* 5574 0x15c6 "ᗆ" */
+0x00,0x00,0x08,0x04,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5575 0x15c7 "ᗇ" */
+0x00,0x00,0x08,0x04,0x02,0x01,0x01,0x05,0x05,0x05,0x05,0x01,0x01,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5576 0x15c8 "ᗈ" */
+0x00,0x00,0x08,0x04,0x02,0x01,0x01,0x01,0x0d,0x0d,0x01,0x01,0x01,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5577 0x15c9 "ᗉ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x06,0x0a,0x12,0x12,0x0a,0x06,0x02,0x01,0x00,0x00,
+0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,
+/* 5578 0x15ca "ᗊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x3f,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xfc,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 5579 0x15cb "ᗋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x3f,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0xfc,0x02,0x00,0x00,
+/* 5580 0x15cc "ᗌ" */
+0x00,0x00,0x08,0x04,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x06,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5581 0x15cd "ᗍ" */
+0x00,0x00,0x08,0x04,0x06,0x05,0x04,0x05,0x05,0x05,0x05,0x04,0x05,0x06,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5582 0x15ce "ᗎ" */
+0x00,0x00,0x08,0x04,0x06,0x05,0x04,0x04,0x05,0x05,0x04,0x04,0x05,0x06,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xa0,0xa0,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5583 0x15cf "ᗏ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x40,
+/* 5584 0x15d0 "ᗐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x21,0x11,0x09,0x05,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 5585 0x15d1 "ᗑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x05,0x09,0x11,0x21,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 5586 0x15d2 "ᗒ" */
+0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5587 0x15d3 "ᗓ" */
+0x00,0x00,0x04,0x02,0x01,0x00,0x04,0x04,0x0f,0x04,0x04,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5588 0x15d4 "ᗔ" */
+0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x06,0x0f,0x06,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5589 0x15d5 "ᗕ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x0f,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x80,0x40,0x20,0x00,
+/* 5590 0x15d6 "ᗖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x21,0x1f,0x09,0x05,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 5591 0x15d7 "ᗗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x05,0x09,0x1f,0x21,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x08,0x04,0x00,0x00,
+/* 5592 0x15d8 "ᗘ" */
+0x00,0x00,0x04,0x02,0x01,0x01,0x01,0x01,0x07,0x01,0x01,0x01,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5593 0x15d9 "ᗙ" */
+0x00,0x00,0x04,0x02,0x01,0x01,0x05,0x05,0x0f,0x05,0x05,0x01,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5594 0x15da "ᗚ" */
+0x00,0x00,0x04,0x02,0x01,0x01,0x01,0x0d,0x1f,0x0d,0x01,0x01,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5595 0x15db "ᗛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x07,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x20,0x40,0xc0,0x40,0x40,0xf0,0x40,0x40,0xc0,0x40,0x20,0x10,0x00,
+/* 5596 0x15dc "ᗜ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5597 0x15dd "ᗝ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 5598 0x15de "ᗞ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5599 0x15df "ᗟ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x11,0x11,0x11,0x11,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5600 0x15e0 "ᗠ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x13,0x13,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5601 0x15e1 "ᗡ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 5602 0x15e2 "ᗢ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x14,0x12,0x11,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5603 0x15e3 "ᗣ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 5604 0x15e4 "ᗤ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5605 0x15e5 "ᗥ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x48,0x48,0x48,0x48,0x08,0x10,0xe0,0x00,0x00,
+/* 5606 0x15e6 "ᗦ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xc8,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5607 0x15e7 "ᗧ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x10,0x20,0x40,0x40,0x20,0x10,0x08,0xf8,0x00,0x00,
+/* 5608 0x15e8 "ᗨ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5609 0x15e9 "ᗩ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5610 0x15ea "ᗪ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5611 0x15eb "ᗫ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x90,0x90,0x90,0x10,0x20,0xc0,0x00,0x00,
+/* 5612 0x15ec "ᗬ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x05,0x05,0x04,0x04,0x04,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x90,0x90,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5613 0x15ed "ᗭ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xf0,0x00,0x00,
+/* 5614 0x15ee "ᗮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5615 0x15ef "ᗯ" */
+0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x88,0x70,0x00,0x00,
+/* 5616 0x15f0 "ᗰ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 5617 0x15f1 "ᗱ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5618 0x15f2 "ᗲ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x02,0x0f,0x02,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5619 0x15f3 "ᗳ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x06,0x0f,0x06,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5620 0x15f4 "ᗴ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5621 0x15f5 "ᗵ" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x88,0x70,0x00,0x00,
+/* 5622 0x15f6 "ᗶ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 5623 0x15f7 "ᗷ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5624 0x15f8 "ᗸ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0xe0,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 5625 0x15f9 "ᗹ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x09,0x0f,0x09,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0xe0,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 5626 0x15fa "ᗺ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 5627 0x15fb "ᗻ" */
+0x00,0x00,0x00,0x00,0x00,0x61,0x59,0x47,0x41,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x34,0xc4,0x04,0x04,0x04,0x04,0x88,0x70,0x00,0x00,
+/* 5628 0x15fc "ᗼ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x41,0x47,0x59,0x61,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x04,0xc4,0x34,0x0c,0x00,0x00,
+/* 5629 0x15fd "ᗽ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x0f,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5630 0x15fe "ᗾ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x0f,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x50,0xe0,0x50,0x10,0x10,0xe0,0x00,0x00,
+/* 5631 0x15ff "ᗿ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x0f,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xd0,0xe0,0xd0,0x10,0x10,0xe0,0x00,0x00,
+/* 5632 0x1600 "ᘀ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0xf0,0x40,0x20,0x10,0xf0,0x00,0x00,
+/* 5633 0x1601 "ᘁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5634 0x1602 "ᘂ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5635 0x1603 "ᘃ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5636 0x1604 "ᘄ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5637 0x1605 "ᘅ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5638 0x1606 "ᘆ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5639 0x1607 "ᘇ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5640 0x1608 "ᘈ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x88,0x70,0x00,0x00,
+/* 5641 0x1609 "ᘉ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 5642 0x160a "ᘊ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5643 0x160b "ᘋ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5644 0x160c "ᘌ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x03,0x07,0x03,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5645 0x160d "ᘍ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5646 0x160e "ᘎ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x11,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5647 0x160f "ᘏ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x13,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x88,0x88,0x88,0x08,0x00,0x00,
+/* 5648 0x1610 "ᘐ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x0e,0x11,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5649 0x1611 "ᘑ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x01,0x0f,0x11,0x11,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5650 0x1612 "ᘒ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x03,0x0f,0x13,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x90,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5651 0x1613 "ᘓ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x11,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5652 0x1614 "ᘔ" */
+0x00,0x00,0x00,0x00,0x1f,0x03,0x04,0x08,0x08,0x11,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5653 0x1615 "ᘕ" */
+0x00,0x00,0x00,0x00,0x1f,0x01,0x00,0x00,0x0e,0x11,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x80,0x40,0x20,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5654 0x1616 "ᘖ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x11,0x0e,0x00,0x00,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0xf0,0x00,0x00,
+/* 5655 0x1617 "ᘗ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x13,0x14,0x18,0x18,0x11,0x11,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xc8,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5656 0x1618 "ᘘ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x13,0x14,0x18,0x18,0x11,0x11,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x48,0xc8,0x48,0x48,0x08,0xf0,0x00,0x00,
+/* 5657 0x1619 "ᘙ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x13,0x14,0x18,0x19,0x12,0x12,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0xc8,0xe8,0xc8,0x08,0x08,0xf0,0x00,0x00,
+/* 5658 0x161a "ᘚ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x11,0x18,0x18,0x14,0x13,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5659 0x161b "ᘛ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x13,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x88,0x88,0x88,0x18,0x18,0x28,0xc8,0x08,0x00,0x00,
+/* 5660 0x161c "ᘜ" */
+0x00,0x00,0x00,0x00,0x10,0x0b,0x04,0x08,0x08,0x11,0x11,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5661 0x161d "ᘝ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x11,0x11,0x0e,0x00,0x00,0x01,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x20,0x40,0xa0,0x10,0x00,0x00,
+/* 5662 0x161e "ᘞ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x0b,0x04,0x08,0x08,0x11,0x11,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xc8,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5663 0x161f "ᘟ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x0b,0x04,0x08,0x08,0x11,0x11,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x48,0xc8,0x48,0x48,0x08,0xf0,0x00,0x00,
+/* 5664 0x1620 "ᘠ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x0b,0x04,0x08,0x09,0x12,0x12,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0xc8,0xe8,0xc8,0x08,0x08,0xf0,0x00,0x00,
+/* 5665 0x1621 "ᘡ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x13,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x88,0x88,0x88,0x10,0x10,0x20,0xd0,0x08,0x00,0x00,
+/* 5666 0x1622 "ᘢ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x04,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5667 0x1623 "ᘣ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0x78,0x00,0x00,
+/* 5668 0x1624 "ᘤ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x18,0x10,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5669 0x1625 "ᘥ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x18,0x11,0x01,0x01,0x01,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5670 0x1626 "ᘦ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x18,0x10,0x03,0x03,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5671 0x1627 "ᘧ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5672 0x1628 "ᘨ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x78,0x48,0x20,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5673 0x1629 "ᘩ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0x20,0x48,0x78,0x08,0x00,
+/* 5674 0x162a "ᘪ" */
+0x00,0x00,0x00,0x00,0x1c,0x09,0x0a,0x0c,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5675 0x162b "ᘫ" */
+0x00,0x00,0x00,0x00,0x1c,0x09,0x0a,0x0c,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x88,0x88,0x88,0x88,0x08,0x10,0xe0,0x00,0x00,
+/* 5676 0x162c "ᘬ" */
+0x00,0x00,0x00,0x00,0x1c,0x09,0x0a,0x0c,0x01,0x01,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x88,0x88,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5677 0x162d "ᘭ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x90,0x50,0x30,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 5678 0x162e "ᘮ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x04,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x20,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5679 0x162f "ᘯ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x04,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0x78,0x00,0x00,
+/* 5680 0x1630 "ᘰ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x18,0x10,0x00,0x00,0x10,0x18,0x14,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5681 0x1631 "ᘱ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x18,0x11,0x01,0x01,0x11,0x18,0x14,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5682 0x1632 "ᘲ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x18,0x10,0x03,0x03,0x10,0x18,0x14,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5683 0x1633 "ᘳ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x00,0x00,0x10,0x30,0x50,0x90,0x00,0x00,
+/* 5684 0x1634 "ᘴ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x78,0x48,0x20,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5685 0x1635 "ᘵ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x04,0x12,0x1e,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0x20,0x40,0x78,0x00,0x00,
+/* 5686 0x1636 "ᘶ" */
+0x00,0x00,0x00,0x00,0x39,0x12,0x14,0x18,0x00,0x00,0x18,0x14,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5687 0x1637 "ᘷ" */
+0x00,0x00,0x00,0x00,0x39,0x12,0x14,0x18,0x00,0x00,0x18,0x14,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x90,0x90,0x90,0x10,0x20,0xc0,0x00,0x00,
+/* 5688 0x1638 "ᘸ" */
+0x00,0x00,0x00,0x00,0x39,0x12,0x14,0x18,0x01,0x01,0x18,0x14,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x90,0x90,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5689 0x1639 "ᘹ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x90,0x50,0x30,0x00,0x00,0x30,0x50,0x90,0x10,0x00,0x00,
+/* 5690 0x163a "ᘺ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x04,0x08,0x10,0x10,0x11,0x11,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x78,0x48,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5691 0x163b "ᘻ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x11,0x11,0x10,0x10,0x08,0x04,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0x48,0x78,0x08,0x00,
+/* 5692 0x163c "ᘼ" */
+0x00,0x00,0x00,0x00,0x38,0x13,0x14,0x18,0x00,0x00,0x00,0x18,0x14,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5693 0x163d "ᘽ" */
+0x00,0x00,0x00,0x00,0x38,0x13,0x14,0x18,0x02,0x02,0x02,0x18,0x14,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5694 0x163e "ᘾ" */
+0x00,0x00,0x00,0x00,0x38,0x13,0x14,0x18,0x02,0x07,0x02,0x18,0x14,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x60,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 5695 0x163f "ᘿ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x0e,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x90,0x50,0x30,0x00,0x00,0x00,0x30,0x50,0x90,0x00,0x00,
+/* 5696 0x1640 "ᙀ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x20,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5697 0x1641 "ᙁ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x04,0x04,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0x20,0x20,0x18,0x00,0x00,
+/* 5698 0x1642 "ᙂ" */
+0x00,0x00,0x00,0x00,0x23,0x24,0x18,0x00,0x00,0x00,0x00,0x18,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5699 0x1643 "ᙃ" */
+0x00,0x00,0x00,0x00,0x23,0x24,0x18,0x00,0x00,0x00,0x00,0x18,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x88,0x88,0x88,0x88,0x08,0x10,0xe0,0x00,0x00,
+/* 5700 0x1644 "ᙄ" */
+0x00,0x00,0x00,0x00,0x23,0x24,0x18,0x00,0x01,0x01,0x00,0x18,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x88,0x88,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5701 0x1645 "ᙅ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x48,0x30,0x00,0x00,0x00,0x00,0x30,0x48,0x88,0x00,0x00,
+/* 5702 0x1646 "ᙆ" */
+0x00,0x00,0x00,0x00,0x7c,0x08,0x10,0x20,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5703 0x1647 "ᙇ" */
+0x00,0x00,0x10,0x10,0x7c,0x08,0x10,0x20,0x7c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5704 0x1648 "ᙈ" */
+0x00,0x00,0x00,0x00,0x00,0x33,0x09,0x09,0x10,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x98,0x20,0x20,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5705 0x1649 "ᙉ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x10,0x09,0x09,0x33,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0x20,0x20,0x98,0x00,0x00,
+/* 5706 0x164a "ᙊ" */
+0x00,0x00,0x00,0x23,0x24,0x18,0x00,0x20,0x38,0x20,0x00,0x18,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5707 0x164b "ᙋ" */
+0x00,0x00,0x00,0x23,0x24,0x18,0x00,0x20,0x38,0x20,0x00,0x18,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x88,0x88,0x88,0x88,0x88,0x08,0x10,0xe0,0x00,0x00,
+/* 5708 0x164c "ᙌ" */
+0x00,0x00,0x00,0x23,0x24,0x18,0x00,0x20,0x39,0x20,0x00,0x18,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xc8,0xe8,0xc8,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 5709 0x164d "ᙍ" */
+0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x88,0x48,0x30,0x00,0x08,0x38,0x08,0x00,0x30,0x48,0x88,0x00,0x00,
+/* 5710 0x164e "ᙎ" */
+0x00,0x00,0x00,0x00,0x00,0x31,0x09,0x09,0x11,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x20,0x10,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5711 0x164f "ᙏ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x11,0x09,0x09,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x18,0x20,0x20,0x18,0x00,0x00,
+/* 5712 0x1650 "ᙐ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x00,0x00,0x1f,0x00,0x00,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5713 0x1651 "ᙑ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x00,0x00,0x1f,0x00,0x00,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0x90,0xe0,0x90,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 5714 0x1652 "ᙒ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x00,0x01,0x1f,0x01,0x00,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x90,0xe0,0x90,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5715 0x1653 "ᙓ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x90,0x60,0x00,0x00,0xf0,0x00,0x00,0x60,0x90,0x10,0x00,0x00,
+/* 5716 0x1654 "ᙔ" */
+0x00,0x00,0x00,0x00,0x00,0x31,0x09,0x0f,0x11,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x20,0xe0,0x10,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5717 0x1655 "ᙕ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x11,0x0f,0x09,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x18,0xe0,0x20,0x18,0x00,0x00,
+/* 5718 0x1656 "ᙖ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x04,0x1f,0x04,0x04,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5719 0x1657 "ᙗ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x04,0x1f,0x04,0x04,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0x90,0xe0,0x90,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 5720 0x1658 "ᙘ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x05,0x1f,0x05,0x04,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x90,0xe0,0x90,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5721 0x1659 "ᙙ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x90,0x60,0x40,0x40,0xf0,0x40,0x40,0x60,0x90,0x10,0x00,0x00,
+/* 5722 0x165a "ᙚ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x3c,0x50,0x38,0x14,0x78,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5723 0x165b "ᙛ" */
+0x00,0x00,0x00,0x00,0x00,0x33,0x09,0x0f,0x11,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x98,0x20,0xe0,0x10,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5724 0x165c "ᙜ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x11,0x0f,0x09,0x33,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x18,0xe0,0x20,0x98,0x00,0x00,
+/* 5725 0x165d "ᙝ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x14,0x1f,0x14,0x04,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5726 0x165e "ᙞ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x14,0x1f,0x14,0x04,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0x90,0xe0,0x90,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 5727 0x165f "ᙟ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x15,0x1f,0x15,0x04,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x90,0xe0,0x90,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5728 0x1660 "ᙠ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x90,0x60,0x40,0x50,0xf0,0x50,0x40,0x60,0x90,0x10,0x00,0x00,
+/* 5729 0x1661 "ᙡ" */
+0x00,0x00,0x00,0x00,0x00,0x33,0x09,0x09,0x11,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x98,0x20,0x20,0x10,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5730 0x1662 "ᙢ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x11,0x09,0x09,0x33,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x18,0x20,0x20,0x98,0x00,0x00,
+/* 5731 0x1663 "ᙣ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x00,0x10,0x1f,0x10,0x00,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5732 0x1664 "ᙤ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x00,0x10,0x1f,0x10,0x00,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0x90,0xe0,0x90,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 5733 0x1665 "ᙥ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x00,0x11,0x1f,0x11,0x00,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x90,0xe0,0x90,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5734 0x1666 "ᙦ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x90,0x60,0x00,0x10,0xf0,0x10,0x00,0x60,0x90,0x10,0x00,0x00,
+/* 5735 0x1667 "ᙧ" */
+0x00,0x00,0x00,0x00,0x00,0x33,0x09,0x09,0x15,0x23,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x98,0x20,0x20,0x50,0x88,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 5736 0x1668 "ᙨ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x23,0x15,0x09,0x09,0x33,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x88,0x58,0x20,0x20,0x98,0x00,0x00,
+/* 5737 0x1669 "ᙩ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x02,0x11,0x1f,0x11,0x02,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5738 0x166a "ᙪ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x02,0x11,0x1f,0x11,0x02,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x50,0x50,0xe0,0x50,0x50,0x10,0x10,0xe0,0x00,0x00,
+/* 5739 0x166b "ᙫ" */
+0x00,0x00,0x00,0x11,0x12,0x0c,0x04,0x12,0x1f,0x12,0x06,0x0c,0x12,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xd0,0xe0,0xd0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 5740 0x166c "ᙬ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x11,0x0f,0x11,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x90,0x60,0x80,0x10,0xf0,0x10,0x80,0x60,0x90,0x10,0x00,0x00,
+/* 5741 0x166d "᙭" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5742 0x166e "᙮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x28,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5743 0x166f "ᙯ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x78,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 5744 0x1670 "ᙰ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x3c,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x82,0x82,0x02,0x02,0x02,0x00,0x00,
+/* 5745 0x1671 "ᙱ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x3e,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0xa0,0xa0,0x20,0x20,0x20,0x00,0x00,
+/* 5746 0x1672 "ᙲ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x3e,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x18,0x18,0x00,0x1c,0x22,0x22,0x22,0xa0,0xa0,0x20,0x20,0x20,0x00,0x00,
+/* 5747 0x1673 "ᙳ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x3e,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x82,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5748 0x1674 "ᙴ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x3e,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x06,0x06,0x00,0x02,0x02,0x02,0x02,0x82,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5749 0x1675 "ᙵ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x3e,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xa0,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5750 0x1676 "ᙶ" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x3e,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0x30,0x00,0x20,0x20,0x20,0x20,0xa0,0xa2,0x22,0x22,0x1c,0x00,0x00,
+/* 5751 0x1677 "ᙷ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x26,0x46,0xf8,0x08,0x7c,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5752 0x1678 "ᙸ" */
+0x00,0x00,0x00,0x00,0x40,0x23,0x13,0x08,0x7c,0x40,0xf8,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5753 0x1679 "ᙹ" */
+0x00,0x60,0x60,0x00,0x40,0x23,0x13,0x08,0x7c,0x40,0xf8,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5754 0x167a "ᙺ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x7c,0x08,0xf8,0x46,0x26,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5755 0x167b "ᙻ" */
+0x00,0x18,0x18,0x00,0x08,0x08,0x08,0x7c,0x08,0xf8,0x46,0x26,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5756 0x167c "ᙼ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xf8,0x40,0x7c,0x0b,0x13,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5757 0x167d "ᙽ" */
+0x00,0x60,0x60,0x00,0x40,0x40,0x40,0xf8,0x40,0x7c,0x0b,0x13,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5758 0x167e "ᙾ" */
+0x00,0x00,0x00,0x10,0x7c,0x10,0x7c,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5759 0x167f "ᙿ" */
+0x00,0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5760 0x1680 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5761 0x1681 "ᚁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5762 0x1682 "ᚂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 5763 0x1683 "ᚃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x05,0x05,0x05,0x05,0x05,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 5764 0x1684 "ᚄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0x00,0x00,
+/* 5765 0x1685 "ᚅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x15,0x15,0x15,0x15,0x15,0x15,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x50,0x50,0x50,0x50,0x50,0x50,0x00,0x00,
+/* 5766 0x1686 "ᚆ" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5767 0x1687 "ᚇ" */
+0x00,0x02,0x02,0x02,0x02,0x02,0x02,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5768 0x1688 "ᚈ" */
+0x00,0x05,0x05,0x05,0x05,0x05,0x05,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x40,0x40,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5769 0x1689 "ᚉ" */
+0x00,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5770 0x168a "ᚊ" */
+0x00,0x15,0x15,0x15,0x15,0x15,0x15,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x50,0x50,0x50,0x50,0x50,0x50,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5771 0x168b "ᚋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xff,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x80,0x80,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5772 0x168c "ᚌ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x02,0xff,0x02,0x05,0x05,0x0a,0x0a,0x00,0x00,0x00,
+0x00,0x00,0xa0,0xa0,0x40,0x40,0x80,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5773 0x168d "ᚍ" */
+0x00,0x00,0x01,0x01,0x02,0x02,0x05,0xff,0x05,0x0a,0x0a,0x15,0x15,0x00,0x00,0x00,
+0x00,0x00,0x50,0x50,0xa0,0xa0,0x40,0xff,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 5774 0x168e "ᚎ" */
+0x00,0x00,0x02,0x02,0x05,0x05,0x0a,0xff,0x0a,0x15,0x15,0x2a,0x2a,0x00,0x00,0x00,
+0x00,0x00,0xa8,0xa8,0x50,0x50,0xa0,0xff,0xa0,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 5775 0x168f "ᚏ" */
+0x00,0x00,0x05,0x05,0x0a,0x0a,0x15,0xff,0x15,0x2a,0x2a,0x55,0x55,0x00,0x00,0x00,
+0x00,0x00,0x54,0x54,0xa8,0xa8,0x50,0xff,0x50,0xa0,0xa0,0x40,0x40,0x00,0x00,0x00,
+/* 5776 0x1690 "ᚐ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0xff,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5777 0x1691 "ᚑ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xff,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xff,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5778 0x1692 "ᚒ" */
+0x00,0x00,0x00,0x00,0x00,0x05,0x05,0xff,0x05,0x05,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xff,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5779 0x1693 "ᚓ" */
+0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0xff,0x0a,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa0,0xa0,0xff,0xa0,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5780 0x1694 "ᚔ" */
+0x00,0x00,0x00,0x00,0x00,0x15,0x15,0xff,0x15,0x15,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0xff,0x50,0x50,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5781 0x1695 "ᚕ" */
+0x00,0x00,0x04,0x04,0x02,0x02,0x01,0xff,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x80,0x80,0x00,0xff,0x00,0x80,0x80,0x40,0x40,0x00,0x00,0x00,
+/* 5782 0x1696 "ᚖ" */
+0x00,0x01,0x01,0x02,0x02,0x04,0x04,0xff,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0xff,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 5783 0x1697 "ᚗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x09,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xc0,0x40,0x40,0xc0,0x00,0x00,
+/* 5784 0x1698 "ᚘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x12,0x09,0x06,0x06,0x09,0x12,0x24,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x90,0x20,0xc0,0xc0,0x20,0x90,0x48,0x00,
+/* 5785 0x1699 "ᚙ" */
+0x05,0x0f,0x05,0x0f,0x05,0x0f,0x05,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x50,0xf8,0x50,0xf8,0x50,0xf8,0x50,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5786 0x169a "ᚚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5787 0x169b "᚛" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5788 0x169c "᚜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,0x00,
+/* 5789 0x169d "᚝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5790 0x169e "᚞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5791 0x169f "᚟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 5792 0x16a0 "ᚠ" */
+0x00,0x92,0xa4,0xc8,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5793 0x16a1 "ᚡ" */
+0x00,0xaa,0x94,0xa8,0xd0,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5794 0x16a2 "ᚢ" */
+0x00,0x40,0x60,0x50,0x48,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5795 0x16a3 "ᚣ" */
+0x00,0x80,0xc0,0xa0,0x90,0x88,0x84,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5796 0x16a4 "ᚤ" */
+0x00,0x40,0x60,0x50,0x48,0x44,0x42,0x42,0x5a,0x5a,0x42,0x42,0x42,0x42,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5797 0x16a5 "ᚥ" */
+0x00,0x80,0xc0,0xa0,0x90,0x88,0x84,0xc2,0xa2,0x92,0x92,0x92,0x92,0x92,0x92,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5798 0x16a6 "ᚦ" */
+0x00,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5799 0x16a7 "ᚧ" */
+0x00,0x40,0x40,0x40,0x60,0x50,0x48,0x54,0x54,0x48,0x50,0x60,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5800 0x16a8 "ᚨ" */
+0x00,0x20,0x30,0x28,0x24,0x30,0x28,0x24,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5801 0x16a9 "ᚩ" */
+0x00,0x80,0xc2,0xa4,0x98,0xc2,0xa4,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5802 0x16aa "ᚪ" */
+0x00,0x80,0xc2,0xa4,0x98,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5803 0x16ab "ᚫ" */
+0x00,0x40,0x60,0x50,0x48,0x64,0x50,0x48,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5804 0x16ac "ᚬ" */
+0x00,0x10,0x10,0x90,0x50,0x30,0x90,0x58,0x34,0x12,0x18,0x14,0x12,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5805 0x16ad "ᚭ" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x30,0x28,0x24,0x30,0x28,0x24,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5806 0x16ae "ᚮ" */
+0x00,0x08,0x08,0x08,0x08,0x08,0x18,0x28,0x48,0x18,0x28,0x48,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5807 0x16af "ᚯ" */
+0x00,0x10,0x10,0x12,0x14,0x18,0x12,0x34,0x58,0x90,0x30,0x50,0x90,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5808 0x16b0 "ᚰ" */
+0x00,0x10,0x10,0x12,0x14,0x18,0x10,0x30,0x50,0x90,0x30,0x50,0x90,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5809 0x16b1 "ᚱ" */
+0x00,0x80,0xc0,0xa0,0x90,0x88,0x84,0x88,0x90,0xa0,0xa0,0x90,0x88,0x84,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5810 0x16b2 "ᚲ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5811 0x16b3 "ᚳ" */
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xc0,0xa0,0x90,0x88,0x84,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5812 0x16b4 "ᚴ" */
+0x00,0x82,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5813 0x16b5 "ᚵ" */
+0x00,0xb2,0xb4,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5814 0x16b6 "ᚶ" */
+0x00,0x42,0x44,0x48,0x50,0xe0,0xe0,0xe0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5815 0x16b7 "ᚷ" */
+0x00,0x82,0x82,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5816 0x16b8 "ᚸ" */
+0x00,0x82,0x82,0x44,0x44,0x28,0x28,0x54,0x54,0x28,0x28,0x44,0x44,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5817 0x16b9 "ᚹ" */
+0x00,0x40,0x60,0x50,0x48,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5818 0x16ba "ᚺ" */
+0x00,0x82,0x82,0x82,0x82,0x82,0xe2,0x92,0x8e,0x82,0x82,0x82,0x82,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5819 0x16bb "ᚻ" */
+0x00,0x82,0x82,0x82,0x82,0xe2,0x92,0x8e,0xe2,0x92,0x8e,0x82,0x82,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5820 0x16bc "ᚼ" */
+0x00,0x10,0x10,0x10,0x92,0x54,0x38,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5821 0x16bd "ᚽ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x38,0x38,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5822 0x16be "ᚾ" */
+0x00,0x10,0x10,0x10,0x90,0x50,0x30,0x10,0x18,0x14,0x12,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5823 0x16bf "ᚿ" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x30,0x28,0x24,0x22,0x20,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5824 0x16c0 "ᛀ" */
+0x00,0x10,0x10,0x10,0x90,0x50,0x38,0x38,0x38,0x14,0x12,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5825 0x16c1 "ᛁ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5826 0x16c2 "ᛂ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x38,0x38,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5827 0x16c3 "ᛃ" */
+0x00,0x00,0x00,0x10,0x20,0x40,0x88,0x44,0x22,0x04,0x08,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5828 0x16c4 "ᛄ" */
+0x00,0x10,0x10,0x10,0x10,0x38,0x54,0x92,0x92,0x54,0x38,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5829 0x16c5 "ᛅ" */
+0x00,0x10,0x10,0x10,0x12,0x14,0x18,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5830 0x16c6 "ᛆ" */
+0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5831 0x16c7 "ᛇ" */
+0x00,0x10,0x18,0x14,0x12,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x30,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5832 0x16c8 "ᛈ" */
+0x00,0x82,0xc4,0xa8,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x90,0xa8,0xc4,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5833 0x16c9 "ᛉ" */
+0x00,0x92,0x92,0x54,0x54,0x38,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5834 0x16ca "ᛊ" */
+0x00,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5835 0x16cb "ᛋ" */
+0x00,0x40,0x40,0x40,0x40,0x44,0x4c,0x54,0x64,0x44,0x04,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5836 0x16cc "ᛌ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5837 0x16cd "ᛍ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x38,0x38,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5838 0x16ce "ᛎ" */
+0x00,0x10,0x10,0x10,0x10,0x92,0x54,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5839 0x16cf "ᛏ" */
+0x00,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5840 0x16d0 "ᛐ" */
+0x00,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5841 0x16d1 "ᛑ" */
+0x00,0x08,0x18,0x28,0x48,0x88,0x08,0x1c,0x1c,0x1c,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5842 0x16d2 "ᛒ" */
+0x00,0x60,0x50,0x48,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x48,0x50,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5843 0x16d3 "ᛓ" */
+0x00,0x40,0x40,0x44,0x48,0x50,0x64,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5844 0x16d4 "ᛔ" */
+0x00,0x60,0x50,0x48,0x54,0x48,0x50,0x60,0x60,0x50,0x48,0x54,0x48,0x50,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5845 0x16d5 "ᛕ" */
+0x00,0x82,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0xc0,0xa0,0x90,0x88,0x84,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5846 0x16d6 "ᛖ" */
+0x00,0x82,0xc6,0xc6,0xaa,0xaa,0x92,0x92,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5847 0x16d7 "ᛗ" */
+0x00,0x82,0xc6,0xaa,0x92,0xaa,0xc6,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5848 0x16d8 "ᛘ" */
+0x00,0x92,0x92,0x54,0x54,0x38,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5849 0x16d9 "ᛙ" */
+0x00,0x38,0x38,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5850 0x16da "ᛚ" */
+0x00,0x40,0x60,0x50,0x48,0x44,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5851 0x16db "ᛛ" */
+0x00,0x40,0x60,0x50,0x48,0x44,0x42,0xe0,0xe0,0xe0,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5852 0x16dc "ᛜ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x82,0x82,0x44,0x28,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5853 0x16dd "ᛝ" */
+0x00,0x82,0x44,0x28,0x10,0x28,0x44,0x82,0x82,0x44,0x28,0x10,0x28,0x44,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5854 0x16de "ᛞ" */
+0x00,0x82,0xc6,0xc6,0xaa,0xaa,0x92,0x92,0x92,0x92,0xaa,0xaa,0xc6,0xc6,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5855 0x16df "ᛟ" */
+0x00,0x00,0x10,0x28,0x44,0x82,0x82,0x44,0x28,0x10,0x28,0x44,0x82,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5856 0x16e0 "ᛠ" */
+0x00,0x41,0x23,0x15,0x09,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x04,0x88,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5857 0x16e1 "ᛡ" */
+0x00,0x10,0x10,0x10,0x92,0x54,0x38,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5858 0x16e2 "ᛢ" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x09,0x15,0x23,0x41,0x00,
+0x00,0x04,0x88,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5859 0x16e3 "ᛣ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x92,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5860 0x16e4 "ᛤ" */
+0x00,0x92,0x92,0x54,0x54,0x38,0x38,0x54,0x54,0x38,0x38,0x54,0x54,0x92,0x92,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5861 0x16e5 "ᛥ" */
+0x00,0x82,0xc6,0xaa,0x92,0xaa,0xc6,0x82,0x82,0xc6,0xaa,0x92,0xaa,0xc6,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5862 0x16e6 "ᛦ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x92,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5863 0x16e7 "ᛧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5864 0x16e8 "ᛨ" */
+0x00,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x10,0x10,0x10,0x92,0x54,0x38,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5865 0x16e9 "ᛩ" */
+0x00,0x04,0x0c,0x14,0x24,0x44,0x24,0x14,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5866 0x16ea "ᛪ" */
+0x00,0x40,0x40,0xe0,0x40,0x44,0x4c,0x54,0x64,0x44,0x04,0x0e,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5867 0x16eb "᛫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x38,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5868 0x16ec "᛬" */
+0x00,0x00,0x38,0x38,0x38,0x00,0x00,0x00,0x00,0x00,0x38,0x38,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5869 0x16ed "᛭" */
+0x00,0x00,0x00,0x38,0x38,0x10,0xd6,0xfe,0xd6,0x10,0x38,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5870 0x16ee "ᛮ" */
+0x00,0x10,0x18,0x14,0x12,0x10,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5871 0x16ef "ᛯ" */
+0x00,0x92,0x54,0x54,0x38,0x38,0x10,0x10,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5872 0x16f0 "ᛰ" */
+0x00,0x10,0x10,0x10,0x38,0x54,0x92,0x92,0x92,0x92,0x92,0x54,0x38,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5873 0x16f1 "ᛱ" */
+0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x48,0x54,0x64,0x44,0x42,0x42,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5874 0x16f2 "ᛲ" */
+0x00,0x04,0x04,0x04,0x04,0x44,0x64,0x54,0x4c,0x44,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5875 0x16f3 "ᛳ" */
+0x00,0x08,0x1c,0x2a,0x49,0x49,0x2a,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5876 0x16f4 "ᛴ" */
+0x00,0x40,0x40,0x40,0x44,0x46,0x4c,0x54,0x64,0xc4,0x44,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5877 0x16f5 "ᛵ" */
+0x00,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5878 0x16f6 "ᛶ" */
+0x00,0x80,0x80,0x40,0x40,0x22,0x24,0x18,0x10,0x28,0x48,0x84,0x04,0x02,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5879 0x16f7 "ᛷ" */
+0x00,0x40,0x40,0x40,0x40,0x70,0x48,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5880 0x16f8 "ᛸ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x44,0x44,0x82,0x82,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5881 0x16f9 "᛹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 5882 0x16fa "᛺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 5883 0x16fb "᛻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 5884 0x16fc "᛼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 5885 0x16fd "᛽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5886 0x16fe "᛾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5887 0x16ff "᛿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 5888 0x1700 "ᜀ" */
+0x00,0x00,0x00,0x00,0x60,0x10,0x78,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0a,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5889 0x1701 "ᜁ" */
+0x00,0x00,0x00,0x00,0x40,0x30,0x0f,0x04,0x0a,0x73,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x02,0x80,0x40,0x22,0x1c,0x00,0x00,0x00,0x00,
+/* 5890 0x1702 "ᜂ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0x50,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 5891 0x1703 "ᜃ" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x1f,0x01,0x01,0x43,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0xfc,0x00,0x00,0xfc,0x02,0x02,0x04,0x00,0x00,0x00,
+/* 5892 0x1704 "ᜄ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x00,0x01,0x02,0x00,0x00,0x01,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x10,0x90,0x90,0x90,0x10,0x0c,0x00,0x00,0x00,
+/* 5893 0x1705 "ᜅ" */
+0x00,0x00,0x00,0x00,0x20,0x40,0x4e,0x31,0x01,0x01,0x01,0x02,0x3c,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0xe2,0x02,0x0c,0x00,0x00,0x00,0x00,
+/* 5894 0x1706 "ᜆ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x20,0x1f,0x08,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5895 0x1707 "ᜇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x3f,0x10,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x04,0x00,0x00,0xf8,0x04,0x00,0x00,0x00,0x00,
+/* 5896 0x1708 "ᜈ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x12,0x01,0x00,0x01,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5897 0x1709 "ᜉ" */
+0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x10,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x10,0x18,0x24,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5898 0x170a "ᜊ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x40,0x40,0x40,0x41,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,
+/* 5899 0x170b "ᜋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0b,0x0c,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x08,0x08,0xd0,0x30,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5900 0x170c "ᜌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x1c,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5901 0x170d "ᜍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x3f,0x10,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x04,0x00,0x00,0xf8,0x24,0x10,0x00,0x00,0x00,
+/* 5902 0x170e "ᜎ" */
+0x00,0x00,0x00,0x00,0x40,0x43,0x3c,0x01,0x00,0x01,0x01,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x82,0x82,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 5903 0x170f "ᜏ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,0x00,0x01,0x03,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,
+/* 5904 0x1710 "ᜐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x04,0x04,0x02,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x22,0x24,0x4a,0x42,0x82,0x84,0x18,0x00,0x00,0x00,
+/* 5905 0x1711 "ᜑ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x21,0x26,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x62,0x82,0x02,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5906 0x1712 "ᜒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5907 0x1713 "ᜓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,
+/* 5908 0x1714 "᜔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,
+/* 5909 0x1715 "᜕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x08,0xf0,
+/* 5910 0x1716 "᜖" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 5911 0x1717 "᜗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 5912 0x1718 "᜘" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 5913 0x1719 "᜙" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 5914 0x171a "᜚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 5915 0x171b "᜛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 5916 0x171c "᜜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 5917 0x171d "᜝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5918 0x171e "᜞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5919 0x171f "ᜟ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x04,0x08,0x48,0x30,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x60,0x10,0x20,0xc0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 5920 0x1720 "ᜠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x68,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5921 0x1721 "ᜡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x68,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x48,0x90,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 5922 0x1722 "ᜢ" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x01,0x07,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x40,0x80,0x00,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5923 0x1723 "ᜣ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x0a,0x06,0x05,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5924 0x1724 "ᜤ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 5925 0x1725 "ᜥ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5926 0x1726 "ᜦ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x12,0x12,0x14,0x14,0x18,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x88,0x88,0x90,0x90,0xa0,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 5927 0x1727 "ᜧ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x38,0x09,0x0a,0x0c,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5928 0x1728 "ᜨ" */
+0x00,0x00,0x00,0x00,0x47,0x3a,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0xe8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 5929 0x1729 "ᜩ" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x10,0x18,0x24,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5930 0x172a "ᜪ" */
+0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5931 0x172b "ᜫ" */
+0x00,0x00,0x00,0x00,0x0c,0x36,0x05,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x90,0x50,0x20,0x50,0x88,0x00,0x00,0x00,0x00,
+/* 5932 0x172c "ᜬ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x48,0x08,0x08,0x09,0x0a,0x0c,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 5933 0x172d "ᜭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5934 0x172e "ᜮ" */
+0x00,0x00,0x00,0x00,0x21,0x23,0x23,0x25,0x25,0x29,0x29,0x31,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x20,0x00,0x00,0x00,
+/* 5935 0x172f "ᜯ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x09,0x11,0x12,0x12,0x14,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xc2,0xa4,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5936 0x1730 "ᜰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x68,0x08,0x09,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x60,0x60,0xa0,0xa0,0x24,0x4c,0x74,0x02,0x00,0x00,0x00,
+/* 5937 0x1731 "ᜱ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x09,0x12,0x14,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5938 0x1732 "ᜲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5939 0x1733 "ᜳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,
+/* 5940 0x1734 "᜴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,
+/* 5941 0x1735 "᜵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5942 0x1736 "᜶" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 5943 0x1737 "᜷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 5944 0x1738 "᜸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 5945 0x1739 "᜹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 5946 0x173a "᜺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 5947 0x173b "᜻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 5948 0x173c "᜼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 5949 0x173d "᜽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5950 0x173e "᜾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5951 0x173f "᜿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 5952 0x1740 "ᝀ" */
+0x00,0x00,0x00,0x00,0x38,0x38,0x08,0x08,0x0f,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5953 0x1741 "ᝁ" */
+0x00,0x00,0x00,0x00,0x38,0x38,0x08,0x08,0x0f,0x0f,0x00,0x1f,0x1f,0x00,0x00,0x00,
+0x00,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5954 0x1742 "ᝂ" */
+0x00,0x00,0x00,0x00,0x0f,0x0f,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf0,0xe0,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 5955 0x1743 "ᝃ" */
+0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 5956 0x1744 "ᝄ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x07,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x10,0x20,0x20,0x40,0x00,0x00,0x00,
+/* 5957 0x1745 "ᝅ" */
+0x00,0x00,0x00,0x00,0x07,0x07,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xf0,0x20,0x20,0x7c,0x7c,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 5958 0x1746 "ᝆ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x22,0x22,0x22,0x44,0x7c,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe2,0xe2,0x22,0x44,0x44,0x44,0x88,0xf8,0xf8,0x00,0x00,0x00,
+/* 5959 0x1747 "ᝇ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x3e,0x3e,0x02,0x04,0x07,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0xe0,0xe0,0x00,0x00,0x00,
+/* 5960 0x1748 "ᝈ" */
+0x00,0x00,0x00,0x00,0x07,0x07,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0xf8,0x40,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5961 0x1749 "ᝉ" */
+0x00,0x00,0x00,0x00,0x3c,0x3c,0x04,0x08,0x08,0x08,0x10,0x1f,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3c,0x3c,0x20,0x40,0x40,0x40,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 5962 0x174a "ᝊ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x0f,0x00,0x00,0x00,0x00,0x0f,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0xe0,0x20,0x20,0x40,0x40,0xc0,0xc0,0x00,0x00,0x00,
+/* 5963 0x174b "ᝋ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x07,0x07,0x08,0x08,0x08,0x1f,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x08,0x08,0x10,0x10,0xf0,0xf0,0x20,0x20,0x20,0xe0,0xc0,0x00,0x00,0x00,
+/* 5964 0x174c "ᝌ" */
+0x00,0x00,0x00,0x00,0x3e,0x3e,0x02,0x04,0x04,0x04,0x09,0x0f,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x44,0x88,0x88,0x88,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 5965 0x174d "ᝍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5966 0x174e "ᝎ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x22,0x22,0x3f,0x3f,0x04,0x04,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xf0,0x10,0x10,0x20,0xe0,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 5967 0x174f "ᝏ" */
+0x00,0x00,0x04,0x04,0x08,0x08,0x08,0x11,0x10,0x1f,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0xf8,0x88,0x08,0x10,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 5968 0x1750 "ᝐ" */
+0x00,0x00,0x3e,0x3e,0x02,0x04,0x07,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x40,0x80,0xf8,0xf8,0x08,0x10,0x10,0x20,
+/* 5969 0x1751 "ᝑ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x04,0x04,0x04,0x08,0x0f,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0xe0,0x00,0x00,0x00,
+/* 5970 0x1752 "ᝒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5971 0x1753 "ᝓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x00,
+/* 5972 0x1754 "᝔" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 5973 0x1755 "᝕" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 5974 0x1756 "᝖" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 5975 0x1757 "᝗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 5976 0x1758 "᝘" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 5977 0x1759 "᝙" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 5978 0x175a "᝚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 5979 0x175b "᝛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 5980 0x175c "᝜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 5981 0x175d "᝝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5982 0x175e "᝞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 5983 0x175f "᝟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 5984 0x1760 "ᝠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x17,0x20,0x20,0x10,
+0x00,0x00,0x00,0x00,0x04,0x0a,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5985 0x1761 "ᝡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x26,0x48,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5986 0x1762 "ᝢ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5987 0x1763 "ᝣ" */
+0x00,0x00,0x00,0x00,0x30,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x00,0x00,0x00,
+/* 5988 0x1764 "ᝤ" */
+0x00,0x00,0x00,0x0f,0x31,0x40,0x01,0x02,0x01,0x00,0x01,0x02,0x01,0x00,0x01,0x00,
+0x00,0x00,0x00,0xe0,0x18,0x84,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 5989 0x1765 "ᝥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x1f,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0xc2,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5990 0x1766 "ᝦ" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x40,0x80,0x40,0x3f,0x40,0x80,0x40,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x84,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 5991 0x1767 "ᝧ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x34,0x48,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x00,0x06,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5992 0x1768 "ᝨ" */
+0x00,0x00,0x00,0x0f,0x31,0x41,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0xe0,0x18,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 5993 0x1769 "ᝩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x08,0x08,0x10,0x10,0x28,0x44,0x82,0x00,0x00,0x00,0x00,
+/* 5994 0x176a "ᝪ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 5995 0x176b "ᝫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x4c,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x08,0xc8,0x30,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5996 0x176c "ᝬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x24,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 5997 0x176d "᝭" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 5998 0x176e "ᝮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x20,0x20,0x54,0x5a,0xac,0x16,0x08,0x00,0x00,
+/* 5999 0x176f "ᝯ" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x20,0x40,0x40,0x41,0x46,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x00,0x00,0x00,0xfc,0x02,0x02,0x00,0x00,0x00,
+/* 6000 0x1770 "ᝰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x09,0x09,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x90,0xa0,0x18,0x10,0x0c,0x08,0x00,0x00,0x00,
+/* 6001 0x1771 "᝱" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 6002 0x1772 "ᝲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6003 0x1773 "ᝳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x10,0x00,
+/* 6004 0x1774 "᝴" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 6005 0x1775 "᝵" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 6006 0x1776 "᝶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 6007 0x1777 "᝷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 6008 0x1778 "᝸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 6009 0x1779 "᝹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6010 0x177a "᝺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6011 0x177b "᝻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6012 0x177c "᝼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6013 0x177d "᝽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6014 0x177e "᝾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6015 0x177f "᝿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6016 0x1780 "ក" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x04,0x0f,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 6017 0x1781 "ខ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 6018 0x1782 "គ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x04,0x0f,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0xf0,0x10,0x10,0x90,0x90,0x10,0x00,0x00,0x00,
+/* 6019 0x1783 "ឃ" */
+0x00,0x00,0x00,0x00,0x19,0x2a,0x2b,0x09,0x09,0x09,0x09,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x98,0x20,0x30,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6020 0x1784 "ង" */
+0x00,0x00,0x04,0x02,0x02,0x03,0x01,0x00,0x06,0x0a,0x0a,0x03,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x40,0x20,0x20,0xa0,0x60,0x20,0x00,0x00,0x00,
+/* 6021 0x1785 "ច" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x18,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x30,0x50,0x50,0x30,0x10,0xf0,0x00,0x00,0x00,
+/* 6022 0x1786 "ឆ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x08,0x08,0x1e,0x29,0x29,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0x70,0x90,0x70,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6023 0x1787 "ជ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0c,0x04,0x04,0x05,0x06,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x10,0x90,0x60,0x00,0x40,0x40,0x40,0xc0,0x40,0x00,0x00,0x00,
+/* 6024 0x1788 "ឈ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x32,0x2a,0x2a,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x66,0x88,0xcc,0x44,0x44,0x44,0x44,0x44,0xb8,0x00,0x00,0x00,
+/* 6025 0x1789 "ញ" */
+0x00,0x00,0x00,0x00,0x0d,0x12,0x10,0x10,0x10,0x18,0x14,0x14,0x18,0x00,0x07,0x08,
+0x00,0x00,0x00,0x00,0xb8,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x10,0x08,0xf0,
+/* 6026 0x178a "ដ" */
+0x00,0x00,0x03,0x00,0x03,0x04,0x03,0x00,0x02,0x02,0x02,0x03,0x02,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x20,0xc0,0x00,0x20,0x20,0xa0,0x60,0x20,0x00,0x00,0x00,
+/* 6027 0x178b "ឋ" */
+0x00,0x00,0x00,0x00,0x0c,0x14,0x14,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x10,0x28,0x08,0x18,0x20,0x30,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6028 0x178c "ឌ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x08,0x00,0x03,0x0c,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0xc0,0x10,0x30,0x30,0xd0,0x00,0x00,0x00,
+/* 6029 0x178d "ឍ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x20,0x20,0x20,0x31,0x2a,0x2a,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x88,0x8c,0x84,0x84,0xc4,0xa4,0xa4,0x98,0x00,0x00,0x00,
+/* 6030 0x178e "ណ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x32,0x2a,0x2b,0x32,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x64,0x24,0x24,0x24,0xa4,0x64,0x24,0x00,0x00,0x00,
+/* 6031 0x178f "ត" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x04,0x0f,0x08,0x0c,0x0a,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 6032 0x1790 "ថ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0c,0x04,0x04,0x04,0x04,0x07,0x00,0x00,0x00,
+0x00,0x00,0x20,0x10,0x10,0xe0,0x00,0x60,0xa0,0xa0,0x60,0x20,0xe0,0x00,0x00,0x00,
+/* 6033 0x1791 "ទ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x08,0x60,0x90,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6034 0x1792 "ធ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x18,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x30,0x50,0x50,0x30,0x90,0x70,0x00,0x00,0x00,
+/* 6035 0x1793 "ន" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x03,0x00,0x05,0x06,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x40,0x00,0xc0,0x40,0x40,0xc0,0x40,0x00,0x00,0x00,
+/* 6036 0x1794 "ប" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x0c,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x30,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6037 0x1795 "ផ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x20,0x10,0x90,0x60,0x00,0x30,0x50,0x50,0x30,0x90,0x70,0x00,0x00,0x00,
+/* 6038 0x1796 "ព" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x0c,0x0a,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 6039 0x1797 "ភ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x04,0x00,0x03,0x02,0x0a,0x12,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 6040 0x1798 "ម" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x18,0x08,0x08,0x0f,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x40,0x60,0x20,0x20,0xe0,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 6041 0x1799 "យ" */
+0x00,0x00,0x00,0x00,0x08,0x15,0x15,0x18,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x10,0x98,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,0x00,
+/* 6042 0x179a "រ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x02,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6043 0x179b "ល" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x18,0x14,0x14,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x90,0x98,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,0x00,
+/* 6044 0x179c "វ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x02,0x04,0x03,0x00,0x00,0x00,
+0x00,0x40,0xa0,0x20,0xe0,0x20,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6045 0x179d "ឝ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x04,0x0f,0x08,0x08,0x0a,0x0d,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0xe0,0x20,0xa8,0x70,0x20,0x20,0x00,0x00,0x00,
+/* 6046 0x179e "ឞ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x18,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x40,0x60,0x20,0xa8,0x70,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 6047 0x179f "ស" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x18,0x0f,0x11,0x19,0x15,0x15,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x30,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6048 0x17a0 "ហ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x18,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0xc4,0x44,0x44,0x44,0x44,0x44,0x84,0x00,0x00,0x00,
+/* 6049 0x17a1 "ឡ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x43,0x24,0x1f,0x44,0x7c,0x01,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0xc6,0x28,0x4c,0x04,0x84,0x04,0x04,0x04,0xc4,0x54,0x6c,0x44,
+/* 6050 0x17a2 "អ" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x0c,0x04,0x07,0x04,0x14,0x24,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x30,0x10,0xf0,0x10,0x50,0x90,0x70,0x00,0x00,0x00,
+/* 6051 0x17a3 "ឣ" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x0c,0x04,0x07,0x04,0x14,0x24,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x30,0x10,0xf0,0x10,0x50,0x90,0x70,0x00,0x00,0x00,
+/* 6052 0x17a4 "ឤ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x18,0x08,0x0f,0x08,0x29,0x4a,0x39,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0xc4,0x44,0xc4,0x44,0x44,0x44,0xc4,0x00,0x00,0x00,
+/* 6053 0x17a5 "ឥ" */
+0x00,0x00,0x00,0x03,0x04,0x02,0x00,0x07,0x04,0x06,0x05,0x05,0x06,0x00,0x00,0x00,
+0x00,0x00,0x20,0x10,0x90,0x60,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 6054 0x17a6 "ឦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x1c,0x12,0x1c,0x00,0x1f,0x18,0x14,0x18,
+0x00,0x04,0x0a,0x02,0x0e,0x12,0x98,0x88,0x88,0x88,0x88,0x08,0x88,0x88,0x88,0xf8,
+/* 6055 0x17a7 "ឧ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x90,0x30,0x50,0x90,0x00,0x00,0x00,
+/* 6056 0x17a8 "ឨ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x04,0x03,0x04,0x00,0x03,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x00,0xc0,0x20,0x40,0x90,0x30,0xd0,0x00,0x00,0x00,
+/* 6057 0x17a9 "ឩ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x08,0x01,0x0e,0x10,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x90,0x10,0x50,0xd0,0x50,0x50,0x00,0x00,0x00,
+/* 6058 0x17aa "ឪ" */
+0x01,0x00,0x00,0x07,0x08,0x06,0x01,0x03,0x04,0x00,0x03,0x04,0x03,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0xc0,0x40,0x00,0xc0,0x20,0x40,0x90,0x30,0xd0,0x00,0x00,0x00,
+/* 6059 0x17ab "ឫ" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x0c,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x07,0x08,
+0x00,0x00,0x00,0x00,0x18,0x20,0x30,0x10,0x10,0x10,0x10,0x10,0xe0,0x30,0x08,0xf0,
+/* 6060 0x17ac "ឬ" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x0c,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x07,0x08,
+0x00,0x00,0x00,0x00,0x18,0x20,0x30,0x10,0x10,0x10,0x10,0x10,0xe0,0x30,0x08,0xf6,
+/* 6061 0x17ad "ឭ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x0c,0x0a,0x0a,0x0c,0x00,0x07,0x08,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x60,0x10,0xe0,
+/* 6062 0x17ae "ឮ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x0c,0x0a,0x0a,0x0c,0x00,0x07,0x08,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x60,0x10,0xec,
+/* 6063 0x17af "ឯ" */
+0x00,0x00,0x00,0x00,0x03,0x01,0x01,0x01,0x00,0x07,0x09,0x05,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x90,0x10,0x10,0x50,0xb0,0x10,0x00,0x00,0x00,
+/* 6064 0x17b0 "ឰ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x0c,0x0a,0x0a,0x0c,0x00,0x03,0x04,0x03,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0xf8,0x90,0x60,
+/* 6065 0x17b1 "ឱ" */
+0x00,0x00,0x00,0x03,0x04,0x06,0x01,0x03,0x04,0x00,0x03,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x00,0xc0,0x20,0x40,0x90,0x30,0xd0,0x00,0x00,0x00,
+/* 6066 0x17b2 "ឲ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x09,0x09,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0xe0,0x00,0xe0,0x10,0x10,0x20,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6067 0x17b3 "ឳ" */
+0x00,0x00,0x00,0x03,0x04,0x06,0x01,0x03,0x04,0x00,0x03,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x88,0x50,0x20,0x00,0xc0,0x20,0x40,0x90,0x30,0xd0,0x00,0x00,0x00,
+/* 6068 0x17b4 "឴" */
+0xaa,0x00,0xa5,0x29,0xb1,0x29,0xa5,0x00,0x80,0x08,0x94,0x22,0xbe,0x22,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0x71,0x88,0xa9,0x98,0x79,0x04,0x55,
+/* 6069 0x17b5 "឵" */
+0xaa,0x00,0xa5,0x29,0xb1,0x29,0xa5,0x00,0x80,0x08,0x94,0x22,0xbe,0x22,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0x11,0x28,0x45,0x7c,0x45,0x00,0x55,
+/* 6070 0x17b6 "ា" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1e,0x22,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 6071 0x17b7 "ិ" */
+0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6072 0x17b8 "ី" */
+0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x90,0x50,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6073 0x17b9 "ឹ" */
+0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x90,0x68,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6074 0x17ba "ឺ" */
+0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x50,0xd0,0x70,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6075 0x17bb "ុ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6076 0x17bc "ូ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xc0,
+/* 6077 0x17bd "ួ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xa0,0x60,
+/* 6078 0x17be "ើ" */
+0x00,0x03,0x04,0x03,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+0x00,0x90,0x50,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6079 0x17bf "ឿ" */
+0x00,0x03,0x04,0x03,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x10,0x08,0x07,
+0x50,0xd0,0x70,0xfe,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x01,0xfe,
+/* 6080 0x17c0 "ៀ" */
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x10,0x08,0x07,
+0x18,0x08,0x10,0x3e,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x01,0xfe,
+/* 6081 0x17c1 "េ" */
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6082 0x17c2 "ែ" */
+0x18,0x88,0x70,0x00,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6083 0x17c3 "ៃ" */
+0x98,0x64,0x44,0x18,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6084 0x17c4 "ោ" */
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1e,0x22,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 6085 0x17c5 "ៅ" */
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x80,0x80,0x80,0xc0,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+0x04,0x02,0x02,0x1e,0x22,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 6086 0x17c6 "ំ" */
+0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6087 0x17c7 "ះ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x02,0x00,0x02,0x05,0x05,0x02,0x00,0x00,0x00,
+/* 6088 0x17c8 "ៈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6089 0x17c9 "៉" */
+0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6090 0x17ca "៊" */
+0x07,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x60,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6091 0x17cb "់" */
+0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6092 0x17cc "៌" */
+0x03,0x04,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x88,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6093 0x17cd "៍" */
+0x03,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x88,0x50,0x20,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6094 0x17ce "៎" */
+0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0xe0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6095 0x17cf "៏" */
+0x01,0x02,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe6,0x1c,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6096 0x17d0 "័" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6097 0x17d1 "៑" */
+0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6098 0x17d2 "្" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 6099 0x17d3 "៓" */
+0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6100 0x17d4 "។" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6101 0x17d5 "៕" */
+0x00,0x00,0x00,0x00,0x06,0x26,0x4a,0x32,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6102 0x17d6 "៖" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x30,0x00,0x78,0x00,0x30,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6103 0x17d7 "ៗ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x38,0x24,0x38,0x00,0x00,0x20,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 6104 0x17d8 "៘" */
+0x00,0x00,0x00,0x00,0x33,0xb4,0x54,0x14,0x14,0x16,0x15,0x15,0x16,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1b,0xab,0xa5,0x91,0x91,0x51,0x51,0x51,0x31,0x00,0x00,0x00,
+/* 6105 0x17d9 "៙" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x0a,0x0a,0x0a,0x09,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xa0,0xa0,0xa0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 6106 0x17da "៚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x71,0x8a,0xaa,0x92,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x95,0x52,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 6107 0x17db "៛" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x03,0x00,0x02,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x80,0x80,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6108 0x17dc "ៜ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x20,0x1c,0x02,0x12,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6109 0x17dd "៝" */
+0x00,0x03,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6110 0x17de "៞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6111 0x17df "៟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6112 0x17e0 "០" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 6113 0x17e1 "១" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x09,0x06,0x00,0x00,0x00,0x0e,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 6114 0x17e2 "២" */
+0x00,0x20,0x20,0x20,0x27,0x28,0x2c,0x2a,0x2a,0x2c,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 6115 0x17e3 "៣" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x31,0x29,0x29,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 6116 0x17e4 "៤" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x09,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x08,0xe8,0x18,0xc0,0x20,0x80,0x40,0x20,0xe0,0x00,0x00,0x00,
+/* 6117 0x17e5 "៥" */
+0x00,0x06,0x09,0x09,0x0a,0x07,0x04,0x08,0x09,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x10,0x20,0x20,0xe0,0x00,0xc0,0x20,0x80,0x40,0x20,0xe0,0x00,0x00,0x00,
+/* 6118 0x17e6 "៦" */
+0x00,0x00,0x00,0x00,0x18,0x08,0x0b,0x0c,0x00,0x06,0x09,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 6119 0x17e7 "៧" */
+0x00,0x00,0x00,0x00,0x1d,0x22,0x20,0x20,0x20,0x30,0x28,0x28,0x30,0x00,0x00,0x00,
+0x00,0x02,0x04,0x04,0xc4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x18,0x00,0x00,0x00,
+/* 6120 0x17e8 "៨" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x13,0x0c,0x00,0x00,0x00,
+0x00,0x08,0x10,0xd0,0x30,0x00,0x30,0x50,0x90,0x50,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 6121 0x17e9 "៩" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x08,0x1f,0x20,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0xd0,0x30,0x00,0x00,0x80,0x40,0x30,0x00,0x00,0x00,
+/* 6122 0x17ea "៪" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6123 0x17eb "៫" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6124 0x17ec "៬" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6125 0x17ed "៭" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6126 0x17ee "៮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6127 0x17ef "៯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6128 0x17f0 "៰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6129 0x17f1 "៱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6130 0x17f2 "៲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6131 0x17f3 "៳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x5a,0x89,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6132 0x17f4 "៴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x28,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6133 0x17f5 "៵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x28,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6134 0x17f6 "៶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6135 0x17f7 "៷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x54,0x88,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6136 0x17f8 "៸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6137 0x17f9 "៹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x78,0x04,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6138 0x17fa "៺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6139 0x17fb "៻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6140 0x17fc "៼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6141 0x17fd "៽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6142 0x17fe "៾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6143 0x17ff "៿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6144 0x1800 "᠀" */
+0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x00,
+0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6145 0x1801 "᠁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6146 0x1802 "᠂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xe0,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6147 0x1803 "᠃" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x1c,0x3e,0x1c,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x7c,0x38,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 6148 0x1804 "᠄" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6149 0x1805 "᠅" */
+0x00,0x00,0x00,0x01,0x03,0x11,0x10,0x38,0x7c,0x38,0x10,0x11,0x03,0x01,0x00,0x00,
+0x00,0x80,0x80,0xc0,0xe0,0xc8,0x88,0x9c,0x3e,0x9c,0x88,0xc8,0xe0,0xc0,0x80,0x80,
+/* 6150 0x1806 "᠆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6151 0x1807 "᠇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x07,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6152 0x1808 "᠈" */
+0x00,0x00,0x00,0x04,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6153 0x1809 "᠉" */
+0x00,0x00,0x00,0x10,0x08,0x04,0x06,0x06,0x06,0x06,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x20,0x10,0x18,0x18,0x18,0x18,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 6154 0x180a "᠊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6155 0x180b "᠋" */
+0xaa,0x00,0xbc,0x20,0xb8,0x20,0xa0,0x00,0x80,0x1c,0xa0,0x18,0x84,0x38,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0x11,0x30,0x11,0x10,0x7d,0x00,0x55,
+/* 6156 0x180c "᠌" */
+0xaa,0x00,0xbc,0x20,0xb8,0x20,0xa0,0x00,0x80,0x1c,0xa0,0x18,0x84,0x38,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0x79,0x04,0x39,0x40,0x7d,0x00,0x55,
+/* 6157 0x180d "᠍" */
+0xaa,0x00,0xbc,0x20,0xb8,0x20,0xa0,0x00,0x80,0x1c,0xa0,0x18,0x84,0x38,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0x79,0x04,0x39,0x04,0x79,0x00,0x55,
+/* 6158 0x180e "᠎" */
+0xaa,0x00,0xa2,0x36,0xaa,0x22,0xa2,0x00,0x80,0x01,0x82,0x01,0x80,0x03,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0xe1,0x00,0xc1,0x20,0xc1,0x00,0x55,
+/* 6159 0x180f "᠏" */
+0xaa,0x00,0xbc,0x20,0xb8,0x20,0xa0,0x00,0x80,0x1c,0xa0,0x18,0x84,0x38,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x28,0x29,0x10,0x01,0x00,0x45,0x44,0x7d,0x04,0x05,0x00,0x55,
+/* 6160 0x1810 "᠐" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0xc0,0x00,0x00,
+/* 6161 0x1811 "᠑" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x04,0x04,0x00,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0xc0,0x00,0x00,
+/* 6162 0x1812 "᠒" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x04,0x02,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0x12,0x12,0x24,0x38,0x00,0x00,0x00,
+/* 6163 0x1813 "᠓" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x04,0x02,0x00,0x00,
+0x00,0x00,0x40,0xa0,0xa0,0x90,0x90,0x90,0x90,0x12,0x12,0x24,0x38,0x00,0x00,0x00,
+/* 6164 0x1814 "᠔" */
+0x00,0x00,0x03,0x04,0x00,0x02,0x04,0x04,0x08,0x08,0x08,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0xc0,0x00,0x00,
+/* 6165 0x1815 "᠕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x50,0x50,0x48,0x48,0x44,0x44,0x42,0x82,0x00,0x00,0x00,
+/* 6166 0x1816 "᠖" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0x80,0x80,0xe0,0x90,0x90,0x10,0x20,0x20,0xc0,0x00,0x00,
+/* 6167 0x1817 "᠗" */
+0x00,0x00,0x07,0x08,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0x10,0x88,0x88,0x88,0x88,0x88,0x88,0x90,0x90,0x60,0x00,0x00,
+/* 6168 0x1818 "᠘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x07,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x10,0x10,0x20,0x20,0xc0,0x00,0x00,
+/* 6169 0x1819 "᠙" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x40,0x60,0x00,0x00,0x20,0x20,0xc0,0x00,0x00,
+/* 6170 0x181a "᠚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6171 0x181b "᠛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6172 0x181c "᠜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6173 0x181d "᠝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6174 0x181e "᠞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6175 0x181f "᠟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6176 0x1820 "ᠠ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1e,0x1e,0x12,0x12,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 6177 0x1821 "ᠡ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x10,0x10,0x10,0x00,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 6178 0x1822 "ᠢ" */
+0x00,0x00,0x00,0x31,0x52,0x12,0x12,0x1e,0x1e,0x12,0x12,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,
+/* 6179 0x1823 "ᠣ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x11,0x11,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0xe0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 6180 0x1824 "ᠤ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x11,0x11,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 6181 0x1825 "ᠥ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x11,0x11,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfe,0x26,0x22,0x22,0xc0,0x00,0x00,0x00,
+/* 6182 0x1826 "ᠦ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x11,0x11,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xfe,0x28,0x24,0x22,0xc0,0x00,0x00,0x00,
+/* 6183 0x1827 "ᠧ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x11,0x11,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfe,0x06,0x02,0x22,0xc0,0x00,0x00,0x00,
+/* 6184 0x1828 "ᠨ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1c,0x1c,0x10,0x10,0x10,0x00,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6185 0x1829 "ᠩ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x1f,0x19,0x11,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 6186 0x182a "ᠪ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x1e,0x1e,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6187 0x182b "ᠫ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x1e,0x1e,0x02,0x02,0x02,0x1e,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6188 0x182c "ᠬ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x1f,0x1f,0x04,0x02,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0xf0,0xf0,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 6189 0x182d "ᠭ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x1f,0x1f,0x04,0x02,0x06,0x00,0x06,0x00,0x06,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0xf0,0xf0,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 6190 0x182e "ᠮ" */
+0x00,0x04,0x04,0x18,0x10,0x30,0x50,0x1c,0x1c,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6191 0x182f "ᠯ" */
+0x00,0x40,0x40,0x30,0x10,0x30,0x50,0x1c,0x1c,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6192 0x1830 "ᠰ" */
+0x00,0x00,0x00,0x0c,0x14,0x14,0x54,0x27,0x07,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6193 0x1831 "ᠱ" */
+0x00,0x1b,0x1b,0x00,0x0c,0x14,0x14,0x57,0x27,0x04,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6194 0x1832 "ᠲ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x87,0x47,0x2e,0x14,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6195 0x1833 "ᠳ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x1f,0x10,0x12,0x15,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6196 0x1834 "ᠴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x00,0x00,0x03,0x07,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x40,0x40,0xc0,0xc0,0x00,0x00,0x00,
+/* 6197 0x1835 "ᠵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x10,0x08,0x08,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6198 0x1836 "ᠶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x10,0x08,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6199 0x1837 "ᠷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x10,0x08,0x08,0x14,0x24,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6200 0x1838 "ᠸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x10,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6201 0x1839 "ᠹ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x1e,0x1e,0x12,0x12,0x12,0x0c,0x10,0x10,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6202 0x183a "ᠺ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x18,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6203 0x183b "ᠻ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x1c,0x1c,0x10,0x10,0x18,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6204 0x183c "ᠼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x01,0x01,0x07,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,
+/* 6205 0x183d "ᠽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x01,0x01,0x07,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,
+/* 6206 0x183e "ᠾ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1e,0x1e,0x12,0x12,0x12,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x78,0x40,0x40,0x20,0x40,0x80,0x00,0x00,
+/* 6207 0x183f "ᠿ" */
+0x00,0x00,0x18,0x24,0x44,0x4c,0x54,0x47,0x47,0x44,0x44,0x50,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6208 0x1840 "ᡀ" */
+0x00,0x00,0x40,0x30,0x10,0x30,0x50,0x1e,0x1e,0x12,0x12,0x12,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x78,0x40,0x40,0x20,0x40,0x80,0x00,0x00,
+/* 6209 0x1841 "ᡁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0x13,0x12,0x12,0x11,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6210 0x1842 "ᡂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0x90,0x90,0x90,0x60,0x00,0x00,0x00,
+/* 6211 0x1843 "ᡃ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x1c,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6212 0x1844 "ᡄ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x12,0x12,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x80,0x00,0x00,0x00,
+/* 6213 0x1845 "ᡅ" */
+0x00,0x00,0x03,0x32,0x52,0x12,0x12,0x1e,0x1e,0x12,0x12,0x12,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 6214 0x1846 "ᡆ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x12,0x12,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 6215 0x1847 "ᡇ" */
+0x00,0x00,0x00,0x31,0x52,0x12,0x12,0x1f,0x1f,0x12,0x12,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xc8,0xc8,0x40,0x40,0x40,0x80,0x80,0x60,0x00,
+/* 6216 0x1848 "ᡈ" */
+0x00,0x00,0x00,0x30,0x51,0x10,0x10,0x1f,0x1f,0x12,0x12,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0xc0,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 6217 0x1849 "ᡉ" */
+0x00,0x00,0x00,0x31,0x52,0x12,0x12,0x1f,0x1f,0x12,0x12,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0xc8,0xc8,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 6218 0x184a "ᡊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x1a,0x12,0x12,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xfc,0x04,0x04,0x04,0x88,0x30,0x20,0x00,
+/* 6219 0x184b "ᡋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x12,0x12,0x12,0x0c,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xe0,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 6220 0x184c "ᡌ" */
+0x00,0x00,0x00,0x11,0x12,0x14,0x14,0x7c,0x7c,0x14,0x14,0x12,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6221 0x184d "ᡍ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x1b,0x12,0x12,0x00,0x12,0x12,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6222 0x184e "ᡎ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x1b,0x12,0x00,0x0c,0x12,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6223 0x184f "ᡏ" */
+0x00,0x00,0x01,0x08,0x14,0x13,0x11,0x31,0x31,0x09,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6224 0x1850 "ᡐ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x13,0x13,0x12,0x0a,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6225 0x1851 "ᡑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x14,0x12,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6226 0x1852 "ᡒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x01,0x01,0x0e,0x12,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6227 0x1853 "ᡓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x01,0x01,0x06,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6228 0x1854 "ᡔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x01,0x01,0x06,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6229 0x1855 "ᡕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x1e,0x10,0x10,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6230 0x1856 "ᡖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x10,0x0e,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6231 0x1857 "ᡗ" */
+0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x02,0x06,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6232 0x1858 "ᡘ" */
+0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x18,0x18,0x08,0x04,0x0a,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6233 0x1859 "ᡙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x1e,0x1a,0x12,0x12,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x7c,0x4c,0x44,0x24,0x40,0x80,0x00,0x00,
+/* 6234 0x185a "ᡚ" */
+0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x1e,0x1e,0x12,0x12,0x12,0x0c,0x01,0x03,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x70,0x70,0x40,0x40,0x40,0x80,0x00,0xc0,0x00,
+/* 6235 0x185b "ᡛ" */
+0x00,0x00,0x00,0x02,0x1e,0x12,0x12,0x1f,0x1f,0x10,0x10,0x10,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6236 0x185c "ᡜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x0f,0x0f,0x09,0x03,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6237 0x185d "ᡝ" */
+0x00,0x00,0x00,0x10,0x11,0x01,0x02,0x12,0x12,0x12,0x12,0x0a,0x0a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6238 0x185e "ᡞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x1a,0x12,0x11,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 6239 0x185f "ᡟ" */
+0x00,0x00,0x00,0x00,0x22,0x14,0x08,0x3f,0x3f,0x18,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6240 0x1860 "ᡠ" */
+0x00,0x00,0x00,0x31,0x51,0x10,0x10,0x1f,0x1f,0x12,0x12,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0xc0,0xc0,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 6241 0x1861 "ᡡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x80,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 6242 0x1862 "ᡢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x1b,0x12,0x12,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x10,0x10,0x10,0x20,0x40,0x40,0x00,
+/* 6243 0x1863 "ᡣ" */
+0x00,0x01,0x00,0x01,0x01,0x02,0x02,0x12,0x12,0x12,0x12,0x0a,0x06,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x40,0x80,0x00,
+/* 6244 0x1864 "ᡤ" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x38,0x38,0x08,0x08,0x04,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x10,0xa0,0x80,0x40,0x40,0x70,0x70,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 6245 0x1865 "ᡥ" */
+0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x38,0x38,0x08,0x08,0x04,0x1c,0x00,0x00,0x00,
+0x00,0x60,0x90,0xe0,0x80,0x40,0x40,0x78,0x78,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 6246 0x1866 "ᡦ" */
+0x00,0x00,0x00,0x0d,0x12,0x12,0x10,0x1e,0x1e,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6247 0x1867 "ᡧ" */
+0x00,0x00,0x00,0x03,0x05,0x15,0x09,0x01,0x01,0x01,0x11,0x09,0x05,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6248 0x1868 "ᡨ" */
+0x00,0x00,0x01,0x02,0x04,0x02,0x01,0x0f,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0xf8,0xf8,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 6249 0x1869 "ᡩ" */
+0x00,0x00,0x00,0x01,0x12,0x28,0x44,0x87,0x47,0x2e,0x14,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6250 0x186a "ᡪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x3f,0x10,0x08,0x04,0x04,0x04,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6251 0x186b "ᡫ" */
+0x00,0x00,0x0c,0x12,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x00,0x00,0x80,0x90,0x60,0x00,0x00,
+/* 6252 0x186c "ᡬ" */
+0x00,0x01,0x02,0x00,0x0e,0x11,0x10,0x10,0x10,0x10,0x18,0x14,0x14,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6253 0x186d "ᡭ" */
+0x00,0x06,0x09,0x06,0x00,0x0e,0x11,0x10,0x10,0x10,0x18,0x14,0x14,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6254 0x186e "ᡮ" */
+0x00,0x04,0x04,0x1f,0x04,0x0c,0x14,0x17,0x57,0x24,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6255 0x186f "ᡯ" */
+0x00,0x00,0x1f,0x04,0x04,0x0c,0x14,0x17,0x57,0x24,0x04,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6256 0x1870 "ᡰ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x1c,0x1c,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6257 0x1871 "ᡱ" */
+0x00,0x00,0x00,0x06,0x09,0x06,0x00,0x1f,0x1f,0x01,0x01,0x01,0x06,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6258 0x1872 "ᡲ" */
+0x00,0x00,0x00,0x0c,0x12,0x0c,0x00,0x3f,0x3f,0x10,0x08,0x04,0x04,0x04,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6259 0x1873 "ᡳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x11,0x11,0x08,0x08,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0xe0,0x00,0x00,0x80,0x80,0x40,0x40,0x00,
+/* 6260 0x1874 "ᡴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x19,0x11,0x10,0x00,0x00,0x01,0x02,
+0x00,0x08,0x04,0x08,0x10,0x10,0x20,0x20,0x20,0x20,0x20,0xa0,0xa0,0x60,0x08,0x10,
+/* 6261 0x1875 "ᡵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x11,0x10,0x08,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6262 0x1876 "ᡶ" */
+0x00,0x00,0x0c,0x12,0x02,0x01,0x01,0x3f,0x3f,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x00,0x00,0x80,0x90,0x60,0x00,0x00,
+/* 6263 0x1877 "ᡷ" */
+0x00,0x00,0x00,0x06,0x09,0x06,0x00,0x1f,0x1f,0x10,0x10,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6264 0x1878 "ᡸ" */
+0x00,0x00,0x00,0x0d,0x0d,0x00,0x00,0x1f,0x1f,0x01,0x01,0x01,0x06,0x08,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6265 0x1879 "᡹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6266 0x187a "᡺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6267 0x187b "᡻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6268 0x187c "᡼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6269 0x187d "᡽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6270 0x187e "᡾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6271 0x187f "᡿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6272 0x1880 "ᢀ" */
+0x00,0x00,0x00,0x02,0x01,0x0c,0x12,0x12,0x12,0x12,0x0c,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6273 0x1881 "ᢁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x13,0x13,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6274 0x1882 "ᢂ" */
+0x00,0x00,0x00,0x00,0x10,0x18,0x15,0x12,0x12,0x15,0x18,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x00,0x00,0x00,0x00,
+/* 6275 0x1883 "ᢃ" */
+0x00,0x00,0x00,0x0e,0x11,0x01,0x01,0x02,0x1c,0x02,0x01,0x01,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6276 0x1884 "ᢄ" */
+0x00,0x00,0x00,0x0e,0x11,0x10,0x10,0x08,0x07,0x08,0x10,0x10,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6277 0x1885 "ᢅ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x25,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x62,0x94,0x08,0x08,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,
+/* 6278 0x1886 "ᢆ" */
+0x00,0x00,0x0e,0x11,0x15,0x08,0x00,0x0e,0x11,0x15,0x08,0x00,0x0e,0x11,0x15,0x08,
+0x00,0x04,0xe8,0x10,0x50,0x90,0x04,0xe8,0x10,0x50,0x90,0x04,0xe8,0x10,0x50,0x90,
+/* 6279 0x1887 "ᢇ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xfc,0x04,0x08,0x10,0x00,0x00,0x00,0x00,
+/* 6280 0x1888 "ᢈ" */
+0x00,0x00,0x00,0x31,0x52,0x14,0x14,0x1c,0x1c,0x14,0x14,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 6281 0x1889 "ᢉ" */
+0x00,0x00,0x06,0x09,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6282 0x188a "ᢊ" */
+0x00,0x00,0x00,0x30,0x51,0x12,0x12,0x1e,0x1e,0x12,0x12,0x12,0x01,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6283 0x188b "ᢋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x01,0x01,0x07,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,
+/* 6284 0x188c "ᢌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x3f,0x08,0x04,0x12,0x0a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6285 0x188d "ᢍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x13,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0x10,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 6286 0x188e "ᢎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x11,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x80,0x40,0x40,0x00,0x00,0x00,
+/* 6287 0x188f "ᢏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x10,0x08,0x0e,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6288 0x1890 "ᢐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x14,0x12,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6289 0x1891 "ᢑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x10,0x12,0x09,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6290 0x1892 "ᢒ" */
+0x00,0x00,0x06,0x09,0x08,0x10,0x10,0x1f,0x1f,0x01,0x01,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6291 0x1893 "ᢓ" */
+0x00,0x00,0x06,0x09,0x08,0x10,0x10,0x1f,0x1f,0x01,0x01,0x0e,0x10,0x12,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6292 0x1894 "ᢔ" */
+0x00,0x07,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x00,0x02,0x02,0x00,
+0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x70,0x70,0x40,0x40,0x00,0x00,0x80,0x80,0x00,
+/* 6293 0x1895 "ᢕ" */
+0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x70,0x70,0x40,0x40,0x00,0x80,0x00,0x00,0x00,
+/* 6294 0x1896 "ᢖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x07,0x00,0x00,0x03,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x40,0x40,0x80,0x40,0x80,0x00,0x00,
+/* 6295 0x1897 "ᢗ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6296 0x1898 "ᢘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x14,0x12,0x0b,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 6297 0x1899 "ᢙ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x13,0x17,0x14,0x14,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xe0,0xe0,0x80,0x80,0x00,0x00,0x80,0x00,0x00,
+/* 6298 0x189a "ᢚ" */
+0x00,0x00,0x00,0x06,0x09,0x08,0x08,0x78,0x78,0x08,0x08,0x08,0x38,0x00,0x00,0x00,
+0x00,0x48,0x54,0x48,0x00,0x80,0x80,0xfe,0xfe,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6299 0x189b "ᢛ" */
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x1f,0x1f,0x10,0x13,0x14,0x13,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 6300 0x189c "ᢜ" */
+0x00,0x0e,0x11,0x0e,0x1f,0x0c,0x0c,0x17,0x17,0x54,0x24,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6301 0x189d "ᢝ" */
+0x00,0x00,0x00,0x00,0x1e,0x0c,0x0c,0x17,0x17,0x54,0x24,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x60,0x00,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6302 0x189e "ᢞ" */
+0x00,0x00,0x10,0x11,0x0a,0x09,0x04,0x07,0x07,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6303 0x189f "ᢟ" */
+0x00,0x00,0x00,0x04,0x0a,0x04,0x00,0x1f,0x1f,0x10,0x08,0x08,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0x40,0x00,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6304 0x18a0 "ᢠ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x00,0x1f,0x1f,0x14,0x12,0x09,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6305 0x18a1 "ᢡ" */
+0x00,0x00,0x02,0x02,0x12,0x28,0x44,0x87,0x47,0x2e,0x14,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0xa0,0x40,0x00,0x00,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6306 0x18a2 "ᢢ" */
+0x00,0x00,0x00,0x03,0x05,0x15,0x09,0x01,0x01,0x01,0x01,0x00,0x00,0x05,0x05,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6307 0x18a3 "ᢣ" */
+0x00,0x00,0x10,0x10,0x08,0x08,0x04,0x07,0x07,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6308 0x18a4 "ᢤ" */
+0x00,0x03,0x04,0x03,0x00,0x03,0x05,0x15,0x09,0x01,0x11,0x09,0x05,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6309 0x18a5 "ᢥ" */
+0x00,0x03,0x04,0x03,0x00,0x03,0x05,0x15,0x09,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6310 0x18a6 "ᢦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x11,0x0a,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6311 0x18a7 "ᢧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x17,0x12,0x0a,0x09,0x05,0x05,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6312 0x18a8 "ᢨ" */
+0x00,0x00,0x00,0x0e,0x11,0x10,0x10,0x1e,0x1e,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x30,0x48,0x30,0x80,0x80,0xfc,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6313 0x18a9 "ᢩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6314 0x18aa "ᢪ" */
+0x00,0x40,0x40,0x33,0x14,0x33,0x50,0x1f,0x1f,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6315 0x18ab "᢫" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6316 0x18ac "᢬" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6317 0x18ad "᢭" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6318 0x18ae "᢮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6319 0x18af "᢯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6320 0x18b0 "ᢰ" */
+0x03,0x04,0x04,0x1b,0x14,0x12,0x11,0x10,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x00,
+0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6321 0x18b1 "ᢱ" */
+0x06,0x09,0x09,0x06,0x01,0x02,0x04,0x08,0x10,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,
+/* 6322 0x18b2 "ᢲ" */
+0x18,0x24,0x24,0x18,0x01,0x02,0x04,0x08,0x10,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0xc0,0xc0,0x00,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,
+/* 6323 0x18b3 "ᢳ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x01,0x02,0x64,0x64,0x02,0x01,0x00,0x00,0x00,0x00,
+0x80,0x40,0x40,0xb0,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x30,0x00,
+/* 6324 0x18b4 "ᢴ" */
+0x18,0x24,0x24,0x58,0x20,0x10,0x08,0x04,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6325 0x18b5 "ᢵ" */
+0x18,0x24,0x24,0x1a,0x04,0x08,0x10,0x20,0x40,0x40,0x20,0x10,0x08,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6326 0x18b6 "ᢶ" */
+0x18,0x24,0x24,0x58,0x20,0x10,0x08,0x04,0x62,0x62,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6327 0x18b7 "ᢷ" */
+0x02,0x02,0x01,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x40,0x40,0x80,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 6328 0x18b8 "ᢸ" */
+0x30,0x48,0x48,0x30,0x00,0x40,0x40,0x40,0x40,0x78,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6329 0x18b9 "ᢹ" */
+0x0c,0x12,0x12,0x0c,0x00,0x10,0x10,0x10,0xd0,0xde,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6330 0x18ba "ᢺ" */
+0x30,0x48,0x48,0x30,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6331 0x18bb "ᢻ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 6332 0x18bc "ᢼ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x0e,0x11,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 6333 0x18bd "ᢽ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x0e,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 6334 0x18be "ᢾ" */
+0x18,0x24,0x24,0x18,0x00,0x04,0x04,0x04,0x1c,0x20,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6335 0x18bf "ᢿ" */
+0x30,0x48,0x48,0x30,0x00,0x40,0x40,0x40,0x70,0x08,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6336 0x18c0 "ᣀ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x0c,0x12,0x11,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x60,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 6337 0x18c1 "ᣁ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x0c,0x10,0x11,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x60,0x90,0x10,0x10,0x60,0x00,0x00,
+/* 6338 0x18c2 "ᣂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x90,0x60,0x00,0x00,0x18,0x84,0x44,0x24,0x18,0x00,0x00,
+/* 6339 0x18c3 "ᣃ" */
+0x18,0x24,0x24,0x18,0x00,0x08,0x08,0x08,0x08,0xf8,0x40,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6340 0x18c4 "ᣄ" */
+0x60,0x90,0x90,0x60,0x00,0x40,0x40,0x40,0x40,0x7c,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6341 0x18c5 "ᣅ" */
+0x18,0x24,0x24,0x18,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6342 0x18c6 "ᣆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 6343 0x18c7 "ᣇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x0c,0x0c,0x00,0x00,0x00,0x00,
+/* 6344 0x18c8 "ᣈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x03,0x34,0x34,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0xfc,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 6345 0x18c9 "ᣉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x1f,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x0c,0x0c,0x00,0x00,0x00,0x00,
+/* 6346 0x18ca "ᣊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0xf8,0x00,0x00,
+/* 6347 0x18cb "ᣋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x2c,0x2c,0x20,0xc0,0x00,0x00,
+/* 6348 0x18cc "ᣌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x38,0x44,0x44,0x44,0xf8,0x00,0x00,
+/* 6349 0x18cd "ᣍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x02,0x02,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0xc0,0x2c,0x2c,0x20,0xc0,0x00,0x00,
+/* 6350 0x18ce "ᣎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x62,0x62,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x08,0xf0,0x00,0x00,
+/* 6351 0x18cf "ᣏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x68,0x68,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x1e,0x00,0x00,
+/* 6352 0x18d0 "ᣐ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x03,0x04,0x68,0x68,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0xc0,0x20,0x10,0x10,0x10,0x1e,0x00,0x00,
+/* 6353 0x18d1 "ᣑ" */
+0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x18,0x18,0x03,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 6354 0x18d2 "ᣒ" */
+0x00,0x01,0x01,0x00,0x03,0x00,0x00,0x00,0x18,0x18,0x03,0x02,0x02,0x02,0x00,0x00,
+0x00,0x80,0x80,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 6355 0x18d3 "ᣓ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x1a,0x19,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x00,0x00,
+/* 6356 0x18d4 "ᣔ" */
+0x00,0x00,0x00,0x10,0x10,0x28,0x28,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6357 0x18d5 "ᣕ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6358 0x18d6 "ᣖ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x70,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6359 0x18d7 "ᣗ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6360 0x18d8 "ᣘ" */
+0x00,0x00,0x00,0x00,0x78,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6361 0x18d9 "ᣙ" */
+0x00,0x00,0x00,0x00,0x3e,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6362 0x18da "ᣚ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x60,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6363 0x18db "ᣛ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x10,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6364 0x18dc "ᣜ" */
+0x00,0x00,0x00,0x08,0xc8,0xd4,0x14,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6365 0x18dd "ᣝ" */
+0x00,0x00,0x00,0x20,0x26,0x56,0x50,0x88,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6366 0x18de "ᣞ" */
+0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6367 0x18df "ᣟ" */
+0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6368 0x18e0 "ᣠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x16,0x16,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 6369 0x18e1 "ᣡ" */
+0x00,0x06,0x06,0x00,0x04,0x04,0x04,0x07,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 6370 0x18e2 "ᣢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x60,0x60,0x00,0x20,0x20,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 6371 0x18e3 "ᣣ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x12,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x2c,0x2c,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 6372 0x18e4 "ᣤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x22,0x21,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x2c,0x2c,0xc0,0x00,0x00,0xe0,0x00,0x00,
+/* 6373 0x18e5 "ᣥ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x2c,0x2c,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 6374 0x18e6 "ᣦ" */
+0x00,0x00,0x06,0x06,0x00,0x1f,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 6375 0x18e7 "ᣧ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x11,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 6376 0x18e8 "ᣨ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x05,0x05,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 6377 0x18e9 "ᣩ" */
+0x00,0x00,0x06,0x06,0x00,0x09,0x09,0x05,0x05,0x0f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6378 0x18ea "ᣪ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x98,0x98,0x80,0x80,0x80,0x00,0x00,
+/* 6379 0x18eb "ᣫ" */
+0x00,0x00,0x06,0x06,0x00,0x02,0x02,0x02,0x02,0x32,0x4a,0x4a,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6380 0x18ec "ᣬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x30,0x30,0x00,0x30,0x50,0x50,0x50,0x90,0x90,0x10,0x10,0x10,0x00,0x00,
+/* 6381 0x18ed "ᣭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x16,0x16,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 6382 0x18ee "ᣮ" */
+0x00,0x00,0x03,0x03,0x00,0x0f,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 6383 0x18ef "ᣯ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 6384 0x18f0 "ᣰ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x20,0x20,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x0c,0xcc,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 6385 0x18f1 "ᣱ" */
+0x00,0x03,0x03,0x00,0x1f,0x01,0x00,0x00,0x0e,0x11,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x80,0x40,0x20,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 6386 0x18f2 "ᣲ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x4c,0x40,0x40,0x23,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x6c,0x6c,0xa0,0x20,0x20,0x00,0x00,
+/* 6387 0x18f3 "ᣳ" */
+0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6388 0x18f4 "ᣴ" */
+0x00,0x00,0x00,0x00,0x58,0x64,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6389 0x18f5 "ᣵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x38,0x04,0x78,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6390 0x18f6 "᣶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 6391 0x18f7 "᣷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 6392 0x18f8 "᣸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 6393 0x18f9 "᣹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6394 0x18fa "᣺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6395 0x18fb "᣻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6396 0x18fc "᣼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6397 0x18fd "᣽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6398 0x18fe "᣾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6399 0x18ff "᣿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6400 0x1900 "ᤀ" */
+0x00,0x00,0x00,0xff,0x10,0x20,0x40,0x7c,0x08,0x10,0x20,0x4e,0x71,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6401 0x1901 "ᤁ" */
+0x00,0x00,0x00,0x3e,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6402 0x1902 "ᤂ" */
+0x00,0x00,0x00,0x3f,0x42,0x84,0x84,0x84,0x84,0x84,0x84,0x4a,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 6403 0x1903 "ᤃ" */
+0x00,0x00,0x00,0x78,0x09,0x12,0x24,0x78,0x14,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6404 0x1904 "ᤄ" */
+0x00,0x00,0x00,0xff,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6405 0x1905 "ᤅ" */
+0x00,0x00,0x00,0x5e,0x44,0x49,0x50,0x5c,0x42,0x41,0x21,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6406 0x1906 "ᤆ" */
+0x00,0x00,0x00,0x70,0x08,0x04,0x02,0x02,0x02,0x22,0x52,0x54,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6407 0x1907 "ᤇ" */
+0x00,0x00,0x00,0x7f,0x08,0x10,0x20,0x78,0x4e,0x40,0x40,0x21,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6408 0x1908 "ᤈ" */
+0x00,0x00,0x00,0x7f,0x00,0x78,0x04,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6409 0x1909 "ᤉ" */
+0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x20,0x20,0x20,0x20,0x1f,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6410 0x190a "ᤊ" */
+0x00,0x00,0x00,0x7f,0x04,0x04,0x34,0x4c,0x46,0x49,0x30,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x40,0x40,0x00,0x00,0x00,
+/* 6411 0x190b "ᤋ" */
+0x00,0x00,0x00,0x1f,0x20,0x40,0x01,0x06,0x01,0x00,0x40,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6412 0x190c "ᤌ" */
+0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x3f,0x44,0x44,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 6413 0x190d "ᤍ" */
+0x00,0x00,0x00,0x60,0x1f,0x04,0x04,0x07,0x00,0x00,0x40,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 6414 0x190e "ᤎ" */
+0x00,0x00,0x00,0x7c,0x18,0x20,0x20,0x18,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6415 0x190f "ᤏ" */
+0x00,0x00,0x00,0x7c,0x04,0x04,0x08,0x08,0x1e,0x10,0x20,0x20,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6416 0x1910 "ᤐ" */
+0x00,0x00,0x00,0x22,0x41,0x41,0x80,0x80,0x80,0x80,0x49,0x49,0x36,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6417 0x1911 "ᤑ" */
+0x00,0x00,0x00,0x00,0x77,0x88,0x08,0x08,0x08,0x08,0x88,0x88,0x77,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6418 0x1912 "ᤒ" */
+0x00,0x00,0x00,0x60,0x1f,0x04,0x04,0x1c,0x20,0x41,0x42,0x22,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 6419 0x1913 "ᤓ" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x48,0x50,0x51,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6420 0x1914 "ᤔ" */
+0x00,0x00,0x00,0x7f,0x08,0x08,0x10,0x10,0x20,0x40,0x78,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6421 0x1915 "ᤕ" */
+0x00,0x00,0x00,0x7e,0x04,0x08,0x1c,0x02,0x32,0x4a,0x3c,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6422 0x1916 "ᤖ" */
+0x00,0x00,0x00,0x7c,0x04,0x04,0x08,0x08,0x18,0x18,0x24,0x22,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6423 0x1917 "ᤗ" */
+0x00,0x00,0x00,0x31,0x2e,0x20,0x10,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6424 0x1918 "ᤘ" */
+0x00,0x00,0x00,0x10,0x30,0x50,0x90,0x10,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6425 0x1919 "ᤙ" */
+0x00,0x00,0x00,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6426 0x191a "ᤚ" */
+0x00,0x00,0x00,0x1d,0x23,0x21,0x21,0x21,0x21,0x23,0x1d,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6427 0x191b "ᤛ" */
+0x00,0x00,0x00,0x3f,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 6428 0x191c "ᤜ" */
+0x00,0x00,0x00,0x1f,0x21,0x42,0x44,0x4f,0x40,0x40,0x20,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 6429 0x191d "ᤝ" */
+0x00,0x00,0x00,0x7f,0x10,0x10,0x1e,0x11,0x11,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6430 0x191e "ᤞ" */
+0x00,0x00,0x00,0x7f,0x10,0x10,0x1f,0x01,0x01,0x11,0x29,0x25,0x1e,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6431 0x191f "᤟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6432 0x1920 "ᤠ" */
+0x30,0x48,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6433 0x1921 "ᤡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3c,0x42,0x04,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6434 0x1922 "ᤢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x4b,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 6435 0x1923 "ᤣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x14,0x14,0x0c,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+/* 6436 0x1924 "ᤤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x12,0x2d,0x2d,0x1b,0x09,0x09,0x12,0x12,0x24,0x24,0x00,0x00,0x00,
+/* 6437 0x1925 "ᤥ" */
+0x30,0x48,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x08,0x14,0x14,0x0c,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+/* 6438 0x1926 "ᤦ" */
+0x30,0x48,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x12,0x2d,0x2d,0x1b,0x09,0x09,0x12,0x12,0x24,0x24,0x00,0x00,0x00,
+/* 6439 0x1927 "ᤧ" */
+0x60,0x18,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6440 0x1928 "ᤨ" */
+0x00,0x31,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6441 0x1929 "ᤩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x22,0x52,0x0c,0x00,0x00,
+/* 6442 0x192a "ᤪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x10,
+/* 6443 0x192b "ᤫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x72,0x0a,0x32,0x46,0x3a,0x02,0x00,0x00,0x00,
+/* 6444 0x192c "᤬" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6445 0x192d "᤭" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6446 0x192e "᤮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6447 0x192f "᤯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6448 0x1930 "ᤰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x3e,0x10,0x20,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6449 0x1931 "ᤱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0c,0x00,0x00,0x00,
+/* 6450 0x1932 "ᤲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6451 0x1933 "ᤳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x00,
+/* 6452 0x1934 "ᤴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x44,0x2a,0x2a,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6453 0x1935 "ᤵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x42,0x22,0x22,0x26,0x1a,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6454 0x1936 "ᤶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x44,0x2a,0x2a,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 6455 0x1937 "ᤷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x00,
+/* 6456 0x1938 "ᤸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x24,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6457 0x1939 "᤹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x00,
+/* 6458 0x193a "᤺" */
+0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6459 0x193b "᤻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,
+/* 6460 0x193c "᤼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6461 0x193d "᤽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6462 0x193e "᤾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6463 0x193f "᤿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6464 0x1940 "᥀" */
+0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x28,0x10,0xe0,0x00,0x00,0x00,
+/* 6465 0x1941 "᥁" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 6466 0x1942 "᥂" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 6467 0x1943 "᥃" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 6468 0x1944 "᥄" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x40,0x00,0x00,0x00,
+/* 6469 0x1945 "᥅" */
+0x00,0x00,0x00,0x04,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6470 0x1946 "᥆" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 6471 0x1947 "᥇" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x50,0x20,0xc0,0x00,0x00,0x00,
+/* 6472 0x1948 "᥈" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 6473 0x1949 "᥉" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 6474 0x194a "᥊" */
+0x00,0x00,0x00,0x18,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x08,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x20,0x18,0x00,0x00,0x00,
+/* 6475 0x194b "᥋" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xa0,0xa0,0x40,0x00,0x00,0x40,0xa0,0xa0,0xc0,0x00,0x00,0x00,
+/* 6476 0x194c "᥌" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x40,0xa0,0xa0,0xc0,0x80,0x40,0x20,
+/* 6477 0x194d "᥍" */
+0x00,0x00,0x00,0x0c,0x10,0x11,0x09,0x06,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 6478 0x194e "᥎" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6479 0x194f "᥏" */
+0x00,0x00,0x00,0x1f,0x12,0x0a,0x06,0x02,0x00,0x00,0x01,0x02,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6480 0x1950 "ᥐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x24,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6481 0x1951 "ᥑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x24,0x04,0x1c,0x24,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6482 0x1952 "ᥒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6483 0x1953 "ᥓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0x56,0x1a,0x12,0x12,0x16,0x1a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6484 0x1954 "ᥔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0x52,0x12,0x12,0x12,0x16,0x1a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6485 0x1955 "ᥕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x56,0x2a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6486 0x1956 "ᥖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0xda,0x92,0x92,0x92,0xb2,0xd2,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6487 0x1957 "ᥗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0xda,0x92,0x92,0x92,0xb6,0xda,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6488 0x1958 "ᥘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x42,0x56,0x2a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6489 0x1959 "ᥙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6490 0x195a "ᥚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x96,0x9a,0x92,0x92,0x92,0xb6,0xda,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6491 0x195b "ᥛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x44,0x4c,0x34,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6492 0x195c "ᥜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x96,0x9a,0x92,0x92,0x92,0xb6,0xda,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6493 0x195d "ᥝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6494 0x195e "ᥞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0xda,0x92,0x92,0x92,0xb2,0xd2,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6495 0x195f "ᥟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0x5a,0x12,0x12,0x12,0x12,0x12,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6496 0x1960 "ᥠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x24,0x04,0x1c,0x24,0x1c,0x04,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6497 0x1961 "ᥡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0x52,0x12,0x12,0x12,0x16,0x1a,0x02,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6498 0x1962 "ᥢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x4a,0x4a,0x52,0x52,0x62,0x42,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6499 0x1963 "ᥣ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6500 0x1964 "ᥤ" */
+0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x34,0x2c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6501 0x1965 "ᥥ" */
+0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6502 0x1966 "ᥦ" */
+0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6503 0x1967 "ᥧ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x00,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6504 0x1968 "ᥨ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6505 0x1969 "ᥩ" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6506 0x196a "ᥪ" */
+0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x34,0x2c,0x20,0x20,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6507 0x196b "ᥫ" */
+0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x20,0x20,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6508 0x196c "ᥬ" */
+0x00,0x00,0x00,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6509 0x196d "ᥭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0x52,0x12,0x12,0x12,0x16,0x1a,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6510 0x196e "᥮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6511 0x196f "᥯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6512 0x1970 "ᥰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0x4a,0x84,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6513 0x1971 "ᥱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x44,0x7c,0x40,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6514 0x1972 "ᥲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x24,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6515 0x1973 "ᥳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x24,0x2a,0x2a,0x26,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6516 0x1974 "ᥴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x40,0x40,0x40,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6517 0x1975 "᥵" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 6518 0x1976 "᥶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 6519 0x1977 "᥷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 6520 0x1978 "᥸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 6521 0x1979 "᥹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6522 0x197a "᥺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6523 0x197b "᥻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6524 0x197c "᥼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6525 0x197d "᥽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6526 0x197e "᥾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6527 0x197f "᥿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6528 0x1980 "ᦀ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x08,0x30,0x08,0x04,0x84,0x78,0x00,
+/* 6529 0x1981 "ᦁ" */
+0x00,0x01,0x02,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x70,0x88,0x04,0x04,0x04,0x08,0x30,0x08,0x04,0x84,0x78,0x00,
+/* 6530 0x1982 "ᦂ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x10,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x02,0x02,0x04,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 6531 0x1983 "ᦃ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x1a,0x24,0x1a,0x02,0x02,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6532 0x1984 "ᦄ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x02,0x01,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x04,0x38,0x00,0xf8,0x04,0xe4,0x14,0xf8,
+/* 6533 0x1985 "ᦅ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 6534 0x1986 "ᦆ" */
+0x03,0x04,0x08,0x08,0x0b,0x0c,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x10,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 6535 0x1987 "ᦇ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x90,0x10,0x10,0x20,0xc0,0x00,
+/* 6536 0x1988 "ᦈ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x06,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 6537 0x1989 "ᦉ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x04,0x04,0x88,0x70,0x00,0x00,0x00,0x00,0x00,
+/* 6538 0x198a "ᦊ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x0c,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6539 0x198b "ᦋ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x20,0x10,0x10,0xe0,0x00,
+/* 6540 0x198c "ᦌ" */
+0x03,0x04,0x08,0x08,0x0b,0x0c,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x04,0x03,0x00,
+0xc0,0x20,0x10,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x20,0x10,0x10,0xe0,0x00,
+/* 6541 0x198d "ᦍ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x04,0x02,0x02,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 6542 0x198e "ᦎ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x04,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 6543 0x198f "ᦏ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x41,0x31,0x41,0x45,0x39,0x01,0x01,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6544 0x1990 "ᦐ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x04,0x38,0x20,0x30,0x08,0x08,0xf0,
+/* 6545 0x1991 "ᦑ" */
+0x1e,0x21,0x40,0x40,0x4e,0x51,0x41,0x46,0x41,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6546 0x1992 "ᦒ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x84,0x88,0x70,0x00,0x00,0x00,0x00,0x00,
+/* 6547 0x1993 "ᦓ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0xc0,0x00,
+/* 6548 0x1994 "ᦔ" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6549 0x1995 "ᦕ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x20,0x18,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x50,0x20,0x52,0x8c,0x00,0x00,0x00,0x00,0x00,
+/* 6550 0x1996 "ᦖ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x01,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x04,0x38,0x20,0xe0,0x04,0x08,0xf0,
+/* 6551 0x1997 "ᦗ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x10,0x0e,0x00,0x03,0x04,0x05,0x04,0x03,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x02,0x06,0x3a,0x02,0xe2,0x12,0xe2,0x04,0xf8,
+/* 6552 0x1998 "ᦘ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x08,0x70,0x00,0x00,0x00,0x00,0x00,
+/* 6553 0x1999 "ᦙ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x0b,0x04,0x03,0x00,0x00,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0xd0,0x20,0xd0,0x10,0x10,0x10,0xe0,0x00,
+/* 6554 0x199a "ᦚ" */
+0x3e,0x40,0x3f,0x01,0x39,0x45,0x41,0x31,0x41,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6555 0x199b "ᦛ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x03,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x04,0x38,0x00,0xe0,0x10,0x10,0xe0,
+/* 6556 0x199c "ᦜ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x03,0x04,0x04,0x02,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x04,0x38,0x08,0x08,0x88,0x48,0x30,
+/* 6557 0x199d "ᦝ" */
+0x0f,0x10,0x20,0x20,0x2e,0x31,0x20,0x20,0x20,0x10,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x38,0x44,0x82,0x02,0x02,0x04,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 6558 0x199e "ᦞ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6559 0x199f "ᦟ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x10,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x04,0x82,0x82,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 6560 0x19a0 "ᦠ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x04,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 6561 0x19a1 "ᦡ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x04,0x18,0x04,0x02,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6562 0x19a2 "ᦢ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 6563 0x19a3 "ᦣ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x42,0x22,0x11,0x51,0x21,0x02,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6564 0x19a4 "ᦤ" */
+0x00,0x18,0x24,0x00,0x38,0x44,0x02,0x02,0x02,0x04,0x18,0x04,0x02,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6565 0x19a5 "ᦥ" */
+0x00,0x01,0x02,0x00,0x02,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 6566 0x19a6 "ᦦ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x10,0x0e,0x00,0x03,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x02,0x02,0x04,0x38,0x00,0xe0,0x10,0x10,0xe0,
+/* 6567 0x19a7 "ᦧ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x3a,0x44,0x3a,0x00,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6568 0x19a8 "ᦨ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x02,0x00,0x03,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x00,0xc0,0x20,0x20,0xc0,
+/* 6569 0x19a9 "ᦩ" */
+0x03,0x04,0x08,0x08,0x0b,0x0c,0x08,0x08,0x08,0x04,0x02,0x00,0x03,0x04,0x04,0x03,
+0xc0,0x20,0x10,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x00,0xc0,0x20,0x20,0xc0,
+/* 6570 0x19aa "ᦪ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1c,0x00,0x07,0x08,0x08,0x07,
+0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x04,0x04,0x88,0x70,0x00,0xc0,0x20,0x20,0xc0,
+/* 6571 0x19ab "ᦫ" */
+0x03,0x04,0x08,0x08,0x0b,0x0c,0x08,0x08,0x08,0x04,0x02,0x00,0x03,0x04,0x04,0x03,
+0xc0,0x20,0x10,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x20,0x90,0x60,0x40,0x80,
+/* 6572 0x19ac "᦬" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6573 0x19ad "᦭" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6574 0x19ae "᦮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6575 0x19af "᦯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6576 0x19b0 "ᦰ" */
+0x00,0x00,0x00,0x00,0x30,0x49,0x26,0x00,0x30,0x49,0x26,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6577 0x19b1 "ᦱ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6578 0x19b2 "ᦲ" */
+0x1c,0x22,0x41,0x41,0x41,0x5d,0x63,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6579 0x19b3 "ᦳ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x44,0x78,0x40,0x40,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6580 0x19b4 "ᦴ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x48,0x30,0x00,
+/* 6581 0x19b5 "ᦵ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 6582 0x19b6 "ᦶ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x13,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x13,0x00,0x00,0x00,0x00,0x00,
+/* 6583 0x19b7 "ᦷ" */
+0x38,0x44,0x40,0x20,0x18,0x20,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6584 0x19b8 "ᦸ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x14,0x08,0x14,0x63,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6585 0x19b9 "ᦹ" */
+0x1c,0x2a,0x49,0x49,0x49,0x5d,0x63,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6586 0x19ba "ᦺ" */
+0x3c,0x42,0x02,0x02,0x1e,0x22,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6587 0x19bb "ᦻ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x00,0x00,0x00,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x48,0x48,0x48,0xc8,0x48,0x48,0x48,0x48,0x30,0x00,
+/* 6588 0x19bc "ᦼ" */
+0x07,0x08,0x10,0x10,0x10,0x17,0x18,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x48,0x48,0xc8,0x48,0x48,0xc8,0x48,0x48,0x48,0x48,0x30,0x00,
+/* 6589 0x19bd "ᦽ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x84,0x44,0x24,0x24,0x24,0x64,0xa4,0x24,0x24,0x24,0x18,0x00,
+/* 6590 0x19be "ᦾ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x14,0x08,0x14,0x63,0x00,0x00,0x00,0x00,0x00,
+0x18,0x24,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6591 0x19bf "ᦿ" */
+0x07,0x0a,0x12,0x12,0x12,0x17,0x18,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x48,0x48,0xc8,0x48,0x48,0xc8,0x48,0x48,0x48,0x48,0x30,0x00,
+/* 6592 0x19c0 "ᧀ" */
+0x07,0x08,0x10,0x10,0x10,0x17,0x18,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x48,0x48,0xc8,0x48,0x48,0xc8,0x48,0x48,0x48,0x48,0x30,0x00,
+/* 6593 0x19c1 "ᧁ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x23,0x1d,0x01,0x0d,0x12,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6594 0x19c2 "ᧂ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x90,0x10,0xd0,0x20,0xc0,0x00,
+/* 6595 0x19c3 "ᧃ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x06,0x09,0x07,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0xc0,0x00,
+/* 6596 0x19c4 "ᧄ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x0b,0x04,0x03,0x00,0x03,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0xd0,0x20,0xd0,0x10,0x10,0x90,0xe0,0x00,
+/* 6597 0x19c5 "ᧅ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x10,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x02,0x02,0x06,0x3a,0x02,0x1a,0x24,0x18,0x00,
+/* 6598 0x19c6 "ᧆ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x04,0x18,0x04,0x32,0x4a,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6599 0x19c7 "ᧇ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0x10,0x30,0xd0,0x10,0xd0,0x20,0xc0,0x00,
+/* 6600 0x19c8 "ᧈ" */
+0x00,0x00,0x00,0x00,0x1c,0x20,0x40,0x5c,0x62,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6601 0x19c9 "ᧉ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x62,0x5c,0x40,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6602 0x19ca "᧊" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6603 0x19cb "᧋" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6604 0x19cc "᧌" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6605 0x19cd "᧍" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6606 0x19ce "᧎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6607 0x19cf "᧏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6608 0x19d0 "᧐" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6609 0x19d1 "᧑" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6610 0x19d2 "᧒" */
+0x00,0x00,0x00,0x00,0x0e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6611 0x19d3 "᧓" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x01,0x01,0x01,0x42,0x3c,0x10,0x08,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6612 0x19d4 "᧔" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x40,0x40,0x40,0x21,0x1e,0x04,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6613 0x19d5 "᧕" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x84,0x04,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+/* 6614 0x19d6 "᧖" */
+0x00,0x3c,0x42,0x40,0x44,0x4a,0x48,0x44,0x42,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6615 0x19d7 "᧗" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x40,0x40,0x20,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x09,0x06,0x00,
+/* 6616 0x19d8 "᧘" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x42,0x42,0x81,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6617 0x19d9 "᧙" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x49,0x46,0x40,0x40,0x40,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6618 0x19da "᧚" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x08,0x08,0xd0,0x20,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 6619 0x19db "᧛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6620 0x19dc "᧜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6621 0x19dd "᧝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6622 0x19de "᧞" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x21,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x0c,0x12,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 6623 0x19df "᧟" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x21,0x10,0x0c,0x00,0x07,0x08,0x08,0x07,
+0x00,0x0c,0x12,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0xc0,0x20,0x20,0xc0,
+/* 6624 0x19e0 "᧠" */
+0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x03,0x04,0x08,0x09,0x08,0x0a,0x0d,
+0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0xc0,0x08,0xf8,0x00,0xe0,0x20,0xa0,0x20,0xe0,
+/* 6625 0x19e1 "᧡" */
+0x00,0x03,0x04,0x05,0x02,0x00,0x04,0x03,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6626 0x19e2 "᧢" */
+0x00,0x10,0x13,0x14,0x14,0x13,0x10,0x0f,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0x90,0x10,0x10,0x10,0xe0,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6627 0x19e3 "᧣" */
+0x00,0x00,0x0e,0x11,0x11,0x19,0x15,0x19,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6628 0x19e4 "᧤" */
+0x00,0x02,0x04,0x09,0x0a,0x0a,0x09,0x07,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6629 0x19e5 "᧥" */
+0x04,0x0b,0x04,0x09,0x0a,0x0a,0x09,0x07,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x80,0x00,0x00,0x80,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6630 0x19e6 "᧦" */
+0x04,0x05,0x06,0x00,0x02,0x05,0x04,0x03,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6631 0x19e7 "᧧" */
+0x00,0x00,0x06,0x09,0x08,0x0c,0x0a,0x0c,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x10,0xc8,0x28,0x28,0x28,0x28,0x10,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6632 0x19e8 "᧨" */
+0x00,0x03,0x04,0x08,0x09,0x08,0x0a,0x0d,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x20,0xe0,0x00,0xe0,0x20,0xa0,0x20,0xc0,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6633 0x19e9 "᧩" */
+0x00,0x00,0x00,0x03,0x04,0x03,0x04,0x03,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0xc0,0x00,0x00,0x40,0x80,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6634 0x19ea "᧪" */
+0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6635 0x19eb "᧫" */
+0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x38,0x44,0x54,0x24,0x04,0x44,0x38,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6636 0x19ec "᧬" */
+0x00,0x39,0x45,0x55,0x25,0x05,0x45,0x38,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x2c,0x52,0x42,0x22,0x02,0xfc,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6637 0x19ed "᧭" */
+0x00,0x38,0x45,0x55,0x25,0x05,0x45,0x39,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0xec,0x12,0x12,0x12,0x92,0x52,0x92,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6638 0x19ee "᧮" */
+0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x48,0x54,0x50,0x48,0x3c,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6639 0x19ef "᧯" */
+0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x24,0x5c,0x20,0x48,0x54,0x50,0x48,0x3c,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,
+/* 6640 0x19f0 "᧰" */
+0x00,0x03,0x04,0x08,0x09,0x08,0x0a,0x0d,0x00,0x03,0x04,0x08,0x09,0x08,0x0a,0x0d,
+0x20,0xe0,0x00,0xe0,0x20,0xa0,0x20,0xc0,0x20,0xe0,0x00,0xe0,0x20,0xa0,0x20,0xc0,
+/* 6641 0x19f1 "᧱" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x03,0x04,0x05,0x02,0x00,0x04,0x03,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x00,
+/* 6642 0x19f2 "᧲" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x10,0x13,0x14,0x14,0x13,0x10,0x0f,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x60,0x90,0x10,0x10,0x10,0xe0,0x00,
+/* 6643 0x19f3 "᧳" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x19,0x15,0x19,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x00,
+/* 6644 0x19f4 "᧴" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x02,0x04,0x09,0x0a,0x0a,0x09,0x07,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x00,
+/* 6645 0x19f5 "᧵" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x04,0x0b,0x04,0x09,0x0a,0x0a,0x09,0x07,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x20,0xe0,0x00,0x00,0x80,0x00,0x00,0x80,0x00,
+/* 6646 0x19f6 "᧶" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x04,0x05,0x06,0x00,0x02,0x05,0x04,0x03,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x00,
+/* 6647 0x19f7 "᧷" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x0c,0x0a,0x0c,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x10,0xc8,0x28,0x28,0x28,0x28,0x10,0x00,
+/* 6648 0x19f8 "᧸" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x09,0x08,0x0a,0x0d,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x20,0xe0,0x00,0xe0,0x20,0xa0,0x20,0xc0,0x00,
+/* 6649 0x19f9 "᧹" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x03,0x04,0x03,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x40,0x40,0xc0,0x00,0x00,0x40,0x80,0x00,
+/* 6650 0x19fa "᧺" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x38,0x00,
+/* 6651 0x19fb "᧻" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x38,0x44,0x54,0x24,0x04,0x44,0x38,0x00,
+/* 6652 0x19fc "᧼" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x39,0x45,0x55,0x25,0x05,0x45,0x38,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x2c,0x52,0x42,0x22,0x02,0xfc,0x00,
+/* 6653 0x19fd "᧽" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x38,0x45,0x55,0x25,0x05,0x45,0x39,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0xec,0x12,0x12,0x12,0x92,0x52,0x92,0x00,
+/* 6654 0x19fe "᧾" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x10,0x20,0x48,0x54,0x50,0x48,0x3c,0x00,
+/* 6655 0x19ff "᧿" */
+0x00,0x04,0x09,0x06,0x00,0x00,0x00,0x00,0x1c,0x22,0x2a,0x12,0x02,0x22,0x1c,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x24,0x5c,0x20,0x48,0x54,0x50,0x48,0x3c,0x00,
+/* 6656 0x1a00 "ᨀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 6657 0x1a01 "ᨁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x90,0x90,0x60,0x60,0x00,0x00,
+/* 6658 0x1a02 "ᨂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x20,0x10,0x00,0x00,
+/* 6659 0x1a03 "ᨃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x10,0x88,0x40,0x20,0x00,0x00,
+/* 6660 0x1a04 "ᨄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x90,0x90,0x60,0x60,0x00,0x00,
+/* 6661 0x1a05 "ᨅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x02,0x01,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x80,0x40,0x20,0x00,0x00,
+/* 6662 0x1a06 "ᨆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6663 0x1a07 "ᨇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x03,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0xa0,0x40,0x00,0x00,
+/* 6664 0x1a08 "ᨈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x00,0x00,
+/* 6665 0x1a09 "ᨉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6666 0x1a0a "ᨊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0xa0,0x00,0x00,
+/* 6667 0x1a0b "ᨋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x09,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x90,0x88,0x48,0x50,0x20,0x80,0x00,
+/* 6668 0x1a0c "ᨌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x90,0x10,0xa0,0x40,0x00,0x00,
+/* 6669 0x1a0d "ᨍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x10,0x10,0xa0,0x40,0x00,0x00,
+/* 6670 0x1a0e "ᨎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x05,0x04,0x08,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x50,0x90,0x08,0x48,0x80,0x00,
+/* 6671 0x1a0f "ᨏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x05,0x04,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x50,0x90,0x48,0x48,0x00,0x00,
+/* 6672 0x1a10 "ᨐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x0a,0x0a,0x11,0x15,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x50,0x50,0x88,0xa8,0x00,0x00,
+/* 6673 0x1a11 "ᨑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x80,0x40,0x20,0x00,0x00,
+/* 6674 0x1a12 "ᨒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x50,0x10,0x48,0x88,0x00,0x00,
+/* 6675 0x1a13 "ᨓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x50,0x50,0x88,0x88,0x00,0x00,
+/* 6676 0x1a14 "ᨔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x08,0x30,0xc0,0x00,0x00,
+/* 6677 0x1a15 "ᨕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x50,0x50,0x88,0xa8,0x00,0x00,
+/* 6678 0x1a16 "ᨖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x11,0x11,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x88,0x88,0x50,0x20,0x00,0x00,
+/* 6679 0x1a17 "ᨗ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6680 0x1a18 "ᨘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,
+/* 6681 0x1a19 "ᨙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x40,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6682 0x1a1a "ᨚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x02,0x02,0x01,0x01,0x00,0x00,
+/* 6683 0x1a1b "ᨛ" */
+0x00,0x00,0x10,0x08,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6684 0x1a1c "᨜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6685 0x1a1d "᨝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6686 0x1a1e "᨞" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x0c,0x0c,0x00,
+/* 6687 0x1a1f "᨟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x44,0x00,0x44,0x38,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6688 0x1a20 "ᨠ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x44,0x44,0x44,0x88,0x30,0x00,0x00,0x00,0x00,
+/* 6689 0x1a21 "ᨡ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0xd0,0x30,0x30,0xc8,0x00,0x00,0x00,0x00,
+/* 6690 0x1a22 "ᨢ" */
+0x03,0x04,0x04,0x04,0x04,0x05,0x06,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0xe0,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0xd0,0x30,0x30,0xc8,0x00,0x00,0x00,0x00,
+/* 6691 0x1a23 "ᨣ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 6692 0x1a24 "ᨤ" */
+0x03,0x04,0x04,0x04,0x04,0x05,0x06,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0xc0,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 6693 0x1a25 "ᨥ" */
+0x00,0x00,0x00,0x00,0x00,0x05,0x0a,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0xa4,0x24,0x24,0xa4,0x58,0x00,0x00,0x00,0x00,
+/* 6694 0x1a26 "ᨦ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0xc8,0x28,0x00,0x00,0x00,0x00,
+/* 6695 0x1a27 "ᨧ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6696 0x1a28 "ᨨ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x88,0x44,0x44,0x44,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 6697 0x1a29 "ᨩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x10,0x08,0x08,0xc8,0x00,0x00,0x00,0x00,
+/* 6698 0x1a2a "ᨪ" */
+0x03,0x04,0x04,0x04,0x04,0x05,0x06,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0xe0,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0x10,0x10,0x90,0x00,0x00,0x00,0x00,
+/* 6699 0x1a2b "ᨫ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x88,0x44,0x44,0x44,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 6700 0x1a2c "ᨬ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x07,0x04,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x44,0x44,0x44,0x88,0x70,0x00,0x04,0x04,0xf8,
+/* 6701 0x1a2d "ᨭ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 6702 0x1a2e "ᨮ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x02,0x04,0x04,0x03,0x00,0x03,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x18,0xe8,0x08,0xc8,0x10,0xe0,
+/* 6703 0x1a2f "ᨯ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x30,0x08,0x00,0x00,0x00,
+/* 6704 0x1a30 "ᨰ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x50,0x48,0x88,0x08,0x50,0xa0,0x00,0x00,0x00,0x00,
+/* 6705 0x1a31 "ᨱ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0xa8,0xa4,0xa4,0xa4,0x48,0x10,0x00,0x00,0x00,0x00,
+/* 6706 0x1a32 "ᨲ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x44,0x44,0x44,0x88,0x30,0x00,0x00,0x00,0x00,
+/* 6707 0x1a33 "ᨳ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x02,0x01,0x02,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x48,0x28,0xa8,0x48,0x00,0x00,0x00,0x00,
+/* 6708 0x1a34 "ᨴ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x10,0x20,0x10,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 6709 0x1a35 "ᨵ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0xd0,0x20,0x00,0x00,0x00,0x00,
+/* 6710 0x1a36 "ᨶ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0xe0,0x10,0x08,0x00,0x00,0x00,
+/* 6711 0x1a37 "ᨷ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 6712 0x1a38 "ᨸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x06,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6713 0x1a39 "ᨹ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x28,0x28,0x90,0x68,0x00,0x00,0x00,0x00,
+/* 6714 0x1a3a "ᨺ" */
+0x03,0x04,0x04,0x04,0x03,0x00,0x02,0x04,0x02,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0xf0,0x08,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 6715 0x1a3b "ᨻ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0xd0,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 6716 0x1a3c "ᨼ" */
+0x03,0x04,0x04,0x04,0x04,0x05,0x06,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0xe0,0x00,0x00,0x00,0x00,0x20,0xd0,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 6717 0x1a3d "ᨽ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x44,0x44,0x44,0x88,0x30,0x00,0x00,0x00,0x00,
+/* 6718 0x1a3e "ᨾ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0xe8,0x10,0xe8,0x04,0x00,0x00,0x00,
+/* 6719 0x1a3f "ᨿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x44,0x44,0x44,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 6720 0x1a40 "ᩀ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x06,0x08,0x08,0x08,0x08,0x88,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 6721 0x1a41 "ᩁ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x02,0x01,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x90,0x48,0x88,0x00,0x00,0x00,0x00,
+/* 6722 0x1a42 "ᩂ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x02,0x00,0x00,0x03,0x04,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x88,0x08,0x08,0x08,0xe8,0x18,0x88,0xf4,0x20,
+/* 6723 0x1a43 "ᩃ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x84,0x84,0x44,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 6724 0x1a44 "ᩄ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x03,0x00,0x03,0x04,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xe0,0x10,0xd0,0x30,0x90,0xe8,0x20,
+/* 6725 0x1a45 "ᩅ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 6726 0x1a46 "ᩆ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0xe8,0x10,0xe8,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 6727 0x1a47 "ᩇ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x44,0x44,0x54,0x88,0x74,0x00,0x00,0x00,0x00,
+/* 6728 0x1a48 "ᩈ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x44,0x44,0x44,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 6729 0x1a49 "ᩉ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x44,0x84,0x84,0x88,0x30,0x00,0x00,0x00,0x00,
+/* 6730 0x1a4a "ᩊ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x02,0x04,0x04,0x03,0x02,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0xc8,0x28,0x00,0x70,0x08,0xf0,
+/* 6731 0x1a4b "ᩋ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x44,0x44,0x44,0x88,0x30,0x08,0x04,0x00,0x00,
+/* 6732 0x1a4c "ᩌ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x01,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x44,0x84,0x84,0x88,0x30,0x10,0x90,0x10,0xe0,
+/* 6733 0x1a4d "ᩍ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x02,0x00,0x03,0x04,0x04,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x30,0xc8,0x08,0x08,0x10,0x00,0xe0,0x10,0xc8,0x48,0x08,
+/* 6734 0x1a4e "ᩎ" */
+0x00,0x01,0x01,0x00,0x00,0x03,0x04,0x04,0x04,0x02,0x00,0x03,0x04,0x04,0x05,0x02,
+0xfc,0x02,0x00,0xfe,0x02,0x32,0xca,0x0a,0x0a,0x12,0x02,0xe2,0x12,0xca,0x4a,0x0c,
+/* 6735 0x1a4f "ᩏ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x04,0x06,0x05,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x10,0xe0,
+/* 6736 0x1a50 "ᩐ" */
+0x03,0x04,0x04,0x04,0x04,0x05,0x06,0x00,0x00,0x04,0x06,0x05,0x04,0x04,0x02,0x01,
+0xc0,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x10,0xe0,
+/* 6737 0x1a51 "ᩑ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x10,0xe0,
+/* 6738 0x1a52 "ᩒ" */
+0x08,0x10,0x10,0x10,0x10,0x13,0x14,0x10,0x10,0x10,0x14,0x13,0x10,0x10,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x44,0x44,0x44,0x88,0x30,0x08,0x04,0x00,0x00,
+/* 6739 0x1a53 "ᩓ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x06,0x08,0x08,0x08,0x08,0x08,0x88,0x88,0x88,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 6740 0x1a54 "ᩔ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0x00,0x00,0x05,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x24,0x92,0x92,0x92,0xb4,0x48,0x00,0x00,0x00,0x00,
+/* 6741 0x1a55 "ᩕ" */
+0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6742 0x1a56 "ᩖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x09,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,
+/* 6743 0x1a57 "ᩗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x06,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x65,0x92,0x4d,
+/* 6744 0x1a58 "ᩘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x10,0x0c,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6745 0x1a59 "ᩙ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0xd0,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6746 0x1a5a "ᩚ" */
+0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xa0,0x50,0x10,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6747 0x1a5b "ᩛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x80,
+/* 6748 0x1a5c "ᩜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xc0,0xa0,
+/* 6749 0x1a5d "ᩝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,
+/* 6750 0x1a5e "ᩞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x0d,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,
+/* 6751 0x1a5f "᩟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6752 0x1a60 "᩠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x08,
+/* 6753 0x1a61 "ᩡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,
+/* 6754 0x1a62 "ᩢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6755 0x1a63 "ᩣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x00,0x00,0x00,0x00,
+/* 6756 0x1a64 "ᩤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0e,0x11,0x11,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+/* 6757 0x1a65 "ᩥ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6758 0x1a66 "ᩦ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6759 0x1a67 "ᩧ" */
+0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x08,0x48,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6760 0x1a68 "ᩨ" */
+0x03,0x04,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xb0,0x48,0x48,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6761 0x1a69 "ᩩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x18,0x00,
+/* 6762 0x1a6a "ᩪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x28,0x2c,0x00,
+/* 6763 0x1a6b "ᩫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x78,0x64,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6764 0x1a6c "ᩬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x48,0x36,
+/* 6765 0x1a6d "ᩭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x09,0x09,0x06,
+/* 6766 0x1a6e "ᩮ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x80,0x80,0x80,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6767 0x1a6f "ᩯ" */
+0x00,0x00,0x00,0x00,0x00,0x50,0xa0,0xa0,0xa0,0xa0,0xa0,0x50,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6768 0x1a70 "ᩰ" */
+0x00,0x40,0x80,0x80,0x80,0x40,0x80,0x80,0x80,0x80,0x80,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6769 0x1a71 "ᩱ" */
+0x00,0x00,0x80,0x40,0x20,0x60,0x80,0x80,0x80,0x80,0x80,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6770 0x1a72 "ᩲ" */
+0x00,0x40,0xa0,0x20,0x20,0x60,0x80,0x80,0x80,0x80,0x80,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6771 0x1a73 "ᩳ" */
+0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0xa0,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6772 0x1a74 "ᩴ" */
+0x02,0x05,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6773 0x1a75 "᩵" */
+0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6774 0x1a76 "᩶" */
+0x00,0x02,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6775 0x1a77 "᩷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6776 0x1a78 "᩸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x02,0x02,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6777 0x1a79 "᩹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x04,0x18,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6778 0x1a7a "᩺" */
+0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x48,0x24,0xe4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6779 0x1a7b "᩻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x16,0x14,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6780 0x1a7c "᩼" */
+0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x34,0x48,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6781 0x1a7d "᩽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6782 0x1a7e "᩾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6783 0x1a7f "᩿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6784 0x1a80 "᪀" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6785 0x1a81 "᪁" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 6786 0x1a82 "᪂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,
+/* 6787 0x1a83 "᪃" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x03,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x80,0x40,
+/* 6788 0x1a84 "᪄" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x01,0x02,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x20,0xc0,0x40,0x80,0x80,0x00,0x00,
+/* 6789 0x1a85 "᪅" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x07,0x04,0x03,0x00,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x90,0x10,0x10,0x10,0x10,0x20,0xc0,
+/* 6790 0x1a86 "᪆" */
+0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x10,0x00,0x60,0x90,0xe0,0x80,0x70,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6791 0x1a87 "᪇" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x30,
+/* 6792 0x1a88 "᪈" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x05,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x90,0x20,0x00,0x00,0x00,0x00,
+/* 6793 0x1a89 "᪉" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x70,0x80,0xe0,0x90,0x60,0x00,0x10,0x20,0xc0,
+/* 6794 0x1a8a "᪊" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6795 0x1a8b "᪋" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6796 0x1a8c "᪌" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6797 0x1a8d "᪍" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6798 0x1a8e "᪎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6799 0x1a8f "᪏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6800 0x1a90 "᪐" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6801 0x1a91 "᪑" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x05,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6802 0x1a92 "᪒" */
+0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x06,0x05,0x02,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6803 0x1a93 "᪓" */
+0x00,0x00,0x01,0x01,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x70,0x08,0x04,0x04,0x04,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 6804 0x1a94 "᪔" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x04,0x02,0x03,0x02,0x02,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x20,0x40,0x20,0x10,0xe0,0x00,0xe0,0x10,0xe0,
+/* 6805 0x1a95 "᪕" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x02,0x03,0x00,0x00,0x00,0x00,
+0x20,0x20,0x40,0x80,0x00,0x60,0x90,0x20,0x40,0x20,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 6806 0x1a96 "᪖" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x02,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6807 0x1a97 "᪗" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x02,0x04,0x05,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6808 0x1a98 "᪘" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x40,0x20,0x00,0x03,0x04,0x09,0x0a,0x04,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x60,0x40,0xf8,0x44,0xf2,0x49,0x31,
+/* 6809 0x1a99 "᪙" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x28,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x82,0x82,0x82,0x44,0x38,0x00,0x00,0x00,0x00,
+/* 6810 0x1a9a "᪚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6811 0x1a9b "᪛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6812 0x1a9c "᪜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6813 0x1a9d "᪝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6814 0x1a9e "᪞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6815 0x1a9f "᪟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6816 0x1aa0 "᪠" */
+0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x1f,0x10,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x90,0x88,0x84,0x84,0xfc,0x84,0x84,0x88,0x90,0xe0,0x00,0x00,0x00,
+/* 6817 0x1aa1 "᪡" */
+0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x1f,0x10,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xfc,0x84,0x84,0x88,0x90,0xe0,0x00,0x00,0x00,
+/* 6818 0x1aa2 "᪢" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x01,0x01,0x01,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x12,0x4c,0x38,0xd0,0x20,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 6819 0x1aa3 "᪣" */
+0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x15,0x0c,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0xc0,0x20,0x98,0x54,0x98,0x20,0xc0,0x40,0x80,0x00,0x00,0x00,
+/* 6820 0x1aa4 "᪤" */
+0x00,0x00,0x00,0x0f,0x10,0x27,0x28,0x29,0x28,0x27,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xc8,0x28,0xc8,0x10,0xe0,0x0c,0xf0,0x00,0x00,0x00,0x00,
+/* 6821 0x1aa5 "᪥" */
+0x00,0x03,0x02,0x09,0x15,0x0a,0x65,0x5a,0x44,0x5a,0x65,0x0a,0x15,0x09,0x02,0x03,
+0x00,0xe0,0x20,0x48,0x54,0xa8,0x53,0x2d,0x11,0x2d,0x53,0xa8,0x54,0x48,0x20,0xe0,
+/* 6822 0x1aa6 "᪦" */
+0x00,0x01,0x02,0x04,0x04,0x01,0x02,0x02,0x02,0x01,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0xc0,0x20,0x10,0x10,0x90,0x60,0x00,0x60,0x90,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 6823 0x1aa7 "ᪧ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0a,0x04,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x08,0x08,0x10,0x60,0x80,0x00,0x00,0x00,0x00,
+/* 6824 0x1aa8 "᪨" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6825 0x1aa9 "᪩" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6826 0x1aaa "᪪" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x09,0x07,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6827 0x1aab "᪫" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x12,0x0e,0x02,0x02,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 6828 0x1aac "᪬" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x0e,0x11,0x01,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x38,0x04,0x04,0xc4,0x28,0x30,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6829 0x1aad "᪭" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x05,0x04,0x02,0x04,0x04,0x04,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x40,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,
+/* 6830 0x1aae "᪮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6831 0x1aaf "᪯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6832 0x1ab0 "᪰" */
+0x00,0x14,0x2a,0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6833 0x1ab1 "᪱" */
+0x00,0x08,0x14,0x55,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6834 0x1ab2 "᪲" */
+0x00,0x36,0x49,0x36,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6835 0x1ab3 "᪳" */
+0x00,0x08,0x2a,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6836 0x1ab4 "᪴" */
+0x00,0x00,0x08,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6837 0x1ab5 "᪵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x22,0x55,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6838 0x1ab6 "᪶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x55,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6839 0x1ab7 "᪷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6840 0x1ab8 "᪸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x12,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6841 0x1ab9 "᪹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6842 0x1aba "᪺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6843 0x1abb "᪻" */
+0x00,0x00,0x42,0x81,0x81,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6844 0x1abc "᪼" */
+0x00,0x24,0xc3,0xc3,0xc3,0xc3,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6845 0x1abd "᪽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x81,0x81,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6846 0x1abe "᪾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x81,0x81,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6847 0x1abf "ᪿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6848 0x1ac0 "ᫀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x54,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6849 0x1ac1 "᫁" */
+0x40,0x80,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6850 0x1ac2 "᫂" */
+0x02,0x01,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6851 0x1ac3 "᫃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6852 0x1ac4 "᫄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6853 0x1ac5 "᫅" */
+0xc3,0x81,0x81,0xc3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6854 0x1ac6 "᫆" */
+0x24,0xff,0x24,0xff,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6855 0x1ac7 "᫇" */
+0x92,0x92,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6856 0x1ac8 "᫈" */
+0x10,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6857 0x1ac9 "᫉" */
+0x44,0xee,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6858 0x1aca "᫊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xee,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6859 0x1acb "᫋" */
+0x49,0x92,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6860 0x1acc "ᫌ" */
+0x7e,0x20,0x1c,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6861 0x1acd "ᫍ" */
+0x58,0x64,0x44,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6862 0x1ace "ᫎ" */
+0x7c,0x20,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6863 0x1acf "᫏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6864 0x1ad0 "᫐" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 6865 0x1ad1 "᫑" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 6866 0x1ad2 "᫒" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 6867 0x1ad3 "᫓" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 6868 0x1ad4 "᫔" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 6869 0x1ad5 "᫕" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 6870 0x1ad6 "᫖" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 6871 0x1ad7 "᫗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 6872 0x1ad8 "᫘" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 6873 0x1ad9 "᫙" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6874 0x1ada "᫚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6875 0x1adb "᫛" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6876 0x1adc "᫜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6877 0x1add "᫝" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6878 0x1ade "᫞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6879 0x1adf "᫟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6880 0x1ae0 "᫠" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 6881 0x1ae1 "᫡" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 6882 0x1ae2 "᫢" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 6883 0x1ae3 "᫣" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 6884 0x1ae4 "᫤" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 6885 0x1ae5 "᫥" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 6886 0x1ae6 "᫦" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 6887 0x1ae7 "᫧" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 6888 0x1ae8 "᫨" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 6889 0x1ae9 "᫩" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6890 0x1aea "᫪" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6891 0x1aeb "᫫" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6892 0x1aec "᫬" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6893 0x1aed "᫭" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6894 0x1aee "᫮" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6895 0x1aef "᫯" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6896 0x1af0 "᫰" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 6897 0x1af1 "᫱" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 6898 0x1af2 "᫲" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 6899 0x1af3 "᫳" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 6900 0x1af4 "᫴" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 6901 0x1af5 "᫵" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 6902 0x1af6 "᫶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 6903 0x1af7 "᫷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 6904 0x1af8 "᫸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 6905 0x1af9 "᫹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 6906 0x1afa "᫺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 6907 0x1afb "᫻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 6908 0x1afc "᫼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 6909 0x1afd "᫽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6910 0x1afe "᫾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6911 0x1aff "᫿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6912 0x1b00 "ᬀ" */
+0x0f,0x11,0x12,0x09,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0x90,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6913 0x1b01 "ᬁ" */
+0x01,0x0a,0x0a,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xa0,0xa0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6914 0x1b02 "ᬂ" */
+0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6915 0x1b03 "ᬃ" */
+0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6916 0x1b04 "ᬄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x05,0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+/* 6917 0x1b05 "ᬅ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x24,0x2a,0x22,0x24,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x28,0xa4,0x24,0xfc,0xa4,0x24,0xc4,0x00,0x00,0x00,
+/* 6918 0x1b06 "ᬆ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x92,0xa8,0x88,0x92,0x49,0x36,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x44,0x28,0x00,0x00,0x00,
+/* 6919 0x1b07 "ᬇ" */
+0x00,0x00,0x00,0x00,0x11,0x2a,0x0a,0x0a,0x04,0x01,0x00,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x08,0x08,0xc8,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 6920 0x1b08 "ᬈ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x13,0x04,0x03,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x22,0x21,0x21,0x26,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 6921 0x1b09 "ᬉ" */
+0x00,0x00,0x00,0x00,0x0b,0x04,0x00,0x00,0x03,0x04,0x09,0x0a,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0xc0,0x20,0x10,0x00,0x00,0x00,
+/* 6922 0x1b0a "ᬊ" */
+0x00,0x00,0x00,0x00,0x17,0x08,0x00,0x01,0x06,0x08,0x13,0x14,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x88,0x84,0x04,0x18,0x00,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 6923 0x1b0b "ᬋ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x03,0x01,0x02,0x01,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0xc8,0x80,0x00,0x80,0x40,0x80,0x00,0x00,0x00,
+/* 6924 0x1b0c "ᬌ" */
+0x00,0x00,0x00,0x00,0x40,0xa1,0x21,0x1e,0x0c,0x10,0x0c,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x98,0x44,0x42,0x42,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6925 0x1b0d "ᬍ" */
+0x00,0x00,0x00,0x00,0x11,0x2a,0x0a,0x0a,0x04,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x0a,0x7c,0x88,0x10,0x90,0x60,0x40,0x00,0x00,0x00,
+/* 6926 0x1b0e "ᬎ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x29,0x12,0x04,0x02,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x2e,0xf1,0x21,0x42,0x49,0x89,0x06,0x00,0x00,0x00,
+/* 6927 0x1b0f "ᬏ" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x13,0x14,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6928 0x1b10 "ᬐ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x10,0x07,0x08,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc5,0x2b,0x2e,0x22,0x42,0x82,0x02,0xc2,0x3c,0x00,0x00,0x00,
+/* 6929 0x1b11 "ᬑ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x10,0x07,0x08,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x80,0x00,0xc0,0x20,0x00,0x00,0x00,
+/* 6930 0x1b12 "ᬒ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x10,0x07,0x08,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x22,0x21,0x21,0x46,0x80,0x00,0xc0,0x20,0x00,0x00,0x00,
+/* 6931 0x1b13 "ᬓ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x3f,0x54,0x23,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0x2a,0xaa,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6932 0x1b14 "ᬔ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x3f,0x54,0x23,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xa0,0x1c,0x02,0x00,0x00,0x00,0x00,0x00,
+/* 6933 0x1b15 "ᬕ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x14,0x12,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x98,0x54,0x54,0x54,0x94,0xe4,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6934 0x1b16 "ᬖ" */
+0x00,0x00,0x00,0x00,0x23,0x55,0x15,0x15,0x15,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x14,0x14,0x14,0x54,0xa4,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6935 0x1b17 "ᬗ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x14,0x14,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6936 0x1b18 "ᬘ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x0e,0x15,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x48,0x28,0x28,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6937 0x1b19 "ᬙ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x4a,0x4a,0x31,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x28,0x28,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6938 0x1b1a "ᬚ" */
+0x00,0x00,0x00,0x00,0x11,0x2a,0x0a,0x0a,0x0a,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x60,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 6939 0x1b1b "ᬛ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x10,0x07,0x08,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x0c,0x12,0x0f,0xc2,0x22,0x22,0x22,0x42,0x82,0x02,0xc2,0x3c,0x00,0x00,0x00,
+/* 6940 0x1b1c "ᬜ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x28,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc6,0x29,0x29,0x29,0x29,0x32,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6941 0x1b1d "ᬝ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x10,0x38,0x54,0x48,0x21,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6942 0x1b1e "ᬞ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x10,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6943 0x1b1f "ᬟ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x10,0x10,0x13,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x28,0x28,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6944 0x1b20 "ᬠ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x08,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6945 0x1b21 "ᬡ" */
+0x00,0x00,0x00,0x00,0x9c,0xa3,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe2,0x15,0x15,0x15,0x15,0x19,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6946 0x1b22 "ᬢ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x17,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0xaa,0xaa,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6947 0x1b23 "ᬣ" */
+0x00,0x00,0x00,0x00,0x11,0x28,0x08,0x0a,0x09,0x07,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x90,0x50,0x50,0x50,0x90,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6948 0x1b24 "ᬤ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x09,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0xc8,0xa8,0x48,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6949 0x1b25 "ᬥ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x08,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x24,0x14,0x14,0x94,0x64,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6950 0x1b26 "ᬦ" */
+0x00,0x00,0x00,0x00,0x08,0x15,0x05,0x0f,0x15,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0xc8,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6951 0x1b27 "ᬧ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x50,0x50,0x50,0x90,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6952 0x1b28 "ᬨ" */
+0x00,0x00,0x00,0x00,0x10,0x29,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x50,0xe0,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6953 0x1b29 "ᬩ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x28,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0x2a,0x2a,0x32,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6954 0x1b2a "ᬪ" */
+0x00,0x00,0x00,0x00,0x20,0x51,0x09,0x03,0x15,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0xc8,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6955 0x1b2b "ᬫ" */
+0x00,0x00,0x00,0x00,0x1f,0x24,0x24,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0x28,0x28,0x28,0x28,0x48,0x88,0x00,0x00,0x00,0x00,0x00,
+/* 6956 0x1b2c "ᬬ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x11,0x11,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x14,0x94,0x64,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6957 0x1b2d "ᬭ" */
+0x00,0x00,0x00,0x00,0x10,0x29,0x05,0x05,0x05,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6958 0x1b2e "ᬮ" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x29,0x29,0x29,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x0a,0x0a,0x0a,0xf2,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6959 0x1b2f "ᬯ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x48,0x28,0x28,0x28,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6960 0x1b30 "ᬰ" */
+0x00,0x00,0x00,0x00,0x47,0xa9,0x2a,0x28,0x24,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe6,0x15,0x95,0x95,0xa5,0x39,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6961 0x1b31 "ᬱ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x12,0x15,0x11,0x0f,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x50,0x50,0x50,0xd0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6962 0x1b32 "ᬲ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x1c,0x2a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x50,0x50,0x50,0x90,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6963 0x1b33 "ᬳ" */
+0x00,0x00,0x00,0x00,0x40,0xa1,0x21,0x21,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0x2a,0x2a,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6964 0x1b34 "᬴" */
+0x00,0x01,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6965 0x1b35 "ᬵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6966 0x1b36 "ᬶ" */
+0x03,0x14,0x0c,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6967 0x1b37 "ᬷ" */
+0x03,0x15,0x0e,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6968 0x1b38 "ᬸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x03,0x05,0x09,0x11,0x12,0x0c,
+/* 6969 0x1b39 "ᬹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x01,0x02,0x04,
+/* 6970 0x1b3a "ᬺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x09,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x90,0xa0,0xc0,0x80,
+/* 6971 0x1b3b "ᬻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x09,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x09,0x26,0x10,0x10,0x90,0xa0,0xc0,0x80,
+/* 6972 0x1b3c "ᬼ" */
+0x00,0x01,0x12,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x08,
+0xe0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x88,0x88,0x70,
+/* 6973 0x1b3d "ᬽ" */
+0x00,0x01,0x12,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x08,
+0xe0,0x20,0x40,0x80,0x0c,0x02,0x01,0x01,0x09,0x06,0x00,0x00,0x08,0x88,0x88,0x70,
+/* 6974 0x1b3e "ᬾ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x10,0x10,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6975 0x1b3f "ᬿ" */
+0x38,0x40,0x30,0x08,0x30,0xb0,0xc8,0x90,0x10,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6976 0x1b40 "ᭀ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x10,0x10,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6977 0x1b41 "ᭁ" */
+0x38,0x40,0x30,0x08,0x30,0xb0,0xc8,0x90,0x10,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6978 0x1b42 "ᭂ" */
+0x00,0x01,0x12,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6979 0x1b43 "ᭃ" */
+0x00,0x01,0x12,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x20,0x40,0x80,0x0c,0x02,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6980 0x1b44 "᭄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0e,0x11,0x11,0x01,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x01,0x00,0x00,0x00,
+/* 6981 0x1b45 "ᭅ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x1c,0x3f,0x5c,0x2b,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0x2a,0xaa,0x12,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 6982 0x1b46 "ᭆ" */
+0x00,0x00,0x00,0x00,0x47,0xa8,0x28,0x7c,0xaa,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x16,0xad,0xad,0xad,0xad,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6983 0x1b47 "ᭇ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x17,0x10,0x14,0x0f,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0xaa,0xaa,0x12,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 6984 0x1b48 "ᭈ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x05,0x05,0x03,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x28,0x28,0x28,0xc8,0x00,0x10,0xe0,0x00,0x00,0x00,
+/* 6985 0x1b49 "ᭉ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x05,0x05,0x03,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x48,0x28,0x28,0x28,0xc8,0x00,0x10,0xe0,0x00,0x00,0x00,
+/* 6986 0x1b4a "ᭊ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x08,0x1d,0x2b,0x11,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x50,0x50,0x50,0x90,0x00,0x10,0xe0,0x00,0x00,0x00,
+/* 6987 0x1b4b "ᭋ" */
+0x00,0x00,0x00,0x00,0x43,0xa2,0x22,0x72,0xaa,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0xa5,0xa5,0xb5,0xb5,0xb5,0x4d,0x00,0x00,0x00,0x00,0x00,
+/* 6988 0x1b4c "ᭌ" */
+0x00,0x00,0x00,0x00,0x30,0x49,0x4a,0x4a,0x0a,0x0a,0x09,0x07,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x02,0x02,0x72,0x0c,0x04,0x02,0x32,0x40,0x38,0x04,0xf8,
+/* 6989 0x1b4d "᭍" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 6990 0x1b4e "᭎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 6991 0x1b4f "᭏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 6992 0x1b50 "᭐" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6993 0x1b51 "᭑" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x14,0x14,0x14,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x04,0x0a,0x07,0x62,0x92,0x12,0x12,0x14,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6994 0x1b52 "᭒" */
+0x00,0x00,0x00,0x00,0x11,0x2a,0x0a,0x0a,0x04,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x0a,0x7c,0x88,0x10,0x90,0x60,0x40,0x00,0x00,0x00,
+/* 6995 0x1b53 "᭓" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x10,0x07,0x08,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x80,0x00,0xc0,0x20,0x00,0x00,0x00,
+/* 6996 0x1b54 "᭔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0x08,0x09,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 6997 0x1b55 "᭕" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0b,0x08,0x09,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xa0,0x20,0xa0,0xa0,0x20,0x20,0x20,0x10,0x00,
+/* 6998 0x1b56 "᭖" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x13,0x14,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 6999 0x1b57 "᭗" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x29,0x29,0x29,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x22,0x54,0x38,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7000 0x1b58 "᭘" */
+0x00,0x00,0x00,0x00,0x10,0x29,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x50,0xe0,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7001 0x1b59 "᭙" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x11,0x11,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x22,0x54,0x38,0x10,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7002 0x1b5a "᭚" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x92,0x92,0x61,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x48,0x89,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 7003 0x1b5b "᭛" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x28,0x18,0x02,0x12,0x11,0x10,0x11,0x0e,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0x2a,0x2a,0x0a,0x3f,0x4a,0x8a,0x0a,0x8a,0x72,
+/* 7004 0x1b5c "᭜" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7005 0x1b5d "᭝" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x03,0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa0,0xc0,0x00,0x10,0xa0,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7006 0x1b5e "᭞" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 7007 0x1b5f "᭟" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x04,0x04,0x02,0x02,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xa0,0x10,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 7008 0x1b60 "᭠" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7009 0x1b61 "᭡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7010 0x1b62 "᭢" */
+0x00,0x00,0x00,0x00,0x05,0x06,0x04,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,
+/* 7011 0x1b63 "᭣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xc0,0xc0,0xc0,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7012 0x1b64 "᭤" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 7013 0x1b65 "᭥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7014 0x1b66 "᭦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x14,0x0c,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7015 0x1b67 "᭧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x05,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x90,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7016 0x1b68 "᭨" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x20,0x10,0x08,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7017 0x1b69 "᭩" */
+0x00,0x00,0x00,0x00,0x46,0xa9,0x28,0x28,0x10,0x07,0x08,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x2a,0x2a,0x2a,0x4a,0x8a,0x0a,0x8a,0x72,0x00,0x00,0x00,
+/* 7018 0x1b6a "᭪" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x04,0x08,0x04,0x04,0x04,0x08,0x08,0x08,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7019 0x1b6b "᭫" */
+0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7020 0x1b6c "᭬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,
+/* 7021 0x1b6d "᭭" */
+0x03,0x01,0x07,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7022 0x1b6e "᭮" */
+0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7023 0x1b6f "᭯" */
+0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7024 0x1b70 "᭰" */
+0x07,0x01,0x0f,0x03,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7025 0x1b71 "᭱" */
+0x07,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7026 0x1b72 "᭲" */
+0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7027 0x1b73 "᭳" */
+0x03,0x04,0x05,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7028 0x1b74 "᭴" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7029 0x1b75 "᭵" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7030 0x1b76 "᭶" */
+0x00,0x00,0x00,0x00,0x00,0x90,0x68,0x28,0x54,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7031 0x1b77 "᭷" */
+0x00,0x00,0x00,0x00,0x00,0xb8,0x44,0x64,0x54,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7032 0x1b78 "᭸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7033 0x1b79 "᭹" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x20,0x40,0x78,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7034 0x1b7a "᭺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x78,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7035 0x1b7b "᭻" */
+0x00,0x00,0x00,0x00,0x00,0x90,0x50,0x20,0x30,0x48,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7036 0x1b7c "᭼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7037 0x1b7d "᭽" */
+0x00,0x00,0x00,0x00,0x10,0x29,0x2a,0x2a,0xaa,0xa4,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0xaa,0xaa,0xa4,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7038 0x1b7e "᭾" */
+0x00,0x00,0x00,0x00,0x45,0xaa,0x28,0x28,0x25,0x4f,0xb0,0x44,0x3b,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc8,0xd5,0xd5,0x52,0x50,0xa0,0x80,0x00,0x00,0x00,0x00,
+/* 7039 0x1b7f "᭿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 7040 0x1b80 "ᮀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7041 0x1b81 "ᮁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x22,0x54,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7042 0x1b82 "ᮂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x12,0x0a,0x08,0x00,0x00,0x00,0x00,
+/* 7043 0x1b83 "ᮃ" */
+0x00,0x00,0x00,0x00,0x05,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x20,0x40,0xe0,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7044 0x1b84 "ᮄ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7045 0x1b85 "ᮅ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7046 0x1b86 "ᮆ" */
+0x00,0x00,0x00,0x00,0x0b,0x10,0x10,0x11,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x40,0xf0,0xc8,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7047 0x1b87 "ᮇ" */
+0x00,0x00,0x00,0x00,0x07,0x05,0x03,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0xd0,0x00,0x00,0x00,0x00,0x00,
+/* 7048 0x1b88 "ᮈ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xf0,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7049 0x1b89 "ᮉ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x50,0x20,0x00,0xf0,0x20,0x70,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7050 0x1b8a "ᮊ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x20,0x20,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 7051 0x1b8b "ᮋ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x09,0x09,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x48,0x48,0x90,0x90,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 7052 0x1b8c "ᮌ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x10,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7053 0x1b8d "ᮍ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 7054 0x1b8e "ᮎ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x06,0x0b,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x10,0x10,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7055 0x1b8f "ᮏ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x05,0x09,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x20,0x90,0x48,0x00,0x00,0x00,0x00,0x00,
+/* 7056 0x1b90 "ᮐ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0xa0,0x00,0x00,0x00,0x00,0x00,
+/* 7057 0x1b91 "ᮑ" */
+0x00,0x00,0x00,0x00,0x0e,0x02,0x02,0x04,0x04,0x09,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0x42,0x02,0xc4,0xa4,0x28,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 7058 0x1b92 "ᮒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x04,0x09,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x70,0x90,0x90,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 7059 0x1b93 "ᮓ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x40,0xa0,0x90,0x88,0x00,0x00,0x00,0x00,0x00,
+/* 7060 0x1b94 "ᮔ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7061 0x1b95 "ᮕ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x20,0x20,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7062 0x1b96 "ᮖ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x20,0x20,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7063 0x1b97 "ᮗ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x10,0x10,0x20,0x20,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7064 0x1b98 "ᮘ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x9f,0x21,0x01,0x62,0x52,0x94,0x8c,0x00,0x00,0x00,0x00,0x00,
+/* 7065 0x1b99 "ᮙ" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x0e,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7066 0x1b9a "ᮚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x04,0x09,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x44,0xa4,0xa8,0x28,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 7067 0x1b9b "ᮛ" */
+0x00,0x00,0x00,0x00,0x03,0x00,0x07,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0xc0,0x40,0xe0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7068 0x1b9c "ᮜ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x09,0x09,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc2,0x44,0x44,0x88,0x88,0x10,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 7069 0x1b9d "ᮝ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x70,0x10,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7070 0x1b9e "ᮞ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x07,0x02,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x08,0x08,0xbc,0x10,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 7071 0x1b9f "ᮟ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x07,0x02,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0xe0,0x20,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 7072 0x1ba0 "ᮠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x48,0x48,0x90,0x90,0x00,0x00,0x00,0x00,0x00,
+/* 7073 0x1ba1 "ᮡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x05,0x08,0x08,0x10,0x10,0x10,0xe0,
+/* 7074 0x1ba2 "ᮢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0xf0,
+/* 7075 0x1ba3 "ᮣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x16,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7076 0x1ba4 "ᮤ" */
+0x07,0x01,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7077 0x1ba5 "ᮥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x40,0x80,0x00,
+/* 7078 0x1ba6 "ᮦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x70,0x80,0xe0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7079 0x1ba7 "ᮧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x01,0x02,0x1c,0x07,0x00,0x00,0x00,0x00,
+/* 7080 0x1ba8 "ᮨ" */
+0x11,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7081 0x1ba9 "ᮩ" */
+0x29,0x1a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7082 0x1baa "᮪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1f,0x01,0x02,0x04,0x07,0x01,0x02,0x04,0x04,0x04,0x03,
+/* 7083 0x1bab "᮫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 7084 0x1bac "ᮬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7085 0x1bad "ᮭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0x09,0x0d,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,
+/* 7086 0x1bae "ᮮ" */
+0x00,0x00,0x00,0x00,0x0f,0x02,0x02,0x04,0x04,0x09,0x09,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xdf,0x51,0x51,0x92,0x92,0x14,0xf4,0x00,0x00,0x00,0x00,0x00,
+/* 7087 0x1baf "ᮯ" */
+0x00,0x00,0x00,0x00,0x0f,0x02,0x02,0x0f,0x04,0x09,0x09,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc8,0x48,0x49,0xc9,0xd5,0x55,0x72,0x00,0x00,0x00,0x00,0x00,
+/* 7088 0x1bb0 "᮰" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7089 0x1bb1 "᮱" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x00,0x70,0x10,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7090 0x1bb2 "᮲" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x01,0x02,0x03,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7091 0x1bb3 "᮳" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7092 0x1bb4 "᮴" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x03,0x04,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x40,0x50,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7093 0x1bb5 "᮵" */
+0x00,0x00,0x00,0x00,0x06,0x0a,0x02,0x04,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x80,0x40,0x40,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7094 0x1bb6 "᮶" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x30,0x40,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7095 0x1bb7 "᮷" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x09,0x09,0x12,0x33,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x8c,0x90,0x90,0x20,0x20,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7096 0x1bb8 "᮸" */
+0x00,0x00,0x00,0x00,0x1c,0x24,0x04,0x08,0x18,0x2c,0x13,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7097 0x1bb9 "᮹" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x01,0x02,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x30,0x40,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7098 0x1bba "ᮺ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x07,0x00,0x00,0x00,0x01,0x01,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0xc0,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 7099 0x1bbb "ᮻ" */
+0x00,0x00,0x00,0x00,0x07,0x01,0x01,0x02,0x02,0x04,0x07,0x00,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x20,0x20,0x40,0xc0,0x00,0xc0,0x00,0x00,0x00,
+/* 7100 0x1bbc "ᮼ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x10,0x23,0x22,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0e,0x02,0x02,0x04,0x84,0x88,0x49,0x11,0x72,0x92,0x6c,0x00,
+/* 7101 0x1bbd "ᮽ" */
+0x00,0x00,0x00,0x00,0x0f,0x11,0x19,0x02,0x02,0x02,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0x22,0x26,0x40,0x40,0x40,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 7102 0x1bbe "ᮾ" */
+0x00,0x00,0x00,0x00,0x1f,0x01,0x19,0x0a,0x12,0x04,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x04,0x64,0x28,0x48,0x10,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 7103 0x1bbf "ᮿ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x0f,0x00,0x0e,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7104 0x1bc0 "ᯀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x42,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7105 0x1bc1 "ᯁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x42,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7106 0x1bc2 "ᯂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0x44,0x08,0x10,0x21,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7107 0x1bc3 "ᯃ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x00,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7108 0x1bc4 "ᯄ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x08,0x11,0x22,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7109 0x1bc5 "ᯅ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x44,0x4a,0x31,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7110 0x1bc6 "ᯆ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7111 0x1bc7 "ᯇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7112 0x1bc8 "ᯈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7113 0x1bc9 "ᯉ" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x07,0x08,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7114 0x1bca "ᯊ" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x1c,0x03,0x04,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7115 0x1bcb "ᯋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x40,0x71,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7116 0x1bcc "ᯌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x00,0x71,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7117 0x1bcd "ᯍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 7118 0x1bce "ᯎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7119 0x1bcf "ᯏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7120 0x1bd0 "ᯐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x60,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7121 0x1bd1 "ᯑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x60,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7122 0x1bd2 "ᯒ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x1f,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7123 0x1bd3 "ᯓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7124 0x1bd4 "ᯔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x11,0x12,0x13,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7125 0x1bd5 "ᯕ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x03,0x0c,0x30,0x06,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 7126 0x1bd6 "ᯖ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x10,0x09,0x06,0x09,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7127 0x1bd7 "ᯗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0x22,0x24,0x19,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7128 0x1bd8 "ᯘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0x44,0x08,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7129 0x1bd9 "ᯙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x00,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7130 0x1bda "ᯚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x48,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7131 0x1bdb "ᯛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0x22,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7132 0x1bdc "ᯜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x11,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7133 0x1bdd "ᯝ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x60,0x18,0x06,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 7134 0x1bde "ᯞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7135 0x1bdf "ᯟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x00,0x70,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7136 0x1be0 "ᯠ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x4c,0x63,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7137 0x1be1 "ᯡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x4a,0x4d,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7138 0x1be2 "ᯢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x0c,0x03,0x00,0x06,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7139 0x1be3 "ᯣ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x46,0x46,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7140 0x1be4 "ᯤ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x31,0x40,0x0e,0x11,0x00,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7141 0x1be5 "ᯥ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x00,0x11,0x0e,0x40,0x31,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7142 0x1be6 "᯦" */
+0x07,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7143 0x1be7 "ᯧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 7144 0x1be8 "ᯨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x20,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7145 0x1be9 "ᯩ" */
+0x00,0x00,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7146 0x1bea "ᯪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 7147 0x1beb "ᯫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 7148 0x1bec "ᯬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x0a,0x04,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,
+/* 7149 0x1bed "ᯭ" */
+0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x20,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7150 0x1bee "ᯮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x10,0x20,0x00,
+/* 7151 0x1bef "ᯯ" */
+0x00,0x00,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7152 0x1bf0 "ᯰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7153 0x1bf1 "ᯱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x07,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7154 0x1bf2 "᯲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+/* 7155 0x1bf3 "᯳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7156 0x1bf4 "᯴" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 7157 0x1bf5 "᯵" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 7158 0x1bf6 "᯶" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 7159 0x1bf7 "᯷" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 7160 0x1bf8 "᯸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 7161 0x1bf9 "᯹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 7162 0x1bfa "᯺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 7163 0x1bfb "᯻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 7164 0x1bfc "᯼" */
+0x00,0x10,0x20,0x23,0x14,0x08,0x14,0x22,0x21,0x22,0x14,0x08,0x14,0x23,0x20,0x10,
+0x00,0x10,0x08,0x88,0x50,0x20,0x50,0x88,0x08,0x88,0x50,0x20,0x50,0x88,0x08,0x10,
+/* 7165 0x1bfd "᯽" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x1a,0x21,0x1a,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0xb0,0x08,0xb0,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 7166 0x1bfe "᯾" */
+0x00,0x00,0x00,0x00,0x11,0x22,0x22,0x22,0x11,0x08,0x08,0x08,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x20,0x20,0x10,0x88,0x88,0x88,0x10,0x00,0x00,0x00,
+/* 7167 0x1bff "᯿" */
+0x00,0x00,0x00,0x00,0x0e,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7168 0x1c00 "ᰀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x0f,0x04,0x04,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 7169 0x1c01 "ᰁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x04,0x05,0x06,0x08,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7170 0x1c02 "ᰂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 7171 0x1c03 "ᰃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x12,0x12,0x11,0x0b,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 7172 0x1c04 "ᰄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x12,0x3f,0x11,0x0b,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 7173 0x1c05 "ᰅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7174 0x1c06 "ᰆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x1c,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 7175 0x1c07 "ᰇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x02,0x04,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0x40,0x20,0xe0,0x00,0x00,0x00,
+/* 7176 0x1c08 "ᰈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x09,0x08,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7177 0x1c09 "ᰉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x02,0x05,0x08,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7178 0x1c0a "ᰊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x04,0x0a,0x09,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7179 0x1c0b "ᰋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x05,0x02,0x05,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7180 0x1c0c "ᰌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x12,0x0f,0x02,0x0f,0x12,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 7181 0x1c0d "ᰍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x09,0x09,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 7182 0x1c0e "ᰎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x0c,0x13,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 7183 0x1c0f "ᰏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x04,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 7184 0x1c10 "ᰐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x10,0x10,0x08,0x0e,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x40,0x40,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 7185 0x1c11 "ᰑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x1f,0x10,0x0c,0x13,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0xc0,0x80,0x40,0x80,0x00,0x00,0x00,
+/* 7186 0x1c12 "ᰒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x12,0x11,0x11,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x30,0x10,0xa0,0xc0,0x00,0x00,0x00,
+/* 7187 0x1c13 "ᰓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 7188 0x1c14 "ᰔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x08,0x08,0x08,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x10,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 7189 0x1c15 "ᰕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x01,0x02,0x0f,0x12,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 7190 0x1c16 "ᰖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x01,0x00,0x07,0x08,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7191 0x1c17 "ᰗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x20,0x40,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 7192 0x1c18 "ᰘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x11,0x15,0x14,0x13,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x60,0x00,0x00,0x00,0x00,
+/* 7193 0x1c19 "ᰙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x07,0x1c,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0xe0,0x80,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 7194 0x1c1a "ᰚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x07,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7195 0x1c1b "ᰛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x0f,0x08,0x04,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7196 0x1c1c "ᰜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x12,0x11,0x11,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0x10,0xa0,0xc0,0x00,0x00,0x00,
+/* 7197 0x1c1d "ᰝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x0f,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x40,0xe0,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 7198 0x1c1e "ᰞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x05,0x02,0x05,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 7199 0x1c1f "ᰟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0f,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xe0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 7200 0x1c20 "ᰠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x11,0x15,0x14,0x13,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7201 0x1c21 "ᰡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x09,0x09,0x0a,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x20,0xc0,0x00,0x00,0x00,
+/* 7202 0x1c22 "ᰢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x12,0x15,0x15,0x12,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xd0,0x20,0x50,0x50,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 7203 0x1c23 "ᰣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x01,0x03,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x40,0x80,0xa0,0x40,0xa0,0x00,0x00,0x00,
+/* 7204 0x1c24 "ᰤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x0a,0x0a,0x04,0x00,0x00,0x00,
+/* 7205 0x1c25 "ᰥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x00,0x00,0x00,
+/* 7206 0x1c26 "ᰦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+/* 7207 0x1c27 "ᰧ" */
+0x00,0x00,0x40,0xa0,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7208 0x1c28 "ᰨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x40,0x40,0x40,0x40,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7209 0x1c29 "ᰩ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7210 0x1c2a "ᰪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x12,0x0c,
+/* 7211 0x1c2b "ᰫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x12,0x0c,
+/* 7212 0x1c2c "ᰬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7213 0x1c2d "ᰭ" */
+0x00,0x01,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7214 0x1c2e "ᰮ" */
+0x00,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7215 0x1c2f "ᰯ" */
+0x00,0x01,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7216 0x1c30 "ᰰ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7217 0x1c31 "ᰱ" */
+0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7218 0x1c32 "ᰲ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7219 0x1c33 "ᰳ" */
+0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7220 0x1c34 "ᰴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xa0,0xa0,0xa0,0x40,0x80,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7221 0x1c35 "ᰵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7222 0x1c36 "ᰶ" */
+0x0f,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7223 0x1c37 "᰷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,
+/* 7224 0x1c38 "᰸" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 7225 0x1c39 "᰹" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 7226 0x1c3a "᰺" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 7227 0x1c3b "᰻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 7228 0x1c3c "᰼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 7229 0x1c3d "᰽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 7230 0x1c3e "᰾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x04,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x90,0x40,0x20,0x00,0x00,0x00,
+/* 7231 0x1c3f "᰿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x09,0x04,0x04,0x04,0x09,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x10,0xa0,0x20,0xa0,0x10,0x88,0x00,0x00,0x00,
+/* 7232 0x1c40 "᱀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7233 0x1c41 "᱁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7234 0x1c42 "᱂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 7235 0x1c43 "᱃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x07,0x08,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xe0,0x10,0x20,0xc0,0x20,0x00,0x00,0x00,
+/* 7236 0x1c44 "᱄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,0x30,0xc0,0x00,0x00,0x00,0x00,
+/* 7237 0x1c45 "᱅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x04,0x05,0x06,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x60,0xa0,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 7238 0x1c46 "᱆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x80,0x40,0x20,0x10,0xe0,0x00,0x00,0x00,
+/* 7239 0x1c47 "᱇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x01,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7240 0x1c48 "᱈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,
+/* 7241 0x1c49 "᱉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7242 0x1c4a "᱊" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 7243 0x1c4b "᱋" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 7244 0x1c4c "᱌" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 7245 0x1c4d "ᱍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x03,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 7246 0x1c4e "ᱎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x03,0x00,0x03,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xe0,0x80,0xe0,0x80,0x00,0x00,0x00,0x00,
+/* 7247 0x1c4f "ᱏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x13,0x01,0x01,0x01,0x0f,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xe0,0x20,0x20,0x20,0x20,0x40,0x00,0x00,0x00,
+/* 7248 0x1c50 "᱐" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7249 0x1c51 "᱑" */
+0x00,0x00,0x00,0x62,0x52,0x4a,0x46,0x40,0x40,0x40,0x40,0x20,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7250 0x1c52 "᱒" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x14,0x08,0x10,0x20,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7251 0x1c53 "᱓" */
+0x00,0x00,0x00,0x32,0x4a,0x4a,0x3e,0x10,0x20,0x20,0x40,0x40,0x30,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7252 0x1c54 "᱔" */
+0x00,0x00,0x00,0x1e,0x20,0x40,0x40,0x40,0x60,0x52,0x4e,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7253 0x1c55 "᱕" */
+0x00,0x00,0x00,0x10,0x20,0x46,0x48,0x50,0x50,0x48,0x46,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7254 0x1c56 "᱖" */
+0x00,0x00,0x00,0x5c,0x22,0x52,0x4c,0x40,0x40,0x40,0x40,0x20,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7255 0x1c57 "᱗" */
+0x00,0x00,0x00,0x0c,0x52,0x32,0x04,0x08,0x10,0x20,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7256 0x1c58 "᱘" */
+0x00,0x00,0x00,0x34,0x4a,0x5a,0x64,0x40,0x40,0x40,0x40,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7257 0x1c59 "᱙" */
+0x00,0x00,0x00,0x1c,0x20,0x40,0x40,0x40,0x4c,0x52,0x52,0x4a,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7258 0x1c5a "ᱚ" */
+0x00,0x00,0x00,0x1c,0x22,0x66,0x0a,0x12,0x22,0x42,0x42,0x42,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7259 0x1c5b "ᱛ" */
+0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7260 0x1c5c "ᱜ" */
+0x00,0x00,0x00,0x1c,0x22,0x40,0x40,0x4e,0x50,0x50,0x4e,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7261 0x1c5d "ᱝ" */
+0x00,0x00,0x00,0x1c,0x22,0x44,0x48,0x10,0x26,0x10,0x48,0x44,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7262 0x1c5e "ᱞ" */
+0x00,0x00,0x00,0x48,0x54,0x62,0x42,0x42,0x42,0x42,0x62,0x54,0x48,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7263 0x1c5f "ᱟ" */
+0x00,0x00,0x00,0x24,0x5a,0xda,0x12,0x32,0x52,0x52,0x92,0xa2,0xa4,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7264 0x1c60 "ᱠ" */
+0x00,0x00,0x00,0x40,0x48,0x54,0x62,0x42,0x42,0x42,0x42,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7265 0x1c61 "ᱡ" */
+0x00,0x00,0x00,0x48,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x62,0x54,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7266 0x1c62 "ᱢ" */
+0x00,0x00,0x00,0x12,0x22,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x2a,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7267 0x1c63 "ᱣ" */
+0x00,0x00,0x00,0x64,0x92,0x8a,0x0a,0x0a,0x12,0xe2,0x82,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7268 0x1c64 "ᱤ" */
+0x00,0x00,0x00,0x38,0x44,0x06,0x0a,0x0a,0x12,0x12,0x22,0x22,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7269 0x1c65 "ᱥ" */
+0x00,0x00,0x00,0x42,0x42,0x44,0x44,0x48,0x48,0x50,0x50,0x60,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7270 0x1c66 "ᱦ" */
+0x00,0x00,0x00,0x44,0x44,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7271 0x1c67 "ᱧ" */
+0x00,0x00,0x00,0x10,0x28,0x44,0x42,0x42,0x42,0x42,0x46,0x2a,0x12,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7272 0x1c68 "ᱨ" */
+0x00,0x00,0x00,0x78,0x04,0x02,0x42,0x22,0x12,0x0a,0x06,0x22,0x52,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7273 0x1c69 "ᱩ" */
+0x00,0x00,0x00,0x40,0x48,0x54,0x62,0x42,0x02,0x02,0x42,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7274 0x1c6a "ᱪ" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0xba,0x82,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7275 0x1c6b "ᱫ" */
+0x00,0x00,0x00,0x10,0x28,0x44,0x82,0x92,0x54,0x10,0x70,0x40,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7276 0x1c6c "ᱬ" */
+0x00,0x00,0x00,0x44,0xaa,0x92,0x82,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7277 0x1c6d "ᱭ" */
+0x00,0x00,0x00,0x30,0x48,0x84,0x84,0x8c,0x90,0xa0,0xa0,0xa2,0x92,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7278 0x1c6e "ᱮ" */
+0x00,0x00,0x00,0x38,0x44,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7279 0x1c6f "ᱯ" */
+0x00,0x00,0x00,0x3c,0x62,0xa4,0xa4,0x24,0x24,0x24,0x25,0x25,0x46,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7280 0x1c70 "ᱰ" */
+0x00,0x00,0x00,0x58,0x94,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x52,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7281 0x1c71 "ᱱ" */
+0x00,0x00,0x00,0x3c,0xc6,0x44,0x44,0x48,0x48,0x50,0x50,0x60,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7282 0x1c72 "ᱲ" */
+0x00,0x00,0x00,0x38,0x44,0x06,0x0a,0x0a,0x12,0x12,0x22,0x22,0xc3,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7283 0x1c73 "ᱳ" */
+0x00,0x00,0x00,0x18,0x24,0x42,0x0e,0x12,0x12,0x12,0x0e,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7284 0x1c74 "ᱴ" */
+0x00,0x00,0x00,0x48,0x54,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7285 0x1c75 "ᱵ" */
+0x00,0x00,0x00,0x34,0x52,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x94,0x58,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7286 0x1c76 "ᱶ" */
+0x00,0x00,0x00,0x62,0x92,0x88,0x08,0x0a,0x12,0xe2,0x82,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7287 0x1c77 "ᱷ" */
+0x00,0x00,0x00,0x18,0x24,0x22,0x12,0x4e,0x82,0x82,0x82,0x92,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7288 0x1c78 "ᱸ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7289 0x1c79 "ᱹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7290 0x1c7a "ᱺ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7291 0x1c7b "ᱻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x92,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7292 0x1c7c "ᱼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7293 0x1c7d "ᱽ" */
+0x00,0x00,0x00,0x30,0x48,0x44,0x24,0x1c,0x04,0x04,0x04,0x44,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7294 0x1c7e "᱾" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7295 0x1c7f "᱿" */
+0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7296 0x1c80 "ᲀ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x2a,0x4a,0x44,0x40,0x44,0x4a,0x2a,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7297 0x1c81 "ᲁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x22,0x22,0x22,0x22,0x22,0x7f,0x41,0x41,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7298 0x1c82 "ᲂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7299 0x1c83 "ᲃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x40,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7300 0x1c84 "ᲄ" */
+0x00,0x00,0x00,0x00,0x32,0x4e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7301 0x1c85 "ᲅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7302 0x1c86 "ᲆ" */
+0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x1c,0x12,0x12,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7303 0x1c87 "ᲇ" */
+0x00,0x00,0x20,0x20,0x78,0x20,0x20,0x20,0x20,0x3c,0x22,0x22,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7304 0x1c88 "ᲈ" */
+0x00,0x00,0x00,0x44,0x4a,0x2a,0x28,0x10,0x38,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7305 0x1c89 "Ᲊ" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 7306 0x1c8a "ᲊ" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 7307 0x1c8b "᲋" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 7308 0x1c8c "᲌" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 7309 0x1c8d "᲍" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 7310 0x1c8e "᲎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 7311 0x1c8f "᲏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 7312 0x1c90 "Ა" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x04,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7313 0x1c91 "Ბ" */
+0x00,0x00,0x00,0x00,0x20,0x38,0x08,0x08,0x34,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7314 0x1c92 "Გ" */
+0x00,0x00,0x00,0x30,0x48,0x48,0x08,0x08,0x34,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7315 0x1c93 "Დ" */
+0x00,0x00,0x00,0x00,0x2c,0x52,0x52,0x52,0x52,0x4c,0x40,0x20,0x1c,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7316 0x1c94 "Ე" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x22,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7317 0x1c95 "Ვ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x1c,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7318 0x1c96 "Ზ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x54,0x38,0x1c,0x12,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7319 0x1c97 "Თ" */
+0x00,0x00,0x00,0x00,0x34,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7320 0x1c98 "Ი" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7321 0x1c99 "Კ" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x02,0x02,0x1c,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7322 0x1c9a "Ლ" */
+0x00,0x00,0x00,0x00,0x2a,0x55,0x55,0x55,0x41,0x41,0x42,0x20,0x1e,0x61,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7323 0x1c9b "Მ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x3e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7324 0x1c9c "Ნ" */
+0x00,0x00,0x00,0x00,0x02,0x3c,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7325 0x1c9d "Ო" */
+0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x54,0x54,0x44,0x44,0x44,0x44,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7326 0x1c9e "Პ" */
+0x00,0x00,0x00,0x00,0x20,0x18,0x04,0x02,0x02,0x1c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7327 0x1c9f "Ჟ" */
+0x00,0x00,0x00,0x00,0x06,0x0a,0x52,0x52,0x22,0x02,0x12,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7328 0x1ca0 "Რ" */
+0x00,0x00,0x00,0x00,0x04,0x38,0x40,0x68,0x54,0x54,0x54,0x54,0x44,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7329 0x1ca1 "Ს" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x48,0x50,0x48,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7330 0x1ca2 "Ტ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x3c,0x66,0x66,0x5a,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7331 0x1ca3 "Უ" */
+0x00,0x00,0x00,0x00,0x6c,0x12,0x12,0x02,0x02,0x02,0x02,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7332 0x1ca4 "Ფ" */
+0x00,0x00,0x00,0x00,0x34,0x4a,0x4a,0x4a,0x4a,0x34,0x02,0x12,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7333 0x1ca5 "Ქ" */
+0x00,0x00,0x00,0x00,0x04,0x0c,0x04,0x04,0x1c,0x24,0x04,0x04,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7334 0x1ca6 "Ღ" */
+0x00,0x00,0x00,0x00,0x2c,0x52,0x52,0x52,0x42,0x44,0x40,0x20,0x1c,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7335 0x1ca7 "Ყ" */
+0x00,0x00,0x00,0x00,0x22,0x42,0x42,0x26,0x1a,0x02,0x22,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7336 0x1ca8 "Შ" */
+0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x04,0x04,0x1c,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7337 0x1ca9 "Ჩ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x78,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7338 0x1caa "Ც" */
+0x00,0x00,0x00,0x00,0x4c,0x42,0x42,0x42,0x5c,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7339 0x1cab "Ძ" */
+0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x02,0x3e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7340 0x1cac "Წ" */
+0x00,0x00,0x00,0x00,0x28,0x54,0x54,0x54,0x40,0x7c,0x44,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7341 0x1cad "Ჭ" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x08,0x19,0x26,0x1d,0x04,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7342 0x1cae "Ხ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x48,0x50,0x78,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7343 0x1caf "Ჯ" */
+0x00,0x00,0x00,0x00,0xcc,0xa2,0xa2,0x24,0x14,0x18,0x30,0x4a,0x2a,0xc4,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7344 0x1cb0 "Ჰ" */
+0x00,0x00,0x10,0x0c,0x02,0x12,0x0c,0x02,0x12,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7345 0x1cb1 "Ჱ" */
+0x00,0x00,0x00,0x00,0xc8,0xa6,0xa1,0xa9,0xa6,0xc1,0x92,0x8c,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7346 0x1cb2 "Ჲ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x24,0x24,0x18,0x24,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7347 0x1cb3 "Ჳ" */
+0x00,0x00,0x00,0x00,0x3e,0x02,0x04,0x08,0x1c,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7348 0x1cb4 "Ჴ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x0c,0x02,0x02,0x1c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7349 0x1cb5 "Ჵ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x3e,0x04,0x3e,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7350 0x1cb6 "Ჶ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x38,0x54,0x54,0x38,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7351 0x1cb7 "Ჷ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x04,0x08,0x10,0x20,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7352 0x1cb8 "Ჸ" */
+0x00,0x00,0x00,0x00,0x44,0x42,0x42,0x42,0x64,0x58,0x40,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7353 0x1cb9 "Ჹ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x3c,0x10,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7354 0x1cba "Ჺ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x30,0x0c,0x1c,0x22,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7355 0x1cbb "᲻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 7356 0x1cbc "᲼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 7357 0x1cbd "Ჽ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x20,0x10,0x08,0x04,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7358 0x1cbe "Ჾ" */
+0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x24,0x24,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7359 0x1cbf "Ჿ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7360 0x1cc0 "᳀" */
+0x00,0x00,0x02,0x01,0x03,0x04,0x29,0x1a,0x29,0x04,0x03,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x80,0x40,0x28,0xb0,0x28,0x40,0x80,0x00,0x80,0x00,0x00,0x00,
+/* 7361 0x1cc1 "᳁" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x05,0x04,0x05,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x50,0x90,0x50,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7362 0x1cc2 "᳂" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x05,0x04,0x05,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xd0,0x10,0xd0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7363 0x1cc3 "᳃" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7364 0x1cc4 "᳄" */
+0x00,0x00,0x00,0x00,0x1b,0x20,0x23,0x48,0x55,0x94,0xf2,0x00,0x01,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0xbb,0x08,0xcb,0x10,0x96,0x20,0xac,0x20,0xc8,0x48,0xb0,0x00,
+/* 7365 0x1cc5 "᳅" */
+0x00,0x00,0x00,0x00,0x1c,0x04,0x04,0x08,0x09,0x10,0x13,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0xf0,0x00,0xe0,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 7366 0x1cc6 "᳆" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x22,0x25,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x00,0xfe,0x00,0x3c,0x80,0x58,0x00,0x00,0x00,0x00,0x00,
+/* 7367 0x1cc7 "᳇" */
+0x00,0x00,0x00,0x00,0x66,0x08,0xc8,0x11,0x91,0x22,0xbe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7d,0x84,0x05,0x88,0x4b,0x50,0x36,0x00,0x00,0x00,0x00,0x00,
+/* 7368 0x1cc8 "᳈" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 7369 0x1cc9 "᳉" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 7370 0x1cca "᳊" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 7371 0x1ccb "᳋" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 7372 0x1ccc "᳌" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 7373 0x1ccd "᳍" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 7374 0x1cce "᳎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 7375 0x1ccf "᳏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 7376 0x1cd0 "᳐" */
+0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7377 0x1cd1 "᳑" */
+0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0xc0,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7378 0x1cd2 "᳒" */
+0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7379 0x1cd3 "᳓" */
+0x00,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7380 0x1cd4 "᳔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7381 0x1cd5 "᳕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x90,0x60,
+/* 7382 0x1cd6 "᳖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,
+/* 7383 0x1cd7 "᳗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,
+/* 7384 0x1cd8 "᳘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xc0,
+/* 7385 0x1cd9 "᳙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,
+/* 7386 0x1cda "᳚" */
+0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7387 0x1cdb "᳛" */
+0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xa0,0xa0,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7388 0x1cdc "᳜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,
+/* 7389 0x1cdd "᳝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,
+/* 7390 0x1cde "᳞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,
+/* 7391 0x1cdf "᳟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x00,
+/* 7392 0x1ce0 "᳠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x7c,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7393 0x1ce1 "᳡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x12,0x11,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,
+/* 7394 0x1ce2 "᳢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x07,0x00,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xe0,0x00,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 7395 0x1ce3 "᳣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7396 0x1ce4 "᳤" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7397 0x1ce5 "᳥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7398 0x1ce6 "᳦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x08,0x08,0x10,0x20,0x00,0x00,0x00,
+/* 7399 0x1ce7 "᳧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x18,0x24,0x20,0x10,0x08,0x08,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7400 0x1ce8 "᳨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x08,0x04,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7401 0x1ce9 "ᳩ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x2c,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x68,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 7402 0x1cea "ᳪ" */
+0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0xa0,0x40,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 7403 0x1ceb "ᳫ" */
+0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x70,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 7404 0x1cec "ᳬ" */
+0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x30,0x18,0x14,0x24,0x48,0x80,0x00,0x00,0x00,
+/* 7405 0x1ced "᳭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,
+/* 7406 0x1cee "ᳮ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x20,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7407 0x1cef "ᳯ" */
+0x00,0x00,0x00,0x07,0x08,0x09,0x04,0x03,0x04,0x05,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x00,0x00,0xc0,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 7408 0x1cf0 "ᳰ" */
+0x00,0x01,0x02,0x02,0x01,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 7409 0x1cf1 "ᳱ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x07,0x00,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xe0,0x10,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 7410 0x1cf2 "ᳲ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x03,0x04,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 7411 0x1cf3 "ᳳ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x02,0x02,0x02,0x04,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x40,0x40,0x40,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 7412 0x1cf4 "᳴" */
+0x00,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7413 0x1cf5 "ᳵ" */
+0xaa,0x00,0x80,0x00,0x90,0x08,0x84,0x02,0x81,0x02,0x84,0x08,0x90,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x10,0x21,0x40,0x81,0x00,0x81,0x40,0x21,0x10,0x01,0x00,0x55,
+/* 7414 0x1cf6 "ᳶ" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0x80,0x11,0x91,0x0e,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x00,0x11,0x10,0xe1,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 7415 0x1cf7 "᳷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x00,
+/* 7416 0x1cf8 "᳸" */
+0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7417 0x1cf9 "᳹" */
+0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7418 0x1cfa "ᳺ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x1c,0x0f,0x00,0x0c,0x12,0x1c,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x70,0xe0,0x00,0x60,0x90,0x70,0xe0,0x00,0x00,0x00,
+/* 7419 0x1cfb "᳻" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 7420 0x1cfc "᳼" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 7421 0x1cfd "᳽" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 7422 0x1cfe "᳾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 7423 0x1cff "᳿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 7424 0x1d00 "ᴀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7425 0x1d01 "ᴁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x28,0x48,0x7e,0x48,0x48,0x48,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7426 0x1d02 "ᴂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x49,0x09,0x09,0x7e,0x48,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7427 0x1d03 "ᴃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x48,0xfe,0x48,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7428 0x1d04 "ᴄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7429 0x1d05 "ᴅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x44,0x44,0x44,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7430 0x1d06 "ᴆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x44,0xe4,0x44,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7431 0x1d07 "ᴇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x78,0x40,0x40,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7432 0x1d08 "ᴈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x1c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7433 0x1d09 "ᴉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x18,0x00,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7434 0x1d0a "ᴊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7435 0x1d0b "ᴋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x24,0x28,0x30,0x30,0x28,0x24,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7436 0x1d0c "ᴌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x28,0x30,0x20,0x60,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7437 0x1d0d "ᴍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x36,0x36,0x2a,0x2a,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7438 0x1d0e "ᴎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x4c,0x4c,0x54,0x54,0x64,0x64,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7439 0x1d0f "ᴏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7440 0x1d10 "ᴐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7441 0x1d11 "ᴑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7442 0x1d12 "ᴒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7443 0x1d13 "ᴓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x3e,0x51,0x49,0x49,0x45,0x3e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7444 0x1d14 "ᴔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x09,0x09,0x79,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7445 0x1d15 "ᴕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7446 0x1d16 "ᴖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7447 0x1d17 "ᴗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7448 0x1d18 "ᴘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7449 0x1d19 "ᴙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x42,0x42,0x3e,0x12,0x22,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7450 0x1d1a "ᴚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x12,0x3e,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7451 0x1d1b "ᴛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7452 0x1d1c "ᴜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7453 0x1d1d "ᴝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x01,0x01,0x01,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7454 0x1d1e "ᴞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x42,0x01,0x01,0x41,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7455 0x1d1f "ᴟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x01,0x01,0x7e,0x01,0x01,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7456 0x1d20 "ᴠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7457 0x1d21 "ᴡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7458 0x1d22 "ᴢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7459 0x1d23 "ᴣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x1c,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7460 0x1d24 "ᴤ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x1c,0x38,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7461 0x1d25 "ᴥ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x7c,0xfe,0xfe,0x7c,0x38,0x10,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7462 0x1d26 "ᴦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7463 0x1d27 "ᴧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7464 0x1d28 "ᴨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7465 0x1d29 "ᴩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7466 0x1d2a "ᴪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7467 0x1d2b "ᴫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x22,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7468 0x1d2c "ᴬ" */
+0x00,0x00,0x00,0x10,0x28,0x44,0x44,0x7c,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7469 0x1d2d "ᴭ" */
+0x00,0x00,0x00,0x1e,0x28,0x48,0x7e,0x48,0x48,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7470 0x1d2e "ᴮ" */
+0x00,0x00,0x00,0x78,0x44,0x44,0x78,0x44,0x44,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7471 0x1d2f "ᴯ" */
+0x00,0x00,0x00,0x78,0x44,0x48,0xfe,0x48,0x44,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7472 0x1d30 "ᴰ" */
+0x00,0x00,0x00,0x78,0x44,0x44,0x44,0x44,0x44,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7473 0x1d31 "ᴱ" */
+0x00,0x00,0x00,0x7c,0x40,0x40,0x78,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7474 0x1d32 "ᴲ" */
+0x00,0x00,0x00,0x7c,0x04,0x04,0x3c,0x04,0x04,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7475 0x1d33 "ᴳ" */
+0x00,0x00,0x00,0x3c,0x40,0x40,0x4e,0x42,0x46,0x3a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7476 0x1d34 "ᴴ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7477 0x1d35 "ᴵ" */
+0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7478 0x1d36 "ᴶ" */
+0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7479 0x1d37 "ᴷ" */
+0x00,0x00,0x00,0x22,0x24,0x28,0x30,0x28,0x24,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7480 0x1d38 "ᴸ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7481 0x1d39 "ᴹ" */
+0x00,0x00,0x00,0x22,0x36,0x36,0x2a,0x22,0x22,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7482 0x1d3a "ᴺ" */
+0x00,0x00,0x00,0x44,0x64,0x64,0x54,0x4c,0x4c,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7483 0x1d3b "ᴻ" */
+0x00,0x00,0x00,0x44,0x4c,0x4c,0x54,0x64,0x64,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7484 0x1d3c "ᴼ" */
+0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7485 0x1d3d "ᴽ" */
+0x00,0x00,0x00,0x44,0x44,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7486 0x1d3e "ᴾ" */
+0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7487 0x1d3f "ᴿ" */
+0x00,0x00,0x00,0x78,0x44,0x44,0x78,0x48,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7488 0x1d40 "ᵀ" */
+0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7489 0x1d41 "ᵁ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7490 0x1d42 "ᵂ" */
+0x00,0x00,0x00,0x44,0x44,0x44,0x54,0x6c,0x6c,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7491 0x1d43 "ᵃ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x3c,0x44,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7492 0x1d44 "ᵄ" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x78,0x40,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7493 0x1d45 "ᵅ" */
+0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x46,0x3a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7494 0x1d46 "ᵆ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x12,0xfc,0x90,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7495 0x1d47 "ᵇ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x78,0x44,0x44,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7496 0x1d48 "ᵈ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x3c,0x44,0x44,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7497 0x1d49 "ᵉ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x7c,0x40,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7498 0x1d4a "ᵊ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x7c,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7499 0x1d4b "ᵋ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x38,0x40,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7500 0x1d4c "ᵌ" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x04,0x38,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7501 0x1d4d "ᵍ" */
+0x00,0x00,0x00,0x00,0x00,0x3a,0x44,0x44,0x3c,0x04,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7502 0x1d4e "ᵎ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x18,0x00,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7503 0x1d4f "ᵏ" */
+0x00,0x00,0x00,0x40,0x40,0x48,0x50,0x60,0x50,0x48,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7504 0x1d50 "ᵐ" */
+0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7505 0x1d51 "ᵑ" */
+0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x04,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7506 0x1d52 "ᵒ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7507 0x1d53 "ᵓ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7508 0x1d54 "ᵔ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7509 0x1d55 "ᵕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7510 0x1d56 "ᵖ" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x44,0x44,0x78,0x40,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7511 0x1d57 "ᵗ" */
+0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7512 0x1d58 "ᵘ" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7513 0x1d59 "ᵙ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x08,0x04,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7514 0x1d5a "ᵚ" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x37,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7515 0x1d5b "ᵛ" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x28,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7516 0x1d5c "ᵜ" */
+0x00,0x00,0x00,0x00,0x38,0x7c,0x7c,0x38,0x92,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7517 0x1d5d "ᵝ" */
+0x00,0x00,0x00,0x30,0x48,0x48,0x78,0x44,0x64,0x58,0x40,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7518 0x1d5e "ᵞ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x52,0x14,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7519 0x1d5f "ᵟ" */
+0x00,0x00,0x00,0x38,0x40,0x40,0x38,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7520 0x1d60 "ᵠ" */
+0x00,0x00,0x00,0x00,0x00,0x26,0x49,0x49,0x49,0x3e,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7521 0x1d61 "ᵡ" */
+0x00,0x00,0x00,0x00,0x00,0x62,0x12,0x14,0x18,0x30,0x48,0x46,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7522 0x1d62 "ᵢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x30,0x10,0x10,0x10,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7523 0x1d63 "ᵣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7524 0x1d64 "ᵤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x4c,0x34,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7525 0x1d65 "ᵥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x28,0x28,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7526 0x1d66 "ᵦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x7c,0x42,0x62,0x5c,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7527 0x1d67 "ᵧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x52,0x0c,0x10,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7528 0x1d68 "ᵨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x78,0x40,0x30,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7529 0x1d69 "ᵩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x26,0x49,0x49,0x49,0x3e,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7530 0x1d6a "ᵪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x61,0x12,0x14,0x18,0x30,0x48,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7531 0x1d6b "ᵫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0x89,0x89,0x8f,0x88,0x88,0x99,0x6e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7532 0x1d6c "ᵬ" */
+0x00,0x00,0x00,0x20,0x28,0x70,0xac,0x32,0x22,0x22,0x22,0x22,0x32,0x2c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7533 0x1d6d "ᵭ" */
+0x00,0x00,0x00,0x05,0x0e,0x14,0x34,0x4c,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7534 0x1d6e "ᵮ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x10,0x14,0x38,0x50,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7535 0x1d6f "ᵯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x4a,0x4a,0x4a,0x7b,0xce,0x4a,0x4a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7536 0x1d70 "ᵰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x22,0x33,0x6e,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7537 0x1d71 "ᵱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x33,0x6e,0x22,0x32,0x2c,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7538 0x1d72 "ᵲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x20,0x20,0x39,0x66,0xa0,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7539 0x1d73 "ᵳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x10,0x39,0x56,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7540 0x1d74 "ᵴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x33,0xcc,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7541 0x1d75 "ᵵ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x32,0x5c,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7542 0x1d76 "ᵶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x6a,0x9c,0x10,0x20,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7543 0x1d77 "ᵷ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x3c,0x04,0x1c,0x22,0x22,0x22,0x5c,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7544 0x1d78 "ᵸ" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7545 0x1d79 "ᵹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x10,0x10,0x08,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7546 0x1d7a "ᵺ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x11,0x12,0x14,0x18,0x10,0x2c,0x00,0x00,
+0x00,0x00,0x00,0x48,0x50,0x60,0x5c,0xe2,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+/* 7547 0x1d7b "ᵻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x7c,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7548 0x1d7c "ᵼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x7c,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7549 0x1d7d "ᵽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x22,0x7f,0x22,0x32,0x2c,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7550 0x1d7e "ᵾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x7f,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7551 0x1d7f "ᵿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0xff,0x42,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7552 0x1d80 "ᶀ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x63,0x5d,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7553 0x1d81 "ᶁ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3b,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7554 0x1d82 "ᶂ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x18,0x18,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7555 0x1d83 "ᶃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x44,0x44,0x44,0x44,0x47,0x3d,0x05,0x85,0x7a,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7556 0x1d84 "ᶄ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x46,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7557 0x1d85 "ᶅ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7558 0x1d86 "ᶆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x74,0x4a,0x4a,0x4a,0x4a,0x4a,0x4b,0x4b,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7559 0x1d87 "ᶇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x43,0x43,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7560 0x1d88 "ᶈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x66,0x5a,0x42,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7561 0x1d89 "ᶉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x20,0x20,0x20,0x30,0x30,0x10,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7562 0x1d8a "ᶊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x43,0x3d,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7563 0x1d8b "ᶋ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0x12,0x12,0x62,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7564 0x1d8c "ᶌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x24,0x24,0x26,0x1a,0x1a,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7565 0x1d8d "ᶍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x28,0x10,0x10,0x28,0x46,0x46,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7566 0x1d8e "ᶎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7567 0x1d8f "ᶏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x3c,0x44,0x44,0x4e,0x32,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7568 0x1d90 "ᶐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4c,0x44,0x44,0x44,0x44,0x4c,0x36,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7569 0x1d91 "ᶑ" */
+0x00,0x00,0x03,0x04,0x04,0x04,0x34,0x4c,0x44,0x44,0x44,0x44,0x44,0x3c,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7570 0x1d92 "ᶒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7571 0x1d93 "ᶓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7572 0x1d94 "ᶔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3c,0x02,0x02,0x42,0x7c,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7573 0x1d95 "ᶕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0xfe,0x8a,0x8a,0x72,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7574 0x1d96 "ᶖ" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3c,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7575 0x1d97 "ᶗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x02,0x42,0x7c,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7576 0x1d98 "ᶘ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x60,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7577 0x1d99 "ᶙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x36,0x02,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7578 0x1d9a "ᶚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x10,0x1c,0x02,0x02,0x3c,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7579 0x1d9b "ᶛ" */
+0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x62,0x5c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7580 0x1d9c "ᶜ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x40,0x40,0x40,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7581 0x1d9d "ᶝ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x40,0x58,0x64,0x38,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7582 0x1d9e "ᶞ" */
+0x00,0x00,0x64,0x18,0x28,0x04,0x3c,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7583 0x1d9f "ᶟ" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x04,0x38,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7584 0x1da0 "ᶠ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x7c,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7585 0x1da1 "ᶡ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x3e,0x08,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7586 0x1da2 "ᶢ" */
+0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x46,0x3a,0x02,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7587 0x1da3 "ᶣ" */
+0x00,0x00,0x00,0x44,0x44,0x44,0x4c,0x34,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7588 0x1da4 "ᶤ" */
+0x00,0x00,0x00,0x10,0x00,0x30,0x10,0x38,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7589 0x1da5 "ᶥ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7590 0x1da6 "ᶦ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7591 0x1da7 "ᶧ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x7c,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7592 0x1da8 "ᶨ" */
+0x00,0x00,0x00,0x08,0x00,0x18,0x08,0x08,0x08,0x38,0x4c,0x32,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7593 0x1da9 "ᶩ" */
+0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7594 0x1daa "ᶪ" */
+0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x18,0x18,0x08,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7595 0x1dab "ᶫ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7596 0x1dac "ᶬ" */
+0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x01,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7597 0x1dad "ᶭ" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x37,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7598 0x1dae "ᶮ" */
+0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x22,0x22,0x20,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7599 0x1daf "ᶯ" */
+0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x04,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7600 0x1db0 "ᶰ" */
+0x00,0x00,0x00,0x22,0x32,0x32,0x2a,0x26,0x26,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7601 0x1db1 "ᶱ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x7c,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7602 0x1db2 "ᶲ" */
+0x00,0x00,0x00,0x00,0x10,0x38,0x54,0x54,0x54,0x38,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7603 0x1db3 "ᶳ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x38,0x04,0x78,0x40,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7604 0x1db4 "ᶴ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x60,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7605 0x1db5 "ᶵ" */
+0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x10,0x0e,0x02,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7606 0x1db6 "ᶶ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x7f,0x26,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7607 0x1db7 "ᶷ" */
+0x00,0x00,0x00,0x42,0x24,0x42,0x42,0x42,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7608 0x1db8 "ᶸ" */
+0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7609 0x1db9 "ᶹ" */
+0x00,0x00,0x00,0x00,0x00,0xcc,0x44,0x44,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7610 0x1dba "ᶺ" */
+0x00,0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7611 0x1dbb "ᶻ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x08,0x10,0x20,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7612 0x1dbc "ᶼ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x08,0x10,0x20,0x7c,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7613 0x1dbd "ᶽ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x08,0x12,0x25,0x7e,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7614 0x1dbe "ᶾ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x1c,0x02,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7615 0x1dbf "ᶿ" */
+0x00,0x00,0x00,0x18,0x24,0x42,0x7e,0x42,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7616 0x1dc0 "᷀" */
+0x24,0x10,0x08,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7617 0x1dc1 "᷁" */
+0x24,0x08,0x10,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7618 0x1dc2 "᷂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x38,0x1c,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7619 0x1dc3 "᷃" */
+0x00,0x02,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7620 0x1dc4 "᷄" */
+0x00,0x02,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7621 0x1dc5 "᷅" */
+0x00,0x40,0x20,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7622 0x1dc6 "᷆" */
+0x00,0x78,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7623 0x1dc7 "᷇" */
+0x00,0x3c,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7624 0x1dc8 "᷈" */
+0x00,0x88,0x54,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7625 0x1dc9 "᷉" */
+0x00,0x22,0x54,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7626 0x1dca "᷊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x30,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7627 0x1dcb "᷋" */
+0x00,0x8e,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7628 0x1dcc "᷌" */
+0x00,0xe2,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7629 0x1dcd "᷍" */
+0x00,0x01,0x06,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x60,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7630 0x1dce "᷎" */
+0x00,0x30,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7631 0x1dcf "᷏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x38,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7632 0x1dd0 "᷐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x3f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7633 0x1dd1 "᷑" */
+0x00,0x64,0x92,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7634 0x1dd2 "᷒" */
+0x00,0x18,0x24,0x14,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7635 0x1dd3 "ᷓ" */
+0x00,0x92,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7636 0x1dd4 "ᷔ" */
+0xec,0x12,0x7e,0x90,0x6e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7637 0x1dd5 "ᷕ" */
+0xec,0x12,0x72,0x92,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7638 0x1dd6 "ᷖ" */
+0xe1,0x11,0x7a,0x9a,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7639 0x1dd7 "ᷗ" */
+0x1c,0x20,0x20,0x20,0x1c,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7640 0x1dd8 "ᷘ" */
+0x30,0x08,0x1c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7641 0x1dd9 "ᷙ" */
+0x28,0x10,0x28,0x1c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7642 0x1dda "ᷚ" */
+0x1c,0x24,0x1c,0x04,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7643 0x1ddb "ᷛ" */
+0x1c,0x20,0x2c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7644 0x1ddc "ᷜ" */
+0x20,0x24,0x28,0x34,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7645 0x1ddd "ᷝ" */
+0x18,0x08,0x08,0x08,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7646 0x1dde "ᷞ" */
+0x20,0x20,0x20,0x20,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7647 0x1ddf "ᷟ" */
+0x44,0x6c,0x54,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7648 0x1de0 "ᷠ" */
+0x58,0x64,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7649 0x1de1 "ᷡ" */
+0x44,0x64,0x54,0x4c,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7650 0x1de2 "ᷢ" */
+0x38,0x24,0x38,0x28,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7651 0x1de3 "ᷣ" */
+0x18,0x24,0x04,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7652 0x1de4 "ᷤ" */
+0x1c,0x20,0x18,0x04,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7653 0x1de5 "ᷥ" */
+0x18,0x24,0x20,0x60,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7654 0x1de6 "ᷦ" */
+0x3c,0x04,0x18,0x20,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7655 0x1de7 "ᷧ" */
+0x00,0x1a,0x24,0x24,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7656 0x1de8 "ᷨ" */
+0x10,0x1c,0x12,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7657 0x1de9 "ᷩ" */
+0x18,0x24,0x28,0x24,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7658 0x1dea "ᷪ" */
+0x38,0x04,0x3c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7659 0x1deb "ᷫ" */
+0x0c,0x10,0x38,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7660 0x1dec "ᷬ" */
+0x10,0x38,0x10,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7661 0x1ded "ᷭ" */
+0x00,0x18,0x24,0x24,0x58,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7662 0x1dee "ᷮ" */
+0x38,0x24,0x38,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7663 0x1def "ᷯ" */
+0x0c,0x10,0x10,0x10,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7664 0x1df0 "ᷰ" */
+0x00,0x24,0x24,0x5c,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7665 0x1df1 "ᷱ" */
+0x00,0x92,0x54,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7666 0x1df2 "ᷲ" */
+0x14,0x00,0x1c,0x24,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7667 0x1df3 "ᷳ" */
+0x28,0x00,0x18,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7668 0x1df4 "ᷴ" */
+0x28,0x00,0x28,0x28,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7669 0x1df5 "᷵" */
+0x00,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7670 0x1df6 "᷶" */
+0x00,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7671 0x1df7 "᷷" */
+0x00,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7672 0x1df8 "᷸" */
+0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7673 0x1df9 "᷹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7674 0x1dfa "᷺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7675 0x1dfb "᷻" */
+0x49,0x49,0x92,0x92,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7676 0x1dfc "᷼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x18,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x18,0x04,
+/* 7677 0x1dfd "᷽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7678 0x1dfe "᷾" */
+0x08,0x10,0x20,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7679 0x1dff "᷿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4a,0x24,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7680 0x1e00 "Ḁ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x18,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7681 0x1e01 "ḁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x46,0x3a,0x18,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7682 0x1e02 "Ḃ" */
+0x00,0x10,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7683 0x1e03 "ḃ" */
+0x00,0x00,0x00,0x48,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7684 0x1e04 "Ḅ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7685 0x1e05 "ḅ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7686 0x1e06 "Ḇ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7687 0x1e07 "ḇ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7688 0x1e08 "Ḉ" */
+0x08,0x10,0x20,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7689 0x1e09 "ḉ" */
+0x00,0x00,0x08,0x10,0x20,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7690 0x1e0a "Ḋ" */
+0x00,0x10,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7691 0x1e0b "ḋ" */
+0x00,0x00,0x00,0x12,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7692 0x1e0c "Ḍ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7693 0x1e0d "ḍ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7694 0x1e0e "Ḏ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7695 0x1e0f "ḏ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7696 0x1e10 "Ḑ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x10,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7697 0x1e11 "ḑ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7698 0x1e12 "Ḓ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x30,0x48,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7699 0x1e13 "ḓ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7700 0x1e14 "Ḕ" */
+0x10,0x08,0x3c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7701 0x1e15 "ḕ" */
+0x20,0x10,0x08,0x00,0x3c,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7702 0x1e16 "Ḗ" */
+0x08,0x10,0x3c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7703 0x1e17 "ḗ" */
+0x08,0x10,0x20,0x00,0x3c,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7704 0x1e18 "Ḙ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7705 0x1e19 "ḙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7706 0x1e1a "Ḛ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7707 0x1e1b "ḛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7708 0x1e1c "Ḝ" */
+0x00,0x22,0x1c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7709 0x1e1d "ḝ" */
+0x00,0x00,0x22,0x1c,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x08,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7710 0x1e1e "Ḟ" */
+0x00,0x10,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7711 0x1e1f "ḟ" */
+0x08,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7712 0x1e20 "Ḡ" */
+0x00,0x00,0x3c,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7713 0x1e21 "ḡ" */
+0x00,0x00,0x00,0x00,0x78,0x02,0x3a,0x44,0x44,0x44,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7714 0x1e22 "Ḣ" */
+0x00,0x00,0x10,0x00,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7715 0x1e23 "ḣ" */
+0x00,0x00,0x00,0x48,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7716 0x1e24 "Ḥ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7717 0x1e25 "ḥ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7718 0x1e26 "Ḧ" */
+0x00,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7719 0x1e27 "ḧ" */
+0x24,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7720 0x1e28 "Ḩ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x62,0x62,0x10,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7721 0x1e29 "ḩ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x62,0x10,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7722 0x1e2a "Ḫ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0x82,0x82,0xfe,0x82,0x82,0x82,0x82,0x82,0x28,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7723 0x1e2b "ḫ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x4e,0x51,0x61,0x41,0x41,0x41,0x41,0x41,0x14,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7724 0x1e2c "Ḭ" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7725 0x1e2d "ḭ" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7726 0x1e2e "Ḯ" */
+0x04,0x08,0x2a,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7727 0x1e2f "ḯ" */
+0x00,0x02,0x04,0x08,0x22,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7728 0x1e30 "Ḱ" */
+0x00,0x04,0x08,0x10,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7729 0x1e31 "ḱ" */
+0x00,0x02,0x04,0x48,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7730 0x1e32 "Ḳ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7731 0x1e33 "ḳ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7732 0x1e34 "Ḵ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7733 0x1e35 "ḵ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7734 0x1e36 "Ḷ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7735 0x1e37 "ḷ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7736 0x1e38 "Ḹ" */
+0x00,0x00,0x3c,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7737 0x1e39 "ḹ" */
+0x00,0x3c,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7738 0x1e3a "Ḻ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7739 0x1e3b "ḻ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7740 0x1e3c "Ḽ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7741 0x1e3d "ḽ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7742 0x1e3e "Ḿ" */
+0x00,0x04,0x08,0x10,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7743 0x1e3f "ḿ" */
+0x00,0x00,0x04,0x08,0x10,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7744 0x1e40 "Ṁ" */
+0x00,0x00,0x10,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7745 0x1e41 "ṁ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7746 0x1e42 "Ṃ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7747 0x1e43 "ṃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7748 0x1e44 "Ṅ" */
+0x00,0x00,0x08,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7749 0x1e45 "ṅ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7750 0x1e46 "Ṇ" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7751 0x1e47 "ṇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7752 0x1e48 "Ṉ" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7753 0x1e49 "ṉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7754 0x1e4a "Ṋ" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7755 0x1e4b "ṋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x18,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7756 0x1e4c "Ṍ" */
+0x04,0x08,0x32,0x4c,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7757 0x1e4d "ṍ" */
+0x02,0x04,0x08,0x32,0x4c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7758 0x1e4e "Ṏ" */
+0x24,0x00,0x32,0x4c,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7759 0x1e4f "ṏ" */
+0x00,0x24,0x00,0x32,0x4c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7760 0x1e50 "Ṑ" */
+0x10,0x08,0x3c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7761 0x1e51 "ṑ" */
+0x20,0x10,0x08,0x00,0x3c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7762 0x1e52 "Ṓ" */
+0x08,0x10,0x3c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7763 0x1e53 "ṓ" */
+0x08,0x10,0x20,0x00,0x3c,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7764 0x1e54 "Ṕ" */
+0x00,0x04,0x08,0x10,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7765 0x1e55 "ṕ" */
+0x00,0x00,0x04,0x08,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7766 0x1e56 "Ṗ" */
+0x00,0x10,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7767 0x1e57 "ṗ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7768 0x1e58 "Ṙ" */
+0x00,0x10,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7769 0x1e59 "ṙ" */
+0x00,0x00,0x00,0x10,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7770 0x1e5a "Ṛ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7771 0x1e5b "ṛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7772 0x1e5c "Ṝ" */
+0x00,0x00,0x3c,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7773 0x1e5d "ṝ" */
+0x00,0x00,0x00,0x00,0x3c,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7774 0x1e5e "Ṟ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7775 0x1e5f "ṟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x40,0x40,0x40,0x40,0x40,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7776 0x1e60 "Ṡ" */
+0x00,0x10,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7777 0x1e61 "ṡ" */
+0x00,0x00,0x00,0x10,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7778 0x1e62 "Ṣ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7779 0x1e63 "ṣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7780 0x1e64 "Ṥ" */
+0x24,0x08,0x10,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7781 0x1e65 "ṥ" */
+0x00,0x20,0x08,0x10,0x20,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7782 0x1e66 "Ṧ" */
+0x08,0x22,0x14,0x08,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7783 0x1e67 "ṧ" */
+0x00,0x08,0x00,0x22,0x14,0x08,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7784 0x1e68 "Ṩ" */
+0x00,0x08,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7785 0x1e69 "ṩ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7786 0x1e6a "Ṫ" */
+0x00,0x08,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7787 0x1e6b "ṫ" */
+0x00,0x10,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7788 0x1e6c "Ṭ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7789 0x1e6d "ṭ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7790 0x1e6e "Ṯ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7791 0x1e6f "ṯ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7792 0x1e70 "Ṱ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x08,0x14,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7793 0x1e71 "ṱ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x12,0x0c,0x14,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7794 0x1e72 "Ṳ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x24,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7795 0x1e73 "ṳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7796 0x1e74 "Ṵ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7797 0x1e75 "ṵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7798 0x1e76 "Ṷ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x14,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7799 0x1e77 "ṷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x14,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7800 0x1e78 "Ṹ" */
+0x04,0x08,0x32,0x4c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7801 0x1e79 "ṹ" */
+0x02,0x04,0x08,0x32,0x4c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7802 0x1e7a "Ṻ" */
+0x24,0x00,0x3c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7803 0x1e7b "ṻ" */
+0x00,0x00,0x24,0x00,0x3c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7804 0x1e7c "Ṽ" */
+0x00,0x00,0x32,0x4c,0x00,0x41,0x41,0x22,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7805 0x1e7d "ṽ" */
+0x00,0x00,0x32,0x4c,0x00,0x00,0x42,0x42,0x42,0x24,0x24,0x24,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7806 0x1e7e "Ṿ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x22,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7807 0x1e7f "ṿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7808 0x1e80 "Ẁ" */
+0x00,0x20,0x10,0x08,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7809 0x1e81 "ẁ" */
+0x00,0x00,0x10,0x08,0x04,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7810 0x1e82 "Ẃ" */
+0x00,0x04,0x08,0x10,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7811 0x1e83 "ẃ" */
+0x00,0x00,0x04,0x08,0x10,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7812 0x1e84 "Ẅ" */
+0x00,0x24,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7813 0x1e85 "ẅ" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7814 0x1e86 "Ẇ" */
+0x00,0x10,0x00,0x00,0x44,0x44,0x44,0x44,0x54,0x54,0x6c,0x6c,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7815 0x1e87 "ẇ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7816 0x1e88 "Ẉ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x54,0x54,0x6c,0x6c,0x44,0x44,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7817 0x1e89 "ẉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7818 0x1e8a "Ẋ" */
+0x00,0x10,0x00,0x00,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7819 0x1e8b "ẋ" */
+0x00,0x00,0x00,0x10,0x00,0x00,0x44,0x44,0x28,0x10,0x10,0x28,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7820 0x1e8c "Ẍ" */
+0x00,0x24,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7821 0x1e8d "ẍ" */
+0x00,0x00,0x00,0x24,0x00,0x00,0x42,0x42,0x24,0x18,0x18,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7822 0x1e8e "Ẏ" */
+0x00,0x08,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7823 0x1e8f "ẏ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7824 0x1e90 "Ẑ" */
+0x18,0x24,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7825 0x1e91 "ẑ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7826 0x1e92 "Ẓ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7827 0x1e93 "ẓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7828 0x1e94 "Ẕ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7829 0x1e95 "ẕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7830 0x1e96 "ẖ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7831 0x1e97 "ẗ" */
+0x00,0x00,0x44,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7832 0x1e98 "ẘ" */
+0x00,0x08,0x14,0x08,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7833 0x1e99 "ẙ" */
+0x00,0x08,0x14,0x08,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7834 0x1e9a "ẚ" */
+0x00,0x02,0x01,0x01,0x02,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7835 0x1e9b "ẛ" */
+0x00,0x10,0x00,0x0c,0x10,0x10,0x10,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7836 0x1e9c "ẜ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x34,0x18,0x30,0x50,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7837 0x1e9d "ẝ" */
+0x00,0x00,0x00,0x0c,0x10,0x7c,0x10,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7838 0x1e9e "ẞ" */
+0x00,0x00,0x00,0x00,0x3e,0x42,0x44,0x48,0x4c,0x42,0x42,0x42,0x52,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7839 0x1e9f "ẟ" */
+0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x20,0x18,0x24,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7840 0x1ea0 "Ạ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7841 0x1ea1 "ạ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7842 0x1ea2 "Ả" */
+0x40,0x20,0x20,0x40,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7843 0x1ea3 "ả" */
+0x00,0x08,0x04,0x04,0x08,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7844 0x1ea4 "Ấ" */
+0x02,0x14,0x28,0x44,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7845 0x1ea5 "ấ" */
+0x00,0x02,0x14,0x28,0x44,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7846 0x1ea6 "Ầ" */
+0x40,0x28,0x14,0x22,0x08,0x14,0x14,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7847 0x1ea7 "ầ" */
+0x00,0x40,0x28,0x14,0x22,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7848 0x1ea8 "Ẩ" */
+0x04,0x02,0x14,0x28,0x54,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7849 0x1ea9 "ẩ" */
+0x02,0x01,0x0a,0x14,0x22,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7850 0x1eaa "Ẫ" */
+0x19,0x26,0x08,0x14,0x22,0x08,0x14,0x14,0x22,0x22,0x3e,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7851 0x1eab "ẫ" */
+0x19,0x26,0x08,0x14,0x22,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7852 0x1eac "Ậ" */
+0x00,0x08,0x14,0x22,0x08,0x14,0x14,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7853 0x1ead "ậ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7854 0x1eae "Ắ" */
+0x08,0x10,0x44,0x38,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7855 0x1eaf "ắ" */
+0x04,0x08,0x10,0x44,0x38,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7856 0x1eb0 "Ằ" */
+0x20,0x10,0x44,0x38,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7857 0x1eb1 "ằ" */
+0x20,0x10,0x08,0x22,0x1c,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7858 0x1eb2 "Ẳ" */
+0x10,0x08,0xb2,0x7c,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7859 0x1eb3 "ẳ" */
+0x08,0x08,0x10,0x44,0x38,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7860 0x1eb4 "Ẵ" */
+0x32,0x4c,0x82,0x7c,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7861 0x1eb5 "ẵ" */
+0x32,0x4c,0x00,0x42,0x3c,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7862 0x1eb6 "Ặ" */
+0x00,0x00,0x44,0x38,0x10,0x28,0x28,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7863 0x1eb7 "ặ" */
+0x00,0x00,0x00,0x24,0x18,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7864 0x1eb8 "Ẹ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7865 0x1eb9 "ẹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7866 0x1eba "Ẻ" */
+0x10,0x08,0x08,0x10,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7867 0x1ebb "ẻ" */
+0x10,0x08,0x08,0x10,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7868 0x1ebc "Ẽ" */
+0x00,0x32,0x4c,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7869 0x1ebd "ẽ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7870 0x1ebe "Ế" */
+0x02,0x14,0x28,0x44,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7871 0x1ebf "ế" */
+0x00,0x02,0x14,0x28,0x44,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7872 0x1ec0 "Ề" */
+0x40,0x28,0x14,0x22,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7873 0x1ec1 "ề" */
+0x00,0x40,0x28,0x14,0x22,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7874 0x1ec2 "Ể" */
+0x04,0x12,0x2a,0x44,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7875 0x1ec3 "ể" */
+0x04,0x02,0x12,0x2c,0x44,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7876 0x1ec4 "Ễ" */
+0x32,0x4c,0x10,0x28,0x44,0x7e,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7877 0x1ec5 "ễ" */
+0x32,0x4c,0x10,0x28,0x44,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7878 0x1ec6 "Ệ" */
+0x00,0x18,0x24,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7879 0x1ec7 "ệ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7880 0x1ec8 "Ỉ" */
+0x08,0x04,0x04,0x08,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7881 0x1ec9 "ỉ" */
+0x00,0x10,0x08,0x08,0x10,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7882 0x1eca "Ị" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7883 0x1ecb "ị" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7884 0x1ecc "Ọ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7885 0x1ecd "ọ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7886 0x1ece "Ỏ" */
+0x10,0x08,0x08,0x10,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7887 0x1ecf "ỏ" */
+0x00,0x10,0x08,0x08,0x10,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7888 0x1ed0 "Ố" */
+0x02,0x14,0x28,0x44,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7889 0x1ed1 "ố" */
+0x00,0x02,0x14,0x28,0x44,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7890 0x1ed2 "Ồ" */
+0x40,0x28,0x14,0x22,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7891 0x1ed3 "ồ" */
+0x00,0x40,0x28,0x14,0x22,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7892 0x1ed4 "Ổ" */
+0x04,0x12,0x2a,0x44,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7893 0x1ed5 "ổ" */
+0x04,0x02,0x12,0x2c,0x44,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7894 0x1ed6 "Ỗ" */
+0x32,0x4c,0x10,0x28,0x44,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7895 0x1ed7 "ỗ" */
+0x32,0x4c,0x10,0x28,0x44,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7896 0x1ed8 "Ộ" */
+0x00,0x18,0x24,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7897 0x1ed9 "ộ" */
+0x00,0x00,0x18,0x24,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7898 0x1eda "Ớ" */
+0x08,0x10,0x22,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7899 0x1edb "ớ" */
+0x00,0x00,0x08,0x10,0x22,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7900 0x1edc "Ờ" */
+0x20,0x10,0x0a,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7901 0x1edd "ờ" */
+0x00,0x00,0x20,0x10,0x0a,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7902 0x1ede "Ở" */
+0x10,0x08,0x0a,0x11,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7903 0x1edf "ở" */
+0x00,0x10,0x08,0x08,0x12,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7904 0x1ee0 "Ỡ" */
+0x00,0x32,0x4c,0x02,0x39,0x45,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7905 0x1ee1 "ỡ" */
+0x00,0x32,0x4c,0x00,0x02,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7906 0x1ee2 "Ợ" */
+0x00,0x00,0x02,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7907 0x1ee3 "ợ" */
+0x00,0x00,0x00,0x00,0x02,0x01,0x39,0x46,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7908 0x1ee4 "Ụ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7909 0x1ee5 "ụ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7910 0x1ee6 "Ủ" */
+0x10,0x08,0x08,0x10,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7911 0x1ee7 "ủ" */
+0x00,0x10,0x08,0x08,0x10,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7912 0x1ee8 "Ứ" */
+0x04,0x08,0x12,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7913 0x1ee9 "ứ" */
+0x00,0x00,0x04,0x08,0x12,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7914 0x1eea "Ừ" */
+0x40,0x20,0x12,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7915 0x1eeb "ừ" */
+0x00,0x00,0x40,0x20,0x12,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7916 0x1eec "Ử" */
+0x10,0x08,0x0a,0x11,0x45,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7917 0x1eed "ử" */
+0x00,0x10,0x08,0x08,0x12,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7918 0x1eee "Ữ" */
+0x32,0x4c,0x02,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7919 0x1eef "ữ" */
+0x00,0x32,0x4c,0x00,0x02,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7920 0x1ef0 "Ự" */
+0x00,0x00,0x02,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7921 0x1ef1 "ự" */
+0x00,0x00,0x00,0x00,0x02,0x01,0x45,0x46,0x44,0x44,0x44,0x44,0x4c,0x34,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7922 0x1ef2 "Ỳ" */
+0x20,0x10,0x08,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7923 0x1ef3 "ỳ" */
+0x00,0x20,0x10,0x08,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7924 0x1ef4 "Ỵ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7925 0x1ef5 "ỵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x3c,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7926 0x1ef6 "Ỷ" */
+0x08,0x04,0x04,0x08,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7927 0x1ef7 "ỷ" */
+0x00,0x10,0x08,0x08,0x10,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7928 0x1ef8 "Ỹ" */
+0x00,0x32,0x4c,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7929 0x1ef9 "ỹ" */
+0x00,0x00,0x32,0x4c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7930 0x1efa "Ỻ" */
+0x00,0x00,0x00,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7931 0x1efb "ỻ" */
+0x00,0x00,0x00,0x6c,0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0x24,0x24,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7932 0x1efc "Ỽ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x20,0x24,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7933 0x1efd "ỽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x20,0x48,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7934 0x1efe "Ỿ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x14,0x14,0x08,0x08,0x08,0x08,0x38,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7935 0x1eff "ỿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x14,0x14,0x08,0x08,0x38,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7936 0x1f00 "ἀ" */
+0x00,0x00,0x30,0x10,0x20,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7937 0x1f01 "ἁ" */
+0x00,0x00,0x30,0x20,0x10,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7938 0x1f02 "ἂ" */
+0x00,0x00,0x68,0x28,0x44,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7939 0x1f03 "ἃ" */
+0x00,0x00,0x68,0x48,0x24,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7940 0x1f04 "ἄ" */
+0x00,0x00,0x64,0x28,0x48,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7941 0x1f05 "ἅ" */
+0x00,0x00,0x64,0x48,0x28,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7942 0x1f06 "ἆ" */
+0x64,0x98,0x00,0x30,0x10,0x20,0x00,0x32,0x4a,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7943 0x1f07 "ἇ" */
+0x64,0x98,0x00,0x30,0x20,0x10,0x00,0x32,0x4a,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7944 0x1f08 "Ἀ" */
+0xc0,0x40,0x80,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7945 0x1f09 "Ἁ" */
+0xc0,0x80,0x40,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7946 0x1f0a "Ἂ" */
+0xd0,0x50,0x88,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7947 0x1f0b "Ἃ" */
+0xd0,0x90,0x48,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7948 0x1f0c "Ἄ" */
+0xc8,0x50,0x90,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7949 0x1f0d "Ἅ" */
+0xc8,0x90,0x50,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7950 0x1f0e "Ἆ" */
+0x64,0x98,0x60,0x20,0x40,0x18,0x24,0x24,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7951 0x1f0f "Ἇ" */
+0x64,0x98,0x60,0x40,0x20,0x18,0x24,0x24,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7952 0x1f10 "ἐ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7953 0x1f11 "ἑ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7954 0x1f12 "ἒ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7955 0x1f13 "ἓ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7956 0x1f14 "ἔ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7957 0x1f15 "ἕ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7958 0x1f16 "἖" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 7959 0x1f17 "἗" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 7960 0x1f18 "Ἐ" */
+0xc0,0x40,0x80,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7961 0x1f19 "Ἑ" */
+0xc0,0x80,0x40,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7962 0x1f1a "Ἒ" */
+0xd0,0x50,0x88,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7963 0x1f1b "Ἓ" */
+0xd0,0x90,0x48,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7964 0x1f1c "Ἔ" */
+0xc8,0x50,0x90,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7965 0x1f1d "Ἕ" */
+0xc8,0x90,0x50,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7966 0x1f1e "἞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 7967 0x1f1f "἟" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 7968 0x1f20 "ἠ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7969 0x1f21 "ἡ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7970 0x1f22 "ἢ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7971 0x1f23 "ἣ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7972 0x1f24 "ἤ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7973 0x1f25 "ἥ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7974 0x1f26 "ἦ" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7975 0x1f27 "ἧ" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7976 0x1f28 "Ἠ" */
+0xc0,0x40,0x80,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7977 0x1f29 "Ἡ" */
+0xc0,0x80,0x40,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7978 0x1f2a "Ἢ" */
+0xd0,0x50,0x88,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7979 0x1f2b "Ἣ" */
+0xd0,0x90,0x48,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7980 0x1f2c "Ἤ" */
+0xc8,0x50,0x90,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7981 0x1f2d "Ἥ" */
+0xc8,0x90,0x50,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7982 0x1f2e "Ἦ" */
+0x64,0x98,0x60,0x20,0x40,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7983 0x1f2f "Ἧ" */
+0x64,0x98,0x60,0x40,0x20,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7984 0x1f30 "ἰ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7985 0x1f31 "ἱ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7986 0x1f32 "ἲ" */
+0x00,0x00,0x68,0x28,0x44,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7987 0x1f33 "ἳ" */
+0x00,0x00,0x68,0x48,0x24,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7988 0x1f34 "ἴ" */
+0x00,0x00,0x64,0x28,0x48,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7989 0x1f35 "ἵ" */
+0x00,0x00,0x64,0x48,0x28,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7990 0x1f36 "ἶ" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7991 0x1f37 "ἷ" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7992 0x1f38 "Ἰ" */
+0xc0,0x40,0x80,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7993 0x1f39 "Ἱ" */
+0xc0,0x80,0x60,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7994 0x1f3a "Ἲ" */
+0xd0,0x50,0x88,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7995 0x1f3b "Ἳ" */
+0xd0,0x90,0x48,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7996 0x1f3c "Ἴ" */
+0xc8,0x50,0x90,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7997 0x1f3d "Ἵ" */
+0xc8,0x90,0x50,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7998 0x1f3e "Ἶ" */
+0x64,0x98,0x60,0x20,0x40,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 7999 0x1f3f "Ἷ" */
+0x64,0x98,0x60,0x40,0x20,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8000 0x1f40 "ὀ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8001 0x1f41 "ὁ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8002 0x1f42 "ὂ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8003 0x1f43 "ὃ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8004 0x1f44 "ὄ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8005 0x1f45 "ὅ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8006 0x1f46 "὆" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 8007 0x1f47 "὇" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 8008 0x1f48 "Ὀ" */
+0xc0,0x40,0x80,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8009 0x1f49 "Ὁ" */
+0xc0,0x80,0x40,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8010 0x1f4a "Ὂ" */
+0xd0,0x50,0x88,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8011 0x1f4b "Ὃ" */
+0xd0,0x90,0x48,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8012 0x1f4c "Ὄ" */
+0xc8,0x50,0x90,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8013 0x1f4d "Ὅ" */
+0xc8,0x90,0x50,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8014 0x1f4e "὎" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8015 0x1f4f "὏" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8016 0x1f50 "ὐ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8017 0x1f51 "ὑ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8018 0x1f52 "ὒ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8019 0x1f53 "ὓ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8020 0x1f54 "ὔ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8021 0x1f55 "ὕ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8022 0x1f56 "ὖ" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8023 0x1f57 "ὗ" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8024 0x1f58 "὘" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 8025 0x1f59 "Ὑ" */
+0xc0,0x80,0x40,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8026 0x1f5a "὚" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 8027 0x1f5b "Ὓ" */
+0xd0,0x90,0x48,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8028 0x1f5c "὜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 8029 0x1f5d "Ὕ" */
+0xc8,0x90,0x50,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8030 0x1f5e "὞" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8031 0x1f5f "Ὗ" */
+0x64,0x98,0x60,0x40,0x20,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8032 0x1f60 "ὠ" */
+0x00,0x00,0x0c,0x04,0x08,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8033 0x1f61 "ὡ" */
+0x00,0x00,0x0c,0x08,0x04,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8034 0x1f62 "ὢ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8035 0x1f63 "ὣ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8036 0x1f64 "ὤ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8037 0x1f65 "ὥ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8038 0x1f66 "ὦ" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x00,0x22,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8039 0x1f67 "ὧ" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x00,0x22,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8040 0x1f68 "Ὠ" */
+0xc0,0x40,0x80,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8041 0x1f69 "Ὡ" */
+0xc0,0x80,0x40,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8042 0x1f6a "Ὢ" */
+0xd0,0x50,0x88,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8043 0x1f6b "Ὣ" */
+0xd0,0x90,0x48,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8044 0x1f6c "Ὤ" */
+0xc8,0x50,0x90,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8045 0x1f6d "Ὥ" */
+0xc8,0x90,0x50,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8046 0x1f6e "Ὦ" */
+0x32,0x4c,0x18,0x08,0x10,0x1c,0x22,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8047 0x1f6f "Ὧ" */
+0x32,0x4c,0x18,0x10,0x08,0x1c,0x23,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8048 0x1f70 "ὰ" */
+0x00,0x00,0x20,0x20,0x10,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8049 0x1f71 "ά" */
+0x00,0x00,0x10,0x20,0x20,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8050 0x1f72 "ὲ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8051 0x1f73 "έ" */
+0x00,0x00,0x08,0x10,0x10,0x00,0x3c,0x42,0x40,0x3c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8052 0x1f74 "ὴ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8053 0x1f75 "ή" */
+0x00,0x00,0x08,0x10,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8054 0x1f76 "ὶ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8055 0x1f77 "ί" */
+0x00,0x00,0x08,0x10,0x10,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8056 0x1f78 "ὸ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8057 0x1f79 "ό" */
+0x00,0x00,0x08,0x10,0x10,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8058 0x1f7a "ὺ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8059 0x1f7b "ύ" */
+0x00,0x00,0x08,0x10,0x10,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8060 0x1f7c "ὼ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8061 0x1f7d "ώ" */
+0x00,0x00,0x04,0x08,0x08,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8062 0x1f7e "὾" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8063 0x1f7f "὿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8064 0x1f80 "ᾀ" */
+0x00,0x00,0x30,0x10,0x20,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8065 0x1f81 "ᾁ" */
+0x00,0x00,0x30,0x20,0x10,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8066 0x1f82 "ᾂ" */
+0x00,0x00,0x68,0x28,0x44,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8067 0x1f83 "ᾃ" */
+0x00,0x00,0x68,0x48,0x24,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8068 0x1f84 "ᾄ" */
+0x00,0x00,0x64,0x28,0x48,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8069 0x1f85 "ᾅ" */
+0x00,0x00,0x64,0x48,0x28,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8070 0x1f86 "ᾆ" */
+0x32,0x4c,0x00,0x30,0x10,0x20,0x00,0x32,0x4a,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8071 0x1f87 "ᾇ" */
+0x32,0x4c,0x00,0x30,0x20,0x10,0x00,0x32,0x4a,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8072 0x1f88 "ᾈ" */
+0xc0,0x40,0x80,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8073 0x1f89 "ᾉ" */
+0xc0,0x80,0x40,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8074 0x1f8a "ᾊ" */
+0xd0,0x50,0x88,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8075 0x1f8b "ᾋ" */
+0xd0,0x90,0x48,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8076 0x1f8c "ᾌ" */
+0xc8,0x50,0x90,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8077 0x1f8d "ᾍ" */
+0xc8,0x90,0x50,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8078 0x1f8e "ᾎ" */
+0x64,0x98,0x60,0x20,0x40,0x18,0x24,0x24,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8079 0x1f8f "ᾏ" */
+0x64,0x98,0x60,0x40,0x20,0x18,0x24,0x24,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8080 0x1f90 "ᾐ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8081 0x1f91 "ᾑ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8082 0x1f92 "ᾒ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8083 0x1f93 "ᾓ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8084 0x1f94 "ᾔ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8085 0x1f95 "ᾕ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8086 0x1f96 "ᾖ" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8087 0x1f97 "ᾗ" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8088 0x1f98 "ᾘ" */
+0xc0,0x40,0x80,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8089 0x1f99 "ᾙ" */
+0xc0,0x80,0x40,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8090 0x1f9a "ᾚ" */
+0xd0,0x50,0x88,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8091 0x1f9b "ᾛ" */
+0xd0,0x90,0x48,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8092 0x1f9c "ᾜ" */
+0xc8,0x50,0x90,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8093 0x1f9d "ᾝ" */
+0xc8,0x90,0x50,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8094 0x1f9e "ᾞ" */
+0x64,0x98,0x60,0x20,0x40,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8095 0x1f9f "ᾟ" */
+0x64,0x98,0x60,0x40,0x20,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x20,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8096 0x1fa0 "ᾠ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8097 0x1fa1 "ᾡ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8098 0x1fa2 "ᾢ" */
+0x00,0x00,0x34,0x14,0x22,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8099 0x1fa3 "ᾣ" */
+0x00,0x00,0x34,0x24,0x12,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8100 0x1fa4 "ᾤ" */
+0x00,0x00,0x32,0x14,0x24,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8101 0x1fa5 "ᾥ" */
+0x00,0x00,0x32,0x24,0x14,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8102 0x1fa6 "ᾦ" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x00,0x22,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8103 0x1fa7 "ᾧ" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x00,0x22,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8104 0x1fa8 "ᾨ" */
+0xc0,0x40,0x80,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8105 0x1fa9 "ᾩ" */
+0xc0,0x80,0x40,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8106 0x1faa "ᾪ" */
+0xd0,0x50,0x88,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8107 0x1fab "ᾫ" */
+0xd0,0x90,0x48,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8108 0x1fac "ᾬ" */
+0xc8,0x50,0x90,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8109 0x1fad "ᾭ" */
+0xc8,0x90,0x50,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8110 0x1fae "ᾮ" */
+0x64,0x98,0x60,0x20,0x40,0x1c,0x22,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8111 0x1faf "ᾯ" */
+0x64,0x98,0x60,0x40,0x20,0x1c,0x22,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8112 0x1fb0 "ᾰ" */
+0x00,0x00,0x44,0x44,0x38,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8113 0x1fb1 "ᾱ" */
+0x00,0x00,0x00,0x00,0x7c,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8114 0x1fb2 "ᾲ" */
+0x00,0x00,0x20,0x20,0x10,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8115 0x1fb3 "ᾳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8116 0x1fb4 "ᾴ" */
+0x00,0x00,0x10,0x20,0x20,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8117 0x1fb5 "᾵" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8118 0x1fb6 "ᾶ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8119 0x1fb7 "ᾷ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x20,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8120 0x1fb8 "Ᾰ" */
+0x42,0x42,0x3c,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8121 0x1fb9 "Ᾱ" */
+0x00,0x3c,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8122 0x1fba "Ὰ" */
+0x80,0x80,0x40,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8123 0x1fbb "Ά" */
+0x40,0x80,0x80,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8124 0x1fbc "ᾼ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8125 0x1fbd "᾽" */
+0x00,0x00,0x00,0x00,0x18,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8126 0x1fbe "ι" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8127 0x1fbf "᾿" */
+0x18,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8128 0x1fc0 "῀" */
+0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8129 0x1fc1 "῁" */
+0x32,0x4c,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8130 0x1fc2 "ῂ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8131 0x1fc3 "ῃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8132 0x1fc4 "ῄ" */
+0x00,0x00,0x08,0x10,0x10,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8133 0x1fc5 "῅" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8134 0x1fc6 "ῆ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8135 0x1fc7 "ῇ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8136 0x1fc8 "Ὲ" */
+0x80,0x80,0x40,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8137 0x1fc9 "Έ" */
+0x40,0x80,0x80,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8138 0x1fca "Ὴ" */
+0x80,0x80,0x40,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8139 0x1fcb "Ή" */
+0x40,0x80,0x80,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8140 0x1fcc "ῌ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x10,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8141 0x1fcd "῍" */
+0x68,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8142 0x1fce "῎" */
+0x64,0x28,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8143 0x1fcf "῏" */
+0x32,0x4c,0x00,0x18,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8144 0x1fd0 "ῐ" */
+0x00,0x00,0x44,0x44,0x38,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8145 0x1fd1 "ῑ" */
+0x00,0x00,0x00,0x00,0x3c,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8146 0x1fd2 "ῒ" */
+0x10,0x10,0x08,0x00,0x66,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8147 0x1fd3 "ΐ" */
+0x08,0x10,0x10,0x00,0x66,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8148 0x1fd4 "῔" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 8149 0x1fd5 "῕" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8150 0x1fd6 "ῖ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8151 0x1fd7 "ῗ" */
+0x00,0x32,0x4c,0x00,0x66,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8152 0x1fd8 "Ῐ" */
+0x22,0x22,0x1c,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8153 0x1fd9 "Ῑ" */
+0x00,0x3e,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8154 0x1fda "Ὶ" */
+0x80,0x80,0x40,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8155 0x1fdb "Ί" */
+0x40,0x80,0x80,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8156 0x1fdc "῜" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 8157 0x1fdd "῝" */
+0x68,0x48,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8158 0x1fde "῞" */
+0x64,0x48,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8159 0x1fdf "῟" */
+0x32,0x4c,0x00,0x18,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8160 0x1fe0 "ῠ" */
+0x00,0x00,0x42,0x42,0x3c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8161 0x1fe1 "ῡ" */
+0x00,0x00,0x00,0x3c,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8162 0x1fe2 "ῢ" */
+0x10,0x10,0x08,0x00,0x66,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8163 0x1fe3 "ΰ" */
+0x08,0x10,0x10,0x00,0x66,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8164 0x1fe4 "ῤ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8165 0x1fe5 "ῥ" */
+0x00,0x00,0x18,0x10,0x08,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8166 0x1fe6 "ῦ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8167 0x1fe7 "ῧ" */
+0x00,0x32,0x4c,0x00,0x66,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8168 0x1fe8 "Ῠ" */
+0x22,0x22,0x1c,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8169 0x1fe9 "Ῡ" */
+0x00,0x00,0x3e,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8170 0x1fea "Ὺ" */
+0x80,0x80,0x40,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8171 0x1feb "Ύ" */
+0x40,0x80,0x80,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8172 0x1fec "Ῥ" */
+0xc0,0x80,0x40,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8173 0x1fed "῭" */
+0x10,0x10,0x08,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8174 0x1fee "΅" */
+0x08,0x10,0x10,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8175 0x1fef "`" */
+0x10,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8176 0x1ff0 "῰" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 8177 0x1ff1 "῱" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 8178 0x1ff2 "ῲ" */
+0x00,0x00,0x10,0x10,0x08,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8179 0x1ff3 "ῳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8180 0x1ff4 "ῴ" */
+0x00,0x00,0x04,0x08,0x08,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8181 0x1ff5 "῵" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8182 0x1ff6 "ῶ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8183 0x1ff7 "ῷ" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x22,0x41,0x41,0x49,0x49,0x49,0x49,0x36,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8184 0x1ff8 "Ὸ" */
+0x80,0x80,0x40,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8185 0x1ff9 "Ό" */
+0x40,0x80,0x80,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8186 0x1ffa "Ὼ" */
+0x80,0x80,0x40,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8187 0x1ffb "Ώ" */
+0x40,0x80,0x80,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8188 0x1ffc "ῼ" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8189 0x1ffd "´" */
+0x08,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8190 0x1ffe "῾" */
+0x18,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8191 0x1fff "῿" */
+0x00,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8192 0x2000 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8193 0x2001 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8194 0x2002 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8195 0x2003 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8196 0x2004 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8197 0x2005 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8198 0x2006 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8199 0x2007 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8200 0x2008 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8201 0x2009 " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8202 0x200a " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8203 0x200b "​" */
+0xaa,0x00,0x9e,0x02,0x84,0x08,0x90,0x1e,0x80,0x0e,0x90,0x0c,0x82,0x1c,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x54,0x55,0x6c,0x45,0x00,0x39,0x24,0x39,0x20,0x21,0x00,0x55,
+/* 8204 0x200c "‌" */
+0xaa,0x00,0x9e,0x02,0x84,0x08,0x90,0x1e,0x80,0x12,0x9a,0x16,0x92,0x12,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x54,0x55,0x6c,0x45,0x00,0x09,0x08,0x49,0x48,0x31,0x00,0x55,
+/* 8205 0x200d "‍" */
+0xaa,0x00,0x9e,0x02,0x84,0x08,0x90,0x1e,0x80,0x00,0x80,0x02,0x82,0x01,0x80,0x55,
+0xaa,0x01,0x44,0x45,0x54,0x55,0x6c,0x45,0x00,0x41,0x40,0x41,0x40,0x81,0x00,0x55,
+/* 8206 0x200e "‎" */
+0xaa,0x00,0x80,0x00,0xc7,0x44,0xc7,0x45,0xf4,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x22,0xb7,0x2a,0x23,0xa2,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8207 0x200f "‏" */
+0xaa,0x00,0x80,0x00,0xf2,0x4a,0xf2,0x52,0xcb,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x22,0x37,0x2a,0x23,0xa2,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8208 0x2010 "‐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8209 0x2011 "‑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8210 0x2012 "‒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8211 0x2013 "–" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8212 0x2014 "—" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8213 0x2015 "―" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8214 0x2016 "‖" */
+0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8215 0x2017 "‗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8216 0x2018 "‘" */
+0x00,0x00,0x08,0x10,0x10,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8217 0x2019 "’" */
+0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8218 0x201a "‚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8219 0x201b "‛" */
+0x00,0x00,0x18,0x10,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8220 0x201c "“" */
+0x00,0x00,0x22,0x44,0x44,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8221 0x201d "”" */
+0x00,0x00,0x66,0x22,0x22,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8222 0x201e "„" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x22,0x22,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8223 0x201f "‟" */
+0x00,0x00,0x66,0x44,0x44,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8224 0x2020 "†" */
+0x00,0x00,0x08,0x1c,0x08,0x2a,0x7f,0x2a,0x08,0x1c,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8225 0x2021 "‡" */
+0x00,0x08,0x1c,0x08,0x2a,0x7f,0x2a,0x08,0x08,0x2a,0x7f,0x2a,0x08,0x1c,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8226 0x2022 "•" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x7c,0x7c,0x7c,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8227 0x2023 "‣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x30,0x38,0x3c,0x38,0x30,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8228 0x2024 "․" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8229 0x2025 "‥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8230 0x2026 "…" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8231 0x2027 "‧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8232 0x2028 " " */
+0xaa,0x00,0x80,0x02,0x82,0x02,0x82,0x03,0x80,0x3b,0xc2,0x33,0x8a,0x73,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x00,0xc1,0x00,0xdd,0x12,0xdd,0x10,0xd1,0x00,0x55,
+/* 8233 0x2029 " " */
+0xaa,0x00,0x80,0x03,0x82,0x03,0x82,0x02,0x80,0x3b,0xc2,0x33,0x8a,0x73,0x80,0x55,
+0xaa,0x01,0x00,0x81,0x40,0x81,0x00,0x01,0x00,0xdd,0x12,0xdd,0x10,0xd1,0x00,0x55,
+/* 8234 0x202a */
+0xaa,0x00,0x80,0x00,0xc3,0x42,0xc3,0x42,0xfa,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x9e,0x51,0x9e,0x91,0x5e,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8235 0x202b */
+0xaa,0x00,0x80,0x00,0xf2,0x4a,0xf2,0x52,0xcb,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x1e,0x11,0x1e,0x11,0xde,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8236 0x202c "‬" */
+0xaa,0x00,0x80,0x00,0xf3,0x4a,0xf2,0x42,0xc3,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x9e,0x51,0x5e,0x51,0x90,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8237 0x202d */
+0xaa,0x00,0x80,0x00,0xc3,0x42,0xc3,0x42,0xfa,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x8c,0x53,0x92,0x93,0x4c,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8238 0x202e */
+0xaa,0x00,0x80,0x00,0xf2,0x4a,0xf2,0x52,0xcb,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x0c,0x13,0x12,0x13,0xcc,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8239 0x202f " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8240 0x2030 "‰" */
+0x00,0x00,0x00,0x00,0x42,0xa4,0xa4,0x48,0x10,0x10,0x2a,0x55,0x55,0x8a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8241 0x2031 "‱" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0xa0,0x4c,0x30,0xc0,0x2a,0x55,0x55,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8242 0x2032 "′" */
+0x00,0x00,0x00,0x00,0x0c,0x18,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8243 0x2033 "″" */
+0x00,0x00,0x00,0x00,0x33,0x66,0x44,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8244 0x2034 "‴" */
+0x00,0x00,0x00,0x00,0x3f,0x7e,0x54,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8245 0x2035 "‵" */
+0x00,0x00,0x00,0x00,0x30,0x18,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8246 0x2036 "‶" */
+0x00,0x00,0x00,0x00,0xcc,0x66,0x22,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8247 0x2037 "‷" */
+0x00,0x00,0x00,0x00,0xfc,0x7e,0x2a,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8248 0x2038 "‸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8249 0x2039 "‹" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x08,0x08,0x10,0x08,0x08,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8250 0x203a "›" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x10,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8251 0x203b "※" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x22,0x14,0x49,0x14,0x22,0x49,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8252 0x203c "‼" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8253 0x203d "‽" */
+0x00,0x00,0x00,0x00,0x3c,0x4a,0x4a,0x0a,0x0c,0x08,0x08,0x00,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8254 0x203e "‾" */
+0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8255 0x203f "‿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8256 0x2040 "⁀" */
+0x3c,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8257 0x2041 "⁁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x28,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8258 0x2042 "⁂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x08,0x00,0x22,0x77,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8259 0x2043 "⁃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8260 0x2044 "⁄" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8261 0x2045 "⁅" */
+0x00,0x00,0x00,0x0e,0x08,0x08,0x08,0x08,0x0e,0x08,0x08,0x08,0x08,0x08,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8262 0x2046 "⁆" */
+0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x70,0x10,0x10,0x10,0x10,0x10,0x70,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8263 0x2047 "⁇" */
+0x00,0x00,0x00,0xee,0x11,0x11,0x22,0xcc,0x88,0x88,0x88,0x00,0x00,0x88,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8264 0x2048 "⁈" */
+0x00,0x00,0x00,0x72,0x0a,0x0a,0x12,0x62,0x42,0x42,0x42,0x00,0x00,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8265 0x2049 "⁉" */
+0x00,0x00,0x00,0x5c,0x42,0x42,0x44,0x58,0x50,0x50,0x50,0x00,0x00,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8266 0x204a "⁊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8267 0x204b "⁋" */
+0x00,0x00,0x00,0x00,0xfc,0x5e,0x5e,0x5e,0x5c,0x50,0x50,0x50,0x50,0x50,0x50,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8268 0x204c "⁌" */
+0x00,0x00,0x00,0x00,0x1e,0x3a,0x3a,0x3a,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8269 0x204d "⁍" */
+0x00,0x00,0x00,0x00,0x78,0x5c,0x5c,0x5c,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8270 0x204e "⁎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x49,0x2a,0x1c,0x2a,0x49,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8271 0x204f "⁏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x10,0x10,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8272 0x2050 "⁐" */
+0x00,0x00,0x00,0x3c,0x42,0x42,0x00,0x00,0x00,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8273 0x2051 "⁑" */
+0x00,0x08,0x49,0x2a,0x1c,0x2a,0x49,0x08,0x00,0x08,0x49,0x2a,0x1c,0x2a,0x49,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8274 0x2052 "⁒" */
+0x00,0x00,0x00,0x00,0x62,0x62,0x04,0x08,0x08,0x10,0x10,0x20,0x46,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8275 0x2053 "⁓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0x8e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8276 0x2054 "⁔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8277 0x2055 "⁕" */
+0x00,0x00,0x00,0x00,0x92,0x54,0x38,0xfe,0x38,0x54,0x92,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8278 0x2056 "⁖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x60,0x60,0x00,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8279 0x2057 "⁗" */
+0x00,0x00,0x00,0x00,0x33,0x66,0x44,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x33,0x66,0x44,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8280 0x2058 "⁘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x66,0x66,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8281 0x2059 "⁙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x18,0x18,0x00,0x66,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8282 0x205a "⁚" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8283 0x205b "⁛" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x18,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8284 0x205c "⁜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x10,0x7c,0x10,0x54,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8285 0x205d "⁝" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8286 0x205e "⁞" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x10,0x00,0x00,0x10,0x00,0x00,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8287 0x205f " " */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8288 0x2060 "⁠" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0xa2,0x22,0xaa,0x36,0xa2,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x08,0x09,0x08,0x89,0x70,0x01,0x00,0x01,0x00,0x55,
+/* 8289 0x2061 "⁡" */
+0xaa,0x00,0x8c,0x10,0x90,0x10,0x91,0x11,0x91,0x7d,0x91,0x11,0x90,0x60,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x88,0x89,0x04,0x05,0x04,0x05,0x04,0x05,0x88,0x89,0x00,0x55,
+/* 8290 0x2062 "⁢" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0x80,0x04,0x82,0x01,0x82,0x04,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x00,0x21,0x40,0x81,0x40,0x21,0x00,0x01,0x00,0x55,
+/* 8291 0x2063 "⁣" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x80,0x18,0x88,0x08,0x90,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8292 0x2064 "⁤" */
+0xaa,0x00,0x80,0x00,0x80,0x01,0x81,0x01,0x8f,0x01,0x81,0x01,0x81,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x00,0x01,0xe0,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8293 0x2065 "⁥" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8294 0x2066 */
+0xaa,0x00,0x80,0x00,0xa3,0x22,0xa3,0x22,0xba,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x9c,0x49,0x88,0x89,0x5c,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8295 0x2067 */
+0xaa,0x00,0x80,0x00,0xb9,0x25,0xb9,0x29,0xa5,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x1c,0x09,0x08,0x09,0xdc,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8296 0x2068 */
+0xaa,0x00,0x80,0x00,0xb9,0x22,0xb9,0x20,0xa3,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0xdc,0x09,0x88,0x49,0x9c,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8297 0x2069 "⁩" */
+0xaa,0x00,0x80,0x00,0xf3,0x4a,0xf2,0x42,0xc3,0x00,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x9c,0x49,0x48,0x49,0x9c,0x01,0x00,0x01,0x00,0x01,0x00,0x55,
+/* 8298 0x206a "⁪" */
+0xaa,0x00,0x80,0x07,0x81,0x01,0x81,0x07,0x80,0x1e,0xa0,0x1c,0x82,0x3c,0x80,0x55,
+0xaa,0x01,0x00,0xc1,0x00,0x01,0x00,0xc1,0x00,0x79,0x80,0x71,0x08,0xf1,0x00,0x55,
+/* 8299 0x206b "⁫" */
+0xaa,0x00,0x80,0x03,0x84,0x07,0x84,0x04,0x80,0x1e,0xa0,0x1c,0x82,0x3c,0x80,0x55,
+0xaa,0x01,0x00,0x81,0x40,0xc1,0x40,0x41,0x00,0x79,0x80,0x71,0x08,0xf1,0x00,0x55,
+/* 8300 0x206c "⁬" */
+0xaa,0x00,0x80,0x03,0x80,0x00,0x80,0x03,0x80,0x39,0xc5,0x7d,0xc5,0x45,0x80,0x55,
+0xaa,0x01,0x00,0xe1,0x80,0x81,0x80,0xe1,0x00,0xf6,0x08,0xe7,0x01,0x0f,0x00,0x55,
+/* 8301 0x206d "⁭" */
+0xaa,0x00,0x80,0x01,0x82,0x03,0x82,0x02,0x80,0x39,0xc5,0x7d,0xc5,0x45,0x80,0x55,
+0xaa,0x01,0x00,0xc1,0x20,0xe1,0x20,0x21,0x00,0xf6,0x08,0xe7,0x01,0x0f,0x00,0x55,
+/* 8302 0x206e "⁮" */
+0xaa,0x00,0x80,0x22,0xb2,0x2a,0xa6,0x22,0x80,0x3c,0xa2,0x22,0xa2,0x3c,0x80,0x55,
+0xaa,0x01,0x00,0x71,0x88,0xf9,0x88,0x89,0x00,0x79,0x80,0x71,0x08,0xf1,0x00,0x55,
+/* 8303 0x206f "⁯" */
+0xaa,0x00,0x80,0x22,0xb2,0x2a,0xa6,0x22,0x80,0x3c,0xa2,0x22,0xa2,0x3c,0x80,0x55,
+0xaa,0x01,0x00,0x71,0x88,0x89,0x88,0x71,0x00,0x79,0x80,0x71,0x08,0xf1,0x00,0x55,
+/* 8304 0x2070 "⁰" */
+0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x42,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8305 0x2071 "ⁱ" */
+0x00,0x00,0x00,0x10,0x00,0x30,0x10,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8306 0x2072 "⁲" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 8307 0x2073 "⁳" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 8308 0x2074 "⁴" */
+0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x7e,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8309 0x2075 "⁵" */
+0x00,0x00,0x00,0x7c,0x40,0x40,0x78,0x04,0x04,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8310 0x2076 "⁶" */
+0x00,0x00,0x00,0x18,0x20,0x40,0x78,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8311 0x2077 "⁷" */
+0x00,0x00,0x00,0x7c,0x04,0x08,0x08,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8312 0x2078 "⁸" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x38,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8313 0x2079 "⁹" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x3c,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8314 0x207a "⁺" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8315 0x207b "⁻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8316 0x207c "⁼" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8317 0x207d "⁽" */
+0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8318 0x207e "⁾" */
+0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8319 0x207f "ⁿ" */
+0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8320 0x2080 "₀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x42,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8321 0x2081 "₁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x10,0x10,0x10,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8322 0x2082 "₂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x18,0x20,0x40,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8323 0x2083 "₃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x38,0x04,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8324 0x2084 "₄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x7e,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8325 0x2085 "₅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x78,0x04,0x04,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8326 0x2086 "₆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x78,0x44,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8327 0x2087 "₇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x08,0x08,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8328 0x2088 "₈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x38,0x44,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8329 0x2089 "₉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x3c,0x04,0x08,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8330 0x208a "₊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8331 0x208b "₋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8332 0x208c "₌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8333 0x208d "₍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8334 0x208e "₎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8335 0x208f "₏" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8336 0x2090 "ₐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x3c,0x44,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8337 0x2091 "ₑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x7c,0x40,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8338 0x2092 "ₒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8339 0x2093 "ₓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x28,0x10,0x28,0x44,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8340 0x2094 "ₔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x04,0x7c,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8341 0x2095 "ₕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x58,0x64,0x44,0x44,0x44,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8342 0x2096 "ₖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x24,0x28,0x30,0x28,0x24,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8343 0x2097 "ₗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8344 0x2098 "ₘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8345 0x2099 "ₙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8346 0x209a "ₚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x64,0x58,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8347 0x209b "ₛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x38,0x04,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8348 0x209c "ₜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x10,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8349 0x209d "₝" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 8350 0x209e "₞" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8351 0x209f "₟" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8352 0x20a0 "₠" */
+0x00,0x00,0x00,0x00,0x3c,0x40,0x40,0x5e,0x50,0x50,0x3c,0x10,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8353 0x20a1 "₡" */
+0x00,0x00,0x00,0x00,0x0a,0x3e,0x4a,0x54,0x54,0x68,0x68,0x72,0x5c,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8354 0x20a2 "₢" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x40,0x56,0x58,0x50,0x50,0x32,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8355 0x20a3 "₣" */
+0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3e,0x20,0x20,0xfc,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8356 0x20a4 "₤" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x10,0x7e,0x10,0x7e,0x10,0x10,0x3e,0x61,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8357 0x20a5 "₥" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x76,0x4d,0x4d,0x49,0x49,0x59,0x69,0x69,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8358 0x20a6 "₦" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x32,0x7f,0x2a,0x7f,0x26,0x26,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8359 0x20a7 "₧" */
+0x00,0x00,0x00,0x00,0x68,0x58,0x5f,0x5c,0x6c,0x4a,0x49,0x49,0x49,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8360 0x20a8 "₨" */
+0x00,0x00,0x00,0x00,0x70,0x48,0x4b,0x4c,0x74,0x54,0x52,0x49,0x49,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8361 0x20a9 "₩" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x7f,0x2a,0x7f,0x36,0x36,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8362 0x20aa "₪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xf2,0x8a,0xaa,0xaa,0xaa,0xaa,0xa2,0xbc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8363 0x20ab "₫" */
+0x00,0x00,0x00,0x02,0x0f,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8364 0x20ac "€" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x20,0x7c,0x20,0x7c,0x20,0x20,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8365 0x20ad "₭" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0xfe,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8366 0x20ae "₮" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x0e,0x38,0x0e,0x38,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8367 0x20af "₯" */
+0x00,0x00,0x00,0x00,0x70,0x48,0x48,0x48,0x48,0x4e,0x4d,0x4d,0x4e,0x74,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8368 0x20b0 "₰" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x28,0x18,0x54,0x64,0x62,0x42,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8369 0x20b1 "₱" */
+0x00,0x00,0x7c,0x42,0xff,0x42,0xff,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8370 0x20b2 "₲" */
+0x00,0x00,0x10,0x10,0x3c,0x52,0x52,0x50,0x50,0x56,0x52,0x52,0x56,0x3a,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8371 0x20b3 "₳" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0xff,0x42,0xff,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8372 0x20b4 "₴" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0xff,0x30,0xff,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8373 0x20b5 "₵" */
+0x00,0x00,0x10,0x10,0x3c,0x52,0x52,0x50,0x50,0x50,0x50,0x52,0x52,0x3c,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8374 0x20b6 "₶" */
+0x00,0x00,0x00,0x00,0x28,0x28,0x28,0x7e,0x28,0x28,0x28,0x28,0x29,0x26,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8375 0x20b7 "₷" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x20,0x18,0x04,0x52,0xaa,0xaa,0xfc,0xa8,0xa8,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8376 0x20b8 "₸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8377 0x20b9 "₹" */
+0x00,0x00,0x00,0x0f,0x01,0x00,0x0f,0x00,0x00,0x0f,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x80,0x40,0xf0,0x40,0x80,0x00,0x00,0x00,0x00,0x80,0x40,0x00,
+/* 8378 0x20ba "₺" */
+0x00,0x00,0x00,0x20,0x20,0x28,0x30,0x60,0xa8,0x30,0x62,0xa2,0x24,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8379 0x20bb "₻" */
+0x00,0x00,0x00,0x00,0x40,0xa0,0xfc,0x22,0x42,0x54,0xe8,0x40,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8380 0x20bc "₼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x54,0x54,0x54,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8381 0x20bd "₽" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x22,0x22,0x7c,0x20,0x7c,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8382 0x20be "₾" */
+0x00,0x00,0x28,0x7c,0xaa,0xaa,0xaa,0x80,0x80,0x80,0x80,0x40,0x20,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8383 0x20bf "₿" */
+0x00,0x00,0x28,0x28,0xfc,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0xfc,0x28,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8384 0x20c0 "⃀" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x42,0x42,0x3c,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8385 0x20c1 "⃁" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 8386 0x20c2 "⃂" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 8387 0x20c3 "⃃" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 8388 0x20c4 "⃄" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 8389 0x20c5 "⃅" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8390 0x20c6 "⃆" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 8391 0x20c7 "⃇" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 8392 0x20c8 "⃈" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 8393 0x20c9 "⃉" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 8394 0x20ca "⃊" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 8395 0x20cb "⃋" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 8396 0x20cc "⃌" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 8397 0x20cd "⃍" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 8398 0x20ce "⃎" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8399 0x20cf "⃏" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8400 0x20d0 "⃐" */
+0x00,0x10,0x20,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8401 0x20d1 "⃑" */
+0x00,0x08,0x04,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8402 0x20d2 "⃒" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8403 0x20d3 "⃓" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8404 0x20d4 "⃔" */
+0x00,0x4c,0x52,0x60,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8405 0x20d5 "⃕" */
+0x00,0x32,0x4a,0x06,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8406 0x20d6 "⃖" */
+0x10,0x20,0x7e,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8407 0x20d7 "⃗" */
+0x08,0x04,0x7e,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8408 0x20d8 "⃘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8409 0x20d9 "⃙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x34,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8410 0x20da "⃚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x2c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8411 0x20db "⃛" */
+0x00,0x00,0x2a,0x2a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8412 0x20dc "⃜" */
+0x00,0x00,0x55,0x55,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8413 0x20dd "⃝" */
+0x00,0x03,0x0c,0x30,0x20,0x40,0x40,0x80,0x80,0x80,0x40,0x40,0x20,0x30,0x0c,0x03,
+0x00,0x80,0x60,0x18,0x08,0x04,0x04,0x02,0x02,0x02,0x04,0x04,0x08,0x18,0x60,0x80,
+/* 8414 0x20de "⃞" */
+0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,
+0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,
+/* 8415 0x20df "⃟" */
+0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x01,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 8416 0x20e0 "⃠" */
+0x00,0x03,0x0c,0x30,0x30,0x58,0x4c,0x86,0x83,0x81,0x40,0x40,0x20,0x30,0x0c,0x03,
+0x00,0x80,0x60,0x18,0x08,0x04,0x04,0x02,0x02,0x82,0xc4,0x64,0x38,0x18,0x60,0x80,
+/* 8417 0x20e1 "⃡" */
+0x24,0x42,0xff,0x42,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8418 0x20e2 "⃢" */
+0x00,0x00,0x00,0x3f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x3f,0x7f,0x00,
+0x00,0x00,0x00,0xfc,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfc,0xfe,0x00,
+/* 8419 0x20e3 "⃣" */
+0x00,0x3f,0x60,0x5f,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x5f,0x60,0x3f,0x00,
+0x00,0xfc,0x06,0xfa,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0xfa,0x06,0xfc,0x00,
+/* 8420 0x20e4 "⃤" */
+0x00,0x01,0x01,0x03,0x02,0x04,0x04,0x08,0x08,0x18,0x10,0x10,0x20,0x20,0x3f,0x00,
+0x80,0xc0,0x40,0x60,0x20,0x10,0x10,0x08,0x08,0x0c,0x04,0x04,0x02,0x02,0xfe,0x00,
+/* 8421 0x20e5 "⃥" */
+0x00,0x00,0x20,0x20,0x20,0x10,0x10,0x10,0x10,0x10,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8422 0x20e6 "⃦" */
+0x00,0x00,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8423 0x20e7 "⃧" */
+0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+/* 8424 0x20e8 "⃨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8425 0x20e9 "⃩" */
+0x00,0xff,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8426 0x20ea "⃪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x1f,0x08,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8427 0x20eb "⃫" */
+0x00,0x00,0x0a,0x0a,0x0a,0x14,0x14,0x14,0x14,0x14,0x28,0x28,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8428 0x20ec "⃬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8429 0x20ed "⃭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8430 0x20ee "⃮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7e,0x20,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8431 0x20ef "⃯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x7e,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8432 0x20f0 "⃰" */
+0x24,0x18,0x7e,0x18,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8433 0x20f1 "⃱" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 8434 0x20f2 "⃲" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 8435 0x20f3 "⃳" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 8436 0x20f4 "⃴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 8437 0x20f5 "⃵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 8438 0x20f6 "⃶" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 8439 0x20f7 "⃷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 8440 0x20f8 "⃸" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 8441 0x20f9 "⃹" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 8442 0x20fa "⃺" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 8443 0x20fb "⃻" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 8444 0x20fc "⃼" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 8445 0x20fd "⃽" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 8446 0x20fe "⃾" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8447 0x20ff "⃿" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8448 0x2100 "℀" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x51,0x52,0x34,0x08,0x13,0x24,0x44,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8449 0x2101 "℁" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x51,0x52,0x34,0x0b,0x14,0x22,0x41,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8450 0x2102 "ℂ" */
+0x00,0x00,0x00,0x00,0x1e,0x31,0x50,0x50,0x50,0x50,0x50,0x50,0x31,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8451 0x2103 "℃" */
+0x40,0xa0,0xa0,0x40,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8452 0x2104 "℄" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x3c,0x50,0x50,0x50,0x50,0x3c,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8453 0x2105 "℅" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x41,0x42,0x34,0x08,0x16,0x29,0x49,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8454 0x2106 "℆" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x41,0x42,0x34,0x08,0x10,0x29,0x49,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8455 0x2107 "ℇ" */
+0x00,0x00,0x00,0x00,0x3e,0x42,0x40,0x40,0x38,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8456 0x2108 "℈" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x02,0x12,0x1e,0x12,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8457 0x2109 "℉" */
+0x40,0xa0,0xa0,0x40,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8458 0x210a "ℊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x3e,0x02,0x3f,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8459 0x210b "ℋ" */
+0x00,0x00,0x00,0x00,0x12,0x75,0x96,0x14,0x1c,0x34,0x54,0x94,0x94,0x63,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8460 0x210c "ℌ" */
+0x00,0x00,0x18,0xb6,0x60,0x68,0x74,0x36,0x66,0x66,0x66,0x66,0xe6,0x06,0x34,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8461 0x210d "ℍ" */
+0x00,0x00,0x00,0x00,0x71,0x51,0x51,0x51,0x5f,0x51,0x51,0x51,0x51,0x71,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8462 0x210e "ℎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x02,0x02,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x40,0x80,0x80,0xf0,0x88,0x08,0x08,0x10,0x10,0x10,0x20,0x00,0x00,
+/* 8463 0x210f "ℏ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x01,0x01,0x01,0x02,0x02,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x50,0xe0,0x80,0xf0,0x88,0x08,0x08,0x10,0x10,0x10,0x20,0x00,0x00,
+/* 8464 0x2110 "ℐ" */
+0x00,0x00,0x00,0x00,0x0c,0x14,0x24,0x04,0x04,0x06,0x0c,0x14,0x24,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8465 0x2111 "ℑ" */
+0x00,0x00,0x00,0x00,0x39,0x7f,0xc6,0x80,0x66,0x08,0x6c,0xa6,0x66,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8466 0x2112 "ℒ" */
+0x00,0x00,0x00,0x0c,0x12,0x12,0x3c,0x10,0x10,0x10,0x10,0x70,0x99,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8467 0x2113 "ℓ" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x28,0x30,0x60,0x20,0x20,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8468 0x2114 "℔" */
+0x00,0x00,0x00,0x00,0x48,0x48,0xfe,0x48,0x4a,0x4d,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8469 0x2115 "ℕ" */
+0x00,0x00,0x00,0x00,0x71,0x51,0x59,0x59,0x55,0x55,0x53,0x53,0x51,0x71,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8470 0x2116 "№" */
+0x00,0x00,0x00,0x00,0x92,0x95,0x95,0xd2,0xd0,0xb7,0xb0,0x90,0x90,0x90,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8471 0x2117 "℗" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0xb9,0xa5,0xa5,0xb9,0xa1,0xa1,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8472 0x2118 "℘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x4c,0x52,0x22,0x22,0x2a,0x54,0x50,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8473 0x2119 "ℙ" */
+0x00,0x00,0x00,0x00,0x7c,0x52,0x52,0x52,0x52,0x5c,0x50,0x50,0x50,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8474 0x211a "ℚ" */
+0x00,0x00,0x00,0x00,0x1c,0x32,0x51,0x51,0x51,0x51,0x51,0x51,0x36,0x1e,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8475 0x211b "ℛ" */
+0x00,0x00,0x00,0x40,0x2e,0x11,0x31,0x51,0x51,0x5e,0x54,0x52,0x52,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8476 0x211c "ℜ" */
+0x00,0x00,0x00,0x00,0x44,0x6e,0xb2,0x33,0x36,0x3c,0x36,0x36,0xa2,0xc3,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8477 0x211d "ℝ" */
+0x00,0x00,0x00,0x00,0x7e,0x51,0x51,0x51,0x51,0x5e,0x58,0x54,0x52,0x71,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8478 0x211e "℞" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x50,0x4a,0x44,0x4a,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8479 0x211f "℟" */
+0x00,0x00,0x38,0x08,0x7c,0x4a,0x4a,0x4a,0x7c,0x68,0x58,0x48,0x4c,0x4a,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8480 0x2120 "℠" */
+0x00,0x00,0x00,0x00,0x71,0x9b,0x55,0x31,0xd1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8481 0x2121 "℡" */
+0x00,0x00,0x00,0x00,0xfe,0x52,0x5a,0x52,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8482 0x2122 "™" */
+0x00,0x00,0x00,0x00,0xf1,0x5b,0x55,0x51,0x51,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8483 0x2123 "℣" */
+0x00,0x00,0x30,0x0c,0x85,0x89,0x4a,0x52,0x54,0x24,0x28,0x78,0x50,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8484 0x2124 "ℤ" */
+0x00,0x00,0x00,0x00,0x7e,0x0a,0x0a,0x12,0x14,0x24,0x28,0x48,0x50,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8485 0x2125 "℥" */
+0x00,0x00,0x00,0x00,0x3c,0x08,0x10,0x3e,0x04,0x08,0x18,0x04,0x02,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8486 0x2126 "Ω" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x22,0x14,0x14,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8487 0x2127 "℧" */
+0x00,0x00,0x00,0x00,0x77,0x14,0x14,0x22,0x41,0x41,0x41,0x41,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8488 0x2128 "ℨ" */
+0x00,0x00,0x00,0x00,0x3c,0x46,0x46,0x06,0x08,0x1e,0x02,0x06,0x66,0xa6,0x66,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8489 0x2129 "℩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x08,0x08,0x08,0x08,0x08,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8490 0x212a "K" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8491 0x212b "Å" */
+0x18,0x24,0x18,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8492 0x212c "ℬ" */
+0x00,0x00,0x00,0x00,0x2e,0x51,0x51,0x51,0x5e,0x51,0x51,0x51,0x51,0x2e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8493 0x212d "ℭ" */
+0x00,0x00,0x00,0x00,0x16,0x24,0x68,0x68,0x66,0x66,0x64,0x68,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8494 0x212e "℮" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x18,0x18,0x1f,0x18,0x18,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x18,0x18,0xf8,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 8495 0x212f "ℯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x48,0x70,0x40,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8496 0x2130 "ℰ" */
+0x00,0x00,0x00,0x00,0x0e,0x12,0x20,0x20,0x1c,0x20,0x40,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8497 0x2131 "ℱ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x04,0x04,0x08,0x3e,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8498 0x2132 "Ⅎ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x3e,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8499 0x2133 "ℳ" */
+0x00,0x00,0x00,0x00,0x63,0x36,0x2a,0x2a,0x2a,0x2a,0x2a,0x6a,0xaa,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8500 0x2134 "ℴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x53,0x4e,0x42,0x42,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8501 0x2135 "ℵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x46,0x22,0x14,0x28,0x64,0x72,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8502 0x2136 "ℶ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x3e,0x02,0x02,0x02,0x02,0x02,0x3f,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8503 0x2137 "ℷ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x3c,0x1e,0x02,0x02,0x02,0x0e,0x32,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8504 0x2138 "ℸ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x3e,0x1f,0x02,0x02,0x02,0x02,0x03,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8505 0x2139 "ℹ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x38,0x18,0x18,0x18,0x18,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8506 0x213a "℺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xe8,0x30,0x50,0x50,0x30,0xe0,0x00,0x00,
+/* 8507 0x213b "℻" */
+0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x72,0x45,0x48,0x4f,0x48,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x14,0x88,0x88,0x94,0xa2,0x00,0x00,
+/* 8508 0x213c "ℼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x50,0x50,0x50,0x50,0x48,0x24,0x1c,0x00,0x00,
+/* 8509 0x213d "ℽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x04,0x02,0x02,0x04,0x09,0x12,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0xa0,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 8510 0x213e "ℾ" */
+0x00,0x00,0x00,0x00,0x7f,0x55,0x53,0x51,0x50,0x50,0x50,0x50,0x50,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8511 0x213f "ℿ" */
+0x00,0x00,0x00,0x00,0x3f,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x70,0x00,0x00,
+/* 8512 0x2140 "⅀" */
+0x00,0x00,0x00,0x00,0x1f,0x12,0x09,0x04,0x02,0x02,0x04,0x09,0x12,0x14,0x1f,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x28,0x18,0x88,0x40,0x40,0x80,0x08,0x18,0x28,0xf8,0x00,
+/* 8513 0x2141 "⅁" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x72,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8514 0x2142 "⅂" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8515 0x2143 "⅃" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8516 0x2144 "⅄" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x14,0x22,0x22,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8517 0x2145 "ⅅ" */
+0x00,0x00,0x00,0x00,0x07,0x05,0x05,0x09,0x0a,0x0a,0x12,0x14,0x14,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x30,0x28,0x28,0x28,0x48,0x50,0x50,0x60,0xc0,0x00,0x00,
+/* 8518 0x2146 "ⅆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x0a,0x12,0x14,0x14,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x28,0x28,0x48,0xd0,0x50,0x90,0xa0,0xa0,0xe0,0x00,0x00,
+/* 8519 0x2147 "ⅇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x05,0x09,0x13,0x14,0x14,0x14,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xf0,0x00,0x00,0x20,0xc0,0x00,0x00,
+/* 8520 0x2148 "ⅈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x02,0x02,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x20,0x40,0x00,0xe0,0x40,0x40,0x40,0x80,0x80,0x80,0xe0,0x00,0x00,
+/* 8521 0x2149 "ⅉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,
+0x00,0x00,0x00,0x08,0x10,0x00,0x38,0x50,0x50,0x50,0xa0,0xa0,0xa0,0xa0,0xc0,0x00,
+/* 8522 0x214a "⅊" */
+0x00,0x00,0x10,0x10,0x7c,0x52,0x52,0x52,0x52,0x5c,0x10,0x10,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8523 0x214b "⅋" */
+0x00,0x00,0x00,0x00,0x4e,0x31,0x21,0x51,0x4a,0x0c,0x14,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8524 0x214c "⅌" */
+0x00,0x00,0x00,0x00,0x34,0x4d,0x25,0x05,0x1f,0x25,0x1f,0x05,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xf8,0x24,0xc4,0x08,0x00,0x00,0x00,0x00,
+/* 8525 0x214d "⅍" */
+0x00,0x00,0x00,0x00,0x42,0xa2,0xe4,0xa8,0x08,0x13,0x14,0x22,0x41,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8526 0x214e "ⅎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8527 0x214f "⅏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x2a,0x2a,0x2a,0x11,0x6e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xa8,0xa8,0xa8,0x10,0xec,0x00,0x00,
+/* 8528 0x2150 "⅐" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x1e,0x12,0x22,0x44,0x44,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8529 0x2151 "⅑" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x1e,0x1a,0x2e,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8530 0x2152 "⅒" */
+0x00,0x00,0x00,0x00,0x42,0xc2,0x44,0x48,0x50,0x22,0x55,0xb5,0x95,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8531 0x2153 "⅓" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x1c,0x12,0x24,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8532 0x2154 "⅔" */
+0x00,0x00,0x00,0x00,0x62,0x12,0x24,0x48,0x78,0x1c,0x12,0x24,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8533 0x2155 "⅕" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x1e,0x18,0x2c,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8534 0x2156 "⅖" */
+0x00,0x00,0x00,0x00,0x62,0x12,0x24,0x48,0x78,0x1e,0x18,0x2c,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8535 0x2157 "⅗" */
+0x00,0x00,0x00,0x00,0x62,0x12,0x24,0x18,0x68,0x1e,0x18,0x2c,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8536 0x2158 "⅘" */
+0x00,0x00,0x00,0x00,0x22,0x62,0xf4,0x28,0x28,0x1e,0x18,0x2c,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8537 0x2159 "⅙" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x16,0x18,0x2e,0x4a,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8538 0x215a "⅚" */
+0x00,0x00,0x00,0x00,0x72,0x42,0x64,0x18,0x68,0x16,0x18,0x2e,0x4a,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8539 0x215b "⅛" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x14,0x1a,0x24,0x4a,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8540 0x215c "⅜" */
+0x00,0x00,0x00,0x00,0x62,0x12,0x24,0x18,0x68,0x14,0x1a,0x24,0x4a,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8541 0x215d "⅝" */
+0x00,0x00,0x00,0x00,0x72,0x42,0x64,0x18,0x68,0x14,0x1a,0x24,0x4a,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8542 0x215e "⅞" */
+0x00,0x00,0x00,0x00,0x72,0x12,0x24,0x48,0x48,0x14,0x1a,0x24,0x4a,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8543 0x215f "⅟" */
+0x00,0x00,0x00,0x00,0x22,0x62,0x24,0x28,0x28,0x10,0x10,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8544 0x2160 "Ⅰ" */
+0x00,0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8545 0x2161 "Ⅱ" */
+0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8546 0x2162 "Ⅲ" */
+0x00,0x00,0x00,0x00,0x7f,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8547 0x2163 "Ⅳ" */
+0x00,0x00,0x00,0x00,0x7f,0x29,0x29,0x29,0x29,0x29,0x26,0x26,0x26,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8548 0x2164 "Ⅴ" */
+0x00,0x00,0x00,0x00,0x7f,0x22,0x22,0x22,0x14,0x14,0x14,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8549 0x2165 "Ⅵ" */
+0x00,0x00,0x00,0x00,0xff,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x32,0x32,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8550 0x2166 "Ⅶ" */
+0x00,0x00,0x00,0x00,0xff,0x55,0x55,0x55,0x55,0x25,0x25,0x25,0x25,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8551 0x2167 "Ⅷ" */
+0x00,0x00,0x00,0x00,0xff,0xb5,0xb5,0xb5,0xb5,0x55,0x55,0x55,0x55,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8552 0x2168 "Ⅸ" */
+0x00,0x00,0x00,0x00,0x7f,0x2a,0x2a,0x2a,0x24,0x24,0x2a,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8553 0x2169 "Ⅹ" */
+0x00,0x00,0x00,0x00,0x7f,0x22,0x22,0x14,0x08,0x08,0x14,0x22,0x22,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8554 0x216a "Ⅺ" */
+0x00,0x00,0x00,0x00,0x7f,0x2a,0x2a,0x2a,0x12,0x12,0x2a,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8555 0x216b "Ⅻ" */
+0x00,0x00,0x00,0x00,0x7f,0x55,0x55,0x55,0x25,0x25,0x55,0x55,0x55,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8556 0x216c "Ⅼ" */
+0x00,0x00,0x00,0x00,0x70,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8557 0x216d "Ⅽ" */
+0x00,0x00,0x00,0x00,0x1a,0x26,0x40,0x40,0x40,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8558 0x216e "Ⅾ" */
+0x00,0x00,0x00,0x00,0x78,0x24,0x22,0x22,0x22,0x22,0x22,0x22,0x24,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8559 0x216f "Ⅿ" */
+0x00,0x00,0x00,0x00,0x63,0x22,0x36,0x36,0x36,0x2a,0x2a,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8560 0x2170 "ⅰ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x08,0x18,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8561 0x2171 "ⅱ" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x00,0x24,0x6c,0x24,0x24,0x24,0x24,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8562 0x2172 "ⅲ" */
+0x00,0x00,0x00,0x00,0x2a,0x2a,0x00,0x2a,0x7e,0x2a,0x2a,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8563 0x2173 "ⅳ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x00,0x3b,0x69,0x29,0x29,0x26,0x26,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8564 0x2174 "ⅴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x22,0x22,0x22,0x14,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8565 0x2175 "ⅵ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x00,0x5a,0x4e,0x4a,0x4a,0x32,0x32,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8566 0x2176 "ⅶ" */
+0x00,0x00,0x00,0x00,0x05,0x05,0x00,0x55,0x5f,0x55,0x55,0x25,0x25,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8567 0x2177 "ⅷ" */
+0x00,0x00,0x00,0x00,0x15,0x15,0x00,0xb5,0xbf,0xb5,0x55,0x55,0x55,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8568 0x2178 "ⅸ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x00,0x2a,0x6a,0x24,0x24,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8569 0x2179 "ⅹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x22,0x14,0x08,0x14,0x22,0x77,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8570 0x217a "ⅺ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x00,0x2a,0x2e,0x12,0x12,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8571 0x217b "ⅻ" */
+0x00,0x00,0x00,0x00,0x05,0x05,0x00,0x55,0x5f,0x25,0x25,0x55,0x55,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8572 0x217c "ⅼ" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8573 0x217d "ⅽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0x26,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8574 0x217e "ⅾ" */
+0x00,0x00,0x00,0x00,0x02,0x06,0x02,0x1a,0x26,0x42,0x42,0x42,0x26,0x1b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8575 0x217f "ⅿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x74,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8576 0x2180 "ↀ" */
+0x00,0x00,0x00,0x00,0x3e,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8577 0x2181 "ↁ" */
+0x00,0x00,0x00,0x00,0x78,0x24,0x32,0x2a,0x2a,0x2a,0x2a,0x32,0x24,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8578 0x2182 "ↂ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x13,0x15,0x15,0x15,0x15,0x13,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x50,0x50,0x50,0x50,0x90,0x20,0xc0,0x00,0x00,
+/* 8579 0x2183 "Ↄ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8580 0x2184 "ↄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8581 0x2185 "ↅ" */
+0x00,0x00,0x00,0x00,0x3a,0x46,0x80,0x80,0x80,0x80,0x80,0x80,0x46,0x3a,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8582 0x2186 "ↆ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x92,0x54,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8583 0x2187 "ↇ" */
+0x00,0x00,0x00,0xf8,0x46,0x71,0x49,0x65,0x55,0x65,0x49,0x71,0x46,0xf8,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8584 0x2188 "ↈ" */
+0x00,0x00,0x00,0x0f,0x31,0x47,0x49,0x53,0x55,0x53,0x49,0x47,0x31,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x18,0xc4,0x24,0x94,0x54,0x94,0x24,0xc4,0x18,0xe0,0x00,0x00,
+/* 8585 0x2189 "↉" */
+0x00,0x00,0x00,0x00,0x22,0x52,0x54,0x58,0x28,0x1c,0x12,0x24,0x42,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8586 0x218a "↊" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x30,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8587 0x218b "↋" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x38,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8588 0x218c "↌" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 8589 0x218d "↍" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 8590 0x218e "↎" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 8591 0x218f "↏" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 8592 0x2190 "←" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8593 0x2191 "↑" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8594 0x2192 "→" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8595 0x2193 "↓" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8596 0x2194 "↔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x42,0xff,0x42,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8597 0x2195 "↕" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x08,0x08,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8598 0x2196 "↖" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x60,0x50,0x48,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8599 0x2197 "↗" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x06,0x0a,0x12,0x20,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8600 0x2198 "↘" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x12,0x0a,0x06,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8601 0x2199 "↙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x48,0x50,0x60,0x78,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8602 0x219a "↚" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x14,0x24,0x7f,0x24,0x14,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8603 0x219b "↛" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x28,0x24,0xfe,0x24,0x28,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8604 0x219c "↜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x30,0x28,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 8605 0x219d "↝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x0c,0x14,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 8606 0x219e "↞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x48,0xff,0x48,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8607 0x219f "↟" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x1c,0x2a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8608 0x21a0 "↠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x12,0xff,0x12,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8609 0x21a1 "↡" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x2a,0x1c,0x08,0x2a,0x1c,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8610 0x21a2 "↢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x22,0x7c,0x22,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8611 0x21a3 "↣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x44,0x3e,0x44,0x88,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8612 0x21a4 "↤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x22,0x7e,0x22,0x12,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8613 0x21a5 "↥" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8614 0x21a6 "↦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x44,0x7e,0x44,0x48,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8615 0x21a7 "↧" */
+0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8616 0x21a8 "↨" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x08,0x08,0x08,0x2a,0x1c,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8617 0x21a9 "↩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x11,0x21,0x7e,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8618 0x21aa "↪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x44,0x42,0x3f,0x02,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8619 0x21ab "↫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x15,0x25,0x7e,0x24,0x14,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8620 0x21ac "↬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x54,0x52,0x3f,0x12,0x14,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8621 0x21ad "↭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x5a,0xe7,0x42,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8622 0x21ae "↮" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x2c,0x4a,0xff,0x4a,0x2c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8623 0x21af "↯" */
+0x00,0x00,0x40,0x40,0x40,0x48,0x58,0x68,0x48,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8624 0x21b0 "↰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x78,0x24,0x14,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8625 0x21b1 "↱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x1e,0x24,0x28,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8626 0x21b2 "↲" */
+0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x24,0x78,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8627 0x21b3 "↳" */
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x24,0x1e,0x04,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8628 0x21b4 "↴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x15,0x0e,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8629 0x21b5 "↵" */
+0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x24,0x7c,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8630 0x21b6 "↶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0xa9,0x71,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8631 0x21b7 "↷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x95,0x8e,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8632 0x21b8 "↸" */
+0x00,0x00,0x00,0x7e,0x00,0x78,0x60,0x50,0x48,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8633 0x21b9 "↹" */
+0x00,0x00,0x00,0x50,0x60,0x7e,0x60,0x50,0x00,0x0a,0x06,0x7e,0x06,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8634 0x21ba "↺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2e,0x4c,0x4a,0x42,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8635 0x21bb "↻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0x32,0x52,0x42,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8636 0x21bc "↼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8637 0x21bd "↽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8638 0x21be "↾" */
+0x00,0x00,0x08,0x0c,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8639 0x21bf "↿" */
+0x00,0x00,0x08,0x18,0x28,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8640 0x21c0 "⇀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8641 0x21c1 "⇁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8642 0x21c2 "⇂" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0a,0x0c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8643 0x21c3 "⇃" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x18,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8644 0x21c4 "⇄" */
+0x00,0x00,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x10,0x20,0x7e,0x20,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8645 0x21c5 "⇅" */
+0x00,0x00,0x24,0x74,0xac,0x24,0x24,0x24,0x24,0x24,0x24,0x35,0x2e,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8646 0x21c6 "⇆" */
+0x00,0x00,0x00,0x10,0x20,0x7e,0x20,0x10,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8647 0x21c7 "⇇" */
+0x00,0x00,0x00,0x10,0x20,0x7e,0x20,0x10,0x00,0x10,0x20,0x7e,0x20,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8648 0x21c8 "⇈" */
+0x00,0x00,0x24,0x7e,0xa5,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8649 0x21c9 "⇉" */
+0x00,0x00,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8650 0x21ca "⇊" */
+0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa5,0x7e,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8651 0x21cb "⇋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7e,0x00,0x7e,0x04,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8652 0x21cc "⇌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x7e,0x00,0x7e,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8653 0x21cd "⇍" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x28,0x7e,0x88,0x7e,0x28,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8654 0x21ce "⇎" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x2c,0x7e,0x89,0x7e,0x2c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8655 0x21cf "⇏" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x14,0x7e,0x11,0x7e,0x14,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8656 0x21d0 "⇐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x3e,0x40,0x3e,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8657 0x21d1 "⇑" */
+0x00,0x00,0x08,0x14,0x36,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8658 0x21d2 "⇒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x7c,0x02,0x7c,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8659 0x21d3 "⇓" */
+0x00,0x00,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x36,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8660 0x21d4 "⇔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x7e,0x81,0x7e,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8661 0x21d5 "⇕" */
+0x00,0x00,0x08,0x14,0x36,0x14,0x14,0x14,0x14,0x14,0x14,0x36,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8662 0x21d6 "⇖" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x50,0x68,0x54,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8663 0x21d7 "⇗" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x0a,0x16,0x2a,0x50,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8664 0x21d8 "⇘" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x2a,0x16,0x0a,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8665 0x21d9 "⇙" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x54,0x68,0x50,0x78,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8666 0x21da "⇚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x3e,0x40,0xfe,0x40,0x3e,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8667 0x21db "⇛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x7c,0x02,0x7f,0x02,0x7c,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8668 0x21dc "⇜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x42,0xf5,0x48,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8669 0x21dd "⇝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x42,0xaf,0x12,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8670 0x21de "⇞" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x08,0x3e,0x08,0x3e,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8671 0x21df "⇟" */
+0x08,0x08,0x08,0x08,0x08,0x3e,0x08,0x3e,0x08,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8672 0x21e0 "⇠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x77,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8673 0x21e1 "⇡" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x00,0x08,0x08,0x08,0x08,0x00,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8674 0x21e2 "⇢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0xef,0x02,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8675 0x21e3 "⇣" */
+0x08,0x08,0x08,0x00,0x08,0x08,0x08,0x08,0x00,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8676 0x21e4 "⇤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x60,0x7f,0x60,0x50,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8677 0x21e5 "⇥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x06,0xfe,0x06,0x0a,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8678 0x21e6 "⇦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x5f,0x81,0x5f,0x30,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8679 0x21e7 "⇧" */
+0x00,0x00,0x08,0x14,0x22,0x77,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8680 0x21e8 "⇨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfa,0x81,0xfa,0x0c,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8681 0x21e9 "⇩" */
+0x00,0x00,0x1c,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x77,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8682 0x21ea "⇪" */
+0x00,0x00,0x08,0x14,0x22,0x77,0x14,0x14,0x14,0x1c,0x00,0x1c,0x14,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8683 0x21eb "⇫" */
+0x00,0x00,0x08,0x14,0x22,0x63,0x22,0x22,0x22,0x22,0x22,0x63,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8684 0x21ec "⇬" */
+0x00,0x00,0x08,0x14,0x3e,0x63,0x22,0x22,0x22,0x22,0x22,0x63,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8685 0x21ed "⇭" */
+0x00,0x00,0x08,0x1c,0x2a,0x6b,0x2a,0x2a,0x2a,0x2a,0x2a,0x6b,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8686 0x21ee "⇮" */
+0x00,0x08,0x14,0x2a,0x77,0x22,0x63,0x22,0x22,0x22,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8687 0x21ef "⇯" */
+0x00,0x08,0x14,0x2a,0x77,0x22,0x63,0x22,0x22,0x22,0x22,0x63,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8688 0x21f0 "⇰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x6c,0x7a,0x41,0x7a,0x6c,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8689 0x21f1 "⇱" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x5c,0x58,0x54,0x42,0x41,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8690 0x21f2 "⇲" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x41,0x21,0x15,0x0d,0x1d,0x01,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8691 0x21f3 "⇳" */
+0x00,0x00,0x08,0x14,0x36,0x14,0x14,0x14,0x14,0x14,0x14,0x36,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8692 0x21f4 "⇴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0xff,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x84,0xfe,0x84,0x08,0x00,0x00,0x00,0x00,
+/* 8693 0x21f5 "⇵" */
+0x00,0x00,0x24,0x2e,0x35,0x24,0x24,0x24,0x24,0x24,0x24,0xac,0x74,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8694 0x21f6 "⇶" */
+0x00,0x00,0x00,0x04,0x02,0xff,0x02,0x04,0x02,0xff,0x02,0x04,0x02,0xff,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8695 0x21f7 "⇷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x44,0xff,0x44,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8696 0x21f8 "⇸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x22,0xff,0x22,0x24,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8697 0x21f9 "⇹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x11,0x3f,0x11,0x09,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0xf8,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 8698 0x21fa "⇺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x21,0x7f,0x21,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xff,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 8699 0x21fb "⇻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xff,0x02,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x84,0xfe,0x84,0x88,0x00,0x00,0x00,0x00,
+/* 8700 0x21fc "⇼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x22,0x7f,0x22,0x12,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x88,0xfc,0x88,0x90,0x00,0x00,0x00,0x00,
+/* 8701 0x21fd "⇽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x60,0xbf,0x60,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8702 0x21fe "⇾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x06,0xfd,0x06,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8703 0x21ff "⇿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x18,0x2f,0x18,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x18,0xf4,0x18,0x10,0x00,0x00,0x00,0x00,
+/* 8704 0x2200 "∀" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x3e,0x22,0x22,0x14,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8705 0x2201 "∁" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x20,0x20,0x20,0x20,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8706 0x2202 "∂" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x02,0x02,0x1e,0x22,0x42,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8707 0x2203 "∃" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8708 0x2204 "∄" */
+0x00,0x00,0x04,0x04,0x7e,0x0a,0x0a,0x12,0x7e,0x12,0x22,0x22,0x22,0x7e,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8709 0x2205 "∅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0x22,0x45,0x49,0x51,0x22,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8710 0x2206 "∆" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x14,0x22,0x22,0x22,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8711 0x2207 "∇" */
+0x00,0x00,0x00,0x00,0x7f,0x41,0x22,0x22,0x22,0x14,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8712 0x2208 "∈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x7e,0x40,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8713 0x2209 "∉" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3e,0x48,0x48,0x7e,0x50,0x50,0x3e,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8714 0x220a "∊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x7e,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8715 0x220b "∋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x7e,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8716 0x220c "∌" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x7c,0x0a,0x0a,0x7e,0x12,0x12,0x7c,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8717 0x220d "∍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x7e,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8718 0x220e "∎" */
+0x00,0x00,0x00,0x00,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8719 0x220f "∏" */
+0x00,0x00,0x00,0x00,0x7f,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x77,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8720 0x2210 "∐" */
+0x00,0x00,0x00,0x00,0x77,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8721 0x2211 "∑" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x42,0x7e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8722 0x2212 "−" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8723 0x2213 "∓" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8724 0x2214 "∔" */
+0x00,0x00,0x08,0x1c,0x08,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8725 0x2215 "∕" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8726 0x2216 "∖" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8727 0x2217 "∗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x2a,0x1c,0x08,0x1c,0x2a,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8728 0x2218 "∘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8729 0x2219 "∙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8730 0x221a "√" */
+0x00,0x00,0x07,0x04,0x04,0x04,0x04,0x04,0x74,0x14,0x14,0x0c,0x0c,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8731 0x221b "∛" */
+0x00,0x00,0x67,0x14,0x64,0x14,0x64,0x04,0x74,0x14,0x14,0x0c,0x0c,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8732 0x221c "∜" */
+0x00,0x00,0x57,0x54,0x74,0x14,0x14,0x04,0x74,0x14,0x14,0x0c,0x0c,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8733 0x221d "∝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x48,0x48,0x36,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8734 0x221e "∞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x36,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8735 0x221f "∟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8736 0x2220 "∠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8737 0x2221 "∡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x14,0x08,0x14,0x24,0x7e,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8738 0x2222 "∢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x0c,0x14,0x64,0x14,0x0c,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8739 0x2223 "∣" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8740 0x2224 "∤" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x1a,0x1c,0x18,0x18,0x38,0x58,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8741 0x2225 "∥" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8742 0x2226 "∦" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x26,0x24,0x2c,0x34,0x24,0x64,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8743 0x2227 "∧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8744 0x2228 "∨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8745 0x2229 "∩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8746 0x222a "∪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8747 0x222b "∫" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8748 0x222c "∬" */
+0x00,0x0a,0x15,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x54,0x68,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8749 0x222d "∭" */
+0x00,0x15,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0xaa,0xd4,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8750 0x222e "∮" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x1c,0x2a,0x2a,0x1c,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8751 0x222f "∯" */
+0x00,0x0a,0x15,0x14,0x14,0x14,0x3e,0x55,0x55,0x3e,0x14,0x14,0x14,0x54,0x68,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8752 0x2230 "∰" */
+0x00,0x15,0x2a,0x2a,0x2a,0x7e,0xab,0xab,0xab,0x7e,0x2a,0x2a,0x2a,0xaa,0xd4,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8753 0x2231 "∱" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x1d,0x2b,0x2f,0x08,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8754 0x2232 "∲" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x1d,0x2b,0x2f,0x2a,0x1c,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8755 0x2233 "∳" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x5c,0x6a,0x7a,0x2a,0x1c,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8756 0x2234 "∴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8757 0x2235 "∵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8758 0x2236 "∶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8759 0x2237 "∷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8760 0x2238 "∸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8761 0x2239 "∹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x78,0x00,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8762 0x223a "∺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x7e,0x00,0x66,0x66,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8763 0x223b "∻" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x32,0x4c,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8764 0x223c "∼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8765 0x223d "∽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x32,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8766 0x223e "∾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x49,0x26,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8767 0x223f "∿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x49,0x09,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8768 0x2240 "≀" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x10,0x10,0x10,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8769 0x2241 "≁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x08,0x3a,0x54,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8770 0x2242 "≂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x32,0x4c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8771 0x2243 "≃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8772 0x2244 "≄" */
+0x00,0x00,0x00,0x04,0x04,0x08,0x08,0x3a,0x54,0x10,0x10,0x7e,0x20,0x20,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8773 0x2245 "≅" */
+0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8774 0x2246 "≆" */
+0x00,0x00,0x00,0x00,0x32,0x4c,0x02,0x04,0x7e,0x08,0x10,0x7e,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8775 0x2247 "≇" */
+0x00,0x00,0x04,0x04,0x3a,0x4c,0x08,0x10,0x7e,0x10,0x20,0x7e,0x20,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8776 0x2248 "≈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x32,0x4c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8777 0x2249 "≉" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3a,0x4c,0x10,0x3a,0x54,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8778 0x224a "≊" */
+0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x32,0x4c,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8779 0x224b "≋" */
+0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x32,0x4c,0x00,0x32,0x4c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8780 0x224c "≌" */
+0x00,0x00,0x00,0x00,0x4c,0x32,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8781 0x224d "≍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x3c,0x00,0x00,0x3c,0x42,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8782 0x224e "≎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x66,0x00,0x00,0x66,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8783 0x224f "≏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x66,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8784 0x2250 "≐" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8785 0x2251 "≑" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x7e,0x00,0x00,0x7e,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8786 0x2252 "≒" */
+0x00,0x00,0x00,0x60,0x60,0x00,0x7e,0x00,0x00,0x7e,0x00,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8787 0x2253 "≓" */
+0x00,0x00,0x00,0x06,0x06,0x00,0x7e,0x00,0x00,0x7e,0x00,0x60,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8788 0x2254 "≔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5e,0x00,0x00,0x5e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8789 0x2255 "≕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7a,0x00,0x00,0x7a,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8790 0x2256 "≖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8791 0x2257 "≗" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8792 0x2258 "≘" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8793 0x2259 "≙" */
+0x00,0x00,0x00,0x18,0x24,0x42,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8794 0x225a "≚" */
+0x00,0x00,0x00,0x42,0x24,0x18,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8795 0x225b "≛" */
+0x00,0x00,0x08,0x3e,0x1c,0x14,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8796 0x225c "≜" */
+0x00,0x00,0x08,0x14,0x22,0x3e,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8797 0x225d "≝" */
+0x00,0x00,0x12,0x14,0x76,0x54,0x74,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8798 0x225e "≞" */
+0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8799 0x225f "≟" */
+0x00,0x30,0x48,0x08,0x10,0x10,0x00,0x10,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8800 0x2260 "≠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x7e,0x08,0x10,0x7e,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8801 0x2261 "≡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x7e,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8802 0x2262 "≢" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x7e,0x08,0x7e,0x10,0x7e,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8803 0x2263 "≣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x7e,0x00,0x7e,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8804 0x2264 "≤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8805 0x2265 "≥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x18,0x06,0x18,0x60,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8806 0x2266 "≦" */
+0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8807 0x2267 "≧" */
+0x00,0x00,0x00,0x60,0x18,0x06,0x18,0x60,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8808 0x2268 "≨" */
+0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x04,0x7e,0x08,0x10,0x7e,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8809 0x2269 "≩" */
+0x00,0x00,0x00,0x60,0x18,0x06,0x18,0x62,0x04,0x7e,0x08,0x10,0x7e,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8810 0x226a "≪" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x12,0x24,0x48,0x90,0x48,0x24,0x12,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8811 0x226b "≫" */
+0x00,0x00,0x00,0x00,0x00,0x90,0x48,0x24,0x12,0x09,0x12,0x24,0x48,0x90,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8812 0x226c "≬" */
+0x00,0x00,0x00,0x00,0x24,0x18,0x18,0x24,0x24,0x24,0x24,0x18,0x18,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8813 0x226d "≭" */
+0x00,0x00,0x00,0x02,0x02,0x04,0x85,0x7e,0x08,0x10,0x7e,0xa1,0x20,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8814 0x226e "≮" */
+0x00,0x00,0x00,0x08,0x08,0x0c,0x18,0x10,0x30,0x50,0x30,0x30,0x18,0x24,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8815 0x226f "≯" */
+0x00,0x00,0x00,0x00,0x08,0x48,0x28,0x10,0x18,0x14,0x18,0x10,0x20,0x60,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8816 0x2270 "≰" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x0e,0x14,0x68,0x18,0x1e,0x10,0x7e,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8817 0x2271 "≱" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x70,0x18,0x16,0x28,0x70,0x20,0x7e,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8818 0x2272 "≲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x00,0x32,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8819 0x2273 "≳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x18,0x06,0x18,0x60,0x00,0x32,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8820 0x2274 "≴" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x0e,0x18,0x68,0x18,0x1e,0x10,0x3a,0x64,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8821 0x2275 "≵" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x78,0x18,0x16,0x18,0x70,0x10,0x32,0x6c,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8822 0x2276 "≶" */
+0x00,0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x60,0x18,0x06,0x18,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8823 0x2277 "≷" */
+0x00,0x00,0x00,0x00,0x60,0x18,0x06,0x18,0x60,0x06,0x18,0x60,0x18,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8824 0x2278 "≸" */
+0x00,0x00,0x02,0x02,0x0e,0x14,0x68,0x18,0x1e,0x70,0x28,0x2e,0x50,0x60,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8825 0x2279 "≹" */
+0x00,0x00,0x04,0x04,0x68,0x18,0x16,0x18,0x70,0x16,0x38,0x60,0x38,0x26,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8826 0x227a "≺" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x18,0x60,0x18,0x04,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8827 0x227b "≻" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x18,0x06,0x18,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8828 0x227c "≼" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x18,0x60,0x18,0x64,0x1a,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8829 0x227d "≽" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x18,0x06,0x18,0x26,0x58,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8830 0x227e "≾" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x18,0x60,0x18,0x04,0x66,0x9a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8831 0x227f "≿" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x18,0x06,0x18,0x20,0x59,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8832 0x2280 "⊀" */
+0x00,0x00,0x00,0x00,0x04,0x06,0x0a,0x0c,0x08,0x70,0x18,0x14,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8833 0x2281 "⊁" */
+0x00,0x00,0x00,0x00,0x04,0x44,0x48,0x28,0x18,0x0e,0x18,0x30,0x50,0x60,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8834 0x2282 "⊂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8835 0x2283 "⊃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x02,0x7c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8836 0x2284 "⊄" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x3e,0x48,0x50,0x50,0x60,0x3e,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8837 0x2285 "⊅" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x7c,0x0a,0x0a,0x12,0x12,0x7c,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8838 0x2286 "⊆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8839 0x2287 "⊇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x02,0x7c,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8840 0x2288 "⊈" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x3e,0x48,0x48,0x50,0x50,0x3e,0x20,0x7e,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8841 0x2289 "⊉" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x7c,0x0a,0x0a,0x12,0x12,0x7c,0x20,0x7e,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8842 0x228a "⊊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x04,0x7e,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8843 0x228b "⊋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x02,0x7c,0x08,0x7e,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8844 0x228c "⊌" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x4a,0x52,0x7e,0x52,0x4a,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8845 0x228d "⊍" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x5a,0x5a,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8846 0x228e "⊎" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x52,0x52,0x7a,0x52,0x52,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8847 0x228f "⊏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8848 0x2290 "⊐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8849 0x2291 "⊑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8850 0x2292 "⊒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x7e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8851 0x2293 "⊓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8852 0x2294 "⊔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8853 0x2295 "⊕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x2a,0x49,0x7f,0x49,0x2a,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8854 0x2296 "⊖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x7f,0x41,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8855 0x2297 "⊗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x55,0x49,0x55,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8856 0x2298 "⊘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x45,0x49,0x51,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8857 0x2299 "⊙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x49,0x41,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8858 0x229a "⊚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x55,0x49,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8859 0x229b "⊛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x5d,0x49,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8860 0x229c "⊜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x5d,0x41,0x5d,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8861 0x229d "⊝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x5d,0x41,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8862 0x229e "⊞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8863 0x229f "⊟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8864 0x22a0 "⊠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x63,0x55,0x49,0x55,0x63,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8865 0x22a1 "⊡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x41,0x49,0x41,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8866 0x22a2 "⊢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8867 0x22a3 "⊣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8868 0x22a4 "⊤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8869 0x22a5 "⊥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8870 0x22a6 "⊦" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8871 0x22a7 "⊧" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x3c,0x20,0x3c,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8872 0x22a8 "⊨" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7e,0x40,0x7e,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8873 0x22a9 "⊩" */
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x5e,0x50,0x50,0x50,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8874 0x22aa "⊪" */
+0x00,0x00,0x00,0x00,0x00,0x54,0x54,0x54,0x54,0x57,0x54,0x54,0x54,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8875 0x22ab "⊫" */
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x5e,0x50,0x5e,0x50,0x50,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8876 0x22ac "⊬" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x48,0x48,0x7e,0x48,0x48,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8877 0x22ad "⊭" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x48,0x48,0x7e,0x48,0x7e,0x48,0x48,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8878 0x22ae "⊮" */
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x54,0x54,0x5e,0x54,0x54,0x50,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8879 0x22af "⊯" */
+0x00,0x00,0x00,0x00,0x00,0x50,0x54,0x54,0x5e,0x54,0x5e,0x54,0x54,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8880 0x22b0 "⊰" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x04,0x18,0x60,0x18,0x04,0x02,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8881 0x22b1 "⊱" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x20,0x18,0x06,0x18,0x20,0x40,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8882 0x22b2 "⊲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1a,0x62,0x1a,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8883 0x22b3 "⊳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x58,0x46,0x58,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8884 0x22b4 "⊴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1a,0x62,0x1a,0x06,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8885 0x22b5 "⊵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x58,0x46,0x58,0x60,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8886 0x22b6 "⊶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x4f,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x1e,0xfe,0x1e,0x0c,0x00,0x00,0x00,0x00,
+/* 8887 0x22b7 "⊷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x78,0x7f,0x78,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0xf2,0x12,0x0c,0x00,0x00,0x00,0x00,
+/* 8888 0x22b8 "⊸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x00,0x00,0x00,
+/* 8889 0x22b9 "⊹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x63,0x00,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8890 0x22ba "⊺" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8891 0x22bb "⊻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x14,0x14,0x08,0x00,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8892 0x22bc "⊼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x00,0x08,0x14,0x14,0x22,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8893 0x22bd "⊽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x00,0x22,0x22,0x14,0x14,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8894 0x22be "⊾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x78,0x48,0x48,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8895 0x22bf "⊿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x12,0x22,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8896 0x22c0 "⋀" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x14,0x22,0x22,0x22,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8897 0x22c1 "⋁" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x22,0x22,0x22,0x14,0x14,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8898 0x22c2 "⋂" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8899 0x22c3 "⋃" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8900 0x22c4 "⋄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8901 0x22c5 "⋅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8902 0x22c6 "⋆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x3e,0x1c,0x14,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8903 0x22c7 "⋇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x42,0x24,0x7e,0x24,0x42,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8904 0x22c8 "⋈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x63,0x55,0x49,0x55,0x63,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8905 0x22c9 "⋉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x62,0x54,0x48,0x54,0x62,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8906 0x22ca "⋊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x23,0x15,0x09,0x15,0x23,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8907 0x22cb "⋋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x14,0x22,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8908 0x22cc "⋌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x14,0x22,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8909 0x22cd "⋍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x32,0x00,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8910 0x22ce "⋎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x22,0x22,0x14,0x14,0x14,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8911 0x22cf "⋏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x14,0x22,0x22,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8912 0x22d0 "⋐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x4e,0x50,0x50,0x4e,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8913 0x22d1 "⋑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x72,0x0a,0x0a,0x72,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8914 0x22d2 "⋒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x49,0x55,0x55,0x55,0x55,0x55,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8915 0x22d3 "⋓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x55,0x55,0x55,0x55,0x49,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8916 0x22d4 "⋔" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x1c,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8917 0x22d5 "⋕" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x7e,0x24,0x24,0x7e,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8918 0x22d6 "⋖" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x22,0x10,0x08,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8919 0x22d7 "⋗" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x44,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8920 0x22d8 "⋘" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x11,0x22,0x11,0x08,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x22,0x44,0x88,0x10,0x20,0x10,0x88,0x44,0x22,0x00,0x00,
+/* 8921 0x22d9 "⋙" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x22,0x11,0x08,0x04,0x08,0x11,0x22,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x88,0x44,0x88,0x10,0x20,0x40,0x00,0x00,
+/* 8922 0x22da "⋚" */
+0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x00,0x7e,0x00,0x60,0x18,0x06,0x18,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8923 0x22db "⋛" */
+0x00,0x00,0x60,0x18,0x06,0x18,0x60,0x00,0x7e,0x00,0x06,0x18,0x60,0x18,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8924 0x22dc "⋜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x06,0x18,0x60,0x18,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8925 0x22dd "⋝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x60,0x18,0x06,0x18,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8926 0x22de "⋞" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x1a,0x64,0x18,0x60,0x18,0x04,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8927 0x22df "⋟" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x58,0x26,0x18,0x06,0x18,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8928 0x22e0 "⋠" */
+0x00,0x00,0x00,0x04,0x14,0x16,0x2a,0xcc,0x18,0x68,0x18,0x14,0x12,0x22,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8929 0x22e1 "⋡" */
+0x00,0x00,0x00,0x02,0x0a,0x4a,0x44,0x2b,0x18,0x16,0x18,0x30,0x60,0x60,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8930 0x22e2 "⋢" */
+0x00,0x00,0x00,0x02,0x02,0x04,0x7e,0x48,0x48,0x50,0x50,0x7e,0x20,0x7e,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8931 0x22e3 "⋣" */
+0x00,0x00,0x00,0x02,0x02,0x04,0x7e,0x0a,0x0a,0x12,0x12,0x7e,0x20,0x7e,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8932 0x22e4 "⋤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x7e,0x08,0x7e,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8933 0x22e5 "⋥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x7e,0x08,0x7e,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8934 0x22e6 "⋦" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x04,0x3a,0x5c,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8935 0x22e7 "⋧" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x18,0x06,0x18,0x62,0x04,0x3a,0x5c,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8936 0x22e8 "⋨" */
+0x00,0x00,0x00,0x02,0x02,0x04,0x18,0x60,0x18,0x04,0x06,0x3a,0x5c,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8937 0x22e9 "⋩" */
+0x00,0x00,0x40,0x40,0x20,0x18,0x06,0x18,0x20,0x42,0x44,0x3a,0x5c,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8938 0x22ea "⋪" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x0e,0x16,0x6a,0x1a,0x1e,0x10,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8939 0x22eb "⋫" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x68,0x5c,0x56,0x68,0x70,0x20,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8940 0x22ec "⋬" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x0e,0x16,0x6a,0x1a,0x1e,0x10,0x7e,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8941 0x22ed "⋭" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x68,0x5c,0x56,0x68,0x70,0x20,0x7e,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8942 0x22ee "⋮" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8943 0x22ef "⋯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdb,0xdb,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8944 0x22f0 "⋰" */
+0x00,0x00,0x00,0x00,0x03,0x03,0x00,0x00,0x18,0x18,0x00,0x00,0xc0,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8945 0x22f1 "⋱" */
+0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x18,0x18,0x00,0x00,0x03,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8946 0x22f2 "⋲" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x7f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 8947 0x22f3 "⋳" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x1f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x10,0xf0,0x10,0x00,0x00,0xf0,0x00,0x00,
+/* 8948 0x22f4 "⋴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x42,0x7e,0x42,0x40,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8949 0x22f5 "⋵" */
+0x00,0x00,0x01,0x01,0x00,0x07,0x08,0x10,0x10,0x1f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 8950 0x22f6 "⋶" */
+0x00,0x00,0x00,0x1f,0x00,0x07,0x08,0x10,0x10,0x1f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 8951 0x22f7 "⋷" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x3e,0x40,0x40,0x7e,0x40,0x40,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8952 0x22f8 "⋸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x7e,0x40,0x40,0x3e,0x00,0x7e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8953 0x22f9 "⋹" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x7f,0x40,0x7f,0x40,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0xc0,0x00,0xc0,0x00,0x00,0xc0,0x00,0x00,
+/* 8954 0x22fa "⋺" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xf8,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 8955 0x22fb "⋻" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x20,0x3f,0x20,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xe0,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 8956 0x22fc "⋼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x42,0x7e,0x42,0x02,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8957 0x22fd "⋽" */
+0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x80,0x40,0x20,0x20,0xe0,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 8958 0x22fe "⋾" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x7c,0x02,0x02,0x7e,0x02,0x02,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8959 0x22ff "⋿" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 8960 0x2300 "⌀" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x11,0x12,0x14,0x08,0x17,0x20,0x00,
+0x00,0x00,0x00,0x00,0x08,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 8961 0x2301 "⌁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x58,0x34,0x12,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8962 0x2302 "⌂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8963 0x2303 "⌃" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8964 0x2304 "⌄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8965 0x2305 "⌅" */
+0x00,0x00,0x00,0x00,0x3e,0x00,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8966 0x2306 "⌆" */
+0x00,0x00,0x00,0x00,0x3e,0x00,0x3e,0x00,0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8967 0x2307 "⌇" */
+0x00,0x00,0x00,0x10,0x08,0x04,0x08,0x10,0x08,0x04,0x08,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8968 0x2308 "⌈" */
+0x00,0x00,0x1e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8969 0x2309 "⌉" */
+0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8970 0x230a "⌊" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8971 0x230b "⌋" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8972 0x230c "⌌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8973 0x230d "⌍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8974 0x230e "⌎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8975 0x230f "⌏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8976 0x2310 "⌐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8977 0x2311 "⌑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x3e,0x22,0x22,0x22,0x3e,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8978 0x2312 "⌒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8979 0x2313 "⌓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8980 0x2314 "⌔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8981 0x2315 "⌕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x5c,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8982 0x2316 "⌖" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x7e,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x80,0x80,0xe0,0x90,0x88,0x84,0x04,0x3f,0x04,0x84,0x88,0x90,0xe0,0x80,0x80,
+/* 8983 0x2317 "⌗" */
+0x00,0x00,0x00,0x00,0x00,0x24,0x24,0xff,0x24,0x24,0xff,0x24,0x24,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8984 0x2318 "⌘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x55,0x3e,0x14,0x3e,0x55,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8985 0x2319 "⌙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8986 0x231a "⌚" */
+0x00,0x00,0x28,0x28,0x28,0x28,0x38,0x54,0x92,0x9b,0x82,0x44,0x38,0x28,0x28,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8987 0x231b "⌛" */
+0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x24,0x18,0x18,0x24,0x24,0x3c,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8988 0x231c "⌜" */
+0x00,0x78,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8989 0x231d "⌝" */
+0x00,0x1e,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8990 0x231e "⌞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8991 0x231f "⌟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8992 0x2320 "⌠" */
+0x00,0x00,0x00,0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8993 0x2321 "⌡" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8994 0x2322 "⌢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8995 0x2323 "⌣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8996 0x2324 "⌤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x08,0x14,0x22,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8997 0x2325 "⌥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8998 0x2326 "⌦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xaa,0x91,0xaa,0xfc,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 8999 0x2327 "⌧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x55,0x49,0x55,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9000 0x2328 "⌨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x7e,0x7e,0x00,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9001 0x2329 "〈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,0x40,0x20,0x20,0x10,0x10,0x08,0x08,
+/* 9002 0x232a "〉" */
+0x00,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,0x04,0x08,0x08,0x10,0x10,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9003 0x232b "⌫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x55,0x89,0x55,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9004 0x232c "⌬" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x0a,0x0a,0x0a,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x90,0x48,0x28,0x08,0x28,0x48,0x90,0x20,0x40,0x80,0x00,
+/* 9005 0x232d "⌭" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x04,0x0c,0x12,0x11,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x81,0x02,0xc4,0x24,0x18,0x10,0x10,0x20,0xc0,0x40,0x80,0x00,
+/* 9006 0x232e "⌮" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x11,0x12,0x0a,0x04,0x2b,0x30,0x38,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0xfe,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 9007 0x232f "⌯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x7f,0x00,0x00,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xfe,0x00,0x00,0xf0,0x00,0x00,0x00,
+/* 9008 0x2330 "⌰" */
+0x00,0x04,0x0c,0x1e,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0xff,0x00,0x00,
+0x00,0x02,0x06,0x0f,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0xc0,0x00,0x00,
+/* 9009 0x2331 "⌱" */
+0x00,0x00,0x00,0x1f,0x24,0x44,0x84,0x84,0x87,0x84,0x84,0x44,0x24,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x24,0xff,0x24,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 9010 0x2332 "⌲" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x23,0x20,0x20,0x7f,0x20,0x20,0x23,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x70,0x0c,0xfe,0x0c,0x70,0x80,0x00,0x00,0x00,
+/* 9011 0x2333 "⌳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x5c,0x43,0x40,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x70,0x0c,0xfe,0x00,0x00,
+/* 9012 0x2334 "⌴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,
+/* 9013 0x2335 "⌵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 9014 0x2336 "⌶" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9015 0x2337 "⌷" */
+0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9016 0x2338 "⌸" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9017 0x2339 "⌹" */
+0x00,0x00,0x00,0x7f,0x41,0x49,0x49,0x41,0x7f,0x41,0x49,0x49,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9018 0x233a "⌺" */
+0x00,0x00,0x00,0x7f,0x41,0x49,0x55,0x63,0x41,0x63,0x55,0x49,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9019 0x233b "⌻" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x49,0x55,0x55,0x49,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9020 0x233c "⌼" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x5d,0x63,0x41,0x41,0x63,0x5d,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9021 0x233d "⌽" */
+0x00,0x00,0x00,0x08,0x08,0x1c,0x2a,0x49,0x49,0x49,0x2a,0x1c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9022 0x233e "⌾" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x55,0x49,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9023 0x233f "⌿" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x08,0x08,0xff,0x10,0x20,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9024 0x2340 "⍀" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x10,0x10,0xff,0x08,0x04,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9025 0x2341 "⍁" */
+0x00,0x00,0x00,0x7f,0x41,0x43,0x45,0x45,0x49,0x51,0x51,0x61,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9026 0x2342 "⍂" */
+0x00,0x00,0x00,0x7f,0x41,0x61,0x51,0x51,0x49,0x45,0x45,0x43,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9027 0x2343 "⍃" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x47,0x59,0x61,0x59,0x47,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9028 0x2344 "⍄" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x71,0x4d,0x43,0x4d,0x71,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9029 0x2345 "⍅" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x28,0x7f,0x28,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9030 0x2346 "⍆" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x0a,0x7f,0x0a,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9031 0x2347 "⍇" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x49,0x51,0x7f,0x51,0x49,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9032 0x2348 "⍈" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x49,0x45,0x7f,0x45,0x49,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9033 0x2349 "⍉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x22,0x51,0x49,0x45,0x22,0x1d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9034 0x234a "⍊" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9035 0x234b "⍋" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x1c,0x1c,0x2a,0x2a,0x3e,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9036 0x234c "⍌" */
+0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x63,0x63,0x55,0x55,0x49,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9037 0x234d "⍍" */
+0x00,0x00,0x7f,0x41,0x41,0x49,0x49,0x55,0x55,0x63,0x63,0x7f,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9038 0x234e "⍎" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x1c,0x2a,0x2a,0x1c,0x08,0x08,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9039 0x234f "⍏" */
+0x00,0x00,0x00,0x00,0x08,0x1c,0x2a,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9040 0x2350 "⍐" */
+0x00,0x00,0x7f,0x49,0x5d,0x6b,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9041 0x2351 "⍑" */
+0x00,0x00,0x00,0x00,0x3e,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9042 0x2352 "⍒" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x3e,0x2a,0x2a,0x1c,0x1c,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9043 0x2353 "⍓" */
+0x00,0x00,0x7f,0x41,0x49,0x55,0x55,0x63,0x63,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9044 0x2354 "⍔" */
+0x00,0x00,0x7f,0x41,0x41,0x7f,0x63,0x63,0x55,0x55,0x49,0x49,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9045 0x2355 "⍕" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x1c,0x2a,0x2a,0x1c,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9046 0x2356 "⍖" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9047 0x2357 "⍗" */
+0x00,0x00,0x7f,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x6b,0x5d,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9048 0x2358 "⍘" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9049 0x2359 "⍙" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x3e,0x00,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9050 0x235a "⍚" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x41,0x22,0x14,0x08,0x00,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9051 0x235b "⍛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9052 0x235c "⍜" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9053 0x235d "⍝" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x55,0x49,0x41,0x41,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9054 0x235e "⍞" */
+0x00,0x00,0x7f,0x41,0x49,0x49,0x49,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9055 0x235f "⍟" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x7f,0x5d,0x55,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9056 0x2360 "⍠" */
+0x00,0x00,0x7f,0x41,0x41,0x49,0x49,0x41,0x41,0x49,0x49,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9057 0x2361 "⍡" */
+0x00,0x24,0x24,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9058 0x2362 "⍢" */
+0x00,0x24,0x24,0x00,0x00,0x3e,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9059 0x2363 "⍣" */
+0x00,0x24,0x24,0x00,0x00,0x08,0x3e,0x1c,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9060 0x2364 "⍤" */
+0x00,0x24,0x24,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9061 0x2365 "⍥" */
+0x00,0x24,0x24,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9062 0x2366 "⍦" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9063 0x2367 "⍧" */
+0x00,0x00,0x00,0x08,0x08,0x1f,0x28,0x48,0x48,0x48,0x28,0x1f,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9064 0x2368 "⍨" */
+0x00,0x24,0x24,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9065 0x2369 "⍩" */
+0x00,0x24,0x24,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9066 0x236a "⍪" */
+0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9067 0x236b "⍫" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x14,0x14,0x39,0x4e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9068 0x236c "⍬" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x33,0x6e,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9069 0x236d "⍭" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x3a,0x4c,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9070 0x236e "⍮" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9071 0x236f "⍯" */
+0x00,0x00,0x7f,0x41,0x43,0x45,0x7f,0x49,0x7f,0x51,0x61,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9072 0x2370 "⍰" */
+0x00,0x00,0x7f,0x41,0x49,0x55,0x55,0x45,0x49,0x49,0x41,0x49,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9073 0x2371 "⍱" */
+0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x22,0x22,0x14,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9074 0x2372 "⍲" */
+0x00,0x00,0x00,0x00,0x00,0x32,0x4c,0x00,0x08,0x14,0x14,0x22,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9075 0x2373 "⍳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9076 0x2374 "⍴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9077 0x2375 "⍵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x22,0x49,0x49,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9078 0x2376 "⍶" */
+0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x44,0x44,0x44,0x4a,0x32,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9079 0x2377 "⍷" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x7c,0x40,0x40,0x3e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9080 0x2378 "⍸" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x06,0x00,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9081 0x2379 "⍹" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x41,0x49,0x49,0x49,0x49,0x36,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9082 0x237a "⍺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x44,0x44,0x44,0x44,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9083 0x237b "⍻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x41,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x02,0x04,0x08,0x10,0xfc,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9084 0x237c "⍼" */
+0x00,0x00,0x0a,0x0c,0x08,0x18,0x28,0x18,0x08,0x0c,0x0a,0x0c,0x4f,0x50,0x60,0x78,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 9085 0x237d "⍽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x20,0x20,0xe0,0x00,0x00,
+/* 9086 0x237e "⍾" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x1f,0x04,0x04,0x04,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0xf8,0x20,0x20,0x20,0x38,0x00,0x00,
+/* 9087 0x237f "⍿" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x1c,0x3e,0x1c,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9088 0x2380 "⎀" */
+0x00,0x00,0x00,0x38,0x04,0x3c,0x44,0x44,0x3a,0x00,0x82,0x44,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9089 0x2381 "⎁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x3c,0x44,0x44,0x3a,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x00,0xfc,0x00,0x00,
+/* 9090 0x2382 "⎂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x3c,0x44,0x44,0x3a,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x08,0x78,0x88,0x88,0x74,0x00,0xfc,0x00,0x00,
+/* 9091 0x2383 "⎃" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x13,0x00,0x73,0x04,0x14,0x23,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x90,0x40,0xdc,0x40,0x50,0xa8,0x04,0x00,0x00,0x00,
+/* 9092 0x2384 "⎄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x21,0x22,0x22,0x22,0x22,0x21,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x08,0xf0,0x00,0x00,
+/* 9093 0x2385 "⎅" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x1d,0x11,0x11,0x11,0x11,0x11,0x11,0x1d,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x00,0x00,
+/* 9094 0x2386 "⎆" */
+0x00,0x01,0x02,0x04,0x08,0x12,0x03,0x7e,0x40,0x7e,0x03,0x12,0x08,0x04,0x02,0x01,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x84,0x42,0x84,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 9095 0x2387 "⎇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x30,0xe8,0x30,0x20,0x00,0xfe,0x00,0x00,
+/* 9096 0x2388 "⎈" */
+0x00,0x01,0x01,0x23,0x1d,0x19,0x15,0x23,0x23,0x15,0x19,0x1d,0x23,0x01,0x01,0x00,
+0x00,0x00,0x00,0x88,0x70,0x30,0x50,0x88,0x88,0x50,0x30,0x70,0x88,0x00,0x00,0x00,
+/* 9097 0x2389 "⎉" */
+0x00,0x00,0x0f,0x30,0x40,0x40,0x80,0x80,0xf0,0x88,0x88,0x45,0x45,0x32,0x0f,0x00,
+0x00,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x78,0x88,0x88,0x10,0x10,0x60,0x80,0x00,
+/* 9098 0x238a "⎊" */
+0x00,0x00,0x0f,0x30,0x40,0x7f,0xa0,0x90,0x90,0x88,0x88,0x45,0x45,0x32,0x0f,0x00,
+0x00,0x00,0x80,0x60,0x10,0xf0,0x28,0x48,0x48,0x88,0x88,0x10,0x10,0x60,0x80,0x00,
+/* 9099 0x238b "⎋" */
+0x00,0x00,0x01,0x7c,0x48,0x50,0x68,0x44,0x02,0x81,0x80,0x40,0x40,0x30,0x0f,0x00,
+0x00,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x08,0x08,0x88,0x50,0x10,0x60,0x80,0x00,
+/* 9100 0x238c "⎌" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x7c,0x28,0x10,0x38,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x1c,0x22,0x22,0x1c,0x00,0x00,
+/* 9101 0x238d "⎍" */
+0x00,0x00,0x00,0x00,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x00,0x00,
+/* 9102 0x238e "⎎" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 9103 0x238f "⎏" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x02,0x04,0x08,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x80,0x40,0x20,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 9104 0x2390 "⎐" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x08,0x04,0x02,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x20,0x40,0x80,0xf0,0x00,0x00,
+/* 9105 0x2391 "⎑" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x02,0x04,0x08,0x1f,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 9106 0x2392 "⎒" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x1f,0x08,0x04,0x02,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xf0,0x20,0x40,0x80,0xf0,0x00,0x00,
+/* 9107 0x2393 "⎓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x73,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x9c,0x00,0x00,0x00,0x00,0x00,
+/* 9108 0x2394 "⎔" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x04,0x02,0x04,0x08,0x10,0xe0,0x00,0x00,
+/* 9109 0x2395 "⎕" */
+0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9110 0x2396 "⎖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x78,0x78,0x70,0x70,0x60,0x60,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9111 0x2397 "⎗" */
+0x00,0x6d,0x40,0x4f,0x48,0x4a,0x4e,0x4b,0x50,0x4b,0x4e,0x7a,0x08,0x0f,0x00,0x00,
+0x00,0xb0,0x10,0xfc,0x04,0x04,0x04,0xe4,0x24,0xe4,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 9112 0x2398 "⎘" */
+0x00,0x7f,0x40,0x4e,0x48,0x49,0x49,0x5f,0x50,0x5f,0x49,0x79,0x08,0x0c,0x00,0x00,
+0x00,0xf0,0x10,0xdc,0x04,0x04,0x84,0x40,0x24,0x44,0x80,0x04,0x04,0xdc,0x00,0x00,
+/* 9113 0x2399 "⎙" */
+0x00,0x01,0x03,0x05,0x0f,0x08,0x38,0x48,0x88,0x88,0x8f,0x80,0x40,0x3f,0x00,0x00,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x38,0x24,0x22,0x22,0xe2,0x02,0x04,0xf8,0x00,0x00,
+/* 9114 0x239a "⎚" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x42,0x44,0x49,0x52,0x44,0x28,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x28,0x44,0x94,0x24,0x44,0x84,0x08,0xf0,0x00,0x00,
+/* 9115 0x239b "⎛" */
+0x00,0x0e,0x18,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9116 0x239c "⎜" */
+0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9117 0x239d "⎝" */
+0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x18,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9118 0x239e "⎞" */
+0x00,0x70,0x18,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9119 0x239f "⎟" */
+0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9120 0x23a0 "⎠" */
+0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x18,0x70,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9121 0x23a1 "⎡" */
+0x00,0x3e,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9122 0x23a2 "⎢" */
+0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9123 0x23a3 "⎣" */
+0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9124 0x23a4 "⎤" */
+0x00,0x7c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9125 0x23a5 "⎥" */
+0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9126 0x23a6 "⎦" */
+0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9127 0x23a7 "⎧" */
+0x00,0x06,0x0c,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9128 0x23a8 "⎨" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x10,0x20,0x40,0x20,0x10,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9129 0x23a9 "⎩" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x0c,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9130 0x23aa "⎪" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9131 0x23ab "⎫" */
+0x00,0x60,0x30,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9132 0x23ac "⎬" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x08,0x04,0x02,0x04,0x08,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9133 0x23ad "⎭" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x30,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9134 0x23ae "⎮" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9135 0x23af "⎯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9136 0x23b0 "⎰" */
+0x06,0x0c,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x30,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9137 0x23b1 "⎱" */
+0x60,0x30,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x0c,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9138 0x23b2 "⎲" */
+0x00,0x00,0x00,0x00,0x7f,0x30,0x30,0x18,0x18,0x0c,0x0c,0x06,0x06,0x03,0x03,0x01,
+0x00,0x00,0x00,0x00,0xfe,0x0e,0x06,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
+/* 9139 0x23b3 "⎳" */
+0x01,0x03,0x03,0x06,0x06,0x0c,0x0c,0x18,0x18,0x30,0x30,0x7f,0x00,0x00,0x00,0x00,
+0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0e,0xfe,0x00,0x00,0x00,0x00,
+/* 9140 0x23b4 "⎴" */
+0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9141 0x23b5 "⎵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,
+/* 9142 0x23b6 "⎶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x00,0x7f,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,0xfe,0x02,0x02,0x00,0x00,0x00,
+/* 9143 0x23b7 "⎷" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x68,0x28,0x28,0x18,0x18,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9144 0x23b8 "⎸" */
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9145 0x23b9 "⎹" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9146 0x23ba "⎺" */
+0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9147 0x23bb "⎻" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9148 0x23bc "⎼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9149 0x23bd "⎽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9150 0x23be "⎾" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9151 0x23bf "⎿" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9152 0x23c0 "⏀" */
+0x00,0x01,0x01,0x03,0x0d,0x11,0x11,0x21,0x21,0x11,0x11,0x0d,0x03,0x01,0x01,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0x00,0x00,
+/* 9153 0x23c1 "⏁" */
+0x00,0xff,0x01,0x03,0x0d,0x11,0x11,0x21,0x21,0x11,0x11,0x0d,0x03,0x01,0x01,0x00,
+0x00,0xff,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0x00,0x00,
+/* 9154 0x23c2 "⏂" */
+0x00,0x01,0x01,0x03,0x0d,0x11,0x11,0x21,0x21,0x11,0x11,0x0d,0x03,0x01,0xff,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0xff,0x00,
+/* 9155 0x23c3 "⏃" */
+0x00,0x01,0x01,0x03,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x3f,0x01,0x01,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0xf8,0x00,0x00,0x00,
+/* 9156 0x23c4 "⏄" */
+0x00,0xff,0x01,0x03,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x3f,0x01,0x01,0x00,
+0x00,0xff,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0xf8,0x00,0x00,0x00,
+/* 9157 0x23c5 "⏅" */
+0x00,0x01,0x01,0x03,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x3f,0x01,0xff,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0xf8,0x00,0xff,0x00,
+/* 9158 0x23c6 "⏆" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x1d,0x23,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9159 0x23c7 "⏇" */
+0x00,0xff,0x01,0x01,0x01,0x01,0x1d,0x23,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9160 0x23c8 "⏈" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x1d,0x23,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x70,0x00,0x00,0x00,0x00,0xff,0x00,
+/* 9161 0x23c9 "⏉" */
+0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9162 0x23ca "⏊" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
+/* 9163 0x23cb "⏋" */
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9164 0x23cc "⏌" */
+0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9165 0x23cd "⏍" */
+0x00,0x00,0x79,0x42,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,
+0x00,0x80,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 9166 0x23ce "⏎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0c,0x17,0x20,0x40,0x20,0x17,0x0c,0x04,0x00,
+0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x42,0x82,0x02,0x04,0x08,0xf0,0x00,0x00,0x00,
+/* 9167 0x23cf "⏏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x7c,0xfe,0x00,0xfe,0xfe,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9168 0x23d0 "⏐" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9169 0x23d1 "⏑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9170 0x23d2 "⏒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9171 0x23d3 "⏓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x38,0x00,0xfe,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9172 0x23d4 "⏔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 9173 0x23d5 "⏕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x38,0x00,0xff,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x38,0x00,0xfe,0x00,0x00,0x00,
+/* 9174 0x23d6 "⏖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 9175 0x23d7 "⏗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9176 0x23d8 "⏘" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9177 0x23d9 "⏙" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9178 0x23da "⏚" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x1c,0x00,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9179 0x23db "⏛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0xff,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0xff,0x08,0x08,0xf8,0x00,0x00,0x00,
+/* 9180 0x23dc "⏜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x38,0x40,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x1c,0x02,0x01,0x00,0x00,
+/* 9181 0x23dd "⏝" */
+0x00,0x00,0x80,0x40,0x38,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x01,0x02,0x1c,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9182 0x23de "⏞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x3c,0x40,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x78,0x04,0x02,0x00,0x00,
+/* 9183 0x23df "⏟" */
+0x00,0x00,0x80,0x40,0x3c,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x02,0x04,0x78,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9184 0x23e0 "⏠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x02,0x00,0x00,
+/* 9185 0x23e1 "⏡" */
+0x00,0x00,0x40,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x02,0x04,0x08,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9186 0x23e2 "⏢" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0xfc,0x00,0x00,
+/* 9187 0x23e3 "⏣" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x09,0x0a,0x0a,0x0a,0x09,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0xc8,0x28,0x28,0x28,0xc8,0x10,0x20,0x40,0x80,0x00,
+/* 9188 0x23e4 "⏤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9189 0x23e5 "⏥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x20,0x20,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x08,0x08,0x10,0x10,0xe0,0x00,0x00,
+/* 9190 0x23e6 "⏦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x84,0x48,0x30,0x00,0x00,0x00,
+/* 9191 0x23e7 "⏧" */
+0x00,0x00,0x24,0x24,0x22,0x22,0xa9,0x71,0x21,0x03,0x01,0x02,0x04,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x18,0xa0,0xc0,0xe0,0xc0,0xa0,0x10,0x08,0x04,0x00,
+/* 9192 0x23e8 "⏨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x6a,0x2a,0x2a,0x2a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9193 0x23e9 "⏩" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x30,0x38,0x3c,0x3e,0x3c,0x38,0x30,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,
+/* 9194 0x23ea "⏪" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0e,0x1e,0x3e,0x1e,0x0e,0x06,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x18,0x38,0x78,0xf8,0x78,0x38,0x18,0x08,0x00,0x00,
+/* 9195 0x23eb "⏫" */
+0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x00,0x01,0x03,0x07,0x0f,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0x00,0x00,0x80,0xc0,0xe0,0xf0,0x00,
+/* 9196 0x23ec "⏬" */
+0x00,0x00,0x00,0x00,0x1f,0x0f,0x07,0x03,0x01,0x00,0x1f,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xe0,0xc0,0x80,0x00,0x00,0xf0,0xe0,0xc0,0x80,0x00,0x00,
+/* 9197 0x23ed "⏭" */
+0x00,0x00,0x00,0x00,0x00,0x41,0x61,0x71,0x79,0x7d,0x79,0x71,0x61,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x84,0xc4,0xe4,0xf4,0xe4,0xc4,0x84,0x04,0x00,0x00,
+/* 9198 0x23ee "⏮" */
+0x00,0x00,0x00,0x00,0x00,0x41,0x43,0x47,0x4f,0x5f,0x4f,0x47,0x43,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x0c,0x1c,0x3c,0x7c,0x3c,0x1c,0x0c,0x04,0x00,0x00,
+/* 9199 0x23ef "⏯" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x18,0x1c,0x1e,0x1f,0x1e,0x1c,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x00,0x00,
+/* 9200 0x23f0 "⏰" */
+0x00,0x01,0x19,0x37,0x28,0x11,0x21,0x21,0x21,0x22,0x24,0x10,0x08,0x0f,0x1c,0x00,
+0x00,0x00,0x30,0xd8,0x28,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0xe0,0x70,0x00,
+/* 9201 0x23f1 "⏱" */
+0x00,0x03,0x03,0x07,0x08,0x11,0x21,0x21,0x21,0x20,0x20,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xd8,0x38,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 9202 0x23f2 "⏲" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x24,0x22,0x21,0x20,0x20,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 9203 0x23f3 "⏳" */
+0x00,0x00,0x7f,0x10,0x10,0x12,0x0d,0x06,0x02,0x06,0x08,0x11,0x1a,0x15,0x7f,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x90,0x60,0xc0,0x80,0xc0,0x20,0x10,0xb0,0x50,0xfc,0x00,
+/* 9204 0x23f4 "⏴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x07,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x40,0x00,
+/* 9205 0x23f5 "⏵" */
+0x00,0x00,0x00,0x00,0x08,0x0c,0x0e,0x0f,0x0f,0x0f,0x0f,0x0f,0x0e,0x0c,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 9206 0x23f6 "⏶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0x00,0x00,0x00,0x00,
+/* 9207 0x23f7 "⏷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x1f,0x0f,0x07,0x03,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 9208 0x23f8 "⏸" */
+0x00,0x00,0x00,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 9209 0x23f9 "⏹" */
+0x00,0x00,0x00,0x00,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0x00,0x00,
+/* 9210 0x23fa "⏺" */
+0x00,0x00,0x00,0x00,0x07,0x0f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x0f,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf0,0xe0,0x00,0x00,
+/* 9211 0x23fb "⏻" */
+0x01,0x01,0x01,0x01,0x19,0x39,0x31,0x71,0x61,0x61,0x70,0x30,0x38,0x1f,0x0f,0x03,
+0x80,0x80,0x80,0x80,0x98,0x9c,0x8c,0x8e,0x86,0x86,0x0e,0x0c,0x1c,0xf8,0xf0,0xc0,
+/* 9212 0x23fc "⏼" */
+0x00,0x07,0x1f,0x3c,0x78,0x71,0x61,0x61,0x61,0x61,0x61,0x71,0x38,0x1f,0x0f,0x03,
+0x00,0xe0,0xf8,0x3c,0x1e,0x8e,0x86,0x86,0x86,0x86,0x86,0x8e,0x1c,0xf8,0xf0,0xc0,
+/* 9213 0x23fd "⏽" */
+0x01,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x01,
+0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,
+/* 9214 0x23fe "⏾" */
+0x04,0x08,0x18,0x38,0x38,0x78,0x78,0x78,0x78,0x7c,0x3c,0x3e,0x1f,0x0f,0x07,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xe0,0xf0,
+/* 9215 0x23ff "⏿" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x60,0x18,0x06,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1c,0x78,0x94,0x24,0x22,0x22,0x22,0x24,0x94,0x78,0x1c,0x00,0x00,
+/* 9216 0x2400 "␀" */
+0x00,0x00,0x00,0x00,0x00,0x4a,0x6a,0x5a,0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x9e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9217 0x2401 "␁" */
+0x00,0x00,0x00,0x00,0x00,0x39,0x42,0x32,0x0a,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x92,0x52,0x5e,0x52,0x92,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9218 0x2402 "␂" */
+0x00,0x00,0x00,0x00,0x00,0x3b,0x41,0x31,0x09,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa4,0x24,0x18,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9219 0x2403 "␃" */
+0x00,0x00,0x00,0x00,0x00,0x7b,0x41,0x79,0x41,0x79,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa4,0x24,0x18,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9220 0x2404 "␄" */
+0x00,0x00,0x00,0x00,0x00,0x79,0x42,0x7a,0x42,0x79,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xbe,0x48,0x48,0x48,0x88,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9221 0x2405 "␅" */
+0x00,0x00,0x00,0x00,0x00,0x7a,0x42,0x7b,0x42,0x7a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0xd6,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9222 0x2406 "␆" */
+0x00,0x00,0x00,0x00,0x00,0x31,0x4a,0x7a,0x4a,0x49,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa4,0x28,0x30,0x28,0xa4,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9223 0x2407 "␇" */
+0x00,0x00,0x00,0x00,0x00,0x73,0x4a,0x73,0x4a,0x73,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xd0,0x10,0xd0,0x10,0xde,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9224 0x2408 "␈" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x11,0x1e,0x11,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0x40,0x30,0x08,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9225 0x2409 "␉" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x3e,0x22,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9226 0x240a "␊" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0xf8,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9227 0x240b "␋" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9228 0x240c "␌" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x20,0x3e,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0xf8,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9229 0x240d "␍" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x20,0x20,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x88,0xf0,0x90,0x88,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9230 0x240e "␎" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x1c,0x02,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9231 0x240f "␏" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x1c,0x02,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9232 0x2410 "␐" */
+0x00,0x00,0x00,0x00,0x00,0x39,0x25,0x25,0x25,0x39,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1c,0x10,0x1c,0x10,0xdc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9233 0x2411 "␑" */
+0x00,0x00,0x00,0x00,0x00,0x71,0x4a,0x4a,0x4a,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x18,0x08,0x08,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9234 0x2412 "␒" */
+0x00,0x00,0x00,0x00,0x00,0x71,0x4a,0x4a,0x4a,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x98,0x04,0x08,0x10,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9235 0x2413 "␓" */
+0x00,0x00,0x00,0x00,0x00,0x71,0x4a,0x4a,0x4a,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x98,0x04,0x18,0x04,0x98,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9236 0x2414 "␔" */
+0x00,0x00,0x00,0x00,0x00,0x71,0x4a,0x4a,0x4a,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x84,0x0c,0x14,0x1c,0x84,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9237 0x2415 "␕" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x6a,0x6a,0x5b,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x92,0x54,0x58,0xd4,0x52,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9238 0x2416 "␖" */
+0x00,0x00,0x00,0x00,0x00,0x34,0x42,0x31,0x09,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x52,0x9a,0x16,0x12,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9239 0x2417 "␗" */
+0x00,0x00,0x00,0x00,0x00,0x7b,0x41,0x79,0x41,0x79,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xb8,0x24,0x38,0x24,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9240 0x2418 "␘" */
+0x00,0x00,0x00,0x00,0x00,0x33,0x44,0x47,0x44,0x34,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x24,0xb4,0xac,0xa4,0xa4,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9241 0x2419 "␙" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x20,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0xd8,0xa8,0x88,0x88,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9242 0x241a "␚" */
+0x00,0x00,0x00,0x00,0x00,0x3a,0x42,0x32,0x0a,0x71,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x5c,0x52,0x5c,0x52,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9243 0x241b "␛" */
+0x00,0x00,0x00,0x00,0x00,0x79,0x42,0x79,0x40,0x7b,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xce,0x10,0x90,0x50,0x8e,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9244 0x241c "␜" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x10,0x1e,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x60,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9245 0x241d "␝" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x10,0x16,0x12,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x60,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9246 0x241e "␞" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x12,0x1c,0x14,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x60,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9247 0x241f "␟" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x60,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9248 0x2420 "␠" */
+0x00,0x00,0x00,0x00,0x00,0x3b,0x42,0x33,0x0a,0x72,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9249 0x2421 "␡" */
+0x00,0x00,0x00,0x00,0x00,0x73,0x4a,0x4b,0x4a,0x73,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xd0,0x10,0xd0,0x10,0xde,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9250 0x2422 "␢" */
+0x00,0x00,0x00,0x00,0x14,0x18,0x10,0x30,0x5c,0x12,0x12,0x12,0x12,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9251 0x2423 "␣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9252 0x2424 "␤" */
+0x00,0x00,0x00,0x00,0x48,0x68,0x58,0x48,0x00,0x10,0x10,0x10,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9253 0x2425 "␥" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x0a,0x15,0x2a,0x54,0x28,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9254 0x2426 "␦" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x20,0x10,0x10,0x00,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9255 0x2427 "␧" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 9256 0x2428 "␨" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 9257 0x2429 "␩" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 9258 0x242a "␪" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 9259 0x242b "␫" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 9260 0x242c "␬" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 9261 0x242d "␭" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 9262 0x242e "␮" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 9263 0x242f "␯" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 9264 0x2430 "␰" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 9265 0x2431 "␱" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 9266 0x2432 "␲" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 9267 0x2433 "␳" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 9268 0x2434 "␴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 9269 0x2435 "␵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 9270 0x2436 "␶" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 9271 0x2437 "␷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 9272 0x2438 "␸" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 9273 0x2439 "␹" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 9274 0x243a "␺" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 9275 0x243b "␻" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 9276 0x243c "␼" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 9277 0x243d "␽" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 9278 0x243e "␾" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 9279 0x243f "␿" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 9280 0x2440 "⑀" */
+0x00,0x00,0x00,0x00,0x0e,0x0a,0x0a,0x0a,0x08,0x08,0x28,0x28,0x28,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9281 0x2441 "⑁" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x3e,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9282 0x2442 "⑂" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x3e,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9283 0x2443 "⑃" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x3e,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9284 0x2444 "⑄" */
+0x00,0x00,0x00,0x00,0x3e,0x2a,0x2a,0x2a,0x08,0x08,0x2a,0x2a,0x2a,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9285 0x2445 "⑅" */
+0x00,0x00,0x00,0x00,0x22,0x36,0x2a,0x36,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9286 0x2446 "⑆" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x6e,0x6e,0x60,0x60,0x6e,0x6e,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9287 0x2447 "⑇" */
+0x00,0x00,0x00,0x00,0x03,0x03,0x03,0x1b,0x18,0x18,0xd8,0xc0,0xc0,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9288 0x2448 "⑈" */
+0x00,0x00,0x00,0x00,0x07,0x57,0x57,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9289 0x2449 "⑉" */
+0x00,0x00,0x00,0x00,0x00,0x6d,0x6d,0x6d,0x6d,0x6d,0x6d,0x6d,0x6d,0x6d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9290 0x244a "⑊" */
+0x00,0x00,0x00,0x00,0xa0,0xa0,0x50,0x28,0x28,0x14,0x14,0x0a,0x05,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9291 0x244b "⑋" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 9292 0x244c "⑌" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 9293 0x244d "⑍" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 9294 0x244e "⑎" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 9295 0x244f "⑏" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 9296 0x2450 "⑐" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 9297 0x2451 "⑑" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 9298 0x2452 "⑒" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 9299 0x2453 "⑓" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 9300 0x2454 "⑔" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 9301 0x2455 "⑕" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 9302 0x2456 "⑖" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 9303 0x2457 "⑗" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 9304 0x2458 "⑘" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 9305 0x2459 "⑙" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 9306 0x245a "⑚" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 9307 0x245b "⑛" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 9308 0x245c "⑜" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 9309 0x245d "⑝" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 9310 0x245e "⑞" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 9311 0x245f "⑟" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 9312 0x2460 "①" */
+0x07,0x18,0x20,0x41,0x43,0x85,0x81,0x81,0x81,0x81,0x41,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x02,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9313 0x2461 "②" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x80,0x80,0x81,0x82,0x44,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x82,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9314 0x2462 "③" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x80,0x81,0x80,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x82,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9315 0x2463 "④" */
+0x07,0x18,0x20,0x40,0x41,0x82,0x84,0x88,0x8f,0x80,0x40,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x84,0x82,0x82,0x82,0xc2,0x82,0x84,0x84,0x08,0x30,0xc0,0x00,
+/* 9316 0x2464 "⑤" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x87,0x80,0x80,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x04,0x02,0x02,0x82,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9317 0x2465 "⑥" */
+0x07,0x18,0x20,0x41,0x42,0x84,0x84,0x87,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x04,0x02,0x02,0x82,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9318 0x2466 "⑦" */
+0x07,0x18,0x20,0x47,0x40,0x80,0x80,0x80,0x80,0x81,0x41,0x41,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x44,0x42,0x82,0x82,0x82,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9319 0x2467 "⑧" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x83,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x82,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9320 0x2468 "⑨" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x83,0x80,0x80,0x40,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0xc2,0x42,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9321 0x2469 "⑩" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x64,0x92,0x92,0x92,0x92,0x92,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9322 0x246a "⑪" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x95,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0xc2,0x42,0x42,0x42,0x42,0xf4,0x04,0x08,0x30,0xc0,0x00,
+/* 9323 0x246b "⑫" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x64,0x92,0x12,0x22,0x42,0x82,0xf4,0x04,0x08,0x30,0xc0,0x00,
+/* 9324 0x246c "⑬" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x64,0x92,0x12,0x22,0x12,0x92,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9325 0x246d "⑭" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x14,0x32,0x52,0x92,0xfa,0x12,0x14,0x04,0x08,0x30,0xc0,0x00,
+/* 9326 0x246e "⑮" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0xf4,0x82,0x82,0xe2,0x12,0x92,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9327 0x246f "⑯" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x74,0x82,0x82,0xe2,0x92,0x92,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9328 0x2470 "⑰" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0xf4,0x12,0x12,0x22,0x22,0x42,0x44,0x04,0x08,0x30,0xc0,0x00,
+/* 9329 0x2471 "⑱" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x64,0x92,0x92,0x62,0x92,0x92,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9330 0x2472 "⑲" */
+0x07,0x18,0x20,0x40,0x44,0x8c,0x94,0x84,0x84,0x84,0x5f,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x64,0x92,0x92,0x72,0x12,0x12,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9331 0x2473 "⑳" */
+0x07,0x18,0x20,0x40,0x4c,0x92,0x82,0x84,0x88,0x90,0x5e,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x64,0x92,0x92,0x92,0x92,0x92,0x64,0x04,0x08,0x30,0xc0,0x00,
+/* 9332 0x2474 "⑴" */
+0x00,0x00,0x10,0x20,0x21,0x42,0x40,0x40,0x40,0x40,0x40,0x20,0x23,0x10,0x00,0x00,
+0x00,0x00,0x08,0x84,0x84,0x82,0x82,0x82,0x82,0x82,0x82,0x84,0xe4,0x08,0x00,0x00,
+/* 9333 0x2475 "⑵" */
+0x00,0x00,0x10,0x23,0x24,0x44,0x40,0x40,0x41,0x42,0x44,0x24,0x27,0x10,0x00,0x00,
+0x00,0x00,0x08,0xc4,0x24,0x22,0x22,0xc2,0x02,0x02,0x02,0x04,0xe4,0x08,0x00,0x00,
+/* 9334 0x2476 "⑶" */
+0x00,0x00,0x10,0x23,0x24,0x44,0x40,0x41,0x40,0x40,0x44,0x24,0x23,0x10,0x00,0x00,
+0x00,0x00,0x08,0xc4,0x24,0x22,0x22,0xc2,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,0x00,
+/* 9335 0x2477 "⑷" */
+0x00,0x00,0x10,0x20,0x20,0x41,0x42,0x44,0x44,0x47,0x40,0x20,0x20,0x10,0x00,0x00,
+0x00,0x00,0x08,0x44,0xc4,0x42,0x42,0x42,0x42,0xe2,0x42,0x44,0x44,0x08,0x00,0x00,
+/* 9336 0x2478 "⑸" */
+0x00,0x00,0x10,0x27,0x24,0x44,0x44,0x47,0x40,0x40,0x40,0x24,0x23,0x10,0x00,0x00,
+0x00,0x00,0x08,0xe4,0x04,0x02,0x02,0xc2,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,0x00,
+/* 9337 0x2479 "⑹" */
+0x00,0x00,0x10,0x21,0x22,0x44,0x44,0x47,0x44,0x44,0x44,0x24,0x23,0x10,0x00,0x00,
+0x00,0x00,0x08,0xc4,0x04,0x02,0x02,0xc2,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,0x00,
+/* 9338 0x247a "⑺" */
+0x00,0x00,0x10,0x27,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x20,0x10,0x00,0x00,
+0x00,0x00,0x08,0xe4,0x24,0x22,0x42,0x42,0x42,0x82,0x82,0x84,0x84,0x08,0x00,0x00,
+/* 9339 0x247b "⑻" */
+0x00,0x00,0x10,0x23,0x24,0x44,0x44,0x43,0x44,0x44,0x44,0x24,0x23,0x10,0x00,0x00,
+0x00,0x00,0x08,0xc4,0x24,0x22,0x22,0xc2,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,0x00,
+/* 9340 0x247c "⑼" */
+0x00,0x00,0x10,0x23,0x24,0x44,0x44,0x43,0x40,0x40,0x40,0x20,0x23,0x10,0x00,0x00,
+0x00,0x00,0x08,0xc4,0x24,0x22,0x22,0xe2,0x22,0x22,0x22,0x44,0x84,0x08,0x00,0x00,
+/* 9341 0x247d "⑽" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x31,0x49,0x85,0x85,0x85,0x85,0x85,0x85,0x49,0x31,0x02,0x00,0x00,
+/* 9342 0x247e "⑾" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x11,0x31,0x51,0x11,0x11,0x11,0x11,0x11,0x11,0x7d,0x02,0x00,0x00,
+/* 9343 0x247f "⑿" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x79,0x85,0x85,0x05,0x19,0x21,0x41,0x81,0x81,0xfd,0x02,0x00,0x00,
+/* 9344 0x2480 "⒀" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x79,0x85,0x85,0x05,0x39,0x05,0x05,0x85,0x85,0x79,0x02,0x00,0x00,
+/* 9345 0x2481 "⒁" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x09,0x19,0x29,0x49,0x89,0x89,0xfd,0x09,0x09,0x09,0x02,0x00,0x00,
+/* 9346 0x2482 "⒂" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0xfd,0x81,0x81,0x81,0xf9,0x05,0x05,0x05,0x85,0x79,0x02,0x00,0x00,
+/* 9347 0x2483 "⒃" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x39,0x41,0x81,0x81,0xf9,0x85,0x85,0x85,0x85,0x79,0x02,0x00,0x00,
+/* 9348 0x2484 "⒄" */
+0x00,0x00,0x40,0x89,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0xf9,0x09,0x09,0x11,0x11,0x11,0x21,0x21,0x21,0x21,0x02,0x00,0x00,
+/* 9349 0x2485 "⒅" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x79,0x85,0x85,0x85,0x79,0x85,0x85,0x85,0x85,0x79,0x02,0x00,0x00,
+/* 9350 0x2486 "⒆" */
+0x00,0x00,0x40,0x88,0x98,0xa8,0x88,0x88,0x88,0x88,0x88,0x88,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x79,0x85,0x85,0x85,0x7d,0x05,0x05,0x05,0x09,0x71,0x02,0x00,0x00,
+/* 9351 0x2487 "⒇" */
+0x00,0x00,0x40,0x9c,0xa2,0xa2,0x82,0x84,0x88,0x90,0xa0,0xa0,0xbe,0x40,0x00,0x00,
+0x00,0x00,0x02,0x31,0x49,0x85,0x85,0x85,0x85,0x85,0x85,0x49,0x31,0x02,0x00,0x00,
+/* 9352 0x2488 "⒈" */
+0x00,0x00,0x00,0x00,0x01,0x03,0x05,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd0,0x00,0x00,
+/* 9353 0x2489 "⒉" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x00,0x01,0x02,0x04,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0xd0,0x00,0x00,
+/* 9354 0x248a "⒊" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x00,0x03,0x00,0x00,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x40,0x40,0x40,0x40,0x90,0x00,0x00,
+/* 9355 0x248b "⒋" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xc0,0x80,0x80,0x90,0x00,0x00,
+/* 9356 0x248c "⒌" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x90,0x00,0x00,
+/* 9357 0x248d "⒍" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x90,0x00,0x00,
+/* 9358 0x248e "⒎" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x40,0x40,0x80,0x80,0x80,0x00,0x00,0x00,0x10,0x00,0x00,
+/* 9359 0x248f "⒏" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x40,0x40,0x40,0x40,0x90,0x00,0x00,
+/* 9360 0x2490 "⒐" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x80,0x10,0x00,0x00,
+/* 9361 0x2491 "⒑" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x51,0x11,0x11,0x11,0x11,0x11,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x08,0x08,0x08,0x08,0x08,0x08,0x90,0x62,0x00,0x00,
+/* 9362 0x2492 "⒒" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0xfa,0x00,0x00,
+/* 9363 0x2493 "⒓" */
+0x00,0x00,0x00,0x00,0x10,0x31,0x51,0x10,0x10,0x10,0x10,0x11,0x11,0x7d,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x40,0x80,0x00,0x00,0xfa,0x00,0x00,
+/* 9364 0x2494 "⒔" */
+0x00,0x00,0x00,0x00,0x10,0x31,0x51,0x10,0x10,0x10,0x10,0x11,0x11,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x70,0x08,0x08,0x08,0x08,0xf2,0x00,0x00,
+/* 9365 0x2495 "⒕" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x10,0x11,0x11,0x11,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x90,0x10,0x10,0xf8,0x10,0x10,0x12,0x00,0x00,
+/* 9366 0x2496 "⒖" */
+0x00,0x00,0x00,0x00,0x11,0x31,0x51,0x11,0x11,0x10,0x10,0x10,0x11,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0xf2,0x00,0x00,
+/* 9367 0x2497 "⒗" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x51,0x11,0x11,0x11,0x11,0x11,0x11,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0xf2,0x00,0x00,
+/* 9368 0x2498 "⒘" */
+0x00,0x00,0x00,0x00,0x11,0x30,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x20,0x22,0x00,0x00,
+/* 9369 0x2499 "⒙" */
+0x00,0x00,0x00,0x00,0x10,0x31,0x51,0x11,0x10,0x11,0x11,0x11,0x11,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0xf0,0x08,0x08,0x08,0x08,0xf2,0x00,0x00,
+/* 9370 0x249a "⒚" */
+0x00,0x00,0x00,0x00,0x10,0x31,0x51,0x11,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x10,0xe2,0x00,0x00,
+/* 9371 0x249b "⒛" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x0c,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x84,0x84,0x84,0x84,0x84,0x48,0x31,0x00,0x00,
+/* 9372 0x249c "⒜" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x40,0x43,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0xe2,0x22,0x22,0x64,0xa4,0x08,0x00,
+/* 9373 0x249d "⒝" */
+0x00,0x00,0x00,0x14,0x24,0x24,0x45,0x46,0x44,0x44,0x44,0x44,0x26,0x25,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,
+/* 9374 0x249e "⒞" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x44,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x02,0x02,0x02,0x02,0x24,0xc4,0x08,0x00,
+/* 9375 0x249f "⒟" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x44,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x28,0x24,0x24,0xa2,0x62,0x22,0x22,0x22,0x22,0x64,0xa4,0x08,0x00,
+/* 9376 0x24a0 "⒠" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x47,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0xe2,0x02,0x02,0x24,0xc4,0x08,0x00,
+/* 9377 0x24a1 "⒡" */
+0x00,0x00,0x00,0x10,0x21,0x21,0x41,0x47,0x41,0x41,0x41,0x41,0x21,0x21,0x10,0x00,
+0x00,0x00,0x00,0xc8,0x04,0x04,0x02,0xc2,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x00,
+/* 9378 0x24a2 "⒢" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x44,0x43,0x42,0x23,0x24,0x14,0x03,
+0x00,0x00,0x00,0x08,0x04,0x24,0xa2,0x42,0x42,0x42,0x82,0x02,0xc4,0x24,0x28,0xc0,
+/* 9379 0x24a3 "⒣" */
+0x00,0x00,0x00,0x14,0x24,0x24,0x45,0x46,0x44,0x44,0x44,0x44,0x24,0x24,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0x22,0x22,0x22,0x24,0x24,0x08,0x00,
+/* 9380 0x24a4 "⒤" */
+0x00,0x00,0x00,0x11,0x21,0x20,0x43,0x41,0x41,0x41,0x41,0x41,0x21,0x27,0x10,0x00,
+0x00,0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0xc8,0x10,0x00,
+/* 9381 0x24a5 "⒥" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x20,0x14,0x03,
+0x00,0x00,0x00,0x50,0x48,0x08,0xc4,0x44,0x44,0x44,0x44,0x44,0x48,0x48,0x90,0x00,
+/* 9382 0x24a6 "⒦" */
+0x00,0x00,0x00,0x14,0x24,0x24,0x44,0x44,0x45,0x46,0x45,0x44,0x24,0x24,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0x42,0x82,0x02,0x02,0x02,0x82,0x44,0x24,0x08,0x00,
+/* 9383 0x24a7 "⒧" */
+0x00,0x00,0x00,0x13,0x21,0x21,0x41,0x41,0x41,0x41,0x41,0x41,0x21,0x27,0x10,0x00,
+0x00,0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0xc8,0x10,0x00,
+/* 9384 0x24a8 "⒨" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x47,0x44,0x44,0x44,0x44,0x44,0x24,0x24,0x10,0x00,
+0x00,0x00,0x00,0x04,0x02,0x02,0x61,0x91,0x91,0x91,0x91,0x91,0x92,0x92,0x04,0x00,
+/* 9385 0x24a9 "⒩" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x45,0x46,0x44,0x44,0x44,0x44,0x24,0x24,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0x22,0x22,0x22,0x24,0x24,0x08,0x00,
+/* 9386 0x24aa "⒪" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x44,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,
+/* 9387 0x24ab "⒫" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x45,0x46,0x44,0x44,0x44,0x44,0x26,0x25,0x14,0x04,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0x22,0x22,0x22,0x24,0xc4,0x08,0x00,
+/* 9388 0x24ac "⒬" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x44,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xa2,0x62,0x22,0x22,0x22,0x22,0x64,0xa4,0x28,0x20,
+/* 9389 0x24ad "⒭" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x45,0x46,0x44,0x44,0x44,0x44,0x24,0x24,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x22,0x02,0x02,0x02,0x04,0x04,0x08,0x00,
+/* 9390 0x24ae "⒮" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x43,0x44,0x44,0x43,0x40,0x40,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x22,0x02,0x02,0xc2,0x22,0x24,0xc4,0x08,0x00,
+/* 9391 0x24af "⒯" */
+0x00,0x00,0x00,0x10,0x21,0x21,0x47,0x41,0x41,0x41,0x41,0x41,0x21,0x20,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xc2,0x02,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x00,
+/* 9392 0x24b0 "⒰" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x44,0x44,0x44,0x44,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0x22,0x22,0x22,0x22,0x22,0x22,0x64,0xa4,0x08,0x00,
+/* 9393 0x24b1 "⒱" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x44,0x44,0x44,0x42,0x42,0x42,0x21,0x21,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0x22,0x22,0x22,0x42,0x42,0x42,0x84,0x84,0x08,0x00,
+/* 9394 0x24b2 "⒲" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x44,0x44,0x44,0x44,0x44,0x44,0x24,0x23,0x10,0x00,
+0x00,0x00,0x00,0x04,0x02,0x02,0x11,0x91,0x91,0x91,0x91,0x91,0x92,0x62,0x04,0x00,
+/* 9395 0x24b3 "⒳" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x44,0x44,0x42,0x41,0x41,0x42,0x24,0x24,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0x22,0x22,0x42,0x82,0x82,0x42,0x24,0x24,0x08,0x00,
+/* 9396 0x24b4 "⒴" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x44,0x44,0x44,0x44,0x44,0x42,0x21,0x20,0x10,0x03,
+0x00,0x00,0x00,0x08,0x04,0x04,0x22,0x22,0x22,0x22,0x22,0x62,0xa4,0x24,0x28,0xc0,
+/* 9397 0x24b5 "⒵" */
+0x00,0x00,0x00,0x10,0x20,0x20,0x47,0x40,0x40,0x40,0x41,0x42,0x24,0x27,0x10,0x00,
+0x00,0x00,0x00,0x08,0x04,0x04,0xe2,0x22,0x42,0x82,0x02,0x02,0x04,0xe4,0x08,0x00,
+/* 9398 0x24b6 "Ⓐ" */
+0x07,0x18,0x20,0x41,0x42,0x82,0x84,0x84,0x87,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x82,0x42,0x42,0xc2,0x42,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9399 0x24b7 "Ⓑ" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x87,0x84,0x84,0x44,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x82,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9400 0x24b8 "Ⓒ" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x84,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x02,0x02,0x02,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9401 0x24b9 "Ⓓ" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x84,0x84,0x84,0x44,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0x42,0x42,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9402 0x24ba "Ⓔ" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x87,0x84,0x84,0x44,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x04,0x02,0x02,0x82,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9403 0x24bb "Ⓕ" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x87,0x84,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x04,0x02,0x02,0x82,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9404 0x24bc "Ⓖ" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x85,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x02,0xc2,0x42,0x42,0xc4,0x44,0x08,0x30,0xc0,0x00,
+/* 9405 0x24bd "Ⓗ" */
+0x07,0x18,0x20,0x44,0x44,0x84,0x84,0x87,0x84,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0x42,0x42,0xc2,0x42,0x42,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9406 0x24be "Ⓘ" */
+0x07,0x18,0x20,0x47,0x41,0x81,0x81,0x81,0x81,0x81,0x41,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x04,0x02,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9407 0x24bf "Ⓙ" */
+0x07,0x18,0x20,0x43,0x40,0x80,0x80,0x80,0x80,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xe4,0x84,0x82,0x82,0x82,0x82,0x82,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9408 0x24c0 "Ⓚ" */
+0x07,0x18,0x20,0x44,0x44,0x84,0x85,0x86,0x85,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0x82,0x02,0x02,0x02,0x82,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9409 0x24c1 "Ⓛ" */
+0x07,0x18,0x20,0x44,0x44,0x84,0x84,0x84,0x84,0x84,0x44,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x02,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9410 0x24c2 "Ⓜ" */
+0x07,0x18,0x20,0x44,0x44,0x86,0x86,0x85,0x85,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0xc2,0xc2,0x42,0x42,0x42,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9411 0x24c3 "Ⓝ" */
+0x07,0x18,0x20,0x40,0x44,0x86,0x86,0x85,0x85,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0x42,0x42,0x42,0x42,0xc2,0xc4,0x44,0x08,0x30,0xc0,0x00,
+/* 9412 0x24c4 "Ⓞ" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x84,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x42,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9413 0x24c5 "Ⓟ" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x87,0x84,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x82,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9414 0x24c6 "Ⓠ" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x84,0x84,0x85,0x46,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x42,0x42,0x42,0xc4,0x84,0x68,0x30,0xc0,0x00,
+/* 9415 0x24c7 "Ⓡ" */
+0x07,0x18,0x20,0x47,0x44,0x84,0x84,0x87,0x85,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x42,0x82,0x02,0x82,0x84,0x44,0x08,0x30,0xc0,0x00,
+/* 9416 0x24c8 "Ⓢ" */
+0x07,0x18,0x20,0x43,0x44,0x84,0x84,0x83,0x80,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x44,0x42,0x02,0x82,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9417 0x24c9 "Ⓣ" */
+0x07,0x18,0x20,0x4f,0x41,0x81,0x81,0x81,0x81,0x81,0x41,0x41,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xe4,0x04,0x02,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9418 0x24ca "Ⓤ" */
+0x07,0x18,0x20,0x44,0x44,0x84,0x84,0x84,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0x42,0x42,0x42,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9419 0x24cb "Ⓥ" */
+0x07,0x18,0x20,0x48,0x48,0x84,0x84,0x84,0x82,0x82,0x41,0x41,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x24,0x24,0x42,0x42,0x42,0x82,0x82,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9420 0x24cc "Ⓦ" */
+0x07,0x18,0x20,0x44,0x44,0x84,0x85,0x85,0x86,0x86,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0x42,0x42,0x42,0xc2,0xc2,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9421 0x24cd "Ⓧ" */
+0x07,0x18,0x20,0x44,0x44,0x82,0x82,0x81,0x82,0x82,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0x82,0x82,0x02,0x82,0x82,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9422 0x24ce "Ⓨ" */
+0x07,0x18,0x20,0x48,0x48,0x84,0x84,0x82,0x81,0x81,0x41,0x41,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x24,0x24,0x42,0x42,0x82,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9423 0x24cf "Ⓩ" */
+0x07,0x18,0x20,0x47,0x40,0x80,0x80,0x81,0x82,0x84,0x44,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x44,0x42,0x82,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9424 0x24d0 "ⓐ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x80,0x83,0x84,0x84,0x43,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0xc2,0x42,0xc2,0x44,0x04,0x08,0x30,0xc0,0x00,
+/* 9425 0x24d1 "ⓑ" */
+0x07,0x18,0x24,0x44,0x44,0x85,0x86,0x84,0x84,0x84,0x46,0x45,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x82,0x42,0x42,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9426 0x24d2 "ⓒ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x84,0x84,0x84,0x84,0x43,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x02,0x02,0x02,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9427 0x24d3 "ⓓ" */
+0x07,0x18,0x20,0x40,0x40,0x83,0x84,0x84,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x48,0x44,0x44,0x42,0xc2,0x42,0x42,0x42,0xc4,0x44,0x08,0x30,0xc0,0x00,
+/* 9428 0x24d4 "ⓔ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x84,0x87,0x84,0x84,0x43,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0xc2,0x02,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9429 0x24d5 "ⓕ" */
+0x07,0x18,0x20,0x40,0x41,0x81,0x81,0x87,0x81,0x81,0x41,0x41,0x21,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0x04,0x02,0x02,0xc2,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9430 0x24d6 "ⓖ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x84,0x83,0x82,0x83,0x44,0x44,0x23,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x44,0x44,0x82,0x82,0x02,0x02,0x82,0x44,0x44,0x88,0x30,0xc0,0x00,
+/* 9431 0x24d7 "ⓗ" */
+0x07,0x18,0x24,0x44,0x44,0x85,0x86,0x84,0x84,0x84,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x82,0x42,0x42,0x42,0x42,0x44,0x44,0x08,0x30,0xc0,0x00,
+/* 9432 0x24d8 "ⓘ" */
+0x07,0x18,0x21,0x41,0x40,0x83,0x81,0x81,0x81,0x81,0x41,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x02,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9433 0x24d9 "ⓙ" */
+0x07,0x18,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0x80,0x40,0x44,0x23,0x18,0x07,0x00,
+0xc0,0x30,0x48,0x44,0x04,0xc2,0x42,0x42,0x42,0x42,0x44,0x84,0x08,0x30,0xc0,0x00,
+/* 9434 0x24da "ⓚ" */
+0x07,0x18,0x20,0x44,0x44,0x84,0x85,0x86,0x86,0x85,0x44,0x44,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x82,0x02,0x02,0x02,0x02,0x84,0x44,0x08,0x30,0xc0,0x00,
+/* 9435 0x24db "ⓛ" */
+0x07,0x18,0x20,0x43,0x41,0x81,0x81,0x81,0x81,0x81,0x41,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0x02,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9436 0x24dc "ⓜ" */
+0x07,0x18,0x20,0x40,0x4e,0x89,0x89,0x89,0x89,0x89,0x49,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0xc4,0x22,0x22,0x22,0x22,0x22,0x24,0x04,0x08,0x30,0xc0,0x00,
+/* 9437 0x24dd "ⓝ" */
+0x07,0x18,0x20,0x40,0x45,0x86,0x84,0x84,0x84,0x84,0x44,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0x42,0x42,0x42,0x44,0x04,0x08,0x30,0xc0,0x00,
+/* 9438 0x24de "ⓞ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x84,0x84,0x84,0x84,0x43,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0x42,0x42,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9439 0x24df "ⓟ" */
+0x07,0x18,0x20,0x40,0x45,0x86,0x84,0x84,0x84,0x86,0x45,0x44,0x24,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0x42,0x42,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9440 0x24e0 "ⓠ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x84,0x84,0x84,0x84,0x44,0x43,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0xc2,0x42,0x42,0x42,0x42,0xc4,0x44,0x48,0x30,0xc0,0x00,
+/* 9441 0x24e1 "ⓡ" */
+0x07,0x18,0x20,0x40,0x45,0x86,0x84,0x84,0x84,0x84,0x44,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0x02,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9442 0x24e2 "ⓢ" */
+0x07,0x18,0x20,0x40,0x43,0x84,0x84,0x83,0x80,0x84,0x43,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x02,0x82,0x42,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9443 0x24e3 "ⓣ" */
+0x07,0x18,0x20,0x41,0x41,0x87,0x81,0x81,0x81,0x81,0x41,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x04,0xc2,0x02,0x02,0x02,0x02,0x04,0xc4,0x08,0x30,0xc0,0x00,
+/* 9444 0x24e4 "ⓤ" */
+0x07,0x18,0x20,0x40,0x44,0x84,0x84,0x84,0x84,0x84,0x43,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0x42,0x42,0x42,0x42,0xc2,0x44,0x04,0x08,0x30,0xc0,0x00,
+/* 9445 0x24e5 "ⓥ" */
+0x07,0x18,0x20,0x40,0x44,0x84,0x82,0x82,0x82,0x81,0x41,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0x42,0x82,0x82,0x82,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9446 0x24e6 "ⓦ" */
+0x07,0x18,0x20,0x40,0x48,0x89,0x89,0x89,0x89,0x89,0x46,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x24,0x22,0x22,0x22,0x22,0x22,0xc4,0x04,0x08,0x30,0xc0,0x00,
+/* 9447 0x24e7 "ⓧ" */
+0x07,0x18,0x20,0x40,0x44,0x84,0x82,0x81,0x82,0x84,0x44,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0x42,0x82,0x02,0x82,0x42,0x44,0x04,0x08,0x30,0xc0,0x00,
+/* 9448 0x24e8 "ⓨ" */
+0x07,0x18,0x20,0x40,0x44,0x84,0x84,0x84,0x82,0x81,0x40,0x40,0x23,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x44,0x42,0x42,0x42,0xc2,0x42,0x44,0x44,0x88,0x30,0xc0,0x00,
+/* 9449 0x24e9 "ⓩ" */
+0x07,0x18,0x20,0x40,0x47,0x80,0x80,0x81,0x82,0x84,0x47,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0xc4,0x42,0x82,0x02,0x02,0x02,0xc4,0x04,0x08,0x30,0xc0,0x00,
+/* 9450 0x24ea "⓪" */
+0x07,0x18,0x20,0x41,0x42,0x84,0x84,0x84,0x84,0x84,0x42,0x41,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x04,0x84,0x42,0x42,0x42,0x42,0x42,0x84,0x04,0x08,0x30,0xc0,0x00,
+/* 9451 0x24eb "⓫" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xea,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0xbc,0x3e,0xbe,0xbe,0xbe,0xbe,0x0c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9452 0x24ec "⓬" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xeb,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x9c,0x6e,0xee,0xde,0xbe,0x7e,0x0c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9453 0x24ed "⓭" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xeb,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x9c,0x6e,0xee,0xde,0xee,0x6e,0x9c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9454 0x24ee "⓮" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xeb,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0xec,0xce,0xae,0x6e,0x06,0xee,0xec,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9455 0x24ef "⓯" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xeb,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x0c,0x7e,0x7e,0x1e,0xee,0x6e,0x9c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9456 0x24f0 "⓰" */
+0x00,0x07,0x1f,0x3f,0x3b,0x73,0x6b,0x7b,0x7b,0x7b,0x20,0x3f,0x1f,0x07,0x00,0x00,
+0x00,0xc0,0xf0,0xf8,0x88,0x7c,0x7c,0x1c,0x6c,0x6c,0x98,0xf8,0xf0,0xc0,0x00,0x00,
+/* 9457 0x24f1 "⓱" */
+0x00,0x07,0x1f,0x3f,0x3b,0x73,0x6b,0x7b,0x7b,0x7b,0x20,0x3f,0x1f,0x07,0x00,0x00,
+0x00,0xc0,0xf0,0xf8,0x08,0xec,0xec,0xdc,0xdc,0xbc,0xb8,0xf8,0xf0,0xc0,0x00,0x00,
+/* 9458 0x24f2 "⓲" */
+0x00,0x07,0x1f,0x3f,0x3b,0x73,0x6b,0x7b,0x7b,0x7b,0x20,0x3f,0x1f,0x07,0x00,0x00,
+0x00,0xc0,0xf0,0xf8,0x98,0x6c,0x6c,0x9c,0x6c,0x6c,0x98,0xf8,0xf0,0xc0,0x00,0x00,
+/* 9459 0x24f3 "⓳" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xeb,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x9c,0x6e,0x6e,0x8e,0xee,0xee,0x9c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9460 0x24f4 "⓴" */
+0x07,0x1f,0x3f,0x7f,0x73,0xed,0xfd,0xfb,0xf7,0xef,0x61,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x9c,0x6e,0x6e,0x6e,0x6e,0x6e,0x9c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9461 0x24f5 "⓵" */
+0x07,0x18,0x23,0x4c,0x50,0x90,0xa1,0xa0,0xa0,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x85,0x85,0x85,0xc9,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9462 0x24f6 "⓶" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa0,0xa0,0xa1,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x45,0x85,0x05,0xc9,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9463 0x24f7 "⓷" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa0,0xa1,0xa0,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x45,0x85,0x45,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9464 0x24f8 "⓸" */
+0x07,0x18,0x23,0x4c,0x50,0x92,0xa2,0xa3,0xa0,0x90,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x85,0xc5,0x85,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9465 0x24f9 "⓹" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa1,0xa1,0xa0,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0xc9,0x05,0x85,0x45,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9466 0x24fa "⓺" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa2,0xa3,0xa2,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x05,0x85,0x45,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9467 0x24fb "⓻" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa0,0xa0,0xa0,0x90,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0xc9,0x45,0x45,0x85,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9468 0x24fc "⓼" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa2,0xa1,0xa2,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x45,0x85,0x45,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9469 0x24fd "⓽" */
+0x07,0x18,0x23,0x4c,0x50,0x91,0xa2,0xa1,0xa0,0x91,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x89,0x45,0xc5,0x45,0x89,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9470 0x24fe "⓾" */
+0x07,0x18,0x23,0x4c,0x50,0x92,0xa6,0xa2,0xa2,0x97,0x50,0x4c,0x23,0x18,0x07,0x00,
+0xe0,0x18,0xc4,0x32,0x0a,0x69,0x95,0x95,0x95,0x69,0x0a,0x32,0xc4,0x18,0xe0,0x00,
+/* 9471 0x24ff "⓿" */
+0x07,0x1f,0x3f,0x7e,0x7d,0xfb,0xfb,0xfb,0xfb,0xfb,0x7d,0x7e,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x7c,0xbe,0xbe,0xbe,0xbe,0xbe,0x7c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 9472 0x2500 "─" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9473 0x2501 "━" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9474 0x2502 "│" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9475 0x2503 "┃" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9476 0x2504 "┄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdb,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9477 0x2505 "┅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdb,0xdb,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9478 0x2506 "┆" */
+0x08,0x08,0x08,0x08,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9479 0x2507 "┇" */
+0x18,0x18,0x18,0x18,0x00,0x00,0x18,0x18,0x18,0x18,0x00,0x00,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9480 0x2508 "┈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9481 0x2509 "┉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9482 0x250a "┊" */
+0x08,0x08,0x08,0x00,0x08,0x08,0x08,0x00,0x08,0x08,0x08,0x00,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9483 0x250b "┋" */
+0x18,0x18,0x18,0x00,0x18,0x18,0x18,0x00,0x18,0x18,0x18,0x00,0x18,0x18,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9484 0x250c "┌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9485 0x250d "┍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9486 0x250e "┎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9487 0x250f "┏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9488 0x2510 "┐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9489 0x2511 "┑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9490 0x2512 "┒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9491 0x2513 "┓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9492 0x2514 "└" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9493 0x2515 "┕" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9494 0x2516 "┖" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9495 0x2517 "┗" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9496 0x2518 "┘" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9497 0x2519 "┙" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9498 0x251a "┚" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9499 0x251b "┛" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9500 0x251c "├" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9501 0x251d "┝" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9502 0x251e "┞" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9503 0x251f "┟" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9504 0x2520 "┠" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9505 0x2521 "┡" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x1f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9506 0x2522 "┢" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9507 0x2523 "┣" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9508 0x2524 "┤" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9509 0x2525 "┥" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9510 0x2526 "┦" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9511 0x2527 "┧" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9512 0x2528 "┨" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9513 0x2529 "┩" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9514 0x252a "┪" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9515 0x252b "┫" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xf8,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9516 0x252c "┬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9517 0x252d "┭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9518 0x252e "┮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9519 0x252f "┯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9520 0x2530 "┰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9521 0x2531 "┱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9522 0x2532 "┲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9523 0x2533 "┳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9524 0x2534 "┴" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9525 0x2535 "┵" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9526 0x2536 "┶" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9527 0x2537 "┷" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9528 0x2538 "┸" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9529 0x2539 "┹" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9530 0x253a "┺" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9531 0x253b "┻" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9532 0x253c "┼" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9533 0x253d "┽" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9534 0x253e "┾" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9535 0x253f "┿" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9536 0x2540 "╀" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9537 0x2541 "╁" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9538 0x2542 "╂" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9539 0x2543 "╃" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9540 0x2544 "╄" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x1f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9541 0x2545 "╅" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9542 0x2546 "╆" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9543 0x2547 "╇" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9544 0x2548 "╈" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xff,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9545 0x2549 "╉" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0xf8,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9546 0x254a "╊" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0x1f,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9547 0x254b "╋" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xff,0xff,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9548 0x254c "╌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9549 0x254d "╍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0xee,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9550 0x254e "╎" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9551 0x254f "╏" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9552 0x2550 "═" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9553 0x2551 "║" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9554 0x2552 "╒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9555 0x2553 "╓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9556 0x2554 "╔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x17,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9557 0x2555 "╕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9558 0x2556 "╖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9559 0x2557 "╗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0xf4,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9560 0x2558 "╘" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9561 0x2559 "╙" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9562 0x255a "╚" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x17,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9563 0x255b "╛" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9564 0x255c "╜" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9565 0x255d "╝" */
+0x14,0x14,0x14,0x14,0x14,0x14,0xf4,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9566 0x255e "╞" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9567 0x255f "╟" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x17,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9568 0x2560 "╠" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x17,0x10,0x17,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9569 0x2561 "╡" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9570 0x2562 "╢" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0xf4,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9571 0x2563 "╣" */
+0x14,0x14,0x14,0x14,0x14,0x14,0xf4,0x04,0xf4,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9572 0x2564 "╤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9573 0x2565 "╥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9574 0x2566 "╦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xf7,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9575 0x2567 "╧" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9576 0x2568 "╨" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9577 0x2569 "╩" */
+0x14,0x14,0x14,0x14,0x14,0x14,0xf7,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9578 0x256a "╪" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9579 0x256b "╫" */
+0x14,0x14,0x14,0x14,0x14,0x14,0x14,0xff,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9580 0x256c "╬" */
+0x14,0x14,0x14,0x14,0x14,0x14,0xf7,0x00,0xf7,0x14,0x14,0x14,0x14,0x14,0x14,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9581 0x256d "╭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9582 0x256e "╮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9583 0x256f "╯" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9584 0x2570 "╰" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9585 0x2571 "╱" */
+0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9586 0x2572 "╲" */
+0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9587 0x2573 "╳" */
+0x81,0x81,0x42,0x42,0x24,0x24,0x18,0x18,0x18,0x18,0x24,0x24,0x42,0x42,0x81,0x81,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9588 0x2574 "╴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9589 0x2575 "╵" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9590 0x2576 "╶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9591 0x2577 "╷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9592 0x2578 "╸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9593 0x2579 "╹" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9594 0x257a "╺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9595 0x257b "╻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9596 0x257c "╼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9597 0x257d "╽" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9598 0x257e "╾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9599 0x257f "╿" */
+0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9600 0x2580 "▀" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9601 0x2581 "▁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9602 0x2582 "▂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9603 0x2583 "▃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9604 0x2584 "▄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9605 0x2585 "▅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9606 0x2586 "▆" */
+0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9607 0x2587 "▇" */
+0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9608 0x2588 "█" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9609 0x2589 "▉" */
+0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9610 0x258a "▊" */
+0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9611 0x258b "▋" */
+0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9612 0x258c "▌" */
+0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9613 0x258d "▍" */
+0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,0xe0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9614 0x258e "▎" */
+0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9615 0x258f "▏" */
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9616 0x2590 "▐" */
+0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9617 0x2591 "░" */
+0x88,0x22,0x88,0x22,0x88,0x22,0x88,0x22,0x88,0x22,0x88,0x22,0x88,0x22,0x88,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9618 0x2592 "▒" */
+0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,0xaa,0x55,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9619 0x2593 "▓" */
+0xee,0xbb,0xee,0xbb,0xee,0xbb,0xee,0xbb,0xee,0xbb,0xee,0xbb,0xee,0xbb,0xee,0xbb,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9620 0x2594 "▔" */
+0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9621 0x2595 "▕" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9622 0x2596 "▖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9623 0x2597 "▗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9624 0x2598 "▘" */
+0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9625 0x2599 "▙" */
+0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9626 0x259a "▚" */
+0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9627 0x259b "▛" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9628 0x259c "▜" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9629 0x259d "▝" */
+0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9630 0x259e "▞" */
+0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9631 0x259f "▟" */
+0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9632 0x25a0 "■" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9633 0x25a1 "□" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9634 0x25a2 "▢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x41,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9635 0x25a3 "▣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x5d,0x5d,0x5d,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9636 0x25a4 "▤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9637 0x25a5 "▥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x55,0x55,0x55,0x55,0x55,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9638 0x25a6 "▦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x55,0x7f,0x55,0x7f,0x55,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9639 0x25a7 "▧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x53,0x49,0x65,0x53,0x49,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9640 0x25a8 "▨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x65,0x49,0x53,0x65,0x49,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9641 0x25a9 "▩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x55,0x6b,0x55,0x6b,0x55,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9642 0x25aa "▪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x3c,0x3c,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9643 0x25ab "▫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9644 0x25ac "▬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9645 0x25ad "▭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x41,0x41,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9646 0x25ae "▮" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x3c,0x3c,0x3c,0x3c,0x3c,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9647 0x25af "▯" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9648 0x25b0 "▰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x7e,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9649 0x25b1 "▱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x42,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9650 0x25b2 "▲" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x3c,0x3c,0x7e,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9651 0x25b3 "△" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x24,0x24,0x42,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9652 0x25b4 "▴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9653 0x25b5 "▵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9654 0x25b6 "▶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x78,0x7e,0x7e,0x78,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9655 0x25b7 "▷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x58,0x46,0x46,0x58,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9656 0x25b8 "▸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x3c,0x3c,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9657 0x25b9 "▹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x2c,0x2c,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9658 0x25ba "►" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x78,0x7e,0x78,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9659 0x25bb "▻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x58,0x46,0x58,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9660 0x25bc "▼" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x7e,0x3c,0x3c,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9661 0x25bd "▽" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x24,0x24,0x18,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9662 0x25be "▾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9663 0x25bf "▿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9664 0x25c0 "◀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1e,0x7e,0x7e,0x1e,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9665 0x25c1 "◁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1a,0x62,0x62,0x1a,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9666 0x25c2 "◂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x3c,0x3c,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9667 0x25c3 "◃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x34,0x34,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9668 0x25c4 "◄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1e,0x7e,0x1e,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9669 0x25c5 "◅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1a,0x62,0x1a,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9670 0x25c6 "◆" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x3e,0x7f,0x3e,0x1c,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9671 0x25c7 "◇" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x41,0x22,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9672 0x25c8 "◈" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x2a,0x5d,0x2a,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9673 0x25c9 "◉" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x59,0x5d,0x4d,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9674 0x25ca "◊" */
+0x00,0x00,0x00,0x18,0x18,0x24,0x24,0x42,0x42,0x24,0x24,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9675 0x25cb "○" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9676 0x25cc "◌" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x41,0x00,0x41,0x00,0x14,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9677 0x25cd "◍" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x36,0x55,0x55,0x55,0x36,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9678 0x25ce "◎" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x49,0x55,0x49,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9679 0x25cf "●" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x3e,0x7f,0x7f,0x7f,0x3e,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9680 0x25d0 "◐" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x32,0x71,0x71,0x71,0x32,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9681 0x25d1 "◑" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x26,0x47,0x47,0x47,0x26,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9682 0x25d2 "◒" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x7f,0x3e,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9683 0x25d3 "◓" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x3e,0x7f,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9684 0x25d4 "◔" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x2e,0x4f,0x4f,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9685 0x25d5 "◕" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x26,0x47,0x47,0x7f,0x3e,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9686 0x25d6 "◖" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x38,0x78,0x78,0x78,0x38,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9687 0x25d7 "◗" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x0e,0x0f,0x0f,0x0f,0x0e,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9688 0x25d8 "◘" */
+0xff,0xff,0xff,0xff,0xff,0xff,0xe7,0xc3,0xc3,0xe7,0xff,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9689 0x25d9 "◙" */
+0xff,0xff,0xff,0xff,0xff,0xe7,0xdb,0xbd,0xbd,0xdb,0xe7,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9690 0x25da "◚" */
+0xff,0xff,0xff,0xff,0xff,0xe7,0xdb,0xbd,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9691 0x25db "◛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbd,0xdb,0xe7,0xff,0xff,0xff,0xff,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9692 0x25dc "◜" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9693 0x25dd "◝" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9694 0x25de "◞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9695 0x25df "◟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9696 0x25e0 "◠" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9697 0x25e1 "◡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9698 0x25e2 "◢" */
+0x01,0x01,0x01,0x03,0x03,0x07,0x07,0x0f,0x0f,0x1f,0x1f,0x3f,0x3f,0x7f,0x7f,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9699 0x25e3 "◣" */
+0x80,0x80,0x80,0xc0,0xc0,0xe0,0xe0,0xf0,0xf0,0xf8,0xf8,0xfc,0xfc,0xfe,0xfe,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9700 0x25e4 "◤" */
+0xff,0xfe,0xfe,0xfc,0xfc,0xf8,0xf8,0xf0,0xf0,0xe0,0xe0,0xc0,0xc0,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9701 0x25e5 "◥" */
+0xff,0x7f,0x7f,0x3f,0x3f,0x1f,0x1f,0x0f,0x0f,0x07,0x07,0x03,0x03,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9702 0x25e6 "◦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9703 0x25e7 "◧" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x72,0x72,0x72,0x72,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9704 0x25e8 "◨" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x4e,0x4e,0x4e,0x4e,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9705 0x25e9 "◩" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x7a,0x72,0x62,0x42,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9706 0x25ea "◪" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x46,0x4e,0x5e,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9707 0x25eb "◫" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9708 0x25ec "◬" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x22,0x2a,0x41,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9709 0x25ed "◭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x34,0x34,0x72,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9710 0x25ee "◮" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x2c,0x2c,0x4e,0x4e,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9711 0x25ef "◯" */
+0x00,0x00,0x01,0x06,0x08,0x10,0x10,0x20,0x20,0x20,0x10,0x10,0x08,0x06,0x01,0x00,
+0x00,0x00,0xc0,0x30,0x08,0x04,0x04,0x02,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9712 0x25f0 "◰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x52,0x72,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9713 0x25f1 "◱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x72,0x52,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9714 0x25f2 "◲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x4e,0x4a,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9715 0x25f3 "◳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x4a,0x4e,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9716 0x25f4 "◴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x52,0x91,0xf1,0x81,0x81,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9717 0x25f5 "◵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0x81,0xf1,0x91,0x52,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9718 0x25f6 "◶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0x81,0x8f,0x89,0x4a,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9719 0x25f7 "◷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x4a,0x89,0x8f,0x81,0x81,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9720 0x25f8 "◸" */
+0xff,0x81,0x81,0x82,0x82,0x84,0x84,0x88,0x88,0x90,0x90,0xa0,0xa0,0xc0,0xc0,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9721 0x25f9 "◹" */
+0xff,0x81,0x81,0x41,0x41,0x21,0x21,0x11,0x11,0x09,0x09,0x05,0x05,0x03,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9722 0x25fa "◺" */
+0x80,0xc0,0xc0,0xa0,0xa0,0x90,0x90,0x88,0x88,0x84,0x84,0x82,0x82,0x81,0x81,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9723 0x25fb "◻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9724 0x25fc "◼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9725 0x25fd "◽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9726 0x25fe "◾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x7c,0x7c,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9727 0x25ff "◿" */
+0x01,0x03,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x21,0x41,0x41,0x81,0x81,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9728 0x2600 "☀" */
+0x00,0x00,0x08,0x49,0x22,0x00,0x1c,0x3e,0x3e,0x1c,0x00,0x22,0x49,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9729 0x2601 "☁" */
+0x00,0x00,0x00,0x00,0x20,0x76,0xff,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9730 0x2602 "☂" */
+0x00,0x00,0x00,0x00,0x1c,0x3e,0x7f,0x08,0x08,0x08,0x08,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9731 0x2603 "☃" */
+0x8b,0x03,0x2f,0x04,0x8a,0x28,0x0a,0x49,0x04,0x47,0x08,0x10,0x78,0x10,0x08,0x07,
+0xc8,0xc0,0xf1,0x24,0x50,0x12,0x50,0x94,0x21,0xe0,0x10,0x88,0x1e,0x88,0x10,0xe0,
+/* 9732 0x2604 "☄" */
+0x00,0x00,0x00,0x22,0x22,0x24,0x24,0x28,0x29,0x02,0x30,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9733 0x2605 "★" */
+0x00,0x01,0x01,0x03,0x03,0x07,0x7f,0x3f,0x1f,0x0f,0x07,0x0f,0x1e,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0xc0,0xfe,0xf8,0xf0,0xe0,0xc0,0xe0,0xf0,0x30,0x08,0x00,
+/* 9734 0x2606 "☆" */
+0x00,0x01,0x01,0x02,0x02,0x04,0x78,0x20,0x10,0x08,0x04,0x09,0x16,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x3c,0x08,0x10,0x20,0x40,0x20,0xd0,0x30,0x08,0x00,
+/* 9735 0x2607 "☇" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x10,0x0a,0x06,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9736 0x2608 "☈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x44,0x48,0x50,0x4a,0x46,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9737 0x2609 "☉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0x99,0x99,0x81,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9738 0x260a "☊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x66,0xa5,0x42,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9739 0x260b "☋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0xa5,0x66,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9740 0x260c "☌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9741 0x260d "☍" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x08,0x30,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9742 0x260e "☎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x63,0x00,0x2a,0x63,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9743 0x260f "☏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x5d,0x3e,0x49,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9744 0x2610 "☐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 9745 0x2611 "☑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x28,0x28,0x29,0x2b,0x2e,0x2c,0x20,0x3f,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x38,0x68,0xc8,0x88,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 9746 0x2612 "☒" */
+0x00,0x00,0x3f,0x20,0x20,0x2c,0x26,0x23,0x21,0x23,0x26,0x2c,0x20,0x3f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x34,0x64,0xc4,0x84,0xc4,0x64,0x34,0x04,0xfc,0x00,0x00,
+/* 9747 0x2613 "☓" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x14,0x14,0x08,0x08,0x14,0x14,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9748 0x2614 "☔" */
+0x05,0x50,0x04,0x41,0x1c,0x3e,0x7f,0x08,0x08,0x08,0x08,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9749 0x2615 "☕" */
+0x00,0x09,0x12,0x12,0x09,0x09,0x12,0x00,0x1f,0x3f,0x2f,0x20,0x20,0x1f,0x00,0x00,
+0x00,0x20,0x40,0x40,0x20,0x20,0x40,0x00,0xc8,0xf4,0xd4,0x14,0x38,0xc0,0x00,0x00,
+/* 9750 0x2616 "☖" */
+0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 9751 0x2617 "☗" */
+0x00,0x01,0x03,0x07,0x0f,0x1f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x00,0x00,
+0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0x00,0x00,
+/* 9752 0x2618 "☘" */
+0x00,0x00,0x02,0x07,0x07,0x33,0x79,0x3f,0x79,0x31,0x02,0x02,0x02,0x04,0x08,0x00,
+0x00,0x00,0x80,0xc0,0xc0,0x98,0x3c,0xf8,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9753 0x2619 "☙" */
+0x00,0x00,0x00,0x01,0x23,0x47,0x4f,0x7f,0x3f,0x0f,0x07,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc8,0xe8,0xe8,0xe8,0xd8,0xdc,0xe4,0xe4,0xe4,0xc4,0x08,0x00,0x00,
+/* 9754 0x261a "☚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x1f,0x1f,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9755 0x261b "☛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x7c,0x7c,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9756 0x261c "☜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x11,0x19,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9757 0x261d "☝" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x1c,0x34,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9758 0x261e "☞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x44,0x4c,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9759 0x261f "☟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x34,0x1c,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9760 0x2620 "☠" */
+0x00,0x00,0xe7,0xa5,0x7e,0x81,0xa5,0xa5,0x81,0x5a,0x5a,0x42,0xbd,0xe7,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9761 0x2621 "☡" */
+0x00,0x00,0x00,0x00,0x38,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9762 0x2622 "☢" */
+0x07,0x18,0x24,0x5c,0x5c,0xbe,0xbe,0xbe,0x81,0x81,0x83,0x43,0x47,0x23,0x18,0x07,
+0xe0,0x18,0x24,0x3a,0x3a,0x7d,0x7d,0x7d,0x81,0x81,0xc1,0xc2,0xe2,0xc4,0x18,0xe0,
+/* 9763 0x2623 "☣" */
+0x00,0x00,0x04,0x08,0x10,0x10,0x13,0x0c,0x3e,0x44,0x85,0x83,0x02,0x04,0x18,0x00,
+0x00,0x00,0x40,0x20,0x10,0x10,0x90,0x60,0xf8,0x44,0x42,0x82,0x80,0x40,0x30,0x00,
+/* 9764 0x2624 "☤" */
+0x00,0x03,0x01,0x7f,0x23,0x1f,0x01,0x0d,0x11,0x0f,0x09,0x07,0x05,0x03,0x05,0x01,
+0x00,0x00,0x00,0xfc,0x88,0xf0,0x00,0x60,0x10,0xe0,0x20,0xc0,0x40,0x80,0x40,0x00,
+/* 9765 0x2625 "☥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x14,0x08,0x3e,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9766 0x2626 "☦" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x10,0xfe,0x10,0x10,0x70,0x1c,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9767 0x2627 "☧" */
+0x00,0x00,0x00,0x00,0x1c,0x12,0x12,0x1c,0x10,0x54,0x38,0x10,0x38,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9768 0x2628 "☨" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9769 0x2629 "☩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x08,0x49,0x7f,0x49,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9770 0x262a "☪" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x40,0xc2,0xc7,0xc2,0x40,0x21,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9771 0x262b "☫" */
+0x00,0x00,0x00,0x05,0x06,0x00,0x15,0x29,0x29,0x29,0x25,0x13,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0x40,0xc0,0x00,0x50,0x28,0x28,0x28,0x48,0x90,0xc0,0x00,0x00,0x00,
+/* 9772 0x262c "☬" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x09,0x1a,0x1a,0x19,0x1c,0x1b,0x11,0x02,0x00,0x00,
+0x00,0x00,0x00,0x80,0xa0,0x90,0xc8,0xac,0xac,0xcc,0x9c,0xec,0xc4,0xa0,0x80,0x00,
+/* 9773 0x262d "☭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x39,0x79,0x0d,0x3e,0x63,0xc1,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9774 0x262e "☮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x49,0x49,0x49,0x5d,0x6b,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9775 0x262f "☯" */
+0x07,0x18,0x20,0x40,0x40,0x9c,0xbe,0xff,0xe7,0xe7,0xff,0x7f,0x7f,0x3f,0x1f,0x07,
+0xe0,0x18,0x04,0x02,0x02,0x31,0x31,0x03,0x83,0xc7,0xff,0xfe,0xfe,0xfc,0xf8,0xe0,
+/* 9776 0x2630 "☰" */
+0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0xfc,0xfc,0x00,0x00,0xfc,0xfc,0x00,0x00,
+/* 9777 0x2631 "☱" */
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0xfc,0xfc,0x00,0x00,0xfc,0xfc,0x00,0x00,
+/* 9778 0x2632 "☲" */
+0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0x7c,0x7c,0x00,0x00,0xfc,0xfc,0x00,0x00,
+/* 9779 0x2633 "☳" */
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,0xfc,0xfc,0x00,0x00,
+/* 9780 0x2634 "☴" */
+0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7c,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0xfc,0xfc,0x00,0x00,0x7c,0x7c,0x00,0x00,
+/* 9781 0x2635 "☵" */
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7c,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0xfc,0xfc,0x00,0x00,0x7c,0x7c,0x00,0x00,
+/* 9782 0x2636 "☶" */
+0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,
+/* 9783 0x2637 "☷" */
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,
+/* 9784 0x2638 "☸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x3e,0x3e,0x77,0x3e,0x3e,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9785 0x2639 "☹" */
+0x00,0x00,0x00,0x3c,0x42,0x81,0xa5,0x81,0x99,0xa5,0x81,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9786 0x263a "☺" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0xa5,0x81,0xa5,0x99,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9787 0x263b "☻" */
+0x00,0x00,0x00,0x00,0x3c,0x7e,0xff,0xdb,0xff,0xdb,0xe7,0x7e,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9788 0x263c "☼" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x2a,0x1c,0x77,0x1c,0x2a,0x49,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9789 0x263d "☽" */
+0x00,0x00,0x00,0x00,0x38,0x0c,0x06,0x05,0x05,0x05,0x05,0x06,0x0c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9790 0x263e "☾" */
+0x00,0x00,0x00,0x00,0x0e,0x18,0x30,0x50,0x50,0x50,0x50,0x30,0x18,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9791 0x263f "☿" */
+0x00,0x00,0x00,0x22,0x22,0x1c,0x22,0x22,0x22,0x1c,0x08,0x3e,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9792 0x2640 "♀" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x08,0x3e,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9793 0x2641 "♁" */
+0x00,0x00,0x00,0x08,0x08,0x3e,0x08,0x08,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9794 0x2642 "♂" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x03,0x05,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9795 0x2643 "♃" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x06,0x0a,0x7e,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9796 0x2644 "♄" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x70,0x20,0x2c,0x32,0x22,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9797 0x2645 "♅" */
+0x00,0x00,0x00,0x00,0x00,0x6b,0x2a,0x3e,0x2a,0x6b,0x08,0x1c,0x14,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9798 0x2646 "♆" */
+0x00,0x00,0x00,0x00,0x08,0x59,0xcb,0x49,0x49,0x49,0x3e,0x08,0x3e,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9799 0x2647 "♇" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9800 0x2648 "♈" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x14,0x14,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9801 0x2649 "♉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x22,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9802 0x264a "♊" */
+0x00,0x00,0x00,0x00,0x41,0x3e,0x14,0x14,0x14,0x14,0x14,0x14,0x3e,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9803 0x264b "♋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x49,0x48,0x30,0x06,0x09,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9804 0x264c "♌" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x12,0x74,0x94,0x94,0x65,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9805 0x264d "♍" */
+0x00,0x00,0x00,0x00,0x54,0x7c,0x55,0x57,0x55,0x55,0x55,0x55,0x06,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9806 0x264e "♎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x77,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9807 0x264f "♏" */
+0x00,0x00,0x00,0x00,0x54,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x55,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9808 0x2650 "♐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x03,0x45,0x29,0x10,0x28,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9809 0x2651 "♑" */
+0x00,0x00,0x00,0x00,0x31,0x4e,0x84,0x08,0x10,0x3c,0x62,0xa2,0xa2,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9810 0x2652 "♒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x54,0x00,0x00,0x2a,0x54,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9811 0x2653 "♓" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x7e,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9812 0x2654 "♔" */
+0x00,0x00,0x00,0x08,0x1c,0x08,0x77,0x5d,0x49,0x49,0x2a,0x7f,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9813 0x2655 "♕" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x49,0x2a,0x2a,0x5d,0x2a,0x3e,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9814 0x2656 "♖" */
+0x00,0x00,0x00,0x00,0x00,0x55,0x7f,0x41,0x41,0x22,0x22,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9815 0x2657 "♗" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x22,0x22,0x22,0x22,0x14,0x77,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9816 0x2658 "♘" */
+0x00,0x00,0x00,0x02,0x1e,0x22,0x42,0x42,0x3a,0x12,0x22,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9817 0x2659 "♙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x24,0x24,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9818 0x265a "♚" */
+0x00,0x00,0x00,0x08,0x1c,0x08,0x77,0x5d,0x49,0x49,0x2a,0x7f,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9819 0x265b "♛" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x49,0x2a,0x2a,0x5d,0x2a,0x3e,0x3e,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9820 0x265c "♜" */
+0x00,0x00,0x00,0x00,0x00,0x55,0x7f,0x7f,0x7f,0x3e,0x3e,0x7f,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9821 0x265d "♝" */
+0x00,0x00,0x00,0x00,0x08,0x1c,0x36,0x22,0x36,0x3e,0x1c,0x7f,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9822 0x265e "♞" */
+0x00,0x00,0x00,0x02,0x1e,0x36,0x7e,0x7e,0x3e,0x1e,0x3e,0x7e,0x7e,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9823 0x265f "♟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,0x3c,0x3c,0x7e,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9824 0x2660 "♠" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x1c,0x3e,0x7f,0x7f,0x7f,0x3e,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9825 0x2661 "♡" */
+0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x41,0x41,0x41,0x22,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9826 0x2662 "♢" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9827 0x2663 "♣" */
+0x00,0x00,0x00,0x00,0x1c,0x1c,0x1c,0x08,0x7f,0x7f,0x6b,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9828 0x2664 "♤" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x22,0x41,0x41,0x41,0x3e,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9829 0x2665 "♥" */
+0x00,0x00,0x00,0x00,0x00,0x36,0x7f,0x7f,0x7f,0x7f,0x3e,0x1c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9830 0x2666 "♦" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x1c,0x1c,0x3e,0x3e,0x1c,0x1c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9831 0x2667 "♧" */
+0x00,0x00,0x00,0x00,0x1c,0x14,0x1c,0x08,0x77,0x5d,0x6b,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9832 0x2668 "♨" */
+0x00,0x00,0x00,0x08,0x51,0x92,0x92,0x92,0x49,0x49,0x49,0x52,0x81,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9833 0x2669 "♩" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x38,0x78,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9834 0x266a "♪" */
+0x00,0x00,0x00,0x00,0x08,0x0c,0x0a,0x0a,0x08,0x08,0x08,0x38,0x78,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9835 0x266b "♫" */
+0x00,0x00,0x00,0x1c,0x17,0x11,0x11,0x11,0x11,0x71,0xf1,0xe7,0x0f,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9836 0x266c "♬" */
+0x00,0x00,0x00,0x1c,0x17,0x11,0x1d,0x17,0x11,0x71,0xf1,0xe7,0x0f,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9837 0x266d "♭" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x5c,0x66,0x46,0x44,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9838 0x266e "♮" */
+0x00,0x00,0x00,0x40,0x40,0x4e,0x7e,0x72,0x42,0x4e,0x7e,0x72,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9839 0x266f "♯" */
+0x00,0x00,0x04,0x24,0x26,0x3e,0x7c,0x64,0x24,0x26,0x3e,0x7c,0x64,0x24,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9840 0x2670 "♰" */
+0x00,0x00,0x00,0x00,0x14,0x08,0x08,0x49,0x3e,0x49,0x08,0x08,0x08,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9841 0x2671 "♱" */
+0x00,0x00,0x00,0x00,0x1c,0x14,0x08,0x6b,0x5d,0x6b,0x08,0x08,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9842 0x2672 "♲" */
+0x03,0x05,0x0a,0x12,0x0a,0x04,0x30,0x48,0x8c,0x50,0xa0,0xae,0x52,0x52,0x1e,0x00,
+0xc0,0x20,0x98,0x48,0xd0,0x30,0x04,0x0a,0x11,0x09,0x05,0x26,0x58,0x86,0x5c,0x20,
+/* 9843 0x2673 "♳" */
+0x03,0x04,0x04,0x08,0x00,0x39,0x1b,0x29,0x21,0x43,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x18,0x38,0x00,0x08,0x84,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9844 0x2674 "♴" */
+0x03,0x04,0x04,0x08,0x00,0x3b,0x18,0x29,0x22,0x43,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x18,0xb8,0x00,0x08,0x84,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9845 0x2675 "♵" */
+0x03,0x04,0x04,0x08,0x00,0x3b,0x18,0x2b,0x20,0x43,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x18,0xb8,0x00,0x88,0x04,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9846 0x2676 "♶" */
+0x03,0x04,0x04,0x08,0x00,0x3a,0x1a,0x2b,0x20,0x40,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x98,0xb8,0x80,0x88,0x84,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9847 0x2677 "♷" */
+0x03,0x04,0x04,0x08,0x00,0x3b,0x1a,0x2b,0x20,0x43,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x98,0x38,0x00,0x88,0x04,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9848 0x2678 "♸" */
+0x03,0x04,0x04,0x08,0x00,0x39,0x1a,0x2b,0x22,0x41,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x98,0x38,0x80,0x48,0x84,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9849 0x2679 "♹" */
+0x03,0x04,0x04,0x08,0x00,0x3b,0x18,0x29,0x21,0x41,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x98,0xb8,0x00,0x08,0x04,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9850 0x267a "♺" */
+0x03,0x04,0x04,0x08,0x00,0x38,0x18,0x28,0x20,0x40,0x40,0x80,0x80,0x7e,0x00,0x00,
+0x80,0x40,0x40,0x20,0x28,0x18,0x38,0x00,0x08,0x04,0x04,0x22,0x42,0xfc,0x40,0x20,
+/* 9851 0x267b "♻" */
+0x03,0x05,0x0e,0x1e,0x0e,0x04,0x30,0x78,0xfc,0x70,0xe0,0xee,0x5e,0x5e,0x1e,0x00,
+0xc0,0xe0,0xf8,0x78,0xf0,0x30,0x04,0x0e,0x1f,0x0f,0x07,0x26,0x78,0xfe,0x7c,0x20,
+/* 9852 0x267c "♼" */
+0x07,0x1f,0x3e,0x7d,0x7b,0xff,0xf7,0xe7,0xf3,0xf7,0xef,0x6f,0x71,0x3f,0x1f,0x07,
+0xe0,0xf8,0x7c,0xbe,0xde,0x8f,0xdf,0xff,0xef,0xef,0xf7,0xb6,0x0e,0xbc,0xf8,0xe0,
+/* 9853 0x267d "♽" */
+0x07,0x18,0x21,0x42,0x44,0x80,0x88,0x98,0x8c,0x88,0x90,0x50,0x4e,0x20,0x18,0x07,
+0xe0,0x18,0x84,0x42,0x22,0x71,0x21,0x01,0x11,0x11,0x09,0x4a,0xf2,0x44,0x18,0xe0,
+/* 9854 0x267e "♾" */
+0x00,0x00,0x00,0x03,0x0c,0x10,0x20,0x26,0x49,0x49,0x26,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x08,0xc8,0x24,0x24,0xc8,0x08,0x10,0x60,0x80,0x00,
+/* 9855 0x267f "♿" */
+0x00,0x00,0x00,0x06,0x06,0x04,0x07,0x04,0x17,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0xe0,0x20,0x10,0x50,0x8c,0x00,0x00,0x00,
+/* 9856 0x2680 "⚀" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,
+/* 9857 0x2681 "⚁" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x14,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x50,0x10,0x10,0xf0,0x00,0x00,0x00,
+/* 9858 0x2682 "⚂" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x14,0x10,0x11,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x50,0x10,0xf0,0x00,0x00,0x00,
+/* 9859 0x2683 "⚃" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x14,0x10,0x10,0x10,0x14,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x50,0x10,0x10,0x10,0x50,0x10,0xf0,0x00,0x00,0x00,
+/* 9860 0x2684 "⚄" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x14,0x10,0x11,0x10,0x14,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x50,0x10,0x10,0x10,0x50,0x10,0xf0,0x00,0x00,0x00,
+/* 9861 0x2685 "⚅" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x14,0x10,0x14,0x10,0x14,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x50,0x10,0x50,0x10,0x50,0x10,0xf0,0x00,0x00,0x00,
+/* 9862 0x2686 "⚆" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x10,0x08,0x04,0x03,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x04,0x64,0x64,0x04,0x08,0x10,0x20,0xc0,0x00,
+/* 9863 0x2687 "⚇" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x20,0x26,0x26,0x20,0x10,0x08,0x04,0x03,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x04,0x64,0x64,0x04,0x08,0x10,0x20,0xc0,0x00,
+/* 9864 0x2688 "⚈" */
+0x00,0x00,0x00,0x03,0x07,0x0f,0x1f,0x3f,0x3f,0x3f,0x3f,0x1f,0x0f,0x07,0x03,0x00,
+0x00,0x00,0x00,0xc0,0xe0,0xf0,0xf8,0xfc,0x9c,0x9c,0xfc,0xf8,0xf0,0xe0,0xc0,0x00,
+/* 9865 0x2689 "⚉" */
+0x00,0x00,0x00,0x03,0x07,0x0f,0x1f,0x3f,0x39,0x39,0x3f,0x1f,0x0f,0x07,0x03,0x00,
+0x00,0x00,0x00,0xc0,0xe0,0xf0,0xf8,0xfc,0x9c,0x9c,0xfc,0xf8,0xf0,0xe0,0xc0,0x00,
+/* 9866 0x268a "⚊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9867 0x268b "⚋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9868 0x268c "⚌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7f,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0xfc,0xfc,0x00,0x00,0x00,0x00,
+/* 9869 0x268d "⚍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7f,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0xfc,0xfc,0x00,0x00,0x00,0x00,
+/* 9870 0x268e "⚎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x00,0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0x00,0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,
+/* 9871 0x268f "⚏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x7c,0x00,0x00,0x7c,0x7c,0x00,0x00,0x00,0x00,
+/* 9872 0x2690 "⚐" */
+0x00,0x00,0x00,0x70,0x4e,0x42,0x42,0x72,0x4e,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9873 0x2691 "⚑" */
+0x00,0x00,0x00,0x70,0x7e,0x7e,0x7e,0x7e,0x4e,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9874 0x2692 "⚒" */
+0x00,0x08,0x5c,0x3e,0x7c,0xf8,0x74,0x22,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x32,0x7c,0x7e,0x1f,0x27,0x43,0x81,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x00,
+/* 9875 0x2693 "⚓" */
+0x00,0x00,0x03,0x04,0x04,0x03,0x01,0x07,0x01,0x21,0x71,0x21,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x80,0x00,0xc0,0x00,0x08,0x1c,0x08,0x10,0xe0,0x00,0x00,
+/* 9876 0x2694 "⚔" */
+0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x28,0x10,0x28,0x40,0x00,0x00,
+0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x28,0x10,0x28,0x04,0x00,0x00,
+/* 9877 0x2695 "⚕" */
+0x00,0x01,0x01,0x0f,0x11,0x11,0x0f,0x01,0x01,0x07,0x09,0x07,0x01,0x03,0x01,0x00,
+0x00,0x00,0x00,0xf0,0x30,0x00,0xc0,0x20,0x20,0xc0,0x00,0x80,0x40,0x80,0x00,0x00,
+/* 9878 0x2696 "⚖" */
+0x00,0x00,0x00,0x01,0x11,0x7f,0x39,0x54,0x54,0x92,0x92,0xfe,0x7c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xfc,0x38,0x54,0x54,0x92,0x92,0xfe,0x7c,0x38,0x00,0x00,
+/* 9879 0x2697 "⚗" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0b,0x0b,0x11,0x10,0x10,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0xf8,0xf8,0xf0,0xe0,0x00,0xf0,0x48,0x44,0x00,0x00,
+/* 9880 0x2698 "⚘" */
+0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x01,0x39,0x3d,0x1d,0x0d,0x03,0x01,0x01,0x00,
+0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x38,0x78,0x70,0x60,0x80,0x00,0x00,0x00,
+/* 9881 0x2699 "⚙" */
+0x00,0x00,0x01,0x21,0x17,0x08,0x10,0x10,0x71,0x10,0x10,0x08,0x17,0x21,0x01,0x00,
+0x00,0x00,0x00,0x08,0xd0,0x20,0x10,0x10,0x1c,0x10,0x10,0x20,0xd0,0x08,0x00,0x00,
+/* 9882 0x269a "⚚" */
+0x00,0x01,0x02,0x39,0x7f,0xfd,0x05,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x80,0x38,0xfc,0x7e,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9883 0x269b "⚛" */
+0x01,0x02,0x02,0x74,0x8e,0x85,0x4e,0x35,0x35,0x4e,0x85,0x8e,0x74,0x02,0x02,0x01,
+0x80,0x40,0x40,0x2e,0x71,0xa1,0x72,0xac,0xac,0x72,0xa1,0x71,0x2e,0x40,0x40,0x80,
+/* 9884 0x269c "⚜" */
+0x01,0x02,0x04,0x34,0x4c,0x84,0xb2,0xca,0x1a,0x10,0x1b,0x0a,0x3a,0x26,0x19,0x01,
+0x00,0x80,0x40,0x58,0x64,0x42,0x9a,0xa6,0xb0,0x10,0xb0,0xa0,0xb8,0xc8,0x30,0x00,
+/* 9885 0x269d "⚝" */
+0x01,0x02,0x04,0x04,0x08,0x6b,0x88,0x88,0x60,0x18,0x06,0x00,0x21,0x26,0x18,0x00,
+0x00,0x80,0x40,0x40,0x00,0xfc,0x02,0x22,0x24,0x10,0x50,0x88,0x08,0x48,0x30,0x00,
+/* 9886 0x269e "⚞" */
+0x30,0x0c,0x03,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x03,0x0c,0x30,0x00,
+0x00,0x00,0x00,0xc0,0x30,0x0c,0x00,0xfc,0x00,0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,
+/* 9887 0x269f "⚟" */
+0x00,0x00,0x00,0x03,0x0c,0x30,0x00,0x3f,0x00,0x30,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xc0,0x30,0x0c,0x00,
+/* 9888 0x26a0 "⚠" */
+0x00,0x01,0x02,0x02,0x04,0x04,0x09,0x09,0x11,0x11,0x21,0x20,0x41,0x40,0x7f,0x00,
+0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0xfc,0x00,
+/* 9889 0x26a1 "⚡" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x7e,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9890 0x26a2 "⚢" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x22,0x22,0x11,0x0e,0x04,0x0e,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x88,0x88,0x10,0xe0,0x40,0xe0,0x40,0x00,0x00,
+/* 9891 0x26a3 "⚣" */
+0x00,0x00,0x00,0x01,0x00,0x01,0x0e,0x11,0x23,0x25,0x1a,0x0c,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xc0,0x40,0x38,0x18,0xa8,0x40,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 9892 0x26a4 "⚤" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x07,0x0a,0x11,0x10,0x08,0x07,0x02,0x07,0x02,0x00,
+0x00,0x38,0x18,0x28,0xc0,0x20,0x10,0x90,0x60,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 9893 0x26a5 "⚥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x01,0x03,0x01,
+0x00,0x00,0x00,0x00,0x70,0x30,0x50,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x80,0x00,
+/* 9894 0x26a6 "⚦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x18,0xa8,0x40,0xa0,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 9895 0x26a7 "⚧" */
+0x00,0x00,0x00,0xe0,0xc0,0xa8,0x10,0x2b,0x04,0x08,0x08,0x04,0x03,0x01,0x03,0x01,
+0x00,0x00,0x00,0x0e,0x06,0x0a,0x10,0xa0,0x40,0x20,0x20,0x40,0x80,0x00,0x80,0x00,
+/* 9896 0x26a8 "⚨" */
+0x00,0x00,0x10,0x38,0x54,0x10,0x38,0x10,0x38,0x44,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9897 0x26a9 "⚩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x44,0xfe,0x44,0x08,0x00,0x00,
+/* 9898 0x26aa "⚪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9899 0x26ab "⚫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x7c,0xfe,0xfe,0xfe,0x7c,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9900 0x26ac "⚬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9901 0x26ad "⚭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x22,0x22,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x88,0x88,0x10,0xe0,0x00,0x00,
+/* 9902 0x26ae "⚮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xb8,0xc4,0xc4,0xc4,0xb8,0x80,0x00,
+/* 9903 0x26af "⚯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x47,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x00,
+/* 9904 0x26b0 "⚰" */
+0x00,0x00,0x0c,0x13,0x20,0x40,0x40,0x40,0x40,0x60,0x53,0x2e,0x1b,0x0c,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x3e,0x02,0x02,0x02,0x02,0x3e,0xc2,0x3e,0xc0,0x00,0x00,0x00,
+/* 9905 0x26b1 "⚱" */
+0x00,0x07,0x02,0x0f,0x10,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0xc0,0x80,0xe0,0x10,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 9906 0x26b2 "⚲" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9907 0x26b3 "⚳" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x04,0x18,0x10,0x7c,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9908 0x26b4 "⚴" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x82,0x44,0x28,0x10,0x10,0x7c,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9909 0x26b5 "⚵" */
+0x00,0x00,0x00,0x00,0x92,0x54,0x38,0xfe,0x38,0x54,0x92,0x10,0x7c,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9910 0x26b6 "⚶" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x39,0x04,0x02,0x79,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x40,0x80,0x3c,0x40,0x80,0x00,0x00,0x00,
+/* 9911 0x26b7 "⚷" */
+0x00,0x00,0x00,0x12,0x14,0x18,0x14,0x12,0x10,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9912 0x26b8 "⚸" */
+0x00,0x00,0x00,0x00,0x1c,0x38,0x70,0x70,0x70,0x38,0x1c,0x08,0x3e,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9913 0x26b9 "⚹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x18,0xff,0x18,0x24,0x42,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9914 0x26ba "⚺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9915 0x26bb "⚻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9916 0x26bc "⚼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x4a,0x7e,0x20,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9917 0x26bd "⚽" */
+0x00,0x00,0x01,0x07,0x0f,0x17,0x10,0x21,0x23,0x39,0x1c,0x18,0x09,0x07,0x01,0x00,
+0x00,0x00,0xc0,0x30,0x38,0x3c,0x04,0xc2,0xe2,0xce,0x1c,0x0c,0xc8,0xf0,0xc0,0x00,
+/* 9918 0x26be "⚾" */
+0x00,0x00,0x01,0x06,0x0c,0x12,0x10,0x21,0x20,0x21,0x10,0x12,0x0c,0x06,0x01,0x00,
+0x00,0x00,0xc0,0x30,0x18,0x24,0x04,0x42,0x02,0x42,0x04,0x24,0x18,0x30,0xc0,0x00,
+/* 9919 0x26bf "⚿" */
+0x00,0x00,0x7f,0x40,0x43,0x44,0x44,0x43,0x41,0x41,0x41,0x41,0x41,0x40,0x7f,0x00,
+0x00,0x00,0xfc,0x04,0x84,0x44,0x44,0x84,0x04,0x04,0x04,0xc4,0x04,0x04,0xfc,0x00,
+/* 9920 0x26c0 "⛀" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x18,0x21,0x21,0x38,0x2f,0x2a,0x1a,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x18,0x84,0x84,0x1c,0xf4,0x54,0x58,0xe0,0x00,0x00,
+/* 9921 0x26c1 "⛁" */
+0x00,0x00,0x07,0x18,0x21,0x21,0x38,0x2f,0x2a,0x3a,0x2f,0x2a,0x1a,0x07,0x00,0x00,
+0x00,0x00,0xe0,0x18,0x84,0x84,0x1c,0xf4,0x54,0x5c,0xf4,0x54,0x58,0xe0,0x00,0x00,
+/* 9922 0x26c2 "⛂" */
+0x00,0x00,0x00,0x00,0x0f,0x38,0x67,0x5e,0x5e,0x47,0x50,0x55,0x65,0x38,0x0f,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x1c,0xe6,0x7a,0x7a,0xe2,0x0a,0xaa,0xa6,0x1c,0xf0,0x00,
+/* 9923 0x26c3 "⛃" */
+0x00,0x0f,0x38,0x67,0x5e,0x5e,0x47,0x50,0x55,0x45,0x50,0x55,0x65,0x38,0x0f,0x00,
+0x00,0xf0,0x1c,0xe6,0x7a,0x7a,0xe2,0x0a,0xaa,0xa2,0x0a,0xaa,0xa6,0x1c,0xf0,0x00,
+/* 9924 0x26c4 "⛄" */
+0x03,0x03,0x0f,0x04,0x0a,0x08,0x0a,0x09,0x04,0x07,0x08,0x10,0x78,0x10,0x08,0x07,
+0xc0,0xc0,0xf0,0x20,0x50,0x10,0x50,0x90,0x20,0xe0,0x10,0x88,0x1e,0x88,0x10,0xe0,
+/* 9925 0x26c5 "⛅" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x07,0x09,0x10,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x20,0x48,0x10,0xc0,0x2c,0xa0,0x60,0x10,0x10,0x60,0x80,0x00,0x00,
+/* 9926 0x26c6 "⛆" */
+0x00,0x22,0x44,0x00,0x10,0x22,0x44,0x00,0x10,0x22,0x44,0x00,0x10,0x22,0x44,0x00,
+0x00,0x22,0x44,0x88,0x00,0x22,0x44,0x88,0x00,0x22,0x44,0x80,0x12,0x24,0x48,0x00,
+/* 9927 0x26c7 "⛇" */
+0x8b,0x03,0x2f,0x07,0x8d,0x2f,0x0d,0x4e,0x07,0x47,0x0f,0x1f,0x7f,0x1f,0x0f,0x07,
+0xc8,0xc0,0xf1,0xe4,0xb0,0xf2,0xb0,0x74,0xe1,0xe0,0xf0,0x78,0xfe,0x78,0xf0,0xe0,
+/* 9928 0x26c8 "⛈" */
+0x00,0x07,0x08,0x10,0x21,0x20,0x11,0x0a,0x07,0x20,0x44,0x00,0x10,0x22,0x44,0x00,
+0x00,0x20,0xcc,0xb2,0x02,0x82,0x04,0x18,0xe0,0x00,0x40,0x80,0x10,0x20,0x40,0x00,
+/* 9929 0x26c9 "⛉" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 9930 0x26ca "⛊" */
+0x00,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x1f,0x0f,0x07,0x03,0x01,0x00,0x00,
+0x00,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,
+/* 9931 0x26cb "⛋" */
+0x00,0x00,0x00,0x7f,0x45,0x48,0x50,0x60,0x40,0x60,0x50,0x48,0x45,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x90,0x50,0x30,0x10,0x30,0x50,0x90,0x10,0xf0,0x00,0x00,
+/* 9932 0x26cc "⛌" */
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 9933 0x26cd "⛍" */
+0x00,0x3c,0x42,0x42,0x81,0xff,0xff,0xff,0x42,0x42,0x00,0x00,0x01,0x02,0x04,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x10,0x08,0x04,0xfe,
+/* 9934 0x26ce "⛎" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x1e,0x25,0x24,0x14,0x04,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x50,0x48,0x48,0xf0,0x40,0x40,0x60,0x00,0x00,
+/* 9935 0x26cf "⛏" */
+0x00,0x40,0x27,0x1c,0x1c,0x3e,0x33,0x21,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x30,0x18,0x0c,0x06,0x00,0x00,
+/* 9936 0x26d0 "⛐" */
+0x00,0x00,0x03,0x05,0x03,0x04,0x00,0x00,0x1c,0x21,0x22,0x1a,0x02,0x3c,0x00,0x00,
+0x00,0xe0,0x10,0xc8,0xf8,0xe8,0x30,0x40,0x00,0x80,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 9937 0x26d1 "⛑" */
+0x00,0x00,0x07,0x1d,0x38,0x7d,0xff,0x40,0x40,0x40,0x20,0x20,0x18,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xe0,0xf0,0xf8,0x10,0x10,0x10,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 9938 0x26d2 "⛒" */
+0x00,0x00,0x07,0x18,0x20,0x50,0x48,0x81,0x82,0x84,0x48,0x50,0x20,0x18,0x07,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x50,0x90,0x08,0x08,0x08,0x90,0x50,0x20,0xc0,0x00,0x00,
+/* 9939 0x26d3 "⛓" */
+0x00,0x22,0x2a,0x1c,0x08,0x1c,0x2a,0x22,0x22,0x2a,0x1c,0x08,0x1c,0x2a,0x22,0x00,
+0x00,0x10,0x38,0x54,0x44,0x44,0x54,0x38,0x10,0x38,0x54,0x44,0x44,0x54,0x38,0x10,
+/* 9940 0x26d4 "⛔" */
+0x00,0x00,0x00,0x07,0x1f,0x3f,0x7f,0x7f,0xc0,0xc0,0x7f,0x7f,0x3f,0x1f,0x07,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0xf0,0xf0,0x18,0x18,0xf0,0xf0,0xe0,0xc0,0x00,0x00,
+/* 9941 0x26d5 "⛕" */
+0x00,0x00,0x0c,0x1e,0x2d,0x0c,0x08,0x0b,0x0a,0x0b,0x08,0x0c,0x0c,0x0c,0x0c,0x00,
+0x00,0x00,0x30,0x30,0x30,0x30,0xe0,0xc0,0x00,0xc0,0xe0,0x30,0xb4,0x78,0x30,0x00,
+/* 9942 0x26d6 "⛖" */
+0x00,0x00,0x01,0x03,0x07,0x0b,0x11,0x2a,0x7b,0x3b,0x1b,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x80,0xc0,0xe0,0xd0,0xd8,0xdc,0xde,0x54,0x88,0xd0,0xe0,0xc0,0x80,0x00,
+/* 9943 0x26d7 "⛗" */
+0x00,0x01,0x02,0x04,0x08,0x14,0x2e,0x55,0x84,0x44,0x24,0x10,0x08,0x04,0x02,0x01,
+0x00,0x80,0x40,0x20,0x10,0x28,0x24,0x22,0x21,0xaa,0x74,0x28,0x10,0x20,0x40,0x80,
+/* 9944 0x26d8 "⛘" */
+0x00,0x00,0x07,0x07,0x07,0x0f,0x1f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x00,0x00,
+0x00,0x00,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0x00,0x00,
+/* 9945 0x26d9 "⛙" */
+0x00,0x00,0x18,0x19,0x19,0x19,0x30,0x61,0xc1,0xc1,0xc0,0xc1,0xc1,0xc1,0x00,0x00,
+0x00,0x00,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+/* 9946 0x26da "⛚" */
+0x00,0x00,0x78,0x78,0x70,0x60,0x00,0x00,0x00,0x00,0x60,0x70,0x78,0x78,0x00,0x00,
+0x00,0x00,0x1e,0x1e,0x0e,0x06,0x00,0x00,0x00,0x00,0x06,0x0e,0x1e,0x1e,0x00,0x00,
+/* 9947 0x26db "⛛" */
+0x00,0x00,0x00,0x00,0x1f,0x18,0x0c,0x0c,0x06,0x07,0x03,0x03,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x30,0x60,0x60,0xc0,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 9948 0x26dc "⛜" */
+0x00,0x00,0x18,0x18,0x18,0x18,0x30,0x60,0xc0,0xc0,0xc4,0xc4,0xc4,0xc4,0x00,0x00,
+0x00,0x00,0x03,0x43,0x43,0x43,0x03,0x43,0x43,0x43,0x03,0x43,0x43,0x43,0x00,0x00,
+/* 9949 0x26dd "⛝" */
+0x00,0x00,0x00,0x3f,0x30,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x30,0x3f,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0xf8,0x00,0x00,
+/* 9950 0x26de "⛞" */
+0x00,0x00,0xfd,0xf8,0xe0,0xd0,0xc8,0x84,0x02,0x81,0xc0,0xc0,0xe0,0xf8,0xfd,0x00,
+0x00,0x00,0xf8,0xf8,0x38,0x18,0x18,0x08,0x00,0x08,0x98,0x58,0x38,0xf8,0xf8,0x00,
+/* 9951 0x26df "⛟" */
+0x00,0x00,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x6f,0x57,0x38,0x10,0x00,0x00,
+0x00,0x00,0xf0,0xf0,0xfc,0xf2,0xf2,0xfe,0xfe,0xfe,0xf6,0xea,0x1c,0x08,0x00,0x00,
+/* 9952 0x26e0 "⛠" */
+0x00,0x7f,0x3e,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x02,0x42,0x42,0x02,0x42,0x42,0x02,0x42,0x42,0x02,0x42,0x42,0x02,0x00,
+/* 9953 0x26e1 "⛡" */
+0x00,0x40,0x60,0x70,0x78,0x70,0x60,0x40,0x40,0x40,0x42,0x46,0x4e,0x5e,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0xfe,0x00,
+/* 9954 0x26e2 "⛢" */
+0x00,0x00,0x00,0x10,0x38,0x7c,0x10,0x10,0x7c,0x82,0xba,0xba,0x82,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9955 0x26e3 "⛣" */
+0x00,0x01,0x19,0x19,0x01,0x01,0x03,0x0c,0x08,0x10,0x10,0x10,0x08,0x0c,0x03,0x00,
+0x00,0x00,0x30,0x30,0x00,0x00,0x80,0x60,0x20,0x10,0x10,0x10,0x20,0x60,0x80,0x00,
+/* 9956 0x26e4 "⛤" */
+0x00,0x01,0x01,0x02,0x02,0x02,0x7f,0x24,0x14,0x0c,0x0a,0x09,0x16,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0xfc,0x48,0x50,0x60,0xa0,0x20,0xd0,0x30,0x08,0x00,
+/* 9957 0x26e5 "⛥" */
+0x00,0x01,0x01,0x02,0x02,0x00,0x7f,0x20,0x14,0x08,0x0a,0x09,0x14,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x5c,0x48,0x10,0x60,0x00,0x20,0xd0,0x30,0x08,0x00,
+/* 9958 0x26e6 "⛦" */
+0x00,0x01,0x01,0x02,0x02,0x02,0x75,0x24,0x10,0x0c,0x00,0x09,0x16,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0xfc,0x08,0x50,0x20,0xa0,0x20,0x50,0x30,0x08,0x00,
+/* 9959 0x26e7 "⛧" */
+0x00,0x20,0x18,0x16,0x09,0x0a,0x0c,0x14,0x24,0x7f,0x02,0x02,0x02,0x01,0x01,0x00,
+0x00,0x08,0x30,0xd0,0x20,0xa0,0x60,0x50,0x48,0xfc,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 9960 0x26e8 "⛨" */
+0x00,0x00,0x00,0x3f,0x20,0x23,0x23,0x2f,0x2f,0x23,0x23,0x20,0x30,0x0c,0x03,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xd0,0xd0,0x10,0x10,0x10,0x30,0xc0,0x00,0x00,
+/* 9961 0x26e9 "⛩" */
+0x00,0x00,0xff,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 9962 0x26ea "⛪" */
+0x01,0x01,0x07,0x01,0x01,0x03,0x07,0x1f,0x7c,0x38,0x33,0x37,0x37,0x37,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0x80,0xc0,0xf0,0x7c,0x38,0x98,0xd8,0xd8,0xd8,0x00,0x00,
+/* 9963 0x26eb "⛫" */
+0x00,0x00,0x00,0x0f,0x08,0x78,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 9964 0x26ec "⛬" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,
+/* 9965 0x26ed "⛭" */
+0x00,0x00,0x00,0x01,0x11,0x0b,0x04,0x08,0x38,0x08,0x04,0x0b,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa0,0x40,0x20,0x38,0x20,0x40,0xa0,0x10,0x00,0x00,0x00,
+/* 9966 0x26ee "⛮" */
+0x00,0x00,0x00,0x01,0x11,0x0b,0x04,0x08,0x78,0x48,0x44,0x0b,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa0,0x44,0x24,0x3c,0x20,0x40,0xa0,0x10,0x00,0x00,0x00,
+/* 9967 0x26ef "⛯" */
+0x00,0x00,0x00,0x01,0x11,0x0b,0x04,0x0b,0x3b,0x0b,0x04,0x0b,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa0,0x40,0xa0,0xb8,0xa0,0x40,0xa0,0x10,0x00,0x00,0x00,
+/* 9968 0x26f0 "⛰" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x08,0x13,0x3f,0x3f,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x18,0xf8,0xfc,0xfc,0xfe,0xfe,0x00,0x00,
+/* 9969 0x26f1 "⛱" */
+0x00,0x07,0x18,0x28,0x47,0x79,0x41,0x02,0x02,0x02,0x04,0x04,0x04,0x7f,0x7f,0x00,
+0x00,0xe0,0x18,0x24,0xe2,0x1e,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xfe,0x00,
+/* 9970 0x26f2 "⛲" */
+0x00,0x14,0x22,0x42,0x40,0x43,0x47,0x07,0x00,0x7f,0x3f,0x0f,0x0f,0x1f,0x3f,0x00,
+0x00,0x50,0x88,0x84,0x04,0x84,0xc4,0xc0,0x00,0xfc,0xf8,0xe0,0xe0,0xf0,0xf8,0x00,
+/* 9971 0x26f3 "⛳" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3d,0x7d,0xfc,0x7e,0x3f,0x07,0x00,
+0x00,0x80,0xe0,0xf8,0x00,0x00,0x00,0x00,0x00,0x78,0x7c,0x7e,0xfc,0xf8,0xc0,0x00,
+/* 9972 0x26f4 "⛴" */
+0x00,0x00,0x03,0x03,0x03,0x07,0x0a,0x12,0x22,0xff,0x3f,0x1f,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x50,0x48,0x48,0xfc,0xf8,0xf8,0xf0,0x00,0x00,0x00,
+/* 9973 0x26f5 "⛵" */
+0x00,0x01,0x01,0x01,0x05,0x0d,0x15,0x25,0x45,0xfd,0x01,0xff,0x3f,0x1f,0x0f,0x00,
+0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0xf8,0x00,0xfc,0xf8,0xf8,0xf0,0x00,
+/* 9974 0x26f6 "⛶" */
+0x00,0x38,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x38,0x00,
+0x00,0x1c,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x1c,0x00,
+/* 9975 0x26f7 "⛷" */
+0x00,0x00,0x38,0x38,0x38,0x06,0x0e,0x7f,0x1c,0x1c,0x0e,0x0f,0x03,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xf0,0x20,0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,
+/* 9976 0x26f8 "⛸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x3f,0x3f,0x08,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xe0,0x40,0xf8,0x00,0x00,
+/* 9977 0x26f9 "⛹" */
+0x00,0x03,0x03,0x03,0x00,0x03,0x07,0x0b,0x13,0x23,0x03,0x06,0x06,0x0c,0x0c,0x78,
+0x00,0x80,0x80,0x80,0x00,0xfc,0x80,0x80,0x8c,0x8c,0x80,0xc0,0xc0,0x60,0x60,0x3c,
+/* 9978 0x26fa "⛺" */
+0x00,0x06,0x05,0x0e,0x0e,0x0e,0x1f,0x1f,0x1f,0x3f,0x3f,0x31,0x71,0x71,0x71,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x82,0x84,0x88,0xc8,0xd0,0xe0,0x00,
+/* 9979 0x26fb "⛻" */
+0x00,0x00,0x07,0x18,0x20,0x30,0x08,0x04,0x04,0x04,0x08,0x30,0x20,0x18,0x07,0x00,
+0x00,0x00,0xc0,0x30,0x08,0x18,0x20,0x40,0x40,0x40,0x20,0x18,0x08,0x30,0xc0,0x00,
+/* 9980 0x26fc "⛼" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x07,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+/* 9981 0x26fd "⛽" */
+0x00,0x00,0x0f,0x1f,0x10,0x10,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x7f,0x00,0x00,
+0x00,0x00,0x80,0xd8,0x44,0x42,0xf2,0xca,0xca,0xca,0xca,0xc4,0xc0,0xf0,0x00,0x00,
+/* 9982 0x26fe "⛾" */
+0x00,0x7f,0x7f,0x70,0x70,0x70,0x70,0x70,0x78,0x7c,0x4f,0x47,0x60,0x78,0x7f,0x00,
+0x00,0xfe,0xfe,0x06,0x1a,0x1a,0x1a,0x06,0x0e,0x1e,0xf2,0xe2,0x06,0x1e,0xfe,0x00,
+/* 9983 0x26ff "⛿" */
+0x00,0x00,0x7f,0x40,0x40,0x7f,0x7f,0x40,0x40,0x7f,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0xfc,0x04,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9984 0x2700 "✀" */
+0x00,0x00,0x38,0x7c,0x6c,0x7f,0x3f,0x03,0x3f,0x7f,0x6c,0x7c,0x38,0x00,0x00,0x00,
+0x00,0x00,0x04,0x1e,0x3c,0x78,0xf0,0xe0,0xf0,0x78,0x3c,0x1e,0x04,0x00,0x00,0x00,
+/* 9985 0x2701 "✁" */
+0x00,0x38,0x7c,0x6c,0x7c,0x3c,0x0e,0x7f,0xff,0xd9,0xf8,0x70,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfe,0xc0,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 9986 0x2702 "✂" */
+0x00,0x00,0x38,0x7c,0x6c,0x7f,0x3f,0x03,0x3f,0x7f,0x6c,0x7c,0x38,0x00,0x00,0x00,
+0x00,0x00,0x06,0x1c,0x38,0x70,0xe0,0xc0,0xe0,0x70,0x38,0x1c,0x06,0x00,0x00,0x00,
+/* 9987 0x2703 "✃" */
+0x00,0x00,0x00,0x00,0x70,0xf8,0xd9,0xff,0x7f,0x0e,0x3c,0x7c,0x6c,0x7c,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0xc0,0xfe,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 9988 0x2704 "✄" */
+0x00,0x00,0x70,0x88,0xae,0x81,0x79,0x06,0x78,0x81,0xae,0x88,0x70,0x00,0x00,0x00,
+0x00,0x00,0x0c,0x32,0x44,0x88,0x10,0x20,0x50,0x88,0x44,0x32,0x0c,0x00,0x00,0x00,
+/* 9989 0x2705 "✅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x51,0x2a,0x24,0x11,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0a,0x12,0x24,0x48,0x90,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 9990 0x2706 "✆" */
+0x07,0x18,0x20,0x41,0x47,0x8f,0x8f,0x9e,0x9c,0x9f,0x4f,0x46,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0xe4,0xf2,0x72,0x62,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 9991 0x2707 "✇" */
+0x07,0x19,0x23,0x43,0x41,0x83,0x87,0x87,0x87,0x8b,0x5c,0x58,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x88,0x84,0x04,0x82,0xc2,0xc2,0xc2,0xa2,0x74,0x34,0x08,0x30,0xc0,0x00,
+/* 9992 0x2708 "✈" */
+0x00,0x08,0x0f,0x06,0x07,0xc3,0xe3,0x7f,0x7f,0xe3,0xc3,0x07,0x06,0x0f,0x08,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x80,0xc0,0xfe,0xfe,0xc0,0x80,0xc0,0x00,0x00,0x00,0x00,
+/* 9993 0x2709 "✉" */
+0x00,0x00,0x00,0x00,0x7f,0x60,0x50,0x49,0x47,0x47,0x49,0x50,0x60,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x06,0x0a,0x92,0xe2,0xe2,0x92,0x0a,0x06,0xfe,0x00,0x00,
+/* 9994 0x270a "✊" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x14,0x35,0x55,0x54,0x54,0x37,0x28,0x10,0x0f,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0xf8,0x04,0xe4,0xc4,0x04,0x08,0x10,0xe0,0x00,
+/* 9995 0x270b "✋" */
+0x00,0x0a,0x15,0x15,0x35,0x55,0x55,0x55,0x40,0x40,0x40,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x40,0x40,0x40,0x4c,0x52,0x22,0x04,0x08,0x10,0x10,0xe0,0x00,0x00,
+/* 9996 0x270c "✌" */
+0x18,0x24,0x22,0x12,0x11,0x09,0x08,0x7c,0x92,0x92,0x92,0x92,0x7c,0x20,0x1f,0x00,
+0x30,0x48,0x88,0x90,0x10,0x20,0x20,0xfc,0x82,0x72,0x22,0x42,0x04,0x08,0xf0,0x00,
+/* 9997 0x270d "✍" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x11,0x23,0x47,0x6f,0x12,0x2f,0x70,0x60,0x00,0x00,
+0x00,0x08,0x1c,0x38,0xf7,0xf5,0xcd,0x85,0x05,0xe5,0x05,0xfd,0x05,0x07,0x00,0x00,
+/* 9998 0x270e "✎" */
+0x00,0x00,0x18,0x26,0x55,0x4a,0x71,0x28,0x14,0x0a,0x05,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xa0,0x50,0x28,0x28,0xc8,0x18,0xf8,0x00,0x00,
+/* 9999 0x270f "✏" */
+0x00,0x00,0x00,0x00,0x3f,0x50,0x8f,0xa8,0x8f,0x50,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x28,0xf4,0x16,0xf4,0x28,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 10000 0x2710 "✐" */
+0x00,0x00,0x00,0x01,0x02,0x05,0x0a,0x14,0x28,0x71,0x4a,0x55,0x26,0x18,0x00,0x00,
+0x00,0x00,0xf8,0x18,0xc8,0x28,0x28,0x50,0xa0,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10001 0x2711 "✑" */
+0x00,0x00,0x00,0x00,0x00,0x79,0x86,0x80,0x86,0x79,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x6c,0xfe,0x6c,0x08,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 10002 0x2712 "✒" */
+0x00,0x00,0x00,0x00,0x00,0x79,0xff,0xff,0xff,0x79,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0x38,0x0e,0x38,0xf0,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 10003 0x2713 "✓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x21,0x12,0x14,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10004 0x2714 "✔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xe0,0xe0,0x70,0x71,0x3b,0x3f,0x1e,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0e,0x1c,0x38,0x70,0xe0,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 10005 0x2715 "✕" */
+0x00,0x00,0x10,0x38,0x1c,0x0e,0x07,0x03,0x07,0x0e,0x1c,0x38,0x10,0x00,0x00,0x00,
+0x00,0x00,0x10,0x38,0x70,0xe0,0xc0,0x80,0xc0,0xe0,0x70,0x38,0x10,0x00,0x00,0x00,
+/* 10006 0x2716 "✖" */
+0x10,0x38,0x7c,0xfe,0x7f,0x3f,0x1f,0x0f,0x1f,0x3f,0x7f,0xfe,0x7c,0x38,0x10,0x00,
+0x10,0x38,0x7c,0xfe,0xfc,0xf8,0xf0,0xe0,0xf0,0xf8,0xfc,0xfe,0x7c,0x38,0x10,0x00,
+/* 10007 0x2717 "✗" */
+0x00,0x60,0x30,0x31,0x1b,0x0e,0x0e,0x1b,0x19,0x30,0x30,0x60,0x60,0x20,0x00,0x00,
+0x00,0x18,0x60,0xc0,0x00,0x00,0x00,0x00,0x80,0xc0,0x60,0x30,0x18,0x00,0x00,0x00,
+/* 10008 0x2718 "✘" */
+0x00,0x60,0x70,0x31,0x3b,0x1f,0x0e,0x1f,0x1b,0x39,0x30,0x70,0x60,0x60,0x20,0x00,
+0x00,0x18,0x70,0xe0,0x80,0x00,0x00,0x00,0x80,0xc0,0xe0,0x70,0x38,0x10,0x00,0x00,
+/* 10009 0x2719 "✙" */
+0x07,0x04,0x05,0x05,0x05,0xfd,0x81,0xbf,0x81,0xfd,0x05,0x05,0x05,0x04,0x07,0x00,
+0xc0,0x40,0x40,0x40,0x40,0x7e,0x02,0xfa,0x02,0x7e,0x40,0x40,0x40,0x40,0xc0,0x00,
+/* 10010 0x271a "✚" */
+0x07,0x07,0x07,0x07,0x07,0xff,0xff,0xff,0xff,0xff,0x07,0x07,0x07,0x07,0x07,0x00,
+0xc0,0xc0,0xc0,0xc0,0xc0,0xfe,0xfe,0xfe,0xfe,0xfe,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,
+/* 10011 0x271b "✛" */
+0x03,0x03,0x03,0x03,0x03,0x03,0xfc,0xfc,0xfc,0x03,0x03,0x03,0x03,0x03,0x03,0x00,
+0x80,0x80,0x80,0x80,0x80,0x80,0x7e,0x7e,0x7e,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 10012 0x271c "✜" */
+0x07,0x07,0x07,0x07,0x07,0xf8,0xf8,0xf8,0xf8,0xf8,0x07,0x07,0x07,0x07,0x07,0x00,
+0xc0,0xc0,0xc0,0xc0,0xc0,0x3e,0x3e,0x3e,0x3e,0x3e,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,
+/* 10013 0x271d "✝" */
+0x00,0x00,0x03,0x03,0x03,0x1f,0x1f,0x1f,0x03,0x03,0x03,0x03,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0xf0,0xf0,0xf0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 10014 0x271e "✞" */
+0x07,0x04,0x04,0x04,0x7c,0x40,0x40,0x7c,0x3c,0x04,0x04,0x04,0x04,0x07,0x03,0x00,
+0x80,0xc0,0xc0,0xc0,0xf8,0x0c,0x0c,0xfc,0xfc,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,
+/* 10015 0x271f "✟" */
+0x00,0x0f,0x08,0x7b,0x43,0x5f,0x5f,0x5f,0x43,0x7b,0x0b,0x0b,0x0b,0x08,0x0f,0x00,
+0x00,0xe0,0x20,0xbc,0x84,0xf4,0xf4,0xf4,0x84,0xbc,0xa0,0xa0,0xa0,0x20,0xe0,0x00,
+/* 10016 0x2720 "✠" */
+0x00,0x0f,0x03,0x21,0x21,0x31,0x3f,0x3f,0x3f,0x31,0x21,0x21,0x03,0x0f,0x00,0x00,
+0x00,0xf8,0xe0,0xc2,0xc2,0xc6,0xfe,0xfe,0xfe,0xc6,0xc2,0xc2,0xe0,0xf8,0x00,0x00,
+/* 10017 0x2721 "✡" */
+0x00,0x00,0x01,0x02,0x04,0x7f,0x24,0x18,0x08,0x18,0x24,0x7f,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x80,0x40,0xfc,0x48,0x30,0x20,0x30,0x48,0xfc,0x40,0x80,0x00,0x00,
+/* 10018 0x2722 "✢" */
+0x03,0x07,0x07,0x03,0x03,0x61,0xf9,0xff,0xf9,0x61,0x03,0x03,0x07,0x07,0x03,0x00,
+0x80,0xc0,0xc0,0x80,0x80,0x0c,0x3e,0xfe,0x3e,0x0c,0x80,0x80,0xc0,0xc0,0x80,0x00,
+/* 10019 0x2723 "✣" */
+0x03,0x07,0x07,0x07,0x03,0x71,0xf9,0xff,0xf9,0x71,0x03,0x07,0x07,0x07,0x03,0x00,
+0x80,0xc0,0xc0,0xc0,0x80,0x1c,0x3e,0xfe,0x3e,0x1c,0x80,0xc0,0xc0,0xc0,0x80,0x00,
+/* 10020 0x2724 "✤" */
+0x07,0x0f,0x0f,0x07,0x63,0xf3,0xff,0xff,0xff,0xf3,0x63,0x07,0x0f,0x0f,0x07,0x00,
+0xc0,0xe0,0xe0,0xc0,0x8c,0x9e,0xfe,0xfe,0xfe,0x9e,0x8c,0xc0,0xe0,0xe0,0xc0,0x00,
+/* 10021 0x2725 "✥" */
+0x01,0x03,0x07,0x07,0x01,0x31,0x71,0xff,0x71,0x31,0x01,0x07,0x07,0x03,0x01,0x00,
+0x00,0x80,0xc0,0xc0,0x00,0x0c,0x0e,0xff,0x0e,0x0c,0x00,0xc0,0xc0,0x80,0x00,0x00,
+/* 10022 0x2726 "✦" */
+0x01,0x03,0x03,0x07,0x07,0x1f,0x7f,0xff,0x7f,0x1f,0x07,0x07,0x03,0x03,0x01,0x00,
+0x00,0x80,0x80,0xc0,0xc0,0xf0,0xfc,0xfe,0xfc,0xf0,0xc0,0xc0,0x80,0x80,0x00,0x00,
+/* 10023 0x2727 "✧" */
+0x01,0x02,0x02,0x04,0x04,0x18,0x60,0x80,0x60,0x18,0x04,0x04,0x02,0x02,0x01,0x00,
+0x00,0x80,0x80,0x40,0x40,0x30,0x0c,0x02,0x0c,0x30,0x40,0x40,0x80,0x80,0x00,0x00,
+/* 10024 0x2728 "✨" */
+0x00,0x04,0x04,0x0a,0x11,0x60,0x11,0x0a,0x04,0x04,0x00,0x00,0x01,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x10,0x10,0x28,0xc6,0x28,0x10,0x10,0x80,0x00,0x00,
+/* 10025 0x2729 "✩" */
+0x00,0x01,0x02,0x02,0xfc,0x40,0x38,0x08,0x10,0x11,0x26,0x28,0x30,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x7e,0x04,0x38,0x20,0x10,0x10,0xc8,0x28,0x18,0x00,0x00,0x00,
+/* 10026 0x272a "✪" */
+0x07,0x1f,0x3e,0x7e,0x7c,0xc0,0xf0,0xf8,0xf0,0xf1,0x67,0x6f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x7c,0x06,0x1e,0x3e,0x1e,0x1e,0xcc,0xec,0xf8,0xf0,0xc0,0x00,
+/* 10027 0x272b "✫" */
+0x00,0x01,0x03,0x03,0xff,0x7c,0x38,0x08,0x1c,0x1f,0x3e,0x38,0x30,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0xfe,0x7c,0x38,0x20,0x70,0xf0,0xf8,0x38,0x18,0x00,0x00,0x00,
+/* 10028 0x272c "✬" */
+0x00,0x01,0x02,0x02,0xfc,0x43,0x27,0x17,0x13,0x10,0x27,0x28,0x30,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x7e,0x84,0xc8,0xd0,0x90,0x10,0xc8,0x28,0x18,0x00,0x00,0x00,
+/* 10029 0x272d "✭" */
+0x00,0x01,0x02,0x1c,0xe1,0x4f,0x23,0x17,0x14,0x11,0x22,0x2c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x80,0x70,0x0e,0xe4,0x88,0xd0,0x50,0x10,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 10030 0x272e "✮" */
+0x00,0x01,0x02,0x1d,0xe3,0x5f,0x2f,0x17,0x16,0x15,0x22,0x2c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x80,0x70,0x8e,0xf4,0xe8,0xd0,0xd0,0x50,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 10031 0x272f "✯" */
+0x00,0x01,0x03,0x05,0xf9,0x5d,0x27,0x13,0x0f,0x1d,0x19,0x32,0x2c,0x30,0x00,0x00,
+0x00,0x00,0x80,0xc0,0xfe,0x8c,0xb8,0xf0,0xd0,0x90,0xd0,0xe8,0x78,0x18,0x00,0x00,
+/* 10032 0x2730 "✰" */
+0x00,0x01,0x02,0x02,0xfc,0x40,0x38,0x08,0x10,0x11,0x27,0x2f,0x3c,0x18,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x7e,0x07,0x3e,0x3c,0x10,0x18,0xc8,0x2c,0x1c,0x0c,0x00,0x00,
+/* 10033 0x2731 "✱" */
+0x00,0x03,0x03,0x03,0x43,0xf3,0x3f,0x0f,0x3f,0xf3,0x43,0x03,0x03,0x03,0x00,0x00,
+0x00,0x80,0x80,0x80,0x84,0x9e,0xfc,0xf0,0xfc,0x9e,0x84,0x80,0x80,0x80,0x00,0x00,
+/* 10034 0x2732 "✲" */
+0x00,0x03,0x03,0x03,0x43,0xf3,0x3c,0x08,0x3c,0xf3,0x43,0x03,0x03,0x03,0x00,0x00,
+0x00,0x80,0x80,0x80,0x84,0x9e,0x7c,0x30,0x7c,0x9e,0x84,0x80,0x80,0x80,0x00,0x00,
+/* 10035 0x2733 "✳" */
+0x01,0x01,0x21,0x11,0x0d,0x0f,0x07,0xff,0x07,0x0f,0x0d,0x11,0x21,0x01,0x01,0x00,
+0x00,0x00,0x08,0x10,0x60,0xe0,0xc0,0xfe,0xc0,0xe0,0x60,0x10,0x08,0x00,0x00,0x00,
+/* 10036 0x2734 "✴" */
+0x01,0x01,0x21,0x1b,0x1f,0x0f,0x1f,0xff,0x1f,0x0f,0x1f,0x1b,0x21,0x01,0x01,0x00,
+0x00,0x00,0x08,0xb0,0xf0,0xe0,0xe0,0xfe,0xf0,0xe0,0xf0,0xb0,0x08,0x00,0x00,0x00,
+/* 10037 0x2735 "✵" */
+0x01,0x02,0x3c,0x2c,0x26,0x32,0x7d,0x83,0x4d,0x3a,0x32,0x26,0x3e,0x02,0x01,0x00,
+0x00,0x80,0xf8,0xc8,0x98,0xb8,0x4c,0x86,0x7c,0x98,0xc8,0x68,0x78,0x80,0x00,0x00,
+/* 10038 0x2736 "✶" */
+0x00,0x01,0x01,0x01,0x43,0x3b,0x1f,0x0f,0x1f,0x3b,0x43,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x84,0xb8,0xf0,0xe0,0xf0,0xb8,0x84,0x00,0x00,0x00,0x00,0x00,
+/* 10039 0x2737 "✷" */
+0x08,0x08,0x0c,0x06,0xe6,0x3b,0x1f,0x07,0x1f,0x3b,0xe6,0x06,0x0c,0x08,0x08,0x00,
+0x20,0x20,0x60,0xc0,0xce,0xb8,0xf0,0xc0,0xf0,0xb8,0xce,0xc0,0x60,0x20,0x20,0x00,
+/* 10040 0x2738 "✸" */
+0x08,0x0c,0x0e,0x0f,0xff,0x7f,0x3f,0x1f,0x3f,0x7f,0xff,0x0f,0x0e,0x0c,0x08,0x00,
+0x20,0x60,0xe0,0xe0,0xfe,0xfc,0xf8,0xf0,0xf8,0xfc,0xfe,0xe0,0xe0,0x60,0x20,0x00,
+/* 10041 0x2739 "✹" */
+0x01,0x19,0x0f,0x4f,0x7f,0x3f,0x3f,0xff,0x3f,0x3f,0x7f,0x4f,0x0f,0x19,0x01,0x00,
+0x00,0x30,0xe0,0xe4,0xfc,0xf8,0xf8,0xfe,0xf8,0xf8,0xfc,0xe4,0xe0,0x30,0x00,0x00,
+/* 10042 0x273a "✺" */
+0x09,0x49,0x25,0x15,0xcb,0x37,0x0f,0xff,0x0f,0x37,0xcb,0x15,0x25,0x49,0x09,0x00,
+0x20,0x24,0x48,0x50,0xa6,0xd8,0xe0,0xfe,0xe0,0xd8,0xa6,0x50,0x48,0x24,0x20,0x00,
+/* 10043 0x273b "✻" */
+0x01,0x03,0x03,0x03,0xe1,0x71,0x0d,0x03,0x0d,0x71,0xe1,0x03,0x03,0x03,0x01,0x00,
+0x00,0x80,0x80,0x80,0x0e,0x1c,0x60,0x80,0x60,0x1c,0x0e,0x80,0x80,0x80,0x00,0x00,
+/* 10044 0x273c "✼" */
+0x03,0x07,0x07,0x63,0xf1,0xf3,0x3c,0x08,0x3c,0xf3,0xf1,0x63,0x07,0x07,0x03,0x00,
+0x80,0xc0,0xc0,0x8c,0x1e,0x9e,0x78,0x20,0x78,0x9e,0x1e,0x8c,0xc0,0xc0,0x80,0x00,
+/* 10045 0x273d "✽" */
+0x03,0x07,0x07,0x63,0xf3,0xf1,0x3d,0x07,0x3d,0xf1,0xf3,0x63,0x07,0x07,0x03,0x00,
+0x80,0xc0,0xc0,0x8c,0x9e,0x1e,0x78,0xc0,0x78,0x1e,0x9e,0x8c,0xc0,0xc0,0x80,0x00,
+/* 10046 0x273e "✾" */
+0x03,0x04,0x04,0x74,0xfc,0xfe,0x7f,0x21,0x43,0x87,0x8f,0x77,0x07,0x07,0x03,0x00,
+0x80,0x40,0x40,0x5c,0x7e,0xfe,0xfc,0x08,0x84,0xc2,0xe2,0xdc,0xc0,0xc0,0x80,0x00,
+/* 10047 0x273f "✿" */
+0x03,0x07,0x0f,0x77,0xff,0xfc,0xf0,0x70,0x18,0x3e,0x7f,0x7e,0x7e,0x3c,0x00,0x00,
+0x80,0xc0,0xe0,0xdc,0xfe,0x7e,0x1e,0x1c,0x30,0xf8,0xfc,0xfc,0xfc,0x78,0x00,0x00,
+/* 10048 0x2740 "❀" */
+0x03,0x04,0x09,0x79,0x85,0xb3,0x8f,0x6f,0x17,0x27,0x49,0x52,0x42,0x3c,0x00,0x00,
+0x80,0x40,0x20,0x3c,0x42,0x9a,0xe2,0xec,0xd0,0xc8,0x24,0x94,0x84,0x78,0x00,0x00,
+/* 10049 0x2741 "❁" */
+0x03,0x3c,0x45,0x51,0x4d,0x6f,0x86,0xbc,0x86,0x6f,0x4d,0x51,0x45,0x3c,0x03,0x00,
+0x80,0x78,0x44,0x14,0x64,0xec,0xc2,0x7a,0xc2,0xec,0x64,0x14,0x44,0x78,0x80,0x00,
+/* 10050 0x2742 "❂" */
+0x07,0x1e,0x3e,0x5c,0x67,0xfc,0xe8,0x88,0xe8,0xfc,0x67,0x5c,0x3e,0x1e,0x07,0x00,
+0xc0,0xf0,0xf8,0x74,0xcc,0x7e,0x2e,0x22,0x2e,0x7e,0xcc,0x74,0xf8,0xf0,0xc0,0x00,
+/* 10051 0x2743 "❃" */
+0x03,0x04,0x04,0x74,0xbc,0x9f,0x4f,0x3f,0x72,0xe6,0xce,0x76,0x06,0x06,0x03,0x00,
+0x80,0xc0,0xc0,0xdc,0xe6,0x9e,0x3c,0xf8,0x64,0x72,0x7a,0x5c,0x40,0x40,0x80,0x00,
+/* 10052 0x2744 "❄" */
+0x00,0x01,0x05,0x03,0xc9,0x31,0x4d,0x03,0x4d,0x31,0xc9,0x03,0x05,0x01,0x00,0x00,
+0x00,0x00,0x40,0x80,0x26,0x18,0x64,0x80,0x64,0x18,0x26,0x80,0x40,0x00,0x00,0x00,
+/* 10053 0x2745 "❅" */
+0x00,0x01,0x05,0x0b,0xc9,0x31,0x4d,0x83,0x4d,0x31,0xc9,0x0b,0x05,0x01,0x00,0x00,
+0x00,0x00,0x40,0xa0,0x26,0x18,0x64,0x82,0x64,0x18,0x26,0xa0,0x40,0x00,0x00,0x00,
+/* 10054 0x2746 "❆" */
+0x09,0x0d,0x07,0x13,0xc9,0x31,0xed,0x03,0xed,0x31,0xc9,0x11,0x07,0x0d,0x09,0x00,
+0x20,0x60,0xc0,0x90,0x26,0x18,0x6e,0x80,0x6e,0x18,0x26,0x10,0xc0,0x60,0x20,0x00,
+/* 10055 0x2747 "❇" */
+0x00,0x03,0x23,0x13,0x09,0x05,0x70,0x7d,0x7d,0x70,0x05,0x09,0x13,0x23,0x03,0x00,
+0x00,0xc0,0xc4,0xc8,0x90,0xa0,0x0e,0xbe,0xbe,0x0e,0xa0,0x90,0xc8,0xc4,0xc0,0x00,
+/* 10056 0x2748 "❈" */
+0x07,0x47,0x27,0x13,0x0b,0xe0,0xfb,0xfb,0xfb,0xe0,0x0b,0x13,0x27,0x47,0x07,0x00,
+0xc0,0xc4,0xc8,0x90,0xa0,0x0e,0xbe,0xbe,0xbe,0x0e,0xa0,0x90,0xc8,0xc4,0xc0,0x00,
+/* 10057 0x2749 "❉" */
+0x03,0x07,0x07,0x77,0xfb,0xf9,0x7d,0x07,0x7d,0xf9,0xfb,0x77,0x07,0x07,0x03,0x00,
+0x80,0xc0,0xc0,0xdc,0xbe,0x3e,0x7c,0xc0,0x7c,0x3e,0xbe,0xdc,0xc0,0xc0,0x80,0x00,
+/* 10058 0x274a "❊" */
+0x01,0x03,0x33,0x31,0x09,0x05,0x63,0xff,0x63,0x05,0x09,0x31,0x33,0x03,0x01,0x00,
+0x00,0x80,0x98,0x18,0x20,0x40,0x8c,0xfe,0x8c,0x40,0x20,0x18,0x98,0x80,0x00,0x00,
+/* 10059 0x274b "❋" */
+0x01,0x03,0x33,0x3b,0x19,0x07,0x77,0xff,0x77,0x07,0x19,0x3b,0x33,0x03,0x01,0x00,
+0x00,0x80,0x98,0xb8,0x30,0xc0,0xdc,0xfe,0xdc,0xc0,0x30,0xb8,0x98,0x80,0x00,0x00,
+/* 10060 0x274c "❌" */
+0x00,0x00,0x18,0x3c,0x1e,0x0f,0x07,0x07,0x0f,0x1e,0x3c,0x38,0x10,0x00,0x00,0x00,
+0x00,0x00,0x30,0x78,0xf0,0xe0,0xc0,0xc0,0xe0,0xf0,0x78,0x38,0x10,0x00,0x00,0x00,
+/* 10061 0x274d "❍" */
+0x00,0x00,0x03,0x0c,0x10,0x10,0x20,0x20,0x20,0x20,0x10,0x10,0x0c,0x03,0x01,0x00,
+0x00,0x00,0xc0,0x30,0x08,0x0c,0x04,0x06,0x06,0x06,0x0e,0x0c,0x3c,0xf8,0xe0,0x00,
+/* 10062 0x274e "❎" */
+0x00,0x7f,0x6f,0x47,0x63,0x71,0x78,0x7c,0x78,0x71,0x63,0x47,0x6f,0x7f,0x00,0x00,
+0x00,0xfc,0xec,0xc4,0x8c,0x1c,0x3c,0x7c,0x3c,0x1c,0x8c,0xc4,0xec,0xfc,0x00,0x00,
+/* 10063 0x274f "❏" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x07,0x07,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0xfe,0xfe,0xfe,0x00,0x00,0x00,
+/* 10064 0x2750 "❐" */
+0x00,0x07,0x07,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0xfe,0xfe,0xfe,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x08,0xf8,0x00,0x00,0x00,
+/* 10065 0x2751 "❑" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x0f,0x07,0x00,0x00,0x00,
+0x00,0xf8,0x0c,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0xfe,0xfe,0xfe,0x00,0x00,0x00,
+/* 10066 0x2752 "❒" */
+0x00,0x07,0x0f,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0xfe,0xfe,0xfe,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x0c,0xf8,0x00,0x00,0x00,
+/* 10067 0x2753 "❓" */
+0x00,0x03,0x0f,0x1e,0x18,0x18,0x01,0x03,0x03,0x03,0x03,0x00,0x03,0x07,0x07,0x03,
+0x00,0x80,0xe0,0x70,0x30,0xf0,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,
+/* 10068 0x2754 "❔" */
+0x07,0x08,0x13,0x14,0x08,0x00,0x01,0x02,0x02,0x02,0x03,0x00,0x03,0x04,0x04,0x03,
+0xc0,0x20,0x90,0x50,0x50,0x90,0x20,0x40,0x80,0x80,0x80,0x00,0x80,0x40,0x40,0x80,
+/* 10069 0x2755 "❕" */
+0x03,0x06,0x0c,0x08,0x0c,0x04,0x06,0x02,0x02,0x03,0x00,0x03,0x04,0x04,0x03,0x00,
+0x80,0xc0,0x60,0x20,0x60,0x40,0xc0,0x80,0x80,0x80,0x00,0x80,0x40,0x40,0x80,0x00,
+/* 10070 0x2756 "❖" */
+0x00,0x01,0x03,0x07,0x03,0x11,0x38,0x7c,0x38,0x11,0x03,0x07,0x03,0x01,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x80,0x10,0x38,0x7c,0x38,0x10,0x80,0xc0,0x80,0x00,0x00,0x00,
+/* 10071 0x2757 "❗" */
+0x01,0x03,0x03,0x03,0x03,0x03,0x03,0x01,0x01,0x01,0x01,0x00,0x01,0x01,0x00,0x00,
+0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00,0x00,
+/* 10072 0x2758 "❘" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 10073 0x2759 "❙" */
+0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x00,
+0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,
+/* 10074 0x275a "❚" */
+0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x0f,0x00,
+0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0xf0,0x00,
+/* 10075 0x275b "❛" */
+0x01,0x07,0x0c,0x0f,0x0f,0x0f,0x0f,0x0f,0x07,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x00,0x00,0x80,0xc0,0xe0,0xe0,0xe0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10076 0x275c "❜" */
+0x03,0x07,0x0f,0x0f,0x0f,0x07,0x03,0x00,0x01,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0xc0,0xe0,0xe0,0xe0,0xe0,0xe0,0x60,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10077 0x275d "❝" */
+0x1c,0x70,0xc0,0xf8,0xfc,0xfe,0xfe,0xfe,0x7c,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x1c,0x70,0xc0,0xf8,0xfc,0xfe,0xfe,0xfe,0x7c,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10078 0x275e "❞" */
+0x38,0x7c,0xfe,0xfe,0xfe,0x7e,0x3e,0x06,0x1c,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x7c,0xfe,0xfe,0xfe,0x7e,0x3e,0x06,0x1c,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10079 0x275f "❟" */
+0x00,0x00,0x00,0x00,0x07,0x0f,0x1f,0x1f,0x1f,0x0f,0x07,0x00,0x03,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x80,0x00,0x00,0x00,
+/* 10080 0x2760 "❠" */
+0x00,0x00,0x00,0x00,0x38,0x7c,0xfe,0xfe,0xfe,0x7e,0x3e,0x06,0x1c,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x7c,0xfe,0xfe,0xfe,0x7e,0x3e,0x06,0x1c,0x70,0x00,0x00,
+/* 10081 0x2761 "❡" */
+0x00,0x00,0x00,0x0f,0x3f,0x7e,0x7e,0x3f,0x0f,0x00,0x30,0x78,0x78,0x31,0x1f,0x00,
+0x00,0x10,0x10,0xfe,0xf8,0x10,0x10,0x10,0xf0,0x10,0x30,0x20,0x60,0xc0,0x00,0x00,
+/* 10082 0x2762 "❢" */
+0x03,0x0f,0x1f,0x1f,0x1f,0x0f,0x03,0x01,0x01,0x00,0x03,0x07,0x07,0x07,0x03,0x00,
+0x80,0xe0,0xf0,0xf0,0xf0,0xe0,0x80,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0x80,0x00,
+/* 10083 0x2763 "❣" */
+0x00,0x0e,0x1f,0x1f,0x1f,0x0f,0x03,0x01,0x00,0x03,0x07,0x07,0x07,0x03,0x00,0x00,
+0x00,0xe0,0xf0,0xf0,0xf0,0xe0,0x80,0x00,0x00,0x80,0xc0,0xc0,0xc0,0x80,0x00,0x00,
+/* 10084 0x2764 "❤" */
+0x00,0x00,0x3c,0x7e,0xff,0xff,0xff,0x7f,0x7f,0x3f,0x1f,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x78,0xfc,0xfe,0xfe,0xfe,0xfc,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,
+/* 10085 0x2765 "❥" */
+0x1c,0x3f,0x7f,0x7f,0x7f,0x7f,0x3f,0x1f,0x3f,0x7f,0x7f,0x7f,0x7f,0x3f,0x1c,0x00,
+0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,
+/* 10086 0x2766 "❦" */
+0x00,0x00,0x1f,0x21,0x01,0x0e,0x1f,0x1f,0x1f,0x0f,0x07,0x03,0x01,0x01,0x00,0x00,
+0x00,0x00,0x04,0xf8,0x80,0x70,0xf8,0xf8,0xf8,0xf0,0xe0,0xc0,0x80,0x90,0xe0,0x00,
+/* 10087 0x2767 "❧" */
+0x00,0x00,0x20,0x13,0x17,0x17,0x17,0x1b,0x3b,0x27,0x27,0x27,0x23,0x10,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc4,0xe2,0xf2,0xfe,0xfc,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,
+/* 10088 0x2768 "❨" */
+0x00,0x00,0x00,0x02,0x04,0x0c,0x18,0x18,0x18,0x18,0x18,0x18,0x0c,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10089 0x2769 "❩" */
+0x00,0x00,0x00,0x20,0x10,0x18,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x18,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10090 0x276a "❪" */
+0x00,0x00,0x00,0x06,0x0c,0x1c,0x38,0x38,0x38,0x38,0x38,0x38,0x1c,0x0c,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10091 0x276b "❫" */
+0x00,0x00,0x00,0x30,0x18,0x1c,0x0e,0x0e,0x0e,0x0e,0x0e,0x0e,0x1c,0x18,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10092 0x276c "❬" */
+0x00,0x00,0x00,0x06,0x0c,0x0c,0x18,0x18,0x30,0x30,0x18,0x18,0x0c,0x0c,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10093 0x276d "❭" */
+0x00,0x00,0x00,0x30,0x18,0x18,0x0c,0x0c,0x06,0x06,0x0c,0x0c,0x18,0x18,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10094 0x276e "❮" */
+0x00,0x00,0x00,0x07,0x0e,0x0e,0x1c,0x1c,0x38,0x38,0x1c,0x1c,0x0e,0x0e,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10095 0x276f "❯" */
+0x00,0x00,0x00,0x70,0x38,0x38,0x1c,0x1c,0x0e,0x0e,0x1c,0x1c,0x38,0x38,0x70,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10096 0x2770 "❰" */
+0x00,0x00,0x00,0x0f,0x1e,0x1e,0x3c,0x3c,0x78,0x78,0x3c,0x3c,0x1e,0x1e,0x0f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10097 0x2771 "❱" */
+0x00,0x00,0x00,0xf0,0x78,0x78,0x3c,0x3c,0x1e,0x1e,0x3c,0x3c,0x78,0x78,0xf0,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10098 0x2772 "❲" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10099 0x2773 "❳" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10100 0x2774 "❴" */
+0x00,0x00,0x00,0x1e,0x38,0x30,0x30,0x18,0x18,0x70,0x18,0x18,0x30,0x30,0x38,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10101 0x2775 "❵" */
+0x00,0x00,0x00,0x78,0x1c,0x0c,0x0c,0x18,0x18,0x0e,0x18,0x18,0x0c,0x0c,0x1c,0x78,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10102 0x2776 "❶" */
+0x07,0x1f,0x3f,0x7e,0x7c,0xfa,0xfe,0xfe,0xfe,0xfe,0x7e,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0xfc,0xfe,0xfe,0xfe,0xfe,0xfe,0xfc,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10103 0x2777 "❷" */
+0x07,0x1f,0x3f,0x7c,0x7b,0xfb,0xff,0xff,0xfe,0xfd,0x7b,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0xbc,0xbe,0xbe,0x7e,0xfe,0xfe,0xfc,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10104 0x2778 "❸" */
+0x07,0x1f,0x3f,0x7c,0x7b,0xfb,0xff,0xfe,0xff,0xfb,0x7b,0x7c,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0xbc,0xbe,0xbe,0x7e,0xbe,0xbe,0xbc,0x7c,0xf8,0xf0,0xc0,0x00,
+/* 10105 0x2779 "❹" */
+0x07,0x1f,0x3f,0x7f,0x7e,0xfd,0xfb,0xf7,0xf0,0xff,0x7f,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0x7c,0x7e,0x7e,0x7e,0x3e,0x7e,0x7c,0x7c,0xf8,0xf0,0xc0,0x00,
+/* 10106 0x277a "❺" */
+0x07,0x1f,0x3f,0x78,0x7b,0xfb,0xfb,0xf8,0xff,0xff,0x7b,0x7c,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0xfc,0xfe,0xfe,0x7e,0xbe,0xbe,0xbc,0x7c,0xf8,0xf0,0xc0,0x00,
+/* 10107 0x277b "❻" */
+0x07,0x1f,0x3f,0x7e,0x7d,0xfb,0xfb,0xf8,0xfb,0xfb,0x7b,0x7c,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0xfc,0xfe,0xfe,0x7e,0xbe,0xbe,0xbc,0x7c,0xf8,0xf0,0xc0,0x00,
+/* 10108 0x277c "❼" */
+0x07,0x1f,0x3f,0x78,0x7f,0xff,0xff,0xff,0xff,0xfe,0x7e,0x7e,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0xbc,0xbe,0x7e,0x7e,0x7e,0xfe,0xfc,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 10109 0x277d "❽" */
+0x07,0x1f,0x3f,0x7c,0x7b,0xfb,0xfb,0xfc,0xfb,0xfb,0x7b,0x7c,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0xbc,0xbe,0xbe,0x7e,0xbe,0xbe,0xbc,0x7c,0xf8,0xf0,0xc0,0x00,
+/* 10110 0x277e "❾" */
+0x07,0x1f,0x3f,0x7c,0x7b,0xfb,0xfb,0xfc,0xff,0xff,0x7f,0x7c,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0xbc,0xbe,0xbe,0x3e,0xbe,0xbe,0x7c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 10111 0x277f "❿" */
+0x07,0x1f,0x3f,0x7f,0x7b,0xf3,0xeb,0xfb,0xfb,0xfb,0x60,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0xfc,0x9c,0x6e,0x6e,0x6e,0x6e,0x6e,0x9c,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 10112 0x2780 "➀" */
+0x07,0x18,0x20,0x40,0x41,0x83,0x81,0x81,0x81,0x81,0x41,0x41,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0x84,0x84,0x82,0x82,0x82,0x82,0x82,0x84,0x84,0x08,0x30,0xc0,0x00,
+/* 10113 0x2781 "➁" */
+0x07,0x18,0x20,0x47,0x4f,0x8c,0x80,0x81,0x87,0x8c,0x4f,0x4f,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0xe4,0x62,0x62,0xc2,0x02,0x02,0xe4,0xe4,0x08,0x30,0xc0,0x00,
+/* 10114 0x2782 "➂" */
+0x07,0x18,0x20,0x47,0x4f,0x8c,0x80,0x81,0x80,0x8c,0x4f,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0xe4,0x62,0x62,0xc2,0x62,0x62,0xe4,0xc4,0x08,0x30,0xc0,0x00,
+/* 10115 0x2783 "➃" */
+0x07,0x18,0x20,0x40,0x41,0x83,0x86,0x8c,0x9f,0x9f,0x40,0x40,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xe4,0xe4,0x62,0x62,0x62,0xf2,0xf2,0x64,0x64,0x08,0x30,0xc0,0x00,
+/* 10116 0x2784 "➄" */
+0x07,0x18,0x20,0x4f,0x4f,0x8c,0x8f,0x8f,0x80,0x8c,0x4f,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xe4,0xe4,0x02,0xc2,0xe2,0x62,0x62,0xe4,0xc4,0x08,0x30,0xc0,0x00,
+/* 10117 0x2785 "➅" */
+0x07,0x18,0x20,0x47,0x4f,0x8c,0x8f,0x8f,0x8c,0x8c,0x4f,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0xe4,0x02,0xc2,0xe2,0x62,0x62,0xe4,0xc4,0x08,0x30,0xc0,0x00,
+/* 10118 0x2786 "➆" */
+0x07,0x18,0x20,0x4f,0x4f,0x80,0x80,0x80,0x83,0x86,0x46,0x46,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xe4,0xe4,0x62,0x62,0xc2,0x82,0x02,0x04,0x04,0x08,0x30,0xc0,0x00,
+/* 10119 0x2787 "➇" */
+0x07,0x18,0x20,0x47,0x4f,0x8c,0x8c,0x87,0x8c,0x8c,0x4f,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0xe4,0x62,0x62,0xc2,0x62,0x62,0xe4,0xc4,0x08,0x30,0xc0,0x00,
+/* 10120 0x2788 "➈" */
+0x07,0x18,0x20,0x47,0x4f,0x8c,0x8c,0x8f,0x87,0x80,0x4f,0x47,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xc4,0xe4,0x62,0x62,0xe2,0xe2,0x62,0xe4,0xc4,0x08,0x30,0xc0,0x00,
+/* 10121 0x2789 "➉" */
+0x07,0x18,0x20,0x44,0x4d,0x9d,0x8d,0x8d,0x8d,0x8d,0x4d,0x4c,0x20,0x18,0x07,0x00,
+0xc0,0x30,0x08,0xe4,0xf4,0xb2,0xb2,0xb2,0xb2,0xb2,0xf4,0xe4,0x08,0x30,0xc0,0x00,
+/* 10122 0x278a "➊" */
+0x07,0x1f,0x3f,0x7f,0x7e,0xfc,0xfe,0xfe,0xfe,0xfe,0x7e,0x7e,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x7c,0x7c,0x7e,0x7e,0x7e,0x7e,0x7e,0x7c,0x7c,0xf8,0xf0,0xc0,0x00,
+/* 10123 0x278b "➋" */
+0x07,0x1f,0x3f,0x78,0x70,0xf3,0xff,0xfe,0xf8,0xf3,0x70,0x70,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0x1c,0x9e,0x9e,0x3e,0xfe,0xfe,0x1c,0x1c,0xf8,0xf0,0xc0,0x00,
+/* 10124 0x278c "➌" */
+0x07,0x1f,0x3f,0x78,0x70,0xf3,0xff,0xfe,0xff,0xf3,0x70,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0x1c,0x9e,0x9e,0x3e,0x9e,0x9e,0x1c,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10125 0x278d "➍" */
+0x07,0x1f,0x3f,0x7f,0x7e,0xfc,0xf9,0xf3,0xe0,0xe0,0x7f,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x1c,0x1c,0x9e,0x9e,0x9e,0x0e,0x0e,0x9c,0x9c,0xf8,0xf0,0xc0,0x00,
+/* 10126 0x278e "➎" */
+0x07,0x1f,0x3f,0x70,0x70,0xf3,0xf0,0xf0,0xff,0xf3,0x70,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x1c,0x1c,0xfe,0x3e,0x1e,0x9e,0x9e,0x1c,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10127 0x278f "➏" */
+0x07,0x1f,0x3f,0x78,0x70,0xf3,0xf0,0xf0,0xf3,0xf3,0x70,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0x1c,0xfe,0x3e,0x1e,0x9e,0x9e,0x1c,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10128 0x2790 "➐" */
+0x07,0x1f,0x3f,0x70,0x70,0xff,0xff,0xff,0xfc,0xf9,0x79,0x79,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x1c,0x1c,0x9e,0x9e,0x3e,0x7e,0xfe,0xfc,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 10129 0x2791 "➑" */
+0x07,0x1f,0x3f,0x78,0x70,0xf3,0xf3,0xf8,0xf3,0xf3,0x70,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0x1c,0x9e,0x9e,0x3e,0x9e,0x9e,0x1c,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10130 0x2792 "➒" */
+0x07,0x1f,0x3f,0x78,0x70,0xf3,0xf3,0xf0,0xf8,0xff,0x70,0x78,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x3c,0x1c,0x9e,0x9e,0x1e,0x1e,0x9e,0x1c,0x3c,0xf8,0xf0,0xc0,0x00,
+/* 10131 0x2793 "➓" */
+0x07,0x1f,0x3f,0x7b,0x72,0xe2,0xf2,0xf2,0xf2,0xf2,0x72,0x73,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0xf8,0x1c,0x0c,0x4e,0x4e,0x4e,0x4e,0x4e,0x0c,0x1c,0xf8,0xf0,0xc0,0x00,
+/* 10132 0x2794 "➔" */
+0x00,0x1f,0x0f,0x07,0x03,0xff,0xff,0xff,0xff,0xff,0x03,0x07,0x0f,0x1f,0x00,0x00,
+0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xfc,0xfe,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,
+/* 10133 0x2795 "➕" */
+0x00,0x00,0x03,0x03,0x03,0x03,0x3f,0x3f,0x3f,0x03,0x03,0x03,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0xf8,0xf8,0xf8,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 10134 0x2796 "➖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10135 0x2797 "➗" */
+0x00,0x00,0x03,0x03,0x03,0x00,0x7f,0x7f,0x7f,0x00,0x03,0x03,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0xfc,0xfc,0xfc,0x00,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 10136 0x2798 "➘" */
+0x00,0x00,0x08,0x1c,0x3e,0x1e,0x0f,0x03,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0xf0,0xf0,0x70,0x08,0x00,0x00,0x00,
+/* 10137 0x2799 "➙" */
+0x00,0x00,0x00,0x01,0x01,0xe0,0xfc,0xff,0xfc,0xe0,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xf0,0xfe,0xf0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10138 0x279a "➚" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x03,0x0f,0x1e,0x3e,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x08,0x70,0xf0,0xf0,0xe0,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10139 0x279b "➛" */
+0x00,0x00,0x00,0x02,0x01,0x01,0x00,0xff,0x00,0x01,0x01,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xf0,0xfe,0xf0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10140 0x279c "➜" */
+0x00,0x00,0x01,0x01,0x00,0x7f,0xff,0xff,0xff,0x7f,0x00,0x01,0x01,0x00,0x00,0x00,
+0x00,0xc0,0xe0,0xf0,0xf8,0xfc,0xfe,0xfe,0xfe,0xfc,0xf8,0xf0,0xe0,0xc0,0x00,0x00,
+/* 10141 0x279d "➝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x18,0x18,0xfc,0xfe,0xfc,0x18,0x18,0x10,0x10,0x00,0x00,0x00,
+/* 10142 0x279e "➞" */
+0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x18,0x18,0xfc,0xfc,0xfe,0xfc,0xfc,0x18,0x18,0x10,0x10,0x00,0x00,
+/* 10143 0x279f "➟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0xaa,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x30,0x38,0xfc,0xfe,0xfc,0x38,0x30,0x20,0x00,0x00,0x00,0x00,
+/* 10144 0x27a0 "➠" */
+0x00,0x00,0x00,0x00,0x00,0xaa,0xaa,0xaa,0xaa,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x30,0xf8,0xfc,0xfe,0xfc,0xf8,0x30,0x20,0x00,0x00,0x00,0x00,
+/* 10145 0x27a1 "➡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x30,0x38,0xfc,0xfe,0xfc,0x38,0x30,0x20,0x00,0x00,0x00,0x00,
+/* 10146 0x27a2 "➢" */
+0x40,0x70,0x2c,0x23,0x10,0x10,0x08,0x07,0x0f,0x1f,0x1f,0x3f,0x3c,0x70,0x40,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x30,0x0c,0xfe,0xfc,0xf0,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 10147 0x27a3 "➣" */
+0x40,0x70,0x3c,0x3f,0x1f,0x1f,0x0f,0x07,0x08,0x10,0x10,0x23,0x2c,0x70,0x40,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xf0,0xfc,0xfe,0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 10148 0x27a4 "➤" */
+0x40,0x70,0x3c,0x3f,0x1f,0x1f,0x0f,0x07,0x0f,0x1f,0x1f,0x3f,0x3c,0x70,0x40,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xf0,0xfc,0xfe,0xfc,0xf0,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 10149 0x27a5 "➥" */
+0x00,0x00,0x00,0x80,0x80,0xc0,0x7f,0x7f,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0xfc,0xfe,0xfc,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10150 0x27a6 "➦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x7f,0x7f,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0xfc,0xfe,0xfc,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10151 0x27a7 "➧" */
+0x00,0x00,0x00,0x00,0x07,0x07,0x07,0x07,0x07,0x07,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0xc0,0xc0,0xe0,0xe0,0xf0,0xe0,0xe0,0xc0,0xc0,0x80,0x80,0x00,0x00,
+/* 10152 0x27a8 "➨" */
+0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xe0,0xf0,0xfe,0xf0,0xe0,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 10153 0x27a9 "➩" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x70,0xd8,0x0c,0x06,0x0c,0xd8,0x70,0x60,0x00,0x00,0x00,0x00,
+/* 10154 0x27aa "➪" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x60,0x60,0x60,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x70,0xe8,0x04,0x02,0x04,0xe8,0x70,0x60,0x00,0x00,0x00,0x00,
+/* 10155 0x27ab "➫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x40,0x80,0xff,0xfe,0x05,0x0f,0x0f,0x0c,0x00,
+0x00,0x00,0x08,0x18,0x24,0x44,0x82,0x02,0x06,0x1e,0x7c,0xf0,0xc0,0x00,0x00,0x00,
+/* 10156 0x27ac "➬" */
+0x00,0x0c,0x0f,0x0f,0x05,0xfe,0xff,0x80,0x40,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xf0,0x7c,0x1e,0x06,0x02,0x82,0x44,0x24,0x18,0x08,0x00,0x00,
+/* 10157 0x27ad "➭" */
+0x00,0x00,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0xff,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xc0,0xa0,0x10,0x08,0x04,0x0e,0x1c,0xb8,0xf0,0xe0,0x40,0x00,0x00,
+/* 10158 0x27ae "➮" */
+0x00,0x00,0x00,0x7f,0xff,0x80,0x80,0x80,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0xe0,0xf0,0xb8,0x1c,0x0e,0x04,0x08,0x10,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 10159 0x27af "➯" */
+0x00,0x00,0x00,0x00,0x00,0xff,0x40,0x40,0x40,0xff,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x60,0x50,0xc8,0x04,0x02,0x07,0xce,0xdc,0x78,0x70,0x20,0x00,0x00,
+/* 10160 0x27b0 "➰" */
+0x00,0x00,0x00,0x00,0x00,0x63,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10161 0x27b1 "➱" */
+0x00,0x00,0x00,0x00,0x7f,0xff,0x40,0x40,0x40,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x70,0x78,0xdc,0xce,0x07,0x02,0x04,0xc8,0x50,0x60,0x40,0x00,0x00,0x00,
+/* 10162 0x27b2 "➲" */
+0x07,0x1f,0x3f,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x3f,0x1f,0x07,0x00,
+0xc0,0xf0,0x78,0x3c,0x1c,0x0e,0x06,0x02,0x06,0x0e,0x1c,0x3c,0x78,0xf0,0xc0,0x00,
+/* 10163 0x27b3 "➳" */
+0x00,0x00,0x00,0x00,0xfe,0x49,0x24,0x1f,0x24,0x49,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x8c,0xfe,0x8c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10164 0x27b4 "➴" */
+0x00,0x00,0x04,0x06,0x07,0x3f,0x1f,0x0f,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x88,0x58,0x38,0x78,0xf8,0x00,0x00,0x00,
+/* 10165 0x27b5 "➵" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x3e,0x1f,0x3e,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10166 0x27b6 "➶" */
+0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x0f,0x1f,0x3f,0x07,0x06,0x04,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x78,0x38,0x58,0x88,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10167 0x27b7 "➷" */
+0x00,0x00,0x02,0x03,0x03,0x03,0x3f,0x1f,0x0f,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x88,0x88,0xd8,0xf8,0x78,0xf8,0xf8,0x00,0x00,0x00,
+/* 10168 0x27b8 "➸" */
+0x00,0x00,0x00,0x00,0xfc,0x7e,0x3f,0x1f,0x3f,0x7e,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x10,0x18,0xfc,0xfe,0xfc,0x18,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 10169 0x27b9 "➹" */
+0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x0f,0x1f,0x3f,0x03,0x03,0x03,0x02,0x00,0x00,
+0x00,0x00,0x00,0xf8,0xf8,0x78,0xf8,0xd8,0x88,0x88,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 10170 0x27ba "➺" */
+0x00,0x00,0x00,0x00,0x00,0x78,0xff,0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0xf0,0xf0,0x38,0x0c,0xfe,0x0c,0x38,0xf0,0xf0,0x60,0x00,0x00,0x00,
+/* 10171 0x27bb "➻" */
+0x00,0x00,0x00,0x00,0x60,0x78,0xfc,0xff,0xfc,0x78,0x60,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0xe0,0xf0,0x78,0xfe,0x78,0xf0,0xe0,0x40,0x00,0x00,0x00,0x00,
+/* 10172 0x27bc "➼" */
+0x00,0x00,0x00,0x00,0xf8,0x7c,0x3e,0x1f,0x3e,0x7c,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0x1c,0xfe,0x1c,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10173 0x27bd "➽" */
+0x00,0x00,0x00,0xf8,0xfc,0x7e,0x7f,0x3f,0x7f,0x7e,0xfc,0xf8,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x70,0x78,0xfc,0xfe,0xfc,0x78,0x70,0x60,0x00,0x00,0x00,0x00,
+/* 10174 0x27be "➾" */
+0x00,0x00,0x00,0x02,0x01,0x00,0xff,0x00,0xff,0x00,0x01,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x10,0x88,0xc4,0x02,0xc4,0x88,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 10175 0x27bf "➿" */
+0x00,0x00,0x00,0x00,0x00,0xe3,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc7,0x38,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 10176 0x27c0 "⟀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x44,0x48,0x50,0x60,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10177 0x27c1 "⟁" */
+0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x09,0x0a,0x12,0x14,0x27,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0xa0,0x90,0x50,0xc8,0x08,0xf8,0x00,0x00,
+/* 10178 0x27c2 "⟂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10179 0x27c3 "⟃" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x30,0x48,0x48,0x30,0x00,0xf8,0x00,0x00,0x00,
+/* 10180 0x27c4 "⟄" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x0c,0x12,0x12,0x0c,0x00,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 10181 0x27c5 "⟅" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x04,0x04,0x08,0x08,0x10,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10182 0x27c6 "⟆" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x10,0x10,0x08,0x08,0x04,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10183 0x27c7 "⟇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x2a,0x22,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10184 0x27c8 "⟈" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x41,0x22,0x22,0x12,0x12,0x09,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 10185 0x27c9 "⟉" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x82,0x44,0x44,0x48,0x48,0x90,0x10,0x00,0x00,0x00,
+/* 10186 0x27ca "⟊" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x38,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10187 0x27cb "⟋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10188 0x27cc "⟌" */
+0x00,0x00,0x3f,0x20,0x10,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x20,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10189 0x27cd "⟍" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 10190 0x27ce "⟎" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x11,0x11,0x12,0x12,0x14,0x14,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x84,0x84,0x44,0x44,0x24,0x24,0x14,0x14,0xfc,0x00,0x00,
+/* 10191 0x27cf "⟏" */
+0x00,0x00,0x00,0x1f,0x14,0x14,0x12,0x12,0x11,0x11,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x14,0x14,0x24,0x24,0x44,0x44,0x84,0x84,0x04,0xfc,0x00,0x00,
+/* 10192 0x27d0 "⟐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x88,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 10193 0x27d1 "⟑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x2a,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10194 0x27d2 "⟒" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10195 0x27d3 "⟓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x12,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10196 0x27d4 "⟔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x48,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10197 0x27d5 "⟕" */
+0x00,0x00,0x00,0x00,0x38,0x0c,0x0a,0x09,0x08,0x08,0x09,0x0a,0x0c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0xc4,0xc4,0x24,0x14,0x0c,0x04,0x00,0x00,
+/* 10198 0x27d6 "⟖" */
+0x00,0x00,0x00,0x00,0x20,0x30,0x28,0x24,0x23,0x23,0x24,0x28,0x30,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x30,0x50,0x90,0x10,0x10,0x90,0x50,0x30,0x1c,0x00,0x00,
+/* 10199 0x27d7 "⟗" */
+0x00,0x00,0x00,0x00,0x70,0x18,0x14,0x12,0x11,0x11,0x12,0x14,0x18,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0e,0x18,0x28,0x48,0x88,0x88,0x48,0x28,0x18,0x0e,0x00,0x00,
+/* 10200 0x27d8 "⟘" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 10201 0x27d9 "⟙" */
+0x00,0x00,0x1f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10202 0x27da "⟚" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x7e,0x02,0x7e,0x02,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xfc,0x80,0xfc,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 10203 0x27db "⟛" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 10204 0x27dc "⟜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x23,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10205 0x27dd "⟝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7f,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10206 0x27de "⟞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0xfe,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 10207 0x27df "⟟" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x38,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10208 0x27e0 "⟠" */
+0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0xfe,0x44,0x44,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10209 0x27e1 "⟡" */
+0x00,0x01,0x02,0x02,0x04,0x08,0x30,0x40,0x30,0x08,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x20,0x18,0x04,0x18,0x20,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 10210 0x27e2 "⟢" */
+0x00,0x00,0x01,0x01,0x02,0x04,0x18,0xe0,0x18,0x04,0x02,0x01,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x20,0x10,0x0c,0x02,0x0c,0x10,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 10211 0x27e3 "⟣" */
+0x00,0x01,0x02,0x02,0x04,0x08,0x30,0x40,0x30,0x08,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x20,0x18,0x07,0x18,0x20,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 10212 0x27e4 "⟤" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,
+/* 10213 0x27e5 "⟥" */
+0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 10214 0x27e6 "⟦" */
+0x00,0x3e,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10215 0x27e7 "⟧" */
+0x00,0x7c,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10216 0x27e8 "⟨" */
+0x00,0x00,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10217 0x27e9 "⟩" */
+0x00,0x00,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10218 0x27ea "⟪" */
+0x00,0x00,0x0a,0x14,0x14,0x28,0x28,0x50,0x50,0x28,0x28,0x14,0x14,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10219 0x27eb "⟫" */
+0x00,0x00,0x50,0x28,0x28,0x14,0x14,0x0a,0x0a,0x14,0x14,0x28,0x28,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10220 0x27ec "⟬" */
+0x00,0x00,0x00,0x02,0x04,0x0c,0x14,0x14,0x14,0x14,0x14,0x14,0x0c,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10221 0x27ed "⟭" */
+0x00,0x00,0x00,0x40,0x20,0x30,0x28,0x28,0x28,0x28,0x28,0x28,0x30,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10222 0x27ee "⟮" */
+0x00,0x00,0x00,0x02,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10223 0x27ef "⟯" */
+0x00,0x00,0x00,0x40,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10224 0x27f0 "⟰" */
+0x00,0x00,0x01,0x02,0x06,0x0a,0x1a,0x2a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xa0,0xb0,0xa8,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0x00,0x00,
+/* 10225 0x27f1 "⟱" */
+0x00,0x00,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x2a,0x1a,0x0a,0x06,0x02,0x01,0x00,0x00,
+0x00,0x00,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa8,0xb0,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 10226 0x27f2 "⟲" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x2a,0x1c,0x08,0x00,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x04,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,0x00,
+/* 10227 0x27f3 "⟳" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x54,0x38,0x10,0x00,0x40,0x80,0x00,0x00,
+/* 10228 0x27f4 "⟴" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x09,0xff,0x09,0x05,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x48,0x24,0xfe,0x24,0x48,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10229 0x27f5 "⟵" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10230 0x27f6 "⟶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10231 0x27f7 "⟷" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10232 0x27f8 "⟸" */
+0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x80,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10233 0x27f9 "⟹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0xfc,0x02,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10234 0x27fa "⟺" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x3f,0x40,0x3f,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0xfc,0x02,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10235 0x27fb "⟻" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10236 0x27fc "⟼" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10237 0x27fd "⟽" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x3f,0x40,0x3f,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,
+/* 10238 0x27fe "⟾" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0xfc,0x02,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10239 0x27ff "⟿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0xd5,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x24,0x5e,0x84,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10240 0x2800 "⠀" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10241 0x2801 "⠁" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10242 0x2802 "⠂" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10243 0x2803 "⠃" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10244 0x2804 "⠄" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10245 0x2805 "⠅" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10246 0x2806 "⠆" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10247 0x2807 "⠇" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10248 0x2808 "⠈" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10249 0x2809 "⠉" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10250 0x280a "⠊" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10251 0x280b "⠋" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10252 0x280c "⠌" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10253 0x280d "⠍" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10254 0x280e "⠎" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10255 0x280f "⠏" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10256 0x2810 "⠐" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10257 0x2811 "⠑" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10258 0x2812 "⠒" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10259 0x2813 "⠓" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10260 0x2814 "⠔" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10261 0x2815 "⠕" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10262 0x2816 "⠖" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10263 0x2817 "⠗" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10264 0x2818 "⠘" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10265 0x2819 "⠙" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10266 0x281a "⠚" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10267 0x281b "⠛" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10268 0x281c "⠜" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10269 0x281d "⠝" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10270 0x281e "⠞" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10271 0x281f "⠟" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10272 0x2820 "⠠" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10273 0x2821 "⠡" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10274 0x2822 "⠢" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10275 0x2823 "⠣" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10276 0x2824 "⠤" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10277 0x2825 "⠥" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10278 0x2826 "⠦" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10279 0x2827 "⠧" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10280 0x2828 "⠨" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10281 0x2829 "⠩" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10282 0x282a "⠪" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10283 0x282b "⠫" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10284 0x282c "⠬" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10285 0x282d "⠭" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10286 0x282e "⠮" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10287 0x282f "⠯" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10288 0x2830 "⠰" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10289 0x2831 "⠱" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10290 0x2832 "⠲" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10291 0x2833 "⠳" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10292 0x2834 "⠴" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10293 0x2835 "⠵" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10294 0x2836 "⠶" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10295 0x2837 "⠷" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10296 0x2838 "⠸" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10297 0x2839 "⠹" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10298 0x283a "⠺" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10299 0x283b "⠻" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10300 0x283c "⠼" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10301 0x283d "⠽" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10302 0x283e "⠾" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10303 0x283f "⠿" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10304 0x2840 "⡀" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10305 0x2841 "⡁" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10306 0x2842 "⡂" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10307 0x2843 "⡃" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10308 0x2844 "⡄" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10309 0x2845 "⡅" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10310 0x2846 "⡆" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10311 0x2847 "⡇" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10312 0x2848 "⡈" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10313 0x2849 "⡉" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10314 0x284a "⡊" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10315 0x284b "⡋" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10316 0x284c "⡌" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10317 0x284d "⡍" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10318 0x284e "⡎" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10319 0x284f "⡏" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10320 0x2850 "⡐" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10321 0x2851 "⡑" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10322 0x2852 "⡒" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10323 0x2853 "⡓" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10324 0x2854 "⡔" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10325 0x2855 "⡕" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10326 0x2856 "⡖" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10327 0x2857 "⡗" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10328 0x2858 "⡘" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10329 0x2859 "⡙" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10330 0x285a "⡚" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10331 0x285b "⡛" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10332 0x285c "⡜" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10333 0x285d "⡝" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10334 0x285e "⡞" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10335 0x285f "⡟" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10336 0x2860 "⡠" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10337 0x2861 "⡡" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10338 0x2862 "⡢" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10339 0x2863 "⡣" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10340 0x2864 "⡤" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10341 0x2865 "⡥" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10342 0x2866 "⡦" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10343 0x2867 "⡧" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10344 0x2868 "⡨" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10345 0x2869 "⡩" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10346 0x286a "⡪" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10347 0x286b "⡫" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10348 0x286c "⡬" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10349 0x286d "⡭" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10350 0x286e "⡮" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10351 0x286f "⡯" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10352 0x2870 "⡰" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10353 0x2871 "⡱" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10354 0x2872 "⡲" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10355 0x2873 "⡳" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10356 0x2874 "⡴" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10357 0x2875 "⡵" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10358 0x2876 "⡶" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10359 0x2877 "⡷" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10360 0x2878 "⡸" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10361 0x2879 "⡹" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10362 0x287a "⡺" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10363 0x287b "⡻" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10364 0x287c "⡼" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10365 0x287d "⡽" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10366 0x287e "⡾" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10367 0x287f "⡿" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10368 0x2880 "⢀" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10369 0x2881 "⢁" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10370 0x2882 "⢂" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10371 0x2883 "⢃" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10372 0x2884 "⢄" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10373 0x2885 "⢅" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10374 0x2886 "⢆" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10375 0x2887 "⢇" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10376 0x2888 "⢈" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10377 0x2889 "⢉" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10378 0x288a "⢊" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10379 0x288b "⢋" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10380 0x288c "⢌" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10381 0x288d "⢍" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10382 0x288e "⢎" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10383 0x288f "⢏" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10384 0x2890 "⢐" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10385 0x2891 "⢑" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10386 0x2892 "⢒" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10387 0x2893 "⢓" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10388 0x2894 "⢔" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10389 0x2895 "⢕" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10390 0x2896 "⢖" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10391 0x2897 "⢗" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10392 0x2898 "⢘" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10393 0x2899 "⢙" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10394 0x289a "⢚" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10395 0x289b "⢛" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10396 0x289c "⢜" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10397 0x289d "⢝" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10398 0x289e "⢞" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10399 0x289f "⢟" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10400 0x28a0 "⢠" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10401 0x28a1 "⢡" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10402 0x28a2 "⢢" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10403 0x28a3 "⢣" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10404 0x28a4 "⢤" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10405 0x28a5 "⢥" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10406 0x28a6 "⢦" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10407 0x28a7 "⢧" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10408 0x28a8 "⢨" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10409 0x28a9 "⢩" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10410 0x28aa "⢪" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10411 0x28ab "⢫" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10412 0x28ac "⢬" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10413 0x28ad "⢭" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10414 0x28ae "⢮" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10415 0x28af "⢯" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10416 0x28b0 "⢰" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10417 0x28b1 "⢱" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10418 0x28b2 "⢲" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10419 0x28b3 "⢳" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10420 0x28b4 "⢴" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10421 0x28b5 "⢵" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10422 0x28b6 "⢶" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10423 0x28b7 "⢷" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10424 0x28b8 "⢸" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10425 0x28b9 "⢹" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10426 0x28ba "⢺" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10427 0x28bb "⢻" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10428 0x28bc "⢼" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10429 0x28bd "⢽" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10430 0x28be "⢾" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10431 0x28bf "⢿" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10432 0x28c0 "⣀" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10433 0x28c1 "⣁" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10434 0x28c2 "⣂" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10435 0x28c3 "⣃" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10436 0x28c4 "⣄" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10437 0x28c5 "⣅" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10438 0x28c6 "⣆" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10439 0x28c7 "⣇" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10440 0x28c8 "⣈" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10441 0x28c9 "⣉" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10442 0x28ca "⣊" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10443 0x28cb "⣋" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10444 0x28cc "⣌" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10445 0x28cd "⣍" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10446 0x28ce "⣎" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10447 0x28cf "⣏" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10448 0x28d0 "⣐" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10449 0x28d1 "⣑" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10450 0x28d2 "⣒" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10451 0x28d3 "⣓" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10452 0x28d4 "⣔" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10453 0x28d5 "⣕" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10454 0x28d6 "⣖" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10455 0x28d7 "⣗" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10456 0x28d8 "⣘" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10457 0x28d9 "⣙" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10458 0x28da "⣚" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10459 0x28db "⣛" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10460 0x28dc "⣜" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10461 0x28dd "⣝" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10462 0x28de "⣞" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10463 0x28df "⣟" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10464 0x28e0 "⣠" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10465 0x28e1 "⣡" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10466 0x28e2 "⣢" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10467 0x28e3 "⣣" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10468 0x28e4 "⣤" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10469 0x28e5 "⣥" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10470 0x28e6 "⣦" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10471 0x28e7 "⣧" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10472 0x28e8 "⣨" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10473 0x28e9 "⣩" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10474 0x28ea "⣪" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10475 0x28eb "⣫" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10476 0x28ec "⣬" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10477 0x28ed "⣭" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10478 0x28ee "⣮" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10479 0x28ef "⣯" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10480 0x28f0 "⣰" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10481 0x28f1 "⣱" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10482 0x28f2 "⣲" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10483 0x28f3 "⣳" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10484 0x28f4 "⣴" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10485 0x28f5 "⣵" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10486 0x28f6 "⣶" */
+0x00,0x00,0x00,0x22,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10487 0x28f7 "⣷" */
+0x00,0x00,0x00,0x32,0x30,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10488 0x28f8 "⣸" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10489 0x28f9 "⣹" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10490 0x28fa "⣺" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10491 0x28fb "⣻" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10492 0x28fc "⣼" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10493 0x28fd "⣽" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10494 0x28fe "⣾" */
+0x00,0x00,0x00,0x26,0x06,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10495 0x28ff "⣿" */
+0x00,0x00,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x36,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10496 0x2900 "⤀" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xff,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0xfe,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10497 0x2901 "⤁" */
+0x00,0x00,0x00,0x00,0x00,0x05,0x05,0xff,0x05,0x05,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0xfe,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10498 0x2902 "⤂" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x3f,0x40,0x3f,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xff,0x80,0xff,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10499 0x2903 "⤃" */
+0x00,0x00,0x00,0x00,0x01,0x01,0xff,0x01,0xff,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0xfc,0x02,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10500 0x2904 "⤄" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x1f,0x20,0x1f,0x08,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x88,0xfc,0x82,0xfc,0x88,0x90,0x00,0x00,0x00,0x00,0x00,
+/* 10501 0x2905 "⤅" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0xfe,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10502 0x2906 "⤆" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x3f,0x40,0x3f,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0xfe,0x02,0xfe,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10503 0x2907 "⤇" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x7f,0x40,0x7f,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0xfc,0x02,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10504 0x2908 "⤈" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x08,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10505 0x2909 "⤉" */
+0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10506 0x290a "⤊" */
+0x00,0x00,0x01,0x03,0x05,0x0d,0x15,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x60,0x50,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 10507 0x290b "⤋" */
+0x00,0x00,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x15,0x0d,0x05,0x03,0x01,0x00,0x00,
+0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x50,0x60,0x40,0x80,0x00,0x00,0x00,
+/* 10508 0x290c "⤌" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10509 0x290d "⤍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10510 0x290e "⤎" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7d,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xef,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10511 0x290f "⤏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xbe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10512 0x2910 "⤐" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x1b,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0x7e,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10513 0x2911 "⤑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xae,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10514 0x2912 "⤒" */
+0x00,0x00,0x7f,0x1c,0x2a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10515 0x2913 "⤓" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x2a,0x1c,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10516 0x2914 "⤔" */
+0x00,0x00,0x00,0x00,0x00,0x41,0x21,0x1f,0x21,0x41,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10517 0x2915 "⤕" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x22,0x1f,0x22,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x84,0xfe,0x84,0x88,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10518 0x2916 "⤖" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x1f,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0xfe,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10519 0x2917 "⤗" */
+0x00,0x00,0x00,0x00,0x00,0x41,0x21,0x1f,0x21,0x41,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0xfe,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10520 0x2918 "⤘" */
+0x00,0x00,0x00,0x00,0x00,0x45,0x25,0x1f,0x25,0x45,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x14,0xfe,0x14,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10521 0x2919 "⤙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0xf8,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10522 0x291a "⤚" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x1f,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10523 0x291b "⤛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x12,0x24,0xf8,0x24,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10524 0x291c "⤜" */
+0x00,0x00,0x00,0x00,0x00,0x48,0x24,0x1f,0x24,0x48,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10525 0x291d "⤝" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x3a,0x7f,0x3a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10526 0x291e "⤞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x44,0x2e,0xff,0x2e,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10527 0x291f "⤟" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x3a,0x7f,0x3a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10528 0x2920 "⤠" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x5c,0xfe,0x5c,0x88,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10529 0x2921 "⤡" */
+0x00,0x3c,0x30,0x28,0x24,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x12,0x0a,0x06,0x1e,0x00,0x00,
+/* 10530 0x2922 "⤢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x24,0x28,0x30,0x3c,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10531 0x2923 "⤣" */
+0x00,0x3c,0x30,0x28,0x24,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x24,0x18,0x00,0x00,
+/* 10532 0x2924 "⤤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x48,0x30,0x00,0x00,
+0x00,0x78,0x18,0x28,0x48,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10533 0x2925 "⤥" */
+0x00,0x30,0x48,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0x28,0x18,0x78,0x00,0x00,
+/* 10534 0x2926 "⤦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x48,0x50,0x60,0x78,0x00,0x00,
+0x00,0x30,0x48,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10535 0x2927 "⤧" */
+0x00,0x78,0x60,0x50,0x48,0x04,0x02,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10536 0x2928 "⤨" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x40,0x80,0x80,0x40,0x20,0x12,0x0a,0x06,0x1e,0x00,
+/* 10537 0x2929 "⤩" */
+0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x01,0x02,0x04,0x48,0x50,0x60,0x78,0x00,0x00,
+0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x12,0x0a,0x06,0x1e,0x00,0x00,
+/* 10538 0x292a "⤪" */
+0x00,0x78,0x60,0x50,0x48,0x04,0x02,0x01,0x01,0x02,0x04,0x48,0x50,0x60,0x78,0x00,
+0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10539 0x292b "⤫" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10540 0x292c "⤬" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x04,0x08,0x10,0x20,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10541 0x292d "⤭" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x00,0x00,0x80,0x40,0x20,0x12,0x0a,0x06,0x1e,0x00,
+/* 10542 0x292e "⤮" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x40,0x80,0x00,0x00,0x20,0x12,0x0a,0x06,0x1e,0x00,
+/* 10543 0x292f "⤯" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10544 0x2930 "⤰" */
+0x00,0x20,0x10,0x08,0x04,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x20,0x12,0x0a,0x06,0x1e,0x00,0x00,
+/* 10545 0x2931 "⤱" */
+0x00,0x78,0x60,0x50,0x48,0x04,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x40,0x80,0x00,0x00,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10546 0x2932 "⤲" */
+0x00,0x78,0x60,0x50,0x48,0x04,0x02,0x01,0x00,0x00,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x1e,0x06,0x0a,0x12,0x20,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 10547 0x2933 "⤳" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10548 0x2934 "⤴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x38,0x54,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10549 0x2935 "⤵" */
+0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x54,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10550 0x2936 "⤶" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x1f,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10551 0x2937 "⤷" */
+0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0xf8,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10552 0x2938 "⤸" */
+0x00,0x00,0x20,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x28,0x28,0x30,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10553 0x2939 "⤹" */
+0x00,0x00,0x04,0x08,0x10,0x10,0x20,0x20,0x20,0x20,0x14,0x14,0x0c,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10554 0x293a "⤺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x2c,0x30,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10555 0x293b "⤻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x0c,0x34,0xc4,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10556 0x293c "⤼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x20,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0x34,0x0c,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10557 0x293d "⤽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x2c,0x30,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x44,0xe0,0x40,0x00,0x00,0x00,0x00,
+/* 10558 0x293e "⤾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x30,0x2c,0x23,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x08,0x04,0x04,0x04,0x08,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 10559 0x293f "⤿" */
+0x00,0x00,0x00,0x08,0x10,0x20,0x20,0x20,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x0c,0x34,0xc4,0x00,0x00,0x00,0x00,0x00,
+/* 10560 0x2940 "⥀" */
+0x00,0x00,0x00,0x01,0x03,0x0d,0x10,0x10,0x20,0x20,0x10,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x80,0x00,0x80,0x60,0x90,0x10,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0x00,
+/* 10561 0x2941 "⥁" */
+0x00,0x00,0x02,0x01,0x03,0x0d,0x12,0x10,0x20,0x20,0x10,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0x00,
+/* 10562 0x2942 "⥂" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x20,0x7e,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10563 0x2943 "⥃" */
+0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x00,0x00,
+/* 10564 0x2944 "⥄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 10565 0x2945 "⥅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x08,0x08,0x3e,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10566 0x2946 "⥆" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0xff,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x20,0x20,0xf8,0x20,0x20,0x00,
+/* 10567 0x2947 "⥇" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x0a,0xff,0x0a,0x11,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x08,0x04,0xfe,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10568 0x2948 "⥈" */
+0x00,0x00,0x00,0x00,0x10,0x23,0x44,0xff,0x44,0x23,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x88,0x44,0xfe,0x44,0x88,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 10569 0x2949 "⥉" */
+0x00,0x00,0x10,0x38,0x54,0x38,0x54,0x10,0x10,0x10,0x38,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10570 0x294a "⥊" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10571 0x294b "⥋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10572 0x294c "⥌" */
+0x00,0x00,0x10,0x18,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x30,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10573 0x294d "⥍" */
+0x00,0x00,0x10,0x30,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10574 0x294e "⥎" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10575 0x294f "⥏" */
+0x00,0x00,0x20,0x30,0x28,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x30,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10576 0x2950 "⥐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10577 0x2951 "⥑" */
+0x00,0x00,0x08,0x18,0x28,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x18,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10578 0x2952 "⥒" */
+0x00,0x00,0x00,0x00,0x00,0x48,0x50,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10579 0x2953 "⥓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x12,0x0a,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10580 0x2954 "⥔" */
+0x00,0x00,0x3e,0x08,0x0c,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10581 0x2955 "⥕" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0a,0x0c,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10582 0x2956 "⥖" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x50,0x48,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10583 0x2957 "⥗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x0a,0x12,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10584 0x2958 "⥘" */
+0x00,0x00,0x3e,0x08,0x18,0x28,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10585 0x2959 "⥙" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x18,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10586 0x295a "⥚" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10587 0x295b "⥛" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10588 0x295c "⥜" */
+0x00,0x00,0x10,0x18,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10589 0x295d "⥝" */
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10590 0x295e "⥞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10591 0x295f "⥟" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10592 0x2960 "⥠" */
+0x00,0x00,0x10,0x30,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10593 0x2961 "⥡" */
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x30,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10594 0x2962 "⥢" */
+0x00,0x00,0x00,0x10,0x20,0x7f,0x00,0x00,0x00,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10595 0x2963 "⥣" */
+0x00,0x00,0x02,0x06,0x0a,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x20,0x30,0x28,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 10596 0x2964 "⥤" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x04,0xfe,0x00,0x00,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,
+/* 10597 0x2965 "⥥" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x06,0x02,0x00,0x00,
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x30,0x20,0x00,0x00,
+/* 10598 0x2966 "⥦" */
+0x00,0x00,0x00,0x10,0x20,0x7f,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x08,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10599 0x2967 "⥧" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x20,0x10,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,
+/* 10600 0x2968 "⥨" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x20,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x04,0xfe,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10601 0x2969 "⥩" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x04,0x08,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10602 0x296a "⥪" */
+0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10603 0x296b "⥫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10604 0x296c "⥬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10605 0x296d "⥭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 10606 0x296e "⥮" */
+0x00,0x00,0x02,0x06,0x0a,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x30,0x20,0x00,0x00,
+/* 10607 0x296f "⥯" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x06,0x02,0x00,0x00,
+0x00,0x00,0x20,0x30,0x28,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 10608 0x2970 "⥰" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x02,0x02,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10609 0x2971 "⥱" */
+0x00,0x00,0x00,0x1f,0x00,0x1f,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x88,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10610 0x2972 "⥲" */
+0x00,0x00,0x00,0x38,0x44,0x03,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x88,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10611 0x2973 "⥳" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x11,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xc0,0x22,0x1c,0x00,0x00,0x00,0x00,
+/* 10612 0x2974 "⥴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x38,0x44,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 10613 0x2975 "⥵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x38,0x44,0x03,0x38,0x44,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x48,0x80,0x00,0x40,0x80,0x00,0x00,
+/* 10614 0x2976 "⥶" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x00,0x02,0x04,0x0f,0x04,0x02,0x00,
+0x00,0x00,0x18,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xf8,0x00,0x00,0x00,
+/* 10615 0x2977 "⥷" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x21,0x7f,0x21,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x06,0x18,0x60,0x80,0xf0,0x80,0x60,0x18,0x06,0x00,0x00,0x00,0x00,
+/* 10616 0x2978 "⥸" */
+0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x00,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x30,0xc0,0x00,0x20,0x10,0xf8,0x10,0x20,0x00,
+/* 10617 0x2979 "⥹" */
+0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x20,0x10,0xf8,0x10,0x20,0x00,
+/* 10618 0x297a "⥺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x12,0x24,0x7f,0x24,0x12,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0xfe,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 10619 0x297b "⥻" */
+0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x02,0x04,0x0f,0x04,0x02,0x00,
+0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 10620 0x297c "⥼" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x40,0x20,0x1f,0x20,0x40,0x40,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10621 0x297d "⥽" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x02,0x7c,0x02,0x01,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10622 0x297e "⥾" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10623 0x297f "⥿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x60,0x00,0x00,
+/* 10624 0x2980 "⦀" */
+0x00,0x00,0x00,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10625 0x2981 "⦁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x7e,0x7e,0x3c,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10626 0x2982 "⦂" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10627 0x2983 "⦃" */
+0x00,0x00,0x1e,0x24,0x24,0x14,0x14,0x24,0x44,0x24,0x14,0x14,0x24,0x24,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10628 0x2984 "⦄" */
+0x00,0x00,0x78,0x24,0x24,0x28,0x28,0x24,0x22,0x24,0x28,0x28,0x24,0x24,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10629 0x2985 "⦅" */
+0x00,0x00,0x00,0x0c,0x18,0x18,0x28,0x28,0x28,0x28,0x28,0x28,0x18,0x18,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10630 0x2986 "⦆" */
+0x00,0x00,0x00,0x30,0x18,0x18,0x14,0x14,0x14,0x14,0x14,0x14,0x18,0x18,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10631 0x2987 "⦇" */
+0x00,0x00,0x00,0x0c,0x14,0x14,0x24,0x24,0x24,0x24,0x24,0x24,0x14,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10632 0x2988 "⦈" */
+0x00,0x00,0x00,0x30,0x28,0x28,0x24,0x24,0x24,0x24,0x24,0x24,0x28,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10633 0x2989 "⦉" */
+0x00,0x00,0x00,0x04,0x0c,0x0c,0x14,0x14,0x24,0x24,0x14,0x14,0x0c,0x0c,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10634 0x298a "⦊" */
+0x00,0x00,0x00,0x20,0x30,0x30,0x28,0x28,0x24,0x24,0x28,0x28,0x30,0x30,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10635 0x298b "⦋" */
+0x00,0x00,0x00,0x0e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0e,0x00,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10636 0x298c "⦌" */
+0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x00,0x70,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10637 0x298d "⦍" */
+0x00,0x00,0x00,0x1e,0x18,0x14,0x12,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10638 0x298e "⦎" */
+0x00,0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x48,0x28,0x18,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10639 0x298f "⦏" */
+0x00,0x00,0x00,0x1e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x14,0x18,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10640 0x2990 "⦐" */
+0x00,0x00,0x00,0x78,0x18,0x28,0x48,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10641 0x2991 "⦑" */
+0x00,0x00,0x00,0x04,0x08,0x08,0x10,0x10,0x26,0x26,0x10,0x10,0x08,0x08,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10642 0x2992 "⦒" */
+0x00,0x00,0x00,0x20,0x10,0x10,0x08,0x08,0x64,0x64,0x08,0x08,0x10,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10643 0x2993 "⦓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x0d,0x11,0x0d,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x8c,0xf0,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0xf0,0x8c,0x40,
+/* 10644 0x2994 "⦔" */
+0x00,0x00,0x00,0x01,0x18,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x18,0x01,
+0x00,0x00,0x00,0x00,0x80,0x80,0xc0,0x60,0x58,0x44,0x58,0x60,0xc0,0x80,0x80,0x00,
+/* 10645 0x2995 "⦕" */
+0x00,0x00,0x00,0x00,0x19,0x07,0x03,0x02,0x02,0x02,0x02,0x02,0x01,0x07,0x18,0x00,
+0x00,0x00,0x00,0xa0,0x40,0x40,0x80,0xe0,0x98,0x84,0x98,0x60,0xc0,0x40,0xa0,0x00,
+/* 10646 0x2996 "⦖" */
+0x00,0x00,0x00,0x02,0x01,0x01,0x00,0x03,0x0c,0x10,0x0c,0x03,0x01,0x01,0x02,0x00,
+0x00,0x00,0x00,0x80,0x4c,0x70,0xe0,0xa0,0xa0,0xa0,0xa0,0x20,0xc0,0x70,0x8c,0x00,
+/* 10647 0x2997 "⦗" */
+0x00,0x00,0x00,0x0c,0x18,0x38,0x38,0x38,0x38,0x38,0x38,0x38,0x38,0x18,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10648 0x2998 "⦘" */
+0x00,0x00,0x00,0x30,0x18,0x1c,0x1c,0x1c,0x1c,0x1c,0x1c,0x1c,0x1c,0x18,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10649 0x2999 "⦙" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x08,0x00,0x00,0x08,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10650 0x299a "⦚" */
+0x00,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10651 0x299b "⦛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x28,0x10,0x28,0x24,0x7e,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10652 0x299c "⦜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x70,0x50,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10653 0x299d "⦝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x78,0x44,0x54,0x44,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10654 0x299e "⦞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x9c,0x20,0x18,0x04,0x38,0x00,0xfe,0x00,0x00,
+/* 10655 0x299f "⦟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x20,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10656 0x29a0 "⦠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x30,0x28,0x26,0x28,0x30,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10657 0x29a1 "⦡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x3e,0x63,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10658 0x29a2 "⦢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10659 0x29a3 "⦣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10660 0x29a4 "⦤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x7e,0x00,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10661 0x29a5 "⦥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x7e,0x00,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10662 0x29a6 "⦦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10663 0x29a7 "⦧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10664 0x29a8 "⦨" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x78,0x18,0x28,0xc8,0xc0,0x20,0x20,0x10,0x10,0x10,0xfe,0x10,0x00,
+/* 10665 0x29a9 "⦩" */
+0x00,0x00,0x00,0x0f,0x0c,0x0a,0x09,0x01,0x02,0x02,0x04,0x04,0x04,0x3f,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x40,0x20,0x10,0x08,0x04,0xfe,0x00,0x00,
+/* 10666 0x29aa "⦪" */
+0x00,0x00,0x00,0x00,0x3f,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0xfe,0x10,0x10,0x10,0x20,0x20,0xc0,0xc8,0x28,0x18,0x78,0x00,
+/* 10667 0x29ab "⦫" */
+0x00,0x00,0x00,0x04,0x3f,0x04,0x04,0x04,0x02,0x02,0x01,0x09,0x0a,0x0c,0x0f,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x04,0x08,0x10,0x20,0x40,0x80,0x80,0x40,0x00,0x00,0x00,
+/* 10668 0x29ac "⦬" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x3e,0x11,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x10,
+0x00,0x00,0x00,0x00,0x00,0x3c,0x0c,0x94,0x64,0x60,0x90,0x00,0x00,0x00,0x00,0x00,
+/* 10669 0x29ad "⦭" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x30,0x29,0x26,0x06,0x09,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x7c,0x88,0x08,0x08,0x08,0x88,0x48,0x28,0x18,0x08,
+/* 10670 0x29ae "⦮" */
+0x00,0x00,0x00,0x10,0x18,0x14,0x12,0x11,0x10,0x10,0x10,0x11,0x3e,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x60,0x64,0x94,0x0c,0x3c,0x00,0x00,
+/* 10671 0x29af "⦯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x06,0x26,0x29,0x30,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x88,0x7c,0x08,0x08,0x08,
+/* 10672 0x29b0 "⦰" */
+0x00,0x00,0x00,0x00,0x00,0x17,0x08,0x14,0x12,0x11,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x90,0x50,0x20,0xd0,0x00,0x00,
+/* 10673 0x29b1 "⦱" */
+0x00,0x00,0x00,0x07,0x00,0x07,0x08,0x10,0x10,0x11,0x12,0x14,0x08,0x17,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10674 0x29b2 "⦲" */
+0x00,0x01,0x02,0x01,0x00,0x07,0x08,0x10,0x10,0x11,0x12,0x14,0x08,0x17,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10675 0x29b3 "⦳" */
+0x01,0x00,0x0f,0x00,0x01,0x07,0x08,0x10,0x10,0x11,0x12,0x14,0x08,0x17,0x00,0x00,
+0x00,0x80,0xc0,0x80,0x00,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10676 0x29b4 "⦴" */
+0x02,0x04,0x0f,0x04,0x02,0x07,0x08,0x10,0x10,0x11,0x12,0x14,0x08,0x17,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10677 0x29b5 "⦵" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x3f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xf8,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10678 0x29b6 "⦶" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10679 0x29b7 "⦷" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x12,0x12,0x12,0x12,0x12,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x90,0x90,0x90,0x90,0x20,0xc0,0x00,0x00,
+/* 10680 0x29b8 "⦸" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x14,0x12,0x11,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x90,0x50,0x20,0xc0,0x00,0x00,
+/* 10681 0x29b9 "⦹" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x11,0x11,0x17,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0xd0,0x20,0xc0,0x00,0x00,
+/* 10682 0x29ba "⦺" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x11,0x1f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xf0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10683 0x29bb "⦻" */
+0x00,0x00,0x00,0x00,0x00,0x17,0x08,0x14,0x12,0x11,0x12,0x14,0x08,0x17,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xd0,0x20,0x50,0x90,0x10,0x90,0x50,0x20,0xd0,0x00,0x00,
+/* 10684 0x29bc "⦼" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x12,0x10,0x10,0x11,0x12,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x24,0x44,0x84,0x04,0x24,0x08,0x10,0xe0,0x00,0x00,
+/* 10685 0x29bd "⦽" */
+0x00,0x01,0x03,0x05,0x01,0x07,0x09,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x01,0x00,
+0x00,0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10686 0x29be "⦾" */
+0x00,0x00,0x00,0x03,0x04,0x09,0x12,0x14,0x14,0x14,0x12,0x09,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xc8,0x24,0x14,0x14,0x14,0x24,0xc8,0x10,0xe0,0x00,0x00,
+/* 10687 0x29bf "⦿" */
+0x00,0x00,0x00,0x03,0x04,0x09,0x13,0x17,0x17,0x17,0x13,0x09,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xc8,0xe4,0xf4,0xf4,0xf4,0xe4,0xc8,0x10,0xe0,0x00,0x00,
+/* 10688 0x29c0 "⧀" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x13,0x14,0x13,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0xc4,0x04,0x04,0x04,0xc4,0x08,0x10,0xe0,0x00,0x00,
+/* 10689 0x29c1 "⧁" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x11,0x10,0x10,0x10,0x11,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x84,0x64,0x14,0x64,0x84,0x08,0x10,0xe0,0x00,0x00,
+/* 10690 0x29c2 "⧂" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x40,0x40,0x40,0x20,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x48,0x54,0x48,0x40,0x80,0x00,0x00,0x00,
+/* 10691 0x29c3 "⧃" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x3c,0x20,0x3c,0x20,0x40,0x80,0x00,0x00,
+/* 10692 0x29c4 "⧄" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x0c,0x14,0x24,0x44,0x84,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 10693 0x29c5 "⧅" */
+0x00,0x00,0x00,0x1f,0x18,0x14,0x12,0x11,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x24,0x14,0x0c,0xfc,0x00,0x00,
+/* 10694 0x29c6 "⧆" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x14,0x12,0x11,0x12,0x14,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x84,0x94,0xa4,0xc4,0xa4,0x94,0x84,0x04,0xfc,0x00,0x00,
+/* 10695 0x29c7 "⧇" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x11,0x12,0x12,0x12,0x11,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xc4,0x24,0x24,0x24,0xc4,0x04,0x04,0xfc,0x00,0x00,
+/* 10696 0x29c8 "⧈" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x13,0x12,0x12,0x12,0x13,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0xfc,0x00,0x00,
+/* 10697 0x29c9 "⧉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x23,0x22,0x22,0x3f,0x02,0x02,0x02,0x03,0x00,0x00,
+0x00,0x00,0xc0,0x40,0x40,0x40,0xfc,0x44,0x44,0xc4,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 10698 0x29ca "⧊" */
+0x00,0x01,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0xfc,0x00,
+/* 10699 0x29cb "⧋" */
+0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x7f,0x00,0x7f,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0xfc,0x00,0xfc,
+/* 10700 0x29cc "⧌" */
+0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x09,0x0a,0x11,0x10,0x23,0x20,0x7f,0x00,
+0x00,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0xc8,0x08,0x84,0x44,0x82,0x02,0xff,0x00,
+/* 10701 0x29cd "⧍" */
+0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0xff,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0xfe,0x00,0x00,
+/* 10702 0x29ce "⧎" */
+0x18,0x16,0x11,0x10,0x10,0x10,0x11,0x16,0x18,0x03,0x0c,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x80,0x60,0x10,0x60,0x80,0x30,0xd0,0x10,0x10,0x10,0x10,0x10,0xd0,0x30,
+/* 10703 0x29cf "⧏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x20,0x18,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x68,0xa8,0x28,0x28,0x28,0x28,0x28,0xa8,0x68,0x00,0x00,
+/* 10704 0x29d0 "⧐" */
+0x00,0x00,0x00,0x00,0x00,0x2c,0x2b,0x28,0x28,0x28,0x28,0x28,0x2b,0x2c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x30,0xc0,0x00,0x00,0x00,0x00,
+/* 10705 0x29d1 "⧑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x63,0x75,0x79,0x75,0x63,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10706 0x29d2 "⧒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x63,0x57,0x4f,0x57,0x63,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10707 0x29d3 "⧓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x63,0x77,0x7f,0x77,0x63,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10708 0x29d4 "⧔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x62,0x74,0x78,0x74,0x62,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10709 0x29d5 "⧕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x23,0x17,0x0f,0x17,0x23,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10710 0x29d6 "⧖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x44,0x28,0x10,0x28,0x44,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10711 0x29d7 "⧗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x7c,0x38,0x10,0x38,0x7c,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10712 0x29d8 "⧘" */
+0x00,0x00,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10713 0x29d9 "⧙" */
+0x00,0x00,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10714 0x29da "⧚" */
+0x00,0x00,0x04,0x02,0x01,0x02,0x04,0x02,0x01,0x02,0x04,0x02,0x01,0x02,0x04,0x00,
+0x00,0x00,0x40,0x20,0x10,0x20,0x40,0x20,0x10,0x20,0x40,0x20,0x10,0x20,0x40,0x00,
+/* 10715 0x29db "⧛" */
+0x00,0x00,0x01,0x02,0x04,0x02,0x01,0x02,0x04,0x02,0x01,0x02,0x04,0x02,0x01,0x00,
+0x00,0x00,0x10,0x20,0x40,0x20,0x10,0x20,0x40,0x20,0x10,0x20,0x40,0x20,0x10,0x00,
+/* 10716 0x29dc "⧜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x49,0x49,0x36,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10717 0x29dd "⧝" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x36,0x49,0x49,0x36,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10718 0x29de "⧞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x2a,0x5d,0x5d,0x2a,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10719 0x29df "⧟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x4f,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0xf2,0x12,0x0c,0x00,0x00,0x00,0x00,
+/* 10720 0x29e0 "⧠" */
+0x00,0x00,0x3f,0x3f,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x3f,0x00,0x00,
+0x00,0x00,0xf8,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 10721 0x29e1 "⧡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1a,0x62,0x7e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10722 0x29e2 "⧢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 10723 0x29e3 "⧣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x7f,0x09,0x12,0x24,0x48,0x00,0x00,
+0x00,0x00,0x00,0x12,0x24,0x48,0x90,0xfe,0x40,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10724 0x29e4 "⧤" */
+0x00,0x00,0x06,0x09,0x00,0x00,0x00,0x7f,0x02,0x7f,0x09,0x12,0x24,0x48,0x00,0x00,
+0x00,0x00,0x40,0x92,0x24,0x48,0x90,0xfe,0x40,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10725 0x29e5 "⧥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x01,0x7f,0x04,0x7f,0x12,0x24,0x48,0x00,
+0x00,0x00,0x00,0x00,0x12,0x24,0x48,0xfe,0x20,0xfe,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 10726 0x29e6 "⧦" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x7f,0x40,0x40,0x7f,0x40,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,
+/* 10727 0x29e7 "⧧" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x1f,0x01,0x01,0x1f,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10728 0x29e8 "⧨" */
+0x00,0x00,0x00,0x7f,0x3f,0x3f,0x1f,0x1f,0x0f,0x0f,0x07,0x07,0x03,0x03,0x01,0x00,
+0x00,0x00,0x00,0xfc,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,
+/* 10729 0x29e9 "⧩" */
+0x00,0x00,0x00,0x7f,0x21,0x21,0x11,0x11,0x09,0x09,0x05,0x05,0x03,0x03,0x01,0x00,
+0x00,0x00,0x00,0xfc,0xf8,0xf8,0xf0,0xf0,0xe0,0xe0,0xc0,0xc0,0x80,0x80,0x00,0x00,
+/* 10730 0x29ea "⧪" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x0f,0x07,0x03,0x01,0x05,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xe0,0xc0,0x80,0x00,0x40,0x80,0x00,0x00,
+/* 10731 0x29eb "⧫" */
+0x00,0x00,0x10,0x38,0x38,0x7c,0x7c,0xfe,0x7c,0x7c,0x38,0x38,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10732 0x29ec "⧬" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x80,0xa0,0xc0,0x80,0x00,
+/* 10733 0x29ed "⧭" */
+0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x07,0x07,0x03,0x01,0x00,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xe0,0xf0,0xf0,0xf0,0xe0,0xc0,0x80,0xa0,0xc0,0x80,0x00,
+/* 10734 0x29ee "⧮" */
+0x00,0x00,0x00,0x7c,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10735 0x29ef "⧯" */
+0x00,0x00,0x00,0x7c,0x10,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10736 0x29f0 "⧰" */
+0x00,0x00,0x00,0x7c,0x10,0x10,0x28,0x44,0x82,0x44,0x28,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10737 0x29f1 "⧱" */
+0x00,0x00,0x00,0x7c,0x10,0x10,0x38,0x7c,0xfe,0x7c,0x38,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10738 0x29f2 "⧲" */
+0x00,0x00,0x00,0x7c,0x10,0x38,0x44,0x82,0x82,0x82,0x44,0x38,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10739 0x29f3 "⧳" */
+0x00,0x00,0x00,0x7c,0x10,0x38,0x7c,0xfe,0xfe,0xfe,0x7c,0x38,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10740 0x29f4 "⧴" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x1f,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10741 0x29f5 "⧵" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10742 0x29f6 "⧶" */
+0x00,0x00,0x78,0x00,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10743 0x29f7 "⧷" */
+0x00,0x00,0x00,0x40,0x40,0x20,0x20,0x7c,0x10,0x08,0x08,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10744 0x29f8 "⧸" */
+0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10745 0x29f9 "⧹" */
+0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10746 0x29fa "⧺" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x28,0xfe,0x28,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10747 0x29fb "⧻" */
+0x00,0x00,0x00,0x00,0x00,0x54,0x54,0xfe,0x54,0x54,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10748 0x29fc "⧼" */
+0x00,0x00,0x02,0x02,0x04,0x18,0x60,0x80,0x60,0x18,0x04,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10749 0x29fd "⧽" */
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x02,0x0c,0x30,0x40,0x80,0x80,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10750 0x29fe "⧾" */
+0x00,0x00,0x00,0x07,0x07,0x03,0x61,0x79,0x7f,0x79,0x61,0x03,0x03,0x07,0x07,0x00,
+0x00,0x00,0x00,0xc0,0xc0,0x80,0x0c,0x3c,0xfc,0x3c,0x0c,0x80,0x80,0xc0,0xc0,0x00,
+/* 10751 0x29ff "⧿" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x78,0x7f,0x78,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x3c,0xfc,0x3c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10752 0x2a00 "⨀" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x04,0x04,0x84,0x04,0x04,0x08,0x10,0xe0,0x00,0x00,
+/* 10753 0x2a01 "⨁" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x1f,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x90,0x88,0x84,0x84,0xfc,0x84,0x84,0x88,0x90,0xe0,0x00,0x00,
+/* 10754 0x2a02 "⨂" */
+0x00,0x00,0x00,0x03,0x04,0x0c,0x12,0x11,0x10,0x11,0x12,0x0c,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x18,0x24,0x44,0x84,0x44,0x24,0x18,0x10,0xe0,0x00,0x00,
+/* 10755 0x2a03 "⨃" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x13,0x13,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 10756 0x2a04 "⨄" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x11,0x11,0x17,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0xd0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10757 0x2a05 "⨅" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 10758 0x2a06 "⨆" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 10759 0x2a07 "⨇" */
+0x00,0x00,0x00,0x02,0x05,0x05,0x09,0x09,0x12,0x12,0x24,0x24,0x48,0x48,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0xa0,0x90,0x90,0x48,0x48,0x24,0x24,0x12,0x12,0x00,0x00,
+/* 10760 0x2a08 "⨈" */
+0x00,0x00,0x00,0x48,0x48,0x24,0x24,0x12,0x12,0x09,0x09,0x05,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x12,0x12,0x24,0x24,0x48,0x48,0x90,0x90,0xa0,0xa0,0x40,0x00,0x00,
+/* 10761 0x2a09 "⨉" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 10762 0x2a0a "⨊" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x0b,0x04,0x0a,0x0a,0x04,0x0b,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x00,0x80,0x40,0x40,0x80,0x00,0x10,0xf0,0x00,0x00,
+/* 10763 0x2a0b "⨋" */
+0x00,0x06,0x0a,0x08,0x7e,0x4a,0x28,0x18,0x08,0x18,0x28,0x4a,0x7e,0x08,0x28,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10764 0x2a0c "⨌" */
+0x00,0x09,0x16,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x5b,0x24,0x00,
+0x00,0x24,0xda,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x68,0x90,0x00,
+/* 10765 0x2a0d "⨍" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x08,0x3e,0x08,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10766 0x2a0e "⨎" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x3e,0x08,0x3e,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10767 0x2a0f "⨏" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x0a,0x0c,0x08,0x18,0x28,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10768 0x2a10 "⨐" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x1c,0x2a,0x28,0x1c,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10769 0x2a11 "⨑" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x08,0x2f,0x2b,0x1d,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10770 0x2a12 "⨒" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x0e,0x02,0x0a,0x02,0x0e,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10771 0x2a13 "⨓" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x0c,0x02,0x0a,0x02,0x0c,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10772 0x2a14 "⨔" */
+0x00,0x0c,0x14,0x10,0x10,0x10,0x1e,0x11,0x05,0x11,0x1e,0x10,0x10,0x50,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10773 0x2a15 "⨕" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x1c,0x22,0x2a,0x22,0x1c,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10774 0x2a16 "⨖" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x3e,0x2a,0x2a,0x2a,0x3e,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10775 0x2a17 "⨗" */
+0x00,0x06,0x0a,0x08,0x08,0x28,0x48,0xfe,0x49,0x2a,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10776 0x2a18 "⨘" */
+0x00,0x06,0x0a,0x08,0x08,0x49,0x2a,0x1c,0x08,0x1c,0x2a,0x49,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10777 0x2a19 "⨙" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x1c,0x2a,0x2a,0x2a,0x2a,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10778 0x2a1a "⨚" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x2a,0x2a,0x2a,0x2a,0x1c,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10779 0x2a1b "⨛" */
+0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x30,0x00,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10780 0x2a1c "⨜" */
+0x3e,0x00,0x06,0x0a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10781 0x2a1d "⨝" */
+0x00,0x00,0x00,0x00,0x10,0x18,0x14,0x12,0x11,0x11,0x12,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x48,0x88,0x88,0x48,0x28,0x18,0x08,0x00,0x00,
+/* 10782 0x2a1e "⨞" */
+0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x12,0x22,0x22,0x12,0x0a,0x06,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10783 0x2a1f "⨟" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x18,0x24,0x24,0x1c,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10784 0x2a20 "⨠" */
+0x00,0x00,0x00,0x11,0x08,0x04,0x02,0x01,0x00,0x01,0x02,0x04,0x08,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x88,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 10785 0x2a21 "⨡" */
+0x20,0x30,0x28,0x24,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10786 0x2a22 "⨢" */
+0x00,0x00,0x08,0x14,0x08,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10787 0x2a23 "⨣" */
+0x00,0x00,0x08,0x14,0x22,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10788 0x2a24 "⨤" */
+0x00,0x00,0x00,0x32,0x4c,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10789 0x2a25 "⨥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10790 0x2a26 "⨦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x00,0x32,0x4c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10791 0x2a27 "⨧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xfe,0x10,0x16,0x11,0x02,0x04,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10792 0x2a28 "⨨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x7f,0x08,0x1c,0x3e,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10793 0x2a29 "⨩" */
+0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10794 0x2a2a "⨪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10795 0x2a2b "⨫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x7e,0x00,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10796 0x2a2c "⨬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x7e,0x00,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10797 0x2a2d "⨭" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x08,0x10,0x17,0x10,0x08,0x08,0x06,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x80,0xf0,0x80,0x80,0x80,0x00,0x80,0x00,
+/* 10798 0x2a2e "⨮" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x01,0x01,0x0f,0x01,0x01,0x01,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x10,0x08,0xe8,0x08,0x10,0x10,0x60,0x80,0x00,
+/* 10799 0x2a2f "⨯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x14,0x08,0x14,0x22,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10800 0x2a30 "⨰" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x42,0x24,0x18,0x24,0x42,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10801 0x2a31 "⨱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x24,0x42,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10802 0x2a32 "⨲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x24,0x18,0x24,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10803 0x2a33 "⨳" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x08,0x05,0x02,0x05,0x08,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x88,0x50,0x20,0x50,0x88,0x40,0x20,0x00,0x00,
+/* 10804 0x2a34 "⨴" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x0a,0x11,0x10,0x11,0x0a,0x08,0x06,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x10,0x20,0xc0,0x20,0x10,0x00,0x00,0x80,0x00,
+/* 10805 0x2a35 "⨵" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x08,0x04,0x03,0x04,0x08,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x50,0x88,0x08,0x88,0x50,0x10,0x60,0x80,0x00,
+/* 10806 0x2a36 "⨶" */
+0x00,0x01,0x02,0x00,0x03,0x0c,0x10,0x14,0x22,0x21,0x22,0x14,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x30,0x08,0x28,0x44,0x84,0x44,0x28,0x08,0x30,0xc0,0x00,
+/* 10807 0x2a37 "⨷" */
+0x00,0x07,0x18,0x23,0x4c,0x50,0x94,0xa2,0xa1,0xa2,0x94,0x50,0x4c,0x23,0x18,0x07,
+0x00,0xe0,0x18,0xc4,0x32,0x0a,0x29,0x45,0x85,0x45,0x29,0x0a,0x32,0xc4,0x18,0xe0,
+/* 10808 0x2a38 "⨸" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x0b,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x88,0x08,0xe8,0x08,0x88,0x10,0xe0,0x00,0x00,
+/* 10809 0x2a39 "⨹" */
+0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x09,0x11,0x17,0x21,0x21,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0xd0,0x08,0x08,0x04,0xfc,0x00,0x00,
+/* 10810 0x2a3a "⨺" */
+0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x17,0x20,0x20,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0xd0,0x08,0x08,0x04,0xfc,0x00,0x00,
+/* 10811 0x2a3b "⨻" */
+0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x0c,0x12,0x11,0x22,0x24,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x60,0x90,0x10,0x88,0x48,0x04,0xfc,0x00,0x00,
+/* 10812 0x2a3c "⨼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10813 0x2a3d "⨽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10814 0x2a3e "⨾" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x08,0x00,0x08,0x14,0x14,0x0c,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10815 0x2a3f "⨿" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10816 0x2a40 "⩀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5a,0x5a,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10817 0x2a41 "⩁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x5d,0x41,0x41,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10818 0x2a42 "⩂" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10819 0x2a43 "⩃" */
+0x00,0x00,0x00,0x00,0x7e,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10820 0x2a44 "⩄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x41,0x49,0x55,0x55,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10821 0x2a45 "⩅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x55,0x49,0x41,0x41,0x41,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10822 0x2a46 "⩆" */
+0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x18,0x00,0x18,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10823 0x2a47 "⩇" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x00,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10824 0x2a48 "⩈" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x18,0x00,0x3c,0x00,0x18,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10825 0x2a49 "⩉" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x00,0x3c,0x00,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10826 0x2a4a "⩊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10827 0x2a4b "⩋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10828 0x2a4c "⩌" */
+0x00,0x00,0x00,0x00,0x00,0xff,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10829 0x2a4d "⩍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10830 0x2a4e "⩎" */
+0x00,0x00,0x00,0x1f,0x10,0x17,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0xd0,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x00,0x00,
+/* 10831 0x2a4f "⩏" */
+0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x14,0x17,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xd0,0x10,0xf0,0x00,0x00,
+/* 10832 0x2a50 "⩐" */
+0x00,0x00,0x00,0x00,0x3f,0x10,0x10,0x11,0x10,0x15,0x12,0x15,0x10,0x09,0x07,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x04,0x04,0x44,0x84,0x54,0x24,0x54,0x8c,0x48,0xf0,0x00,
+/* 10833 0x2a51 "⩑" */
+0x00,0x00,0x00,0x01,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,0x00,
+/* 10834 0x2a52 "⩒" */
+0x00,0x00,0x00,0x01,0x00,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 10835 0x2a53 "⩓" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x09,0x12,0x12,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x90,0x90,0x48,0x48,0x00,0x00,
+/* 10836 0x2a54 "⩔" */
+0x00,0x00,0x00,0x24,0x24,0x12,0x12,0x09,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x48,0x48,0x90,0x90,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 10837 0x2a55 "⩕" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x09,0x09,0x12,0x12,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0xa0,0x90,0x90,0x48,0x48,0x24,0x24,0x00,0x00,
+/* 10838 0x2a56 "⩖" */
+0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x12,0x12,0x09,0x09,0x05,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x48,0x48,0x90,0x90,0xa0,0xa0,0x40,0x00,0x00,
+/* 10839 0x2a57 "⩗" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x11,0x12,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10840 0x2a58 "⩘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0x44,0x84,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 10841 0x2a59 "⩙" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x11,0x0a,0x04,0x0a,0x11,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0xa0,0x40,0xa0,0x10,0x08,0x04,0x00,0x00,
+/* 10842 0x2a5a "⩚" */
+0x00,0x00,0x00,0x01,0x03,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x00,0x00,
+/* 10843 0x2a5b "⩛" */
+0x00,0x00,0x00,0x21,0x21,0x11,0x11,0x09,0x09,0x05,0x05,0x03,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 10844 0x2a5c "⩜" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x3f,0x08,0x10,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0xf8,0x20,0x10,0x10,0x08,0x08,0x00,0x00,
+/* 10845 0x2a5d "⩝" */
+0x00,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x3f,0x04,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x10,0x10,0x20,0xf8,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 10846 0x2a5e "⩞" */
+0x00,0x1f,0x00,0x1f,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,
+0x00,0xf0,0x00,0xf0,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,0x00,
+/* 10847 0x2a5f "⩟" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,0xf0,0x00,0x00,
+/* 10848 0x2a60 "⩠" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x1f,0x00,0x1f,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,0xf0,0x00,0xf0,
+/* 10849 0x2a61 "⩡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x01,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0xf0,0x00,0x00,
+/* 10850 0x2a62 "⩢" */
+0x00,0x00,0x00,0x1f,0x00,0x1f,0x00,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,
+0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,
+/* 10851 0x2a63 "⩣" */
+0x00,0x00,0x00,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x1f,0x00,0x1f,
+0x00,0x00,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0xf0,0x00,0xf0,
+/* 10852 0x2a64 "⩤" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x3f,0x18,0x06,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x18,0x68,0x88,0x08,0x08,0xf8,0x08,0x08,0x88,0x68,0x18,0x00,0x00,
+/* 10853 0x2a65 "⩥" */
+0x00,0x00,0x00,0x30,0x2c,0x23,0x20,0x20,0x3f,0x20,0x20,0x23,0x2c,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0xf8,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 10854 0x2a66 "⩦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10855 0x2a67 "⩧" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10856 0x2a68 "⩨" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3f,0x02,0x3f,0x02,0x3f,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0x80,0xf8,0x80,0xf8,0x80,0x00,0x00,0x00,
+/* 10857 0x2a69 "⩩" */
+0x00,0x00,0x00,0x00,0x00,0x05,0x05,0x3f,0x05,0x3f,0x05,0x3f,0x05,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xf8,0x40,0xf8,0x40,0xf8,0x40,0x00,0x00,0x00,
+/* 10858 0x2a6a "⩪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x64,0x98,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10859 0x2a6b "⩫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x64,0x98,0x00,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10860 0x2a6c "⩬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x98,0x00,0xfc,0x00,0x64,0x98,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10861 0x2a6d "⩭" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x32,0x4c,0x00,0x7e,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10862 0x2a6e "⩮" */
+0x00,0x00,0x00,0x00,0x2a,0x1c,0x08,0x1c,0x2a,0x00,0x7f,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10863 0x2a6f "⩯" */
+0x00,0x00,0x00,0x30,0x48,0x84,0x00,0x64,0x98,0x00,0x64,0x98,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10864 0x2a70 "⩰" */
+0x00,0x00,0x00,0x00,0x64,0x98,0x00,0x64,0x98,0x00,0xfc,0x00,0xfc,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10865 0x2a71 "⩱" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10866 0x2a72 "⩲" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10867 0x2a73 "⩳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x7e,0x00,0x32,0x4c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10868 0x2a74 "⩴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2b,0x00,0x00,0x2b,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 10869 0x2a75 "⩵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+/* 10870 0x2a76 "⩶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x00,0x00,0x7b,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xde,0x00,0x00,0xde,0x00,0x00,0x00,0x00,0x00,
+/* 10871 0x2a77 "⩷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x00,0x7e,0x00,0x00,0x7e,0x00,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10872 0x2a78 "⩸" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,0x00,0x00,
+/* 10873 0x2a79 "⩹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xc0,0x00,0x40,0xa0,0x40,0x00,0xc0,0x30,0x00,0x00,0x00,
+/* 10874 0x2a7a "⩺" */
+0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x04,0x0a,0x04,0x01,0x06,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10875 0x2a7b "⩻" */
+0x18,0x24,0x08,0x08,0x00,0x08,0x03,0x0c,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x00,0x00,
+/* 10876 0x2a7c "⩼" */
+0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x00,
+0x30,0x48,0x10,0x10,0x00,0x10,0x80,0x60,0x10,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 10877 0x2a7d "⩽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,0x80,0x60,0x00,
+/* 10878 0x2a7e "⩾" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x20,0xc0,0x00,0x00,0x00,
+/* 10879 0x2a7f "⩿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x40,0x00,0x80,0x60,0x00,0x80,0x60,0x00,
+/* 10880 0x2a80 "⪀" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x08,0x00,0x03,0x0c,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x20,0xc0,0x00,0x00,0x00,
+/* 10881 0x2a81 "⪁" */
+0x00,0x00,0x00,0x00,0x04,0x00,0x01,0x06,0x08,0x06,0x01,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,0x80,0x60,0x00,
+/* 10882 0x2a82 "⪂" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x40,0x00,0x00,0xc0,0x20,0xc0,0x00,0x20,0xc0,0x00,0x00,0x00,
+/* 10883 0x2a83 "⪃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x20,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,0x80,0x60,0x00,
+/* 10884 0x2a84 "⪄" */
+0x00,0x00,0x00,0x08,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x20,0xc0,0x00,0x00,0x00,
+/* 10885 0x2a85 "⪅" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x00,0x00,0x00,0x07,0x08,0x07,0x08,
+0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x10,0xe0,0x10,0xe0,
+/* 10886 0x2a86 "⪆" */
+0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x00,0x0e,0x11,0x0e,0x11,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x20,0xc0,0x20,0xc0,
+/* 10887 0x2a87 "⪇" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x00,0x00,0x00,0x0f,0x02,0x04,
+0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x40,0x80,0xe0,0x00,0x00,
+/* 10888 0x2a88 "⪈" */
+0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x00,0x0f,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x40,0x80,0xe0,0x00,0x00,
+/* 10889 0x2a89 "⪉" */
+0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x00,0x00,0x00,0x07,0x08,0x07,0x0a,0x04,0x08,
+0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x10,0x20,0x50,0xe0,0x10,0xe0,0x00,0x00,
+/* 10890 0x2a8a "⪊" */
+0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x00,0x0e,0x11,0x0e,0x15,0x08,0x10,
+0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x20,0x40,0xa0,0xc0,0x20,0xc0,0x00,0x00,
+/* 10891 0x2a8b "⪋" */
+0x00,0x18,0x60,0x80,0x60,0x18,0x00,0xfc,0x00,0xfc,0x00,0x60,0x18,0x04,0x18,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10892 0x2a8c "⪌" */
+0x00,0x60,0x18,0x04,0x18,0x60,0x00,0xfc,0x00,0xfc,0x00,0x18,0x60,0x80,0x60,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10893 0x2a8d "⪍" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x00,0x00,0x00,0x07,0x08,0x00,0x0f,
+0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x10,0xe0,0x00,0xf0,
+/* 10894 0x2a8e "⪎" */
+0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x00,0x0e,0x11,0x00,0x1f,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0xe0,
+/* 10895 0x2a8f "⪏" */
+0x00,0x06,0x18,0x20,0x18,0x06,0x00,0x32,0x4c,0x00,0x60,0x18,0x04,0x18,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10896 0x2a90 "⪐" */
+0x00,0x60,0x18,0x04,0x18,0x60,0x00,0x32,0x4c,0x00,0x06,0x18,0x20,0x18,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10897 0x2a91 "⪑" */
+0x00,0x0c,0x30,0x40,0x30,0x0c,0x60,0x18,0x04,0x18,0x60,0x00,0x7c,0x00,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10898 0x2a92 "⪒" */
+0x00,0x60,0x18,0x04,0x18,0x60,0x0c,0x30,0x40,0x30,0x0c,0x00,0x7c,0x00,0x7c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10899 0x2a93 "⪓" */
+0x00,0x0c,0x30,0x40,0x30,0x0c,0x40,0x30,0x0c,0x60,0x18,0x04,0x18,0x62,0x0c,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10900 0x2a94 "⪔" */
+0x00,0x30,0x0c,0x02,0x0c,0x30,0x02,0x0c,0x30,0x06,0x18,0x20,0x18,0x46,0x30,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10901 0x2a95 "⪕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x01,0x06,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,
+/* 10902 0x2a96 "⪖" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 10903 0x2a97 "⪗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x01,0x06,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x60,0x80,0x00,0x40,0x00,0x80,0x60,0x00,
+/* 10904 0x2a98 "⪘" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x0c,0x03,0x00,0x04,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 10905 0x2a99 "⪙" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,
+/* 10906 0x2a9a "⪚" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x0f,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 10907 0x2a9b "⪛" */
+0x00,0x00,0x00,0x01,0x06,0x08,0x01,0x06,0x08,0x01,0x06,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x60,0x80,0x00,0x60,0x80,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,
+/* 10908 0x2a9c "⪜" */
+0x00,0x00,0x0c,0x03,0x00,0x0c,0x03,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0xc0,0x20,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 10909 0x2a9d "⪝" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x00,0x00,0x00,0x03,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x30,0xc0,0x00,0x00,0x00,0xc0,0x30,0x00,
+/* 10910 0x2a9e "⪞" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 10911 0x2a9f "⪟" */
+0x00,0x00,0x07,0x08,0x00,0x00,0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x0f,0x00,0x0f,
+0x00,0x00,0x10,0xe0,0x00,0x30,0xc0,0x00,0x00,0x00,0xc0,0x30,0x00,0xf0,0x00,0xf0,
+/* 10912 0x2aa0 "⪠" */
+0x00,0x00,0x08,0x07,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x0f,0x00,0x0f,
+0x00,0x00,0xe0,0x10,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0xf0,0x00,0xf0,
+/* 10913 0x2aa1 "⪡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x11,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0xc0,0x30,0xc0,0x00,0xc0,0x30,0xc0,0x30,0x00,0x00,
+/* 10914 0x2aa2 "⪢" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x06,0x19,0x06,0x01,0x06,0x19,0x06,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x60,0x80,0x00,0x00,0x00,0x00,
+/* 10915 0x2aa3 "⪣" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x21,0x18,0x06,0x01,0x00,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x8c,0x30,0xc0,0x00,0xc0,0x30,0x8c,0x00,0xfc,0x00,0x00,0x00,
+/* 10916 0x2aa4 "⪤" */
+0x00,0x00,0x00,0x00,0x06,0x01,0x00,0x01,0x00,0x01,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0xb0,0xe0,0x10,0xe0,0xb0,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 10917 0x2aa5 "⪥" */
+0x00,0x00,0x00,0x00,0x40,0x30,0x0c,0x02,0x0c,0x30,0x40,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x18,0x60,0x80,0x60,0x18,0x04,0x00,0x00,0x00,0x00,0x00,
+/* 10918 0x2aa6 "⪦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10919 0x2aa7 "⪧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x10,0x10,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x60,0x80,0x00,0x00,0x00,
+/* 10920 0x2aa8 "⪨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x0c,0x03,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0xc0,0x00,
+/* 10921 0x2aa9 "⪩" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x10,0x10,0x09,0x06,0x00,0x01,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x60,0x80,0x10,0x60,0x80,0x00,0x00,
+/* 10922 0x2aaa "⪪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x1f,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0xc0,0x00,0x00,0xf0,0x00,0x00,0xc0,0x30,0x00,0x00,
+/* 10923 0x2aab "⪫" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0xf0,0x60,0x80,0x00,0x00,0x00,0x00,
+/* 10924 0x2aac "⪬" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x1f,0x0c,0x03,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x30,0xc0,0x00,0x00,0xf0,0x00,0x00,0xc0,0x30,0x00,0xf0,0x00,0x00,
+/* 10925 0x2aad "⪭" */
+0x00,0x00,0x00,0x18,0x06,0x01,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x60,0xf0,0x60,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 10926 0x2aae "⪮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x3c,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x78,0x00,0xf8,0x00,0xf8,0x00,0x00,0x00,
+/* 10927 0x2aaf "⪯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x03,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0xf0,0x00,0x00,
+/* 10928 0x2ab0 "⪰" */
+0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x03,0x04,0x08,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x38,0xc0,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 10929 0x2ab1 "⪱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x03,0x00,0x00,0x00,0x00,0x1f,0x02,0x04,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x50,0x80,0xf0,0x00,0x00,
+/* 10930 0x2ab2 "⪲" */
+0x00,0x00,0x00,0x10,0x08,0x06,0x01,0x00,0x01,0x06,0x08,0x10,0x01,0x1f,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x80,0x00,0xf0,0x00,0x00,
+/* 10931 0x2ab3 "⪳" */
+0x00,0x00,0x00,0x00,0x03,0x1c,0x03,0x00,0x00,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x10,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 10932 0x2ab4 "⪴" */
+0x00,0x10,0x08,0x06,0x01,0x00,0x01,0x06,0x08,0x10,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 10933 0x2ab5 "⪵" */
+0x00,0x00,0x00,0x00,0x03,0x1c,0x03,0x00,0x00,0x00,0x00,0x1f,0x01,0x1f,0x04,0x08,
+0x00,0x10,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x30,0x40,0xf0,0x00,0xf0,0x00,0x00,
+/* 10934 0x2ab6 "⪶" */
+0x00,0x10,0x08,0x06,0x01,0x00,0x01,0x06,0x08,0x10,0x00,0x1f,0x02,0x1f,0x08,0x10,
+0x00,0x00,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x40,0x80,0xf0,0x00,0xf0,0x00,0x00,
+/* 10935 0x2ab7 "⪷" */
+0x00,0x00,0x00,0x03,0x1c,0x03,0x00,0x00,0x00,0x00,0x07,0x08,0x07,0x08,0x00,0x00,
+0x10,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0x90,0x60,0x10,0xe0,0x00,0x00,
+/* 10936 0x2ab8 "⪸" */
+0x10,0x08,0x06,0x01,0x00,0x01,0x06,0x08,0x10,0x00,0x0e,0x11,0x0e,0x11,0x00,0x00,
+0x00,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x00,0x00,0x20,0xc0,0x20,0xc0,0x00,0x00,
+/* 10937 0x2ab9 "⪹" */
+0x00,0x00,0x00,0x03,0x1c,0x03,0x00,0x00,0x00,0x00,0x07,0x08,0x07,0x09,0x02,0x02,
+0x10,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x50,0x40,0x90,0xe0,0x10,0xe0,0x00,0x00,
+/* 10938 0x2aba "⪺" */
+0x10,0x08,0x06,0x01,0x00,0x01,0x06,0x08,0x10,0x00,0x0f,0x11,0x0e,0x13,0x04,0x04,
+0x00,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x80,0x80,0x20,0xc0,0x20,0xc0,0x00,0x00,
+/* 10939 0x2abb "⪻" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x73,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x42,0x84,0x18,0x60,0x80,0x60,0x18,0x84,0x42,0x00,0x00,0x00,0x00,
+/* 10940 0x2abc "⪼" */
+0x00,0x00,0x00,0x42,0x21,0x18,0x06,0x01,0x06,0x18,0x21,0x42,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0xce,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10941 0x2abd "⪽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x26,0x26,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 10942 0x2abe "⪾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0xc8,0xc8,0x08,0x10,0xe0,0x00,0x00,
+/* 10943 0x2abf "⪿" */
+0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x08,0x08,0x3e,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10944 0x2ac0 "⫀" */
+0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x10,0x10,0x7c,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10945 0x2ac1 "⫁" */
+0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x22,0x14,0x08,0x14,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10946 0x2ac2 "⫂" */
+0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x44,0x28,0x10,0x28,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10947 0x2ac3 "⫃" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10948 0x2ac4 "⫄" */
+0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10949 0x2ac5 "⫅" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x7e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10950 0x2ac6 "⫆" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x7e,0x00,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10951 0x2ac7 "⫇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x40,0x3e,0x00,0x32,0x4c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10952 0x2ac8 "⫈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x02,0x7c,0x00,0x32,0x4c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10953 0x2ac9 "⫉" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x32,0x4c,0x32,0x4c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10954 0x2aca "⫊" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x32,0x4c,0x32,0x4c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10955 0x2acb "⫋" */
+0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x04,0x7e,0x08,0x7e,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10956 0x2acc "⫌" */
+0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x04,0x7e,0x08,0x7e,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10957 0x2acd "⫍" */
+0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10958 0x2ace "⫎" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,
+/* 10959 0x2acf "⫏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 10960 0x2ad0 "⫐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10961 0x2ad1 "⫑" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0xf0,0x00,0x00,
+/* 10962 0x2ad2 "⫒" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0xf0,0x00,0x00,
+/* 10963 0x2ad3 "⫓" */
+0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10964 0x2ad4 "⫔" */
+0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10965 0x2ad5 "⫕" */
+0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10966 0x2ad6 "⫖" */
+0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10967 0x2ad7 "⫗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x01,0x01,0x01,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x00,0x00,0x00,
+/* 10968 0x2ad8 "⫘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x01,0x07,0x01,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0xf0,0x40,0x3e,0x00,0x00,0x00,0x00,
+/* 10969 0x2ad9 "⫙" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 10970 0x2ada "⫚" */
+0x00,0x00,0x0f,0x01,0x07,0x09,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0xe0,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 10971 0x2adb "⫛" */
+0x00,0x00,0x01,0x01,0x07,0x09,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x01,0x01,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 10972 0x2adc "⫝̸" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x11,0x13,0x15,0x09,0x17,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10973 0x2add "⫝" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 10974 0x2ade "⫞" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10975 0x2adf "⫟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10976 0x2ae0 "⫠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 10977 0x2ae1 "⫡" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0x40,0x30,0x08,0x70,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 10978 0x2ae2 "⫢" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 10979 0x2ae3 "⫣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x14,0xf4,0x14,0x14,0x14,0x14,0x00,0x00,
+/* 10980 0x2ae4 "⫤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,0xf8,0x08,0x08,0x08,0x00,0x00,
+/* 10981 0x2ae5 "⫥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x14,0xf4,0x14,0xf4,0x14,0x14,0x14,0x00,0x00,
+/* 10982 0x2ae6 "⫦" */
+0x00,0x00,0x00,0x00,0x00,0x28,0x28,0x28,0x28,0x3f,0x28,0x28,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10983 0x2ae7 "⫧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x1f,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10984 0x2ae8 "⫨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 10985 0x2ae9 "⫩" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x00,0x1f,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10986 0x2aea "⫪" */
+0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 10987 0x2aeb "⫫" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xf0,0x00,0x00,
+/* 10988 0x2aec "⫬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0xf8,0x08,0x08,0x00,0x00,0x00,
+/* 10989 0x2aed "⫭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x1f,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 10990 0x2aee "⫮" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x58,0x38,0x18,0x18,0x1c,0x1a,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10991 0x2aef "⫯" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10992 0x2af0 "⫰" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x38,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10993 0x2af1 "⫱" */
+0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x38,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10994 0x2af2 "⫲" */
+0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x14,0x7f,0x14,0x14,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10995 0x2af3 "⫳" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x07,0x0a,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x50,0xe0,0x40,0x40,0x40,0x00,0x00,
+/* 10996 0x2af4 "⫴" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 10997 0x2af5 "⫵" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x3f,0x09,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xf8,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 10998 0x2af6 "⫶" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 10999 0x2af7 "⫷" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x19,0x22,0x19,0x06,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x18,0x60,0x98,0x60,0x98,0x20,0x98,0x60,0x98,0x60,0x18,0x00,0x00,
+/* 11000 0x2af8 "⫸" */
+0x00,0x00,0x00,0x30,0x0c,0x33,0x0c,0x33,0x08,0x33,0x0c,0x33,0x0c,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x88,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 11001 0x2af9 "⫹" */
+0x00,0x00,0x00,0x01,0x06,0x08,0x06,0x01,0x08,0x06,0x01,0x08,0x06,0x01,0x00,0x00,
+0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x80,0x60,0x00,0x80,0x60,0x00,0x80,0x60,0x00,
+/* 11002 0x2afa "⫺" */
+0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x00,0x03,0x0c,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x20,0xc0,0x00,0x20,0xc0,0x00,0x00,0x00,
+/* 11003 0x2afb "⫻" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x04,0x09,0x09,0x12,0x12,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x48,0x48,0x90,0x90,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,
+/* 11004 0x2afc "⫼" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+/* 11005 0x2afd "⫽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x90,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 11006 0x2afe "⫾" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11007 0x2aff "⫿" */
+0x00,0x00,0x00,0x00,0x38,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11008 0x2b00 "⬀" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x02,0x04,0x08,0x11,0x22,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x88,0x08,0x28,0x58,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11009 0x2b01 "⬁" */
+0x00,0x00,0x00,0x3f,0x21,0x22,0x21,0x28,0x34,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x88,0x50,0x20,0x00,0x00,
+/* 11010 0x2b02 "⬂" */
+0x00,0x00,0x00,0x08,0x14,0x22,0x11,0x08,0x04,0x02,0x01,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x58,0x28,0x08,0x88,0x08,0xf8,0x00,0x00,
+/* 11011 0x2b03 "⬃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x34,0x28,0x21,0x22,0x21,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x20,0x50,0x88,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11012 0x2b04 "⬄" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x2f,0x40,0x2f,0x18,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0xf4,0x02,0xf4,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 11013 0x2b05 "⬅" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x3f,0x7f,0x3f,0x18,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11014 0x2b06 "⬆" */
+0x00,0x00,0x10,0x38,0x7c,0xfe,0x38,0x38,0x38,0x38,0x38,0x38,0x38,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11015 0x2b07 "⬇" */
+0x00,0x00,0x38,0x38,0x38,0x38,0x38,0x38,0x38,0x38,0xfe,0x7c,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11016 0x2b08 "⬈" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x03,0x07,0x0f,0x1f,0x3e,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0xf8,0xf8,0xf8,0xf8,0xf8,0xd8,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11017 0x2b09 "⬉" */
+0x00,0x00,0x00,0x3f,0x3f,0x3e,0x3f,0x3f,0x37,0x03,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0x70,0x20,0x00,0x00,
+/* 11018 0x2b0a "⬊" */
+0x00,0x00,0x00,0x08,0x1c,0x3e,0x1f,0x0f,0x07,0x03,0x01,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xd8,0xf8,0xf8,0xf8,0xf8,0xf8,0x00,0x00,
+/* 11019 0x2b0b "⬋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x37,0x3f,0x3f,0x3e,0x3f,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x20,0x70,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11020 0x2b0c "⬌" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x3f,0x7f,0x3f,0x18,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0xfc,0xfe,0xfc,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 11021 0x2b0d "⬍" */
+0x00,0x00,0x10,0x38,0x7c,0xfe,0x38,0x38,0x38,0x38,0xfe,0x7c,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11022 0x2b0e "⬎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x2a,0x1c,0x08,0x00,0x00,0x00,0x00,
+/* 11023 0x2b0f "⬏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x1c,0x2a,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11024 0x2b10 "⬐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x54,0x38,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11025 0x2b11 "⬑" */
+0x00,0x00,0x00,0x10,0x38,0x54,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11026 0x2b12 "⬒" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x1f,0x1f,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0xf8,0xf8,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,
+/* 11027 0x2b13 "⬓" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x1f,0x1f,0x1f,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0xf8,0xf8,0xf8,0xf8,0x00,
+/* 11028 0x2b14 "⬔" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x1f,0x17,0x13,0x11,0x10,0x10,0x10,0x10,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0x78,0x38,0x18,0xf8,0x00,
+/* 11029 0x2b15 "⬕" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x18,0x1c,0x1e,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x88,0xc8,0xe8,0xf8,0xf8,0x00,
+/* 11030 0x2b16 "⬖" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x1f,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 11031 0x2b17 "⬗" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x10,0x08,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xf8,0xf0,0xe0,0xc0,0x80,0x00,
+/* 11032 0x2b18 "⬘" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x10,0x08,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 11033 0x2b19 "⬙" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x1f,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0xf8,0xf0,0xe0,0xc0,0x80,0x00,
+/* 11034 0x2b1a "⬚" */
+0x00,0x00,0x00,0x2a,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x2a,0x00,0x00,
+0x00,0x00,0x00,0xa8,0x00,0x08,0x00,0x08,0x00,0x08,0x00,0x08,0x00,0xa8,0x00,0x00,
+/* 11035 0x2b1b "⬛" */
+0x00,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x00,
+0x00,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0xfe,0x00,
+/* 11036 0x2b1c "⬜" */
+0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,
+0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,
+/* 11037 0x2b1d "⬝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x3c,0x3c,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11038 0x2b1e "⬞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11039 0x2b1f "⬟" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x3f,0x1f,0x1f,0x0f,0x0f,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xfc,0xf8,0xf8,0xf0,0xf0,0xe0,0x00,0x00,
+/* 11040 0x2b20 "⬠" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x10,0x10,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x08,0x08,0x10,0x10,0xe0,0x00,0x00,
+/* 11041 0x2b21 "⬡" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x20,0x20,0x20,0x20,0x20,0x18,0x06,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x08,0x08,0x08,0x08,0x30,0xc0,0x00,0x00,
+/* 11042 0x2b22 "⬢" */
+0x00,0x00,0x00,0x00,0x01,0x07,0x1f,0x3f,0x3f,0x3f,0x3f,0x3f,0x1f,0x07,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xf0,0xf8,0xf8,0xf8,0xf8,0xf8,0xf0,0xc0,0x00,0x00,
+/* 11043 0x2b23 "⬣" */
+0x00,0x00,0x00,0x00,0x07,0x0f,0x1f,0x3f,0x7f,0x7f,0x3f,0x1f,0x0f,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0xf8,0xfc,0xfe,0xfe,0xfc,0xf8,0xf0,0xe0,0x00,0x00,
+/* 11044 0x2b24 "⬤" */
+0x00,0x00,0x01,0x07,0x0f,0x1f,0x1f,0x3f,0x3f,0x3f,0x1f,0x1f,0x0f,0x07,0x01,0x00,
+0x00,0x00,0xc0,0xf0,0xf8,0xfc,0xfc,0xfe,0xfe,0xfe,0xfc,0xfc,0xf8,0xf0,0xc0,0x00,
+/* 11045 0x2b25 "⬥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x7c,0xfe,0x7c,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11046 0x2b26 "⬦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x82,0x44,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11047 0x2b27 "⬧" */
+0x00,0x00,0x00,0x10,0x38,0x38,0x7c,0x7c,0xfe,0x7c,0x7c,0x38,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11048 0x2b28 "⬨" */
+0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x82,0x44,0x44,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11049 0x2b29 "⬩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x7c,0x38,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11050 0x2b2a "⬪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x38,0x7c,0x38,0x38,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11051 0x2b2b "⬫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11052 0x2b2c "⬬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x7f,0xff,0xff,0x7f,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0xfc,0xfe,0xfe,0xfc,0xe0,0x00,0x00,
+/* 11053 0x2b2d "⬭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x70,0x80,0x80,0x70,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x1c,0x02,0x02,0x1c,0xe0,0x00,0x00,
+/* 11054 0x2b2e "⬮" */
+0x00,0x18,0x3c,0x3c,0x3c,0x7e,0x7e,0x7e,0x7e,0x7e,0x3c,0x3c,0x3c,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11055 0x2b2f "⬯" */
+0x00,0x18,0x24,0x24,0x24,0x42,0x42,0x42,0x42,0x42,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11056 0x2b30 "⬰" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x21,0x7f,0x21,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0xff,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11057 0x2b31 "⬱" */
+0x20,0x40,0xff,0x40,0x20,0x20,0x40,0xff,0x40,0x20,0x20,0x40,0xff,0x40,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11058 0x2b32 "⬲" */
+0x00,0x00,0x00,0x00,0x01,0x12,0x24,0x7f,0x24,0x12,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0xff,0x90,0xa0,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 11059 0x2b33 "⬳" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x24,0x7a,0x21,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xab,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11060 0x2b34 "⬴" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7f,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xff,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11061 0x2b35 "⬵" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7f,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x50,0x50,0xff,0x50,0x50,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11062 0x2b36 "⬶" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7f,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11063 0x2b37 "⬷" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7e,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0xd8,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11064 0x2b38 "⬸" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x75,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11065 0x2b39 "⬹" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x42,0x44,0xf8,0x44,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11066 0x2b3a "⬺" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa2,0xa4,0xf8,0xa4,0xa2,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11067 0x2b3b "⬻" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7f,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0xf8,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11068 0x2b3c "⬼" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7f,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x42,0x44,0xf8,0x44,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11069 0x2b3d "⬽" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x7f,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa2,0xa4,0xf8,0xa4,0xa2,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11070 0x2b3e "⬾" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x7f,0x20,0x10,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x50,0xff,0x50,0x88,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11071 0x2b3f "⬿" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11072 0x2b40 "⭀" */
+0x00,0x00,0x00,0x01,0x00,0x11,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0xf8,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11073 0x2b41 "⭁" */
+0x00,0x00,0x00,0x00,0x02,0x11,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1c,0x22,0xc0,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11074 0x2b42 "⭂" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x12,0x01,0x00,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x1c,0x22,0xc0,0x1c,0x22,0xc0,0x00,0x00,
+/* 11075 0x2b43 "⭃" */
+0x00,0x00,0x00,0x60,0x18,0x06,0x01,0x0f,0x01,0x06,0x18,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x84,0xfe,0x84,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11076 0x2b44 "⭄" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x7f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x48,0x24,0xfe,0x24,0x48,0x80,0x00,0x00,0x00,0x00,
+/* 11077 0x2b45 "⭅" */
+0x00,0x00,0x02,0x04,0x0f,0x10,0x3f,0x40,0x3f,0x10,0x0f,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 11078 0x2b46 "⭆" */
+0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x20,0xf0,0x08,0xfc,0x02,0xfc,0x08,0xf0,0x20,0x40,0x00,0x00,0x00,
+/* 11079 0x2b47 "⭇" */
+0x00,0x00,0x00,0x03,0x44,0x38,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x08,0x04,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11080 0x2b48 "⭈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x03,0x44,0x38,0x03,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x84,0x48,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 11081 0x2b49 "⭉" */
+0x00,0x00,0x00,0x01,0x02,0x10,0x20,0x7f,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x22,0x1c,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11082 0x2b4a "⭊" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x21,0x12,0x00,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xc0,0x22,0x1c,0xc0,0x22,0x1c,0x00,0x00,
+/* 11083 0x2b4b "⭋" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7f,0x20,0x10,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x1c,0x22,0xc0,0x00,0x00,0x00,0x00,
+/* 11084 0x2b4c "⭌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x03,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0xfe,0x04,0x88,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 11085 0x2b4d "⭍" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x1f,0x00,0x00,0x00,0x02,0x03,0x03,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x80,0x00,0x00,
+/* 11086 0x2b4e "⭎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x0c,0x14,0x10,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11087 0x2b4f "⭏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x14,0x0c,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11088 0x2b50 "⭐" */
+0x00,0x01,0x01,0x02,0x02,0x7c,0x20,0x10,0x08,0x04,0x08,0x11,0x26,0x38,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x7c,0x08,0x10,0x20,0x40,0x20,0x10,0xc8,0x38,0x00,0x00,
+/* 11089 0x2b51 "⭑" */
+0x00,0x00,0x00,0x01,0x03,0x03,0x3f,0x1f,0x0f,0x0f,0x1e,0x3c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xf8,0xf0,0xe0,0xe0,0xf0,0x78,0x18,0x00,0x00,0x00,
+/* 11090 0x2b52 "⭒" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x3c,0x10,0x08,0x09,0x12,0x2c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x78,0x10,0x20,0x20,0x90,0x68,0x18,0x00,0x00,0x00,
+/* 11091 0x2b53 "⭓" */
+0x00,0x00,0x00,0x03,0x0f,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x0f,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xfc,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,
+/* 11092 0x2b54 "⭔" */
+0x00,0x00,0x00,0x03,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 11093 0x2b55 "⭕" */
+0x00,0x07,0x0f,0x18,0x30,0x60,0x60,0x60,0x60,0x60,0x30,0x18,0x0f,0x07,0x00,0x00,
+0x00,0xc0,0xe0,0x30,0x18,0x0c,0x0c,0x0c,0x0c,0x0c,0x18,0x30,0xe0,0xc0,0x00,0x00,
+/* 11094 0x2b56 "⭖" */
+0x00,0x00,0x00,0x0f,0x1f,0x30,0x67,0x68,0x68,0x67,0x30,0x1f,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0xf0,0x18,0xcc,0x2c,0x2c,0xcc,0x18,0xf0,0xe0,0x00,0x00,0x00,
+/* 11095 0x2b57 "⭗" */
+0x00,0x07,0x0f,0x18,0x30,0x63,0x64,0x64,0x64,0x63,0x30,0x18,0x0f,0x07,0x00,0x00,
+0x00,0xc0,0xe0,0x30,0x18,0x8c,0x4c,0x4c,0x4c,0x8c,0x18,0x30,0xe0,0xc0,0x00,0x00,
+/* 11096 0x2b58 "⭘" */
+0x00,0x00,0x00,0x00,0x03,0x0f,0x0c,0x18,0x18,0x18,0x0c,0x0f,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xe0,0x60,0x30,0x30,0x30,0x60,0xe0,0x80,0x00,0x00,0x00,
+/* 11097 0x2b59 "⭙" */
+0x00,0x07,0x0f,0x18,0x38,0x64,0x62,0x61,0x62,0x64,0x38,0x18,0x0f,0x07,0x00,0x00,
+0x00,0xc0,0xe0,0x30,0x38,0x4c,0x8c,0x0c,0x8c,0x4c,0x38,0x30,0xe0,0xc0,0x00,0x00,
+/* 11098 0x2b5a "⭚" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x08,0x09,0x08,0x10,0x10,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x50,0xe0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11099 0x2b5b "⭛" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x54,0x38,0x10,0x00,0x00,
+/* 11100 0x2b5c "⭜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x20,0x70,0xa8,0x20,0x40,0x40,0x40,0x40,0x80,0x80,0x80,0x00,0x00,
+/* 11101 0x2b5d "⭝" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x40,0x40,0x40,0x40,0x20,0xa8,0x70,0x20,0x00,0x00,
+/* 11102 0x2b5e "⭞" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x02,0x02,0x02,0x02,0x04,0x05,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x78,0x90,0x20,0x00,0x00,
+/* 11103 0x2b5f "⭟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x04,0x04,0x05,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x78,0x90,0x20,0x00,0x00,
+/* 11104 0x2b60 "⭠" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11105 0x2b61 "⭡" */
+0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11106 0x2b62 "⭢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11107 0x2b63 "⭣" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,
+/* 11108 0x2b64 "⭤" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x60,0xff,0x60,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11109 0x2b65 "⭥" */
+0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x03,0x01,
+0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,
+/* 11110 0x2b66 "⭦" */
+0x00,0x00,0x00,0x00,0x1e,0x1c,0x1c,0x12,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 11111 0x2b67 "⭧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x38,0x38,0x48,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11112 0x2b68 "⭨" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0x38,0x38,0x78,0x00,0x00,
+/* 11113 0x2b69 "⭩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x12,0x1c,0x1c,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11114 0x2b6a "⭪" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x7d,0x30,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11115 0x2b6b "⭫" */
+0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x00,0x01,0x01,0x00,0x01,0x01,0x00,0x01,0x01,
+0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11116 0x2b6c "⭬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xbe,0x0c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11117 0x2b6d "⭭" */
+0x00,0x00,0x01,0x01,0x00,0x01,0x01,0x00,0x01,0x01,0x00,0x01,0x01,0x07,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,
+/* 11118 0x2b6e "⭮" */
+0x00,0x00,0x00,0x00,0x1c,0x0c,0x14,0x20,0x20,0x20,0x20,0x20,0x10,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,
+/* 11119 0x2b6f "⭯" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x10,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x38,0x30,0x28,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,
+/* 11120 0x2b70 "⭰" */
+0x00,0x00,0x00,0x00,0x00,0x44,0x4c,0x5f,0x4c,0x44,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11121 0x2b71 "⭱" */
+0x00,0x00,0x07,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc0,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11122 0x2b72 "⭲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x22,0x32,0xfa,0x32,0x22,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11123 0x2b73 "⭳" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x03,0x01,0x00,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,0x00,0xc0,
+/* 11124 0x2b74 "⭴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 11125 0x2b75 "⭵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 11126 0x2b76 "⭶" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x07,0x07,0x07,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x80,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 11127 0x2b77 "⭷" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0xf0,0x70,0x70,0x90,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11128 0x2b78 "⭸" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x70,0x70,0xf0,0x00,0xf8,0x00,0x00,
+/* 11129 0x2b79 "⭹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x07,0x07,0x07,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x80,0x00,0xc0,0x00,0x00,
+/* 11130 0x2b7a "⭺" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x31,0x7f,0x31,0x11,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 11131 0x2b7b "⭻" */
+0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x01,0x0f,0x01,0x0f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x00,0x00,0x00,
+/* 11132 0x2b7c "⭼" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x7f,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x88,0x8c,0xfe,0x8c,0x88,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 11133 0x2b7d "⭽" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x0f,0x01,0x0f,0x01,0x01,0x01,0x01,0x07,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,
+/* 11134 0x2b7e "⭾" */
+0x00,0x00,0x00,0x00,0x44,0x4c,0x5f,0x4c,0x44,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x22,0x32,0xfa,0x32,0x22,0x00,0x00,
+/* 11135 0x2b7f "⭿" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x1f,0x0e,0x04,0x00,0x1f,
+0x00,0x00,0xf8,0x00,0x20,0x70,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 11136 0x2b80 "⮀" */
+0x00,0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,
+/* 11137 0x2b81 "⮁" */
+0x00,0x00,0x04,0x0e,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xf8,0x70,0x20,
+/* 11138 0x2b82 "⮂" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 11139 0x2b83 "⮃" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x1f,0x0e,0x04,
+0x00,0x00,0x20,0x70,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 11140 0x2b84 "⮄" */
+0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 11141 0x2b85 "⮅" */
+0x00,0x00,0x08,0x1c,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x20,0x70,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 11142 0x2b86 "⮆" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,
+/* 11143 0x2b87 "⮇" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x1c,0x08,
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xf8,0x70,0x20,
+/* 11144 0x2b88 "⮈" */
+0x00,0x03,0x07,0x0e,0x1c,0x38,0x30,0x20,0x30,0x38,0x1c,0x0e,0x07,0x03,0x00,0x00,
+0x00,0xe0,0xf0,0xf8,0xfc,0xfc,0x00,0x00,0x00,0xfc,0xfc,0xf8,0xf0,0xe0,0x00,0x00,
+/* 11145 0x2b89 "⮉" */
+0x00,0x00,0x03,0x07,0x0e,0x1c,0x38,0x30,0x3e,0x3e,0x3e,0x1e,0x0e,0x06,0x00,0x00,
+0x00,0x00,0xe0,0x70,0x38,0x1c,0x0e,0x06,0x3e,0x3e,0x3e,0x3c,0x38,0x30,0x00,0x00,
+/* 11146 0x2b8a "⮊" */
+0x00,0x07,0x0f,0x1f,0x3f,0x3f,0x00,0x00,0x00,0x3f,0x3f,0x1f,0x0f,0x07,0x00,0x00,
+0x00,0xc0,0xe0,0x70,0x38,0x1c,0x0c,0x04,0x0c,0x1c,0x38,0x70,0xe0,0xc0,0x00,0x00,
+/* 11147 0x2b8b "⮋" */
+0x00,0x00,0x06,0x0e,0x1e,0x3e,0x3e,0x3e,0x30,0x38,0x1c,0x0e,0x07,0x03,0x00,0x00,
+0x00,0x00,0x30,0x38,0x3c,0x3e,0x3e,0x3e,0x06,0x0e,0x1c,0x38,0x70,0xe0,0x00,0x00,
+/* 11148 0x2b8c "⮌" */
+0x00,0x00,0x08,0x18,0x3f,0x18,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x02,0x02,0x02,0x02,0x04,0x08,0xf0,0x00,0x00,
+/* 11149 0x2b8d "⮍" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,
+0x00,0x00,0x00,0x08,0x1c,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,
+/* 11150 0x2b8e "⮎" */
+0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,
+/* 11151 0x2b8f "⮏" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x1f,0x0e,0x04,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x04,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 11152 0x2b90 "⮐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x1e,0x02,0x04,0x04,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 11153 0x2b91 "⮑" */
+0x00,0x00,0x00,0x00,0x00,0x78,0x40,0x20,0x20,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,
+/* 11154 0x2b92 "⮒" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x02,0x06,0x6f,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 11155 0x2b93 "⮓" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x40,0x60,0xf6,0x60,0x40,0x00,0x00,0x00,
+/* 11156 0x2b94 "⮔" */
+0x00,0x00,0x00,0x00,0x3e,0x20,0x20,0xa8,0x70,0x20,0x00,0x24,0x22,0x3f,0x02,0x04,
+0x00,0x00,0x20,0x40,0xfc,0x44,0x24,0x00,0x04,0x0e,0x15,0x04,0x04,0x7c,0x00,0x00,
+/* 11157 0x2b95 "⮕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x30,0xf8,0xfc,0xf8,0x30,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 11158 0x2b96 "⮖" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 11159 0x2b97 "⮗" */
+0x00,0x00,0x7f,0x40,0x4f,0x20,0x2f,0x11,0x11,0x09,0x09,0x05,0x04,0x02,0x01,0x00,
+0x00,0x00,0xfc,0x04,0xe4,0x08,0xe8,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 11160 0x2b98 "⮘" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x30,0x40,0x3f,0x0f,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x04,0x38,0xc8,0x10,0x10,0x20,0x40,0xe0,0xf0,0xf0,0xf8,0x38,0x04,0x00,0x00,
+/* 11161 0x2b99 "⮙" */
+0x00,0x00,0x01,0x02,0x02,0x06,0x06,0x0e,0x0e,0x1e,0x1f,0x3e,0x3c,0x30,0x40,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x88,0x68,0x18,0x04,0x00,
+/* 11162 0x2b9a "⮚" */
+0x00,0x40,0x38,0x26,0x11,0x10,0x08,0x04,0x0f,0x1f,0x1f,0x3e,0x38,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x04,0xf8,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 11163 0x2b9b "⮛" */
+0x00,0x00,0x40,0x30,0x2c,0x22,0x11,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x00,
+0x00,0x00,0x04,0x18,0x78,0xf8,0xf0,0xf0,0xe0,0xe0,0xc0,0xc0,0x80,0x80,0x00,0x00,
+/* 11164 0x2b9c "⮜" */
+0x00,0x00,0x00,0x00,0x03,0x0f,0x3f,0x7f,0x3f,0x0f,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x04,0x38,0xf8,0xf0,0xf0,0xe0,0xc0,0xe0,0xf0,0xf0,0xf8,0x38,0x04,0x00,0x00,
+/* 11165 0x2b9d "⮝" */
+0x00,0x00,0x01,0x03,0x03,0x07,0x07,0x0f,0x0f,0x1f,0x1f,0x3e,0x3c,0x30,0x40,0x00,
+0x00,0x00,0x00,0x80,0x80,0xc0,0xc0,0xe0,0xe0,0xf0,0xf0,0xf8,0x78,0x18,0x04,0x00,
+/* 11166 0x2b9e "⮞" */
+0x00,0x40,0x38,0x3e,0x1f,0x1f,0x0f,0x07,0x0f,0x1f,0x1f,0x3e,0x38,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xe0,0xf8,0xfc,0xf8,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 11167 0x2b9f "⮟" */
+0x00,0x00,0x40,0x30,0x3c,0x3e,0x1f,0x1f,0x0f,0x0f,0x07,0x07,0x03,0x03,0x01,0x00,
+0x00,0x00,0x04,0x18,0x78,0xf8,0xf0,0xf0,0xe0,0xe0,0xc0,0xc0,0x80,0x80,0x00,0x00,
+/* 11168 0x2ba0 "⮠" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11169 0x2ba1 "⮡" */
+0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11170 0x2ba2 "⮢" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x30,0x7f,0x30,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+/* 11171 0x2ba3 "⮣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x0c,0xfe,0x0c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11172 0x2ba4 "⮤" */
+0x00,0x00,0x04,0x0e,0x1f,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,
+/* 11173 0x2ba5 "⮥" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,
+0x00,0x00,0x40,0xe0,0xf0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,
+/* 11174 0x2ba6 "⮦" */
+0x00,0x00,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x1f,0x0e,0x04,0x00,
+0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11175 0x2ba7 "⮧" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xf0,0xe0,0x40,0x00,
+/* 11176 0x2ba8 "⮨" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x7f,0xff,0x7f,0x30,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x02,0x06,0xfc,0xfc,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11177 0x2ba9 "⮩" */
+0x00,0x00,0x00,0x80,0x80,0xc0,0x7f,0x7f,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0xfc,0xfe,0xfc,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 11178 0x2baa "⮪" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x7f,0xff,0x7f,0x30,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0xfc,0xfc,0x06,0x02,0x02,0x00,0x00,0x00,0x00,
+/* 11179 0x2bab "⮫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x7f,0x7f,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x18,0xfc,0xfe,0xfc,0x18,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 11180 0x2bac "⮬" */
+0x00,0x00,0x00,0x02,0x07,0x0f,0x1f,0x07,0x07,0x07,0x07,0x07,0x07,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xe0,0x00,
+/* 11181 0x2bad "⮭" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x03,0x03,0x03,0x03,0x03,0x03,0x07,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 11182 0x2bae "⮮" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x07,0x07,0x07,0x07,0x07,0x1f,0x0f,0x07,0x02,0x00,
+0x00,0x00,0x00,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,0x00,0x00,
+/* 11183 0x2baf "⮯" */
+0x00,0x00,0x00,0x1c,0x07,0x03,0x03,0x03,0x03,0x03,0x03,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xe0,0xc0,0x80,0x00,0x00,
+/* 11184 0x2bb0 "⮰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x13,0x20,0x40,0x20,0x13,0x0a,0x04,0x00,
+0x00,0x22,0x36,0x2a,0x22,0x22,0x22,0x22,0xfc,0x04,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 11185 0x2bb1 "⮱" */
+0x00,0x44,0x6c,0x54,0x44,0x44,0x44,0x44,0x3f,0x20,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0xc8,0x04,0x02,0x04,0xc8,0x50,0x20,0x00,
+/* 11186 0x2bb2 "⮲" */
+0x00,0x04,0x0a,0x13,0x20,0x40,0x20,0x13,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x04,0xfc,0x22,0x22,0x22,0x22,0x2a,0x36,0x22,0x00,
+/* 11187 0x2bb3 "⮳" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x3f,0x44,0x44,0x44,0x44,0x54,0x6c,0x44,0x00,
+0x00,0x20,0x50,0xc8,0x04,0x02,0x04,0xc8,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11188 0x2bb4 "⮴" */
+0x00,0x04,0x0a,0x11,0x20,0x40,0x31,0x11,0x11,0x11,0x11,0x09,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0xfe,0x04,0x08,0x04,0xfe,0x00,
+/* 11189 0x2bb5 "⮵" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x7f,0x20,0x10,0x20,0x7f,0x00,
+0x00,0x20,0x50,0x88,0x04,0x02,0x8c,0x88,0x88,0x88,0x88,0x90,0xa0,0xc0,0x00,0x00,
+/* 11190 0x2bb6 "⮶" */
+0x00,0x00,0x03,0x05,0x09,0x11,0x11,0x11,0x11,0x31,0x40,0x20,0x11,0x0a,0x04,0x00,
+0x00,0xfe,0x04,0x08,0x04,0xfe,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 11191 0x2bb7 "⮷" */
+0x00,0x7f,0x20,0x10,0x20,0x7f,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xa0,0x90,0x88,0x88,0x88,0x88,0x8c,0x02,0x04,0x88,0x50,0x20,0x00,
+/* 11192 0x2bb8 "⮸" */
+0x00,0x01,0x02,0x04,0x0f,0x10,0x0c,0x04,0x04,0x07,0x00,0x07,0x04,0x07,0x00,0x00,
+0x00,0x00,0x80,0x40,0xe0,0x10,0x60,0x40,0x40,0xc0,0x00,0xc0,0x40,0xc0,0x00,0x00,
+/* 11193 0x2bb9 "⮹" */
+0x00,0x00,0x00,0x7f,0x40,0x41,0x42,0x44,0x48,0x50,0x40,0x40,0x40,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x84,0x44,0x24,0x14,0x04,0x04,0x04,0xfc,0x00,0x00,
+/* 11194 0x2bba "⮺" */
+0x00,0x00,0x03,0x02,0x02,0x02,0x3f,0x22,0x22,0x23,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xc4,0x44,0x44,0xfc,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 11195 0x2bbb "⮻" */
+0x00,0x00,0x03,0x03,0x03,0x03,0x3f,0x23,0x23,0x23,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 11196 0x2bbc "⮼" */
+0x00,0x00,0x03,0x03,0x03,0x03,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x3f,0x00,0x00,
+0x00,0x00,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 11197 0x2bbd "⮽" */
+0x00,0x00,0x3f,0x20,0x20,0x24,0x22,0x21,0x20,0x21,0x22,0x24,0x20,0x3f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x14,0x24,0x44,0x84,0x44,0x24,0x14,0x04,0xfc,0x00,0x00,
+/* 11198 0x2bbe "⮾" */
+0x00,0x00,0x07,0x08,0x10,0x20,0x24,0x42,0x41,0x42,0x24,0x20,0x10,0x08,0x07,0x00,
+0x00,0x00,0xc0,0x20,0x10,0x08,0x48,0x84,0x04,0x84,0x48,0x08,0x10,0x20,0xc0,0x00,
+/* 11199 0x2bbf "⮿" */
+0x00,0x00,0x07,0x1f,0x38,0x30,0x64,0x62,0x61,0x62,0x64,0x30,0x38,0x1f,0x07,0x00,
+0x00,0x00,0xc0,0xf0,0x38,0x18,0x4c,0x8c,0x0c,0x8c,0x4c,0x18,0x38,0xf0,0xc0,0x00,
+/* 11200 0x2bc0 "⯀" */
+0x00,0x00,0x00,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0xfc,0x00,0x00,
+/* 11201 0x2bc1 "⯁" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x3f,0x1f,0x0f,0x07,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xf0,0xe0,0xc0,0x80,0x00,0x00,0x00,
+/* 11202 0x2bc2 "⯂" */
+0x00,0x00,0x00,0x07,0x0f,0x0f,0x1f,0x1f,0x3f,0x3f,0x1f,0x0f,0x07,0x03,0x01,0x00,
+0x00,0x00,0x00,0xe0,0xf0,0xf0,0xf8,0xf8,0xfc,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0x00,
+/* 11203 0x2bc3 "⯃" */
+0x00,0x00,0x07,0x0f,0x1f,0x3f,0x7f,0x7f,0x7f,0x7f,0x7f,0x3f,0x1f,0x0f,0x07,0x00,
+0x00,0x00,0xc0,0xe0,0xf0,0xf8,0xfc,0xfc,0xfc,0xfc,0xfc,0xf8,0xf0,0xe0,0xc0,0x00,
+/* 11204 0x2bc4 "⯄" */
+0x00,0x03,0x07,0x3f,0x3f,0x3f,0x7f,0xff,0xff,0xff,0x7f,0x3f,0x3f,0x3f,0x07,0x03,
+0x00,0x80,0xc0,0xf8,0xf8,0xf8,0xfc,0xfe,0xfe,0xfe,0xfc,0xf8,0xf8,0xf8,0xc0,0x80,
+/* 11205 0x2bc5 "⯅" */
+0x00,0x00,0x01,0x03,0x03,0x07,0x07,0x0f,0x0f,0x1f,0x1f,0x3f,0x3f,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0xc0,0xc0,0xe0,0xe0,0xf0,0xf0,0xf8,0xf8,0xfc,0x00,0x00,
+/* 11206 0x2bc6 "⯆" */
+0x00,0x00,0x00,0x7f,0x3f,0x3f,0x1f,0x1f,0x0f,0x0f,0x07,0x07,0x03,0x03,0x01,0x00,
+0x00,0x00,0x00,0xfc,0xf8,0xf8,0xf0,0xf0,0xe0,0xe0,0xc0,0xc0,0x80,0x80,0x00,0x00,
+/* 11207 0x2bc7 "⯇" */
+0x00,0x00,0x00,0x00,0x03,0x0f,0x3f,0x7f,0x3f,0x0f,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x38,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0x38,0x08,0x00,0x00,
+/* 11208 0x2bc8 "⯈" */
+0x00,0x40,0x70,0x7c,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7f,0x7c,0x70,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xf0,0xf8,0xf0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11209 0x2bc9 "⯉" */
+0x00,0x00,0x40,0x4a,0x4c,0x58,0x78,0x7e,0x08,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11210 0x2bca "⯊" */
+0x00,0x00,0x07,0x0f,0x1f,0x3f,0x3f,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xe0,0xf0,0xf8,0xf8,0xfc,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11211 0x2bcb "⯋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x3f,0x3f,0x1f,0x0f,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0xfc,0xf8,0xf8,0xf0,0xe0,0xc0,0x00,
+/* 11212 0x2bcc "⯌" */
+0x01,0x01,0x03,0x03,0x07,0x0f,0x3f,0xff,0x3f,0x0f,0x07,0x03,0x03,0x01,0x01,0x00,
+0x00,0x00,0x80,0x80,0xc0,0xe0,0xf8,0xfe,0xf8,0xe0,0xc0,0x80,0x80,0x00,0x00,0x00,
+/* 11213 0x2bcd "⯍" */
+0x00,0x00,0x00,0x20,0x10,0x0c,0x0f,0x07,0x07,0x07,0x0f,0x0c,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x60,0xe0,0xc0,0xc0,0xc0,0xe0,0x60,0x10,0x08,0x00,0x00,
+/* 11214 0x2bce "⯎" */
+0x01,0x01,0x03,0x02,0x04,0x08,0x30,0xe0,0x30,0x08,0x04,0x02,0x03,0x01,0x01,0x00,
+0x00,0x00,0x80,0x80,0x40,0x20,0x18,0x0e,0x18,0x20,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 11215 0x2bcf "⯏" */
+0x00,0x00,0x00,0x20,0x10,0x0c,0x0b,0x04,0x04,0x04,0x0b,0x0c,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x60,0xa0,0x40,0x40,0x40,0xa0,0x60,0x10,0x08,0x00,0x00,
+/* 11216 0x2bd0 "⯐" */
+0x00,0x00,0x01,0x01,0x1f,0x11,0x11,0x10,0x7c,0x10,0x11,0x11,0x1f,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,
+/* 11217 0x2bd1 "⯑" */
+0x00,0x00,0x01,0x02,0x04,0x0b,0x14,0x20,0x41,0x21,0x10,0x09,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x80,0x40,0xa0,0x50,0x48,0x84,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 11218 0x2bd2 "⯒" */
+0x00,0x00,0x00,0x01,0x01,0x0f,0x01,0x01,0x0f,0x01,0x01,0x0f,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,
+/* 11219 0x2bd3 "⯓" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x28,0x28,0x24,0x13,0x08,0x07,0x01,0x07,0x01,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x28,0x28,0x48,0x90,0x20,0xc0,0x00,0xc0,0x00,
+/* 11220 0x2bd4 "⯔" */
+0x00,0x00,0x1c,0x22,0x21,0x07,0x01,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x70,0x88,0x08,0xc0,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 11221 0x2bd5 "⯕" */
+0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x44,0x63,0x50,0x4c,0x23,0x10,0x08,0x07,0x00,
+0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x44,0x8c,0x14,0x64,0x88,0x10,0x20,0xc0,0x00,
+/* 11222 0x2bd6 "⯖" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xa0,0x50,0x48,0x28,0x28,0x28,0x48,0x50,0xa0,0xc0,0x00,0x00,
+/* 11223 0x2bd7 "⯗" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x01,0x03,0x04,0x0b,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x00,0x80,0x40,0xa0,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 11224 0x2bd8 "⯘" */
+0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x04,0x05,0x05,0x04,0x04,0x04,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3c,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0x20,0x3c,0x00,0x00,
+/* 11225 0x2bd9 "⯙" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x01,0x02,0x1e,0x01,0x00,
+0x00,0x00,0x00,0x80,0x40,0x78,0xc0,0x40,0x80,0x80,0x00,0x80,0x40,0x40,0x80,0x00,
+/* 11226 0x2bda "⯚" */
+0x00,0x00,0x11,0x21,0x21,0x21,0x19,0x07,0x09,0x11,0x09,0x07,0x09,0x07,0x00,0x00,
+0x00,0x00,0x10,0x08,0x08,0x08,0x30,0xc0,0x20,0x10,0x20,0xc0,0x20,0xc0,0x00,0x00,
+/* 11227 0x2bdb "⯛" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,
+/* 11228 0x2bdc "⯜" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x20,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,
+/* 11229 0x2bdd "⯝" */
+0x00,0x00,0x00,0x07,0x02,0x01,0x01,0x00,0x00,0x01,0x01,0x02,0x07,0x01,0x07,0x01,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xa0,0xa0,0x20,0x40,0x80,0x00,0x00,0xc0,0x00,
+/* 11230 0x2bde "⯞" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x0f,0x1f,0x0f,0x07,0x03,0x01,0x01,0x07,0x01,0x01,
+0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xf0,0xe0,0xc0,0x80,0x00,0x00,0xc0,0x00,0x00,
+/* 11231 0x2bdf "⯟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x30,0x2c,0x13,0x08,0x07,0x01,0x07,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x18,0x68,0x90,0x20,0xc0,0x00,0xc0,0x00,
+/* 11232 0x2be0 "⯠" */
+0x00,0x00,0x00,0x38,0x04,0x02,0x02,0x02,0x02,0x04,0x08,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x70,0x20,0xf8,0x20,0xf8,0x20,0x20,
+/* 11233 0x2be1 "⯡" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x21,0x21,0x27,0x21,0x21,0x11,0x09,0x07,0x01,0x01,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0x00,0xc0,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 11234 0x2be2 "⯢" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x19,0x07,0x01,0x06,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x30,0xc0,0x00,0xc0,0x30,0x00,0x00,
+/* 11235 0x2be3 "⯣" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x21,0x21,0x27,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11236 0x2be4 "⯤" */
+0x00,0x00,0x00,0x38,0x04,0x02,0x02,0x02,0x02,0x04,0x08,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0xf8,0x50,0x50,0x50,0x50,
+/* 11237 0x2be5 "⯥" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x03,0x05,0x07,0x05,0x03,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x40,0xc0,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 11238 0x2be6 "⯦" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x01,0x01,0x02,0x04,0x08,0x10,0x3f,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0xf8,
+/* 11239 0x2be7 "⯧" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x11,0x09,0x07,0x01,0x01,0x07,0x09,0x11,0x20,0x20,
+0x00,0x00,0x00,0x00,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,
+/* 11240 0x2be8 "⯨" */
+0x00,0x00,0x00,0x01,0x01,0x03,0x3f,0x1f,0x0f,0x07,0x03,0x07,0x0f,0x0c,0x10,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 11241 0x2be9 "⯩" */
+0x00,0x04,0x04,0x06,0x06,0x07,0x07,0x07,0x07,0x07,0x07,0x07,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xe0,0xc0,0x80,0x00,0x80,0xc0,0xc0,0x20,0x00,
+/* 11242 0x2bea "⯪" */
+0x00,0x01,0x01,0x03,0x03,0x07,0x7f,0x3f,0x1f,0x0f,0x07,0x0f,0x1e,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x3c,0x08,0x10,0x60,0x40,0x20,0xd0,0x30,0x08,0x00,
+/* 11243 0x2beb "⯫" */
+0x00,0x01,0x01,0x03,0x03,0x05,0x79,0x21,0x11,0x0d,0x05,0x09,0x16,0x18,0x20,0x00,
+0x00,0x00,0x00,0x80,0x80,0xc0,0xfc,0xf8,0xf0,0xe0,0xc0,0xe0,0xf0,0x30,0x08,0x00,
+/* 11244 0x2bec "⯬" */
+0x00,0x00,0x02,0x06,0x0e,0x1e,0x3e,0x7f,0x3e,0x1e,0x0e,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x08,0x18,0x38,0x78,0xf8,0xfe,0xf8,0x78,0x38,0x18,0x08,0x00,0x00,0x00,
+/* 11245 0x2bed "⯭" */
+0x00,0x01,0x03,0x07,0x0f,0x1f,0x3f,0x01,0x03,0x07,0x0f,0x1f,0x3f,0x01,0x01,0x00,
+0x00,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0x00,0x80,0xc0,0xe0,0xf0,0xf8,0x00,0x00,0x00,
+/* 11246 0x2bee "⯮" */
+0x00,0x00,0x10,0x18,0x1c,0x1e,0x1f,0x7f,0x1f,0x1e,0x1c,0x18,0x10,0x00,0x00,0x00,
+0x00,0x00,0x40,0x60,0x70,0x78,0x7c,0xfe,0x7c,0x78,0x70,0x60,0x40,0x00,0x00,0x00,
+/* 11247 0x2bef "⯯" */
+0x00,0x00,0x00,0x1f,0x0f,0x07,0x03,0x01,0x00,0x1f,0x0f,0x07,0x03,0x01,0x00,0x00,
+0x00,0x80,0x80,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0xfc,0xf8,0xf0,0xe0,0xc0,0x80,0x00,
+/* 11248 0x2bf0 "⯰" */
+0x00,0x00,0x00,0x39,0x05,0x03,0x03,0x01,0x01,0x01,0x03,0x03,0x05,0x39,0x00,0x00,
+0x00,0x00,0x00,0x38,0x40,0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x40,0x38,0x00,0x00,
+/* 11249 0x2bf1 "⯱" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x01,0x07,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0xc0,0x80,0x00,0x00,0x00,
+/* 11250 0x2bf2 "⯲" */
+0x00,0x00,0x00,0x00,0x19,0x25,0x25,0x1f,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x80,0x40,0x20,0x20,0x20,0x00,0x00,
+/* 11251 0x2bf3 "⯳" */
+0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x01,0x06,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0xc0,0x30,0x00,0x00,
+/* 11252 0x2bf4 "⯴" */
+0x00,0x00,0x00,0x00,0x7f,0x41,0x22,0x14,0x08,0x08,0x14,0x22,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x04,0x88,0x50,0x20,0x20,0x50,0x88,0x04,0xfc,0x00,0x00,
+/* 11253 0x2bf5 "⯵" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x14,0x08,0x08,0x14,0x22,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x88,0x50,0x20,0x20,0x50,0x88,0x04,0x04,0x00,0x00,
+/* 11254 0x2bf6 "⯶" */
+0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xf0,0x00,0x00,
+/* 11255 0x2bf7 "⯷" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0xf8,0x00,0x00,
+/* 11256 0x2bf8 "⯸" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x3f,0x03,0x05,0x09,0x11,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 11257 0x2bf9 "⯹" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x3f,0x00,0x1c,0x22,0x21,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0xf8,0x00,0x70,0x88,0x08,0x88,0x70,0x00,0x00,
+/* 11258 0x2bfa "⯺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 11259 0x2bfb "⯻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x8a,0x88,0x70,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0xa2,0x22,0x1c,0x00,0x00,0x00,0x00,
+/* 11260 0x2bfc "⯼" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 11261 0x2bfd "⯽" */
+0x00,0x00,0x00,0x01,0x03,0x07,0x01,0x01,0x01,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 11262 0x2bfe "⯾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 11263 0x2bff "⯿" */
+0x00,0x00,0x00,0x00,0x7c,0x7c,0x10,0x10,0x1c,0x1c,0x10,0x10,0x7c,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11264 0x2c00 "Ⰰ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x54,0x54,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11265 0x2c01 "Ⰱ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0xfe,0x80,0x80,0x80,0x80,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11266 0x2c02 "Ⰲ" */
+0x00,0x00,0x00,0x00,0x44,0xaa,0x6c,0x28,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11267 0x2c03 "Ⰳ" */
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x70,0x20,0x20,0x4c,0x52,0x92,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11268 0x2c04 "Ⰴ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x28,0x6c,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11269 0x2c05 "Ⰵ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x1c,0x04,0x1c,0x04,0x04,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11270 0x2c06 "Ⰶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x28,0x28,0x6c,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11271 0x2c07 "Ⰷ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x44,0x38,0xfe,0x92,0x64,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11272 0x2c08 "Ⰸ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x88,0x88,0xff,0x8d,0x8d,0x55,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11273 0x2c09 "Ⰹ" */
+0x00,0x00,0x00,0x00,0x7c,0x6c,0x92,0x92,0x7c,0x10,0x10,0x10,0x10,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11274 0x2c0a "Ⰺ" */
+0x00,0x00,0x00,0x00,0x7c,0x6c,0x92,0x92,0x6c,0x28,0x44,0x44,0x82,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11275 0x2c0b "Ⰻ" */
+0x00,0x00,0x00,0x00,0xfe,0x82,0x44,0x28,0x54,0x82,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11276 0x2c0c "Ⰼ" */
+0x00,0x00,0x00,0x00,0x62,0x65,0x65,0x66,0x96,0x96,0x96,0x99,0x91,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11277 0x2c0d "Ⰽ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x3c,0x04,0x04,0x3c,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11278 0x2c0e "Ⰾ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x7c,0xaa,0xaa,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11279 0x2c0f "Ⰿ" */
+0x00,0x00,0x00,0x00,0x0f,0x12,0x12,0x0c,0x00,0x03,0x07,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0xa4,0xa4,0x98,0x80,0xe0,0x70,0x48,0x48,0x30,0x00,0x00,
+/* 11280 0x2c10 "Ⱀ" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x22,0x22,0xfc,0xa0,0xa0,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11281 0x2c11 "Ⱁ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x1e,0x02,0x02,0x02,0x02,0x1e,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11282 0x2c12 "Ⱂ" */
+0x00,0x00,0x00,0x00,0x3e,0x2a,0x2a,0x2a,0xe4,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11283 0x2c13 "Ⱃ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11284 0x2c14 "Ⱄ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x54,0x28,0x44,0x82,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11285 0x2c15 "Ⱅ" */
+0x00,0x00,0x00,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11286 0x2c16 "Ⱆ" */
+0x00,0x00,0x00,0x00,0x48,0xb4,0x6c,0x24,0x27,0x24,0x24,0x6c,0xb4,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11287 0x2c17 "Ⱇ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x54,0x92,0x92,0x92,0x92,0x54,0x38,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11288 0x2c18 "Ⱈ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x2c,0x32,0x52,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11289 0x2c19 "Ⱉ" */
+0x00,0x00,0x00,0x00,0x7c,0xaa,0xaa,0x92,0x82,0x82,0x92,0xaa,0xaa,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11290 0x2c1a "Ⱊ" */
+0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x72,0x92,0x92,0x92,0x92,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11291 0x2c1b "Ⱋ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0xfe,0x44,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11292 0x2c1c "Ⱌ" */
+0x00,0x00,0x00,0x00,0x71,0x91,0x91,0x6a,0x0a,0x0a,0x0a,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11293 0x2c1d "Ⱍ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x92,0xfe,0x44,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11294 0x2c1e "Ⱎ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11295 0x2c1f "Ⱏ" */
+0x00,0x00,0x00,0x00,0x03,0x01,0x00,0x00,0x1f,0x15,0x08,0x00,0x01,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x10,0xa0,0xe0,0x10,0x10,0xe0,0xa0,0x10,0xf8,0x00,0x00,
+/* 11296 0x2c20 "Ⱐ" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x24,0x18,0xf8,0x98,0xa4,0x24,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11297 0x2c21 "Ⱑ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x7c,0x92,0x92,0x92,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11298 0x2c22 "Ⱒ" */
+0x00,0x00,0x20,0x90,0x78,0x6c,0x44,0x82,0x82,0x82,0x82,0x44,0x6c,0x3c,0x12,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11299 0x2c23 "Ⱓ" */
+0x00,0x00,0x00,0x00,0x7c,0x4a,0x4a,0x4a,0x4c,0x50,0x50,0x60,0x60,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11300 0x2c24 "Ⱔ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x20,0x60,0xb8,0x60,0x20,0x20,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11301 0x2c25 "Ⱕ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x10,0x30,0xdc,0xb0,0x10,0x10,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11302 0x2c26 "Ⱖ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x4c,0x92,0xfe,0x44,0x44,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11303 0x2c27 "Ⱗ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x02,0x0e,0x03,0x0e,0x02,0x02,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x40,0xc0,0x70,0xc0,0x40,0x40,0x44,0x38,0x00,0x00,
+/* 11304 0x2c28 "Ⱘ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x3c,0x05,0x06,0x05,0x04,0x3c,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x80,0x80,0xe0,0x80,0x80,0x80,0x88,0x70,0x00,0x00,
+/* 11305 0x2c29 "Ⱙ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x4c,0x92,0xff,0x38,0x44,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x40,0xc0,0x70,0xc0,0x40,0x40,0x44,0x38,0x00,0x00,
+/* 11306 0x2c2a "Ⱚ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0xff,0xa5,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11307 0x2c2b "Ⱛ" */
+0x00,0x00,0x00,0x00,0xf8,0x88,0x50,0x70,0x8e,0x8a,0x70,0x50,0x88,0xf8,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11308 0x2c2c "Ⱜ" */
+0x00,0x00,0x00,0x00,0x1c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11309 0x2c2d "Ⱝ" */
+0x00,0x00,0x00,0x00,0x82,0xc2,0xb2,0x8a,0xfe,0x8a,0xb2,0xc2,0x82,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11310 0x2c2e "Ⱞ" */
+0x00,0x00,0x00,0x00,0x24,0x54,0x56,0x52,0x52,0x52,0x56,0x5a,0x52,0x52,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11311 0x2c2f "Ⱟ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x1e,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11312 0x2c30 "ⰰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x54,0x54,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11313 0x2c31 "ⰱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0x2a,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11314 0x2c32 "ⰲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xaa,0x6c,0x28,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11315 0x2c33 "ⰳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x70,0x2c,0x52,0x92,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11316 0x2c34 "ⰴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x28,0x6c,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11317 0x2c35 "ⰵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x1c,0x04,0x1c,0x04,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11318 0x2c36 "ⰶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc6,0x28,0x6c,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11319 0x2c37 "ⰷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x1c,0x7f,0x49,0x32,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11320 0x2c38 "ⰸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x88,0xff,0x8d,0x55,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11321 0x2c39 "ⰹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x6c,0x92,0x92,0x7c,0x10,0x10,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11322 0x2c3a "ⰺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x6c,0x92,0x92,0x6c,0x44,0x82,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11323 0x2c3b "ⰻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x82,0x44,0x28,0x54,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11324 0x2c3c "ⰼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x4a,0x4a,0xac,0xac,0xb2,0xa2,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11325 0x2c3d "ⰽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3c,0x04,0x04,0x3c,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11326 0x2c3e "ⰾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x3c,0x5a,0x5a,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11327 0x2c3f "ⰿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x25,0x19,0x01,0x07,0x0e,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x48,0x30,0x00,0xc0,0xe0,0x90,0x60,0x00,0x00,
+/* 11328 0x2c40 "ⱀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x12,0x12,0x7c,0x50,0x50,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11329 0x2c41 "ⱁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x1e,0x02,0x02,0x1e,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11330 0x2c42 "ⱂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x2a,0x2a,0x2a,0x64,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11331 0x2c43 "ⱃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x78,0x44,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11332 0x2c44 "ⱄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x54,0x28,0x44,0x82,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11333 0x2c45 "ⱅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11334 0x2c46 "ⱆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0xb4,0x6c,0x26,0x24,0x6c,0xb4,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11335 0x2c47 "ⱇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x54,0x92,0x92,0x54,0x38,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11336 0x2c48 "ⱈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x52,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11337 0x2c49 "ⱉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0xaa,0x92,0x82,0x82,0x92,0xaa,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11338 0x2c4a "ⱊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x0a,0x0a,0x3a,0x4a,0x4a,0x4a,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11339 0x2c4b "ⱋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0x2a,0x3e,0x14,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11340 0x2c4c "ⱌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x62,0xa2,0xa2,0x74,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11341 0x2c4d "ⱍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x7c,0x92,0xfe,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11342 0x2c4e "ⱎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11343 0x2c4f "ⱏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x01,0x00,0x1f,0x15,0x08,0x01,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x10,0xe0,0x10,0x10,0xe0,0x10,0xf8,0x00,0x00,
+/* 11344 0x2c50 "ⱐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x14,0x78,0x48,0x54,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11345 0x2c51 "ⱑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x7c,0x92,0x92,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11346 0x2c52 "ⱒ" */
+0x00,0x00,0x00,0x00,0x20,0x90,0x78,0x6c,0x44,0x82,0x82,0x44,0x6c,0x3c,0x12,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11347 0x2c53 "ⱓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x54,0x54,0x58,0x50,0x50,0x60,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11348 0x2c54 "ⱔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x30,0x5c,0x30,0x10,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11349 0x2c55 "ⱕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x18,0x6e,0x58,0x08,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11350 0x2c56 "ⱖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x4c,0x92,0xfe,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11351 0x2c57 "ⱗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x0e,0x03,0x0e,0x02,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xc0,0x70,0xc0,0x40,0x44,0x38,0x00,0x00,
+/* 11352 0x2c58 "ⱘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x1e,0x03,0x02,0x1e,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xc0,0x70,0xc0,0x40,0x44,0x38,0x00,0x00,
+/* 11353 0x2c59 "ⱙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x26,0x49,0x7f,0x1c,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x60,0xb8,0x60,0x20,0x22,0x1c,0x00,0x00,
+/* 11354 0x2c5a "ⱚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0xfe,0xaa,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11355 0x2c5b "ⱛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x48,0x30,0x4e,0x4a,0x30,0x48,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11356 0x2c5c "ⱜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11357 0x2c5d "ⱝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x62,0x52,0x4a,0x7e,0x4a,0x52,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11358 0x2c5e "ⱞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x54,0x56,0x52,0x56,0x5a,0x52,0x52,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11359 0x2c5f "ⱟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x1e,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11360 0x2c60 "Ⱡ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x70,0x20,0x70,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11361 0x2c61 "ⱡ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x1c,0x08,0x1c,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11362 0x2c62 "Ɫ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x34,0x58,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11363 0x2c63 "Ᵽ" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x72,0x22,0x3c,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11364 0x2c64 "Ɽ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11365 0x2c65 "ⱥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x39,0x46,0x04,0x3c,0x54,0x64,0x4c,0xb4,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11366 0x2c66 "ⱦ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x11,0x7e,0x14,0x18,0x10,0x30,0x50,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11367 0x2c67 "Ⱨ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11368 0x2c68 "ⱨ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11369 0x2c69 "Ⱪ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11370 0x2c6a "ⱪ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x43,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11371 0x2c6b "Ⱬ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11372 0x2c6c "ⱬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11373 0x2c6d "Ɑ" */
+0x00,0x00,0x00,0x00,0x1a,0x26,0x42,0x42,0x42,0x42,0x42,0x42,0x26,0x1a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11374 0x2c6e "Ɱ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x0a,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11375 0x2c6f "Ɐ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11376 0x2c70 "Ɒ" */
+0x00,0x00,0x00,0x00,0x4c,0x52,0x62,0x42,0x42,0x42,0x42,0x42,0x62,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11377 0x2c71 "ⱱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x85,0x85,0x48,0x48,0x48,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11378 0x2c72 "Ⱳ" */
+0x00,0x00,0x00,0x00,0x84,0x8a,0x8a,0x88,0xa8,0xa8,0xd8,0xd8,0x88,0x88,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11379 0x2c73 "ⱳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x55,0x55,0x54,0x54,0x54,0x54,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11380 0x2c74 "ⱴ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x52,0x62,0xc2,0x24,0x24,0x24,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11381 0x2c75 "Ⱶ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11382 0x2c76 "ⱶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11383 0x2c77 "ⱷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x26,0x49,0x49,0x49,0x49,0x49,0x49,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11384 0x2c78 "ⱸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x7c,0x40,0x45,0x45,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11385 0x2c79 "ⱹ" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x02,0x02,0x02,0x02,0x02,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11386 0x2c7a "ⱺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x49,0x55,0x55,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11387 0x2c7b "ⱻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x02,0x02,0x1e,0x02,0x02,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11388 0x2c7c "ⱼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x0c,0x04,0x04,0x04,0x14,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11389 0x2c7d "ⱽ" */
+0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11390 0x2c7e "Ȿ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x30,0x0c,0x02,0x02,0x42,0x3c,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11391 0x2c7f "Ɀ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x04,0x08,0x10,0x20,0x20,0x40,0x60,0x10,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11392 0x2c80 "Ⲁ" */
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x38,0x48,0x44,0x44,0x4a,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11393 0x2c81 "ⲁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x38,0x44,0x44,0x4a,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11394 0x2c82 "Ⲃ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x44,0x48,0x78,0x44,0x44,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11395 0x2c83 "ⲃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x48,0x50,0x70,0x48,0x44,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11396 0x2c84 "Ⲅ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11397 0x2c85 "ⲅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11398 0x2c86 "Ⲇ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x0c,0x0c,0x14,0x12,0x12,0x12,0xa1,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11399 0x2c87 "ⲇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x18,0x18,0x14,0x14,0xa2,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11400 0x2c88 "Ⲉ" */
+0x00,0x00,0x00,0x00,0x3c,0x66,0x42,0x80,0xfe,0x80,0x80,0x42,0x66,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11401 0x2c89 "ⲉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x80,0xfe,0x80,0x80,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11402 0x2c8a "Ⲋ" */
+0x00,0x00,0x00,0x00,0x3a,0x44,0x40,0x40,0x40,0x20,0x10,0x08,0x04,0x04,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11403 0x2c8b "ⲋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x44,0x40,0x40,0x20,0x18,0x04,0x04,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11404 0x2c8c "Ⲍ" */
+0x00,0x00,0x00,0x80,0xfe,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0xfe,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11405 0x2c8d "ⲍ" */
+0x00,0x00,0x00,0x00,0x00,0x80,0xfe,0x02,0x04,0x08,0x10,0x20,0x40,0xfe,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11406 0x2c8e "Ⲏ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11407 0x2c8f "ⲏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11408 0x2c90 "Ⲑ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0xa4,0xff,0x25,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11409 0x2c91 "ⲑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0xa4,0xff,0x25,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11410 0x2c92 "Ⲓ" */
+0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11411 0x2c93 "ⲓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11412 0x2c94 "Ⲕ" */
+0x00,0x00,0x00,0x00,0x4c,0x44,0x48,0x50,0x70,0x48,0x44,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11413 0x2c95 "ⲕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x44,0x48,0x50,0x70,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11414 0x2c96 "Ⲗ" */
+0x00,0x00,0x00,0x00,0x60,0x10,0x18,0x08,0x08,0x0c,0x14,0x24,0x42,0x83,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11415 0x2c97 "ⲗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x18,0x28,0x44,0x86,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11416 0x2c98 "Ⲙ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0xc6,0xaa,0x92,0x82,0x82,0x82,0x82,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11417 0x2c99 "ⲙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x6c,0x54,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11418 0x2c9a "Ⲛ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0xc2,0xa2,0x92,0x92,0x8a,0x86,0x82,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11419 0x2c9b "ⲛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x64,0x64,0x54,0x54,0x4c,0x4c,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11420 0x2c9c "Ⲝ" */
+0x00,0x00,0x00,0x80,0xff,0x02,0x0c,0x30,0xf8,0x04,0x02,0x02,0x0c,0x7f,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11421 0x2c9d "ⲝ" */
+0x00,0x00,0x00,0x00,0x00,0x80,0xfc,0x04,0x18,0x60,0xf0,0x08,0x18,0x7e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11422 0x2c9e "Ⲟ" */
+0x00,0x00,0x00,0x00,0x38,0x6c,0x44,0x82,0x82,0x82,0x82,0x44,0x6c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11423 0x2c9f "ⲟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x6c,0x44,0x82,0x82,0x44,0x6c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11424 0x2ca0 "Ⲡ" */
+0x00,0x00,0x00,0x00,0xff,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11425 0x2ca1 "ⲡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11426 0x2ca2 "Ⲣ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11427 0x2ca3 "ⲣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11428 0x2ca4 "Ⲥ" */
+0x00,0x00,0x00,0x00,0x1c,0x36,0x22,0x40,0x40,0x40,0x40,0x22,0x36,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11429 0x2ca5 "ⲥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x36,0x22,0x40,0x40,0x22,0x36,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11430 0x2ca6 "Ⲧ" */
+0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11431 0x2ca7 "ⲧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11432 0x2ca8 "Ⲩ" */
+0x00,0x00,0x00,0x00,0x83,0x82,0x44,0x28,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11433 0x2ca9 "ⲩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x83,0x44,0x28,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11434 0x2caa "Ⲫ" */
+0x00,0x00,0x10,0x10,0x38,0x7c,0x54,0x92,0x92,0x92,0x92,0x54,0x7c,0x38,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11435 0x2cab "ⲫ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x7c,0x54,0x92,0x92,0x54,0x7c,0x38,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11436 0x2cac "Ⲭ" */
+0x00,0x00,0x00,0x00,0x43,0x42,0x24,0x18,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11437 0x2cad "ⲭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x43,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11438 0x2cae "Ⲯ" */
+0x00,0x00,0x10,0x10,0x93,0x92,0x54,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11439 0x2caf "ⲯ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x93,0x54,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11440 0x2cb0 "Ⲱ" */
+0x00,0x00,0x00,0x00,0x44,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11441 0x2cb1 "ⲱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x92,0x92,0x92,0x92,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11442 0x2cb2 "Ⲳ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11443 0x2cb3 "ⲳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11444 0x2cb4 "Ⲵ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x46,0x20,0x10,0x08,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11445 0x2cb5 "ⲵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x44,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11446 0x2cb6 "Ⲷ" */
+0x00,0x00,0x00,0x00,0x02,0xfe,0x00,0x00,0x02,0xfe,0x00,0x00,0x02,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11447 0x2cb7 "ⲷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x7e,0x00,0x02,0x7e,0x00,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11448 0x2cb8 "Ⲹ" */
+0x00,0x00,0x00,0x40,0x40,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11449 0x2cb9 "ⲹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x08,0x04,0x08,0x10,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11450 0x2cba "Ⲻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11451 0x2cbb "ⲻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11452 0x2cbc "Ⲽ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11453 0x2cbd "ⲽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11454 0x2cbe "Ⲿ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0xff,0x92,0x92,0x92,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11455 0x2cbf "ⲿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x92,0xff,0x92,0x92,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11456 0x2cc0 "Ⳁ" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x22,0x22,0x3c,0x20,0xfe,0xa0,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11457 0x2cc1 "ⳁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x22,0x22,0x22,0x3c,0x20,0xfe,0xa0,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11458 0x2cc2 "Ⳃ" */
+0x54,0x10,0x7c,0x10,0x44,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x6e,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11459 0x2cc3 "ⳃ" */
+0x00,0x00,0x00,0x54,0x10,0x7c,0x10,0x44,0x92,0x92,0x92,0x92,0x92,0x6e,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11460 0x2cc4 "Ⳅ" */
+0x00,0x00,0x00,0x40,0x7e,0x02,0x0c,0x30,0x78,0x04,0x02,0x02,0x02,0x04,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11461 0x2cc5 "ⳅ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x7c,0x04,0x08,0x10,0x3c,0x02,0x02,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11462 0x2cc6 "Ⳇ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11463 0x2cc7 "ⳇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11464 0x2cc8 "Ⳉ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x7e,0x10,0x20,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11465 0x2cc9 "ⳉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x04,0x7e,0x30,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11466 0x2cca "Ⳋ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x4a,0x32,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11467 0x2ccb "ⳋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x4a,0x32,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11468 0x2ccc "Ⳍ" */
+0x00,0x00,0x00,0x00,0x78,0xc4,0xc2,0x02,0x04,0x7c,0x02,0x02,0x02,0x02,0x82,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11469 0x2ccd "ⳍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xc4,0xc2,0x02,0x3c,0x04,0x02,0x02,0x82,0x7c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11470 0x2cce "Ⳏ" */
+0x00,0x00,0x00,0x00,0x1e,0x11,0x11,0x21,0x22,0x20,0x20,0x40,0x40,0x40,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11471 0x2ccf "ⳏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x11,0x21,0x21,0x22,0x40,0x40,0x40,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11472 0x2cd0 "Ⳑ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11473 0x2cd1 "ⳑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11474 0x2cd2 "Ⳓ" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x4c,0x52,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11475 0x2cd3 "ⳓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x4c,0x52,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11476 0x2cd4 "Ⳕ" */
+0x00,0x0c,0x10,0x20,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11477 0x2cd5 "ⳕ" */
+0x00,0x00,0x00,0x0c,0x10,0x20,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11478 0x2cd6 "Ⳗ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x7e,0xa0,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11479 0x2cd7 "ⳗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x3e,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11480 0x2cd8 "Ⳙ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11481 0x2cd9 "ⳙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11482 0x2cda "Ⳛ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x0c,0x0c,0x54,0x32,0x1a,0x16,0xa3,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11483 0x2cdb "ⳛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x0c,0x2c,0x1a,0x0e,0x53,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11484 0x2cdc "Ⳝ" */
+0x00,0x3c,0x40,0x40,0x38,0x6c,0x44,0x82,0x82,0x82,0x82,0x44,0x6c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11485 0x2cdd "ⳝ" */
+0x00,0x00,0x00,0x3c,0x40,0x40,0x38,0x6c,0x44,0x82,0x82,0x44,0x6c,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11486 0x2cde "Ⳟ" */
+0x00,0x00,0x00,0x00,0x7e,0x22,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11487 0x2cdf "ⳟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x22,0x20,0x20,0x20,0x20,0x24,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11488 0x2ce0 "Ⳡ" */
+0x00,0x00,0x00,0x00,0x10,0x26,0x49,0x51,0x62,0x24,0x58,0x40,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11489 0x2ce1 "ⳡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x26,0x49,0x72,0x24,0x58,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11490 0x2ce2 "Ⳣ" */
+0x00,0x00,0x00,0x00,0xfc,0x20,0x3c,0x22,0x22,0x22,0x3c,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11491 0x2ce3 "ⳣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x3c,0x22,0x22,0x22,0x3c,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11492 0x2ce4 "ⳤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x44,0x48,0x50,0x70,0x48,0x44,0x42,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11493 0x2ce5 "⳥" */
+0x00,0x00,0x1e,0x11,0x11,0x1e,0x10,0x92,0xd6,0xba,0x92,0x92,0x92,0x92,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11494 0x2ce6 "⳦" */
+0x00,0x1e,0x11,0x11,0x1e,0x10,0xfe,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11495 0x2ce7 "⳧" */
+0x01,0x01,0x01,0x01,0x01,0x7f,0x39,0x6d,0x45,0x81,0x81,0x45,0x6d,0x39,0x01,0x01,
+0xe0,0x10,0x10,0xe0,0x00,0xfe,0x1c,0x36,0x22,0x40,0x40,0x22,0x36,0x1c,0x00,0x00,
+/* 11496 0x2ce8 "⳨" */
+0x00,0x1e,0x11,0x11,0x1e,0x10,0x7e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11497 0x2ce9 "⳩" */
+0x1e,0x11,0x11,0x1e,0x10,0x10,0x56,0x54,0x54,0x38,0x38,0x38,0x54,0x54,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11498 0x2cea "⳪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x36,0x22,0x41,0x41,0x22,0x36,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x36,0x22,0x40,0x40,0x22,0x36,0x1c,0x00,0x00,
+/* 11499 0x2ceb "Ⳬ" */
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x92,0x6c,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11500 0x2cec "ⳬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x6c,0x00,0xfe,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11501 0x2ced "Ⳮ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x66,0x5a,0x5a,0x66,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11502 0x2cee "ⳮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x5a,0x5a,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11503 0x2cef "⳯" */
+0x00,0x00,0x0c,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11504 0x2cf0 "⳰" */
+0x60,0x3e,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11505 0x2cf1 "⳱" */
+0x06,0x7c,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11506 0x2cf2 "Ⳳ" */
+0x00,0x08,0x10,0x20,0x3c,0x82,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11507 0x2cf3 "ⳳ" */
+0x00,0x00,0x00,0x08,0x10,0x20,0x3c,0x82,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11508 0x2cf4 "⳴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 11509 0x2cf5 "⳵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 11510 0x2cf6 "⳶" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 11511 0x2cf7 "⳷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11512 0x2cf8 "⳸" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11513 0x2cf9 "⳹" */
+0x00,0x00,0x00,0x00,0xd8,0xd8,0x48,0x24,0x24,0x24,0x24,0x12,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11514 0x2cfa "⳺" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x10,0x20,0x20,0x20,0x20,0x40,0x4c,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11515 0x2cfb "⳻" */
+0x00,0x00,0x00,0x00,0x30,0x30,0x10,0x08,0x08,0x08,0x08,0x04,0x64,0x64,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11516 0x2cfc "⳼" */
+0x00,0x00,0x00,0x00,0x36,0x36,0x24,0x48,0x48,0x48,0x48,0x90,0x90,0x90,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11517 0x2cfd "⳽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x08,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11518 0x2cfe "⳾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x10,0x10,0xd6,0x10,0x10,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11519 0x2cff "⳿" */
+0x00,0x30,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11520 0x2d00 "ⴀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x22,0x20,0x20,0x20,0x3e,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11521 0x2d01 "ⴁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0x44,0x44,0x7c,0x04,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11522 0x2d02 "ⴂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x42,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11523 0x2d03 "ⴃ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x7c,0x14,0x10,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11524 0x2d04 "ⴄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11525 0x2d05 "ⴅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x11,0x11,0x11,0x11,0x11,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x80,
+/* 11526 0x2d06 "ⴆ" */
+0x00,0x00,0x00,0x40,0x70,0x10,0x10,0x10,0x1c,0x12,0x12,0x12,0x12,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11527 0x2d07 "ⴇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0x00,0x00,
+/* 11528 0x2d08 "ⴈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x32,0x22,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11529 0x2d09 "ⴉ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x38,0x24,0x24,0x24,0x24,0x1c,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11530 0x2d0a "ⴊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x00,0x00,
+/* 11531 0x2d0b "ⴋ" */
+0x00,0x00,0x00,0x20,0x3c,0x04,0x04,0x04,0x1e,0x24,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11532 0x2d0c "ⴌ" */
+0x00,0x00,0x00,0x00,0x7c,0x44,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11533 0x2d0d "ⴍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x11,0x11,0x11,0x11,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0xf8,0x00,0x00,
+/* 11534 0x2d0e "ⴎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb2,0xd2,0x12,0x12,0x12,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11535 0x2d0f "ⴏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb2,0xd2,0x12,0x12,0x12,0x1f,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11536 0x2d10 "ⴐ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 11537 0x2d11 "ⴑ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x48,0x48,0x48,0x48,0x48,0x7c,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11538 0x2d12 "ⴒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x44,0x44,0x7c,0x40,0x40,0x40,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11539 0x2d13 "ⴓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0xf8,0x08,0x08,
+/* 11540 0x2d14 "ⴔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x80,0x80,
+/* 11541 0x2d15 "ⴕ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x16,0xba,0xd0,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11542 0x2d16 "ⴖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11543 0x2d17 "ⴗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x22,0x22,0x22,0x3e,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11544 0x2d18 "ⴘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x22,0x22,0x22,0x3e,0x02,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11545 0x2d19 "ⴙ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x3c,0x24,0x24,0x24,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11546 0x2d1a "ⴚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x40,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11547 0x2d1b "ⴛ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x11,0x11,0x11,0x11,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 11548 0x2d1c "ⴜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x98,0x00,0x00,
+/* 11549 0x2d1d "ⴝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x24,0x20,0x38,0x04,0x24,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11550 0x2d1e "ⴞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x22,0x22,0x22,0x22,0x3e,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11551 0x2d1f "ⴟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xfe,0x22,0x14,0x0c,0x12,0x21,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11552 0x2d20 "ⴠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x11,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0xf8,0x00,0x00,
+/* 11553 0x2d21 "ⴡ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x78,0x4c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11554 0x2d22 "ⴢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x78,0x04,0x04,0x04,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11555 0x2d23 "ⴣ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x64,0x24,0x24,0x3c,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11556 0x2d24 "ⴤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x22,0x22,0x3e,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11557 0x2d25 "ⴥ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1f,0x11,0x11,0x11,0x11,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 11558 0x2d26 "⴦" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 11559 0x2d27 "ⴧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x08,0x30,0x40,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11560 0x2d28 "⴨" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11561 0x2d29 "⴩" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 11562 0x2d2a "⴪" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11563 0x2d2b "⴫" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 11564 0x2d2c "⴬" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 11565 0x2d2d "ⴭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x08,0x10,0x20,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11566 0x2d2e "⴮" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11567 0x2d2f "⴯" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11568 0x2d30 "ⴰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11569 0x2d31 "ⴱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0xfe,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11570 0x2d32 "ⴲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x54,0x92,0xfe,0x92,0x54,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11571 0x2d33 "ⴳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x44,0x28,0x10,0x10,0x28,0x44,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11572 0x2d34 "ⴴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x28,0x10,0x10,0x28,0x44,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11573 0x2d35 "ⴵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x44,0x28,0x10,0x10,0x28,0x44,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11574 0x2d36 "ⴶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xd6,0xd6,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11575 0x2d37 "ⴷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11576 0x2d38 "ⴸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x28,0x28,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11577 0x2d39 "ⴹ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x78,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11578 0x2d3a "ⴺ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11579 0x2d3b "ⴻ" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x7e,0x00,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11580 0x2d3c "ⴼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xee,0x28,0x28,0x28,0x38,0x28,0x28,0x28,0xee,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11581 0x2d3d "ⴽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x84,0x88,0x90,0x90,0xa8,0xc4,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11582 0x2d3e "ⴾ" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x00,0x00,0x0c,0x0c,0x00,0x00,0x60,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11583 0x2d3f "ⴿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0xc4,0xa8,0x90,0x90,0x88,0x84,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11584 0x2d40 "ⵀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x54,0x92,0x92,0x92,0x54,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11585 0x2d41 "ⵁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x44,0x8a,0x92,0xa2,0x44,0xb8,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11586 0x2d42 "ⵂ" */
+0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11587 0x2d43 "ⵃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x18,0x24,0x42,0x81,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11588 0x2d44 "ⵄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11589 0x2d45 "ⵅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x54,0x38,0x10,0x10,0x28,0x44,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11590 0x2d46 "ⵆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x66,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11591 0x2d47 "ⵇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x84,0x88,0x90,0x90,0xa0,0xc0,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11592 0x2d48 "ⵈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0x19,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x98,0x98,0x00,0x00,0x00,0x00,0x00,
+/* 11593 0x2d49 "ⵉ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11594 0x2d4a "ⵊ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11595 0x2d4b "ⵋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc6,0x28,0x10,0x10,0x10,0x28,0xc6,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11596 0x2d4c "ⵌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x28,0x28,0xfe,0x28,0xfe,0x28,0x28,0x28,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11597 0x2d4d "ⵍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x2c,0x34,0x24,0x24,0x24,0x24,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11598 0x2d4e "ⵎ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11599 0x2d4f "ⵏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11600 0x2d50 "ⵐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xfe,0x10,0xfe,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11601 0x2d51 "ⵑ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11602 0x2d52 "ⵒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x08,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11603 0x2d53 "ⵓ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11604 0x2d54 "ⵔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11605 0x2d55 "ⵕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0x92,0x8a,0x44,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11606 0x2d56 "ⵖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x7c,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11607 0x2d57 "ⵗ" */
+0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11608 0x2d58 "ⵘ" */
+0x00,0x00,0x00,0x00,0x00,0xc3,0xc3,0x00,0x00,0x18,0x18,0x00,0x00,0xc3,0xc3,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11609 0x2d59 "ⵙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xba,0xba,0xba,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11610 0x2d5a "ⵚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x44,0x8a,0x92,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11611 0x2d5b "ⵛ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x29,0x46,0x40,0x40,0x40,0x46,0x29,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11612 0x2d5c "ⵜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11613 0x2d5d "ⵝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x44,0x28,0x10,0x10,0x28,0x44,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11614 0x2d5e "ⵞ" */
+0x00,0x00,0x00,0x00,0x00,0x1e,0x29,0x46,0x50,0x78,0x50,0x46,0x29,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11615 0x2d5f "ⵟ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x48,0x48,0x7c,0x48,0x48,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11616 0x2d60 "ⵠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11617 0x2d61 "ⵡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11618 0x2d62 "ⵢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x10,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11619 0x2d63 "ⵣ" */
+0x00,0x00,0x00,0x92,0x92,0x54,0x38,0x10,0x10,0x10,0x38,0x54,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11620 0x2d64 "ⵤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11621 0x2d65 "ⵥ" */
+0x00,0x00,0x00,0x92,0x92,0x54,0x38,0x10,0xfe,0x10,0x38,0x54,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11622 0x2d66 "ⵦ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11623 0x2d67 "ⵧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11624 0x2d68 "⵨" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11625 0x2d69 "⵩" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 11626 0x2d6a "⵪" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11627 0x2d6b "⵫" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 11628 0x2d6c "⵬" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 11629 0x2d6d "⵭" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 11630 0x2d6e "⵮" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11631 0x2d6f "ⵯ" */
+0x00,0x24,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11632 0x2d70 "⵰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11633 0x2d71 "⵱" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 11634 0x2d72 "⵲" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 11635 0x2d73 "⵳" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 11636 0x2d74 "⵴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 11637 0x2d75 "⵵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 11638 0x2d76 "⵶" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 11639 0x2d77 "⵷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11640 0x2d78 "⵸" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11641 0x2d79 "⵹" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 11642 0x2d7a "⵺" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11643 0x2d7b "⵻" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 11644 0x2d7c "⵼" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 11645 0x2d7d "⵽" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 11646 0x2d7e "⵾" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11647 0x2d7f "⵿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x1f,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11648 0x2d80 "ⶀ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x0f,0x19,0xd8,0xf8,0xd8,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xfc,0xd6,0xdc,0xc0,0xc0,0x00,0x00,
+/* 11649 0x2d81 "ⶁ" */
+0x00,0x00,0x07,0x0f,0x18,0x10,0x11,0x1f,0x0e,0x02,0x02,0x36,0x3c,0x34,0x00,0x00,
+0x00,0x00,0xfc,0xfc,0xa6,0xa6,0x46,0x7c,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11650 0x2d82 "ⶂ" */
+0x00,0x00,0x00,0x01,0x03,0x06,0x6c,0x7c,0x6c,0x0c,0x0c,0x0c,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xf8,0xe4,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xf0,0x30,0x00,
+/* 11651 0x2d83 "ⶃ" */
+0x00,0x00,0x06,0x06,0x06,0x0f,0x0f,0x19,0xd8,0xf8,0xd8,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11652 0x2d84 "ⶄ" */
+0x00,0x00,0x60,0x7f,0x06,0x0f,0x0f,0x19,0xd8,0xf8,0xd8,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x60,0xe0,0x00,0x00,0x80,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11653 0x2d85 "ⶅ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x0f,0x19,0xd8,0xf8,0xd8,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11654 0x2d86 "ⶆ" */
+0x00,0x00,0x03,0x06,0x0c,0x0c,0x0c,0x0c,0x0e,0x07,0x3f,0x33,0x03,0x3f,0x30,0x00,
+0x00,0x00,0x80,0xc0,0x60,0x60,0x60,0x60,0xc0,0x80,0xf0,0x30,0x00,0x00,0x00,0x00,
+/* 11655 0x2d87 "ⶇ" */
+0x00,0x18,0x1f,0x06,0x0c,0x0c,0x0c,0x0c,0x0e,0x07,0x3f,0x33,0x03,0x3f,0x30,0x00,
+0x00,0x30,0xf0,0xc0,0x60,0x60,0x60,0x60,0xc0,0x80,0xf0,0x30,0x00,0x00,0x00,0x00,
+/* 11656 0x2d88 "ⶈ" */
+0x00,0x00,0x07,0x0f,0x18,0x18,0x1c,0x0c,0x07,0x00,0x00,0x0c,0x0f,0x0c,0x00,0x00,
+0x00,0x00,0xf8,0xcc,0x78,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,0x00,
+/* 11657 0x2d89 "ⶉ" */
+0x18,0x1f,0x01,0x07,0x0f,0x18,0x18,0x0c,0x07,0x00,0x00,0x0c,0x0f,0x0c,0x00,0x00,
+0x18,0xf8,0x80,0xf8,0xcc,0x78,0x00,0x00,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,0x00,
+/* 11658 0x2d8a "ⶊ" */
+0x00,0x00,0x03,0x03,0x03,0x03,0x00,0x01,0x31,0x3f,0x37,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0xc0,0xe0,0x70,0x30,0x30,0x30,0x00,0x00,0x00,
+/* 11659 0x2d8b "ⶋ" */
+0x00,0x00,0x00,0x00,0x01,0x31,0xb1,0xff,0xb1,0x31,0x30,0x30,0x30,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11660 0x2d8c "ⶌ" */
+0x00,0x00,0x01,0x03,0x36,0x3e,0x36,0x07,0x01,0x03,0x03,0x06,0x0e,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xe0,0x20,0x20,0x40,0xf8,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11661 0x2d8d "ⶍ" */
+0x01,0x01,0x01,0x03,0x36,0x3e,0x36,0x07,0x01,0x03,0x03,0x06,0x0e,0x00,0x00,0x00,
+0x80,0x80,0xc0,0xe0,0x20,0x20,0x40,0xf8,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11662 0x2d8e "ⶎ" */
+0x0c,0x0f,0x01,0x01,0x33,0x3e,0x36,0x07,0x01,0x03,0x03,0x06,0x0e,0x00,0x00,0x00,
+0x30,0xf0,0x80,0xc0,0xe0,0x20,0x40,0xf8,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11663 0x2d8f "ⶏ" */
+0x00,0x00,0x00,0x01,0x03,0x03,0x36,0x3e,0x36,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x58,0x58,0x4c,0x4c,0x4c,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11664 0x2d90 "ⶐ" */
+0x00,0x00,0x00,0x01,0x03,0x06,0x0c,0x0c,0x6c,0x7f,0x6e,0x0c,0x06,0x03,0x00,0x00,
+0x00,0x00,0x00,0xfc,0xcc,0xcc,0xaa,0xee,0x00,0x00,0x80,0x40,0xc0,0x80,0x00,0x00,
+/* 11665 0x2d91 "ⶑ" */
+0x00,0x00,0x01,0x03,0x02,0x03,0x01,0x00,0x00,0x07,0x06,0x7e,0x63,0x03,0x00,0x00,
+0x00,0x00,0xc0,0xe0,0x30,0x30,0xf0,0x60,0xc0,0xf0,0x18,0x18,0x00,0x00,0x00,0x00,
+/* 11666 0x2d92 "ⶒ" */
+0x00,0x00,0x0c,0x0f,0x1f,0x19,0x01,0x01,0x31,0x3f,0x33,0x06,0x0c,0x08,0x00,0x00,
+0x00,0x00,0x30,0xf0,0xf8,0x98,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11667 0x2d93 "ⶓ" */
+0x01,0x63,0x7e,0x0c,0x1c,0x33,0x63,0x61,0x60,0x00,0x00,0x00,0x00,0x00,0x07,0x0e,
+0xc0,0xc0,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xfc,0xd4,0xdc,0xc0,0xc0,0xf8,0x1c,
+/* 11668 0x2d94 "ⶔ" */
+0x00,0x00,0xc0,0xff,0x0c,0x1e,0x3e,0x73,0x63,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x60,0xe0,0x7c,0x0c,0x00,0x00,0x00,0x00,
+/* 11669 0x2d95 "ⶕ" */
+0x00,0x00,0x60,0x7f,0x06,0x0f,0x1f,0x39,0x31,0x01,0x01,0x01,0x01,0x0f,0x0c,0x00,
+0x00,0x00,0x60,0xe0,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x90,0xf0,0x00,0x00,
+/* 11670 0x2d96 "ⶖ" */
+0x01,0x63,0x7e,0x0c,0x1c,0x33,0x63,0x61,0x60,0x00,0x00,0x00,0x00,0x00,0x07,0x0e,
+0xc0,0xc0,0x00,0x00,0x00,0x00,0x80,0xd8,0xd8,0xfe,0xc6,0xc0,0xc0,0xc0,0xf8,0x1c,
+/* 11671 0x2d97 "⶗" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11672 0x2d98 "⶘" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11673 0x2d99 "⶙" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 11674 0x2d9a "⶚" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11675 0x2d9b "⶛" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 11676 0x2d9c "⶜" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 11677 0x2d9d "⶝" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 11678 0x2d9e "⶞" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11679 0x2d9f "⶟" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11680 0x2da0 "ⶠ" */
+0x00,0x00,0x1f,0x19,0x01,0x03,0x03,0x06,0x36,0x3e,0x36,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0xf8,0x98,0x80,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 11681 0x2da1 "ⶡ" */
+0x00,0x00,0x3f,0x33,0x03,0x07,0x07,0x0c,0x6c,0x7c,0x6c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0xf0,0x30,0x00,0x80,0xc0,0xe0,0x6c,0x7c,0x6c,0x60,0x60,0x60,0x00,0x00,
+/* 11682 0x2da2 "ⶢ" */
+0x00,0x00,0x3f,0x33,0x03,0x07,0x07,0x0c,0x6c,0x7c,0x6c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0xf0,0x30,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x6c,0x7c,0x0c,0x00,
+/* 11683 0x2da3 "ⶣ" */
+0x00,0x00,0x1f,0x19,0x01,0x03,0x03,0x06,0x36,0x3e,0x36,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x98,0x80,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 11684 0x2da4 "ⶤ" */
+0x00,0x00,0x3f,0x33,0x03,0x07,0x07,0x0c,0x6c,0x7c,0x6c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0xf0,0x30,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x7c,0x64,0x7c,0x00,0x00,
+/* 11685 0x2da5 "ⶥ" */
+0x00,0x00,0x7f,0x66,0x03,0x07,0x07,0x0c,0x6c,0x7c,0x6c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0xe0,0x60,0x00,0x80,0xc0,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 11686 0x2da6 "ⶦ" */
+0x00,0x00,0x0f,0x0c,0x00,0x01,0x03,0x07,0x36,0x3e,0x36,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0xfc,0xcc,0xc0,0xe0,0xe0,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 11687 0x2da7 "⶧" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11688 0x2da8 "ⶨ" */
+0x00,0x18,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x00,0x00,0x00,
+0x00,0x18,0xf8,0x98,0x80,0x80,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 11689 0x2da9 "ⶩ" */
+0x00,0x18,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x00,0x00,0x00,
+0x00,0x18,0xf8,0x98,0x80,0x80,0xf8,0x98,0x80,0x98,0xf8,0x98,0x80,0x00,0x00,0x00,
+/* 11690 0x2daa "ⶪ" */
+0x00,0x18,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x00,0x00,0x00,
+0x00,0x18,0xf8,0x98,0x80,0x80,0xf8,0x98,0x80,0x80,0x80,0x98,0xf8,0x18,0x00,0x00,
+/* 11691 0x2dab "ⶫ" */
+0x00,0x18,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x01,0x1f,0x19,0x03,0x07,0x18,0x18,
+0x00,0x18,0xf8,0x98,0x80,0x80,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 11692 0x2dac "ⶬ" */
+0x00,0x18,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x00,0x00,0x00,
+0x00,0x18,0xf8,0x98,0x80,0x80,0xf8,0x98,0x80,0x80,0xf0,0x90,0xf0,0x00,0x00,0x00,
+/* 11693 0x2dad "ⶭ" */
+0x00,0x30,0x3f,0x33,0x01,0x01,0x1f,0x19,0x01,0x01,0x1f,0x19,0x01,0x00,0x00,0x00,
+0x00,0x30,0xf0,0x30,0x80,0x80,0xf8,0x98,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 11694 0x2dae "ⶮ" */
+0x30,0x30,0x3b,0x06,0x0c,0x0c,0x0c,0x0c,0x0e,0x7f,0x63,0x03,0x3f,0x33,0x03,0x00,
+0x18,0x18,0xa0,0xc0,0x60,0x60,0x60,0x60,0xc0,0xf8,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 11695 0x2daf "⶯" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11696 0x2db0 "ⶰ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x66,0x06,0x7f,0x66,0x06,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3e,0x66,0x60,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,
+/* 11697 0x2db1 "ⶱ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x66,0x06,0x7f,0x66,0x06,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3e,0x66,0x60,0xfe,0x66,0x60,0x60,0x60,0x00,0x00,0x00,
+/* 11698 0x2db2 "ⶲ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x66,0x06,0x7f,0x66,0x06,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3e,0x66,0x60,0xe0,0x60,0x60,0x66,0x7e,0x06,0x00,0x00,
+/* 11699 0x2db3 "ⶳ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x66,0x06,0x7f,0x66,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3e,0x66,0x60,0xe0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,
+/* 11700 0x2db4 "ⶴ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x66,0x06,0x7f,0x66,0x06,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3e,0x66,0x60,0xe0,0x60,0x7c,0x64,0x7c,0x00,0x00,0x00,
+/* 11701 0x2db5 "ⶵ" */
+0x61,0x7f,0x0c,0x0c,0x7c,0x66,0x06,0x7f,0x66,0x06,0x06,0x06,0x06,0x00,0x00,0x00,
+0x80,0x80,0x00,0x00,0x3e,0x66,0x60,0xe0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,0x00,
+/* 11702 0x2db6 "ⶶ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x66,0x06,0x7f,0x66,0x06,0x06,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3e,0x66,0x60,0xe0,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 11703 0x2db7 "⶷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11704 0x2db8 "ⶸ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x18,0xf8,0xc8,0x1c,0x1a,0x1a,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0x98,0x8c,0x8c,0x8c,0xce,0xad,0xad,0xef,0x00,0x00,
+/* 11705 0x2db9 "ⶹ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x18,0xf8,0xc8,0x1c,0x1a,0x1a,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0x98,0x8f,0x8b,0x88,0xcc,0xaa,0xaa,0xee,0x00,0x00,
+/* 11706 0x2dba "ⶺ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x18,0xf8,0xc8,0x1c,0x1a,0x1a,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0x98,0x8c,0x8c,0x8c,0xcc,0xac,0xac,0xef,0x03,0x00,
+/* 11707 0x2dbb "ⶻ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x1c,0xfa,0xda,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0xf0,0x98,0xcc,0xac,0xac,0xec,0x18,0x1c,0x32,0x3e,0x00,
+/* 11708 0x2dbc "ⶼ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x18,0xf8,0xc8,0x1c,0x1a,0x1a,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xf8,0x9b,0x8e,0x8b,0x88,0xcc,0xaa,0xaa,0xee,0x00,0x00,
+/* 11709 0x2dbd "ⶽ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x1c,0xfa,0xda,0x1e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xf8,0xd8,0xcc,0xea,0x6a,0x6e,0x50,0x50,0x70,0x00,0x00,
+/* 11710 0x2dbe "ⶾ" */
+0x00,0x00,0x00,0x00,0x03,0x07,0x0c,0x18,0xf8,0xc8,0x1c,0x1a,0x1a,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0xf8,0x98,0xcc,0xaa,0xaa,0xee,0x00,0x00,0x00,0x00,0x00,
+/* 11711 0x2dbf "⶿" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11712 0x2dc0 "ⷀ" */
+0x00,0x0c,0x0e,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x30,0x70,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 11713 0x2dc1 "ⷁ" */
+0x00,0x0c,0x0e,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x30,0x70,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x98,0xf8,0x98,0x80,0x00,0x00,
+/* 11714 0x2dc2 "ⷂ" */
+0x00,0x0c,0x0e,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x30,0x70,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x98,0xf8,0x18,0x00,
+/* 11715 0x2dc3 "ⷃ" */
+0x00,0x18,0x1c,0x03,0x03,0x07,0x1b,0x33,0x33,0x1f,0x03,0x06,0x0c,0x38,0x38,0x38,
+0x00,0x60,0xe0,0x00,0x00,0xe0,0x30,0x30,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11716 0x2dc4 "ⷄ" */
+0x00,0x0c,0x0e,0x01,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x30,0x70,0x80,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0xf0,0x90,0xf0,0x00,0x00,
+/* 11717 0x2dc5 "ⷅ" */
+0x00,0x30,0x39,0x06,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0xc0,0xc0,0x00,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 11718 0x2dc6 "ⷆ" */
+0x00,0x0c,0x0e,0x01,0x02,0x02,0x01,0x03,0x0d,0x19,0x19,0x0f,0x01,0x01,0x00,0x00,
+0x00,0x30,0x70,0x80,0x40,0x40,0x80,0xf0,0x98,0x98,0xb0,0xc0,0x80,0x80,0x00,0x00,
+/* 11719 0x2dc7 "⷇" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11720 0x2dc8 "ⷈ" */
+0x00,0x00,0x00,0x0d,0x0d,0x0f,0x0e,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x98,0xd8,0xf0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 11721 0x2dc9 "ⷉ" */
+0x00,0x00,0x00,0x1b,0x1b,0x1f,0x1c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x30,0xb0,0xe0,0xc0,0xc0,0xf8,0xd8,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 11722 0x2dca "ⷊ" */
+0x00,0x00,0x00,0x1b,0x1b,0x1f,0x1c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x30,0xb0,0xe0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0x18,0x00,
+/* 11723 0x2dcb "ⷋ" */
+0x00,0x00,0x00,0x0d,0x0d,0x0f,0x0e,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x98,0xd8,0xf0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 11724 0x2dcc "ⷌ" */
+0x00,0x00,0x00,0x1b,0x1b,0x1f,0x1c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x30,0xb0,0xe0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xc8,0xf8,0x00,0x00,
+/* 11725 0x2dcd "ⷍ" */
+0x00,0x00,0x00,0x19,0x19,0x1f,0x18,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x98,0xd8,0xf0,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 11726 0x2dce "ⷎ" */
+0x00,0x00,0x00,0x0d,0x0d,0x0f,0x0e,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x98,0xd8,0xf0,0x60,0x60,0x60,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11727 0x2dcf "⷏" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11728 0x2dd0 "ⷐ" */
+0x30,0x39,0xc6,0xff,0xc6,0x01,0x03,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 11729 0x2dd1 "ⷑ" */
+0x30,0x39,0xc6,0xff,0xc6,0x01,0x03,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x36,0x3e,0x36,0x30,0x30,0x30,0x00,0x00,
+/* 11730 0x2dd2 "ⷒ" */
+0x30,0x39,0xc6,0xff,0xc6,0x01,0x03,0x06,0x36,0x3e,0x36,0x06,0x06,0x06,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x36,0x3e,0x06,0x00,
+/* 11731 0x2dd3 "ⷓ" */
+0x30,0x39,0xc6,0xff,0xc6,0x01,0x03,0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 11732 0x2dd4 "ⷔ" */
+0x30,0x39,0xc6,0xff,0xc6,0x01,0x03,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x30,0x30,0x30,0x3e,0x32,0x3e,0x00,0x00,
+/* 11733 0x2dd5 "ⷕ" */
+0x30,0x39,0xc6,0xff,0xc6,0x03,0x0f,0x18,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 11734 0x2dd6 "ⷖ" */
+0x30,0x39,0xc6,0xff,0xc6,0x01,0x03,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x00,0x00,
+0xc0,0xc0,0x30,0xf0,0x30,0xc0,0xe0,0x70,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11735 0x2dd7 "⷗" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11736 0x2dd8 "ⷘ" */
+0x00,0x00,0x18,0x1c,0x0f,0x07,0x3f,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0xe0,0xc0,0x80,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 11737 0x2dd9 "ⷙ" */
+0x00,0x00,0x30,0x39,0x1f,0x0f,0x7f,0x61,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x80,0x00,0x00,0x80,0xf0,0xb0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 11738 0x2dda "ⷚ" */
+0x00,0x00,0x30,0x39,0x1f,0x0f,0x7f,0x61,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xf0,0x30,0x00,
+/* 11739 0x2ddb "ⷛ" */
+0x00,0x00,0x30,0x39,0x1f,0x0f,0x7f,0x61,0x01,0x01,0x01,0x03,0x07,0x7c,0x60,0x00,
+0x00,0x00,0xc0,0xc0,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 11740 0x2ddc "ⷜ" */
+0x00,0x00,0x30,0x39,0x1f,0x0f,0x7f,0x61,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0xf0,0x90,0xf0,0x00,0x00,
+/* 11741 0x2ddd "ⷝ" */
+0x00,0x00,0x30,0x39,0x1f,0x0f,0x3f,0x25,0x3d,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0xc0,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 11742 0x2dde "ⷞ" */
+0x30,0x39,0x1f,0x06,0x06,0x0f,0x7f,0x61,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0xc0,0xc0,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 11743 0x2ddf "⷟" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11744 0x2de0 "ⷠ" */
+0x04,0x18,0x20,0x38,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11745 0x2de1 "ⷡ" */
+0x38,0x24,0x38,0x24,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11746 0x2de2 "ⷢ" */
+0x38,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11747 0x2de3 "ⷣ" */
+0x1c,0x14,0x14,0x24,0x3e,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11748 0x2de4 "ⷤ" */
+0x54,0x54,0x38,0x54,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11749 0x2de5 "ⷥ" */
+0x18,0x24,0x08,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11750 0x2de6 "ⷦ" */
+0x24,0x28,0x30,0x28,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11751 0x2de7 "ⷧ" */
+0x1e,0x12,0x12,0x52,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11752 0x2de8 "ⷨ" */
+0x44,0x6c,0x54,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11753 0x2de9 "ⷩ" */
+0x24,0x24,0x3c,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11754 0x2dea "ⷪ" */
+0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11755 0x2deb "ⷫ" */
+0x3c,0x24,0x24,0x24,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11756 0x2dec "ⷬ" */
+0x38,0x24,0x38,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11757 0x2ded "ⷭ" */
+0x18,0x20,0x20,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11758 0x2dee "ⷮ" */
+0x7c,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11759 0x2def "ⷯ" */
+0x44,0x28,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11760 0x2df0 "ⷰ" */
+0x24,0x24,0x24,0x24,0x3e,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11761 0x2df1 "ⷱ" */
+0x24,0x24,0x1c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11762 0x2df2 "ⷲ" */
+0x54,0x54,0x54,0x54,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11763 0x2df3 "ⷳ" */
+0x54,0x54,0x54,0x54,0x7e,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11764 0x2df4 "ⷴ" */
+0x18,0x24,0x3c,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11765 0x2df5 "ⷵ" */
+0x3f,0x44,0x44,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11766 0x2df6 "ⷶ" */
+0x18,0x04,0x1c,0x24,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11767 0x2df7 "ⷷ" */
+0x18,0x24,0x3c,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11768 0x2df8 "ⷸ" */
+0x08,0x1c,0x08,0x1c,0x22,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11769 0x2df9 "ⷹ" */
+0x04,0x28,0x10,0x28,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11770 0x2dfa "ⷺ" */
+0x10,0x7c,0x10,0x1c,0x12,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11771 0x2dfb "ⷻ" */
+0x4c,0x52,0x72,0x52,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11772 0x2dfc "ⷼ" */
+0x4c,0x42,0x7e,0x52,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11773 0x2dfd "ⷽ" */
+0x10,0x28,0x38,0x54,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11774 0x2dfe "ⷾ" */
+0x7c,0x44,0x28,0x38,0x54,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11775 0x2dff "ⷿ" */
+0x5f,0x51,0x4a,0x7e,0x55,0x55,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11776 0x2e00 "⸀" */
+0x00,0x00,0x00,0x3c,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11777 0x2e01 "⸁" */
+0x00,0x00,0x00,0x3c,0x20,0x24,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11778 0x2e02 "⸂" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11779 0x2e03 "⸃" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11780 0x2e04 "⸄" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x24,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11781 0x2e05 "⸅" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x24,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11782 0x2e06 "⸆" */
+0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11783 0x2e07 "⸇" */
+0x00,0x00,0x00,0x7c,0x10,0x14,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11784 0x2e08 "⸈" */
+0x00,0x00,0x00,0x38,0x44,0x40,0x24,0x10,0x88,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11785 0x2e09 "⸉" */
+0x00,0x00,0x00,0x38,0x44,0x40,0x20,0x10,0x88,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11786 0x2e0a "⸊" */
+0x00,0x00,0x00,0x70,0x88,0x08,0x10,0x20,0x44,0x48,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11787 0x2e0b "⸋" */
+0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11788 0x2e0c "⸌" */
+0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11789 0x2e0d "⸍" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11790 0x2e0e "⸎" */
+0x00,0x00,0x01,0x03,0x00,0x0f,0x01,0x02,0x7f,0x02,0x01,0x0f,0x00,0x03,0x01,0x02,
+0x00,0x80,0x00,0x80,0x00,0xe0,0x00,0x80,0xfc,0x80,0x00,0xe0,0x00,0x80,0x00,0x00,
+/* 11791 0x2e0f "⸏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,
+/* 11792 0x2e10 "⸐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 11793 0x2e11 "⸑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x04,0x02,
+/* 11794 0x2e12 "⸒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11795 0x2e13 "⸓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 11796 0x2e14 "⸔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x22,0x24,0x28,0x10,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11797 0x2e15 "⸕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x28,0x48,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11798 0x2e16 "⸖" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11799 0x2e17 "⸗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x60,0x06,0x18,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11800 0x2e18 "⸘" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x30,0x50,0x52,0x52,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11801 0x2e19 "⸙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x2b,0xac,0xaf,0xb0,0x7e,0xe0,0xdc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11802 0x2e1a "⸚" */
+0x00,0x00,0x00,0x00,0x00,0x24,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11803 0x2e1b "⸛" */
+0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x31,0x49,0x46,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11804 0x2e1c "⸜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11805 0x2e1d "⸝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11806 0x2e1e "⸞" */
+0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x31,0x49,0x46,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11807 0x2e1f "⸟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x49,0x46,0x00,0x00,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11808 0x2e20 "⸠" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x1c,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11809 0x2e21 "⸡" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x38,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11810 0x2e22 "⸢" */
+0x00,0x00,0x00,0x0e,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11811 0x2e23 "⸣" */
+0x00,0x00,0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11812 0x2e24 "⸤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11813 0x2e25 "⸥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x70,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11814 0x2e26 "⸦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11815 0x2e27 "⸧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x02,0x02,0x02,0x7c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11816 0x2e28 "⸨" */
+0x00,0x00,0x00,0x12,0x24,0x24,0x48,0x48,0x48,0x48,0x48,0x48,0x24,0x24,0x12,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11817 0x2e29 "⸩" */
+0x00,0x00,0x00,0x90,0x48,0x48,0x24,0x24,0x24,0x24,0x24,0x24,0x48,0x48,0x90,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11818 0x2e2a "⸪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11819 0x2e2b "⸫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11820 0x2e2c "⸬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,0x66,0x66,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11821 0x2e2d "⸭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0xdb,0xdb,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11822 0x2e2e "⸮" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x20,0x10,0x10,0x00,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11823 0x2e2f "ⸯ" */
+0x08,0x10,0x10,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11824 0x2e30 "⸰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11825 0x2e31 "⸱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11826 0x2e32 "⸲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11827 0x2e33 "⸳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11828 0x2e34 "⸴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11829 0x2e35 "⸵" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11830 0x2e36 "⸶" */
+0x00,0x00,0x08,0x18,0x08,0x28,0x78,0x28,0x08,0x18,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11831 0x2e37 "⸷" */
+0x00,0x00,0x08,0x0c,0x08,0x0a,0x0f,0x0a,0x08,0x0c,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11832 0x2e38 "⸸" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x1c,0x08,0x2a,0x7f,0x2a,0x08,0x1c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11833 0x2e39 "⸹" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11834 0x2e3a "⸺" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11835 0x2e3b "⸻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11836 0x2e3c "⸼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x08,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11837 0x2e3d "⸽" */
+0x00,0x00,0x00,0x08,0x00,0x08,0x00,0x08,0x00,0x08,0x00,0x08,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11838 0x2e3e "⸾" */
+0x00,0x0c,0x10,0x08,0x04,0x08,0x10,0x08,0x04,0x08,0x10,0x08,0x04,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11839 0x2e3f "⸿" */
+0x00,0x0a,0x7f,0x8a,0x8a,0xff,0x8a,0x7f,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11840 0x2e40 "⹀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11841 0x2e41 "⹁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x10,0x10,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11842 0x2e42 "⹂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x44,0x44,0x22,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11843 0x2e43 "⹃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11844 0x2e44 "⹄" */
+0x00,0x00,0x00,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11845 0x2e45 "⹅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11846 0x2e46 "⹆" */
+0x00,0x00,0x00,0x00,0x24,0x24,0x18,0x00,0x18,0x24,0x24,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11847 0x2e47 "⹇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11848 0x2e48 "⹈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11849 0x2e49 "⹉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x10,0x00,0x18,0x08,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11850 0x2e4a "⹊" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x18,0x3c,0x3c,0x18,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11851 0x2e4b "⹋" */
+0x00,0x08,0x2a,0x7f,0x2a,0x08,0x08,0x2a,0x7f,0x2a,0x08,0x08,0x2a,0x7f,0x2a,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11852 0x2e4c "⹌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x10,0x60,0x00,0x00,0x60,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11853 0x2e4d "⹍" */
+0x00,0x00,0x00,0x00,0x7e,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11854 0x2e4e "⹎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x68,0x70,0x00,0x00,0x60,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11855 0x2e4f "⹏" */
+0x00,0x00,0x00,0x00,0x00,0x62,0x64,0x08,0x12,0x24,0x08,0x10,0x26,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11856 0x2e50 "⹐" */
+0x00,0x3f,0x0f,0x07,0x07,0x07,0x07,0x07,0x07,0x07,0x07,0x07,0x0f,0x3f,0x00,0x00,
+0x00,0xe0,0x80,0x08,0x08,0x18,0xf8,0xf8,0xf8,0x18,0x08,0x08,0x80,0xe0,0x00,0x00,
+/* 11857 0x2e51 "⹑" */
+0x00,0x0f,0x03,0x21,0x21,0x31,0x3f,0x3f,0x3f,0x31,0x21,0x21,0x03,0x0f,0x00,0x00,
+0x00,0xf8,0xe0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xe0,0xf8,0x00,0x00,
+/* 11858 0x2e52 "⹒" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11859 0x2e53 "⹓" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,0x30,0x30,0x00,0xc0,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11860 0x2e54 "⹔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x3c,0x40,0x00,0xc0,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11861 0x2e55 "⹕" */
+0x00,0x00,0x1e,0x10,0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x10,0x10,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11862 0x2e56 "⹖" */
+0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x08,0x7e,0x08,0x08,0x08,0x08,0x08,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11863 0x2e57 "⹗" */
+0x00,0x00,0x1e,0x10,0x10,0x10,0x10,0x7e,0x10,0x7e,0x10,0x10,0x10,0x10,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11864 0x2e58 "⹘" */
+0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x7e,0x08,0x7e,0x08,0x08,0x08,0x08,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11865 0x2e59 "⹙" */
+0x00,0x00,0x00,0x04,0x08,0x08,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11866 0x2e5a "⹚" */
+0x00,0x00,0x00,0x20,0x10,0x10,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11867 0x2e5b "⹛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x08,0x08,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11868 0x2e5c "⹜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11869 0x2e5d "⹝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x60,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11870 0x2e5e "⹞" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11871 0x2e5f "⹟" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11872 0x2e60 "⹠" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 11873 0x2e61 "⹡" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 11874 0x2e62 "⹢" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 11875 0x2e63 "⹣" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 11876 0x2e64 "⹤" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 11877 0x2e65 "⹥" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 11878 0x2e66 "⹦" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 11879 0x2e67 "⹧" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11880 0x2e68 "⹨" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11881 0x2e69 "⹩" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 11882 0x2e6a "⹪" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11883 0x2e6b "⹫" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 11884 0x2e6c "⹬" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 11885 0x2e6d "⹭" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 11886 0x2e6e "⹮" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11887 0x2e6f "⹯" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11888 0x2e70 "⹰" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 11889 0x2e71 "⹱" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 11890 0x2e72 "⹲" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 11891 0x2e73 "⹳" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 11892 0x2e74 "⹴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 11893 0x2e75 "⹵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 11894 0x2e76 "⹶" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 11895 0x2e77 "⹷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 11896 0x2e78 "⹸" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 11897 0x2e79 "⹹" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 11898 0x2e7a "⹺" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11899 0x2e7b "⹻" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 11900 0x2e7c "⹼" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 11901 0x2e7d "⹽" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 11902 0x2e7e "⹾" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 11903 0x2e7f "⹿" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 11904 0x2e80 "⺀" */
+0x00,0x00,0x00,0x00,0x0e,0x01,0x00,0x00,0x1c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,
+/* 11905 0x2e81 "⺁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x80,
+0x00,0x7c,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11906 0x2e82 "⺂" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 11907 0x2e83 "⺃" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xf0,
+/* 11908 0x2e84 "⺄" */
+0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x12,0x0a,0x06,0x02,
+/* 11909 0x2e85 "⺅" */
+0x00,0x00,0x00,0x01,0x01,0x03,0x05,0x09,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11910 0x2e86 "⺆" */
+0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x40,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 11911 0x2e87 "⺇" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x80,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x0a,0x0a,0x06,0x02,
+/* 11912 0x2e88 "⺈" */
+0x04,0x04,0x07,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11913 0x2e89 "⺉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x14,0x08,
+/* 11914 0x2e8a "⺊" */
+0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11915 0x2e8b "⺋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,
+/* 11916 0x2e8c "⺌" */
+0x01,0x11,0x09,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11917 0x2e8d "⺍" */
+0x02,0x21,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x08,0x90,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11918 0x2e8e "⺎" */
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 11919 0x2e8f "⺏" */
+0x02,0x02,0x04,0x08,0x10,0x64,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x20,0x10,0x08,0x04,0x02,0x22,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,
+/* 11920 0x2e90 "⺐" */
+0x01,0x01,0x01,0x01,0x01,0xff,0x02,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,
+/* 11921 0x2e91 "⺑" */
+0x02,0x02,0x04,0x08,0x10,0x67,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x20,0x10,0x08,0x04,0x02,0xe2,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,
+/* 11922 0x2e92 "⺒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 11923 0x2e93 "⺓" */
+0x00,0x01,0x01,0x02,0x04,0x08,0x10,0x1f,0x01,0x02,0x04,0x08,0x10,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,0x04,
+/* 11924 0x2e94 "⺔" */
+0x00,0x04,0x04,0x04,0x07,0x04,0x08,0x08,0x08,0x08,0x1f,0x00,0x00,0x00,0x7f,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x20,0x20,0x20,0x20,0x40,0xc0,0x40,0x40,0x40,0xfc,0x00,
+/* 11925 0x2e95 "⺕" */
+0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 11926 0x2e96 "⺖" */
+0x08,0x08,0x08,0x08,0x0c,0x4a,0x4a,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11927 0x2e97 "⺗" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x12,0x12,0x22,0x22,0x42,0x0a,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x90,0x48,0x24,0x14,0x10,0x00,0x00,0x00,
+/* 11928 0x2e98 "⺘" */
+0x01,0x01,0x01,0x1f,0x01,0x01,0x01,0x01,0x07,0x19,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11929 0x2e99 "⺙" */
+0x08,0x08,0x08,0x0f,0x18,0x24,0x44,0x82,0x01,0x00,0x01,0x02,0x04,0x08,0x10,0xe0,
+0x00,0x00,0x00,0xfc,0x10,0x10,0x20,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 11930 0x2e9a "⺚" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 11931 0x2e9b "⺛" */
+0x3f,0x02,0x02,0x42,0x42,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,0x00,
+0xf0,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x7c,0x00,0x00,
+/* 11932 0x2e9c "⺜" */
+0x3f,0x20,0x2f,0x20,0x2f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x08,0xe8,0x08,0xe8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11933 0x2e9d "⺝" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 11934 0x2e9e "⺞" */
+0x00,0x00,0x00,0x08,0x08,0x0f,0x10,0x14,0x22,0x41,0x01,0x00,0x01,0x02,0x0c,0x70,
+0x80,0x80,0xfe,0x80,0x80,0xf8,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 11935 0x2e9f "⺟" */
+0x00,0x1f,0x10,0x12,0x11,0x11,0xff,0x20,0x22,0x21,0x21,0x3f,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0xa0,0x40,
+/* 11936 0x2ea0 "⺠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x38,0x30,
+0x00,0x10,0xf8,0x08,0x08,0x08,0xf8,0x00,0x88,0xfc,0x80,0x40,0x20,0x10,0x0e,0x04,
+/* 11937 0x2ea1 "⺡" */
+0x20,0x10,0x10,0x80,0x40,0x48,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11938 0x2ea2 "⺢" */
+0x01,0x01,0x01,0x21,0x11,0x09,0x01,0x01,0x05,0x09,0x11,0xe1,0x41,0x01,0x05,0x02,
+0x00,0x00,0x00,0x08,0x10,0x20,0x00,0x40,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,
+/* 11939 0x2ea3 "⺣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x22,0x42,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x44,0x44,0x04,0x00,0x00,
+/* 11940 0x2ea4 "⺤" */
+0x00,0x00,0x07,0xf8,0x21,0x18,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0x7c,0x80,0x08,0x08,0x90,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11941 0x2ea5 "⺥" */
+0x00,0x1f,0x11,0x11,0x21,0x21,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x7c,0x90,0x10,0x10,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11942 0x2ea6 "⺦" */
+0x02,0x02,0x02,0x22,0x12,0x0a,0x02,0x02,0x06,0x0a,0x12,0x62,0x22,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11943 0x2ea7 "⺧" */
+0x01,0x11,0x1f,0x21,0x01,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11944 0x2ea8 "⺨" */
+0x44,0x28,0x10,0x28,0x48,0x88,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x50,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11945 0x2ea9 "⺩" */
+0xfe,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x16,0x38,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11946 0x2eaa "⺪" */
+0x00,0x00,0xfc,0x08,0x10,0x10,0x10,0x5c,0x50,0x50,0x50,0x50,0x5c,0xf0,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11947 0x2eab "⺫" */
+0x3f,0x24,0x24,0x24,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x48,0x48,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11948 0x2eac "⺬" */
+0x00,0x7e,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11949 0x2ead "⺭" */
+0x20,0x10,0x10,0xf8,0x08,0x10,0x10,0x38,0x54,0x94,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11950 0x2eae "⺮" */
+0x00,0x10,0x10,0x10,0x3e,0x28,0x49,0x8a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0xfe,0x90,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11951 0x2eaf "⺯" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11952 0x2eb0 "⺰" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11953 0x2eb1 "⺱" */
+0x3f,0x20,0x24,0x22,0x21,0x22,0x24,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x08,0x48,0x88,0x08,0x88,0x48,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11954 0x2eb2 "⺲" */
+0x3f,0x24,0x24,0x24,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x48,0x48,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11955 0x2eb3 "⺳" */
+0x00,0x3f,0x20,0x40,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x08,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11956 0x2eb4 "⺴" */
+0x00,0x7f,0x44,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0xfe,0x44,0x48,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x42,0x3e,
+/* 11957 0x2eb5 "⺵" */
+0x00,0x00,0x00,0x3f,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x20,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x00,0x00,
+/* 11958 0x2eb6 "⺶" */
+0x10,0x08,0x3f,0x01,0x1f,0x01,0x02,0xff,0x04,0x08,0x10,0xe0,0x00,0x00,0x00,0x00,
+0x10,0x20,0xf8,0x00,0xf0,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11959 0x2eb7 "⺷" */
+0x08,0x04,0x7f,0x01,0x1f,0x01,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x00,0xf0,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11960 0x2eb8 "⺸" */
+0x04,0x04,0x04,0x7c,0x04,0x04,0x00,0xff,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,
+0x40,0x40,0x40,0x7c,0x40,0x40,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 11961 0x2eb9 "⺹" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x00,0x01,0x02,0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x08,0xc8,0x10,0x20,0xfe,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11962 0x2eba "⺺" */
+0x01,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11963 0x2ebb "⺻" */
+0x01,0x01,0x1f,0x01,0xff,0x01,0x1f,0x01,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11964 0x2ebc "⺼" */
+0x07,0x04,0x05,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x08,0x08,0x10,0x20,0x40,
+0xf8,0x08,0x08,0x88,0x48,0x68,0x08,0x18,0x28,0x48,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 11965 0x2ebd "⺽" */
+0x02,0x0c,0x70,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 11966 0x2ebe "⺾" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11967 0x2ebf "⺿" */
+0x08,0x08,0xfe,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11968 0x2ec0 "⻀" */
+0x00,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+/* 11969 0x2ec1 "⻁" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x20,0x23,0x22,0x22,0x44,0x48,0x90,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x00,0xe0,0x20,0x20,0x24,0x24,0x1c,
+/* 11970 0x2ec2 "⻂" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11971 0x2ec3 "⻃" */
+0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11972 0x2ec4 "⻄" */
+0x00,0x00,0xff,0x04,0x04,0x04,0x7f,0x44,0x44,0x44,0x44,0x48,0x48,0x50,0x40,0x7f,
+0x00,0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x94,0xf4,0x04,0x04,0xfc,
+/* 11973 0x2ec5 "⻅" */
+0x1f,0x10,0x10,0x11,0x11,0x11,0x11,0x11,0x12,0x12,0x04,0x04,0x08,0x30,0xc0,0x00,
+0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x90,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 11974 0x2ec6 "⻆" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x41,0x41,0x80,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 11975 0x2ec7 "⻇" */
+0x04,0x04,0x07,0x08,0x10,0x3f,0x51,0x11,0x12,0x15,0x19,0x12,0x14,0x18,0x10,0x10,
+0x00,0x00,0xf0,0x20,0x40,0xf8,0x08,0x88,0x48,0x28,0x88,0x48,0x28,0x08,0x28,0x10,
+/* 11976 0x2ec8 "⻈" */
+0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11977 0x2ec9 "⻉" */
+0x1f,0x10,0x10,0x10,0x11,0x11,0x11,0x11,0x11,0x12,0x02,0x04,0x08,0x10,0x20,0x00,
+0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x80,0x40,0x20,0x10,0x08,0x00,
+/* 11978 0x2eca "⻊" */
+0x00,0x7f,0x41,0x41,0x41,0x7f,0x49,0x08,0x08,0x4f,0x48,0x48,0x48,0x4f,0xf0,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11979 0x2ecb "⻋" */
+0x02,0x02,0x02,0x7f,0x04,0x09,0x11,0x21,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 11980 0x2ecc "⻌" */
+0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 11981 0x2ecd "⻍" */
+0x20,0x10,0x08,0x40,0x20,0x10,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x28,0x44,0x83,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,
+/* 11982 0x2ece "⻎" */
+0x00,0x20,0x10,0x00,0x00,0xf8,0x08,0x10,0x20,0x78,0x08,0x08,0x10,0x10,0x28,0xc7,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,
+/* 11983 0x2ecf "⻏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3c,0x24,0x28,0x28,0x30,0x28,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,0x20,
+/* 11984 0x2ed0 "⻐" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11985 0x2ed1 "⻑" */
+0x0f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x12,0x11,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfe,0x00,0x10,0xa0,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 11986 0x2ed2 "⻒" */
+0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0xff,0x04,0x08,0x10,0x3f,0x10,0x00,
+0xf8,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xfe,0x00,0x20,0x10,0xf8,0x08,0x00,
+/* 11987 0x2ed3 "⻓" */
+0x08,0x08,0x08,0x08,0x08,0x09,0x08,0xff,0x0a,0x09,0x08,0x08,0x09,0x0a,0x0c,0x08,
+0x00,0x10,0x20,0x40,0x80,0x00,0x00,0xfe,0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 11988 0x2ed4 "⻔" */
+0x20,0x13,0x10,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 11989 0x2ed5 "⻕" */
+0x02,0x04,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,
+/* 11990 0x2ed6 "⻖" */
+0xf8,0x88,0x90,0x90,0xa0,0x90,0x90,0x88,0x88,0x88,0x88,0xf0,0x80,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11991 0x2ed7 "⻗" */
+0x7f,0x01,0xff,0x91,0x8d,0x01,0x1d,0x61,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xfc,0x00,0xfe,0x12,0x62,0x00,0x70,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11992 0x2ed8 "⻘" */
+0x02,0x02,0x7f,0x02,0x3f,0x02,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x00,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xe0,0x20,0xe0,0x20,0xe0,0x20,0x20,0xc0,
+/* 11993 0x2ed9 "⻙" */
+0x01,0x01,0x01,0xff,0x01,0x01,0x3f,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xfe,0x00,0x10,0xf8,0x00,0x04,0xfe,0x04,0x04,0x04,0x28,0x10,0x00,
+/* 11994 0x2eda "⻚" */
+0x7f,0x02,0x04,0x1f,0x10,0x11,0x11,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,0x00,
+0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x40,0x20,0x10,0x08,0x00,
+/* 11995 0x2edb "⻛" */
+0x3f,0x20,0x20,0x28,0x24,0x22,0x22,0x21,0x21,0x22,0x22,0x24,0x48,0x40,0x80,0x00,
+0xf0,0x10,0x10,0x50,0x50,0x90,0x90,0x10,0x10,0x90,0x92,0x4a,0x4a,0x06,0x02,0x00,
+/* 11996 0x2edc "⻜" */
+0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x20,0x20,0x12,0x0a,0x06,0x02,0x00,
+/* 11997 0x2edd "⻝" */
+0x01,0x02,0x04,0x0a,0x31,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x11,0x10,0x12,0x14,0x18,
+0x00,0x80,0x40,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x10,0x08,0x04,
+/* 11998 0x2ede "⻞" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x3e,0x20,0x20,0x3e,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 11999 0x2edf "⻟" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12000 0x2ee0 "⻠" */
+0x20,0x20,0x20,0x3e,0x44,0x48,0x80,0x10,0x10,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12001 0x2ee1 "⻡" */
+0x08,0x08,0x11,0x22,0x11,0x08,0xff,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x88,0x88,0x10,0x20,0x10,0x88,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 12002 0x2ee2 "⻢" */
+0x7f,0x00,0x00,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x20,0x20,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0xe4,0x04,0x04,0x28,0x10,0x00,
+/* 12003 0x2ee3 "⻣" */
+0x1f,0x10,0x1f,0x10,0x10,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0xf0,0x10,0x90,0x90,0x90,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 12004 0x2ee4 "⻤" */
+0x02,0x04,0x3f,0x21,0x21,0x3f,0x22,0x22,0x3f,0x05,0x09,0x09,0x11,0x21,0x41,0x80,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x10,0x20,0x48,0x7c,0x02,0x02,0xfe,
+/* 12005 0x2ee5 "⻥" */
+0x04,0x04,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x3f,0x21,0x21,0x3f,0x00,0x00,0xff,0x00,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 12006 0x2ee6 "⻦" */
+0x01,0x02,0x1f,0x10,0x12,0x11,0x11,0x10,0x10,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x10,0x10,0x10,0x50,0x20,0x00,0xfc,0x04,0x04,0xe4,0x04,0x28,0x10,
+/* 12007 0x2ee7 "⻧" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0xf8,0x08,
+/* 12008 0x2ee8 "⻨" */
+0x01,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe0,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 12009 0x2ee9 "⻩" */
+0x04,0x3f,0x04,0x04,0xff,0x01,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x04,0x08,0x10,
+0x40,0xf8,0x40,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x40,0x20,0x10,
+/* 12010 0x2eea "⻪" */
+0x1f,0x10,0x10,0x1f,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x01,0x01,0x00,
+0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x0a,0x02,0x02,0xfe,
+/* 12011 0x2eeb "⻫" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xf0,0x10,0x1f,0x10,0x10,0x1f,0x10,0x20,0x40,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x1e,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x10,
+/* 12012 0x2eec "⻬" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x0c,0x30,0xc8,0x08,0x08,0x08,0x08,0x10,0x10,0x20,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x60,0x18,0x26,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 12013 0x2eed "⻭" */
+0x01,0x01,0x11,0x11,0x11,0xff,0x00,0x29,0x25,0x23,0x3f,0x23,0x25,0x29,0x21,0x3f,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x28,0x48,0x88,0xf8,0x88,0x48,0x28,0x08,0xf8,
+/* 12014 0x2eee "⻮" */
+0x01,0x01,0x11,0x11,0x11,0x11,0xff,0x00,0x21,0x21,0x22,0x24,0x28,0x20,0x3f,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x08,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 12015 0x2eef "⻯" */
+0x02,0x01,0x7f,0x10,0x08,0xff,0x01,0x1f,0x11,0x1f,0x11,0x11,0x1f,0x11,0x01,0x00,
+0x00,0x00,0xfc,0x10,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0x10,0xf0,0x12,0x02,0xfe,
+/* 12016 0x2ef0 "⻰" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x11,0x22,0x44,0x80,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x88,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 12017 0x2ef1 "⻱" */
+0x04,0x3f,0x20,0x3e,0x02,0x7a,0x0a,0xfe,0x0a,0x7a,0x02,0x7a,0x0a,0xfe,0x0a,0x79,
+0x00,0xf8,0x08,0xf8,0x80,0x80,0xfc,0x94,0xd4,0xa4,0xa4,0xd4,0x94,0xfc,0x82,0xfe,
+/* 12018 0x2ef2 "⻲" */
+0x04,0x0f,0x10,0x3f,0xd1,0x1f,0x11,0x1f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x00,0xc0,0x80,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x02,0xfe,
+/* 12019 0x2ef3 "⻳" */
+0x04,0x04,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x3f,0x21,0x21,0x3f,0x21,0x01,0x01,0x00,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x02,0x02,0xfe,
+/* 12020 0x2ef4 "⻴" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 12021 0x2ef5 "⻵" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 12022 0x2ef6 "⻶" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 12023 0x2ef7 "⻷" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 12024 0x2ef8 "⻸" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 12025 0x2ef9 "⻹" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 12026 0x2efa "⻺" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 12027 0x2efb "⻻" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 12028 0x2efc "⻼" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 12029 0x2efd "⻽" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 12030 0x2efe "⻾" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 12031 0x2eff "⻿" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 12032 0x2f00 "⼀" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12033 0x2f01 "⼁" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12034 0x2f02 "⼂" */
+0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12035 0x2f03 "⼃" */
+0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12036 0x2f04 "⼄" */
+0x00,0x3f,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x40,0xe0,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x06,0xfc,0x00,0x00,0x00,
+/* 12037 0x2f05 "⼅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x00,0x00,
+/* 12038 0x2f06 "⼆" */
+0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x10,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,
+/* 12039 0x2f07 "⼇" */
+0x00,0x00,0x01,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x84,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12040 0x2f08 "⼈" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x0e,0x04,0x00,
+/* 12041 0x2f09 "⼉" */
+0x08,0x0c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,
+0x40,0x60,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x46,0x3c,0x00,
+/* 12042 0x2f0a "⼊" */
+0x1e,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x0c,0x06,0x02,0x00,0x00,
+/* 12043 0x2f0b "⼋" */
+0x00,0x00,0x00,0x06,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,
+0xc0,0x40,0x40,0x40,0x40,0x40,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x06,0x02,0x00,
+/* 12044 0x2f0c "⼌" */
+0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+0x04,0xfe,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x24,0x1c,0x08,0x00,
+/* 12045 0x2f0d "⼍" */
+0x00,0x00,0x00,0x20,0x3f,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12046 0x2f0e "⼎" */
+0x04,0x03,0x01,0x00,0x00,0x00,0x00,0x01,0x01,0x06,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12047 0x2f0f "⼏" */
+0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0x40,0x00,
+0x20,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 12048 0x2f10 "⼐" */
+0x20,0x30,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,0x00,
+0x04,0x06,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,
+/* 12049 0x2f11 "⼑" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x60,0x00,
+0x04,0xfe,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x38,0x10,0x00,
+/* 12050 0x2f12 "⼒" */
+0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x08,0xfc,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x70,0x20,0x00,
+/* 12051 0x2f13 "⼓" */
+0x10,0x10,0x10,0x1f,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xfe,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x38,0x10,0x00,
+/* 12052 0x2f14 "⼔" */
+0x08,0x0c,0x08,0x08,0x08,0x08,0x09,0x0a,0x0c,0x38,0xc8,0x08,0x08,0x08,0x07,0x00,
+0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x04,0x04,0x06,0xfc,0x00,
+/* 12053 0x2f15 "⼕" */
+0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,0x00,
+0x08,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xfc,0x00,0x00,0x00,
+/* 12054 0x2f16 "⼖" */
+0x7f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xfc,0x00,0x00,0x00,
+/* 12055 0x2f17 "⼗" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12056 0x2f18 "⼘" */
+0x02,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x30,0x18,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12057 0x2f19 "⼙" */
+0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+0x20,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 12058 0x2f1a "⼚" */
+0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,
+0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12059 0x2f1b "⼛" */
+0x01,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x11,0xfe,0x40,0x00,0x00,0x00,
+0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,0x04,0x00,0x00,0x00,
+/* 12060 0x2f1c "⼜" */
+0x00,0x3f,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x02,0x04,0x18,0x60,0x00,0x00,
+0x10,0xf8,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x40,0x20,0x1e,0x04,0x00,0x00,
+/* 12061 0x2f1d "⼝" */
+0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,0x00,0x00,
+0x08,0xfc,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 12062 0x2f1e "⼞" */
+0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,0x00,
+0x04,0xfe,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,
+/* 12063 0x2f1f "⼟" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x80,0x00,0x00,0x00,0x08,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xfe,0x00,
+/* 12064 0x2f20 "⼠" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x00,
+0x00,0x80,0x00,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xfc,0x00,
+/* 12065 0x2f21 "⼡" */
+0x04,0x04,0x07,0x0c,0x12,0x21,0x01,0x0e,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0xf8,0x10,0x20,0x40,0x80,0x70,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12066 0x2f22 "⼢" */
+0x02,0x02,0x12,0x0b,0x04,0x04,0x0a,0x0a,0x11,0x21,0x40,0x01,0x06,0x18,0xe0,0x00,
+0x00,0x00,0x10,0xf8,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 12067 0x2f23 "⼣" */
+0x02,0x02,0x02,0x03,0x04,0x04,0x0c,0x12,0x21,0x41,0x00,0x00,0x01,0x06,0x38,0x00,
+0x00,0x00,0x08,0xfc,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12068 0x2f24 "⼤" */
+0x01,0x01,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x80,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x0e,0x04,0x00,
+/* 12069 0x2f25 "⼥" */
+0x02,0x03,0x02,0x02,0x02,0x7f,0x04,0x04,0x08,0x08,0x10,0x0e,0x01,0x06,0x78,0x00,
+0x00,0x00,0x00,0x00,0x04,0xfe,0x20,0x20,0x20,0x20,0x40,0x80,0x80,0x70,0x0e,0x00,
+/* 12070 0x2f26 "⼦" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x04,0x03,0x01,0x00,
+0x08,0xfc,0x10,0x20,0xc0,0x80,0x84,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 12071 0x2f27 "⼧" */
+0x00,0x01,0x00,0x20,0x3f,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x84,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12072 0x2f28 "⼨" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x08,0x04,0x04,0x04,0x00,0x01,0x00,0x00,0x00,
+0x20,0x20,0x20,0x24,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x40,0x00,
+/* 12073 0x2f29 "⼩" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x08,0x10,0x10,0x20,0x40,0x00,0x04,0x03,0x01,0x00,
+0x80,0x80,0x80,0x80,0x80,0x90,0x88,0x84,0x86,0x82,0x82,0x80,0x80,0x80,0x00,0x00,
+/* 12074 0x2f2a "⼪" */
+0x02,0x02,0x02,0x02,0xff,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,0x00,
+0x00,0x00,0x00,0x08,0xfc,0x00,0x00,0x80,0x80,0x80,0x84,0x84,0x84,0x86,0x7c,0x00,
+/* 12075 0x2f2b "⼫" */
+0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0x00,
+0x08,0xfc,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12076 0x2f2c "⼬" */
+0x01,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x02,0x0c,0x70,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12077 0x2f2d "⼭" */
+0x01,0x01,0x01,0x01,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x40,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 12078 0x2f2e "⼮" */
+0x04,0x04,0x08,0x08,0x11,0x11,0x22,0x44,0x22,0x11,0x08,0x08,0x04,0x04,0x04,0x00,
+0x44,0x44,0x88,0x88,0x10,0x10,0x20,0x40,0x20,0x10,0x88,0x88,0x44,0x44,0x44,0x00,
+/* 12079 0x2f2f "⼯" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,0x00,0x00,
+0x08,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,
+/* 12080 0x2f30 "⼰" */
+0x00,0x7f,0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x10,0xf8,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,0x00,0x00,0x04,0x04,0x06,0xfc,0x00,
+/* 12081 0x2f31 "⼱" */
+0x00,0x00,0x00,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x80,0x80,0x80,0x84,0xfe,0x84,0x84,0x84,0x84,0x84,0x84,0xbc,0x88,0x80,0x80,0x00,
+/* 12082 0x2f32 "⼲" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x08,0xfc,0x00,0x00,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12083 0x2f33 "⼳" */
+0x03,0x02,0x04,0x04,0x08,0x10,0x7f,0x21,0x02,0x04,0x08,0x13,0x7c,0x20,0x00,0x00,
+0x00,0x00,0x00,0x30,0x20,0x40,0x80,0x00,0x00,0x20,0x10,0xe8,0x0c,0x04,0x00,0x00,
+/* 12084 0x2f34 "⼴" */
+0x01,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0x00,
+0x00,0x80,0x84,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12085 0x2f35 "⼵" */
+0x08,0x7c,0x08,0x08,0x10,0x24,0x3e,0x04,0x84,0x44,0x28,0x10,0x28,0xc4,0x83,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0xfc,0x00,
+/* 12086 0x2f36 "⼶" */
+0x04,0x04,0x04,0x04,0x04,0x04,0x7f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x00,
+0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+/* 12087 0x2f37 "⼷" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x18,0x08,0x00,0x1e,0xe0,0x00,0x80,0x80,0x80,0x40,0x42,0x22,0x12,0x0e,0x00,
+/* 12088 0x2f38 "⼸" */
+0x00,0x3f,0x00,0x00,0x00,0x1f,0x10,0x10,0x3f,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x10,0xf8,0x10,0x10,0x10,0xf0,0x00,0x08,0xfc,0x08,0x08,0x08,0x08,0xf0,0x20,0x00,
+/* 12089 0x2f39 "⼹" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,
+0x08,0xfc,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 12090 0x2f3a "⼺" */
+0x00,0x00,0x01,0x02,0x04,0x00,0x00,0x01,0x02,0x04,0x00,0x00,0x01,0x02,0x04,0x00,
+0xc0,0x80,0x00,0x00,0x00,0xc0,0x80,0x00,0x00,0x60,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12091 0x2f3b "⼻" */
+0x00,0x00,0x01,0x02,0x04,0x08,0x01,0x03,0x05,0x09,0x11,0x01,0x01,0x01,0x01,0x00,
+0xc0,0x80,0x00,0x00,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12092 0x2f3c "⼼" */
+0x01,0x00,0x00,0x00,0x04,0x04,0x24,0x24,0x24,0x24,0x44,0x84,0x04,0x04,0x03,0x00,
+0x00,0x80,0xc0,0x40,0x00,0x00,0x08,0x04,0x06,0x02,0x00,0x10,0x10,0x18,0xf0,0x00,
+/* 12093 0x2f3d "⼽" */
+0x02,0x02,0x02,0x02,0x02,0x02,0x7f,0x02,0x02,0x02,0x01,0x01,0x02,0x0c,0x70,0x00,
+0x00,0x40,0x20,0x00,0x1c,0xe0,0x00,0x18,0x10,0x20,0x40,0x82,0x44,0x24,0x1e,0x00,
+/* 12094 0x2f3e "⼾" */
+0x00,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x20,0x20,0x40,0x80,0x00,
+0x10,0x38,0xc0,0x08,0xfc,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12095 0x2f3f "⼿" */
+0x00,0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0x7f,0x01,0x01,0x01,0x09,0x07,0x02,0x00,
+0x10,0x78,0x80,0x00,0x10,0xf8,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12096 0x2f40 "⽀" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x02,0x01,0x00,0x01,0x06,0x38,0x00,
+0x80,0x80,0x84,0xfe,0x80,0x90,0xf8,0x10,0x10,0x20,0x40,0x80,0x40,0x30,0x0e,0x00,
+/* 12097 0x2f41 "⽁" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x08,0x04,0x04,0x02,0x01,0x01,0x0e,0x70,0x00,
+0x00,0x00,0x04,0xfe,0x00,0x10,0xf8,0x10,0x20,0x20,0x40,0x80,0x80,0x70,0x0e,0x00,
+/* 12098 0x2f42 "⽂" */
+0x01,0x00,0x00,0x7f,0x08,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x06,0x18,0x60,0x00,
+0x00,0x80,0x84,0xfe,0x20,0x20,0x20,0x40,0x40,0x40,0x80,0x80,0x60,0x18,0x06,0x00,
+/* 12099 0x2f43 "⽃" */
+0x00,0x08,0x04,0x02,0x02,0x08,0x04,0x02,0x02,0x00,0x03,0x7c,0x20,0x00,0x00,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x3e,0xe0,0x20,0x20,0x20,0x20,0x00,
+/* 12100 0x2f44 "⽄" */
+0x00,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0x00,
+0x20,0x70,0x80,0x00,0x00,0x04,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+/* 12101 0x2f45 "⽅" */
+0x01,0x00,0x00,0x7f,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x04,0x08,0x10,0x60,0x00,
+0x00,0x80,0x84,0xfe,0x00,0x00,0x08,0xfc,0x08,0x08,0x08,0x08,0x88,0x70,0x20,0x00,
+/* 12102 0x2f46 "⽆" */
+0x00,0x1f,0x01,0x01,0x01,0x01,0x7f,0x02,0x02,0x02,0x02,0x04,0x08,0x10,0x60,0x00,
+0x08,0xfc,0x00,0x00,0x00,0x04,0xfe,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 12103 0x2f47 "⽇" */
+0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x10,0xf8,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,
+/* 12104 0x2f48 "⽈" */
+0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,0x00,0x00,
+0x08,0xfc,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 12105 0x2f49 "⽉" */
+0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x10,0x20,0x40,0x00,
+0x10,0xf8,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x90,0x70,0x20,0x00,
+/* 12106 0x2f4a "⽊" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x60,0x00,0x00,
+0x80,0x80,0x80,0x84,0xfe,0x80,0x80,0xa0,0xa0,0x90,0x90,0x88,0x86,0x84,0x80,0x00,
+/* 12107 0x2f4b "⽋" */
+0x08,0x08,0x08,0x0f,0x10,0x21,0x41,0x01,0x01,0x01,0x01,0x02,0x04,0x18,0x60,0x00,
+0x00,0x00,0x04,0xfe,0x08,0x10,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 12108 0x2f4c "⽌" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,
+0x80,0x80,0x80,0x80,0x80,0x88,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0xfe,0x00,
+/* 12109 0x2f4d "⽍" */
+0x00,0x7f,0x02,0x02,0x02,0x03,0x04,0x0c,0x12,0x21,0x41,0x00,0x01,0x06,0x78,0x00,
+0x04,0xfe,0x00,0x00,0x10,0xf8,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12110 0x2f4e "⽎" */
+0x04,0x07,0x04,0x04,0x04,0x08,0x10,0x20,0x1f,0x08,0x04,0x02,0x01,0x0e,0x70,0x00,
+0x20,0xf0,0x20,0x20,0x20,0x20,0x1c,0x00,0xf8,0x10,0x20,0x40,0x80,0x70,0x0c,0x00,
+/* 12111 0x2f4f "⽏" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x7f,0x11,0x11,0x21,0x22,0x7f,0x04,0x09,0x30,0x00,
+0x08,0xfc,0x88,0x88,0x88,0x88,0xfe,0x08,0x08,0x08,0x08,0xfe,0x10,0xf0,0x20,0x00,
+/* 12112 0x2f50 "⽐" */
+0x00,0x10,0x10,0x10,0x10,0x12,0x1f,0x10,0x10,0x10,0x10,0x10,0x13,0x3c,0x10,0x00,
+0x40,0x40,0x40,0x40,0x4c,0x48,0x50,0x60,0x40,0x40,0x40,0x44,0x44,0x46,0x3c,0x00,
+/* 12113 0x2f51 "⽑" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x00,0x00,
+0x10,0x38,0xc0,0x00,0x00,0x1c,0xe0,0x00,0x0e,0xf0,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 12114 0x2f52 "⽒" */
+0x00,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x12,0x14,0x78,0x20,0x00,
+0x10,0x38,0xc0,0x80,0x80,0x88,0xfc,0x80,0x80,0x80,0x80,0x42,0x22,0x12,0x0e,0x00,
+/* 12115 0x2f53 "⽓" */
+0x08,0x08,0x0f,0x10,0x2f,0x40,0xbf,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x0a,0x06,0x02,0x00,
+/* 12116 0x2f54 "⽔" */
+0x01,0x01,0x01,0x01,0x01,0x7d,0x05,0x05,0x09,0x09,0x11,0x21,0x49,0x87,0x02,0x00,
+0x00,0x00,0x00,0x18,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x0c,0x06,0x02,0x00,0x00,
+/* 12117 0x2f55 "⽕" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x20,0x00,0x01,0x02,0x04,0x18,0x60,0x00,
+0x80,0x80,0x80,0x80,0x8c,0x88,0x90,0xa0,0xc0,0x80,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 12118 0x2f56 "⽖" */
+0x00,0x10,0x1f,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x21,0x21,0x41,0x81,0x00,
+0x10,0x38,0xe0,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x06,0x02,0x00,
+/* 12119 0x2f57 "⽗" */
+0x04,0x04,0x08,0x10,0x20,0x40,0x04,0x04,0x02,0x02,0x01,0x01,0x02,0x0c,0x30,0x00,
+0x40,0x20,0x10,0x0c,0x04,0x20,0x20,0x40,0x40,0x80,0x80,0x80,0x40,0x30,0x0e,0x00,
+/* 12120 0x2f58 "⽘" */
+0x00,0x18,0x06,0x01,0x02,0x0c,0x30,0x04,0x04,0x02,0x02,0x01,0x02,0x0c,0x30,0x00,
+0x18,0x10,0x20,0xc0,0x30,0x0c,0x24,0x20,0x40,0x40,0x80,0x80,0xc0,0x30,0x0e,0x00,
+/* 12121 0x2f59 "⽙" */
+0x00,0x04,0x04,0x04,0x04,0x07,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x08,0x30,0x00,
+0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+/* 12122 0x2f5a "⽚" */
+0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x20,0x40,0x00,
+0x40,0x40,0x40,0x40,0x44,0xfe,0x00,0x20,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+/* 12123 0x2f5b "⽛" */
+0x00,0x7f,0x00,0x08,0x08,0x10,0x3f,0x01,0x02,0x04,0x08,0x10,0x22,0x41,0x00,0x00,
+0x04,0xfe,0x40,0x40,0x40,0x44,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x80,0x00,
+/* 12124 0x2f5c "⽜" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x20,0x40,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x80,0x88,0xfc,0x80,0x80,0x80,0x84,0xfe,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 12125 0x2f5d "⽝" */
+0x01,0x01,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0xa0,0x10,0x10,0x04,0xfe,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x0e,0x04,0x00,
+/* 12126 0x2f5e "⽞" */
+0x01,0x00,0x00,0x7f,0x01,0x01,0x02,0x05,0x1e,0x08,0x01,0x02,0x05,0x1e,0x08,0x00,
+0x00,0x80,0x84,0xfe,0x00,0x00,0x30,0xe0,0x40,0x80,0x00,0x10,0xf8,0x0c,0x04,0x00,
+/* 12127 0x2f5f "⽟" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0x1f,0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,0x00,
+0x08,0xfc,0x00,0x00,0x00,0x10,0xf8,0x00,0x20,0x10,0x10,0x00,0x04,0xfe,0x00,0x00,
+/* 12128 0x2f60 "⽠" */
+0x00,0x10,0x1f,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x21,0x43,0x81,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x50,0x48,0x48,0xa6,0x22,0x00,
+/* 12129 0x2f61 "⽡" */
+0x00,0x7f,0x04,0x04,0x04,0x07,0x08,0x0a,0x09,0x09,0x10,0x10,0x13,0x7c,0x20,0x00,
+0x04,0xfe,0x00,0x00,0x20,0xf0,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 12130 0x2f62 "⽢" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x0f,0x08,0x00,
+0x10,0x10,0x14,0xfe,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,
+/* 12131 0x2f63 "⽣" */
+0x00,0x10,0x10,0x10,0x1f,0x10,0x20,0x40,0x00,0x1f,0x00,0x00,0x00,0x00,0x7f,0x00,
+0x80,0x80,0x80,0x88,0xfc,0x80,0x80,0x80,0x90,0xf8,0x80,0x80,0x80,0x84,0xfe,0x00,
+/* 12132 0x2f64 "⽤" */
+0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x20,0x20,0x40,0x80,0x00,
+0x04,0xfe,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0xa4,0x9c,0x88,0x00,
+/* 12133 0x2f65 "⽥" */
+0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,0x00,
+0x04,0xfe,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x04,0x00,0x00,
+/* 12134 0x2f66 "⽦" */
+0x00,0x7f,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x18,0x14,0x22,0xc1,0x80,0x00,
+0x04,0xfe,0x84,0x88,0x80,0x80,0x88,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0xfe,0x00,
+/* 12135 0x2f67 "⽧" */
+0x00,0x08,0x0f,0x48,0x28,0x28,0x08,0x18,0x68,0x48,0x08,0x10,0x10,0x20,0x40,0x00,
+0x80,0x44,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12136 0x2f68 "⽨" */
+0x00,0x7f,0x02,0x22,0x14,0x08,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x10,0xa2,0x44,0x28,0x10,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12137 0x2f69 "⽩" */
+0x01,0x01,0x12,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x00,0x00,0x08,0xfc,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 12138 0x2f6a "⽪" */
+0x00,0x00,0x10,0x1f,0x10,0x10,0x10,0x1f,0x12,0x12,0x11,0x20,0x20,0x43,0x9c,0x00,
+0x80,0x80,0x84,0xfe,0x84,0x88,0x80,0xf8,0x10,0x10,0x20,0xc0,0xc0,0x30,0x0e,0x00,
+/* 12139 0x2f6b "⽫" */
+0x10,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x7f,0x00,0x00,0x00,
+0x08,0xfc,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,0x00,0x00,
+/* 12140 0x2f6c "⽬" */
+0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x10,0xf8,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x00,
+/* 12141 0x2f6d "⽭" */
+0x00,0x1f,0x00,0x03,0x00,0x00,0x7f,0x01,0x02,0x04,0x08,0x10,0x24,0x43,0x01,0x00,
+0x10,0xf8,0x20,0x40,0x80,0x84,0xfe,0x88,0x90,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 12142 0x2f6e "⽮" */
+0x08,0x08,0x08,0x0f,0x10,0x20,0x00,0x00,0x7f,0x00,0x01,0x02,0x04,0x18,0x60,0x00,
+0x00,0x00,0x08,0xfc,0x80,0x80,0x80,0x84,0xfe,0x80,0x40,0x20,0x10,0x0e,0x04,0x00,
+/* 12143 0x2f6f "⽯" */
+0x00,0x7f,0x01,0x01,0x02,0x04,0x0f,0x14,0x24,0x44,0x04,0x04,0x07,0x04,0x00,0x00,
+0x04,0xfe,0x00,0x00,0x00,0x08,0xfc,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,
+/* 12144 0x2f70 "⽰" */
+0x00,0x1f,0x00,0x00,0x00,0x00,0x7f,0x00,0x0c,0x08,0x10,0x20,0x44,0x03,0x01,0x00,
+0x10,0xf8,0x00,0x00,0x00,0x04,0xfe,0x80,0xa0,0x90,0x88,0x84,0x84,0x80,0x00,0x00,
+/* 12145 0x2f71 "⽱" */
+0x01,0x01,0x21,0x3f,0x21,0x22,0x22,0x22,0x24,0x3f,0x28,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x04,0xfe,0x04,0x04,0x44,0x24,0xf4,0x14,0x14,0x04,0x04,0x3c,0x08,0x00,
+/* 12146 0x2f72 "⽲" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x01,0x02,0x04,0x08,0x10,0x60,0x00,0x00,
+0x08,0x3c,0xc0,0x80,0x80,0x84,0xfe,0x80,0xc0,0xa0,0x90,0x88,0x86,0x82,0x80,0x00,
+/* 12147 0x2f73 "⽳" */
+0x01,0x00,0x20,0x3f,0x20,0x40,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,
+0x00,0x80,0x82,0xfe,0x04,0x08,0x40,0x40,0x40,0x20,0x20,0x10,0x08,0x0c,0x06,0x00,
+/* 12148 0x2f74 "⽴" */
+0x02,0x01,0x00,0x00,0x3f,0x00,0x08,0x08,0x04,0x04,0x02,0x02,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x80,0x88,0xfc,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x84,0xfe,0x00,0x00,
+/* 12149 0x2f75 "⽵" */
+0x10,0x10,0x10,0x12,0x1f,0x28,0x49,0x8a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x60,0x40,0x44,0x7e,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x70,0x20,0x00,
+/* 12150 0x2f76 "⽶" */
+0x00,0x10,0x08,0x0c,0x04,0x00,0x7f,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
+0x80,0x8c,0x88,0x90,0xa0,0xc4,0xfe,0x80,0xc0,0xa0,0x90,0x88,0x86,0x82,0x80,0x00,
+/* 12151 0x2f77 "⽷" */
+0x01,0x01,0x02,0x04,0x1f,0x08,0x01,0x02,0x3f,0x10,0x00,0x0c,0x08,0x10,0x20,0x00,
+0x80,0x00,0x30,0x20,0xc0,0x80,0x20,0x10,0xfc,0x84,0x80,0x90,0x88,0x86,0x82,0x00,
+/* 12152 0x2f78 "⽸" */
+0x08,0x08,0x08,0x0f,0x10,0x20,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x00,0x00,0x08,0xfc,0x80,0x80,0x84,0xfe,0x80,0x84,0x84,0x84,0x84,0xfc,0x04,0x00,
+/* 12153 0x2f79 "⽹" */
+0x20,0x3f,0x20,0x21,0x21,0x2a,0x24,0x22,0x25,0x29,0x30,0x21,0x20,0x20,0x20,0x00,
+0x04,0xfe,0x04,0x14,0x14,0x94,0x64,0x24,0x24,0x54,0x94,0x04,0x24,0x1c,0x08,0x00,
+/* 12154 0x2f7a "⽺" */
+0x08,0x04,0x02,0x7f,0x01,0x01,0x01,0x1f,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x00,
+0x30,0x20,0x44,0xfe,0x00,0x00,0x10,0xf8,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 12155 0x2f7b "⽻" */
+0x02,0x7f,0x02,0x22,0x12,0x12,0x02,0x06,0x1a,0x62,0x02,0x02,0x12,0x0e,0x04,0x00,
+0x04,0xfe,0x04,0x44,0x24,0x24,0x04,0x0c,0x34,0xc4,0x04,0x04,0x24,0x1c,0x08,0x00,
+/* 12156 0x2f7c "⽼" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x7f,0x00,0x01,0x06,0x0c,0x17,0x64,0x04,0x03,0x00,
+0x00,0x00,0x0c,0xe8,0x10,0x24,0xfe,0x80,0x00,0x30,0xc0,0x04,0x04,0x06,0xfc,0x00,
+/* 12157 0x2f7d "⽽" */
+0x00,0x7f,0x00,0x00,0x21,0x3f,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x20,0x00,
+0x04,0xfe,0x80,0x80,0x04,0xfe,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x5c,0x08,0x00,
+/* 12158 0x2f7e "⽾" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x01,0x01,0xff,0x05,0x05,0x09,0x11,0x21,0xc1,0x00,
+0x00,0x04,0xfe,0x00,0x10,0xf8,0x00,0x04,0xfe,0x40,0x20,0x10,0x0c,0x06,0x02,0x00,
+/* 12159 0x2f7f "⽿" */
+0x00,0x7f,0x08,0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x0f,0x78,0x00,0x00,0x00,
+0x04,0xfe,0x20,0x20,0xe0,0x20,0x20,0x20,0xe0,0x24,0x3e,0xe0,0x20,0x20,0x20,0x00,
+/* 12160 0x2f80 "⾀" */
+0x01,0x01,0x1f,0x01,0x7f,0x01,0x1f,0x01,0x01,0x3f,0x01,0x7f,0x01,0x01,0x01,0x00,
+0x00,0x08,0xfc,0x08,0xfe,0x08,0xf8,0x08,0x00,0xf8,0x04,0xfe,0x00,0x00,0x00,0x00,
+/* 12161 0x2f81 "⾁" */
+0x01,0x01,0x21,0x3f,0x21,0x21,0x22,0x24,0x29,0x21,0x21,0x22,0x24,0x28,0x20,0x00,
+0x00,0x00,0x04,0xfe,0x04,0x84,0x44,0x34,0x14,0x04,0x84,0x44,0x24,0x1c,0x08,0x00,
+/* 12162 0x2f82 "⾂" */
+0x20,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x3f,0x21,0x21,0x21,0x3f,0x20,0x00,
+0x08,0xfc,0x00,0x00,0x08,0xfc,0x08,0x08,0x08,0xf8,0x08,0x00,0x04,0xfe,0x00,0x00,
+/* 12163 0x2f83 "⾃" */
+0x01,0x01,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x00,
+0x80,0x00,0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,
+/* 12164 0x2f84 "⾄" */
+0x00,0x7f,0x01,0x02,0x04,0x08,0x7f,0x21,0x01,0x01,0x3f,0x01,0x01,0x01,0x7f,0x00,
+0x04,0xfe,0x00,0x00,0x20,0x10,0xf8,0x04,0x00,0x08,0xfc,0x00,0x00,0x04,0xfe,0x00,
+/* 12165 0x2f85 "⾅" */
+0x02,0x27,0x38,0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,
+0x00,0x04,0x7e,0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 12166 0x2f86 "⾆" */
+0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x00,
+0x10,0x78,0x80,0x80,0x84,0xfe,0x80,0x80,0x88,0xfc,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 12167 0x2f87 "⾇" */
+0x10,0x10,0x10,0x12,0x1f,0x12,0x22,0x52,0x0a,0x0a,0x04,0x08,0x10,0x20,0x40,0x00,
+0x10,0x10,0x10,0x14,0x7e,0x10,0x50,0x50,0x90,0xfe,0x10,0x10,0x10,0x10,0x10,0x00,
+/* 12168 0x2f88 "⾈" */
+0x01,0x01,0x0a,0x0f,0x09,0x08,0x08,0x08,0x7f,0x09,0x08,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0x10,0xf8,0x10,0x90,0x90,0x14,0xfe,0x10,0x90,0x90,0x10,0xf0,0x20,0x00,
+/* 12169 0x2f89 "⾉" */
+0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x12,0x11,0x11,0x10,0x16,0x78,0x20,0x00,
+0x10,0xf8,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x0c,0x30,0xc0,0x60,0x18,0x06,0x00,
+/* 12170 0x2f8a "⾊" */
+0x04,0x04,0x07,0x08,0x10,0x3f,0x51,0x11,0x11,0x1f,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x20,0xf0,0x40,0x88,0xfc,0x08,0x08,0x08,0xf8,0x08,0x02,0x02,0x02,0xfe,0x00,
+/* 12171 0x2f8b "⾋" */
+0x08,0x08,0x08,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x3e,0x2a,0x08,0x10,0x20,0x40,0x00,
+0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x7c,0x54,0x10,0x10,0x10,0x10,0x00,
+/* 12172 0x2f8c "⾌" */
+0x01,0x01,0x01,0x01,0x3f,0x20,0x21,0x21,0x21,0x21,0x2f,0x21,0x21,0x41,0x80,0x00,
+0x00,0xfc,0x00,0x00,0xfe,0x02,0x04,0x10,0x38,0xc0,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 12173 0x2f8d "⾍" */
+0x00,0x00,0x00,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,0x00,0x00,0x7f,0x30,0x00,
+0x80,0x80,0x80,0x88,0xfc,0x88,0x88,0x88,0xf8,0x88,0x80,0x88,0x84,0xfe,0x02,0x00,
+/* 12174 0x2f8e "⾎" */
+0x00,0x00,0x01,0x12,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x7f,0x00,0x00,
+0xc0,0x80,0x00,0x08,0xfc,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,0x00,
+/* 12175 0x2f8f "⾏" */
+0x18,0x11,0x20,0x40,0x0c,0x0b,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x00,
+0x08,0xfc,0x00,0x00,0x04,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x70,0x20,0x00,
+/* 12176 0x2f90 "⾐" */
+0x01,0x00,0x00,0x7f,0x01,0x02,0x04,0x0c,0x14,0x24,0x44,0x04,0x05,0x0e,0x04,0x00,
+0x00,0x80,0x84,0xfe,0x80,0x8c,0x88,0x50,0x60,0x40,0x20,0x90,0x08,0x06,0x02,0x00,
+/* 12177 0x2f91 "⾑" */
+0x00,0x7f,0x02,0x02,0x22,0x3f,0x22,0x22,0x22,0x22,0x23,0x22,0x20,0x20,0x20,0x00,
+0x04,0xfe,0x20,0x20,0x24,0xfe,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x04,0x00,
+/* 12178 0x2f92 "⾒" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x14,0x08,0x30,0xc0,0x00,
+0x20,0xf0,0x20,0x20,0xe0,0x20,0x20,0xe0,0x20,0x20,0xe0,0xa4,0x84,0x86,0x7c,0x00,
+/* 12179 0x2f93 "⾓" */
+0x04,0x07,0x04,0x08,0x1f,0x28,0x48,0x0f,0x08,0x08,0x0f,0x10,0x10,0x20,0x40,0x00,
+0x20,0xf0,0x20,0x44,0xfe,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x9c,0x88,0x00,
+/* 12180 0x2f94 "⾔" */
+0x02,0x01,0xff,0x00,0x00,0x1f,0x00,0x1f,0x00,0x10,0x1f,0x10,0x10,0x1f,0x10,0x00,
+0x00,0x04,0xfe,0x00,0x00,0xf0,0x00,0xf0,0x00,0x10,0xf8,0x10,0x10,0xf0,0x10,0x00,
+/* 12181 0x2f95 "⾕" */
+0x04,0x04,0x08,0x10,0x21,0x02,0x04,0x18,0x60,0x0f,0x08,0x08,0x08,0x0f,0x08,0x00,
+0x40,0x20,0x10,0x0c,0x84,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x10,0xf0,0x10,0x00,
+/* 12182 0x2f96 "⾖" */
+0x00,0x3f,0x00,0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x04,0x04,0x02,0x02,0x7f,0x00,
+0x08,0xfc,0x00,0x10,0xf8,0x10,0x10,0x10,0xf0,0x10,0x60,0x40,0x40,0x84,0xfe,0x00,
+/* 12183 0x2f97 "⾗" */
+0x00,0x7f,0x01,0x02,0x04,0x1a,0x63,0x04,0x19,0x62,0x04,0x18,0x60,0x04,0x03,0x00,
+0x04,0xfe,0x00,0x00,0x0c,0x08,0x10,0xa0,0xc0,0xa0,0x90,0x8e,0x84,0x80,0x00,0x00,
+/* 12184 0x2f98 "⾘" */
+0x00,0x00,0x01,0x06,0x1a,0x01,0x03,0x0c,0x10,0x03,0x1c,0x00,0x03,0x1d,0x00,0x00,
+0x60,0xc0,0x88,0x5c,0x20,0xc0,0x20,0x60,0x90,0x30,0x50,0x90,0x10,0x20,0xc0,0x00,
+/* 12185 0x2f99 "⾙" */
+0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x03,0x0c,0x30,0x00,
+0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x60,0x18,0x06,0x00,
+/* 12186 0x2f9a "⾚" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x12,0x12,0x22,0x24,0x44,0x09,0x30,0x00,
+0x80,0x80,0x88,0xfc,0x80,0x84,0xfe,0x40,0x48,0x44,0x44,0x42,0x42,0xc0,0x80,0x00,
+/* 12187 0x2f9b "⾛" */
+0x01,0x01,0x01,0x1f,0x01,0x01,0x7f,0x01,0x09,0x09,0x09,0x09,0x15,0x23,0x40,0x00,
+0x00,0x00,0x10,0xf8,0x00,0x04,0xfe,0x00,0x00,0x08,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 12188 0x2f9c "⾜" */
+0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x00,0x08,0x08,0x08,0x14,0x12,0x21,0x40,0x00,
+0x10,0xf8,0x10,0x10,0x10,0xf0,0x90,0x80,0x88,0xfc,0x80,0x80,0x80,0x86,0xfc,0x00,
+/* 12189 0x2f9d "⾝" */
+0x00,0x09,0x0f,0x08,0x0f,0x08,0x08,0x0f,0x08,0x7f,0x00,0x01,0x06,0x18,0x60,0x00,
+0x80,0x10,0xf8,0x10,0xf0,0x10,0x16,0xf4,0x18,0xf0,0x50,0x90,0x10,0xf0,0x20,0x00,
+/* 12190 0x2f9e "⾞" */
+0x01,0x01,0x7f,0x01,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x01,0x7f,0x01,0x01,0x00,
+0x00,0x04,0xfe,0x00,0x08,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x04,0xfe,0x00,0x00,0x00,
+/* 12191 0x2f9f "⾟" */
+0x01,0x00,0x3f,0x08,0x04,0x02,0x02,0x7f,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x00,
+0x00,0x88,0xfc,0x20,0x20,0x40,0x44,0xfe,0x00,0x08,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 12192 0x2fa0 "⾠" */
+0x10,0x1f,0x10,0x10,0x17,0x10,0x10,0x1f,0x12,0x12,0x12,0x22,0x22,0x4f,0x84,0x00,
+0x04,0xfe,0x00,0x10,0xf8,0x00,0x04,0xfe,0x40,0x48,0x50,0x20,0x90,0x08,0x06,0x00,
+/* 12193 0x2fa1 "⾡" */
+0x00,0x01,0x1e,0x00,0x1f,0x00,0x1f,0x00,0x10,0x10,0x18,0x14,0x22,0x41,0x80,0x00,
+0x60,0x80,0x38,0xc0,0x18,0x60,0x80,0x80,0x80,0x88,0xfc,0x80,0x80,0x80,0x7e,0x00,
+/* 12194 0x2fa2 "⾢" */
+0x1f,0x10,0x10,0x1f,0x10,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,
+0xf0,0x10,0x10,0xf0,0x10,0x00,0xf8,0x08,0x08,0xf8,0x08,0x04,0x04,0x06,0xfc,0x00,
+/* 12195 0x2fa3 "⾣" */
+0x00,0x7f,0x02,0x12,0x1f,0x12,0x12,0x12,0x14,0x18,0x10,0x1f,0x10,0x1f,0x10,0x00,
+0x04,0xfe,0x40,0x44,0xfe,0x44,0x44,0x44,0x3c,0x04,0x04,0xfc,0x04,0xfc,0x04,0x00,
+/* 12196 0x2fa4 "⾤" */
+0x00,0x00,0x3f,0x01,0x11,0x09,0x09,0x7f,0x03,0x05,0x09,0x11,0x21,0x41,0x01,0x00,
+0x30,0xf8,0x00,0x10,0x10,0x20,0x44,0xfe,0x80,0x40,0x20,0x10,0x0e,0x04,0x00,0x00,
+/* 12197 0x2fa5 "⾥" */
+0x10,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x11,0x01,0x01,0x3f,0x01,0x01,0x7f,0x00,
+0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x08,0xfc,0x00,0x04,0xfe,0x00,
+/* 12198 0x2fa6 "⾦" */
+0x00,0x01,0x02,0x04,0x08,0x10,0x6f,0x01,0x01,0x3f,0x01,0x11,0x09,0x09,0x7f,0x00,
+0x80,0x80,0x40,0x20,0x10,0x08,0xf6,0x00,0x08,0xfc,0x00,0x18,0x10,0x24,0xfe,0x00,
+/* 12199 0x2fa7 "⾧" */
+0x08,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x08,0x7f,0x08,0x08,0x08,0x09,0x0e,0x38,0x00,
+0x10,0xf8,0x00,0xf0,0x00,0xf0,0x00,0x04,0xfe,0x88,0x50,0x20,0x90,0x0e,0x04,0x00,
+/* 12200 0x2fa8 "⾨" */
+0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x04,0x04,0x04,0x04,0x04,0x24,0x1c,0x08,0x00,
+/* 12201 0x2fa9 "⾩" */
+0x01,0x12,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x10,0xf8,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x88,0x84,0xfe,0x80,0x80,0x80,0x00,
+/* 12202 0x2faa "⾪" */
+0x01,0x01,0x3f,0x01,0x7f,0x01,0x3f,0x01,0x31,0x09,0x07,0x09,0x71,0x27,0x02,0x00,
+0x00,0x10,0xf8,0x10,0xfe,0x10,0xf0,0x10,0x88,0x90,0x60,0x20,0x18,0x06,0x00,0x00,
+/* 12203 0x2fab "⾫" */
+0x04,0x04,0x04,0x0f,0x08,0x18,0x28,0x4f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x00,
+0x80,0x40,0x44,0xfe,0x40,0x40,0x48,0xfc,0x40,0x48,0xfc,0x40,0x44,0xfe,0x00,0x00,
+/* 12204 0x2fac "⾬" */
+0x00,0x7f,0x01,0x21,0x3f,0x21,0x29,0x25,0x25,0x21,0x29,0x25,0x25,0x21,0x21,0x00,
+0x04,0xfe,0x00,0x04,0xfe,0x04,0x44,0x24,0x24,0x04,0x44,0x24,0x24,0x1c,0x08,0x00,
+/* 12205 0x2fad "⾭" */
+0x01,0xff,0x01,0x3f,0x01,0xff,0x00,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x00,
+0x04,0xfe,0x00,0xf8,0x04,0xfe,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x78,0x10,0x00,
+/* 12206 0x2fae "⾮" */
+0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x3e,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x00,
+0x40,0x40,0x44,0x7e,0x40,0x40,0x48,0x7c,0x40,0x40,0x44,0x7e,0x40,0x40,0x40,0x00,
+/* 12207 0x2faf "⾯" */
+0x00,0x7f,0x00,0x21,0x3f,0x22,0x22,0x23,0x22,0x22,0x23,0x22,0x22,0x3f,0x20,0x00,
+0x04,0xfe,0x80,0x04,0xfe,0x44,0x44,0xc4,0x44,0x44,0xc4,0x44,0x44,0xfc,0x04,0x00,
+/* 12208 0x2fb0 "⾰" */
+0x08,0x08,0xff,0x08,0x0f,0x01,0x3f,0x21,0x3f,0x21,0x01,0xff,0x01,0x01,0x01,0x00,
+0x20,0x24,0xfe,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 12209 0x2fb1 "⾱" */
+0x02,0x02,0x1f,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x00,0x3f,0x10,0x3f,0x00,0x00,0x00,
+0x00,0x20,0xf0,0x24,0xfe,0x00,0xf0,0x10,0xf0,0x80,0xfc,0x80,0xfc,0x80,0x80,0x00,
+/* 12210 0x2fb2 "⾲" */
+0x02,0x02,0x02,0x02,0x7e,0x02,0x02,0x3e,0x02,0x02,0x7e,0x02,0x02,0x02,0x7f,0x00,
+0x40,0x40,0x40,0x44,0x7e,0x40,0x40,0x7c,0x40,0x44,0x7e,0x40,0x40,0x44,0xfe,0x00,
+/* 12211 0x2fb3 "⾳" */
+0x03,0x01,0x7f,0x10,0x08,0x04,0xff,0x00,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x00,
+0x00,0x08,0xfc,0x20,0x20,0x40,0xfe,0x00,0x10,0xf8,0x10,0xf0,0x10,0xf0,0x10,0x00,
+/* 12212 0x2fb4 "⾴" */
+0x00,0x7f,0x00,0x11,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x03,0x0c,0x30,0x00,
+0x04,0xfe,0x80,0x08,0xfc,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x60,0x18,0x06,0x00,
+/* 12213 0x2fb5 "⾵" */
+0x20,0x3f,0x20,0x21,0x2f,0x21,0x2f,0x29,0x29,0x2f,0x29,0x21,0x21,0x4f,0x84,0x00,
+0x08,0xfc,0x48,0xe8,0x08,0x08,0xe8,0x28,0x28,0xe8,0x28,0x4a,0xea,0x26,0x02,0x00,
+/* 12214 0x2fb6 "⾶" */
+0x3f,0x00,0x00,0x0d,0x39,0x09,0x09,0x7f,0x09,0x09,0x09,0x11,0x11,0x21,0x41,0x00,
+0xe0,0x24,0x28,0x30,0x2c,0x22,0x12,0xee,0x24,0x28,0x30,0x2c,0x12,0x0a,0x06,0x00,
+/* 12215 0x2fb7 "⾷" */
+0x00,0x01,0x02,0x05,0x18,0x6f,0x08,0x0f,0x08,0x0f,0x08,0x09,0x0a,0x3c,0x10,0x00,
+0x80,0x80,0x40,0x20,0x98,0xf6,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x18,0x06,0x00,
+/* 12216 0x2fb8 "⾸" */
+0x08,0x04,0x7f,0x00,0x11,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x10,0x00,
+0x30,0x20,0xfe,0x80,0x10,0xf8,0x10,0x10,0xf0,0x10,0xf0,0x10,0x10,0xf0,0x10,0x00,
+/* 12217 0x2fb9 "⾹" */
+0x00,0x00,0x3f,0x01,0x7f,0x05,0x09,0x31,0xc8,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x00,
+0x20,0x70,0x80,0x04,0xfe,0x40,0x20,0x18,0x16,0xf8,0x10,0xf0,0x10,0xf0,0x10,0x00,
+/* 12218 0x2fba "⾺" */
+0x10,0x1f,0x11,0x11,0x1f,0x11,0x1f,0x11,0x11,0x1f,0x00,0x09,0x24,0x24,0x40,0x00,
+0x08,0xfc,0x00,0x10,0xf8,0x00,0xf8,0x00,0x04,0xfe,0x24,0x14,0x94,0x84,0x38,0x00,
+/* 12219 0x2fbb "⾻" */
+0x08,0x0f,0x08,0x09,0x29,0x3f,0x20,0x4f,0x08,0x0f,0x08,0x0f,0x08,0x08,0x08,0x00,
+0x10,0xf8,0x10,0xf0,0x12,0xfe,0x04,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x70,0x20,0x00,
+/* 12220 0x2fbc "⾼" */
+0x01,0x00,0x7f,0x00,0x0f,0x08,0x0f,0x20,0x3f,0x20,0x27,0x24,0x27,0x24,0x20,0x00,
+0x00,0x84,0xfe,0x00,0xf0,0x10,0xf0,0x04,0xfe,0x04,0xe4,0x24,0xe4,0x3c,0x08,0x00,
+/* 12221 0x2fbd "⾽" */
+0x22,0x3f,0x20,0x20,0x3f,0x20,0x3f,0x20,0x7f,0x10,0x10,0x22,0xff,0x41,0x01,0x00,
+0x00,0x0c,0x08,0x10,0x26,0x44,0x88,0x10,0x26,0x44,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 12222 0x2fbe "⾾" */
+0x80,0xbe,0x88,0xbe,0x88,0xbe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+0x02,0xfa,0x22,0xfa,0x22,0xfa,0x02,0x02,0x02,0x02,0x02,0x02,0x12,0x0e,0x04,0x00,
+/* 12223 0x2fbf "⾿" */
+0x02,0x29,0x24,0x32,0x29,0x22,0x24,0x3f,0x20,0x10,0x10,0x17,0x18,0x10,0x0f,0x00,
+0x10,0x24,0x44,0xa4,0x94,0x44,0xa4,0xfc,0x04,0x30,0xc0,0x00,0x04,0x04,0xfc,0x00,
+/* 12224 0x2fc0 "⿀" */
+0x00,0x7f,0x00,0x0f,0x08,0x0f,0x00,0x3f,0x20,0x24,0x22,0x2f,0x21,0x21,0x21,0x00,
+0x04,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x44,0x84,0xf4,0x04,0x1c,0x08,0x00,
+/* 12225 0x2fc1 "⿁" */
+0x01,0x12,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x10,0x01,0x02,0x04,0x18,0x60,0x00,
+0x00,0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x88,0x90,0xa8,0xfe,0x82,0x7e,0x00,
+/* 12226 0x2fc2 "⿂" */
+0x04,0x07,0x04,0x08,0x1f,0x28,0x48,0x0f,0x08,0x08,0x0f,0x08,0x24,0x22,0x42,0x00,
+0x20,0xf0,0x20,0x40,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x08,0x44,0x22,0x22,0x00,
+/* 12227 0x2fc3 "⿃" */
+0x01,0x0a,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x0f,0x29,0x24,0x44,0x00,0x00,
+0x00,0x10,0xf8,0x10,0xf0,0x10,0xf0,0x08,0xfc,0x00,0xfc,0x24,0x94,0x94,0x18,0x00,
+/* 12228 0x2fc4 "⿄" */
+0x01,0x01,0x01,0x01,0x3f,0x22,0x29,0x24,0x32,0x29,0x22,0x25,0x28,0x3f,0x20,0x00,
+0x00,0x04,0xfe,0x00,0xfc,0x14,0x24,0x44,0xa4,0x94,0x44,0x24,0x94,0xfc,0x04,0x00,
+/* 12229 0x2fc5 "⿅" */
+0x01,0x20,0x3f,0x22,0x22,0x3f,0x22,0x3f,0x28,0x28,0x2f,0x28,0x29,0x5e,0x88,0x00,
+0x00,0x84,0xfe,0x20,0x24,0xfe,0x24,0xfc,0x04,0x20,0xa4,0x38,0xa2,0x22,0x3e,0x00,
+/* 12230 0x2fc6 "⿆" */
+0x00,0x00,0x7f,0x08,0x08,0x14,0x23,0x04,0x19,0x63,0x04,0x0b,0x30,0x01,0x1e,0x00,
+0x80,0x84,0xfe,0x88,0x88,0x94,0xe2,0x90,0x08,0xf6,0x20,0x40,0xc0,0x20,0x10,0x00,
+/* 12231 0x2fc7 "⿇" */
+0x01,0x40,0x7f,0x44,0x44,0x7f,0x44,0x55,0x55,0x55,0x55,0x55,0x64,0xa4,0x84,0x00,
+0x00,0x84,0xfe,0x10,0x10,0x7e,0x10,0x54,0x54,0x54,0x54,0x54,0x94,0x96,0x10,0x00,
+/* 12232 0x2fc8 "⿈" */
+0x04,0x7f,0x04,0x07,0x00,0x7f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x10,0x0c,0x70,0x00,
+0x24,0xfe,0x20,0xe0,0x04,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x30,0x0e,0x00,
+/* 12233 0x2fc9 "⿉" */
+0x00,0x1f,0x01,0x7f,0x01,0x07,0x19,0x62,0x0d,0x71,0x0d,0x03,0x05,0x19,0x63,0x00,
+0x70,0x80,0x08,0xfe,0x00,0xe0,0x18,0x86,0x60,0x1e,0x64,0x80,0x60,0x18,0x06,0x00,
+/* 12234 0x2fca "⿊" */
+0x10,0x1f,0x11,0x19,0x15,0x1f,0x11,0x01,0x3f,0x01,0x01,0x7f,0x24,0x22,0x42,0x00,
+0x08,0xfc,0x08,0x28,0x48,0xf8,0x08,0x00,0xf8,0x00,0x00,0xfe,0x44,0x22,0x22,0x00,
+/* 12235 0x2fcb "⿋" */
+0x12,0x12,0x0a,0x0a,0x7f,0x10,0x20,0x5f,0x10,0x11,0x12,0x14,0x18,0x10,0x10,0x00,
+0x48,0x48,0x50,0x50,0xfe,0x88,0x84,0xfe,0x84,0x84,0xc4,0xa4,0x94,0x9c,0x88,0x00,
+/* 12236 0x2fcc "⿌" */
+0x3f,0x22,0x22,0x3e,0x22,0x02,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x02,0x02,0x01,0x00,
+0xfc,0x44,0x44,0x7c,0x44,0x40,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x42,0x42,0xfe,0x00,
+/* 12237 0x2fcd "⿍" */
+0x07,0x04,0x27,0x24,0x27,0x24,0x27,0x24,0x3e,0x02,0x7e,0x12,0x12,0x22,0x42,0x00,
+0xe0,0x20,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x7c,0x40,0x7e,0x48,0x48,0x48,0x48,0x00,
+/* 12238 0x2fce "⿎" */
+0x08,0x08,0xff,0x08,0x7e,0x00,0x7f,0x42,0x42,0x7e,0x42,0x24,0x1e,0x70,0x21,0x00,
+0x20,0x20,0x24,0xfe,0x20,0x24,0xfe,0x44,0x44,0x48,0x28,0x10,0x30,0x4e,0x84,0x00,
+/* 12239 0x2fcf "⿏" */
+0x06,0x38,0x20,0x3e,0x20,0x3f,0x20,0x09,0x25,0x21,0x29,0x25,0x21,0x29,0x73,0x00,
+0x08,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x40,0x28,0x08,0x48,0x2a,0x0a,0x46,0x82,0x00,
+/* 12240 0x2fd0 "⿐" */
+0x01,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x1f,0x11,0x1f,0x11,0x7f,0x04,0x04,0x38,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf8,0x08,0xf8,0x08,0xfe,0x20,0x20,0x20,0x00,
+/* 12241 0x2fd1 "⿑" */
+0x02,0x01,0x7f,0x02,0x3e,0x15,0x15,0x25,0x59,0x08,0x0f,0x08,0x0f,0x10,0x60,0x00,
+0x00,0x04,0xfe,0x48,0xb0,0x28,0x28,0x34,0x22,0x10,0xf0,0x10,0xf0,0x10,0x10,0x00,
+/* 12242 0x2fd2 "⿒" */
+0x00,0x08,0x08,0x08,0xff,0x04,0x44,0x4a,0x51,0x7f,0x44,0x4a,0x51,0x7f,0x40,0x00,
+0x80,0x90,0xf8,0x80,0xfe,0x40,0x44,0xa4,0x14,0xfc,0x44,0xa4,0x14,0xfc,0x04,0x00,
+/* 12243 0x2fd3 "⿓" */
+0x10,0x08,0x7f,0x22,0x14,0x7f,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2e,0x24,0x00,
+0x40,0x44,0x7e,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x40,0x7e,0x42,0x3e,0x00,
+/* 12244 0x2fd4 "⿔" */
+0x08,0x0f,0x08,0x10,0x7f,0x11,0x7f,0x05,0x7f,0x05,0x7d,0x05,0x7f,0x05,0x7c,0x00,
+0x40,0xe0,0x40,0x80,0xfc,0x44,0x7c,0x44,0x6c,0x54,0x6c,0x44,0x7e,0x02,0xfc,0x00,
+/* 12245 0x2fd5 "⿕" */
+0x01,0x06,0x18,0x63,0x00,0x7b,0x4a,0x7b,0x00,0x3f,0x22,0x3f,0x22,0x22,0x22,0x00,
+0x80,0x60,0x18,0xc6,0x00,0xde,0x52,0xde,0x00,0xfc,0x44,0xfc,0x44,0x5c,0x48,0x00,
+/* 12246 0x2fd6 "⿖" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 12247 0x2fd7 "⿗" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 12248 0x2fd8 "⿘" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 12249 0x2fd9 "⿙" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 12250 0x2fda "⿚" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 12251 0x2fdb "⿛" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 12252 0x2fdc "⿜" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 12253 0x2fdd "⿝" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 12254 0x2fde "⿞" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 12255 0x2fdf "⿟" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 12256 0x2fe0 "⿠" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 12257 0x2fe1 "⿡" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 12258 0x2fe2 "⿢" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 12259 0x2fe3 "⿣" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 12260 0x2fe4 "⿤" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 12261 0x2fe5 "⿥" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 12262 0x2fe6 "⿦" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 12263 0x2fe7 "⿧" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 12264 0x2fe8 "⿨" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 12265 0x2fe9 "⿩" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 12266 0x2fea "⿪" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 12267 0x2feb "⿫" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 12268 0x2fec "⿬" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 12269 0x2fed "⿭" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 12270 0x2fee "⿮" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 12271 0x2fef "⿯" */
+0x00,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 12272 0x2ff0 "⿰" */
+0xdb,0x00,0x81,0x80,0x01,0x80,0x81,0x00,0x81,0x80,0x81,0x00,0x81,0x80,0x01,0xdb,
+0xb6,0x00,0x02,0x02,0x00,0x02,0x02,0x00,0x02,0x02,0x02,0x00,0x02,0x02,0x00,0xb6,
+/* 12273 0x2ff1 "⿱" */
+0xdb,0x00,0x80,0x80,0x00,0x80,0x80,0x2a,0x80,0x80,0x80,0x00,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0x00,0x02,0x02,0xa8,0x02,0x02,0x02,0x00,0x02,0x02,0x00,0xb6,
+/* 12274 0x2ff2 "⿲" */
+0xdb,0x00,0x84,0x80,0x04,0x80,0x84,0x00,0x84,0x80,0x84,0x00,0x84,0x80,0x04,0xdb,
+0xb6,0x00,0x42,0x02,0x40,0x02,0x42,0x00,0x42,0x02,0x42,0x00,0x42,0x02,0x40,0xb6,
+/* 12275 0x2ff3 "⿳" */
+0xdb,0x00,0x80,0x80,0x00,0x80,0xaa,0x00,0x80,0x80,0xaa,0x00,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0x00,0x02,0xaa,0x00,0x02,0x02,0xaa,0x00,0x02,0x02,0x00,0xb6,
+/* 12276 0x2ff4 "⿴" */
+0xdb,0x00,0x80,0x95,0x00,0x90,0x80,0x10,0x80,0x90,0x80,0x10,0x95,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x52,0x10,0x02,0x12,0x00,0x12,0x02,0x12,0x00,0x52,0x02,0x00,0xb6,
+/* 12277 0x2ff5 "⿵" */
+0xdb,0x00,0x80,0x80,0x0a,0x88,0x80,0x08,0x80,0x88,0x80,0x08,0x80,0x88,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0xa0,0x22,0x02,0x20,0x02,0x22,0x02,0x20,0x02,0x22,0x00,0xb6,
+/* 12278 0x2ff6 "⿶" */
+0xdb,0x00,0x88,0x80,0x08,0x80,0x88,0x00,0x88,0x80,0x88,0x0a,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x22,0x02,0x20,0x02,0x22,0x00,0x22,0x02,0x22,0xa0,0x02,0x02,0x00,0xb6,
+/* 12279 0x2ff7 "⿷" */
+0xdb,0x00,0x80,0x80,0x0a,0x88,0x80,0x08,0x80,0x88,0x80,0x0a,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0xa8,0x02,0x02,0x00,0x02,0x02,0x02,0xa8,0x02,0x02,0x00,0xb6,
+/* 12280 0x2ff8 "⿸" */
+0xdb,0x00,0x80,0x80,0x0a,0x80,0x88,0x00,0x88,0x80,0x88,0x00,0x88,0x80,0x08,0xdb,
+0xb6,0x00,0x02,0x02,0xa8,0x02,0x02,0x00,0x02,0x02,0x02,0x00,0x02,0x02,0x00,0xb6,
+/* 12281 0x2ff9 "⿹" */
+0xdb,0x00,0x80,0x80,0x2a,0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0xa0,0x02,0x22,0x00,0x22,0x02,0x22,0x00,0x22,0x02,0x20,0xb6,
+/* 12282 0x2ffa "⿺" */
+0xdb,0x08,0x80,0x88,0x00,0x88,0x80,0x08,0x80,0x88,0x80,0x0a,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0x00,0x02,0x02,0x00,0x02,0x02,0x02,0xa8,0x02,0x02,0x00,0xb6,
+/* 12283 0x2ffb "⿻" */
+0x00,0xdb,0x80,0x00,0x9b,0x90,0x00,0x90,0x90,0x00,0x90,0xdb,0x00,0x10,0x1b,0x00,
+0x00,0x60,0x20,0x00,0x6c,0x24,0x00,0x24,0x24,0x00,0x24,0x64,0x00,0x04,0x6c,0x00,
+/* 12284 0x2ffc "⿼" */
+0xdb,0x00,0x80,0x80,0x2a,0x80,0x80,0x00,0x80,0x80,0x80,0x2a,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0xa0,0x22,0x02,0x20,0x02,0x22,0x02,0xa0,0x02,0x02,0x00,0xb6,
+/* 12285 0x2ffd "⿽" */
+0xdb,0x00,0x80,0x80,0x00,0x80,0x80,0x00,0x80,0x80,0x80,0x2a,0x80,0x80,0x00,0xdb,
+0xb6,0x20,0x02,0x22,0x00,0x22,0x02,0x20,0x02,0x22,0x02,0xa0,0x02,0x02,0x00,0xb6,
+/* 12286 0x2ffe "⿾" */
+0xdb,0x00,0x80,0x80,0x00,0x88,0x90,0x2a,0x90,0x88,0x80,0x00,0x80,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x02,0x00,0x22,0x12,0xa8,0x12,0x22,0x02,0x00,0x02,0x02,0x00,0xb6,
+/* 12287 0x2fff "⿿" */
+0xdb,0x14,0x81,0x80,0x00,0x80,0x80,0x00,0x80,0x80,0x88,0x10,0xaa,0x90,0x08,0xdb,
+0xb6,0x00,0x02,0x42,0x00,0x22,0x02,0x20,0x02,0x22,0x02,0x80,0x02,0x02,0x00,0xb6,
+/* 12288 0x3000 "　" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12289 0x3001 "、" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x0c,0x06,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12290 0x3002 "。" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12291 0x3003 "〃" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x04,0x04,0x09,0x09,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12292 0x3004 "〄" */
+0x00,0x06,0x18,0x20,0x41,0x41,0x81,0x8d,0x93,0x49,0x44,0x24,0x18,0x01,0x00,0x00,
+0x00,0x00,0x20,0x30,0x28,0xa8,0x44,0x04,0x04,0x08,0x08,0x10,0x60,0x80,0x00,0x00,
+/* 12293 0x3005 "々" */
+0x00,0x00,0x02,0x01,0x01,0x02,0x03,0x04,0x08,0x12,0x21,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0xc8,0x10,0x20,0x40,0x80,0x80,0x40,0x00,0x00,0x00,
+/* 12294 0x3006 "〆" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x09,0x12,0x14,0x18,0x30,0x20,0x00,0x00,
+0x00,0x00,0x10,0x08,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 12295 0x3007 "〇" */
+0x00,0x07,0x18,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x18,0x07,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 12296 0x3008 "〈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x00,
+/* 12297 0x3009 "〉" */
+0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x01,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12298 0x300a "《" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x48,0x48,0x90,0x90,0x20,0x20,0x40,0x80,0x40,0x20,0x20,0x90,0x90,0x48,0x48,0x00,
+/* 12299 0x300b "》" */
+0x12,0x12,0x09,0x09,0x04,0x04,0x02,0x01,0x02,0x04,0x04,0x09,0x09,0x12,0x12,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12300 0x300c "「" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12301 0x300d "」" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12302 0x300e "『" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x08,0x78,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 12303 0x300f "』" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x1e,0x10,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 12304 0x3010 "【" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0xf0,0xe0,0xe0,0xe0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xe0,0xe0,0xf0,0xf8,0x00,
+/* 12305 0x3011 "】" */
+0x1f,0x0f,0x07,0x07,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x07,0x07,0x0f,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12306 0x3012 "〒" */
+0x00,0x7f,0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0xfe,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12307 0x3013 "〓" */
+0x3f,0x3f,0x3f,0x3f,0x3f,0x00,0x00,0x00,0x3f,0x3f,0x3f,0x3f,0x3f,0x00,0x00,0x00,
+0xfe,0xfe,0xfe,0xfe,0xfe,0x00,0x00,0x00,0xfe,0xfe,0xfe,0xfe,0xfe,0x00,0x00,0x00,
+/* 12308 0x3014 "〔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x10,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x10,0x08,0x00,
+/* 12309 0x3015 "〕" */
+0x10,0x08,0x04,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12310 0x3016 "〖" */
+0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x03,0x00,
+0xf8,0x10,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x10,0xf8,0x00,
+/* 12311 0x3017 "〗" */
+0x1f,0x08,0x04,0x02,0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x1f,0x00,
+0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,
+/* 12312 0x3018 "〘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x30,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x30,0x08,0x00,
+/* 12313 0x3019 "〙" */
+0x10,0x0c,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0c,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12314 0x301a "〚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf8,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xa0,0xf8,0x00,
+/* 12315 0x301b "〛" */
+0x1f,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12316 0x301c "〜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12317 0x301d "〝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x90,0x48,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12318 0x301e "〞" */
+0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12319 0x301f "〟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x12,0x24,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12320 0x3020 "〠" */
+0x00,0x3f,0x3f,0x00,0x3f,0x3f,0x55,0xd9,0xa5,0xa5,0x59,0x41,0x24,0x13,0x08,0x07,
+0x00,0xfc,0xfc,0x00,0xfc,0xfc,0x96,0xb9,0xa5,0xa5,0x9a,0x82,0x24,0xc8,0x10,0xe0,
+/* 12321 0x3021 "〡" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12322 0x3022 "〢" */
+0x00,0x00,0x0c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x60,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 12323 0x3023 "〣" */
+0x00,0x20,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x20,0x20,0x00,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 12324 0x3024 "〤" */
+0x00,0x00,0x10,0x08,0x04,0x02,0x01,0x00,0x01,0x02,0x04,0x08,0x30,0x00,0x00,0x00,
+0x10,0x10,0x20,0x20,0x40,0x40,0x80,0xc0,0x20,0x10,0x08,0x08,0x00,0x00,0x00,0x00,
+/* 12325 0x3025 "〥" */
+0x00,0x04,0x04,0x08,0x1c,0x03,0x04,0x08,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,
+0x00,0x20,0x30,0x20,0xc0,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,
+/* 12326 0x3026 "〦" */
+0x00,0x01,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x84,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12327 0x3027 "〧" */
+0x00,0x01,0x01,0x01,0x01,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12328 0x3028 "〨" */
+0x01,0x01,0x01,0x7f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 12329 0x3029 "〩" */
+0x08,0x08,0x08,0x0f,0x10,0x28,0x04,0x02,0x01,0x00,0x00,0x01,0x02,0x0c,0x30,0x00,
+0x00,0x00,0x00,0xfc,0x10,0x10,0x20,0x20,0x40,0x80,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 12330 0x302a "〪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12331 0x302b "〫" */
+0x00,0x60,0x90,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12332 0x302c "〬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12333 0x302d "〭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,
+/* 12334 0x302e "〮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12335 0x302f "〯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0xc0,0x00,0xc0,0xc0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12336 0x3030 "〰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x61,0x92,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x86,0x49,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12337 0x3031 "〱" */
+0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x10,0x08,0x04,0x02,0x01,0x01,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,
+/* 12338 0x3032 "〲" */
+0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x10,0x08,0x04,0x02,0x01,0x01,0x00,0x00,
+0x00,0x80,0x10,0x08,0x48,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,
+/* 12339 0x3033 "〳" */
+0x04,0x06,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12340 0x3034 "〴" */
+0x04,0x06,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x80,
+0x00,0x00,0x40,0x20,0x80,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12341 0x3035 "〵" */
+0x80,0x80,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12342 0x3036 "〶" */
+0x07,0x18,0x20,0x5f,0x5f,0x80,0x9f,0x9f,0x81,0x81,0x81,0x41,0x41,0x21,0x18,0x07,
+0xc0,0x30,0x08,0xf4,0xf4,0x02,0xf2,0xf2,0x02,0x02,0x02,0x04,0x04,0x08,0x30,0xc0,
+/* 12343 0x3037 "〷" */
+0x82,0x82,0x82,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x82,0x82,
+0x82,0x82,0x82,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x82,0x82,
+/* 12344 0x3038 "〸" */
+0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12345 0x3039 "〹" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+/* 12346 0x303a "〺" */
+0x10,0x10,0x10,0x10,0x10,0xff,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0x00,
+0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x00,
+/* 12347 0x303b "〻" */
+0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 12348 0x303c "〼" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x21,0x22,0x24,0x28,0x30,0x3f,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,
+/* 12349 0x303d "〽" */
+0x00,0x00,0x10,0x28,0x44,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x08,0x04,0x00,
+/* 12350 0x303e "〾" */
+0xdb,0x80,0x0e,0x91,0x80,0x00,0x80,0x80,0x1f,0x80,0x81,0x1f,0x84,0x88,0x00,0xdb,
+0x6d,0x01,0x00,0x89,0x71,0x00,0x11,0x21,0xf8,0x81,0x01,0xf8,0x01,0x00,0x01,0x6d,
+/* 12351 0x303f "〿" */
+0x00,0xfe,0x82,0xc6,0xc6,0xaa,0xaa,0x92,0xaa,0xaa,0xc6,0xc6,0x82,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12352 0x3040 "぀" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 12353 0x3041 "ぁ" */
+0x00,0x00,0x00,0x00,0x04,0x02,0x13,0x0e,0x04,0x07,0x0d,0x16,0x26,0x2a,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0xe0,0x10,0x10,0x10,0x20,0xc0,0x00,
+/* 12354 0x3042 "あ" */
+0x00,0x04,0x02,0x02,0x1f,0x04,0x04,0x07,0x0d,0x15,0x22,0x26,0x2a,0x10,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x80,0x80,0xe0,0x10,0x08,0x08,0x08,0x10,0x60,0x00,0x00,
+/* 12355 0x3043 "ぃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x0a,0x0c,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 12356 0x3044 "い" */
+0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x20,0x22,0x24,0x14,0x18,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x08,0x08,0x18,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 12357 0x3045 "ぅ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x13,0x0c,0x00,0x00,0x00,0x00,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 12358 0x3046 "う" */
+0x00,0x02,0x01,0x00,0x00,0x03,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0xc0,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 12359 0x3047 "ぇ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x01,0x0e,0x01,0x02,0x07,0x09,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0xc0,0x80,0x00,0x00,0x00,0x00,0xf0,0x00,
+/* 12360 0x3048 "え" */
+0x00,0x04,0x03,0x00,0x00,0x11,0x0e,0x01,0x02,0x04,0x0e,0x11,0x21,0x20,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 12361 0x3049 "ぉ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x0c,0x38,0x0b,0x0c,0x18,0x28,0x18,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x30,0x20,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 12362 0x304a "お" */
+0x00,0x00,0x08,0x04,0x05,0x06,0x1c,0x04,0x05,0x06,0x0c,0x34,0x0c,0x04,0x00,0x00,
+0x00,0x00,0x00,0x30,0x08,0x0c,0x00,0x60,0x90,0x08,0x08,0x88,0x70,0x00,0x00,0x00,
+/* 12363 0x304b "か" */
+0x00,0x00,0x08,0x04,0x04,0x47,0x3c,0x08,0x08,0x08,0x10,0x11,0x25,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x10,0x88,0x98,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12364 0x304c "が" */
+0x00,0x00,0x08,0x04,0x04,0x47,0x3c,0x08,0x08,0x08,0x10,0x11,0x25,0x22,0x00,0x00,
+0x00,0x08,0x24,0x10,0x40,0x20,0x90,0x88,0x98,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12365 0x304d "き" */
+0x00,0x02,0x01,0x01,0x0f,0x00,0x00,0x1f,0x00,0x00,0x07,0x08,0x08,0x06,0x01,0x00,
+0x00,0x00,0x00,0x60,0x80,0x80,0xf0,0x40,0x20,0x20,0xf0,0x10,0x00,0x00,0xc0,0x00,
+/* 12366 0x304e "ぎ" */
+0x00,0x04,0x02,0x02,0x1f,0x01,0x01,0x3e,0x00,0x00,0x0f,0x10,0x10,0x0c,0x03,0x00,
+0x00,0x08,0x24,0xd0,0x00,0x00,0xe0,0x80,0x40,0x40,0xe0,0x20,0x00,0x00,0x80,0x00,
+/* 12367 0x304f "く" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x00,
+/* 12368 0x3050 "ぐ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x08,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x88,0x24,0x10,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x00,
+/* 12369 0x3051 "け" */
+0x00,0x00,0x20,0x10,0x10,0x10,0x23,0x20,0x20,0x20,0x20,0x18,0x10,0x10,0x00,0x00,
+0x00,0x80,0x40,0x20,0x20,0x3c,0xe0,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,
+/* 12370 0x3052 "げ" */
+0x00,0x01,0x40,0x20,0x20,0x20,0x47,0x40,0x40,0x40,0x40,0x30,0x20,0x20,0x01,0x00,
+0x00,0x08,0xa4,0x50,0x40,0x78,0xc0,0x40,0x40,0x40,0x40,0x40,0x80,0x80,0x00,0x00,
+/* 12371 0x3053 "こ" */
+0x00,0x00,0x08,0x07,0x00,0x01,0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 12372 0x3054 "ご" */
+0x00,0x00,0x08,0x07,0x00,0x01,0x00,0x00,0x00,0x00,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x08,0x04,0xf0,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 12373 0x3055 "さ" */
+0x00,0x04,0x02,0x01,0x21,0x1e,0x00,0x00,0x07,0x08,0x10,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x30,0xc0,0x80,0x40,0x40,0xe0,0x20,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 12374 0x3056 "ざ" */
+0x00,0x04,0x02,0x01,0x21,0x1e,0x00,0x00,0x07,0x08,0x10,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x08,0x04,0x30,0xc8,0x80,0x40,0x40,0xe0,0x20,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 12375 0x3057 "し" */
+0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x60,0x80,0x00,0x00,
+/* 12376 0x3058 "じ" */
+0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x20,0x90,0x40,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x60,0x80,0x00,0x00,
+/* 12377 0x3059 "す" */
+0x00,0x01,0x00,0x40,0x3f,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x80,0xf8,0x80,0x80,0x80,0xc0,0x40,0xc0,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 12378 0x305a "ず" */
+0x00,0x01,0x00,0x40,0x3f,0x00,0x03,0x04,0x04,0x03,0x00,0x00,0x00,0x01,0x02,0x00,
+0x00,0x28,0x94,0xf8,0x80,0x80,0x80,0xc0,0x40,0xc0,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 12379 0x305b "せ" */
+0x00,0x00,0x00,0x10,0x08,0x08,0x4b,0x3c,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x78,0xc0,0x40,0x40,0x40,0xc0,0x40,0x00,0xe0,0x00,0x00,
+/* 12380 0x305c "ぜ" */
+0x00,0x00,0x00,0x10,0x08,0x08,0x4b,0x3c,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x08,0x84,0x50,0x48,0x78,0xc0,0x40,0x40,0x40,0xc0,0x40,0x00,0xe0,0x00,0x00,
+/* 12381 0x305d "そ" */
+0x00,0x00,0x09,0x06,0x00,0x01,0x02,0x07,0x38,0x01,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0xc0,0x40,0x80,0x00,0x38,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,
+/* 12382 0x305e "ぞ" */
+0x00,0x00,0x09,0x06,0x00,0x01,0x02,0x07,0x38,0x01,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0xc8,0x64,0x90,0x00,0x38,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,
+/* 12383 0x305f "た" */
+0x00,0x00,0x08,0x04,0x07,0x3c,0x08,0x08,0x08,0x10,0x10,0x11,0x21,0x20,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0xf0,0x18,0x20,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 12384 0x3060 "だ" */
+0x00,0x00,0x08,0x04,0x07,0x3c,0x08,0x08,0x08,0x10,0x10,0x11,0x21,0x20,0x00,0x00,
+0x00,0x08,0x24,0x90,0x00,0x00,0xf0,0x18,0x20,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 12385 0x3061 "ち" */
+0x00,0x08,0x04,0x04,0x47,0x3c,0x08,0x08,0x0b,0x1c,0x10,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12386 0x3062 "ぢ" */
+0x00,0x08,0x04,0x04,0x47,0x3c,0x08,0x08,0x0b,0x1c,0x10,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x08,0xc4,0x10,0x08,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12387 0x3063 "っ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12388 0x3064 "つ" */
+0x00,0x00,0x00,0x00,0x03,0x4c,0x30,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x60,0x80,0x00,0x00,0x00,
+/* 12389 0x3065 "づ" */
+0x00,0x00,0x00,0x00,0x03,0x4c,0x30,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
+0x00,0x08,0x24,0x10,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x60,0x80,0x00,0x00,0x00,
+/* 12390 0x3066 "て" */
+0x00,0x00,0x00,0x43,0x3c,0x01,0x01,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x38,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 12391 0x3067 "で" */
+0x00,0x00,0x00,0x43,0x3c,0x01,0x01,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x38,0xc0,0x88,0x24,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 12392 0x3068 "と" */
+0x00,0x00,0x04,0x02,0x02,0x02,0x02,0x03,0x06,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12393 0x3069 "ど" */
+0x00,0x00,0x04,0x02,0x02,0x02,0x02,0x03,0x06,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x08,0x24,0x10,0x00,0x70,0x80,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12394 0x306a "な" */
+0x00,0x04,0x02,0x02,0x3f,0x04,0x08,0x08,0x10,0x10,0x20,0x03,0x04,0x04,0x03,0x00,
+0x00,0x00,0x00,0x80,0x00,0x70,0x18,0x20,0x40,0x40,0x40,0xc0,0x60,0x50,0x80,0x00,
+/* 12395 0x306b "に" */
+0x00,0x00,0x20,0x10,0x10,0x13,0x20,0x20,0x20,0x20,0x22,0x2a,0x11,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x18,0x20,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 12396 0x306c "ぬ" */
+0x00,0x00,0x01,0x00,0x00,0x13,0x15,0x19,0x12,0x2a,0x4c,0x4c,0x54,0x20,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0xe0,0x10,0x08,0x08,0x08,0x08,0x68,0x90,0x68,0x00,0x00,
+/* 12397 0x306d "ね" */
+0x00,0x10,0x08,0x08,0x08,0x4c,0x3f,0x0c,0x08,0x18,0x18,0x28,0x59,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0xf0,0x18,0xe0,0x00,0x00,
+/* 12398 0x306e "の" */
+0x00,0x00,0x00,0x03,0x0d,0x11,0x11,0x22,0x22,0x24,0x24,0x28,0x10,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0x00,
+/* 12399 0x306f "は" */
+0x00,0x00,0x20,0x10,0x14,0x13,0x20,0x20,0x20,0x20,0x29,0x12,0x12,0x11,0x00,0x00,
+0x00,0x40,0x20,0x20,0x38,0xe0,0x20,0x20,0x20,0x20,0xe0,0x30,0x28,0xc0,0x00,0x00,
+/* 12400 0x3070 "ば" */
+0x00,0x00,0x40,0x20,0x28,0x27,0x40,0x40,0x40,0x40,0x53,0x24,0x24,0x23,0x00,0x00,
+0x00,0x88,0x44,0x50,0x78,0xc0,0x40,0x40,0x40,0x40,0xc0,0x60,0x50,0x80,0x00,0x00,
+/* 12401 0x3071 "ぱ" */
+0x00,0x00,0x40,0x20,0x28,0x27,0x40,0x40,0x40,0x40,0x53,0x24,0x24,0x23,0x00,0x00,
+0x00,0x98,0x64,0x64,0x78,0xc0,0x40,0x40,0x40,0x40,0xc0,0x60,0x50,0x80,0x00,0x00,
+/* 12402 0x3072 "ひ" */
+0x00,0x00,0x00,0x04,0x3c,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x40,0x40,0x20,0x20,0x30,0x28,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12403 0x3073 "び" */
+0x00,0x00,0x00,0x04,0x3c,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x08,0x44,0x50,0x28,0x20,0x30,0x28,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12404 0x3074 "ぴ" */
+0x00,0x00,0x00,0x04,0x3c,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x30,0x48,0x48,0x30,0x20,0x30,0x28,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12405 0x3075 "ふ" */
+0x00,0x00,0x04,0x03,0x00,0x01,0x02,0x02,0x01,0x02,0x4c,0x38,0x24,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0xb0,0x88,0x9c,0x80,0x00,0x00,0x00,
+/* 12406 0x3076 "ぶ" */
+0x00,0x00,0x04,0x03,0x00,0x01,0x02,0x02,0x01,0x02,0x4c,0x38,0x24,0x03,0x00,0x00,
+0x00,0x00,0x00,0x88,0xa4,0x10,0x00,0x00,0x00,0xb0,0x88,0x9c,0x80,0x00,0x00,0x00,
+/* 12407 0x3077 "ぷ" */
+0x00,0x00,0x04,0x03,0x00,0x01,0x02,0x02,0x01,0x02,0x4c,0x38,0x24,0x03,0x00,0x00,
+0x00,0x00,0x00,0x98,0xa4,0x24,0x18,0x00,0x00,0xb0,0x88,0x9c,0x80,0x00,0x00,0x00,
+/* 12408 0x3078 "へ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 12409 0x3079 "べ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x48,0x20,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 12410 0x307a "ぺ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 12411 0x307b "ほ" */
+0x00,0x00,0x22,0x11,0x10,0x10,0x23,0x20,0x20,0x20,0x29,0x12,0x12,0x11,0x00,0x00,
+0x00,0x00,0x30,0xc0,0x40,0x38,0xe0,0x20,0x20,0x20,0xe0,0x30,0x28,0xc0,0x00,0x00,
+/* 12412 0x307c "ぼ" */
+0x00,0x00,0x44,0x23,0x20,0x20,0x47,0x40,0x40,0x40,0x53,0x24,0x24,0x23,0x00,0x00,
+0x00,0x00,0x68,0x84,0x90,0x78,0xc0,0x40,0x40,0x40,0xc0,0x60,0x50,0x80,0x00,0x00,
+/* 12413 0x307d "ぽ" */
+0x00,0x00,0x44,0x23,0x20,0x20,0x47,0x40,0x40,0x40,0x53,0x24,0x24,0x23,0x00,0x00,
+0x00,0x18,0x64,0xa4,0x98,0x70,0xc0,0x40,0x40,0x40,0xc0,0x60,0x50,0x80,0x00,0x00,
+/* 12414 0x307e "ま" */
+0x00,0x01,0x00,0x10,0x0f,0x00,0x10,0x0f,0x00,0x00,0x0f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x80,0xf0,0x80,0x80,0xe0,0x80,0x80,0x80,0x80,0xe0,0x90,0x00,0x00,0x00,
+/* 12415 0x307f "み" */
+0x00,0x00,0x08,0x07,0x01,0x01,0x02,0x02,0x0f,0x34,0x44,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0x20,0x10,0xf0,0x18,0x24,0x20,0x40,0x80,0x00,0x00,
+/* 12416 0x3080 "む" */
+0x00,0x08,0x04,0x27,0x1c,0x04,0x1c,0x24,0x24,0x2c,0x18,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x08,0x0c,0x00,0x00,0x20,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 12417 0x3081 "め" */
+0x00,0x00,0x01,0x00,0x10,0x13,0x1c,0x11,0x29,0x2a,0x46,0x44,0x4a,0x30,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0xc0,0xa0,0x10,0x08,0x08,0x08,0x08,0x10,0x60,0x00,0x00,
+/* 12418 0x3082 "も" */
+0x00,0x02,0x01,0x11,0x0e,0x03,0x12,0x24,0x1c,0x07,0x04,0x04,0x04,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x20,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,
+/* 12419 0x3083 "ゃ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x08,0x09,0x0e,0x3c,0x04,0x02,0x02,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xe0,0x10,0x10,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 12420 0x3084 "や" */
+0x00,0x01,0x00,0x01,0x18,0x10,0x0b,0x4c,0x34,0x02,0x02,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x00,0xf0,0x08,0x08,0x08,0x70,0x00,0x00,0x00,0x80,0x80,0x00,
+/* 12421 0x3085 "ゅ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x21,0x27,0x29,0x31,0x23,0x21,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 12422 0x3086 "ゆ" */
+0x00,0x00,0x03,0x40,0x21,0x22,0x24,0x28,0x30,0x34,0x22,0x21,0x00,0x01,0x02,0x00,
+0x00,0x00,0x00,0x80,0xe0,0x90,0x88,0x88,0x88,0x88,0x90,0xe0,0x80,0x00,0x00,0x00,
+/* 12423 0x3087 "ょ" */
+0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x11,0x11,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,
+/* 12424 0x3088 "よ" */
+0x00,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x1f,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xc0,0x00,0x00,0x00,0x00,0x80,0x60,0x10,0x00,0x00,0x00,
+/* 12425 0x3089 "ら" */
+0x00,0x02,0x01,0x01,0x06,0x08,0x08,0x08,0x09,0x0e,0x08,0x08,0x00,0x00,0x03,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12426 0x308a "り" */
+0x00,0x10,0x09,0x0a,0x0c,0x0c,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12427 0x308b "る" */
+0x00,0x00,0x08,0x07,0x00,0x01,0x02,0x07,0x0c,0x10,0x20,0x03,0x04,0x04,0x03,0x00,
+0x00,0x00,0xc0,0x40,0x80,0x00,0x00,0xc0,0x20,0x10,0x10,0x90,0x60,0x40,0x80,0x00,
+/* 12428 0x308c "れ" */
+0x00,0x00,0x10,0x08,0x09,0x0a,0x1c,0x6c,0x08,0x18,0x18,0x28,0x48,0x18,0x08,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x18,0x00,0x00,
+/* 12429 0x308d "ろ" */
+0x00,0x00,0x11,0x0e,0x01,0x02,0x04,0x0f,0x08,0x10,0x20,0x00,0x00,0x00,0x07,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12430 0x308e "ゎ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x06,0x1d,0x06,0x0c,0x0c,0x14,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x20,0x40,0x00,
+/* 12431 0x308f "わ" */
+0x00,0x10,0x08,0x08,0x08,0x4c,0x3f,0x0c,0x08,0x18,0x18,0x28,0x48,0x18,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 12432 0x3090 "ゐ" */
+0x00,0x00,0x09,0x06,0x01,0x01,0x03,0x0e,0x12,0x24,0x24,0x28,0x19,0x10,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0xc8,0x30,0xe0,0x00,0x00,
+/* 12433 0x3091 "ゑ" */
+0x00,0x00,0x09,0x07,0x02,0x07,0x08,0x10,0x06,0x09,0x07,0x08,0x1c,0x23,0x40,0x00,
+0x00,0x00,0x80,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0xe0,0x10,0x38,0x00,
+/* 12434 0x3092 "を" */
+0x00,0x04,0x02,0x12,0x0f,0x04,0x04,0x0f,0x18,0x21,0x02,0x04,0x08,0x08,0x07,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x20,0x38,0xc0,0x80,0x80,0x80,0x00,0x00,0xe0,0x00,
+/* 12435 0x3093 "ん" */
+0x00,0x02,0x01,0x01,0x02,0x02,0x04,0x04,0x0f,0x08,0x10,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x88,0x90,0x60,0x00,0x00,
+/* 12436 0x3094 "ゔ" */
+0x00,0x02,0x01,0x00,0x00,0x03,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0xc8,0x04,0x10,0xc8,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 12437 0x3095 "ゕ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3f,0x04,0x08,0x10,0x11,0x25,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x88,0x98,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12438 0x3096 "ゖ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x11,0x10,0x10,0x14,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x38,0xe0,0x20,0x20,0x20,0x40,0x40,0x80,0x00,
+/* 12439 0x3097 "゗" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 12440 0x3098 "゘" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 12441 0x3099 "゙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x04,0x12,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12442 0x309a "゚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12443 0x309b "゛" */
+0x00,0x10,0x48,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12444 0x309c "゜" */
+0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12445 0x309d "ゝ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12446 0x309e "ゞ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x90,0x40,0x00,0x80,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12447 0x309f "ゟ" */
+0x00,0x00,0x06,0x01,0x08,0x08,0x08,0x08,0x0f,0x10,0x00,0x00,0x00,0x00,0x03,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12448 0x30a0 "゠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,
+/* 12449 0x30a1 "ァ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x1e,0x02,0x01,0x01,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12450 0x30a2 "ア" */
+0x00,0x00,0x00,0x21,0x1e,0x00,0x02,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12451 0x30a3 "ィ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 12452 0x30a4 "イ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0d,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 12453 0x30a5 "ゥ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x1e,0x08,0x08,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12454 0x30a6 "ウ" */
+0x00,0x00,0x02,0x01,0x01,0x01,0x3e,0x10,0x10,0x08,0x08,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12455 0x30a7 "ェ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x10,0x00,0x00,
+/* 12456 0x30a8 "エ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x02,0x01,0x01,0x01,0x01,0x03,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x00,0x00,0x00,
+/* 12457 0x30a9 "ォ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x10,0x0f,0x01,0x02,0x04,0x08,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xe0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 12458 0x30aa "オ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x1f,0x00,0x01,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x40,0x78,0xc0,0xc0,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x00,
+/* 12459 0x30ab "カ" */
+0x00,0x00,0x02,0x01,0x01,0x21,0x1f,0x02,0x02,0x04,0x04,0x08,0x11,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0xc0,0x80,0x00,
+/* 12460 0x30ac "ガ" */
+0x00,0x00,0x02,0x01,0x01,0x21,0x1f,0x02,0x02,0x04,0x04,0x08,0x11,0x20,0x00,0x00,
+0x00,0x08,0x24,0x14,0x10,0xf0,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0xc0,0x80,0x00,
+/* 12461 0x30ad "キ" */
+0x00,0x00,0x04,0x02,0x02,0x03,0x1d,0x01,0x01,0x03,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x78,0x80,0x80,0x80,0x40,0x40,0x40,0x00,
+/* 12462 0x30ae "ギ" */
+0x00,0x00,0x04,0x02,0x02,0x03,0x1d,0x01,0x01,0x03,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x24,0x14,0x70,0x80,0x00,0x00,0x78,0x80,0x80,0x80,0x40,0x40,0x40,0x00,
+/* 12463 0x30af "ク" */
+0x00,0x00,0x04,0x02,0x03,0x02,0x04,0x04,0x08,0x10,0x00,0x01,0x02,0x04,0x08,0x00,
+0x00,0x00,0x00,0x70,0x90,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12464 0x30b0 "グ" */
+0x00,0x00,0x08,0x04,0x07,0x04,0x08,0x08,0x10,0x21,0x01,0x02,0x04,0x08,0x10,0x00,
+0x00,0x08,0x24,0xd4,0x50,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12465 0x30b1 "ケ" */
+0x00,0x00,0x08,0x04,0x04,0x04,0x0f,0x09,0x10,0x20,0x00,0x01,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0xc0,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12466 0x30b2 "ゲ" */
+0x00,0x00,0x08,0x04,0x04,0x04,0x0f,0x09,0x10,0x20,0x00,0x01,0x01,0x02,0x04,0x00,
+0x00,0x08,0x24,0x14,0x10,0x38,0xc0,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12467 0x30b3 "コ" */
+0x00,0x00,0x00,0x00,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x20,0x20,0xe0,0x20,0x00,0x00,0x00,
+/* 12468 0x30b4 "ゴ" */
+0x00,0x00,0x00,0x00,0x43,0x3c,0x00,0x00,0x00,0x00,0x00,0x07,0x38,0x00,0x00,0x00,
+0x00,0x08,0x24,0x14,0xd0,0x40,0x40,0x40,0x40,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 12469 0x30b5 "サ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x24,0x1f,0x04,0x04,0x04,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x80,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 12470 0x30b6 "ザ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x24,0x1f,0x04,0x04,0x04,0x00,0x00,0x01,0x02,0x00,
+0x00,0x08,0xa4,0x54,0x50,0x40,0xf8,0x40,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 12471 0x30b7 "シ" */
+0x00,0x00,0x00,0x0c,0x02,0x00,0x18,0x04,0x00,0x00,0x00,0x00,0x13,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12472 0x30b8 "ジ" */
+0x00,0x00,0x00,0x0c,0x02,0x00,0x18,0x04,0x00,0x00,0x00,0x00,0x13,0x0c,0x00,0x00,
+0x00,0x00,0x08,0x24,0x14,0x10,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12473 0x30b9 "ス" */
+0x00,0x00,0x00,0x10,0x0f,0x00,0x00,0x00,0x00,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x40,0x40,0x80,0x80,0x40,0x20,0x10,0x10,0x00,0x00,0x00,
+/* 12474 0x30ba "ズ" */
+0x00,0x00,0x00,0x21,0x1e,0x00,0x00,0x01,0x01,0x02,0x04,0x18,0x60,0x00,0x00,0x00,
+0x00,0x08,0x24,0xd4,0x50,0x80,0x80,0x00,0x00,0x80,0x40,0x20,0x20,0x00,0x00,0x00,
+/* 12475 0x30bb "セ" */
+0x00,0x00,0x08,0x04,0x04,0x04,0x05,0x26,0x1c,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x88,0x10,0x20,0x40,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12476 0x30bc "ゼ" */
+0x00,0x00,0x08,0x04,0x04,0x04,0x05,0x26,0x1c,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x08,0x24,0x14,0x10,0x78,0x88,0x10,0x20,0x40,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 12477 0x30bd "ソ" */
+0x00,0x00,0x00,0x10,0x08,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x20,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 12478 0x30be "ゾ" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x08,0x08,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x00,
+0x00,0x08,0xa4,0x54,0x50,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12479 0x30bf "タ" */
+0x00,0x00,0x02,0x01,0x01,0x02,0x02,0x05,0x08,0x10,0x00,0x01,0x02,0x0c,0x30,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x20,0xc0,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12480 0x30c0 "ダ" */
+0x00,0x00,0x04,0x02,0x03,0x04,0x04,0x0a,0x11,0x20,0x01,0x02,0x04,0x18,0x60,0x00,
+0x00,0x08,0x24,0x14,0xf0,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12481 0x30c1 "チ" */
+0x00,0x00,0x00,0x01,0x1e,0x01,0x00,0x23,0x1c,0x00,0x00,0x01,0x01,0x02,0x04,0x00,
+0x00,0x00,0x40,0x80,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12482 0x30c2 "ヂ" */
+0x00,0x00,0x00,0x01,0x1e,0x01,0x00,0x23,0x1c,0x00,0x00,0x01,0x01,0x02,0x04,0x00,
+0x00,0x08,0x64,0x94,0x10,0x00,0xf8,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12483 0x30c3 "ッ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x12,0x0a,0x08,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12484 0x30c4 "ツ" */
+0x00,0x00,0x00,0x04,0x22,0x11,0x09,0x08,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x10,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12485 0x30c5 "ヅ" */
+0x00,0x00,0x00,0x10,0x08,0x44,0x24,0x10,0x10,0x00,0x01,0x02,0x04,0x08,0x00,0x00,
+0x00,0x08,0x24,0x94,0x50,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12486 0x30c6 "テ" */
+0x00,0x00,0x00,0x11,0x0e,0x00,0x00,0x23,0x1c,0x00,0x01,0x01,0x02,0x04,0x08,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x78,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12487 0x30c7 "デ" */
+0x00,0x00,0x00,0x11,0x0e,0x00,0x20,0x1f,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x00,
+0x00,0x08,0x24,0xd4,0x10,0x00,0xf0,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12488 0x30c8 "ト" */
+0x00,0x00,0x08,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12489 0x30c9 "ド" */
+0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x0e,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x20,0x90,0x50,0x40,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12490 0x30ca "ナ" */
+0x00,0x00,0x01,0x00,0x00,0x20,0x1f,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x00,
+0x00,0x00,0x00,0x80,0x80,0xf8,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12491 0x30cb "ニ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x01,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x00,0x00,0x00,0x00,
+/* 12492 0x30cc "ヌ" */
+0x00,0x00,0x00,0x10,0x0f,0x00,0x00,0x0e,0x01,0x00,0x01,0x02,0x0c,0x30,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x20,0x20,0x40,0xc0,0xc0,0x20,0x10,0x10,0x00,0x00,0x00,
+/* 12493 0x30cd "ネ" */
+0x00,0x00,0x02,0x01,0x01,0x1e,0x00,0x00,0x01,0x03,0x0d,0x31,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x00,0x40,0x30,0x08,0x00,0x00,0x00,0x00,
+/* 12494 0x30ce "ノ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x00,
+0x00,0x00,0x40,0x20,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12495 0x30cf "ハ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12496 0x30d0 "バ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x00,0x08,0x24,0x14,0x90,0x40,0x20,0x10,0x10,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12497 0x30d1 "パ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x18,0x24,0x24,0x18,0x80,0x40,0x20,0x10,0x10,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12498 0x30d2 "ヒ" */
+0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12499 0x30d3 "ビ" */
+0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x10,0x48,0x28,0x20,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12500 0x30d4 "ピ" */
+0x00,0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x30,0x48,0x48,0x30,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12501 0x30d5 "フ" */
+0x00,0x00,0x00,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12502 0x30d6 "ブ" */
+0x00,0x00,0x00,0x23,0x1c,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x08,0x24,0xd4,0x50,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12503 0x30d7 "プ" */
+0x00,0x00,0x00,0x23,0x1c,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x18,0x24,0xe4,0x58,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12504 0x30d8 "ヘ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 12505 0x30d9 "ベ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x90,0x50,0x40,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 12506 0x30da "ペ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x60,0x90,0x90,0x60,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 12507 0x30db "ホ" */
+0x00,0x00,0x02,0x01,0x01,0x21,0x1f,0x01,0x01,0x09,0x09,0x11,0x21,0x03,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x40,0x20,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 12508 0x30dc "ボ" */
+0x00,0x00,0x02,0x01,0x01,0x21,0x1f,0x01,0x01,0x09,0x09,0x11,0x21,0x03,0x01,0x00,
+0x00,0x08,0x24,0x14,0x10,0xf0,0x00,0x00,0x40,0x20,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 12509 0x30dd "ポ" */
+0x00,0x00,0x02,0x01,0x01,0x21,0x1f,0x01,0x01,0x09,0x09,0x11,0x21,0x03,0x01,0x00,
+0x00,0x18,0x24,0x24,0x18,0xf0,0x00,0x00,0x40,0x20,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 12510 0x30de "マ" */
+0x00,0x00,0x00,0x00,0x20,0x1f,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 12511 0x30df "ミ" */
+0x00,0x00,0x04,0x03,0x00,0x00,0x08,0x06,0x01,0x00,0x10,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0xc0,0x20,0x00,
+/* 12512 0x30e0 "ム" */
+0x00,0x00,0x02,0x01,0x01,0x01,0x02,0x02,0x02,0x04,0x04,0x29,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x30,0xc8,0x08,0x00,0x00,0x00,
+/* 12513 0x30e1 "メ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x00,0x00,0x00,0x01,0x02,0x0c,0x30,0x00,
+0x00,0x00,0x40,0x20,0x20,0x20,0x20,0xc0,0x40,0xa0,0x90,0x00,0x00,0x00,0x00,0x00,
+/* 12514 0x30e2 "モ" */
+0x00,0x00,0x00,0x10,0x0f,0x02,0x02,0x23,0x1e,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,
+/* 12515 0x30e3 "ャ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x03,0x1e,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x90,0x20,0x40,0x00,0x80,0x80,0x80,0x00,
+/* 12516 0x30e4 "ヤ" */
+0x00,0x00,0x08,0x04,0x04,0x03,0x26,0x1a,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x88,0x10,0x20,0x40,0x00,0x00,0x80,0x80,0x80,0x00,0x00,
+/* 12517 0x30e5 "ュ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x0e,0x00,0x00,0x01,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x40,0x40,0x80,0xe0,0x10,0x00,0x00,0x00,
+/* 12518 0x30e6 "ユ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x0e,0x00,0x00,0x00,0x01,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x40,0x40,0x80,0x80,0xf0,0x08,0x00,0x00,0x00,0x00,
+/* 12519 0x30e7 "ョ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x0e,0x00,0x01,0x0e,0x00,0x01,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0xe0,0x40,0x40,0xc0,0x20,0x00,0x00,
+/* 12520 0x30e8 "ヨ" */
+0x00,0x00,0x00,0x01,0x1e,0x00,0x00,0x01,0x0e,0x00,0x00,0x00,0x01,0x0e,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0xe0,0x10,0x00,0x00,
+/* 12521 0x30e9 "ラ" */
+0x00,0x00,0x00,0x11,0x0e,0x00,0x23,0x1c,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x70,0x90,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 12522 0x30ea "リ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x01,0x02,0x00,
+0x00,0x00,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12523 0x30eb "ル" */
+0x00,0x00,0x00,0x01,0x08,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x88,0x88,0x90,0x90,0xa0,0xc0,0x80,0x00,0x00,
+/* 12524 0x30ec "レ" */
+0x00,0x00,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12525 0x30ed "ロ" */
+0x00,0x00,0x00,0x00,0x21,0x1e,0x10,0x10,0x08,0x08,0x09,0x0e,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x20,0x20,0xe0,0x10,0x00,0x00,0x00,0x00,
+/* 12526 0x30ee "ヮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x0f,0x08,0x04,0x04,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 12527 0x30ef "ワ" */
+0x00,0x00,0x00,0x21,0x1e,0x10,0x08,0x08,0x08,0x00,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12528 0x30f0 "ヰ" */
+0x00,0x00,0x01,0x00,0x00,0x01,0x1e,0x08,0x04,0x05,0x3e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0xf0,0x80,0x80,0x80,0xf0,0x88,0x80,0x80,0x80,0x80,0x00,
+/* 12529 0x30f1 "ヱ" */
+0x00,0x00,0x00,0x00,0x01,0x1e,0x02,0x01,0x01,0x01,0x01,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x00,0x00,0xf0,0x08,0x00,0x00,0x00,0x00,
+/* 12530 0x30f2 "ヲ" */
+0x00,0x00,0x00,0x01,0x1e,0x00,0x00,0x01,0x0e,0x00,0x00,0x00,0x01,0x06,0x18,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0xe0,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12531 0x30f3 "ン" */
+0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x00,0x00,0x00,0x00,0x00,0x13,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12532 0x30f4 "ヴ" */
+0x00,0x00,0x04,0x02,0x02,0x43,0x3c,0x20,0x10,0x10,0x00,0x00,0x01,0x02,0x04,0x00,
+0x00,0x08,0x24,0x14,0x10,0xe0,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 12533 0x30f5 "ヵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x11,0x0e,0x02,0x02,0x04,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0xc0,0x40,0x00,
+/* 12534 0x30f6 "ヶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x07,0x08,0x10,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 12535 0x30f7 "ヷ" */
+0x00,0x00,0x00,0x21,0x1e,0x10,0x08,0x08,0x08,0x00,0x00,0x00,0x01,0x02,0x04,0x00,
+0x04,0x12,0x08,0xf0,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12536 0x30f8 "ヸ" */
+0x00,0x00,0x01,0x00,0x00,0x01,0x1e,0x08,0x04,0x05,0x3e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x04,0x90,0x88,0xf0,0x80,0x80,0x80,0xf0,0x88,0x80,0x80,0x80,0x80,0x00,
+/* 12537 0x30f9 "ヹ" */
+0x00,0x00,0x00,0x00,0x01,0x1e,0x02,0x01,0x01,0x01,0x01,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x08,0x04,0x10,0xe8,0x20,0x40,0x80,0x00,0x00,0xf0,0x08,0x00,0x00,0x00,0x00,
+/* 12538 0x30fa "ヺ" */
+0x00,0x00,0x00,0x01,0x1e,0x00,0x00,0x01,0x0e,0x00,0x00,0x00,0x01,0x06,0x18,0x00,
+0x04,0x02,0x08,0xf4,0x10,0x10,0x20,0xe0,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12539 0x30fb "・" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x07,0x07,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12540 0x30fc "ー" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12541 0x30fd "ヽ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12542 0x30fe "ヾ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x90,0x40,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12543 0x30ff "ヿ" */
+0x00,0x00,0x21,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+/* 12544 0x3100 "㄀" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 12545 0x3101 "㄁" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 12546 0x3102 "㄂" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 12547 0x3103 "㄃" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 12548 0x3104 "㄄" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 12549 0x3105 "ㄅ" */
+0x00,0x00,0x02,0x02,0x04,0x08,0x1f,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 12550 0x3106 "ㄆ" */
+0x00,0x00,0x01,0x01,0x02,0x07,0x00,0x00,0x02,0x01,0x00,0x01,0x06,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x40,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 12551 0x3107 "ㄇ" */
+0x00,0x00,0x3f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12552 0x3108 "ㄈ" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 12553 0x3109 "ㄉ" */
+0x00,0x02,0x02,0x04,0x08,0x1f,0x01,0x01,0x02,0x04,0x08,0x10,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 12554 0x310a "ㄊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x01,0x01,0x02,0x02,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x80,0x80,0xfe,0x00,0x00,0x20,0x10,0xf0,0x08,0x08,0x00,0x00,
+/* 12555 0x310b "ㄋ" */
+0x00,0x00,0x0f,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x20,0x40,0x80,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 12556 0x310c "ㄌ" */
+0x00,0x00,0x00,0x04,0x04,0x08,0x0f,0x00,0x01,0x02,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0xf8,0x88,0x08,0x10,0x10,0x10,0xa0,0x40,0x00,0x00,
+/* 12557 0x310d "ㄍ" */
+0x00,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x10,0x08,0x04,0x04,0x02,0x02,0x00,0x00,
+0x00,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x10,0x08,0x08,0x00,0x00,
+/* 12558 0x310e "ㄎ" */
+0x00,0x00,0x3f,0x01,0x02,0x04,0x07,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 12559 0x310f "ㄏ" */
+0x00,0x00,0x0f,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12560 0x3110 "ㄐ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 12561 0x3111 "ㄑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x80,0x40,0x30,0x08,0x04,0x00,0x00,
+/* 12562 0x3112 "ㄒ" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 12563 0x3113 "ㄓ" */
+0x00,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 12564 0x3114 "ㄔ" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x00,0x00,0x03,0x04,0x18,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x60,0x80,0x08,0x10,0x20,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+/* 12565 0x3115 "ㄕ" */
+0x00,0x00,0x0f,0x00,0x00,0x04,0x07,0x04,0x04,0x04,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12566 0x3116 "ㄖ" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x22,0x21,0x21,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x88,0x88,0x08,0xf8,0x08,0x00,0x00,
+/* 12567 0x3117 "ㄗ" */
+0x00,0x00,0x1f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x08,0x08,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12568 0x3118 "ㄘ" */
+0x00,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x10,0x20,0x20,0x40,0x00,
+/* 12569 0x3119 "ㄙ" */
+0x00,0x00,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,0x00,0x00,0x00,
+/* 12570 0x311a "ㄚ" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12571 0x311b "ㄛ" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 12572 0x311c "ㄜ" */
+0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x00,0x00,0x00,0x08,0x10,0xe0,0x00,0x00,
+/* 12573 0x311d "ㄝ" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x7f,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x10,0xfe,0x10,0x20,0x20,0x40,0x00,0xf0,0x00,0x00,0x00,
+/* 12574 0x311e "ㄞ" */
+0x00,0x00,0x1f,0x00,0x08,0x11,0x1f,0x01,0x02,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x80,0x00,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x00,0x00,
+/* 12575 0x311f "ㄟ" */
+0x00,0x00,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x10,0x10,0x0c,0x00,0x00,0x00,
+/* 12576 0x3120 "ㄠ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x1f,0x00,0x01,0x06,0x18,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x10,0x20,0xc0,0x80,0x00,0x10,0x18,0xe4,0x04,0x00,0x00,
+/* 12577 0x3121 "ㄡ" */
+0x00,0x00,0x0f,0x00,0x00,0x04,0x02,0x01,0x00,0x01,0x02,0x04,0x18,0x20,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x10,0x20,0x40,0xc0,0xc0,0x30,0x08,0x04,0x04,0x00,0x00,0x00,
+/* 12578 0x3122 "ㄢ" */
+0x00,0x00,0x1f,0x04,0x04,0x08,0x08,0x10,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x10,0x20,0x20,0x40,0x80,0xf8,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 12579 0x3123 "ㄣ" */
+0x00,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,0x00,0x00,0x00,
+/* 12580 0x3124 "ㄤ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x1f,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x00,0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0x7e,0x00,0x00,
+/* 12581 0x3125 "ㄥ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x04,0x08,0x10,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 12582 0x3126 "ㄦ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x3e,0x00,0x00,0x00,
+/* 12583 0x3127 "ㄧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12584 0x3128 "ㄨ" */
+0x00,0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x08,0x08,0x10,0x20,0x20,0xc0,0xc0,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,
+/* 12585 0x3129 "ㄩ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 12586 0x312a "ㄪ" */
+0x00,0x00,0x7f,0x02,0x02,0x02,0x02,0x03,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xa0,0x40,0x00,
+/* 12587 0x312b "ㄫ" */
+0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x00,
+0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x3c,0x00,
+/* 12588 0x312c "ㄬ" */
+0x00,0x01,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x00,
+0x00,0x00,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12589 0x312d "ㄭ" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12590 0x312e "ㄮ" */
+0x00,0x01,0x01,0x00,0x3f,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x80,0x00,0xfc,0x80,0x80,0x80,0x00,0x00,0x00,0x08,0x10,0xe0,0x00,0x00,
+/* 12591 0x312f "ㄯ" */
+0x00,0x00,0x1f,0x00,0x00,0x01,0x02,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0xe0,0x40,0x80,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,0x00,0x00,
+/* 12592 0x3130 "㄰" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 12593 0x3131 "ㄱ" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12594 0x3132 "ㄲ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 12595 0x3133 "ㄳ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12596 0x3134 "ㄴ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 12597 0x3135 "ㄵ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12598 0x3136 "ㄶ" */
+0x00,0x00,0x00,0x40,0x40,0x41,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x78,0x00,0xfe,0x00,0x78,0x84,0x84,0x84,0x84,0x78,0x00,0x00,0x00,
+/* 12599 0x3137 "ㄷ" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 12600 0x3138 "ㄸ" */
+0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12601 0x3139 "ㄹ" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 12602 0x313a "ㄺ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 12603 0x313b "ㄻ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0x00,
+/* 12604 0x313c "ㄼ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0x00,
+/* 12605 0x313d "ㄽ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12606 0x313e "ㄾ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12607 0x313f "ㄿ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0xfe,0x00,0x00,0x00,
+/* 12608 0x3140 "ㅀ" */
+0x00,0x00,0x00,0x7e,0x02,0x03,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x78,0x00,0xfe,0x00,0x78,0x84,0x84,0x84,0x84,0x78,0x00,0x00,0x00,
+/* 12609 0x3141 "ㅁ" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,
+/* 12610 0x3142 "ㅂ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,
+/* 12611 0x3143 "ㅃ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0x00,
+/* 12612 0x3144 "ㅄ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12613 0x3145 "ㅅ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x00,0x00,0x00,
+/* 12614 0x3146 "ㅆ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x00,0x00,0x00,
+/* 12615 0x3147 "ㅇ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x20,0x20,0x20,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 12616 0x3148 "ㅈ" */
+0x00,0x00,0x00,0x3f,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x00,0x00,0x00,
+/* 12617 0x3149 "ㅉ" */
+0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x00,0x00,0x00,
+/* 12618 0x314a "ㅊ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x3f,0x01,0x01,0x02,0x04,0x08,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0xf8,0x00,0x00,0x80,0x40,0x20,0x18,0x00,0x00,0x00,
+/* 12619 0x314b "ㅋ" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12620 0x314c "ㅌ" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 12621 0x314d "ㅍ" */
+0x00,0x00,0x00,0x3f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xf8,0x00,0x00,0x00,
+/* 12622 0x314e "ㅎ" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xf8,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 12623 0x314f "ㅏ" */
+0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12624 0x3150 "ㅐ" */
+0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 12625 0x3151 "ㅑ" */
+0x02,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 12626 0x3152 "ㅒ" */
+0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x04,
+0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,
+/* 12627 0x3153 "ㅓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 12628 0x3154 "ㅔ" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 12629 0x3155 "ㅕ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,
+/* 12630 0x3156 "ㅖ" */
+0x01,0x01,0x01,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 12631 0x3157 "ㅗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 12632 0x3158 "ㅘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xff,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0e,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,
+/* 12633 0x3159 "ㅙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xff,0x00,0x00,
+0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,
+/* 12634 0x315a "ㅚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xff,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,
+/* 12635 0x315b "ㅛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 12636 0x315c "ㅜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12637 0x315d "ㅝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,0xf8,0x08,0x08,0x08,
+/* 12638 0x315e "ㅞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x09,0x08,0x08,0x08,
+0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0xe4,0x24,0x24,0x24,
+/* 12639 0x315f "ㅟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 12640 0x3160 "ㅠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 12641 0x3161 "ㅡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 12642 0x3162 "ㅢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,
+/* 12643 0x3163 "ㅣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 12644 0x3164 "ㅤ" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0x91,0x11,0x9f,0x11,0x91,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x3c,0x21,0x38,0x21,0x20,0x01,0x00,0x01,0x00,0x55,
+/* 12645 0x3165 "ㅥ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12646 0x3166 "ㅦ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12647 0x3167 "ㅧ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12648 0x3168 "ㅨ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x82,0xfe,0x00,0x00,0x00,
+/* 12649 0x3169 "ㅩ" */
+0x00,0x00,0x00,0x7b,0x08,0x08,0x08,0x78,0x40,0x40,0x40,0x40,0x78,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc8,0x48,0x48,0x48,0x54,0x54,0x54,0x62,0x62,0x62,0x00,0x00,0x00,
+/* 12650 0x316a "ㅪ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12651 0x316b "ㅫ" */
+0x00,0x00,0x00,0x7a,0x0a,0x0a,0x0a,0x7b,0x42,0x42,0x42,0x42,0x7b,0x00,0x00,0x00,
+0x00,0x00,0x00,0x48,0x48,0x48,0x48,0xd4,0x54,0x54,0x62,0x62,0xe2,0x00,0x00,0x00,
+/* 12652 0x316c "ㅬ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x82,0xfe,0x00,0x00,0x00,
+/* 12653 0x316d "ㅭ" */
+0x00,0x00,0x00,0x7e,0x03,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x78,0x84,0x84,0x84,0x84,0x84,0x78,0x00,0x00,0x00,
+/* 12654 0x316e "ㅮ" */
+0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0x00,
+/* 12655 0x316f "ㅯ" */
+0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12656 0x3170 "ㅰ" */
+0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x82,0xfe,0x00,0x00,0x00,
+/* 12657 0x3171 "ㅱ" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x3f,0x00,0x0f,0x10,0x20,0x20,0x20,0x10,0x0f,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0xe0,0x10,0x08,0x08,0x08,0x10,0xe0,0x00,
+/* 12658 0x3172 "ㅲ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 12659 0x3173 "ㅳ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12660 0x3174 "ㅴ" */
+0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x7d,0x45,0x45,0x46,0x46,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xbc,0x84,0x84,0x84,0x44,0x44,0x44,0x24,0x24,0x24,0x00,0x00,0x00,
+/* 12661 0x3175 "ㅵ" */
+0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x7a,0x4a,0x4a,0x4c,0x4c,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x3c,0x20,0x20,0x20,0xa0,0xa0,0xa0,0x60,0x60,0x7c,0x00,0x00,0x00,
+/* 12662 0x3176 "ㅶ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12663 0x3177 "ㅷ" */
+0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12664 0x3178 "ㅸ" */
+0x00,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x00,0x0f,0x10,0x20,0x20,0x10,0x0f,0x00,
+0x00,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x00,0xe0,0x10,0x08,0x08,0x10,0xe0,0x00,
+/* 12665 0x3179 "ㅹ" */
+0x00,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x00,0x0f,0x10,0x20,0x20,0x10,0x0f,0x00,
+0x00,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x00,0xe0,0x10,0x08,0x08,0x10,0xe0,0x00,
+/* 12666 0x317a "ㅺ" */
+0x00,0x00,0x00,0x09,0x08,0x08,0x08,0x08,0x14,0x14,0x22,0x22,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12667 0x317b "ㅻ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12668 0x317c "ㅼ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0x00,
+/* 12669 0x317d "ㅽ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+0x00,0x00,0x00,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0x00,
+/* 12670 0x317e "ㅾ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,
+/* 12671 0x317f "ㅿ" */
+0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0xf8,0x00,0x00,0x00,
+/* 12672 0x3180 "ㆀ" */
+0x00,0x00,0x08,0x08,0x08,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x78,0x84,0x84,0x84,0x84,0x84,0x84,0x78,0x00,0x00,0x00,
+/* 12673 0x3181 "ㆁ" */
+0x00,0x00,0x01,0x01,0x01,0x0f,0x10,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 12674 0x3182 "ㆂ" */
+0x00,0x00,0x08,0x08,0x08,0x3c,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x00,0x00,0x00,
+/* 12675 0x3183 "ㆃ" */
+0x00,0x00,0x08,0x08,0x08,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x82,0xfe,0x00,0x00,0x00,
+/* 12676 0x3184 "ㆄ" */
+0x00,0x3f,0x08,0x08,0x08,0x08,0x08,0x3f,0x00,0x0f,0x10,0x20,0x20,0x10,0x0f,0x00,
+0x00,0xf8,0x20,0x20,0x20,0x20,0x20,0xf8,0x00,0xe0,0x10,0x08,0x08,0x10,0xe0,0x00,
+/* 12677 0x3185 "ㆅ" */
+0x00,0x00,0x00,0x3c,0x00,0xff,0x00,0x3c,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x78,0x00,0xfe,0x00,0x78,0x84,0x84,0x84,0x84,0x78,0x00,0x00,0x00,
+/* 12678 0x3186 "ㆆ" */
+0x00,0x00,0x00,0x00,0x3f,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 12679 0x3187 "ㆇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0xff,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x0e,0x08,0x08,0x08,0x08,0x0e,0x08,0x08,0xc8,0x08,0x08,
+/* 12680 0x3188 "ㆈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x24,0xff,0x00,0x00,
+0x24,0x24,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x24,0x3c,0x24,0x24,0xa4,0x24,0x24,
+/* 12681 0x3189 "ㆉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0xff,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,
+/* 12682 0x318a "ㆊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x12,0x12,0x12,0x12,0x12,0x12,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 12683 0x318b "ㆋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x24,0x25,0x24,0x25,0x24,0x24,
+0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0xe4,0x24,0xe4,0x24,0x24,
+/* 12684 0x318c "ㆌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x12,0x12,0x12,0x12,0x12,0x12,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 12685 0x318d "ㆍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,
+/* 12686 0x318e "ㆎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 12687 0x318f "㆏" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 12688 0x3190 "㆐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12689 0x3191 "㆑" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12690 0x3192 "㆒" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12691 0x3193 "㆓" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12692 0x3194 "㆔" */
+0x00,0x00,0x1f,0x00,0x0f,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x00,0xc0,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12693 0x3195 "㆕" */
+0x00,0x00,0x3f,0x25,0x25,0x28,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x20,0x20,0xe0,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12694 0x3196 "㆖" */
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x04,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12695 0x3197 "㆗" */
+0x00,0x04,0x04,0x3f,0x24,0x24,0x3f,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12696 0x3198 "㆘" */
+0x00,0x00,0x3f,0x04,0x06,0x05,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12697 0x3199 "㆙" */
+0x00,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x22,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x40,0xc0,0x40,0xc0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12698 0x319a "㆚" */
+0x00,0x00,0x3f,0x03,0x04,0x08,0x10,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12699 0x319b "㆛" */
+0x00,0x00,0x3f,0x02,0x3f,0x22,0x23,0x24,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x00,0xe0,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12700 0x319c "㆜" */
+0x00,0x00,0x3f,0x02,0x02,0x02,0x02,0x02,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12701 0x319d "㆝" */
+0x00,0x00,0x1f,0x02,0x02,0x3f,0x02,0x05,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0xe0,0x00,0x00,0xe0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12702 0x319e "㆞" */
+0x00,0x08,0x09,0x3d,0x0b,0x09,0x09,0x0d,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x50,0xf0,0x50,0x50,0x28,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12703 0x319f "㆟" */
+0x00,0x04,0x04,0x04,0x04,0x0a,0x09,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12704 0x31a0 "ㆠ" */
+0x00,0x08,0x08,0x10,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x10,0x20,0xc0,0x00,
+/* 12705 0x31a1 "ㆡ" */
+0x00,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x1e,0x22,0x22,0x1c,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x10,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12706 0x31a2 "ㆢ" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x08,0x09,0x0e,0x00,0x01,0x02,0x02,0x01,0x00,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x60,0xa0,0x20,0x20,0xe0,0x20,0x20,0xc0,0x00,
+/* 12707 0x31a3 "ㆣ" */
+0x00,0x00,0x04,0x04,0x08,0x08,0x11,0x11,0x22,0x11,0x11,0x08,0x08,0x04,0x04,0x00,
+0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0xb8,0xc4,0x44,0x38,0x00,
+/* 12708 0x31a4 "ㆤ" */
+0x00,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,
+/* 12709 0x31a5 "ㆥ" */
+0x00,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x08,0x10,0x00,0x18,0x24,0x24,0xf8,0x08,0x00,
+/* 12710 0x31a6 "ㆦ" */
+0x00,0x00,0x7f,0x02,0x02,0x04,0x08,0x10,0x20,0x20,0x10,0x08,0x05,0x02,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 12711 0x31a7 "ㆧ" */
+0x00,0x00,0x7f,0x02,0x02,0x04,0x08,0x10,0x20,0x21,0x11,0x08,0x05,0x02,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x40,0x80,0x60,0x00,0x00,0x00,
+/* 12712 0x31a8 "ㆨ" */
+0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x02,0x04,0x18,0x60,0x00,0x00,
+0x00,0x00,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,
+/* 12713 0x31a9 "ㆩ" */
+0x00,0x00,0x20,0x10,0x08,0x04,0x03,0x02,0x02,0x02,0x0f,0x12,0x22,0x22,0x1c,0x00,
+0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12714 0x31aa "ㆪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x18,0x24,0x44,0x44,0xf8,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12715 0x31ab "ㆫ" */
+0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x02,0x04,0x18,0x60,0x00,0x00,
+0x00,0x00,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x8c,0x52,0x22,0x5c,0x40,0x00,
+/* 12716 0x31ac "ㆬ" */
+0x00,0x00,0x20,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 12717 0x31ad "ㆭ" */
+0x00,0x00,0x7f,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x11,0x61,0x00,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1e,0x00,0x00,
+/* 12718 0x31ae "ㆮ" */
+0x00,0x00,0x7f,0x01,0x11,0x11,0x21,0x3f,0x01,0x01,0x02,0x32,0x4c,0x4a,0x32,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x00,
+/* 12719 0x31af "ㆯ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x1f,0x00,0x01,0x06,0x18,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x10,0x20,0xc0,0x80,0x18,0x24,0x24,0xf8,0x10,0x0c,0x00,
+/* 12720 0x31b0 "ㆰ" */
+0x00,0x18,0x04,0x02,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x00,
+0x00,0x30,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+/* 12721 0x31b1 "ㆱ" */
+0x00,0x00,0x7f,0x01,0x7f,0x41,0x47,0x48,0x50,0x50,0x48,0x45,0x42,0x40,0x40,0x00,
+0x00,0x00,0xfc,0x00,0xfc,0x04,0x04,0x04,0x04,0x44,0x84,0x04,0x04,0x04,0x04,0x00,
+/* 12722 0x31b2 "ㆲ" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 12723 0x31b3 "ㆳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x07,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xe0,0x80,0x80,0x80,0x00,0x00,
+/* 12724 0x31b4 "ㆴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x07,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 12725 0x31b5 "ㆵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x07,0x01,0x02,0x04,0x09,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 12726 0x31b6 "ㆶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x01,0x02,0x07,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0xc0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 12727 0x31b7 "ㆷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x02,0x02,0x02,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12728 0x31b8 "ㆸ" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x3f,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 12729 0x31b9 "ㆹ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12730 0x31ba "ㆺ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12731 0x31bb "ㆻ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x08,0x08,0x11,0x08,0x08,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x40,0x00,0x00,
+/* 12732 0x31bc "ㆼ" */
+0x00,0x00,0x02,0x04,0x08,0x0c,0x02,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x30,0x30,0x40,0xc0,0x80,0x80,0x40,0x60,0x30,0x18,0x18,0x00,0x00,
+/* 12733 0x31bd "ㆽ" */
+0x00,0x3f,0x02,0x04,0x08,0x0c,0x02,0x01,0x01,0x02,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0xf8,0x00,0x30,0x30,0x40,0xc0,0x80,0x80,0x40,0x60,0x30,0x18,0x18,0x00,0x00,
+/* 12734 0x31be "ㆾ" */
+0x00,0x00,0x10,0x10,0x08,0x08,0x08,0x04,0x3f,0x04,0x02,0x02,0x02,0x01,0x01,0x00,
+0x00,0x00,0x10,0x10,0x20,0x20,0x20,0x40,0xf8,0x40,0x40,0x80,0x80,0x80,0x00,0x00,
+/* 12735 0x31bf "ㆿ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 12736 0x31c0 "㇀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12737 0x31c1 "㇁" */
+0x04,0x02,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12738 0x31c2 "㇂" */
+0x10,0x10,0x10,0x10,0x08,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x50,0x20,0x00,
+/* 12739 0x31c3 "㇃" */
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 12740 0x31c4 "㇄" */
+0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12741 0x31c5 "㇅" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 12742 0x31c6 "㇆" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,0x00,
+/* 12743 0x31c7 "㇇" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 12744 0x31c8 "㇈" */
+0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x82,0x82,0x82,0x7c,
+/* 12745 0x31c9 "㇉" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x10,0x10,0xa0,0x40,
+/* 12746 0x31ca "㇊" */
+0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x90,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 12747 0x31cb "㇋" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x08,0x10,0x20,0x7c,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+/* 12748 0x31cc "㇌" */
+0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
+0x00,0xe0,0x20,0x40,0x80,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 12749 0x31cd "㇍" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x40,0x3e,0x00,0x00,0x00,0x00,
+/* 12750 0x31ce "㇎" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+/* 12751 0x31cf "㇏" */
+0x00,0x08,0x08,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x14,0x08,
+/* 12752 0x31d0 "㇐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12753 0x31d1 "㇑" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12754 0x31d2 "㇒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12755 0x31d3 "㇓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x00,
+0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12756 0x31d4 "㇔" */
+0x00,0x00,0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12757 0x31d5 "㇕" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 12758 0x31d6 "㇖" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12759 0x31d7 "㇗" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 12760 0x31d8 "㇘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,0x00,
+/* 12761 0x31d9 "㇙" */
+0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x06,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 12762 0x31da "㇚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,
+0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 12763 0x31db "㇛" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 12764 0x31dc "㇜" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x04,0x08,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 12765 0x31dd "㇝" */
+0x00,0x08,0x08,0x14,0x24,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x0a,0x04,0x00,
+/* 12766 0x31de "㇞" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,
+/* 12767 0x31df "㇟" */
+0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0xf8,0x00,
+/* 12768 0x31e0 "㇠" */
+0x00,0x7f,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x40,0x3f,0x00,
+0x00,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x06,0xfc,0x00,
+/* 12769 0x31e1 "㇡" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x10,0x10,0x20,0x7c,0x04,0x04,0x04,0x04,0x04,0x08,0x28,0x10,0x00,
+/* 12770 0x31e2 "㇢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x22,0x24,0x38,0x00,
+0x00,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12771 0x31e3 "㇣" */
+0x00,0x00,0x00,0x1f,0x20,0x40,0x40,0x40,0x40,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 12772 0x31e4 "㇤" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 12773 0x31e5 "㇥" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 12774 0x31e6 "㇦" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 12775 0x31e7 "㇧" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 12776 0x31e8 "㇨" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 12777 0x31e9 "㇩" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 12778 0x31ea "㇪" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 12779 0x31eb "㇫" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 12780 0x31ec "㇬" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 12781 0x31ed "㇭" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 12782 0x31ee "㇮" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 12783 0x31ef "㇯" */
+0xdb,0x00,0x80,0x95,0x00,0x90,0x80,0x10,0x85,0x90,0x80,0x10,0x95,0x80,0x00,0xdb,
+0xb6,0x00,0x02,0x52,0x10,0x02,0x12,0x00,0x52,0x02,0x12,0x00,0x52,0x02,0x00,0xb6,
+/* 12784 0x31f0 "ㇰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x2e,0x32,0x24,0x44,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12785 0x31f1 "ㇱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x10,0x00,0x61,0x12,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12786 0x31f2 "ㇲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0x72,0x04,0x04,0x08,0x14,0x22,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12787 0x31f3 "ㇳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x30,0x28,0x24,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12788 0x31f4 "ㇴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0x72,0x04,0x34,0x08,0x14,0x22,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12789 0x31f5 "ㇵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x10,0x10,0x00,0x00,0x00,
+/* 12790 0x31f6 "ㇶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x4e,0x70,0x40,0x40,0x40,0x3e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12791 0x31f7 "ㇷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0x72,0x04,0x04,0x08,0x10,0x20,0xc0,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12792 0x31f8 "ㇸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x00,0x00,
+/* 12793 0x31f9 "ㇹ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x1e,0xf0,0x10,0x54,0x92,0x10,0x50,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12794 0x31fa "ㇺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x01,0x01,0x02,0x02,0x14,0x0f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xd0,0x08,0x00,
+/* 12795 0x31fb "ㇻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0x70,0x00,0x8e,0x72,0x02,0x04,0x08,0x70,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12796 0x31fc "ㇼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x44,0x44,0x44,0x04,0x04,0x08,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12797 0x31fd "ㇽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x04,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x20,0x20,0x24,0x24,0x28,0x30,0x00,
+/* 12798 0x31fe "ㇾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 12799 0x31ff "ㇿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x11,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x20,0x20,0xf0,0x00,0x00,0x00,
+/* 12800 0x3200 "㈀" */
+0x00,0x18,0x20,0x40,0x4f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x02,0x04,0x18,0x00,
+/* 12801 0x3201 "㈁" */
+0x00,0x18,0x20,0x40,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xf2,0x02,0x04,0x18,0x00,
+/* 12802 0x3202 "㈂" */
+0x00,0x18,0x20,0x40,0x4f,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x02,0x02,0x02,0x02,0x02,0x02,0xf2,0x02,0x04,0x18,0x00,
+/* 12803 0x3203 "㈃" */
+0x00,0x18,0x20,0x40,0x4f,0x40,0x40,0x4f,0x48,0x48,0x48,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x12,0x12,0xf2,0x02,0x02,0x02,0xf2,0x02,0x04,0x18,0x00,
+/* 12804 0x3204 "㈄" */
+0x00,0x18,0x20,0x40,0x4f,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0xf2,0x02,0x04,0x18,0x00,
+/* 12805 0x3205 "㈅" */
+0x00,0x18,0x20,0x40,0x48,0x48,0x48,0x4f,0x48,0x48,0x48,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0x12,0x12,0x12,0xf2,0x12,0x12,0x12,0xf2,0x02,0x04,0x18,0x00,
+/* 12806 0x3206 "㈆" */
+0x00,0x18,0x20,0x40,0x40,0x40,0x40,0x41,0x41,0x42,0x44,0x48,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x82,0x82,0x82,0x82,0x42,0x42,0x22,0x12,0x0a,0x02,0x04,0x18,0x00,
+/* 12807 0x3207 "㈇" */
+0x00,0x18,0x20,0x40,0x43,0x44,0x48,0x48,0x48,0x48,0x44,0x43,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xc2,0x22,0x12,0x12,0x12,0x12,0x22,0xc2,0x02,0x04,0x18,0x00,
+/* 12808 0x3208 "㈈" */
+0x00,0x18,0x20,0x40,0x4f,0x40,0x40,0x41,0x41,0x42,0x44,0x48,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xfa,0x82,0x82,0x42,0x42,0x22,0x12,0x0a,0x02,0x04,0x18,0x00,
+/* 12809 0x3209 "㈉" */
+0x00,0x18,0x20,0x43,0x40,0x4f,0x40,0x40,0x41,0x42,0x44,0x48,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0xe2,0x02,0xfa,0x82,0x82,0x42,0x22,0x12,0x0a,0x02,0x04,0x18,0x00,
+/* 12810 0x320a "㈊" */
+0x00,0x18,0x20,0x40,0x4f,0x40,0x40,0x40,0x4f,0x40,0x40,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x12,0x12,0x12,0xf2,0x12,0x12,0x12,0x02,0x04,0x18,0x00,
+/* 12811 0x320b "㈋" */
+0x00,0x18,0x20,0x40,0x4f,0x48,0x48,0x4f,0x48,0x48,0x48,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x02,0x02,0xf2,0x02,0x02,0x02,0xf2,0x02,0x04,0x18,0x00,
+/* 12812 0x320c "㈌" */
+0x00,0x18,0x20,0x40,0x4f,0x42,0x42,0x42,0x42,0x42,0x42,0x4f,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x02,0xf2,0x42,0x42,0x42,0x42,0x42,0x42,0xf2,0x02,0x04,0x18,0x00,
+/* 12813 0x320d "㈍" */
+0x00,0x18,0x20,0x43,0x40,0x4f,0x40,0x43,0x44,0x44,0x44,0x43,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0xc2,0x02,0xf2,0x02,0xc2,0x22,0x22,0x22,0xc2,0x02,0x04,0x18,0x00,
+/* 12814 0x320e "㈎" */
+0x00,0x18,0x20,0x40,0x4f,0x41,0x41,0x42,0x42,0x44,0x48,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12815 0x320f "㈏" */
+0x00,0x18,0x20,0x40,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0xa2,0x22,0x22,0x04,0x18,0x00,
+/* 12816 0x3210 "㈐" */
+0x00,0x18,0x20,0x40,0x4f,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12817 0x3211 "㈑" */
+0x00,0x18,0x20,0x40,0x4f,0x41,0x41,0x4f,0x48,0x48,0x4f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12818 0x3212 "㈒" */
+0x00,0x18,0x20,0x40,0x4f,0x49,0x49,0x49,0x49,0x49,0x4f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12819 0x3213 "㈓" */
+0x00,0x18,0x20,0x40,0x49,0x49,0x4f,0x49,0x49,0x49,0x4f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12820 0x3214 "㈔" */
+0x00,0x18,0x20,0x40,0x42,0x42,0x42,0x45,0x45,0x48,0x48,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0xa2,0xa2,0x22,0x22,0x04,0x18,0x00,
+/* 12821 0x3215 "㈕" */
+0x00,0x18,0x20,0x40,0x46,0x49,0x49,0x49,0x49,0x49,0x46,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12822 0x3216 "㈖" */
+0x00,0x18,0x20,0x40,0x4f,0x42,0x42,0x45,0x45,0x48,0x48,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0xa2,0x22,0x22,0x3a,0x22,0xa2,0xa2,0x22,0x22,0x04,0x18,0x00,
+/* 12823 0x3217 "㈗" */
+0x00,0x18,0x20,0x47,0x40,0x4f,0x42,0x42,0x45,0x45,0x48,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0xa2,0x22,0x3a,0x22,0x22,0xa2,0x22,0x22,0x04,0x18,0x00,
+/* 12824 0x3218 "㈘" */
+0x00,0x18,0x20,0x40,0x4f,0x41,0x41,0x4e,0x42,0x44,0x48,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12825 0x3219 "㈙" */
+0x00,0x18,0x20,0x40,0x4f,0x48,0x48,0x4f,0x48,0x48,0x4f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12826 0x321a "㈚" */
+0x00,0x18,0x20,0x40,0x5f,0x49,0x49,0x49,0x49,0x49,0x5f,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0xa2,0x22,0x22,0x3a,0x22,0x22,0xa2,0x22,0x22,0x04,0x18,0x00,
+/* 12827 0x321b "㈛" */
+0x00,0x18,0x20,0x47,0x40,0x4f,0x40,0x47,0x48,0x48,0x47,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0x22,0x22,0xa2,0x22,0x3a,0xa2,0xa2,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12828 0x321c "㈜" */
+0x00,0x18,0x20,0x47,0x40,0x41,0x42,0x44,0x40,0x4f,0x40,0x40,0x40,0x20,0x18,0x00,
+0x00,0x18,0x04,0xf2,0x82,0x42,0x22,0x12,0x02,0xfa,0x82,0x82,0x86,0x84,0x18,0x00,
+/* 12829 0x321d "㈝" */
+0x00,0x30,0x40,0x99,0xa4,0xa4,0xa4,0x99,0x80,0x88,0x88,0xbe,0x80,0x40,0x30,0x00,
+0x00,0x18,0x04,0xea,0x4a,0x5a,0xaa,0x2a,0x0a,0x8a,0x82,0x82,0xfa,0x04,0x18,0x00,
+/* 12830 0x321e "㈞" */
+0x30,0x40,0x80,0x99,0xa4,0xa4,0xa4,0x98,0x80,0x89,0x88,0xbe,0x80,0x40,0x30,0x00,
+0x18,0x04,0x62,0xfa,0x62,0x92,0x92,0x62,0x02,0xfa,0x22,0x22,0x22,0x04,0x18,0x00,
+/* 12831 0x321f "㈟" */
+0x00,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 12832 0x3220 "㈠" */
+0x00,0x20,0x40,0x80,0x80,0x80,0x80,0xbf,0x80,0x80,0x80,0x80,0x80,0x40,0x20,0x00,
+0x00,0x08,0x04,0x02,0x02,0x02,0x12,0xfa,0x02,0x02,0x02,0x02,0x02,0x04,0x08,0x00,
+/* 12833 0x3221 "㈡" */
+0x00,0x20,0x40,0x80,0x9f,0x80,0x80,0x80,0x80,0x80,0xbf,0x80,0x80,0x40,0x20,0x00,
+0x00,0x08,0x04,0x22,0xf2,0x02,0x02,0x02,0x02,0x12,0xfa,0x02,0x02,0x04,0x08,0x00,
+/* 12834 0x3222 "㈢" */
+0x00,0x20,0x40,0x9f,0x80,0x80,0x80,0x8f,0x80,0x80,0x80,0xbf,0x80,0x40,0x20,0x00,
+0x00,0x08,0x24,0xf2,0x02,0x02,0x42,0xe2,0x02,0x02,0x12,0xfa,0x02,0x04,0x08,0x00,
+/* 12835 0x3223 "㈣" */
+0x00,0x20,0x40,0x80,0xbf,0xa4,0xa4,0xa4,0xa4,0xa4,0xbf,0x80,0x80,0x40,0x20,0x00,
+0x00,0x08,0x04,0x02,0xfa,0x4a,0x4a,0x4a,0x4a,0x4a,0xfa,0x02,0x02,0x04,0x08,0x00,
+/* 12836 0x3224 "㈤" */
+0x00,0x20,0x40,0x9f,0x82,0x82,0x82,0x9f,0x84,0x84,0x84,0x84,0xbf,0x40,0x20,0x00,
+0x00,0x08,0x24,0xf2,0x02,0x02,0x22,0xf2,0x22,0x22,0x22,0x22,0xfa,0x04,0x08,0x00,
+/* 12837 0x3225 "㈥" */
+0x00,0x20,0x40,0x82,0x81,0x80,0xbf,0x80,0x80,0x84,0x84,0x88,0x90,0x40,0x20,0x00,
+0x00,0x08,0x04,0x02,0x02,0x12,0xfa,0x02,0x02,0x42,0x22,0x12,0x12,0x04,0x08,0x00,
+/* 12838 0x3226 "㈦" */
+0x00,0x20,0x42,0x82,0x82,0x82,0x82,0x83,0xbe,0x82,0x82,0x82,0x82,0x41,0x20,0x00,
+0x00,0x08,0x04,0x02,0x02,0x12,0x7a,0x82,0x02,0x02,0x02,0x22,0x22,0xe4,0x08,0x00,
+/* 12839 0x3227 "㈧" */
+0x00,0x20,0x40,0x84,0x84,0x84,0x84,0x84,0x88,0x88,0x90,0xa0,0x80,0x40,0x20,0x00,
+0x00,0x08,0x84,0x82,0x82,0x82,0x82,0x82,0x42,0x22,0x1a,0x12,0x02,0x04,0x08,0x00,
+/* 12840 0x3228 "㈨" */
+0x00,0x20,0x42,0x82,0x82,0x9f,0x82,0x82,0x82,0x84,0x84,0x88,0x90,0x40,0x20,0x00,
+0x00,0x08,0x04,0x02,0x42,0xe2,0x42,0x42,0x42,0x42,0x4a,0x4a,0x3a,0x04,0x08,0x00,
+/* 12841 0x3229 "㈩" */
+0x00,0x20,0x41,0x81,0x81,0x81,0xbf,0x81,0x81,0x81,0x81,0x81,0x81,0x40,0x20,0x00,
+0x00,0x08,0x04,0x02,0x02,0x12,0xfa,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x08,0x00,
+/* 12842 0x322a "㈪" */
+0x00,0x30,0x47,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x84,0x88,0x90,0x40,0x30,0x00,
+0x00,0x18,0xf4,0x12,0x12,0xf2,0x12,0x12,0xf2,0x12,0x12,0x52,0x22,0x04,0x18,0x00,
+/* 12843 0x322b "㈫" */
+0x00,0x30,0x41,0x81,0x89,0x89,0x89,0x91,0x82,0x82,0x84,0x88,0xb0,0x40,0x30,0x00,
+0x00,0x18,0x04,0x02,0x12,0x22,0x42,0x02,0x82,0x82,0x42,0x22,0x1a,0x04,0x18,0x00,
+/* 12844 0x322c "㈬" */
+0x00,0x30,0x41,0x81,0x81,0xbd,0x85,0x85,0x89,0x89,0x91,0xa5,0x82,0x40,0x30,0x00,
+0x00,0x18,0x04,0x02,0x12,0xa2,0x42,0x42,0x22,0x22,0x12,0x0a,0x02,0x04,0x18,0x00,
+/* 12845 0x322d "㈭" */
+0x00,0x30,0x41,0x81,0x81,0xbf,0x81,0x83,0x85,0x89,0xb1,0x81,0x81,0x40,0x30,0x00,
+0x00,0x18,0x04,0x02,0x02,0xfa,0x02,0x82,0x42,0x22,0x1a,0x12,0x02,0x04,0x18,0x00,
+/* 12846 0x322e "㈮" */
+0x00,0x30,0x41,0x82,0x84,0x88,0xb7,0x81,0x9f,0x81,0x89,0x85,0xbf,0x40,0x30,0x00,
+0x00,0x18,0x04,0x82,0x42,0x22,0xda,0x02,0xf2,0x02,0x22,0x42,0xfa,0x04,0x18,0x00,
+/* 12847 0x322f "㈯" */
+0x00,0x30,0x41,0x81,0x81,0x81,0x9f,0x81,0x81,0x81,0x81,0x81,0xbf,0x40,0x30,0x00,
+0x00,0x18,0x04,0x02,0x02,0x02,0xf2,0x02,0x02,0x02,0x02,0x02,0xfa,0x04,0x18,0x00,
+/* 12848 0x3230 "㈰" */
+0x00,0x30,0x40,0x8f,0x88,0x88,0x88,0x8f,0x88,0x88,0x88,0x8f,0x88,0x40,0x30,0x00,
+0x00,0x18,0x04,0xe2,0x22,0x22,0x22,0xe2,0x22,0x22,0x22,0xe2,0x22,0x04,0x18,0x00,
+/* 12849 0x3231 "㈱" */
+0x00,0x30,0x48,0x89,0xbd,0x8a,0x9c,0x9b,0xa8,0xa8,0x89,0x8a,0x88,0x40,0x30,0x00,
+0x00,0x18,0x44,0x42,0xf2,0x42,0x42,0xfa,0x42,0xe2,0x52,0x4a,0x42,0x04,0x18,0x00,
+/* 12850 0x3232 "㈲" */
+0x00,0x30,0x42,0xbf,0x84,0x87,0x8c,0x97,0xa4,0x87,0x84,0x84,0x84,0x40,0x30,0x00,
+0x00,0x18,0x04,0xfa,0x02,0xe2,0x22,0xe2,0x22,0xe2,0x22,0x22,0x62,0x04,0x18,0x00,
+/* 12851 0x3233 "㈳" */
+0x00,0x30,0x50,0x88,0xbe,0x84,0x89,0x8c,0x9a,0xa8,0x88,0x88,0x8b,0x40,0x30,0x00,
+0x00,0x18,0x44,0x42,0x42,0x42,0xf2,0x42,0x42,0x42,0x42,0x42,0xfa,0x04,0x18,0x00,
+/* 12852 0x3234 "㈴" */
+0x00,0x30,0x44,0x87,0x84,0x8a,0x91,0x81,0x87,0xbc,0x84,0x84,0x87,0x40,0x30,0x00,
+0x00,0x18,0x04,0xf2,0x22,0x42,0x82,0x02,0xf2,0x12,0x12,0x12,0xf2,0x04,0x18,0x00,
+/* 12853 0x3235 "㈵" */
+0x00,0x30,0x48,0xa9,0xbc,0xa8,0xab,0x8c,0x9b,0xa9,0x88,0x88,0x88,0x40,0x30,0x00,
+0x00,0x18,0x44,0xf2,0x42,0x42,0xfa,0x22,0xfa,0x22,0xa2,0x22,0xe2,0x04,0x18,0x00,
+/* 12854 0x3236 "㈶" */
+0x00,0x30,0x40,0x9e,0x93,0x9e,0x92,0x9e,0x92,0x9f,0x80,0x92,0xa1,0x40,0x30,0x00,
+0x00,0x18,0x14,0x12,0xfa,0x12,0x32,0x52,0x92,0x12,0x12,0x52,0x22,0x04,0x18,0x00,
+/* 12855 0x3237 "㈷" */
+0x00,0x30,0x51,0x89,0xbf,0x83,0x85,0x8c,0x9a,0xaa,0x88,0x89,0x8a,0x40,0x30,0x00,
+0x00,0x18,0xf4,0x12,0x12,0x12,0xf2,0xa2,0xa2,0xa2,0xaa,0x2a,0x1a,0x04,0x18,0x00,
+/* 12856 0x3238 "㈸" */
+0x00,0x30,0x52,0x89,0x89,0x9f,0x91,0xa1,0x9f,0x81,0x82,0x84,0x98,0x40,0x30,0x00,
+0x00,0x18,0x14,0x12,0x22,0xfa,0x0a,0x02,0xf2,0x12,0x12,0x12,0x62,0x04,0x18,0x00,
+/* 12857 0x3239 "㈹" */
+0x00,0x30,0x44,0x84,0x88,0x88,0x9b,0xa8,0x88,0x88,0x88,0x88,0x88,0x40,0x30,0x00,
+0x00,0x18,0xa4,0x92,0x82,0xfa,0x82,0x82,0x82,0x42,0x4a,0x2a,0x1a,0x04,0x18,0x00,
+/* 12858 0x323a "㈺" */
+0x00,0x30,0x40,0xbb,0xa8,0xaa,0xa9,0xaf,0xb8,0xa8,0x80,0x80,0x81,0x40,0x30,0x00,
+0x00,0x18,0x34,0xc2,0x4a,0x4a,0x52,0xfa,0x42,0x42,0x42,0x42,0xc2,0x04,0x18,0x00,
+/* 12859 0x323b "㈻" */
+0x00,0x30,0x49,0x84,0x9f,0x90,0x87,0x80,0x80,0x9f,0x80,0x80,0x83,0x40,0x30,0x00,
+0x00,0x18,0x14,0xa2,0xfa,0x0a,0xe2,0x42,0x82,0xfa,0x82,0x82,0x82,0x04,0x18,0x00,
+/* 12860 0x323c "㈼" */
+0x00,0x30,0x5f,0x94,0x9f,0x91,0x9f,0x94,0x9f,0x80,0x9f,0x92,0xbf,0x40,0x30,0x00,
+0x00,0x18,0x24,0x22,0x3a,0x42,0x52,0x0a,0x82,0x02,0xf2,0x92,0xfa,0x04,0x18,0x00,
+/* 12861 0x323d "㈽" */
+0x00,0x30,0x41,0x81,0x82,0x84,0x88,0xb0,0x84,0x84,0x84,0x84,0x9f,0x40,0x30,0x00,
+0x00,0x18,0x04,0x82,0x42,0x22,0x9a,0x82,0xe2,0x82,0x82,0x82,0xfa,0x04,0x18,0x00,
+/* 12862 0x323e "㈾" */
+0x00,0x30,0x51,0x8b,0x84,0x9f,0x8c,0x87,0x84,0x87,0x84,0x87,0x9c,0x40,0x30,0x00,
+0x00,0x18,0x04,0xfa,0x4a,0xe2,0x3a,0xe2,0x22,0xe2,0x22,0xe2,0x3a,0x04,0x18,0x00,
+/* 12863 0x323f "㈿" */
+0x00,0x30,0x48,0x89,0x88,0xbe,0x89,0x89,0x8f,0x8a,0x8a,0x8c,0x89,0x40,0x30,0x00,
+0x00,0x18,0x84,0xf2,0x92,0x92,0x22,0x22,0xfa,0xaa,0xaa,0xca,0x12,0x04,0x18,0x00,
+/* 12864 0x3240 "㉀" */
+0x00,0x30,0x48,0x8f,0x92,0xaa,0x94,0x8b,0x90,0xaf,0x84,0x8a,0xb1,0x40,0x30,0x00,
+0x00,0x18,0xfc,0x92,0xa2,0x42,0x22,0xd2,0x0a,0xf2,0xa2,0x92,0x0a,0x04,0x18,0x00,
+/* 12865 0x3241 "㉁" */
+0x00,0x30,0x44,0x84,0x88,0x8f,0x98,0xa8,0x88,0x89,0x8a,0x8c,0x88,0x40,0x30,0x00,
+0x00,0x18,0x44,0x42,0x42,0xfa,0x42,0xe2,0xe2,0x52,0x4a,0x42,0x42,0x04,0x18,0x00,
+/* 12866 0x3242 "㉂" */
+0x00,0x30,0x42,0x84,0x8f,0x88,0x88,0x8f,0x88,0x8f,0x88,0x88,0x8f,0x40,0x30,0x00,
+0x00,0x18,0x04,0x02,0xe2,0x22,0x22,0xe2,0x22,0xe2,0x22,0x22,0xe2,0x04,0x18,0x00,
+/* 12867 0x3243 "㉃" */
+0x00,0x30,0x5f,0x82,0x84,0x88,0x9f,0x81,0x81,0x8f,0x81,0x81,0xbf,0x40,0x30,0x00,
+0x00,0x18,0xf4,0x02,0x42,0x22,0xf2,0x02,0x02,0xe2,0x02,0x02,0xf2,0x04,0x18,0x00,
+/* 12868 0x3244 "㉄" */
+0x00,0x3f,0x40,0xbe,0xa2,0xbe,0xa2,0xbe,0xa0,0xa7,0xa4,0xa4,0xa7,0xa0,0x40,0x3f,
+0x00,0xf8,0x04,0xfa,0x8a,0xfa,0x8a,0xfa,0x0a,0xca,0x4a,0x4a,0xca,0x1a,0x04,0xf8,
+/* 12869 0x3245 "㉅" */
+0x00,0x3f,0x40,0x84,0x84,0x88,0x93,0xbe,0x84,0x88,0x92,0xbd,0x90,0x81,0x40,0x3f,
+0x00,0xf8,0x04,0x42,0x42,0x42,0xfa,0x4a,0x4a,0x4a,0x4a,0x4a,0xaa,0x12,0x04,0xf8,
+/* 12870 0x3246 "㉆" */
+0x00,0x3f,0x40,0x82,0x81,0xbf,0x84,0x84,0x84,0x82,0x82,0x81,0x86,0xb8,0x40,0x3f,
+0x00,0xf8,0x04,0x02,0x02,0xfa,0x42,0x42,0x42,0x82,0x82,0x02,0xc2,0x3a,0x04,0xf8,
+/* 12871 0x3247 "㉇" */
+0x00,0x3f,0x40,0x9e,0xa5,0x9f,0x89,0x9f,0x81,0xbf,0x81,0x9f,0x81,0x83,0x40,0x3f,
+0x00,0xf8,0x04,0xf2,0x22,0xe2,0x42,0xe2,0x22,0xfa,0x22,0xe2,0x02,0x02,0x04,0xf8,
+/* 12872 0x3248 "㉈" */
+0x00,0xfc,0xe0,0xc0,0x88,0x98,0x08,0x08,0x08,0x88,0x88,0xbe,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12873 0x3249 "㉉" */
+0x00,0xfc,0xe0,0xc0,0x9c,0xa2,0x02,0x02,0x1c,0xa0,0xa0,0xbe,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12874 0x324a "㉊" */
+0x00,0xfc,0xe0,0xc0,0x9c,0xa2,0x02,0x0c,0x02,0x82,0xa2,0x9c,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12875 0x324b "㉋" */
+0x00,0xfc,0xe0,0xc0,0xa4,0xa4,0x24,0x3e,0x04,0x84,0x84,0x84,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12876 0x324c "㉌" */
+0x00,0xfc,0xe0,0xc0,0xbe,0xa0,0x20,0x1c,0x02,0x82,0xa2,0x9c,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12877 0x324d "㉍" */
+0x00,0xfc,0xe0,0xc0,0x9c,0xa2,0x20,0x3c,0x22,0xa2,0xa2,0x9c,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12878 0x324e "㉎" */
+0x00,0xfc,0xe0,0xc0,0xbe,0xa2,0x02,0x04,0x04,0x88,0x88,0x88,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12879 0x324f "㉏" */
+0x00,0xfc,0xe0,0xc0,0x9c,0xa2,0x22,0x1c,0x22,0xa2,0xa2,0x9c,0xc0,0xe0,0xfc,0x00,
+0x00,0x7e,0x0e,0x06,0x72,0x8a,0x88,0x88,0x88,0x8a,0x8a,0x72,0x06,0x0e,0x7e,0x00,
+/* 12880 0x3250 "㉐" */
+0x00,0x00,0x00,0x00,0x77,0x49,0x49,0x49,0x71,0x41,0x41,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0xde,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x1e,0x00,0x00,
+/* 12881 0x3251 "㉑" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x22,0x62,0x22,0x22,0x22,0x22,0x22,0xfa,0x04,0x08,0xf0,0x00,
+/* 12882 0x3252 "㉒" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x0a,0x0a,0x72,0x82,0x82,0xfa,0x04,0x08,0xf0,0x00,
+/* 12883 0x3253 "㉓" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x0a,0x32,0x0a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12884 0x3254 "㉔" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x92,0x92,0x92,0xfa,0x12,0x12,0x12,0x12,0x04,0x08,0xf0,0x00,
+/* 12885 0x3255 "㉕" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x82,0x82,0x72,0x0a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12886 0x3256 "㉖" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x82,0xf2,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12887 0x3257 "㉗" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x8a,0x0a,0x12,0x12,0x22,0x22,0x22,0x04,0x08,0xf0,0x00,
+/* 12888 0x3258 "㉘" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x72,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12889 0x3259 "㉙" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x82,0x9c,0xa0,0xa0,0xbe,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x8a,0x7a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12890 0x325a "㉚" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12891 0x325b "㉛" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x22,0x62,0x22,0x22,0x22,0x22,0x22,0xfa,0x04,0x08,0xf0,0x00,
+/* 12892 0x325c "㉜" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x0a,0x0a,0x72,0x82,0x82,0xfa,0x04,0x08,0xf0,0x00,
+/* 12893 0x325d "㉝" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x0a,0x32,0x0a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12894 0x325e "㉞" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x92,0x92,0x92,0xfa,0x12,0x12,0x12,0x12,0x04,0x08,0xf0,0x00,
+/* 12895 0x325f "㉟" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x82,0x82,0x72,0x0a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12896 0x3260 "㉠" */
+0x00,0x0f,0x10,0x20,0x4f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x04,0x08,0xf0,0x00,
+/* 12897 0x3261 "㉡" */
+0x00,0x0f,0x10,0x20,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xf2,0x04,0x08,0xf0,0x00,
+/* 12898 0x3262 "㉢" */
+0x00,0x0f,0x10,0x20,0x4f,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x02,0x02,0x02,0x02,0x02,0x02,0xf2,0x04,0x08,0xf0,0x00,
+/* 12899 0x3263 "㉣" */
+0x00,0x0f,0x10,0x20,0x4f,0x40,0x40,0x4f,0x48,0x48,0x48,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x12,0x12,0xf2,0x02,0x02,0x02,0xf2,0x04,0x08,0xf0,0x00,
+/* 12900 0x3264 "㉤" */
+0x00,0x0f,0x10,0x20,0x4f,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0xf2,0x04,0x08,0xf0,0x00,
+/* 12901 0x3265 "㉥" */
+0x00,0x0f,0x10,0x20,0x48,0x48,0x48,0x4f,0x48,0x48,0x48,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0x12,0x12,0x12,0xf2,0x12,0x12,0x12,0xf2,0x04,0x08,0xf0,0x00,
+/* 12902 0x3266 "㉦" */
+0x00,0x0f,0x10,0x20,0x40,0x40,0x40,0x41,0x41,0x42,0x44,0x48,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x84,0x82,0x82,0x82,0x42,0x42,0x22,0x12,0x0a,0x04,0x08,0xf0,0x00,
+/* 12903 0x3267 "㉧" */
+0x00,0x0f,0x10,0x20,0x43,0x44,0x48,0x48,0x48,0x48,0x44,0x43,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xc2,0x22,0x12,0x12,0x12,0x12,0x22,0xc2,0x04,0x08,0xf0,0x00,
+/* 12904 0x3268 "㉨" */
+0x00,0x0f,0x10,0x20,0x4f,0x40,0x40,0x41,0x41,0x42,0x44,0x48,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x82,0x82,0x42,0x42,0x22,0x12,0x0a,0x04,0x08,0xf0,0x00,
+/* 12905 0x3269 "㉩" */
+0x00,0x0f,0x10,0x20,0x43,0x40,0x4f,0x40,0x41,0x42,0x44,0x48,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xe2,0x02,0xfa,0x82,0x42,0x22,0x12,0x0a,0x04,0x08,0xf0,0x00,
+/* 12906 0x326a "㉪" */
+0x00,0x0f,0x10,0x20,0x4f,0x40,0x40,0x4f,0x40,0x40,0x40,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x12,0x12,0xf2,0x12,0x12,0x12,0x12,0x04,0x08,0xf0,0x00,
+/* 12907 0x326b "㉫" */
+0x00,0x0f,0x10,0x20,0x4f,0x48,0x48,0x4f,0x48,0x48,0x48,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x02,0x02,0xf2,0x02,0x02,0x02,0xf2,0x04,0x08,0xf0,0x00,
+/* 12908 0x326c "㉬" */
+0x00,0x0f,0x10,0x20,0x4f,0x42,0x42,0x42,0x42,0x42,0x42,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x42,0x42,0x42,0x42,0x42,0x42,0xf2,0x04,0x08,0xf0,0x00,
+/* 12909 0x326d "㉭" */
+0x00,0x0f,0x10,0x20,0x43,0x40,0x4f,0x40,0x43,0x44,0x44,0x43,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0xc2,0x02,0xf2,0x02,0xc2,0x22,0x22,0xc2,0x04,0x08,0xf0,0x00,
+/* 12910 0x326e "㉮" */
+0x00,0x0f,0x10,0x20,0x4f,0x41,0x41,0x42,0x42,0x44,0x48,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12911 0x326f "㉯" */
+0x00,0x0f,0x10,0x20,0x48,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0xa2,0x22,0x24,0x08,0xf0,0x00,
+/* 12912 0x3270 "㉰" */
+0x00,0x0f,0x10,0x20,0x4f,0x48,0x48,0x48,0x48,0x48,0x4f,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12913 0x3271 "㉱" */
+0x00,0x0f,0x10,0x20,0x4f,0x41,0x41,0x4f,0x48,0x48,0x4f,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12914 0x3272 "㉲" */
+0x00,0x0f,0x10,0x20,0x4f,0x49,0x49,0x49,0x49,0x49,0x4f,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12915 0x3273 "㉳" */
+0x00,0x0f,0x10,0x20,0x49,0x49,0x4f,0x49,0x49,0x49,0x4f,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12916 0x3274 "㉴" */
+0x00,0x0f,0x10,0x20,0x42,0x42,0x42,0x45,0x45,0x48,0x48,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0xa2,0xa2,0x22,0x24,0x08,0xf0,0x00,
+/* 12917 0x3275 "㉵" */
+0x00,0x0f,0x10,0x20,0x46,0x49,0x49,0x49,0x49,0x49,0x46,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12918 0x3276 "㉶" */
+0x00,0x0f,0x10,0x20,0x4f,0x42,0x42,0x45,0x45,0x48,0x48,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0xa2,0x22,0x22,0x3a,0x22,0xa2,0xa2,0x22,0x24,0x08,0xf0,0x00,
+/* 12919 0x3277 "㉷" */
+0x00,0x0f,0x10,0x27,0x40,0x4f,0x42,0x42,0x45,0x45,0x48,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0xa2,0x22,0x3a,0x22,0x22,0xa2,0x22,0x24,0x08,0xf0,0x00,
+/* 12920 0x3278 "㉸" */
+0x00,0x0f,0x10,0x20,0x4f,0x41,0x41,0x4e,0x42,0x44,0x48,0x60,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12921 0x3279 "㉹" */
+0x00,0x0f,0x10,0x20,0x4f,0x48,0x48,0x4f,0x48,0x48,0x4f,0x60,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0x22,0x22,0x3a,0x22,0x22,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12922 0x327a "㉺" */
+0x00,0x0f,0x10,0x20,0x5f,0x49,0x49,0x49,0x49,0x49,0x5f,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0xa2,0x22,0x22,0x3a,0x22,0x22,0xa2,0x22,0x24,0x08,0xf0,0x00,
+/* 12923 0x327b "㉻" */
+0x00,0x0f,0x10,0x27,0x40,0x4f,0x40,0x47,0x48,0x48,0x47,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x24,0x22,0xa2,0x22,0x3a,0xa2,0xa2,0x22,0x22,0x24,0x08,0xf0,0x00,
+/* 12924 0x327c "㉼" */
+0x00,0x0f,0x10,0x20,0x49,0x5d,0x49,0x55,0x40,0x4f,0x49,0x4f,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0x7a,0x8a,0x0a,0x0a,0x2a,0x22,0x22,0x7a,0x04,0x08,0xf0,0x00,
+/* 12925 0x327d "㉽" */
+0x00,0x0f,0x10,0x20,0x5f,0x44,0x4a,0x51,0x40,0x5f,0x44,0x44,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0x4a,0xaa,0xaa,0x4a,0x0a,0x0a,0xea,0x0a,0x04,0x08,0xf0,0x00,
+/* 12926 0x327e "㉾" */
+0x00,0x0f,0x10,0x27,0x48,0x48,0x47,0x40,0x5f,0x41,0x41,0x41,0x21,0x10,0x0f,0x00,
+0x00,0xe0,0x10,0xc8,0x24,0x24,0xc4,0x04,0xf4,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,
+/* 12927 0x327f "㉿" */
+0x00,0x0f,0x10,0x20,0x40,0x44,0x44,0x75,0x07,0x44,0x44,0x40,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0x42,0x82,0x00,0x1e,0x82,0x42,0x02,0x04,0x08,0xf0,0x00,
+/* 12928 0x3280 "㊀" */
+0x00,0x1f,0x20,0x40,0x80,0x80,0x80,0xbf,0x80,0x80,0x80,0x80,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0x02,0x12,0xfa,0x02,0x02,0x02,0x02,0x04,0x08,0xf0,0x00,
+/* 12929 0x3281 "㊁" */
+0x00,0x1f,0x20,0x40,0x9f,0x80,0x80,0x80,0x80,0x80,0xbf,0x80,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x24,0xf2,0x02,0x02,0x02,0x02,0x12,0xfa,0x02,0x04,0x08,0xf0,0x00,
+/* 12930 0x3282 "㊂" */
+0x00,0x1f,0x20,0x40,0x9f,0x80,0x80,0x8f,0x80,0x80,0xbf,0x80,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x24,0xf2,0x02,0x42,0xe2,0x02,0x12,0xfa,0x02,0x04,0x08,0xf0,0x00,
+/* 12931 0x3283 "㊃" */
+0x00,0x1f,0x20,0x5f,0x92,0x92,0x92,0x92,0x94,0x98,0x90,0x9f,0x50,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xf4,0x92,0x92,0x92,0x92,0xf2,0x12,0x12,0xf2,0x14,0x08,0xf0,0x00,
+/* 12932 0x3284 "㊄" */
+0x00,0x1f,0x20,0x40,0x9f,0x81,0x81,0x8f,0x82,0x82,0x82,0x82,0x7f,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xf2,0x02,0x02,0xe2,0x22,0x22,0x22,0x22,0xfc,0x08,0xf0,0x00,
+/* 12933 0x3285 "㊅" */
+0x00,0x1f,0x22,0x41,0x80,0xbf,0x80,0x84,0x84,0x88,0x90,0xa0,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0xfa,0x02,0x42,0x22,0x12,0x0a,0x0a,0x04,0x08,0xf0,0x00,
+/* 12934 0x3286 "㊆" */
+0x00,0x0f,0x10,0x22,0x42,0x42,0x43,0x5e,0x42,0x42,0x42,0x42,0x21,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0x32,0xc2,0x02,0x02,0x02,0x12,0x12,0xf4,0x08,0xf0,0x00,
+/* 12935 0x3287 "㊇" */
+0x00,0x1f,0x20,0x40,0x84,0x84,0x84,0x84,0x88,0x88,0x90,0xa0,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x84,0x82,0x82,0x42,0x42,0x22,0x22,0x12,0x0a,0x04,0x08,0xf0,0x00,
+/* 12936 0x3288 "㊈" */
+0x00,0x1f,0x22,0x42,0x82,0x9f,0x82,0x82,0x82,0x84,0x84,0x88,0x50,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0xc2,0x42,0x42,0x42,0x42,0x4a,0x4a,0x3c,0x08,0xf0,0x00,
+/* 12937 0x3289 "㊉" */
+0x00,0x0f,0x10,0x21,0x41,0x41,0x5f,0x41,0x41,0x41,0x41,0x41,0x20,0x10,0x0f,0x00,
+0x00,0xe0,0x10,0x08,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,
+/* 12938 0x328a "㊊" */
+0x00,0x1f,0x20,0x47,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x84,0x48,0x30,0x1f,0x00,
+0x00,0xf0,0x08,0xf4,0x12,0x12,0xf2,0x12,0x12,0xf2,0x12,0x12,0x54,0x28,0xf0,0x00,
+/* 12939 0x328b "㊋" */
+0x00,0x1f,0x20,0x41,0x89,0x89,0x89,0x91,0x82,0x82,0x84,0x88,0x70,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x12,0x22,0x42,0x02,0x82,0x82,0x42,0x22,0x1c,0x08,0xf0,0x00,
+/* 12940 0x328c "㊌" */
+0x00,0x1f,0x21,0x41,0x81,0xbd,0x85,0x85,0x89,0x89,0x91,0xa5,0x42,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x12,0xa2,0x42,0x42,0x22,0x22,0x12,0x0a,0x04,0x08,0xf0,0x00,
+/* 12941 0x328d "㊍" */
+0x00,0x1f,0x21,0x41,0x81,0xbf,0x81,0x83,0x85,0x89,0xb1,0x81,0x41,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0xfa,0x02,0x82,0x42,0x22,0x1a,0x12,0x04,0x08,0xf0,0x00,
+/* 12942 0x328e "㊎" */
+0x00,0x1f,0x21,0x42,0x84,0x88,0xb7,0x81,0x9f,0x81,0x89,0x85,0x7f,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x84,0x42,0x22,0xda,0x02,0xf2,0x02,0x22,0x42,0xfc,0x08,0xf0,0x00,
+/* 12943 0x328f "㊏" */
+0x00,0x1f,0x21,0x41,0x81,0x81,0x9f,0x81,0x81,0x81,0x81,0x81,0x7f,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0x02,0xf2,0x02,0x02,0x02,0x02,0x02,0xfc,0x08,0xf0,0x00,
+/* 12944 0x3290 "㊐" */
+0x00,0x07,0x08,0x17,0x24,0x24,0x24,0x27,0x24,0x24,0x24,0x27,0x14,0x08,0x07,0x00,
+0x00,0xf0,0x08,0xf4,0x12,0x12,0x12,0xf2,0x12,0x12,0x12,0xf2,0x14,0x08,0xf0,0x00,
+/* 12945 0x3291 "㊑" */
+0x00,0x1f,0x28,0x49,0xbd,0x8a,0x9c,0x9b,0xa8,0xa8,0x89,0x8a,0x48,0x20,0x1f,0x00,
+0x00,0xf0,0x48,0x44,0xf2,0x42,0x42,0xfa,0x42,0xe2,0x52,0x4a,0x44,0x08,0xf0,0x00,
+/* 12946 0x3292 "㊒" */
+0x00,0x1f,0x22,0x7f,0x84,0x87,0x8c,0x97,0xa4,0x87,0x84,0x84,0x44,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xfc,0x02,0xe2,0x22,0xe2,0x22,0xe2,0x22,0x22,0x64,0x08,0xf0,0x00,
+/* 12947 0x3293 "㊓" */
+0x00,0x1f,0x30,0x48,0xbe,0x84,0x89,0x8c,0x9a,0xa8,0x88,0x88,0x4b,0x20,0x1f,0x00,
+0x00,0xf0,0x48,0x44,0x42,0x42,0xf2,0x42,0x42,0x42,0x42,0x42,0xfc,0x08,0xf0,0x00,
+/* 12948 0x3294 "㊔" */
+0x00,0x1f,0x24,0x47,0x84,0x8a,0x91,0x81,0x87,0xbc,0x84,0x84,0x47,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xf4,0x22,0x42,0x82,0x02,0xf2,0x12,0x12,0x12,0xf4,0x08,0xf0,0x00,
+/* 12949 0x3295 "㊕" */
+0x00,0x1f,0x28,0x69,0xbc,0xa8,0xab,0x8c,0x9b,0xa9,0x88,0x88,0x48,0x20,0x1f,0x00,
+0x00,0xf0,0x48,0xf4,0x42,0x42,0xfa,0x22,0xfa,0x22,0xa2,0x22,0xe4,0x08,0xf0,0x00,
+/* 12950 0x3296 "㊖" */
+0x00,0x1f,0x20,0x5e,0x93,0x9e,0x92,0x9e,0x92,0x9f,0x80,0x92,0x61,0x20,0x1f,0x00,
+0x00,0xf0,0x18,0x14,0xfa,0x12,0x32,0x52,0x92,0x12,0x12,0x52,0x24,0x08,0xf0,0x00,
+/* 12951 0x3297 "㊗" */
+0x00,0x1f,0x20,0x51,0x89,0xbf,0x83,0x85,0x8c,0x9a,0xaa,0x89,0x4a,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xf4,0x12,0x12,0x12,0xf2,0xa2,0xa2,0xaa,0x2a,0x1c,0x08,0xf0,0x00,
+/* 12952 0x3298 "㊘" */
+0x00,0x1f,0x32,0x49,0x89,0x9f,0x91,0xa1,0x9f,0x81,0x82,0x84,0x58,0x20,0x1f,0x00,
+0x00,0xf0,0x18,0x14,0x22,0xfa,0x0a,0x02,0xf2,0x12,0x12,0x12,0x64,0x08,0xf0,0x00,
+/* 12953 0x3299 "㊙" */
+0x00,0x1f,0x24,0x78,0x88,0xbe,0x88,0x8d,0x9a,0xaa,0x88,0x89,0x4e,0x20,0x1f,0x00,
+0x00,0xf0,0x88,0x54,0x92,0x92,0xa2,0xa2,0xaa,0xca,0x92,0x92,0x74,0x08,0xf0,0x00,
+/* 12954 0x329a "㊚" */
+0x00,0x0f,0x10,0x3f,0x49,0x4f,0x49,0x4f,0x41,0x5f,0x41,0x42,0x24,0x18,0x0f,0x00,
+0x00,0xf0,0x08,0xfc,0x12,0xf2,0x12,0xf2,0x02,0xfa,0x0a,0x0a,0x4c,0x38,0xf0,0x00,
+/* 12955 0x329b "㊛" */
+0x00,0x1f,0x22,0x42,0x82,0xbf,0x84,0x84,0x88,0x8e,0x81,0x82,0x5c,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0xfa,0x42,0x42,0x42,0x82,0x82,0x62,0x14,0x08,0xf0,0x00,
+/* 12956 0x329c "㊜" */
+0x00,0x1f,0x30,0x4b,0x88,0x83,0xba,0x8b,0x8a,0x8a,0x8a,0x94,0x63,0x20,0x1f,0x00,
+0x00,0xf0,0x48,0xfc,0xa2,0xfa,0x4a,0xfa,0xaa,0xea,0x1a,0x02,0xfc,0x08,0xf0,0x00,
+/* 12957 0x329d "㊝" */
+0x00,0x1f,0x2b,0x49,0x89,0x89,0x9b,0xac,0x8b,0x8d,0x89,0x88,0x4f,0x20,0x1f,0x00,
+0x00,0xf0,0xf8,0x14,0xf2,0x12,0xfa,0x8a,0x52,0xea,0x22,0xc2,0x3c,0x08,0xf0,0x00,
+/* 12958 0x329e "㊞" */
+0x00,0x0f,0x12,0x3c,0x50,0x50,0x5e,0x50,0x50,0x52,0x5c,0x50,0x20,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0xfc,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0xb2,0x82,0x84,0x08,0xf0,0x00,
+/* 12959 0x329f "㊟" */
+0x00,0x1f,0x30,0x48,0xa3,0x94,0x84,0x88,0x89,0xb0,0x90,0x90,0x53,0x20,0x1f,0x00,
+0x00,0xf0,0x88,0x44,0xfa,0x42,0x42,0x42,0xf2,0x42,0x42,0x42,0xfc,0x08,0xf0,0x00,
+/* 12960 0x32a0 "㊠" */
+0x00,0x1f,0x20,0x41,0xbe,0x89,0x89,0x89,0x89,0x8f,0xb1,0x81,0x40,0x23,0x1f,0x00,
+0x00,0xf8,0x04,0xfa,0x41,0xf9,0x09,0xf9,0x09,0xf9,0x09,0xf9,0x92,0x0c,0xf8,0x00,
+/* 12961 0x32a1 "㊡" */
+0x00,0x1f,0x24,0x44,0x88,0x8f,0x98,0xa8,0x88,0x89,0x8a,0x8c,0x48,0x20,0x1f,0x00,
+0x00,0xf0,0x48,0x44,0x42,0xfa,0x42,0xe2,0xe2,0x52,0x4a,0x42,0x44,0x08,0xf0,0x00,
+/* 12962 0x32a2 "㊢" */
+0x00,0x1f,0x20,0x5f,0x90,0xa4,0x87,0x84,0x87,0x80,0x9f,0x80,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xfc,0x0a,0x12,0xe2,0x02,0xf2,0x12,0xd2,0x12,0xa4,0x48,0xf0,0x00,
+/* 12963 0x32a3 "㊣" */
+0x00,0x1f,0x20,0x40,0x80,0x9f,0x81,0x81,0x89,0x89,0x89,0x9f,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0xf2,0x02,0x02,0xe2,0x02,0x02,0xf2,0x04,0x08,0xf0,0x00,
+/* 12964 0x32a4 "㊤" */
+0x00,0x1f,0x21,0x41,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x7f,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x02,0x02,0xf2,0x02,0x02,0x02,0x02,0x02,0xfc,0x08,0xf0,0x00,
+/* 12965 0x32a5 "㊥" */
+0x00,0x07,0x08,0x10,0x2f,0x28,0x28,0x28,0x2f,0x28,0x20,0x20,0x10,0x08,0x07,0x00,
+0x00,0xf0,0x88,0x84,0xfa,0x8a,0x8a,0x8a,0xfa,0x8a,0x82,0x82,0x84,0x08,0xf0,0x00,
+/* 12966 0x32a6 "㊦" */
+0x00,0x1f,0x20,0x7f,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x41,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xfc,0x02,0x02,0x82,0x42,0x22,0x22,0x02,0x02,0x04,0x08,0xf0,0x00,
+/* 12967 0x32a7 "㊧" */
+0x00,0x1f,0x22,0x42,0xbf,0x82,0x84,0x87,0x88,0x88,0x90,0xa0,0x4f,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x02,0x02,0xf2,0x82,0x82,0x82,0x82,0xfc,0x08,0xf0,0x00,
+/* 12968 0x32a8 "㊨" */
+0x00,0x1f,0x21,0x41,0xbf,0x82,0x84,0x87,0x8c,0x94,0xa4,0x87,0x44,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x02,0x02,0xe2,0x22,0x22,0x22,0xe2,0x24,0x08,0xf0,0x00,
+/* 12969 0x32a9 "㊩" */
+0x00,0x0f,0x10,0x3f,0x52,0x53,0x54,0x5f,0x50,0x51,0x52,0x54,0x3f,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0xfc,0x02,0xf2,0x82,0xfa,0x82,0x42,0x22,0x12,0xfc,0x08,0xf0,0x00,
+/* 12970 0x32aa "㊪" */
+0x00,0x1f,0x20,0x40,0x9f,0x90,0xa7,0x80,0x9f,0x80,0x88,0x88,0x52,0x21,0x1f,0x00,
+0x00,0xf0,0x08,0x84,0xfa,0x0a,0xe2,0x02,0xfa,0x82,0xa2,0x92,0x94,0x08,0xf0,0x00,
+/* 12971 0x32ab "㊫" */
+0x00,0x0f,0x19,0x24,0x5f,0x50,0x47,0x40,0x40,0x5f,0x40,0x40,0x23,0x10,0x0f,0x00,
+0x00,0xf0,0x18,0xa4,0xfa,0x0a,0xe2,0x42,0x82,0xfa,0x82,0x82,0x84,0x08,0xf0,0x00,
+/* 12972 0x32ac "㊬" */
+0x00,0x1f,0x3e,0x68,0xbe,0xa2,0xbe,0xa8,0xbf,0x80,0x9f,0x92,0x7f,0x20,0x1f,0x00,
+0x00,0xf0,0x48,0x44,0x7a,0x82,0xa2,0x12,0x02,0x02,0xf2,0x92,0xfc,0x08,0xf0,0x00,
+/* 12973 0x32ad "㊭" */
+0x00,0x1f,0x21,0x41,0x82,0x84,0x88,0xb0,0x84,0x84,0x84,0x84,0x5f,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x84,0x42,0x22,0x9a,0x82,0xe2,0x82,0x82,0x82,0xfc,0x08,0xf0,0x00,
+/* 12974 0x32ae "㊮" */
+0x00,0x0f,0x11,0x2b,0x44,0x5f,0x4c,0x47,0x44,0x47,0x44,0x47,0x3c,0x10,0x0f,0x00,
+0x00,0xf0,0x08,0xfc,0x4a,0xe2,0x3a,0xe2,0x22,0xe2,0x22,0xe2,0x3c,0x08,0xf0,0x00,
+/* 12975 0x32af "㊯" */
+0x00,0x0f,0x18,0x29,0x48,0x7e,0x49,0x49,0x4f,0x4a,0x4a,0x4c,0x29,0x10,0x0f,0x00,
+0x00,0xf0,0x88,0xf4,0x92,0x92,0x22,0x22,0xfa,0xaa,0xaa,0xca,0x14,0x08,0xf0,0x00,
+/* 12976 0x32b0 "㊰" */
+0x00,0x1f,0x21,0x7f,0x84,0x84,0x89,0x9a,0xad,0x88,0x88,0x88,0x4b,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0xfc,0x82,0xf2,0x92,0x52,0x22,0xa2,0x42,0xa2,0x1c,0x08,0xf0,0x00,
+/* 12977 0x32b1 "㊱" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x82,0xf2,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12978 0x32b2 "㊲" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x8a,0x0a,0x12,0x12,0x22,0x22,0x22,0x04,0x08,0xf0,0x00,
+/* 12979 0x32b3 "㊳" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x72,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12980 0x32b4 "㊴" */
+0x00,0x1f,0x20,0x40,0x9c,0xa2,0x82,0x8c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x8a,0x7a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12981 0x32b5 "㊵" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12982 0x32b6 "㊶" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x22,0x62,0x22,0x22,0x22,0x22,0x22,0xfa,0x04,0x08,0xf0,0x00,
+/* 12983 0x32b7 "㊷" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x0a,0x0a,0x72,0x82,0x82,0xfa,0x04,0x08,0xf0,0x00,
+/* 12984 0x32b8 "㊸" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x0a,0x32,0x0a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12985 0x32b9 "㊹" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x92,0x92,0x92,0xfa,0x12,0x12,0x12,0x12,0x04,0x08,0xf0,0x00,
+/* 12986 0x32ba "㊺" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x82,0x82,0x72,0x0a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12987 0x32bb "㊻" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x82,0xf2,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12988 0x32bc "㊼" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0xfa,0x8a,0x0a,0x12,0x12,0x22,0x22,0x22,0x04,0x08,0xf0,0x00,
+/* 12989 0x32bd "㊽" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x72,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12990 0x32be "㊾" */
+0x00,0x1f,0x20,0x40,0xa4,0xa4,0xa4,0xbe,0x84,0x84,0x84,0x84,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x8a,0x7a,0x0a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12991 0x32bf "㊿" */
+0x00,0x1f,0x20,0x40,0xbe,0xa0,0xa0,0x9c,0x82,0x82,0xa2,0x9c,0x40,0x20,0x1f,0x00,
+0x00,0xf0,0x08,0x04,0x72,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0x72,0x04,0x08,0xf0,0x00,
+/* 12992 0x32c0 "㋀" */
+0x00,0x10,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12993 0x32c1 "㋁" */
+0x00,0x00,0x18,0x24,0x24,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x3c,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12994 0x32c2 "㋂" */
+0x00,0x00,0x18,0x24,0x24,0x04,0x04,0x04,0x18,0x04,0x04,0x04,0x04,0x24,0x24,0x18,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12995 0x32c3 "㋃" */
+0x00,0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12996 0x32c4 "㋄" */
+0x00,0x00,0x3c,0x20,0x20,0x20,0x20,0x20,0x38,0x04,0x04,0x04,0x04,0x24,0x24,0x18,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12997 0x32c5 "㋅" */
+0x00,0x00,0x18,0x24,0x24,0x20,0x20,0x20,0x38,0x24,0x24,0x24,0x24,0x24,0x24,0x18,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12998 0x32c6 "㋆" */
+0x00,0x00,0x3c,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 12999 0x32c7 "㋇" */
+0x00,0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x18,0x24,0x24,0x24,0x24,0x24,0x24,0x18,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 13000 0x32c8 "㋈" */
+0x00,0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x18,0x04,0x04,0x04,0x04,0x24,0x24,0x18,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x94,0x88,
+/* 13001 0x32c9 "㋉" */
+0x00,0x00,0x23,0x64,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x73,
+0x00,0x3e,0x22,0xa2,0xa2,0xbe,0xa2,0xa2,0xa2,0xbe,0xa2,0xa2,0xa2,0xa2,0xca,0x44,
+/* 13002 0x32ca "㋊" */
+0x00,0x00,0x22,0x66,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x77,
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x4a,0x44,
+/* 13003 0x32cb "㋋" */
+0x00,0x00,0x23,0x64,0x24,0x20,0x20,0x21,0x21,0x21,0x22,0x22,0x22,0x24,0x24,0x77,
+0x00,0x3e,0x22,0xa2,0xa2,0xbe,0xa2,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x4a,0xc4,
+/* 13004 0x32cc "㋌" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x74,0x88,0x88,0x88,0x70,0x40,0x78,0x84,0x84,0x78,
+/* 13005 0x32cd "㋍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x65,0x96,0x94,0xf4,0x84,0x84,0x94,0x64,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x1a,0xa4,0xa4,0x24,0x18,0x10,0x1c,0x22,0x22,0x1c,
+/* 13006 0x32ce "㋎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+/* 13007 0x32cf "㋏" */
+0x00,0x00,0x00,0x00,0x4f,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7a,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb8,0x24,0x22,0x22,0x22,0x22,0x22,0x22,0x24,0x38,0x00,0x00,
+/* 13008 0x32d0 "㋐" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x41,0x41,0x41,0x22,0x24,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x44,0x84,0x04,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13009 0x32d1 "㋑" */
+0x00,0x03,0x0c,0x10,0x20,0x20,0x41,0x43,0x45,0x49,0x21,0x21,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x48,0x88,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13010 0x32d2 "㋒" */
+0x00,0x03,0x0c,0x11,0x21,0x2f,0x48,0x48,0x40,0x40,0x20,0x20,0x11,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x24,0x44,0x48,0x88,0x10,0x60,0x80,0x00,
+/* 13011 0x32d3 "㋓" */
+0x00,0x03,0x0c,0x10,0x20,0x20,0x47,0x41,0x41,0x41,0x2f,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0xc4,0x04,0x04,0x04,0xe8,0x08,0x10,0x60,0x80,0x00,
+/* 13012 0x32d4 "㋔" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x41,0x42,0x44,0x48,0x22,0x21,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x88,0xe8,0x84,0x84,0x84,0x84,0x88,0x88,0x10,0x60,0x80,0x00,
+/* 13013 0x32d5 "㋕" */
+0x00,0x03,0x0c,0x11,0x21,0x2f,0x41,0x42,0x44,0x48,0x22,0x21,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x44,0x44,0x88,0x08,0x10,0x60,0x80,0x00,
+/* 13014 0x32d6 "㋖" */
+0x00,0x03,0x0c,0x10,0x22,0x23,0x4f,0x41,0x41,0x4f,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xc8,0x04,0x04,0xf4,0xc4,0x48,0x48,0x10,0x60,0x80,0x00,
+/* 13015 0x32d7 "㋗" */
+0x00,0x03,0x0c,0x10,0x22,0x23,0x42,0x44,0x48,0x40,0x20,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x44,0x44,0x88,0x08,0x10,0x60,0x80,0x00,
+/* 13016 0x32d8 "㋘" */
+0x00,0x03,0x0c,0x10,0x24,0x27,0x44,0x48,0x50,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x84,0x84,0x84,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13017 0x32d9 "㋙" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x40,0x40,0x40,0x2f,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x44,0x44,0xe8,0x08,0x10,0x60,0x80,0x00,
+/* 13018 0x32da "㋚" */
+0x00,0x03,0x0c,0x10,0x22,0x22,0x4f,0x42,0x42,0x42,0x20,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x48,0x48,0xf4,0x44,0x44,0x44,0x88,0x08,0x10,0x60,0x80,0x00,
+/* 13019 0x32db "㋛" */
+0x00,0x03,0x0c,0x10,0x26,0x21,0x4c,0x42,0x40,0x40,0x29,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x24,0x44,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13020 0x32dc "㋜" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x40,0x40,0x41,0x22,0x24,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xc8,0x44,0x44,0x84,0x84,0x48,0x48,0x10,0x60,0x80,0x00,
+/* 13021 0x32dd "㋝" */
+0x00,0x03,0x0c,0x10,0x22,0x2f,0x42,0x42,0x42,0x42,0x22,0x21,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x44,0x84,0x04,0x08,0xe8,0x10,0x60,0x80,0x00,
+/* 13022 0x32de "㋞" */
+0x00,0x03,0x0c,0x10,0x20,0x28,0x44,0x44,0x40,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x28,0x24,0x24,0x44,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13023 0x32df "㋟" */
+0x00,0x03,0x0c,0x10,0x22,0x23,0x42,0x46,0x45,0x48,0x20,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x44,0xc4,0xa8,0x08,0x10,0x60,0x80,0x00,
+/* 13024 0x32e0 "㋠" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x5f,0x40,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0xe8,0x88,0xf4,0x84,0x84,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13025 0x32e1 "㋡" */
+0x00,0x03,0x0c,0x10,0x22,0x29,0x45,0x44,0x40,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x28,0x24,0x24,0x44,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13026 0x32e2 "㋢" */
+0x00,0x03,0x0c,0x10,0x27,0x20,0x4f,0x40,0x40,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0xc8,0x08,0xe4,0x84,0x84,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13027 0x32e3 "㋣" */
+0x00,0x03,0x0c,0x10,0x22,0x22,0x42,0x43,0x42,0x42,0x22,0x22,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x04,0x84,0x44,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13028 0x32e4 "㋤" */
+0x00,0x03,0x0c,0x11,0x20,0x2f,0x40,0x40,0x40,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x88,0xe8,0x84,0x84,0x84,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13029 0x32e5 "㋥" */
+0x00,0x03,0x0c,0x10,0x20,0x21,0x4e,0x40,0x40,0x4f,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x04,0x04,0xf4,0x04,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13030 0x32e6 "㋦" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x46,0x41,0x41,0x22,0x24,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xc8,0x44,0x44,0x84,0x84,0x48,0x48,0x10,0x60,0x80,0x00,
+/* 13031 0x32e7 "㋧" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x40,0x41,0x43,0x25,0x21,0x11,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xc8,0x44,0x84,0x04,0x44,0x28,0x08,0x10,0x60,0x80,0x00,
+/* 13032 0x32e8 "㋨" */
+0x00,0x03,0x0c,0x10,0x20,0x20,0x40,0x40,0x40,0x40,0x21,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x28,0x24,0x24,0x44,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13033 0x32e9 "㋩" */
+0x00,0x03,0x0c,0x10,0x20,0x22,0x42,0x44,0x58,0x40,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x88,0x44,0x24,0x24,0x04,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13034 0x32ea "㋪" */
+0x00,0x03,0x0c,0x10,0x20,0x28,0x49,0x4e,0x48,0x48,0x28,0x27,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x84,0x04,0x04,0x04,0x08,0xc8,0x10,0x60,0x80,0x00,
+/* 13035 0x32eb "㋫" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x40,0x40,0x40,0x20,0x20,0x11,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x24,0x44,0x48,0x88,0x10,0x60,0x80,0x00,
+/* 13036 0x32ec "㋬" */
+0x00,0x03,0x0c,0x10,0x20,0x22,0x45,0x48,0x40,0x40,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x84,0x44,0x24,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13037 0x32ed "㋭" */
+0x00,0x03,0x0c,0x11,0x21,0x2f,0x41,0x45,0x49,0x41,0x25,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x04,0x44,0x24,0x24,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13038 0x32ee "㋮" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x43,0x40,0x40,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x44,0x84,0x44,0x48,0x08,0x10,0x60,0x80,0x00,
+/* 13039 0x32ef "㋯" */
+0x00,0x03,0x0c,0x10,0x23,0x20,0x46,0x41,0x40,0x46,0x21,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xc8,0x04,0x84,0x04,0x04,0xc8,0x18,0x10,0x60,0x80,0x00,
+/* 13040 0x32f0 "㋰" */
+0x00,0x03,0x0c,0x11,0x21,0x21,0x42,0x42,0x44,0x44,0x27,0x28,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x04,0x44,0x24,0xe8,0x28,0x10,0x60,0x80,0x00,
+/* 13041 0x32f1 "㋱" */
+0x00,0x03,0x0c,0x10,0x20,0x20,0x40,0x42,0x41,0x40,0x20,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x28,0x24,0x24,0x44,0xc4,0xa8,0x08,0x10,0x60,0x80,0x00,
+/* 13042 0x32f2 "㋲" */
+0x00,0x03,0x0c,0x10,0x2f,0x22,0x43,0x5e,0x42,0x42,0x22,0x21,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0xc8,0x08,0xc4,0x04,0x04,0x04,0x08,0xe8,0x10,0x60,0x80,0x00,
+/* 13043 0x32f3 "㋳" */
+0x00,0x03,0x0c,0x12,0x22,0x2f,0x42,0x41,0x41,0x41,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x44,0x04,0x04,0x88,0x88,0x90,0x60,0x80,0x00,
+/* 13044 0x32f4 "㋴" */
+0x00,0x03,0x0c,0x10,0x20,0x20,0x47,0x40,0x40,0x40,0x2f,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0xe4,0x24,0x44,0x84,0xe8,0x08,0x10,0x60,0x80,0x00,
+/* 13045 0x32f5 "㋵" */
+0x00,0x03,0x0c,0x10,0x20,0x27,0x40,0x47,0x40,0x40,0x27,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0xe4,0x24,0x24,0xe8,0x08,0x10,0x60,0x80,0x00,
+/* 13046 0x32f6 "㋶" */
+0x00,0x03,0x0c,0x10,0x27,0x20,0x4f,0x40,0x40,0x40,0x20,0x20,0x13,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0xc8,0x08,0xe4,0x24,0x24,0x44,0x48,0x88,0x10,0x60,0x80,0x00,
+/* 13047 0x32f7 "㋷" */
+0x00,0x03,0x0c,0x10,0x22,0x22,0x42,0x42,0x42,0x40,0x20,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x48,0x48,0x44,0x44,0x44,0x44,0x88,0x08,0x10,0x60,0x80,0x00,
+/* 13048 0x32f8 "㋸" */
+0x00,0x03,0x0c,0x10,0x21,0x25,0x45,0x45,0x45,0x45,0x25,0x29,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x14,0x24,0x44,0x88,0x08,0x10,0x60,0x80,0x00,
+/* 13049 0x32f9 "㋹" */
+0x00,0x03,0x0c,0x10,0x24,0x24,0x44,0x44,0x44,0x44,0x25,0x26,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0x08,0x04,0x24,0x44,0x84,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13050 0x32fa "㋺" */
+0x00,0x03,0x0c,0x10,0x20,0x28,0x4f,0x48,0x48,0x49,0x2e,0x28,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x44,0xe4,0x08,0x08,0x10,0x60,0x80,0x00,
+/* 13051 0x32fb "㋻" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x48,0x48,0x40,0x40,0x20,0x20,0x11,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x24,0x24,0x44,0x48,0x88,0x10,0x60,0x80,0x00,
+/* 13052 0x32fc "㋼" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x44,0x44,0x5f,0x40,0x20,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x90,0x88,0xe8,0x84,0x84,0xe4,0x84,0x88,0x88,0x90,0x60,0x80,0x00,
+/* 13053 0x32fd "㋽" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x43,0x40,0x40,0x3f,0x20,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0x44,0x84,0x44,0xf8,0x08,0x10,0x60,0x80,0x00,
+/* 13054 0x32fe "㋾" */
+0x00,0x03,0x0c,0x10,0x20,0x2f,0x40,0x47,0x40,0x40,0x20,0x23,0x10,0x0c,0x03,0x00,
+0x00,0x80,0x60,0x10,0x08,0xe8,0x24,0xe4,0x24,0x44,0x88,0x08,0x10,0x60,0x80,0x00,
+/* 13055 0x32ff "㋿" */
+0x00,0x20,0x50,0x48,0x84,0xbb,0x00,0xfc,0x24,0x25,0x25,0x24,0x2c,0x20,0x20,0x20,
+0x00,0x30,0xc0,0x4e,0x4a,0xfa,0x4a,0xca,0xea,0x5a,0x4a,0x4a,0x4e,0x4a,0x48,0x40,
+/* 13056 0x3300 "㌀" */
+0x7c,0x04,0x15,0x19,0x11,0x12,0x20,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,
+0x04,0x0a,0x4a,0x24,0x20,0x20,0x00,0x00,0x40,0x40,0x40,0x60,0x50,0x40,0x40,0x00,
+/* 13057 0x3301 "㌁" */
+0x3e,0x02,0x0a,0x0c,0x08,0x08,0x10,0x00,0x00,0x3e,0x02,0x02,0x02,0x04,0x18,0x00,
+0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,0x00,0x00,0x7c,0x04,0x18,0x10,0x20,0x00,
+/* 13058 0x3302 "㌂" */
+0x3e,0x02,0x0a,0x0c,0x08,0x08,0x10,0x00,0x01,0x22,0x52,0x09,0x04,0x00,0x00,0x00,
+0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,0x3e,0x82,0x8a,0x0c,0x08,0x08,0x10,0x00,
+/* 13059 0x3303 "㌃" */
+0x3e,0x02,0x0a,0x0c,0x08,0x08,0x10,0x00,0x00,0x08,0x28,0x28,0x2a,0x2a,0x2c,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13060 0x3304 "㌄" */
+0x02,0x04,0x08,0x18,0x28,0x08,0x08,0x00,0x01,0x81,0x41,0x0a,0x30,0xc0,0x01,0x00,
+0x00,0x38,0x00,0x00,0x00,0x7c,0x00,0x00,0x02,0xe9,0x24,0x20,0x20,0x40,0x80,0x00,
+/* 13061 0x3305 "㌅" */
+0x02,0x04,0x08,0x18,0x28,0x08,0x08,0x00,0x04,0x38,0x08,0x3e,0x08,0x08,0x10,0x00,
+0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13062 0x3306 "㌆" */
+0x08,0x3e,0x22,0x22,0x02,0x04,0x08,0x00,0x00,0x20,0x10,0x02,0x0c,0x30,0x00,0x00,
+0x00,0x00,0x08,0x7c,0x18,0x28,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13063 0x3307 "㌇" */
+0x00,0x7c,0x10,0x10,0x10,0x10,0x7c,0x00,0x40,0x78,0x48,0x8b,0x08,0x10,0x60,0x00,
+0x00,0xf8,0x08,0x10,0x20,0x50,0x88,0x00,0x22,0x29,0x24,0xb0,0x28,0x20,0x20,0x00,
+/* 13064 0x3308 "㌈" */
+0x00,0x3e,0x08,0x08,0x08,0x08,0x3e,0x00,0x10,0x3e,0x12,0x12,0x12,0x12,0x24,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,
+/* 13065 0x3309 "㌉" */
+0x04,0x3e,0x04,0x0c,0x14,0x24,0x0c,0x00,0x00,0x3e,0x02,0x04,0x08,0x14,0x22,0x00,
+0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13066 0x330a "㌊" */
+0x04,0x3e,0x04,0x0c,0x14,0x24,0x0c,0x00,0x08,0x08,0x10,0x20,0x22,0x3e,0x02,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13067 0x330b "㌋" */
+0x10,0x3e,0x12,0x12,0x12,0x12,0x24,0x00,0x24,0x24,0x24,0x24,0x04,0x08,0x30,0x00,
+0x04,0x08,0x10,0x30,0x50,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13068 0x330c "㌌" */
+0x10,0x3e,0x12,0x12,0x12,0x12,0x24,0x00,0x00,0x00,0x2a,0x2a,0x02,0x04,0x18,0x00,
+0x38,0x00,0x7c,0x04,0x04,0x08,0x30,0x00,0x20,0x20,0x20,0x30,0x28,0x20,0x20,0x00,
+/* 13069 0x330d "㌍" */
+0x10,0x3e,0x12,0x12,0x12,0x12,0x24,0x00,0x24,0x24,0x24,0x24,0x04,0x08,0x30,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,
+/* 13070 0x330e "㌎" */
+0x41,0xfc,0x4a,0x48,0x48,0x48,0x90,0x00,0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,
+0x00,0xbe,0x22,0x22,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13071 0x330f "㌏" */
+0x40,0xfa,0x49,0x48,0x48,0x48,0x90,0x00,0x00,0x7c,0x04,0x04,0x28,0x10,0x08,0x00,
+0x80,0x50,0x08,0x02,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13072 0x3310 "㌐" */
+0x20,0x7d,0x10,0x7c,0x10,0x08,0x08,0x00,0x02,0x07,0x02,0x02,0x02,0x02,0x04,0x00,
+0x40,0x20,0x80,0x00,0x00,0x00,0x00,0x00,0x04,0xd2,0x48,0x40,0x40,0x40,0x80,0x00,
+/* 13073 0x3311 "㌑" */
+0x40,0xfa,0x21,0xf8,0x20,0x10,0x10,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,
+0x80,0x5c,0x00,0x00,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13074 0x3312 "㌒" */
+0x10,0x3e,0x08,0x3e,0x08,0x04,0x04,0x00,0x24,0x24,0x24,0x24,0x04,0x08,0x30,0x00,
+0x00,0x00,0x00,0x38,0x08,0x7c,0x00,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,
+/* 13075 0x3313 "㌓" */
+0x40,0xfa,0x21,0xf8,0x20,0x10,0x10,0x00,0x40,0x7a,0x49,0xa8,0x18,0x10,0x60,0x00,
+0x80,0x44,0x14,0x14,0x15,0x15,0x16,0x00,0x80,0x40,0x00,0x3e,0x00,0x00,0x00,0x00,
+/* 13076 0x3314 "㌔" */
+0x10,0x3e,0x08,0x3e,0x08,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,
+/* 13077 0x3315 "㌕" */
+0x20,0x7c,0x10,0x7c,0x10,0x08,0x08,0x00,0x41,0x74,0x52,0x90,0x10,0x20,0x40,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x00,0x00,0x32,0x82,0x74,0x14,0x15,0x27,0x41,0x00,
+/* 13078 0x3316 "㌖" */
+0x40,0xfb,0x22,0xfa,0x22,0x13,0x10,0x00,0x02,0x02,0x02,0xfb,0x02,0x02,0x02,0x00,
+0x02,0xc2,0x42,0x54,0x48,0xd4,0x20,0x00,0x00,0x08,0x28,0x28,0xaa,0x2a,0x2c,0x00,
+/* 13079 0x3317 "㌗" */
+0x10,0x3e,0x08,0x3e,0x08,0x04,0x04,0x00,0x00,0xf8,0x8a,0x8a,0x08,0x10,0x61,0x00,
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x08,0x08,0xa8,0xac,0x2a,0x48,0x88,0x00,
+/* 13080 0x3318 "㌘" */
+0x40,0x7a,0x49,0x88,0x08,0x10,0x60,0x00,0x10,0x10,0x20,0x40,0x44,0x7c,0x04,0x00,
+0x8c,0x40,0x1e,0x02,0x02,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13081 0x3319 "㌙" */
+0x40,0x7a,0x49,0x88,0x08,0x10,0x60,0x00,0x22,0x22,0x42,0x83,0x8a,0xfa,0x0a,0x00,
+0x8c,0x40,0x1e,0x02,0x02,0x04,0x08,0x00,0x00,0x10,0x08,0x02,0x8c,0x30,0x00,0x00,
+/* 13082 0x331a "㌚" */
+0x20,0x3c,0x24,0x44,0x04,0x08,0x30,0x00,0x41,0xfc,0x4a,0x50,0x41,0x40,0x38,0x00,
+0x00,0x20,0xa0,0xa0,0xa8,0xa8,0xb0,0x00,0x10,0xaf,0x49,0xc9,0x49,0x49,0x4f,0x00,
+/* 13083 0x331b "㌛" */
+0x10,0x1e,0x12,0x22,0x02,0x04,0x18,0x00,0x00,0x00,0x00,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x10,0x7c,0x08,0x10,0x38,0x54,0x10,0x00,
+/* 13084 0x331c "㌜" */
+0x10,0x1e,0x24,0x04,0x04,0x04,0x08,0x00,0x00,0x3e,0x02,0x04,0x08,0x14,0x22,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13085 0x331d "㌝" */
+0x00,0x3e,0x02,0x02,0x02,0x02,0x3e,0x00,0x08,0x08,0x3e,0x08,0x08,0x10,0x20,0x00,
+0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13086 0x331e "㌞" */
+0x00,0x3e,0x02,0x02,0x02,0x02,0x3e,0x00,0x08,0x3e,0x08,0x2a,0x2a,0x08,0x18,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x40,0xa0,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 13087 0x331f "㌟" */
+0x14,0x3e,0x14,0x14,0x04,0x08,0x10,0x00,0x10,0x1e,0x12,0x22,0x02,0x04,0x18,0x00,
+0x04,0x08,0x10,0x30,0x50,0x10,0x10,0x00,0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,
+/* 13088 0x3320 "㌠" */
+0x14,0x3e,0x14,0x14,0x04,0x08,0x10,0x00,0x10,0xe0,0x20,0xfb,0x20,0x20,0x40,0x00,
+0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,0x08,0x08,0x10,0xa0,0x22,0x3e,0x02,0x00,
+/* 13089 0x3321 "㌡" */
+0x20,0x14,0x44,0x24,0x08,0x70,0x00,0x00,0x01,0x81,0x41,0x0a,0x30,0xc0,0x01,0x00,
+0x90,0x90,0x90,0x90,0x10,0x20,0xc0,0x00,0x02,0xe9,0x24,0x20,0x20,0x40,0x80,0x00,
+/* 13090 0x3322 "㌢" */
+0x10,0x3e,0x12,0x14,0x10,0x10,0x0e,0x00,0x04,0x38,0x08,0x3e,0x08,0x08,0x10,0x00,
+0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13091 0x3323 "㌣" */
+0x10,0x3e,0x12,0x14,0x10,0x10,0x0e,0x00,0x10,0x10,0x10,0x18,0x14,0x10,0x10,0x00,
+0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13092 0x3324 "㌤" */
+0x40,0x7a,0x49,0xa8,0x18,0x10,0x60,0x00,0x00,0x7c,0x04,0x08,0x10,0x28,0x44,0x00,
+0x80,0x40,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13093 0x3325 "㌥" */
+0x1c,0x00,0x3e,0x08,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x90,0x40,0x00,0x00,0x00,0x00,0x00,0x20,0x14,0x44,0x24,0x08,0x70,0x00,0x00,
+/* 13094 0x3326 "㌦" */
+0x21,0x24,0x22,0x30,0x28,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,
+/* 13095 0x3327 "㌧" */
+0x10,0x10,0x10,0x18,0x14,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,
+/* 13096 0x3328 "㌨" */
+0x08,0x08,0x3e,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x10,0x20,0x00,
+/* 13097 0x3329 "㌩" */
+0x04,0x04,0x04,0x04,0x04,0x08,0x10,0x00,0x08,0x08,0x08,0x0c,0x0a,0x08,0x08,0x00,
+0x00,0x00,0x54,0x54,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13098 0x332a "㌪" */
+0x00,0x00,0x14,0x12,0x12,0x22,0x00,0x00,0x00,0x2a,0x2a,0x02,0x02,0x04,0x18,0x00,
+0x04,0x08,0x10,0x30,0x50,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13099 0x332b "㌫" */
+0x01,0x02,0x52,0x49,0x48,0x88,0x00,0x00,0x40,0xfa,0x49,0x50,0x40,0x43,0x38,0x00,
+0x00,0x80,0x80,0x3e,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x2c,0xca,0x08,0x08,0x00,
+/* 13100 0x332c "㌬" */
+0x01,0x02,0x52,0x49,0x48,0x88,0x00,0x00,0x00,0x54,0x54,0x04,0x04,0x08,0x30,0x00,
+0x00,0x80,0x80,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13101 0x332d "㌭" */
+0x01,0x04,0x52,0x48,0x48,0x88,0x00,0x00,0x00,0x40,0x40,0x44,0x48,0x50,0x60,0x00,
+0x00,0x80,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x20,0xa0,0xa0,0xa8,0xa8,0xb0,0x00,
+/* 13102 0x332e "㌮" */
+0x81,0x9a,0xe2,0x81,0x80,0x80,0x78,0x00,0x02,0xfa,0x0a,0x13,0x22,0x52,0x8a,0x00,
+0x3e,0x82,0x8a,0x0c,0x08,0x08,0x10,0x00,0x00,0x08,0x28,0x28,0xaa,0x2a,0x2c,0x00,
+/* 13103 0x332f "㌯" */
+0x81,0x9a,0xe2,0x81,0x80,0x80,0x78,0x00,0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,
+0x10,0x9e,0x92,0x22,0x02,0x04,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13104 0x3330 "㌰" */
+0x20,0x26,0x38,0x20,0x20,0x20,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0xa0,0xa0,0x40,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x7c,0x00,
+/* 13105 0x3331 "㌱" */
+0x40,0x4d,0x70,0x40,0x40,0x40,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x20,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,
+/* 13106 0x3332 "㌲" */
+0x00,0x7c,0x04,0x04,0x04,0x08,0x30,0x00,0xe0,0x00,0xea,0x2a,0x20,0x41,0x86,0x00,
+0x00,0x00,0xf8,0x08,0x30,0x20,0x40,0x00,0x22,0x29,0xa4,0xb0,0xa8,0x20,0x20,0x00,
+/* 13107 0x3333 "㌳" */
+0x00,0x3e,0x02,0x02,0x02,0x04,0x18,0x00,0x00,0x00,0x00,0x3e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x08,0x10,0x30,0x50,0x10,0x00,0x20,0x20,0x20,0x30,0x28,0x20,0x20,0x00,
+/* 13108 0x3334 "㌴" */
+0x01,0xf4,0x12,0x10,0x10,0x20,0xc0,0x00,0x40,0x28,0x88,0x4f,0x11,0xe1,0x07,0x00,
+0x00,0x80,0x2a,0x2a,0x02,0x04,0x18,0x00,0x00,0x04,0x14,0xd4,0x15,0x15,0xd6,0x00,
+/* 13109 0x3335 "㌵" */
+0x00,0x3e,0x02,0x02,0x02,0x04,0x18,0x00,0x00,0x20,0x10,0x02,0x0c,0x30,0x00,0x00,
+0x38,0x00,0x7c,0x04,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13110 0x3336 "㌶" */
+0x00,0x20,0x50,0x08,0x04,0x00,0x00,0x00,0x40,0x78,0x48,0xab,0x18,0x10,0x60,0x00,
+0x40,0x78,0x48,0x88,0x08,0x10,0x60,0x00,0x00,0x04,0x14,0xd4,0x15,0x15,0x16,0x00,
+/* 13111 0x3337 "㌷" */
+0x01,0x22,0x52,0x09,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x14,0x14,0x04,0x08,0x30,0x00,
+/* 13112 0x3338 "㌸" */
+0x01,0x22,0x52,0x09,0x04,0x00,0x00,0x00,0x20,0x26,0x38,0x20,0x20,0x20,0x1e,0x00,
+0x00,0x9c,0x80,0x00,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13113 0x3339 "㌹" */
+0x00,0x10,0x28,0x04,0x02,0x00,0x00,0x00,0x00,0x2a,0x2a,0x02,0x02,0x04,0x18,0x00,
+0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13114 0x333a "㌺" */
+0x01,0x22,0x52,0x09,0x04,0x00,0x00,0x00,0x00,0x3e,0x02,0x04,0x08,0x14,0x22,0x00,
+0x00,0xa0,0x90,0x02,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13115 0x333b "㌻" */
+0x01,0x22,0x52,0x09,0x04,0x00,0x00,0x00,0x20,0x15,0x44,0x24,0x08,0x70,0x00,0x00,
+0x00,0x80,0x80,0x3e,0x00,0x00,0x00,0x00,0x40,0x20,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 13116 0x333c "㌼" */
+0x01,0x24,0x52,0x08,0x04,0x00,0x00,0x00,0x10,0x1e,0x12,0x2a,0x06,0x04,0x18,0x00,
+0x00,0x80,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13117 0x333d "㌽" */
+0x10,0x7d,0x11,0x54,0x54,0x10,0x30,0x00,0x00,0x20,0x10,0x02,0x0c,0x30,0x00,0x00,
+0x82,0x44,0x48,0x98,0x28,0x08,0x08,0x00,0x20,0x20,0x20,0x30,0x28,0x20,0x20,0x00,
+/* 13118 0x333e "㌾" */
+0x10,0x7d,0x10,0x54,0x54,0x10,0x30,0x00,0x10,0x10,0x10,0x18,0x14,0x10,0x10,0x00,
+0x40,0x24,0x94,0x14,0x15,0x15,0x16,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13119 0x333f "㌿" */
+0x08,0x3e,0x08,0x2a,0x2a,0x08,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,
+/* 13120 0x3340 "㍀" */
+0x10,0x7d,0x11,0x54,0x54,0x10,0x30,0x00,0x10,0x12,0x11,0x18,0x14,0x10,0x10,0x00,
+0x80,0x50,0x48,0x82,0x0c,0x30,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13121 0x3341 "㍁" */
+0x08,0x3e,0x08,0x2a,0x2a,0x08,0x18,0x00,0x00,0x08,0x28,0x28,0x2a,0x2a,0x2c,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13122 0x3342 "㍂" */
+0x08,0x3e,0x08,0x2a,0x2a,0x08,0x18,0x00,0x00,0x20,0x10,0x02,0x0c,0x30,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13123 0x3343 "㍃" */
+0x00,0x3e,0x02,0x02,0x14,0x08,0x04,0x00,0x10,0x1e,0x12,0x02,0x02,0x04,0x18,0x00,
+0x04,0x08,0x10,0x30,0x50,0x10,0x10,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,
+/* 13124 0x3344 "㍄" */
+0x00,0x3e,0x02,0x02,0x14,0x08,0x04,0x00,0x00,0x08,0x28,0x28,0x2a,0x2a,0x2c,0x00,
+0x04,0x08,0x10,0x30,0x50,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13125 0x3345 "㍅" */
+0x00,0x3e,0x02,0x02,0x14,0x08,0x04,0x00,0x00,0x00,0x14,0x12,0x12,0x22,0x00,0x00,
+0x00,0x00,0x54,0x54,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13126 0x3346 "㍆" */
+0x00,0x3e,0x02,0x02,0x14,0x08,0x04,0x00,0x10,0x1e,0x12,0x22,0x02,0x04,0x18,0x00,
+0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13127 0x3347 "㍇" */
+0x00,0x7c,0x04,0x04,0x28,0x10,0x08,0x00,0x00,0x40,0x2b,0x88,0x4b,0x10,0xe3,0x00,
+0x00,0x80,0x40,0x08,0x30,0xc0,0x00,0x00,0x00,0x20,0x90,0x82,0x8c,0xb0,0x80,0x00,
+/* 13128 0x3348 "㍈" */
+0x18,0x04,0x30,0x08,0x00,0x30,0x0c,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,
+0x20,0x3c,0x24,0x44,0x04,0x08,0x30,0x00,0x00,0x40,0x20,0x04,0x18,0x60,0x00,0x00,
+/* 13129 0x3349 "㍉" */
+0x18,0x04,0x30,0x08,0x00,0x30,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x48,0x48,0x48,0x08,0x10,0x60,0x00,
+/* 13130 0x334a "㍊" */
+0x18,0x04,0x30,0x08,0x00,0x30,0x0c,0x00,0x01,0x04,0x52,0x48,0x49,0x88,0x00,0x00,
+0x48,0x48,0x48,0x48,0x08,0x10,0x60,0x00,0x00,0x84,0x14,0x14,0xd5,0x15,0x16,0x00,
+/* 13131 0x334b "㍋" */
+0x04,0x04,0x04,0x28,0x10,0x28,0x40,0x00,0x02,0x07,0x02,0x02,0x02,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xd2,0x48,0x40,0x40,0x40,0x80,0x00,
+/* 13132 0x334c "㍌" */
+0x09,0x0b,0x09,0x51,0x21,0x51,0x82,0x00,0x20,0x20,0x20,0x30,0x28,0x20,0x20,0x00,
+0x02,0xe9,0x24,0x20,0x20,0x20,0x40,0x00,0x00,0x80,0x40,0x08,0x30,0xc0,0x00,0x00,
+/* 13133 0x334d "㍍" */
+0x02,0x02,0x02,0x14,0x08,0x14,0x20,0x00,0x10,0x10,0x10,0x18,0x14,0x10,0x10,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,
+/* 13134 0x334e "㍎" */
+0x10,0x10,0x3e,0x12,0x14,0x10,0x10,0x00,0x21,0x24,0x22,0x30,0x28,0x20,0x20,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13135 0x334f "㍏" */
+0x10,0x10,0x3e,0x12,0x14,0x10,0x10,0x00,0x00,0x08,0x28,0x28,0x2a,0x2a,0x2c,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13136 0x3350 "㍐" */
+0x00,0x1c,0x04,0x04,0x04,0x3e,0x00,0x00,0x00,0x20,0x10,0x02,0x0c,0x30,0x00,0x00,
+0x7c,0x04,0x14,0x18,0x10,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13137 0x3351 "㍑" */
+0x24,0x24,0x24,0x24,0x04,0x08,0x30,0x00,0x10,0x10,0x10,0x18,0x14,0x10,0x10,0x00,
+0x00,0x00,0x54,0x54,0x04,0x08,0x30,0x00,0x00,0x10,0x50,0x50,0x54,0x54,0x58,0x00,
+/* 13138 0x3352 "㍒" */
+0x24,0x24,0x24,0x24,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x7c,0x04,0x04,0x08,0x30,0x00,
+/* 13139 0x3353 "㍓" */
+0x11,0x51,0x51,0x51,0x55,0x55,0x58,0x00,0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,
+0x02,0x35,0xc5,0x02,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13140 0x3354 "㍔" */
+0x00,0x08,0x28,0x28,0x2a,0x2a,0x2c,0x00,0x00,0xfa,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x00,0x00,0x00,0x80,0x44,0x14,0x14,0x15,0x15,0x16,0x00,
+/* 13141 0x3355 "㍕" */
+0x00,0x20,0x20,0x22,0x24,0x28,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x40,0x44,0x7c,0x04,0x00,
+/* 13142 0x3356 "㍖" */
+0x00,0x40,0x40,0x44,0x48,0x50,0x60,0x00,0x88,0x8e,0x94,0xc4,0xa4,0x84,0x88,0x00,
+0x00,0x80,0x40,0x08,0x30,0xc0,0x00,0x00,0x20,0x94,0x42,0x00,0x01,0x06,0x18,0x00,
+/* 13143 0x3357 "㍗" */
+0x00,0x3e,0x22,0x22,0x02,0x04,0x18,0x00,0x10,0x10,0x10,0x18,0x14,0x10,0x10,0x00,
+0x00,0x00,0x54,0x54,0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13144 0x3358 "㍘" */
+0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x18,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13145 0x3359 "㍙" */
+0x00,0x10,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13146 0x335a "㍚" */
+0x00,0x18,0x24,0x24,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x3c,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13147 0x335b "㍛" */
+0x00,0x18,0x24,0x24,0x04,0x04,0x04,0x18,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13148 0x335c "㍜" */
+0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13149 0x335d "㍝" */
+0x00,0x3c,0x20,0x20,0x20,0x20,0x20,0x38,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13150 0x335e "㍞" */
+0x00,0x18,0x24,0x24,0x20,0x20,0x20,0x38,0x24,0x24,0x24,0x24,0x24,0x24,0x18,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13151 0x335f "㍟" */
+0x00,0x3c,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13152 0x3360 "㍠" */
+0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x18,0x24,0x24,0x24,0x24,0x24,0x24,0x18,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13153 0x3361 "㍡" */
+0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x18,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13154 0x3362 "㍢" */
+0x00,0x26,0x69,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x76,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13155 0x3363 "㍣" */
+0x00,0x22,0x66,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x77,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13156 0x3364 "㍤" */
+0x00,0x26,0x69,0x29,0x21,0x21,0x22,0x22,0x22,0x24,0x24,0x24,0x28,0x28,0x7f,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13157 0x3365 "㍥" */
+0x00,0x26,0x69,0x29,0x21,0x21,0x21,0x26,0x21,0x21,0x21,0x21,0x29,0x29,0x76,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13158 0x3366 "㍦" */
+0x00,0x29,0x69,0x29,0x29,0x29,0x29,0x2f,0x21,0x21,0x21,0x21,0x21,0x21,0x71,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13159 0x3367 "㍧" */
+0x00,0x2f,0x68,0x28,0x28,0x28,0x28,0x2e,0x21,0x21,0x21,0x21,0x29,0x29,0x76,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13160 0x3368 "㍨" */
+0x00,0x26,0x69,0x29,0x28,0x28,0x28,0x2e,0x29,0x29,0x29,0x29,0x29,0x29,0x76,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13161 0x3369 "㍩" */
+0x00,0x2f,0x61,0x21,0x21,0x22,0x22,0x22,0x24,0x24,0x24,0x24,0x24,0x24,0x74,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13162 0x336a "㍪" */
+0x00,0x26,0x69,0x29,0x29,0x29,0x29,0x26,0x29,0x29,0x29,0x29,0x29,0x29,0x76,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13163 0x336b "㍫" */
+0x00,0x26,0x69,0x29,0x29,0x29,0x29,0x26,0x21,0x21,0x21,0x21,0x29,0x29,0x76,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x54,0xaa,0xaa,
+/* 13164 0x336c "㍬" */
+0x00,0x63,0x94,0x94,0x14,0x14,0x24,0x24,0x24,0x44,0x44,0x44,0x84,0x84,0xf3,0x00,
+0x08,0x08,0x88,0x8f,0x88,0x88,0xbe,0xa2,0xa2,0xa2,0xbe,0xa2,0x80,0xaa,0x55,0x55,
+/* 13165 0x336d "㍭" */
+0x00,0x62,0x96,0x92,0x12,0x12,0x22,0x22,0x22,0x42,0x42,0x42,0x82,0x82,0xf7,0x00,
+0x08,0x08,0x08,0x0f,0x08,0x08,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,0x2a,0x55,0x55,
+/* 13166 0x336e "㍮" */
+0x00,0x63,0x94,0x94,0x10,0x10,0x21,0x21,0x21,0x42,0x42,0x42,0x84,0x84,0xf7,0x00,
+0x08,0x08,0x88,0x8f,0x88,0x88,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,0x2a,0xd5,0x55,
+/* 13167 0x336f "㍯" */
+0x00,0x63,0x94,0x94,0x10,0x10,0x20,0x23,0x20,0x40,0x40,0x40,0x84,0x84,0xf3,0x00,
+0x08,0x08,0x88,0x8f,0x88,0x88,0xbe,0x22,0xa2,0xa2,0xbe,0xa2,0x80,0xaa,0x55,0x55,
+/* 13168 0x3370 "㍰" */
+0x00,0x64,0x94,0x94,0x14,0x14,0x24,0x27,0x20,0x40,0x40,0x40,0x80,0x80,0xf0,0x00,
+0x08,0x88,0x88,0x8f,0x88,0x88,0xbe,0xa2,0xa2,0xa2,0xbe,0xa2,0x80,0xaa,0xd5,0x55,
+/* 13169 0x3371 "㍱" */
+0x00,0x00,0x43,0x42,0x42,0x42,0x53,0x6a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x20,0xcc,0x12,0x02,0x0e,0x12,0x12,0x16,0x0a,0x00,0x00,
+/* 13170 0x3372 "㍲" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+/* 13171 0x3373 "㍳" */
+0x00,0x00,0x08,0x14,0x14,0x14,0x22,0x22,0x3e,0x22,0x41,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+/* 13172 0x3374 "㍴" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x71,0x4a,0x48,0x49,0x4a,0x4a,0x4a,0x71,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x94,0x5a,0x52,0xd0,0x50,0x50,0xd0,0x50,0x00,0x00,
+/* 13173 0x3375 "㍵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x84,0x84,0x84,0x84,0x78,0x00,0x00,
+0x00,0x00,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+/* 13174 0x3376 "㍶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+/* 13175 0x3377 "㍷" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x1d,0x23,0x41,0x41,0x41,0x41,0x23,0x1d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+/* 13176 0x3378 "㍸" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x3a,0x46,0x82,0x82,0x82,0x82,0x46,0x3a,0x00,0x00,
+0x1e,0x02,0x1e,0x10,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13177 0x3379 "㍹" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x3a,0x46,0x82,0x82,0x82,0x82,0x46,0x3a,0x00,0x00,
+0x1e,0x02,0x0e,0x02,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13178 0x337a "㍺" */
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x78,0x00,0x00,
+/* 13179 0x337b "㍻" */
+0x00,0x00,0x00,0xfe,0x10,0x92,0x52,0x54,0x10,0xfe,0x10,0x10,0x10,0x10,0x11,0x00,
+0x00,0x0a,0x09,0x09,0x08,0x7f,0x48,0x48,0x78,0x55,0x55,0x95,0xd6,0xb5,0x0a,0x10,
+/* 13180 0x337c "㍼" */
+0x00,0x1e,0x0a,0xea,0xaa,0xaa,0xea,0xb6,0xa0,0xae,0xeb,0xaa,0x0e,0x0a,0x00,0x00,
+0x00,0x30,0xee,0x4a,0xfa,0x4a,0x4a,0xca,0xea,0xda,0x4a,0x4a,0x4e,0x4a,0x00,0x00,
+/* 13181 0x337d "㍽" */
+0x00,0x00,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x82,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x50,0x50,0x50,0x5e,0x50,0x50,0x50,0x50,0x50,0xfe,0x00,
+/* 13182 0x337e "㍾" */
+0x00,0x00,0x0e,0xea,0xaa,0xaa,0xee,0xaa,0xaa,0xaa,0xee,0xaa,0x0a,0x12,0x26,0x00,
+0x00,0x01,0x81,0x42,0x02,0x94,0x55,0x17,0x21,0x20,0x6f,0x29,0x29,0x2f,0x29,0x00,
+/* 13183 0x337f "㍿" */
+0x2a,0x7f,0x2a,0x77,0xa2,0x27,0x2a,0x00,0x10,0x28,0x44,0xba,0x00,0xfe,0x24,0x7a,
+0x05,0x84,0x3f,0x02,0x3a,0x12,0xb9,0x00,0x44,0xf4,0x1e,0x24,0xd4,0x44,0x44,0x5f,
+/* 13184 0x3380 "㎀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,0x40,
+0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x7c,0x44,0x82,0x82,0x82,0x82,0x00,0x00,
+/* 13185 0x3381 "㎁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x7c,0x44,0x82,0x82,0x82,0x82,0x00,0x00,
+/* 13186 0x3382 "㎂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x12,0x22,0x22,0x22,0x3d,0x40,0x40,
+0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x7c,0x44,0x82,0x82,0x82,0x82,0x00,0x00,
+/* 13187 0x3383 "㎃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x7c,0x44,0x82,0x82,0x82,0x82,0x00,0x00,
+/* 13188 0x3384 "㎄" */
+0x00,0x00,0x80,0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xd0,0x88,0x84,0x82,0x00,0x00,
+0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x7c,0x44,0x82,0x82,0x82,0x82,0x00,0x00,
+/* 13189 0x3385 "㎅" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x68,0x44,0x42,0x41,0x00,0x00,
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+/* 13190 0x3386 "㎆" */
+0x00,0x00,0x41,0x41,0x63,0x63,0x55,0x55,0x49,0x49,0x41,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+/* 13191 0x3387 "㎇" */
+0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+/* 13192 0x3388 "㎈" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x71,0x8a,0x80,0x81,0x82,0x82,0x8a,0x71,0x00,0x00,
+0x00,0x00,0x0c,0x04,0x04,0x04,0xe4,0x14,0x14,0xf4,0x14,0x14,0x34,0xde,0x00,0x00,
+/* 13193 0x3389 "㎉" */
+0x00,0x00,0x80,0x80,0x80,0x80,0x93,0x94,0xa4,0xc4,0xa4,0x94,0x8c,0x8f,0x00,0x00,
+0x00,0x00,0x0c,0x04,0x04,0x04,0x64,0x94,0x14,0x74,0x94,0x94,0xb4,0x5e,0x00,0x00,
+/* 13194 0x338a "㎊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,0x40,
+0x00,0x00,0xfe,0x80,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 13195 0x338b "㎋" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 13196 0x338c "㎌" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x44,0x44,0x44,0x7b,0x80,0x80,
+0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 13197 0x338d "㎍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x22,0x22,0x22,0x3d,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x04,0x34,0x48,0x48,0x48,0x30,0x20,0x38,0xc4,0x44,0x38,
+/* 13198 0x338e "㎎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x68,0x90,0x90,0x90,0x60,0x40,0x70,0x88,0x88,0x70,
+/* 13199 0x338f "㎏" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x68,0x44,0x42,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x34,0x48,0x48,0x48,0x30,0x20,0x38,0x44,0x44,0x38,
+/* 13200 0x3390 "㎐" */
+0x00,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+/* 13201 0x3391 "㎑" */
+0x00,0x84,0x84,0x84,0x84,0x84,0x94,0x97,0xa4,0xc4,0xa4,0x94,0x8c,0x8c,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x40,0x5e,0xc2,0x44,0x48,0x48,0x50,0x60,0x7e,0x00,0x00,
+/* 13202 0x3392 "㎒" */
+0x00,0x8a,0x8a,0xda,0xda,0xaa,0xaa,0x8b,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x40,0x5e,0xc2,0x44,0x44,0x48,0x48,0x50,0x5e,0x00,0x00,
+/* 13203 0x3393 "㎓" */
+0x00,0x00,0x72,0x8a,0x8a,0x82,0x82,0x83,0x9e,0x8a,0x8a,0x8a,0x8a,0x7a,0x00,0x00,
+0x00,0x00,0x40,0x40,0x40,0x40,0x5e,0xc2,0x44,0x44,0x48,0x48,0x50,0x5e,0x00,0x00,
+/* 13204 0x3394 "㎔" */
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x27,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0xbe,0x82,0x84,0x88,0x88,0x90,0xa0,0xbe,0x00,0x00,
+/* 13205 0x3395 "㎕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x22,0x22,0x22,0x22,0x5d,0x40,0x40,
+0x00,0x00,0x08,0x14,0x14,0x24,0x28,0x48,0x48,0x50,0x52,0x62,0x64,0xd8,0x00,0x00,
+/* 13206 0x3396 "㎖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x00,0x00,
+0x00,0x00,0x08,0x14,0x14,0x24,0x28,0x48,0x48,0x50,0x52,0x62,0x64,0xd8,0x00,0x00,
+/* 13207 0x3397 "㎗" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3b,0x00,0x00,
+0x00,0x00,0x08,0x14,0x14,0x24,0x28,0x48,0x48,0x50,0x52,0x62,0x64,0xd8,0x00,0x00,
+/* 13208 0x3398 "㎘" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x68,0x44,0x42,0x41,0x00,0x00,
+0x00,0x00,0x08,0x14,0x14,0x24,0x28,0x48,0x48,0x50,0x52,0x62,0x64,0xd8,0x00,0x00,
+/* 13209 0x3399 "㎙" */
+0x00,0x00,0x1c,0x22,0x20,0x20,0x78,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc8,0x34,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+/* 13210 0x339a "㎚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x59,0x65,0x45,0x45,0x45,0x45,0x45,0x45,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xd8,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+/* 13211 0x339b "㎛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x42,0x44,0x44,0x44,0x7b,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa4,0xda,0x92,0x92,0x92,0x92,0x92,0x92,0x00,0x00,
+/* 13212 0x339c "㎜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+/* 13213 0x339d "㎝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x40,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+/* 13214 0x339e "㎞" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x68,0x44,0x42,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+/* 13215 0x339f "㎟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+0x1e,0x02,0x1e,0x10,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13216 0x33a0 "㎠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x80,0x80,0x80,0x80,0x44,0x38,0x00,0x00,
+0x1e,0x02,0x1e,0x10,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13217 0x33a1 "㎡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x33,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x3c,0x04,0x3c,0x20,0x3c,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 13218 0x33a2 "㎢" */
+0x00,0x00,0x80,0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xd0,0x88,0x84,0x82,0x00,0x00,
+0x1e,0x02,0x1e,0x10,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13219 0x33a3 "㎣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+0x1e,0x02,0x0e,0x02,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13220 0x33a4 "㎤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x80,0x80,0x80,0x80,0x44,0x38,0x00,0x00,
+0x1e,0x02,0x0e,0x02,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13221 0x33a5 "㎥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x33,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x3c,0x04,0x1c,0x04,0x3c,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 13222 0x33a6 "㎦" */
+0x00,0x00,0x80,0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xd0,0x88,0x84,0x82,0x00,0x00,
+0x1e,0x02,0x0e,0x02,0x1e,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0x00,0x00,
+/* 13223 0x33a7 "㎧" */
+0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa9,0xaa,0x02,0x04,0x08,0x10,0x20,0x40,0x80,
+0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x78,0x84,0x80,0x78,0x04,0x84,0x78,0x00,0x00,
+/* 13224 0x33a8 "㎨" */
+0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa9,0xaa,0xac,0x04,0x08,0x10,0x10,0x20,0x40,0x80,
+0x10,0x2e,0x22,0x4e,0x88,0x8e,0x00,0x78,0x84,0x80,0x78,0x04,0x84,0x78,0x00,0x00,
+/* 13225 0x33a9 "㎩" */
+0x00,0x00,0x3e,0x21,0x21,0x21,0x21,0x3e,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x04,0x7c,0x84,0x84,0x8c,0x74,0x00,0x00,
+/* 13226 0x33aa "㎪" */
+0x00,0x00,0x81,0x81,0x81,0x81,0x85,0x89,0x91,0xa1,0xd1,0x89,0x85,0x83,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x20,0x3c,0xc2,0x02,0x1e,0x22,0x22,0x26,0x1a,0x00,0x00,
+/* 13227 0x33ab "㎫" */
+0x00,0x00,0x89,0x89,0xd9,0xd9,0xa9,0xa9,0x89,0x89,0x89,0x89,0x89,0x89,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x20,0x3c,0xc2,0x02,0x1e,0x22,0x22,0x26,0x1a,0x00,0x00,
+/* 13228 0x33ac "㎬" */
+0x00,0x00,0x71,0x89,0x89,0x81,0x81,0x81,0x9d,0x89,0x89,0x89,0x89,0x79,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0x20,0x3c,0xc2,0x02,0x1e,0x22,0x22,0x26,0x1a,0x00,0x00,
+/* 13229 0x33ad "㎭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5b,0x64,0x40,0x47,0x48,0x48,0x49,0x46,0x00,0x00,
+0x00,0x00,0x02,0x02,0x02,0x02,0x1a,0xa6,0xa2,0xa2,0xa2,0xa2,0xa6,0xda,0x00,0x00,
+/* 13230 0x33ae "㎮" */
+0x00,0x00,0x00,0xb1,0xca,0x9a,0xaa,0xaa,0xaa,0x9d,0x00,0x01,0x01,0x02,0x04,0x08,
+0x82,0x84,0x84,0x88,0x88,0x90,0x90,0xa0,0xac,0xd2,0x90,0x0c,0x02,0x12,0x0c,0x00,
+/* 13231 0x33af "㎯" */
+0x00,0x00,0x00,0xb1,0xca,0x9a,0xaa,0xaa,0xaa,0x9d,0x00,0x01,0x01,0x02,0x02,0x04,
+0x90,0x9e,0x92,0xae,0xa8,0xae,0xc0,0xc0,0x98,0xa4,0xa0,0x18,0x04,0x24,0x18,0x00,
+/* 13232 0x33b0 "㎰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x80,0x70,0x08,0x04,0x84,0x78,0x00,0x00,
+/* 13233 0x33b1 "㎱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x80,0x70,0x08,0x04,0x84,0x78,0x00,0x00,
+/* 13234 0x33b2 "㎲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x22,0x22,0x22,0x3d,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x38,0x04,0x02,0x42,0xbc,0x00,0x00,
+/* 13235 0x33b3 "㎳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x80,0x70,0x08,0x04,0x84,0x78,0x00,0x00,
+/* 13236 0x33b4 "㎴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,0x40,
+0x00,0x00,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+/* 13237 0x33b5 "㎵" */
+0x00,0x00,0x01,0x01,0x01,0x01,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x20,0x00,0x00,
+/* 13238 0x33b6 "㎶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x44,0x44,0x44,0x7b,0x80,0x80,
+0x00,0x00,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+/* 13239 0x33b7 "㎷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+/* 13240 0x33b8 "㎸" */
+0x00,0x00,0x81,0x81,0x81,0x81,0x85,0x88,0x90,0xa0,0xd0,0x88,0x84,0x82,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x00,0x00,
+/* 13241 0x33b9 "㎹" */
+0x00,0x00,0x82,0x82,0xc6,0xc6,0xaa,0xaa,0x92,0x92,0x82,0x82,0x82,0x82,0x00,0x00,
+0x00,0x00,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+/* 13242 0x33ba "㎺" */
+0x00,0x00,0x02,0x02,0x02,0x01,0x59,0x65,0x44,0x44,0x44,0x64,0x58,0x40,0x40,0x40,
+0x00,0x00,0x22,0x22,0x22,0x22,0x14,0x14,0x94,0x94,0xb4,0xc8,0x48,0x48,0x00,0x00,
+/* 13243 0x33bb "㎻" */
+0x00,0x00,0x02,0x02,0x02,0x01,0x59,0x65,0x44,0x44,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x22,0x22,0x22,0x22,0x14,0x14,0x94,0x94,0xb4,0xc8,0x48,0x48,0x00,0x00,
+/* 13244 0x33bc "㎼" */
+0x00,0x00,0x02,0x02,0x02,0x01,0x25,0x25,0x24,0x24,0x48,0x48,0x48,0x76,0x80,0x80,
+0x00,0x00,0x22,0x22,0x22,0x22,0x14,0x14,0x94,0x94,0xb4,0xc8,0x48,0x48,0x00,0x00,
+/* 13245 0x33bd "㎽" */
+0x00,0x00,0x02,0x02,0x02,0x01,0x69,0x55,0x54,0x54,0x54,0x54,0x54,0x54,0x00,0x00,
+0x00,0x00,0x22,0x22,0x22,0x22,0x14,0x14,0x94,0x94,0xb4,0xc8,0x48,0x48,0x00,0x00,
+/* 13246 0x33be "㎾" */
+0x00,0x00,0x82,0x82,0x82,0x81,0x85,0x89,0x90,0xa0,0xd0,0x88,0x84,0x83,0x00,0x00,
+0x00,0x00,0x22,0x22,0x22,0x22,0x14,0x14,0x94,0x94,0xb4,0xc8,0x48,0x48,0x00,0x00,
+/* 13247 0x33bf "㎿" */
+0x00,0x00,0x83,0x83,0xc7,0xc7,0xaa,0xaa,0x92,0x92,0x82,0x82,0x82,0x82,0x00,0x00,
+0x00,0x00,0x22,0x22,0x22,0x22,0x94,0x94,0x94,0x94,0xb4,0x48,0x48,0x48,0x00,0x00,
+/* 13248 0x33c0 "㏀" */
+0x00,0x00,0x40,0x40,0x41,0x41,0x49,0x49,0x51,0x61,0x51,0x48,0x44,0x47,0x00,0x00,
+0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x88,0x88,0xde,0x00,0x00,
+/* 13249 0x33c1 "㏁" */
+0x00,0x00,0x44,0x44,0x6c,0x6c,0x54,0x54,0x44,0x44,0x44,0x44,0x44,0x45,0x00,0x00,
+0x00,0x00,0x38,0x44,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x44,0x44,0xef,0x00,0x00,
+/* 13250 0x33c2 "㏂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x38,0x48,0x48,0x58,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x00,0x00,
+/* 13251 0x33c3 "㏃" */
+0x00,0x00,0x3c,0x22,0x22,0x22,0x22,0x3c,0x22,0x21,0x21,0x21,0x22,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4c,0x44,0x44,0x44,0x4c,0x34,0x04,0x04,0x04,
+/* 13252 0x33c4 "㏄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x40,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x80,0x80,0x80,0x80,0x44,0x38,0x00,0x00,
+/* 13253 0x33c5 "㏅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x04,0x04,0x04,0x04,0x04,0x74,0x8c,0x84,0x84,0x84,0x84,0x8c,0x74,0x00,0x00,
+/* 13254 0x33c6 "㏆" */
+0x00,0x70,0x88,0x80,0x81,0x8a,0x76,0x0a,0x12,0x22,0x43,0x82,0x02,0x02,0x00,0x00,
+0x10,0x20,0x40,0x80,0x00,0x00,0x01,0x4d,0x52,0x92,0x12,0x8c,0x48,0x4e,0x11,0x0e,
+/* 13255 0x33c7 "㏇" */
+0x00,0x00,0x3c,0x42,0x81,0x80,0x80,0x80,0x80,0x80,0x80,0x81,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x72,0x00,0x00,
+/* 13256 0x33c8 "㏈" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x74,0x8c,0x84,0x84,0x84,0x84,0x8c,0x74,0x00,0x00,
+0x00,0x00,0xf8,0x84,0x84,0x84,0x84,0xf8,0x84,0x82,0x82,0x82,0x84,0xf8,0x00,0x00,
+/* 13257 0x33c9 "㏉" */
+0x00,0x00,0x1e,0x21,0x41,0x40,0x40,0x40,0x40,0x43,0x41,0x41,0x23,0x1d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x22,0xa4,0x14,0x18,0x08,0x10,0x10,0x60,
+/* 13258 0x33ca "㏊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x04,0x7c,0x84,0x84,0x8c,0x74,0x00,0x00,
+/* 13259 0x33cb "㏋" */
+0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 13260 0x33cc "㏌" */
+0x00,0x00,0x00,0x10,0x10,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xb8,0xc4,0x84,0x84,0x84,0x84,0x84,0x84,0x00,0x00,
+/* 13261 0x33cd "㏍" */
+0x00,0x00,0x41,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x41,0x00,0x00,
+0x00,0x00,0x41,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x41,0x00,0x00,
+/* 13262 0x33ce "㏎" */
+0x00,0x00,0x45,0x45,0x45,0x49,0x51,0x61,0x51,0x49,0x45,0x45,0x45,0x45,0x00,0x00,
+0x00,0x00,0x04,0x04,0x8c,0x8c,0x54,0x54,0x24,0x24,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 13263 0x33cf "㏏" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x68,0x44,0x42,0x41,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x78,0x20,0x20,0x20,0x20,0x24,0x24,0x18,0x00,0x00,
+/* 13264 0x33d0 "㏐" */
+0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xec,0x92,0x92,0x92,0x92,0x92,0x92,0x00,0x00,
+/* 13265 0x33d1 "㏑" */
+0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbc,0xc2,0x82,0x82,0x82,0x82,0x82,0x00,0x00,
+/* 13266 0x33d2 "㏒" */
+0x00,0x00,0x60,0x20,0x20,0x20,0x27,0x28,0x28,0x28,0x28,0x28,0x28,0xf7,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x1a,0xa4,0xa4,0xa4,0x98,0x90,0x9c,0x22,0x22,0x1c,
+/* 13267 0x33d3 "㏓" */
+0x00,0x00,0x30,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x10,0x10,0x10,0x7d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x84,0x48,0x30,0x30,0x48,0x84,0x02,0x00,0x00,
+/* 13268 0x33d4 "㏔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0xb8,0xc4,0x84,0x84,0x84,0x84,0xc4,0xb8,0x00,0x00,
+/* 13269 0x33d5 "㏕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x69,0x54,0x54,0x54,0x54,0x54,0x54,0x57,0x00,0x00,
+0x00,0x00,0x18,0x88,0x88,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,0x00,
+/* 13270 0x33d6 "㏖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xd1,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xa9,0x00,0x00,
+0x00,0x00,0x0c,0x04,0x04,0x04,0xc4,0x24,0x24,0x24,0x24,0x24,0x24,0xdf,0x00,0x00,
+/* 13271 0x33d7 "㏗" */
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+/* 13272 0x33d8 "㏘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x78,0x40,0x44,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0xd0,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x00,0x00,
+/* 13273 0x33d9 "㏙" */
+0x00,0x00,0xe7,0x94,0x94,0x94,0x94,0xe7,0x84,0x84,0x84,0x84,0x84,0x84,0x00,0x00,
+0x00,0x00,0x22,0xa2,0xb6,0xb6,0xaa,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+/* 13274 0x33da "㏚" */
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x7c,0x42,0x42,0x42,0x42,0x7c,0x48,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+/* 13275 0x33db "㏛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x38,0x04,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 13276 0x33dc "㏜" */
+0x00,0x00,0x1e,0x21,0x40,0x40,0x30,0x0c,0x03,0x00,0x00,0x40,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x82,0x44,0xc4,0xa8,0xa8,0x10,0x10,0x00,0x00,
+/* 13277 0x33dd "㏝" */
+0x00,0x00,0x88,0x88,0x88,0x88,0x44,0x45,0x4d,0x4d,0x55,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0xa0,0xa0,0xa0,0xa0,0xbc,0x22,0x22,0x22,0x22,0x22,0x22,0x3c,0x00,0x00,
+/* 13278 0x33de "㏞" */
+0x00,0x00,0x22,0x22,0x22,0x22,0x14,0x14,0x09,0x0a,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x02,0x04,0x08,0x10,0x20,0x40,0xb4,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+/* 13279 0x33df "㏟" */
+0x00,0x08,0x14,0x22,0x3e,0x22,0x22,0x22,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x02,0x04,0x08,0x10,0x20,0x40,0xb4,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+/* 13280 0x33e0 "㏠" */
+0x00,0x10,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13281 0x33e1 "㏡" */
+0x00,0x18,0x24,0x24,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0x3c,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13282 0x33e2 "㏢" */
+0x00,0x18,0x24,0x24,0x04,0x04,0x04,0x18,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13283 0x33e3 "㏣" */
+0x00,0x24,0x24,0x24,0x24,0x24,0x24,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13284 0x33e4 "㏤" */
+0x00,0x3c,0x20,0x20,0x20,0x20,0x20,0x38,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13285 0x33e5 "㏥" */
+0x00,0x18,0x24,0x24,0x20,0x20,0x20,0x38,0x24,0x24,0x24,0x24,0x24,0x24,0x18,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13286 0x33e6 "㏦" */
+0x00,0x3c,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13287 0x33e7 "㏧" */
+0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x18,0x24,0x24,0x24,0x24,0x24,0x24,0x18,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13288 0x33e8 "㏨" */
+0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x18,0x04,0x04,0x04,0x04,0x24,0x24,0x18,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13289 0x33e9 "㏩" */
+0x00,0x26,0x69,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x76,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13290 0x33ea "㏪" */
+0x00,0x22,0x66,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x77,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13291 0x33eb "㏫" */
+0x00,0x26,0x69,0x29,0x21,0x21,0x22,0x22,0x22,0x24,0x24,0x24,0x28,0x28,0x7f,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13292 0x33ec "㏬" */
+0x00,0x26,0x69,0x29,0x21,0x21,0x21,0x26,0x21,0x21,0x21,0x21,0x29,0x29,0x76,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13293 0x33ed "㏭" */
+0x00,0x29,0x69,0x29,0x29,0x29,0x29,0x2f,0x21,0x21,0x21,0x21,0x21,0x21,0x71,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13294 0x33ee "㏮" */
+0x00,0x2f,0x68,0x28,0x28,0x28,0x28,0x2e,0x21,0x21,0x21,0x21,0x29,0x29,0x76,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13295 0x33ef "㏯" */
+0x00,0x26,0x69,0x29,0x28,0x28,0x28,0x2e,0x29,0x29,0x29,0x29,0x29,0x29,0x76,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13296 0x33f0 "㏰" */
+0x00,0x2f,0x61,0x21,0x21,0x22,0x22,0x22,0x24,0x24,0x24,0x24,0x24,0x24,0x74,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13297 0x33f1 "㏱" */
+0x00,0x26,0x69,0x29,0x29,0x29,0x29,0x26,0x29,0x29,0x29,0x29,0x29,0x29,0x76,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13298 0x33f2 "㏲" */
+0x00,0x26,0x69,0x29,0x29,0x29,0x29,0x26,0x21,0x21,0x21,0x21,0x29,0x29,0x76,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,
+/* 13299 0x33f3 "㏳" */
+0x00,0x31,0x4a,0x4a,0x0a,0x0a,0x12,0x12,0x12,0x22,0x22,0x22,0x42,0x42,0x79,0x00,
+0x00,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13300 0x33f4 "㏴" */
+0x00,0x31,0x4b,0x49,0x09,0x09,0x11,0x11,0x11,0x21,0x21,0x21,0x41,0x41,0x7b,0x00,
+0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x12,0x1e,0x92,0x12,
+/* 13301 0x33f5 "㏵" */
+0x00,0x31,0x4a,0x4a,0x08,0x08,0x10,0x10,0x10,0x21,0x21,0x21,0x42,0x42,0x7b,0x00,
+0x00,0x9e,0x52,0x52,0x52,0x52,0x92,0x9e,0x92,0x12,0x12,0x12,0x12,0x1e,0xd2,0x12,
+/* 13302 0x33f6 "㏶" */
+0x00,0x31,0x4a,0x4a,0x08,0x08,0x10,0x11,0x10,0x20,0x20,0x20,0x42,0x42,0x79,0x00,
+0x00,0x9e,0x52,0x52,0x52,0x52,0x52,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13303 0x33f7 "㏷" */
+0x00,0x32,0x4a,0x4a,0x0a,0x0a,0x12,0x13,0x10,0x20,0x20,0x20,0x40,0x40,0x78,0x00,
+0x00,0x5e,0x52,0x52,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x12,
+/* 13304 0x33f8 "㏸" */
+0x00,0x33,0x4a,0x4a,0x0a,0x0a,0x12,0x13,0x10,0x20,0x20,0x20,0x42,0x42,0x79,0x00,
+0x00,0xde,0x12,0x12,0x12,0x12,0x12,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13305 0x33f9 "㏹" */
+0x00,0x31,0x4a,0x4a,0x0a,0x0a,0x12,0x13,0x12,0x22,0x22,0x22,0x42,0x42,0x79,0x00,
+0x00,0x9e,0x52,0x52,0x12,0x12,0x12,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13306 0x33fa "㏺" */
+0x00,0x33,0x48,0x48,0x08,0x08,0x10,0x10,0x11,0x21,0x21,0x21,0x41,0x41,0x79,0x00,
+0x00,0xde,0x52,0x52,0x52,0x92,0x92,0x9e,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,
+/* 13307 0x33fb "㏻" */
+0x00,0x31,0x4a,0x4a,0x0a,0x0a,0x12,0x11,0x12,0x22,0x22,0x22,0x42,0x42,0x79,0x00,
+0x00,0x9e,0x52,0x52,0x52,0x52,0x52,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13308 0x33fc "㏼" */
+0x00,0x31,0x4a,0x4a,0x0a,0x0a,0x12,0x11,0x10,0x20,0x20,0x20,0x42,0x42,0x79,0x00,
+0x00,0x9e,0x52,0x52,0x52,0x52,0x52,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13309 0x33fd "㏽" */
+0x00,0x31,0x4a,0x4a,0x0a,0x0a,0x0a,0x32,0x0a,0x0a,0x0a,0x0a,0x4a,0x4a,0x31,0x00,
+0x00,0x9e,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x52,0x52,0x52,0x52,0x5e,0x92,0x12,
+/* 13310 0x33fe "㏾" */
+0x00,0x31,0x4b,0x49,0x09,0x09,0x09,0x31,0x09,0x09,0x09,0x09,0x49,0x49,0x33,0x00,
+0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x12,0x1e,0x92,0x12,
+/* 13311 0x33ff "㏿" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x34,0x49,0x48,0x48,0x31,0x21,0x39,0x44,0x44,0x38,
+0x00,0x00,0x06,0x02,0x02,0x02,0xe2,0x12,0x12,0xf2,0x12,0x12,0x32,0xd7,0x00,0x00,
+/* 13312 0x3400 "㐀" */
+0x04,0x04,0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xff,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 13313 0x3401 "㐁" */
+0x00,0xff,0x01,0x01,0x3f,0x21,0x21,0x21,0x22,0x22,0x24,0x28,0x20,0x20,0x3f,0x20,
+0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x88,0x48,0x28,0x28,0x08,0x08,0xf8,0x08,
+/* 13314 0x3402 "㐂" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x00,0x10,0x10,0x10,0x16,0xf8,0x10,0x11,0x16,0x18,
+0x00,0x00,0xf8,0x00,0x04,0x04,0xfc,0x00,0x20,0x20,0x3c,0xe0,0x22,0x22,0x1e,0x00,
+/* 13315 0x3403 "㐃" */
+0x01,0x02,0x04,0x08,0x10,0x20,0x40,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x80,0x40,0x20,0x10,0x08,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13316 0x3404 "㐄" */
+0x01,0x01,0x01,0x01,0x3f,0x01,0x21,0x21,0x41,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13317 0x3405 "㐅" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 13318 0x3406 "㐆" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x20,0x20,0x40,0x80,
+0x10,0xf8,0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x04,0x04,0x28,0x10,
+/* 13319 0x3407 "㐇" */
+0x02,0x02,0x3f,0x04,0x04,0x08,0x30,0xc0,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13320 0x3408 "㐈" */
+0x06,0x01,0x02,0x04,0x08,0x30,0xc0,0x3f,0x00,0x00,0x01,0x06,0x18,0x20,0x1f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0xf8,0x10,0x60,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 13321 0x3409 "㐉" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x05,0x02,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13322 0x340a "㐊" */
+0x01,0x01,0x01,0xff,0x01,0x01,0x3f,0x00,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13323 0x340b "㐋" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13324 0x340c "㐌" */
+0x08,0x08,0x1f,0x20,0x41,0x81,0x11,0x13,0x1d,0xf1,0x11,0x11,0x11,0x10,0x0f,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x70,0x90,0x10,0x10,0x50,0x22,0x02,0x02,0xfe,0x00,
+/* 13325 0x340d "㐍" */
+0x00,0x7f,0x02,0x21,0x11,0x10,0x00,0x3f,0x00,0x00,0x01,0x06,0x18,0x20,0x1f,0x00,
+0xfc,0x00,0x08,0x08,0x10,0x20,0x00,0xf8,0x10,0x60,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 13326 0x340e "㐎" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe0,0x00,0x3f,0x00,0x00,0x03,0x1c,0x20,0x1f,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0x00,0xf8,0x10,0x60,0x80,0x04,0x04,0xfc,
+/* 13327 0x340f "㐏" */
+0x00,0x3f,0x01,0x01,0x1f,0x02,0x04,0x7f,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xfe,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13328 0x3410 "㐐" */
+0x10,0x10,0xfe,0x22,0x44,0x28,0x10,0x28,0xc5,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x00,0x00,0xfc,0x84,0x88,0x50,0x20,0x58,0x86,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13329 0x3411 "㐑" */
+0x08,0x1f,0x28,0x07,0x18,0xe1,0x0c,0x03,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xf0,0x20,0xc0,0x30,0x8e,0x40,0x00,0x80,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13330 0x3412 "㐒" */
+0x00,0x7f,0x04,0x08,0x30,0xdf,0x10,0x10,0x1f,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x00,0xf8,0x08,0x50,0x20,0xf8,0x08,0x08,0xf8,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13331 0x3413 "㐓" */
+0x00,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfe,0x10,0x90,0x90,0x90,0x90,0x50,0x20,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13332 0x3414 "㐔" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13333 0x3415 "㐕" */
+0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13334 0x3416 "㐖" */
+0x08,0x08,0x08,0xff,0x08,0x08,0x7f,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,0x00,
+0x20,0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 13335 0x3417 "㐗" */
+0x02,0x3f,0x02,0xff,0x02,0x0c,0x3f,0xc8,0x07,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x08,0xd0,0x20,0xfe,0x00,0x70,0x84,0x04,0xfc,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13336 0x3418 "㐘" */
+0x01,0x11,0x09,0xff,0x05,0x09,0x31,0xc1,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0x10,0x20,0xfe,0x40,0x20,0x18,0x06,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13337 0x3419 "㐙" */
+0x00,0x7f,0x00,0x1f,0x10,0x1f,0x08,0x04,0xff,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x20,0x40,0xfe,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13338 0x341a "㐚" */
+0x7f,0x02,0x3f,0x04,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0xfc,0x00,0xf0,0x10,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13339 0x341b "㐛" */
+0x08,0x08,0x17,0x30,0x51,0x93,0x15,0x11,0x11,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x40,0x40,0xfc,0x80,0x00,0xf8,0x08,0x08,0xf8,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13340 0x341c "㐜" */
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0x92,0x54,0x10,0x38,0x54,0x92,0x11,0x52,0x24,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x8a,0x8a,0x0a,0x06,0x00,
+/* 13341 0x341d "㐝" */
+0x11,0x11,0xf9,0x12,0x19,0x31,0xd1,0x10,0x50,0x20,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x00,0x00,0xf8,0x08,0xe8,0x28,0xe8,0x08,0x50,0x20,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13342 0x341e "㐞" */
+0x08,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x10,0x2f,0x40,0x83,0x0c,0x10,0x0f,
+0x20,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0xe8,0x44,0x82,0x08,0x08,0xf8,
+/* 13343 0x341f "㐟" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 13344 0x3420 "㐠" */
+0x07,0xf8,0x48,0x25,0x7f,0x02,0x07,0xfc,0x44,0x0c,0x00,0x3f,0x01,0x1e,0x20,0x1f,
+0xa0,0x20,0xa0,0x20,0x20,0x20,0xa2,0x22,0x22,0x1e,0x00,0xf0,0xc0,0x04,0x04,0xfc,
+/* 13345 0x3421 "㐡" */
+0x20,0x27,0x20,0x23,0xfa,0x2a,0x2a,0x2a,0x28,0x2f,0x28,0x29,0x2a,0x48,0x47,0x80,
+0x00,0xfc,0x40,0xf8,0xa8,0xa8,0xa8,0x18,0x40,0xfc,0xa0,0x12,0x0a,0x02,0xfe,0x00,
+/* 13346 0x3422 "㐢" */
+0x20,0x17,0x82,0x49,0x13,0xe0,0x27,0x20,0x20,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x3c,0xc0,0x44,0x28,0xf8,0x10,0xfe,0x20,0xa0,0x40,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 13347 0x3423 "㐣" */
+0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x27,0x24,0x3f,0x20,0x2f,0x40,0x43,0x84,0x03,
+0x80,0xfe,0x80,0xf8,0x80,0xf0,0x90,0xf0,0x90,0xfc,0x80,0xf8,0x60,0x80,0x04,0xfc,
+/* 13348 0x3424 "㐤" */
+0x20,0x23,0x20,0x21,0xf9,0x29,0x29,0x29,0x29,0x29,0x29,0x2b,0x28,0x49,0x47,0x80,
+0x40,0xf8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfa,0xa2,0x12,0xfe,0x00,
+/* 13349 0x3425 "㐥" */
+0x10,0x29,0x45,0xb9,0x11,0x7d,0x11,0x55,0x3d,0xe3,0x00,0x3f,0x01,0x1e,0x20,0x1f,
+0x08,0xc8,0x5e,0x4a,0xca,0x4a,0xca,0x52,0x6a,0x84,0x00,0xf0,0xc0,0x04,0x04,0xfc,
+/* 13350 0x3426 "㐦" */
+0x3b,0x22,0x3b,0x24,0xff,0x10,0x27,0xc1,0x1f,0x01,0x03,0x3f,0x01,0x1e,0x20,0x1f,
+0xb8,0x08,0xb8,0x88,0xfe,0x50,0x88,0x06,0xf0,0x00,0x00,0xf0,0xc0,0x04,0x04,0xfc,
+/* 13351 0x3427 "㐧" */
+0x00,0x10,0x08,0x04,0x04,0x00,0x7f,0x01,0x02,0x04,0x08,0x30,0xc0,0x00,0x02,0x01,
+0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x84,0x88,0x90,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 13352 0x3428 "㐨" */
+0x00,0x7c,0x04,0x28,0x10,0x08,0xfe,0x12,0x14,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x04,0x28,0x10,0x08,0xfe,0x12,0x14,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 13353 0x3429 "㐩" */
+0x24,0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x24,0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+/* 13354 0x342a "㐪" */
+0x02,0x01,0x01,0xff,0x00,0x01,0x21,0x21,0x21,0x21,0x3f,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x88,0x40,0x20,0x18,0x06,
+/* 13355 0x342b "㐫" */
+0x02,0x01,0x01,0xff,0x00,0x08,0x04,0x22,0x21,0x22,0x24,0x28,0x20,0x20,0x3f,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x20,0x40,0x88,0x08,0x88,0x48,0x28,0x08,0x08,0xf8,0x08,
+/* 13356 0x342c "㐬" */
+0x02,0x01,0xff,0x04,0x08,0x10,0x3f,0x10,0x00,0x11,0x11,0x11,0x21,0x21,0x41,0x80,
+0x00,0x00,0xfe,0x00,0x20,0x10,0xf8,0x08,0x00,0x10,0x10,0x10,0x10,0x12,0x12,0x0e,
+/* 13357 0x342d "㐭" */
+0x02,0x01,0xff,0x00,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x08,0x08,0xf8,0x08,
+/* 13358 0x342e "㐮" */
+0x02,0x01,0xff,0x10,0x24,0x44,0x1f,0x04,0x1f,0x04,0x7f,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0x00,0xfe,0x10,0x48,0x44,0xf0,0x40,0xf0,0x40,0xfc,0x90,0x60,0x18,0x06,0x00,
+/* 13359 0x342f "㐯" */
+0x01,0x7f,0x08,0x1f,0x10,0x1f,0x00,0x1f,0x01,0x7f,0x09,0x3f,0xc8,0x0f,0x08,0x0f,
+0x00,0xfc,0x20,0xf0,0x10,0xf0,0x00,0xe0,0x00,0xfc,0x20,0xf8,0x26,0xe0,0x20,0xe0,
+/* 13360 0x3430 "㐰" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x10,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 13361 0x3431 "㐱" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x21,0xc6,0x38,0x00,0x07,0x38,0x00,0x03,0x7c,0x00,
+0x00,0x00,0x80,0x40,0x20,0x50,0x88,0x06,0x20,0xc0,0x00,0x18,0x60,0x80,0x00,0x00,
+/* 13362 0x3432 "㐲" */
+0x08,0x08,0x08,0x10,0x10,0x37,0x30,0x50,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 13363 0x3433 "㐳" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 13364 0x3434 "㐴" */
+0x08,0x08,0x08,0x10,0x11,0x31,0x32,0x54,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x16,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x84,0x48,0x28,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 13365 0x3435 "㐵" */
+0x08,0x0b,0x08,0x10,0x10,0x30,0x3f,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x10,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 13366 0x3436 "㐶" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x11,0x10,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 13367 0x3437 "㐷" */
+0x08,0x0f,0x08,0x10,0x12,0x32,0x32,0x53,0x90,0x10,0x10,0x17,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 13368 0x3438 "㐸" */
+0x08,0x08,0x08,0x10,0x11,0x31,0x32,0x54,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 13369 0x3439 "㐹" */
+0x09,0x09,0x09,0x12,0x14,0x31,0x30,0x50,0x93,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 13370 0x343a "㐺" */
+0x11,0x11,0x11,0x22,0x22,0x66,0x66,0xaa,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x23,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x48,0x88,0x84,0x02,
+/* 13371 0x343b "㐻" */
+0x08,0x08,0x08,0x10,0x13,0x32,0x32,0x52,0x92,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 13372 0x343c "㐼" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x53,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 13373 0x343d "㐽" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x52,0x92,0x12,0x12,0x13,0x14,0x14,0x18,0x10,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 13374 0x343e "㐾" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x37,0x51,0x91,0x11,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 13375 0x343f "㐿" */
+0x08,0x08,0x0b,0x10,0x10,0x33,0x30,0x50,0x90,0x17,0x10,0x10,0x10,0x10,0x11,0x10,
+0x10,0x78,0xc0,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 13376 0x3440 "㑀" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x50,0x90,0x10,0x11,0x11,0x12,0x12,0x14,0x18,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x88,0x48,0x44,0x02,
+/* 13377 0x3441 "㑁" */
+0x08,0x08,0x0a,0x12,0x12,0x32,0x33,0x50,0x90,0x10,0x14,0x14,0x14,0x14,0x17,0x10,
+0x40,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x40,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 13378 0x3442 "㑂" */
+0x10,0x17,0x10,0x20,0x20,0x67,0x64,0xa4,0x24,0x24,0x25,0x26,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x40,0x40,0x40,0xfc,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0x04,0x14,0x08,
+/* 13379 0x3443 "㑃" */
+0x12,0x12,0x12,0x24,0x25,0x69,0x6e,0xa2,0x24,0x24,0x29,0x2f,0x21,0x20,0x20,0x21,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 13380 0x3444 "㑄" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x37,0x52,0x92,0x12,0x12,0x13,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x48,0x28,0x28,0xfe,0x08,0x48,0x28,0x28,0xfe,0x08,0x08,0x50,0x20,
+/* 13381 0x3445 "㑅" */
+0x09,0x09,0x09,0x11,0x12,0x32,0x34,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 13382 0x3446 "㑆" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x33,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,0x00,
+/* 13383 0x3447 "㑇" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x33,0x50,0x90,0x10,0x11,0x10,0x10,0x10,0x13,0x10,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 13384 0x3448 "㑈" */
+0x08,0x08,0x08,0x17,0x10,0x31,0x31,0x52,0x93,0x10,0x11,0x11,0x12,0x14,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x80,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 13385 0x3449 "㑉" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa4,0x25,0x25,0x26,0x24,0x24,0x28,0x29,0x32,
+0x00,0xf8,0x08,0x08,0xf8,0x88,0x88,0xe8,0x28,0x28,0xa8,0x4a,0x4a,0x8a,0x06,0x02,
+/* 13386 0x344a "㑊" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x30,0x52,0x92,0x12,0x14,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x90,0x90,0x90,0x94,0x92,0x92,0x92,0x90,0x10,0x10,0x50,0x20,
+/* 13387 0x344b "㑋" */
+0x10,0x10,0x10,0x20,0x27,0x64,0x64,0xa4,0x24,0x27,0x24,0x24,0x24,0x24,0x27,0x24,
+0xa0,0xa0,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0xa4,0xfc,0x04,
+/* 13388 0x344c "㑌" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x52,0x92,0x12,0x12,0x13,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 13389 0x344d "㑍" */
+0x10,0x10,0x17,0x20,0x20,0x63,0x60,0xa0,0x27,0x20,0x21,0x21,0x22,0x24,0x28,0x20,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 13390 0x344e "㑎" */
+0x10,0x12,0x12,0x24,0x24,0x62,0x62,0xa0,0x20,0x24,0x24,0x24,0x24,0x24,0x27,0x20,
+0x00,0x48,0x48,0x90,0x90,0x48,0x48,0x00,0x40,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 13391 0x344f "㑏" */
+0x08,0x08,0x0b,0x12,0x14,0x30,0x30,0x53,0x90,0x11,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x14,0x10,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 13392 0x3450 "㑐" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x37,0x50,0x90,0x10,0x12,0x12,0x14,0x18,0x11,0x10,
+0x40,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 13393 0x3451 "㑑" */
+0x08,0x08,0x08,0x13,0x12,0x32,0x32,0x53,0x92,0x12,0x13,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 13394 0x3452 "㑒" */
+0x01,0x02,0x04,0x08,0x30,0xcf,0x01,0x01,0x1f,0x11,0x11,0x1f,0x02,0x04,0x18,0xe0,
+0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf0,0x10,0x10,0xf0,0x80,0x40,0x30,0x0e,
+/* 13395 0x3453 "㑓" */
+0x08,0x08,0x08,0x11,0x13,0x30,0x30,0x57,0x90,0x10,0x11,0x11,0x12,0x12,0x14,0x11,
+0x20,0x40,0x88,0x04,0xfe,0x42,0x40,0xfe,0x80,0xfc,0x44,0x44,0x28,0x10,0x68,0x86,
+/* 13396 0x3454 "㑔" */
+0x08,0x0b,0x08,0x10,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x04,
+/* 13397 0x3455 "㑕" */
+0x08,0x08,0x0a,0x12,0x12,0x33,0x30,0x50,0x90,0x11,0x12,0x14,0x10,0x10,0x10,0x17,
+0x20,0x20,0x22,0x22,0x22,0xfe,0x40,0x40,0xfc,0x04,0x84,0x48,0x50,0x20,0xc0,0x00,
+/* 13398 0x3456 "㑖" */
+0x11,0x11,0x11,0x22,0x22,0x66,0x66,0xaa,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,
+/* 13399 0x3457 "㑗" */
+0x08,0x09,0x0b,0x12,0x13,0x32,0x33,0x52,0x92,0x17,0x10,0x10,0x10,0x11,0x1e,0x10,
+0x80,0x00,0xf8,0x08,0xf8,0x08,0xfa,0x0a,0x0c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 13400 0x3458 "㑘" */
+0x10,0x10,0x10,0x2f,0x20,0x62,0x62,0xa2,0x2f,0x22,0x22,0x22,0x22,0x24,0x24,0x28,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xd2,0x94,0x94,0x88,0x8a,0x9a,0x26,0x42,
+/* 13401 0x3459 "㑙" */
+0x10,0x1f,0x14,0x24,0x24,0x67,0x64,0xa4,0x24,0x27,0x24,0x24,0x24,0x2f,0x20,0x20,
+0x00,0xfe,0x80,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0xd2,0x92,0x8e,0x80,
+/* 13402 0x345a "㑚" */
+0x10,0x17,0x12,0x22,0x22,0x67,0x62,0xa2,0x22,0x2f,0x22,0x22,0x22,0x24,0x25,0x28,
+0x00,0xde,0x52,0x52,0x54,0xd4,0x58,0x54,0x52,0xd2,0x52,0x5a,0x54,0x50,0x50,0x90,
+/* 13403 0x345b "㑛" */
+0x08,0x08,0x0f,0x10,0x10,0x37,0x34,0x54,0x97,0x10,0x10,0x11,0x12,0x1c,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 13404 0x345c "㑜" */
+0x12,0x12,0x12,0x22,0x2f,0x62,0x62,0xa2,0x23,0x2e,0x22,0x22,0x22,0x22,0x2a,0x25,
+0x08,0x1c,0x60,0x40,0xc0,0x40,0x7e,0xc8,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 13405 0x345d "㑝" */
+0x10,0x17,0x10,0x20,0x23,0x60,0x60,0xa7,0x21,0x21,0x2f,0x21,0x21,0x22,0x22,0x24,
+0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 13406 0x345e "㑞" */
+0x10,0x10,0x12,0x22,0x24,0x61,0x62,0xac,0x21,0x21,0x2f,0x21,0x21,0x22,0x22,0x24,
+0x40,0x40,0x44,0x44,0xa8,0x10,0x08,0x06,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 13407 0x345f "㑟" */
+0x08,0x08,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x17,0x10,0x10,0x11,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,0x02,
+/* 13408 0x3460 "㑠" */
+0x08,0x0a,0x0a,0x12,0x12,0x32,0x32,0x50,0x90,0x10,0x11,0x10,0x10,0x10,0x13,0x10,
+0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 13409 0x3461 "㑡" */
+0x10,0x17,0x14,0x24,0x24,0x67,0x64,0xa4,0x24,0x27,0x24,0x25,0x24,0x25,0x26,0x20,
+0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x34,0x28,0xa0,0x60,0x20,0x20,
+/* 13410 0x3462 "㑢" */
+0x09,0x09,0x09,0x13,0x11,0x31,0x31,0x57,0x91,0x11,0x12,0x12,0x17,0x12,0x10,0x10,
+0x00,0x00,0x1e,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0x1a,0x94,0xd0,0x50,0x10,0x10,
+/* 13411 0x3463 "㑣" */
+0x09,0x09,0x09,0x11,0x17,0x31,0x31,0x53,0x93,0x15,0x15,0x19,0x11,0x11,0x11,0x11,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 13412 0x3464 "㑤" */
+0x11,0x11,0x1f,0x21,0x21,0x60,0x67,0xa4,0x24,0x24,0x27,0x24,0x24,0x24,0x27,0x24,
+0x10,0x10,0xfe,0x10,0x10,0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x04,
+/* 13413 0x3465 "㑥" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x31,0x51,0x93,0x14,0x18,0x11,0x12,0x14,0x11,0x12,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0xfc,0x94,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 13414 0x3466 "㑦" */
+0x08,0x08,0x0b,0x12,0x12,0x33,0x32,0x52,0x92,0x13,0x12,0x12,0x12,0x14,0x15,0x1a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 13415 0x3467 "㑧" */
+0x10,0x13,0x10,0x27,0x20,0x61,0x62,0xac,0x23,0x20,0x20,0x27,0x20,0x20,0x21,0x20,
+0x38,0xc0,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf0,0x20,0x40,0xfc,0x40,0x40,0x40,0x80,
+/* 13416 0x3468 "㑨" */
+0x08,0x0b,0x0a,0x12,0x13,0x31,0x31,0x53,0x94,0x10,0x1f,0x10,0x10,0x11,0x12,0x1c,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 13417 0x3469 "㑩" */
+0x08,0x0b,0x0a,0x12,0x12,0x33,0x30,0x50,0x90,0x11,0x12,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfe,0x52,0x52,0x52,0xfe,0x20,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0x00,
+/* 13418 0x346a "㑪" */
+0x08,0x08,0x0f,0x11,0x10,0x30,0x31,0x56,0x91,0x11,0x11,0x11,0x11,0x11,0x12,0x14,
+0x40,0x20,0xfe,0x08,0x90,0x60,0x98,0x06,0x08,0xf8,0x08,0xf8,0x08,0x08,0x08,0x08,
+/* 13419 0x346b "㑫" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x33,0x50,0x90,0x10,0x11,0x15,0x15,0x15,0x18,0x10,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf0,0x10,0xa0,0x40,0x48,0x04,0x14,0x14,0xf0,0x00,
+/* 13420 0x346c "㑬" */
+0x12,0x12,0x12,0x22,0x2f,0x65,0x65,0xa5,0x25,0x29,0x25,0x22,0x22,0x25,0x25,0x28,
+0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 13421 0x346d "㑭" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa7,0x20,0x20,0x2f,0x22,0x22,0x22,0x24,0x28,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfe,0x08,0x08,0x08,0x08,0x08,
+/* 13422 0x346e "㑮" */
+0x08,0x0b,0x0a,0x10,0x13,0x30,0x31,0x51,0x91,0x11,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 13423 0x346f "㑯" */
+0x08,0x0f,0x08,0x10,0x13,0x32,0x32,0x53,0x92,0x13,0x12,0x12,0x13,0x10,0x11,0x12,
+0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x08,0x04,
+/* 13424 0x3470 "㑰" */
+0x09,0x09,0x0a,0x13,0x10,0x37,0x30,0x51,0x96,0x10,0x11,0x16,0x10,0x11,0x16,0x10,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 13425 0x3471 "㑱" */
+0x08,0x0b,0x08,0x10,0x17,0x30,0x31,0x52,0x94,0x10,0x17,0x10,0x11,0x12,0x1c,0x10,
+0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0x20,0x60,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 13426 0x3472 "㑲" */
+0x10,0x10,0x1f,0x20,0x20,0x67,0x65,0xa4,0x25,0x24,0x24,0x25,0x24,0x24,0x24,0x24,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x14,0xa4,0xf4,0x44,0x44,0xf4,0x44,0x44,0x54,0x08,
+/* 13427 0x3473 "㑳" */
+0x09,0x09,0x0b,0x14,0x12,0x33,0x30,0x51,0x96,0x13,0x14,0x1a,0x13,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x42,0x52,0xf2,0x82,0x14,0x08,0xfe,0x42,0x52,0xf2,0x82,0x14,0x08,
+/* 13428 0x3474 "㑴" */
+0x0b,0x08,0x09,0x10,0x13,0x30,0x37,0x54,0x93,0x12,0x12,0x10,0x13,0x11,0x10,0x17,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xf8,0x48,0x58,0x40,0xf8,0x10,0xe0,0x1e,
+/* 13429 0x3475 "㑵" */
+0x08,0x08,0x09,0x11,0x11,0x35,0x33,0x51,0x91,0x13,0x15,0x11,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x00,0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 13430 0x3476 "㑶" */
+0x09,0x09,0x09,0x12,0x15,0x30,0x33,0x50,0x92,0x11,0x17,0x10,0x11,0x16,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 13431 0x3477 "㑷" */
+0x11,0x12,0x14,0x27,0x20,0x60,0x67,0xa4,0x24,0x27,0x24,0x24,0x27,0x24,0x25,0x24,
+0x10,0x12,0x54,0xd8,0x10,0x12,0xd2,0x4e,0x40,0xd2,0x54,0x58,0xd0,0x52,0x52,0x8e,
+/* 13432 0x3478 "㑸" */
+0x08,0x08,0x0f,0x10,0x13,0x32,0x33,0x50,0x9f,0x10,0x13,0x12,0x13,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x00,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x28,0x10,
+/* 13433 0x3479 "㑹" */
+0x01,0x02,0x04,0x0f,0x31,0xdf,0x11,0x1f,0x11,0x1f,0x00,0x0f,0x08,0x0f,0x08,0x0f,
+0x00,0x80,0x40,0xe0,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x00,0xe0,0x20,0xe0,0x20,0xe0,
+/* 13434 0x347a "㑺" */
+0x08,0x08,0x09,0x13,0x15,0x31,0x31,0x51,0x91,0x11,0x13,0x10,0x10,0x11,0x12,0x14,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 13435 0x347b "㑻" */
+0x10,0x10,0x17,0x24,0x28,0x60,0x65,0xa5,0x28,0x23,0x20,0x24,0x24,0x24,0x27,0x20,
+0x80,0x40,0xfe,0x02,0x94,0x50,0x24,0x4a,0xfa,0x00,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 13436 0x347c "㑼" */
+0x10,0x10,0x10,0x2f,0x2a,0x6a,0x6a,0xaf,0x2a,0x2a,0x2a,0x2a,0x2f,0x28,0x20,0x20,
+0x10,0x10,0x3c,0xa4,0xc4,0xa8,0x90,0xa8,0xc6,0x80,0xbc,0xa4,0xa4,0xa4,0x3c,0x24,
+/* 13437 0x347d "㑽" */
+0x10,0x14,0x12,0x2f,0x28,0x63,0x62,0xa2,0x23,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,
+0x40,0x44,0x48,0xfe,0x02,0xf8,0x08,0x08,0xf8,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 13438 0x347e "㑾" */
+0x08,0x08,0x09,0x16,0x11,0x30,0x33,0x5f,0x90,0x13,0x10,0x13,0x10,0x13,0x12,0x13,
+0x40,0xfc,0x08,0x50,0x20,0xc0,0x20,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,
+/* 13439 0x347f "㑿" */
+0x12,0x14,0x12,0x20,0x23,0x62,0x63,0xa2,0x23,0x20,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x48,0x90,0x48,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 13440 0x3480 "㒀" */
+0x10,0x10,0x17,0x21,0x20,0x67,0x64,0xa5,0x24,0x25,0x25,0x25,0x25,0x24,0x24,0x24,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xf4,0x44,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 13441 0x3481 "㒁" */
+0x10,0x17,0x14,0x24,0x25,0x64,0x67,0xa5,0x24,0x25,0x24,0x27,0x24,0x24,0x27,0x24,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0xfc,0x14,0xa4,0xf4,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 13442 0x3482 "㒂" */
+0x09,0x09,0x0f,0x11,0x10,0x33,0x30,0x50,0x97,0x10,0x11,0x13,0x15,0x19,0x11,0x11,
+0x08,0x08,0xfe,0x08,0x44,0xf4,0x48,0x50,0xfe,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 13443 0x3483 "㒃" */
+0x08,0x0b,0x08,0x13,0x10,0x33,0x30,0x53,0x92,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x14,0xfe,0x10,0xd0,0x10,0xd0,0x10,0xd0,0x50,0xd0,0x50,0xc8,0x4a,0xca,0x86,0x42,
+/* 13444 0x3484 "㒄" */
+0x09,0x09,0x09,0x12,0x12,0x35,0x30,0x52,0x91,0x11,0x12,0x14,0x10,0x12,0x12,0x14,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 13445 0x3485 "㒅" */
+0x08,0x0b,0x08,0x10,0x13,0x30,0x33,0x50,0x91,0x10,0x10,0x13,0x10,0x11,0x16,0x10,
+0x20,0xfe,0x40,0xf8,0x48,0x30,0xd0,0x3c,0xc4,0x48,0x30,0xc4,0xa8,0x90,0xa8,0xc6,
+/* 13446 0x3486 "㒆" */
+0x08,0x08,0x09,0x16,0x10,0x33,0x32,0x53,0x90,0x17,0x10,0x14,0x12,0x14,0x12,0x11,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 13447 0x3487 "㒇" */
+0x11,0x11,0x13,0x26,0x2a,0x62,0x67,0xa2,0x22,0x22,0x2f,0x20,0x22,0x22,0x24,0x20,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 13448 0x3488 "㒈" */
+0x10,0x17,0x10,0x21,0x2f,0x64,0x64,0xa7,0x24,0x27,0x24,0x24,0x27,0x2c,0x20,0x20,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 13449 0x3489 "㒉" */
+0x08,0x0a,0x09,0x17,0x14,0x31,0x31,0x51,0x91,0x10,0x17,0x10,0x11,0x12,0x14,0x10,
+0x40,0x48,0x50,0xfc,0x04,0xf0,0x10,0x10,0xf0,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 13450 0x348a "㒊" */
+0x10,0x17,0x12,0x26,0x2a,0x64,0x65,0xa8,0x21,0x21,0x25,0x25,0x25,0x25,0x2e,0x20,
+0x00,0xbc,0x94,0xb4,0xd4,0xa4,0xac,0x40,0x08,0x08,0xa8,0x2c,0x28,0xa8,0x7e,0x00,
+/* 13451 0x348b "㒋" */
+0x14,0x14,0x14,0x2f,0x24,0x67,0x64,0xa7,0x24,0x24,0x2f,0x20,0x25,0x28,0x30,0x20,
+0x80,0x82,0x9c,0xd0,0x90,0x90,0x9e,0x94,0x94,0x94,0xd4,0x14,0x14,0xa4,0x24,0x44,
+/* 13452 0x348c "㒌" */
+0x11,0x15,0x15,0x29,0x22,0x64,0x60,0xa7,0x24,0x29,0x21,0x21,0x21,0x22,0x24,0x28,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0x00,0xfc,0x04,0xe8,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 13453 0x348d "㒍" */
+0x08,0x09,0x0b,0x12,0x14,0x37,0x30,0x51,0x93,0x10,0x10,0x17,0x10,0x12,0x15,0x10,
+0x80,0x10,0xf8,0x10,0xa4,0xbc,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x48,0x44,0x80,
+/* 13454 0x348e "㒎" */
+0x08,0x0b,0x08,0x17,0x11,0x32,0x3c,0x50,0x97,0x10,0x13,0x10,0x17,0x10,0x10,0x10,
+0x00,0xf8,0x80,0xfc,0x10,0x08,0xa6,0xa0,0xbc,0xa0,0xb8,0xa0,0xbc,0xa0,0xa0,0xa0,
+/* 13455 0x348f "㒏" */
+0x08,0x08,0x0f,0x14,0x13,0x30,0x33,0x50,0x97,0x11,0x12,0x14,0x10,0x11,0x10,0x10,
+0x40,0x20,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0x04,0x62,0x10,0x80,0x60,0x10,
+/* 13456 0x3490 "㒐" */
+0x09,0x09,0x09,0x12,0x14,0x31,0x31,0x52,0x95,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x10,0x10,0xde,0xa8,0x44,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x14,0x28,0x10,
+/* 13457 0x3491 "㒑" */
+0x10,0x17,0x14,0x26,0x25,0x64,0x64,0xa4,0x26,0x25,0x24,0x24,0x25,0x26,0x27,0x20,
+0x00,0xfe,0x28,0x24,0x7e,0x48,0xc8,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x40,0xfe,0x00,
+/* 13458 0x3492 "㒒" */
+0x10,0x14,0x12,0x20,0x27,0x61,0x60,0xa7,0x20,0x23,0x20,0x27,0x21,0x22,0x2c,0x20,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0x50,0x48,0x46,0x40,
+/* 13459 0x3493 "㒓" */
+0x10,0x14,0x12,0x20,0x20,0x60,0x66,0xa2,0x22,0x22,0x22,0x22,0x22,0x22,0x25,0x28,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 13460 0x3494 "㒔" */
+0x10,0x17,0x14,0x24,0x27,0x62,0x63,0xa4,0x2b,0x22,0x23,0x20,0x20,0x27,0x22,0x20,
+0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xfe,0x42,0xfa,0x4a,0xfa,0x52,0x7a,0x8a,0x14,0x08,
+/* 13461 0x3495 "㒕" */
+0x10,0x10,0x17,0x20,0x22,0x62,0x64,0xa7,0x21,0x22,0x24,0x2f,0x21,0x22,0x24,0x28,
+0x40,0x20,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x7e,0x40,
+/* 13462 0x3496 "㒖" */
+0x11,0x11,0x17,0x21,0x23,0x62,0x63,0xa2,0x23,0x20,0x27,0x24,0x24,0x25,0x24,0x24,
+0x10,0x10,0xfc,0x10,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xf4,0x14,0x0c,
+/* 13463 0x3497 "㒗" */
+0x11,0x17,0x11,0x21,0x21,0x61,0x61,0xa7,0x24,0x2b,0x21,0x23,0x20,0x23,0x20,0x27,
+0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xf8,0x40,0xfc,
+/* 13464 0x3498 "㒘" */
+0x10,0x17,0x15,0x27,0x24,0x67,0x65,0xa7,0x20,0x20,0x27,0x20,0x22,0x21,0x2f,0x20,
+0x00,0xbc,0x14,0x94,0x88,0x88,0x14,0xa2,0x80,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,
+/* 13465 0x3499 "㒙" */
+0x11,0x11,0x12,0x22,0x24,0x6f,0x61,0xa2,0x24,0x2f,0x20,0x20,0x2a,0x2a,0x28,0x20,
+0x08,0x10,0x3e,0xa2,0xbe,0x22,0x3e,0x08,0xbe,0xaa,0xaa,0x2a,0xaa,0xae,0x08,0x08,
+/* 13466 0x349a "㒚" */
+0x10,0x17,0x12,0x21,0x23,0x60,0x67,0xa0,0x23,0x20,0x23,0x20,0x23,0x25,0x25,0x28,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 13467 0x349b "㒛" */
+0x10,0x17,0x10,0x24,0x22,0x64,0x61,0xa2,0x27,0x2a,0x23,0x22,0x23,0x22,0x23,0x22,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 13468 0x349c "㒜" */
+0x09,0x0a,0x0a,0x12,0x13,0x32,0x32,0x53,0x92,0x12,0x17,0x10,0x11,0x11,0x12,0x14,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 13469 0x349d "㒝" */
+0x09,0x0f,0x09,0x10,0x13,0x32,0x32,0x53,0x90,0x13,0x12,0x13,0x12,0x12,0x14,0x18,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 13470 0x349e "㒞" */
+0x08,0x0a,0x0b,0x10,0x11,0x33,0x35,0x51,0x91,0x11,0x11,0x11,0x13,0x12,0x12,0x12,
+0x20,0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xde,0x52,0x72,0x06,
+/* 13471 0x349f "㒟" */
+0x10,0x17,0x10,0x23,0x22,0x63,0x62,0xa3,0x22,0x23,0x20,0x25,0x20,0x23,0x2d,0x21,
+0x40,0xfe,0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0xa8,0x10,0x48,0x86,
+/* 13472 0x34a0 "㒠" */
+0x11,0x11,0x15,0x27,0x24,0x6a,0x61,0xa2,0x27,0x20,0x23,0x20,0x27,0x20,0x2f,0x20,
+0x00,0xbc,0x24,0xa8,0x90,0xa8,0x46,0xa0,0xbc,0xa0,0xb8,0xa0,0xbc,0xa0,0xfe,0x00,
+/* 13473 0x34a1 "㒡" */
+0x11,0x1e,0x10,0x2a,0x25,0x64,0x67,0xaa,0x22,0x2f,0x22,0x2a,0x2a,0x2b,0x2e,0x20,
+0x82,0x3c,0x88,0x90,0x22,0x3c,0x88,0x12,0x3e,0x88,0x08,0xac,0xaa,0xca,0xa8,0x90,
+/* 13474 0x34a2 "㒢" */
+0x10,0x10,0x11,0x22,0x2d,0x60,0x6e,0xaa,0x2e,0x20,0x2f,0x29,0x2f,0x29,0x29,0x28,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xee,0xaa,0xee,0x00,0xfe,0x22,0xfe,0x22,0x2a,0x04,
+/* 13475 0x34a3 "㒣" */
+0x10,0x10,0x17,0x24,0x24,0x65,0x67,0xa5,0x25,0x25,0x25,0x25,0x28,0x2a,0x32,0x24,
+0x40,0x20,0xfe,0xa8,0xfe,0x50,0x7c,0x50,0x7c,0x50,0x7e,0x40,0xa4,0x8a,0x8a,0x78,
+/* 13476 0x34a4 "㒤" */
+0x0b,0x09,0x09,0x11,0x11,0x31,0x37,0x50,0x97,0x12,0x13,0x12,0x13,0x12,0x17,0x10,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 13477 0x34a5 "㒥" */
+0x11,0x13,0x15,0x27,0x25,0x67,0x65,0xa7,0x20,0x27,0x20,0x23,0x22,0x23,0x21,0x2f,
+0x50,0xf8,0x54,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x10,0xfe,
+/* 13478 0x34a6 "㒦" */
+0x17,0x14,0x17,0x24,0x27,0x60,0x6f,0xaa,0x2f,0x2a,0x2f,0x20,0x20,0x27,0x20,0x2f,
+0xfc,0x44,0xfc,0x44,0xfc,0x00,0xbe,0xaa,0xbe,0xaa,0xbe,0x40,0x40,0xfc,0x40,0xfe,
+/* 13479 0x34a7 "㒧" */
+0x14,0x12,0x1f,0x25,0x2a,0x6d,0x68,0xaf,0x22,0x2f,0x2a,0x2a,0x2b,0x28,0x2a,0x29,
+0x18,0x14,0x90,0x3e,0xa8,0xe8,0xbe,0xa8,0x28,0xbe,0xa8,0xa8,0xa8,0xbe,0xa0,0x20,
+/* 13480 0x34a8 "㒨" */
+0x10,0x15,0x19,0x29,0x2d,0x69,0x69,0xad,0x20,0x2f,0x22,0x25,0x29,0x21,0x21,0x20,
+0x40,0xf6,0x12,0xb2,0x56,0xb2,0x12,0xf6,0x80,0xfe,0x08,0xf4,0x12,0xf0,0x04,0xfc,
+/* 13481 0x34a9 "㒩" */
+0x11,0x12,0x13,0x20,0x27,0x61,0x66,0xa1,0x26,0x21,0x22,0x2f,0x2a,0x2f,0x22,0x2f,
+0xf0,0x10,0xe0,0x20,0xfc,0x88,0x50,0xa8,0x64,0xa0,0x48,0xbe,0xaa,0xbe,0x8a,0xbe,
+/* 13482 0x34aa "㒪" */
+0x03,0x0c,0x3e,0xe8,0x3e,0x22,0x3e,0x28,0x3e,0x10,0x11,0x5c,0x51,0x50,0x5d,0xe0,
+0x80,0x60,0xf8,0xa6,0xf8,0x88,0xf8,0xa0,0xf8,0x00,0xfc,0xa0,0x54,0xb8,0x54,0xb2,
+/* 13483 0x34ab "㒫" */
+0x00,0x0f,0x08,0x08,0x0f,0x08,0x08,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0xf8,0x00,0x00,0xf0,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 13484 0x34ac "㒬" */
+0x00,0x7d,0x00,0x00,0x00,0xfc,0x28,0x28,0x28,0x28,0x29,0x28,0x28,0x48,0x47,0x80,
+0x00,0xfc,0x20,0x20,0x20,0xf8,0x20,0x20,0x20,0x20,0xfc,0x00,0x00,0x02,0xfe,0x00,
+/* 13485 0x34ad "㒭" */
+0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x14,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x81,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x28,0x28,0x28,0x28,0x4a,0x4a,0x8a,0x86,0x00,
+/* 13486 0x34ae "㒮" */
+0x00,0x01,0x78,0x00,0x00,0x03,0xfc,0x28,0x2b,0x28,0x28,0x2b,0x28,0x48,0x47,0x80,
+0x00,0xfe,0x20,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x92,0x50,0x22,0x02,0xfe,0x00,
+/* 13487 0x34af "㒯" */
+0x10,0x13,0x90,0x54,0x59,0x10,0xfc,0x2b,0x28,0x28,0x29,0x28,0x2b,0x4c,0x48,0x80,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 13488 0x34b0 "㒰" */
+0x06,0x01,0x02,0x04,0x08,0x30,0xc0,0x00,0x1f,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 13489 0x34b1 "㒱" */
+0x06,0x01,0x02,0x04,0x08,0x32,0xc2,0x07,0x08,0x14,0x22,0x01,0x00,0x03,0x1c,0xe0,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 13490 0x34b2 "㒲" */
+0x06,0x01,0x02,0x04,0x08,0x30,0xdf,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x80,0x40,0x20,0x18,0xf6,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 13491 0x34b3 "㒳" */
+0x00,0x7f,0x41,0x41,0x41,0x51,0x49,0x49,0x55,0x63,0x41,0x41,0x41,0x41,0x41,0x41,
+0x00,0xfc,0x04,0x04,0x04,0x44,0x24,0x24,0x54,0x8c,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 13492 0x34b4 "㒴" */
+0x06,0x01,0x02,0x04,0x08,0x31,0xd1,0x11,0x11,0x1f,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x16,0x10,0x10,0xf0,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 13493 0x34b5 "㒵" */
+0x04,0x08,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x00,0x00,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0x40,0x20,0x10,0x08,0x04,
+/* 13494 0x34b6 "㒶" */
+0x04,0x04,0x08,0x10,0x21,0xc2,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x20,0x10,0x08,0x06,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 13495 0x34b7 "㒷" */
+0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x14,0x10,0x10,0x7f,0x00,0x04,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x10,0x10,0xfc,0x00,0x40,0x20,0x10,0x08,
+/* 13496 0x34b8 "㒸" */
+0x08,0x04,0x04,0x7f,0x02,0x06,0x19,0x62,0x04,0x18,0x61,0x02,0x0c,0x30,0xc2,0x01,
+0x20,0x20,0x40,0xfc,0x00,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x80,0x00,
+/* 13497 0x34b9 "㒹" */
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x28,0x44,0x82,
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x28,0x44,0x82,
+/* 13498 0x34ba "㒺" */
+0x00,0x7f,0x40,0x48,0x44,0x5f,0x40,0x48,0x48,0x49,0x4a,0x48,0x4f,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x24,0x44,0xf4,0x04,0x84,0x84,0x44,0x24,0x04,0xf4,0x04,0x14,0x08,
+/* 13499 0x34bb "㒻" */
+0x7f,0x40,0x5f,0x40,0x5f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0xfc,0x04,0xf4,0x04,0xf4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 13500 0x34bc "㒼" */
+0x08,0x08,0xff,0x08,0x08,0x0f,0x01,0x7f,0x41,0x51,0x49,0x55,0x63,0x41,0x41,0x41,
+0x20,0x20,0xfe,0x20,0x20,0xe0,0x00,0xfc,0x04,0x44,0x24,0x54,0x8c,0x04,0x14,0x08,
+/* 13501 0x34bd "㒽" */
+0x3f,0x20,0x2f,0x20,0x2f,0x11,0x09,0x7f,0x04,0xff,0x10,0x2f,0xc8,0x08,0x08,0x07,
+0xf8,0x08,0xe8,0x08,0xe8,0x10,0x20,0xfc,0x00,0xfe,0x10,0xe8,0x26,0xa0,0x48,0xf8,
+/* 13502 0x34be "㒾" */
+0x00,0x3f,0x20,0x2f,0x20,0x2f,0x20,0x10,0xfe,0x21,0x3c,0x24,0x27,0x44,0x54,0x88,
+0x00,0xf8,0x08,0xe8,0x08,0xe8,0x40,0x40,0xfe,0x20,0xac,0xf4,0xa4,0xac,0xa2,0x7e,
+/* 13503 0x34bf "㒿" */
+0x3f,0x20,0x2f,0x20,0x2f,0x08,0x7f,0x14,0x49,0x55,0x7f,0x08,0x7f,0x55,0x5d,0x43,
+0xf8,0x08,0xe8,0x08,0xe8,0x00,0x28,0x24,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,0x40,
+/* 13504 0x34c0 "㓀" */
+0x00,0x7f,0x40,0x80,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 13505 0x34c1 "㓁" */
+0x00,0x00,0x7f,0x40,0x84,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x02,0x44,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13506 0x34c2 "㓂" */
+0x00,0x7f,0x40,0x80,0x3e,0x01,0x00,0x7e,0x14,0x14,0x14,0x14,0x25,0x24,0x43,0x80,
+0x00,0xfe,0x02,0x24,0x20,0xfe,0x44,0x44,0xc8,0x28,0x10,0x6a,0x86,0x02,0xfe,0x00,
+/* 13507 0x34c3 "㓃" */
+0x00,0x7f,0x40,0x90,0x08,0x7f,0x00,0x3e,0x00,0x3e,0x01,0x3e,0x22,0x22,0x3e,0x22,
+0x00,0xfe,0x02,0x04,0x00,0x1c,0xe0,0x20,0x20,0x3e,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 13508 0x34c4 "㓄" */
+0x10,0x22,0x7f,0x42,0x94,0xf7,0x08,0x36,0xc9,0x30,0xc4,0x19,0x62,0x0c,0x30,0xc1,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0xa8,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 13509 0x34c5 "㓅" */
+0x00,0x40,0x23,0x20,0x00,0x08,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 13510 0x34c6 "㓆" */
+0x00,0x40,0x20,0x20,0x01,0x0a,0x0c,0x11,0x11,0xe1,0x21,0x21,0x21,0x21,0x20,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 13511 0x34c7 "㓇" */
+0x00,0x40,0x27,0x20,0x00,0x08,0x08,0x17,0x10,0xe0,0x20,0x21,0x21,0x22,0x24,0x08,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 13512 0x34c8 "㓈" */
+0x00,0x40,0x27,0x20,0x00,0x08,0x08,0x11,0x13,0xe5,0x29,0x21,0x21,0x21,0x21,0x01,
+0x00,0x00,0xfe,0x40,0x40,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 13513 0x34c9 "㓉" */
+0x00,0x40,0x23,0x20,0x00,0x07,0x10,0x10,0x20,0xe3,0x22,0x22,0x22,0x22,0x23,0x02,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 13514 0x34ca "㓊" */
+0x00,0x47,0x24,0x24,0x05,0x04,0x14,0x15,0x25,0xe5,0x25,0x25,0x24,0x24,0x24,0x04,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x04,0x14,0x08,
+/* 13515 0x34cb "㓋" */
+0x01,0x41,0x21,0x21,0x07,0x01,0x11,0x11,0x21,0xef,0x20,0x21,0x21,0x22,0x24,0x08,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 13516 0x34cc "㓌" */
+0x00,0x40,0x20,0x21,0x02,0x04,0x13,0x10,0x20,0xe0,0x23,0x20,0x20,0x20,0x27,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 13517 0x34cd "㓍" */
+0x00,0x40,0x20,0x27,0x00,0x01,0x12,0x17,0x21,0xe1,0x21,0x21,0x22,0x22,0x24,0x08,
+0x80,0x40,0x40,0xfe,0x80,0x10,0x08,0xfc,0x24,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 13518 0x34ce "㓎" */
+0x00,0x43,0x20,0x21,0x00,0x0b,0x08,0x17,0x14,0xe3,0x21,0x21,0x20,0x20,0x21,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf0,0x10,0x10,0xa0,0x40,0xb0,0x0e,
+/* 13519 0x34cf "㓏" */
+0x00,0x47,0x24,0x24,0x05,0x06,0x14,0x15,0x25,0xe5,0x25,0x25,0x25,0x24,0x24,0x04,
+0x00,0xfc,0x04,0xa4,0x14,0x0c,0x04,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0x14,0x08,
+/* 13520 0x34d0 "㓐" */
+0x00,0x40,0x23,0x20,0x00,0x07,0x11,0x12,0x24,0xe0,0x23,0x20,0x20,0x20,0x27,0x00,
+0x40,0x40,0xf8,0x40,0x40,0xfc,0x10,0x08,0x44,0x40,0xf8,0x40,0x40,0x40,0xfc,0x00,
+/* 13521 0x34d1 "㓑" */
+0x00,0x40,0x27,0x20,0x00,0x0f,0x11,0x10,0x27,0xe0,0x20,0x2f,0x20,0x20,0x20,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0xa0,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 13522 0x34d2 "㓒" */
+0x20,0x10,0x04,0x0b,0x70,0x10,0x11,0x12,0x0c,0x31,0xc1,0x09,0x11,0x21,0x05,0x02,
+0x40,0x40,0x78,0xc4,0x44,0x3c,0x00,0x80,0x60,0x18,0x06,0x90,0x48,0x48,0x00,0x00,
+/* 13523 0x34d3 "㓓" */
+0x00,0x40,0x2f,0x20,0x00,0x07,0x15,0x14,0x25,0xe4,0x24,0x25,0x24,0x24,0x24,0x04,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x14,0xa4,0xf4,0x44,0x44,0xf4,0x44,0x44,0x54,0x08,
+/* 13524 0x34d4 "㓔" */
+0x01,0x42,0x27,0x24,0x07,0x04,0x17,0x14,0x24,0xef,0x21,0x22,0x24,0x28,0x22,0x01,
+0x08,0x08,0x88,0x88,0xbe,0x88,0x88,0xc8,0xa8,0xa8,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 13525 0x34d5 "㓕" */
+0x00,0x40,0x20,0x27,0x04,0x04,0x17,0x14,0x24,0xe5,0x26,0x24,0x25,0x29,0x2a,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xf2,0x92,0x92,0xb4,0xd4,0x88,0x4a,0x3a,0x26,0x42,
+/* 13526 0x34d6 "㓖" */
+0x00,0x47,0x24,0x27,0x04,0x07,0x12,0x12,0x2f,0xe2,0x22,0x27,0x20,0x2f,0x20,0x00,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0xfe,0x40,0x40,
+/* 13527 0x34d7 "㓗" */
+0x01,0x47,0x21,0x23,0x01,0x07,0x11,0x10,0x21,0xe3,0x20,0x27,0x20,0x22,0x25,0x00,
+0x00,0xbc,0x14,0x94,0x14,0xa4,0x4c,0x80,0x10,0xe0,0x48,0xfc,0x44,0x48,0x44,0x80,
+/* 13528 0x34d8 "㓘" */
+0x00,0x3f,0x20,0x2f,0x21,0x23,0x24,0x2a,0x21,0x26,0x3b,0x21,0x2f,0x41,0x41,0x9f,
+0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0x88,0x08,0x08,0xe8,0x0a,0xea,0x4a,0x26,0xf2,
+/* 13529 0x34d9 "㓙" */
+0x02,0x01,0x01,0x1f,0x40,0x48,0x44,0x42,0x41,0x42,0x44,0x48,0x50,0x40,0x7f,0x00,
+0x00,0x00,0x00,0xf0,0x44,0x44,0x84,0x84,0x04,0x84,0x44,0x24,0x24,0x04,0xfc,0x04,
+/* 13530 0x34da "㓚" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0xf0,0x40,0x00,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13531 0x34db "㓛" */
+0x00,0x01,0x00,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x0e,0xf0,0x41,0x01,0x02,0x04,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 13532 0x34dc "㓜" */
+0x08,0x08,0x10,0x10,0x22,0x42,0xfc,0x04,0x08,0x10,0x24,0x42,0xfe,0x42,0x00,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 13533 0x34dd "㓝" */
+0x22,0x22,0x22,0x22,0x7f,0x22,0x22,0x22,0xff,0x22,0x22,0x22,0x22,0x42,0x42,0x82,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13534 0x34de "㓞" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x09,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x44,0x44,0x94,0x08,
+/* 13535 0x34df "㓟" */
+0x04,0x04,0x04,0x3f,0x24,0x25,0x24,0x3f,0x20,0x29,0x25,0x22,0x25,0x48,0x90,0x00,
+0x04,0x04,0x04,0xa4,0xa4,0x24,0x24,0xa4,0xa4,0x24,0x24,0x24,0x04,0x84,0x94,0x08,
+/* 13536 0x34e0 "㓠" */
+0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x04,0x04,0x04,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13537 0x34e1 "㓡" */
+0x20,0x20,0x3f,0x48,0x88,0x08,0xff,0x08,0x08,0x49,0x49,0x49,0x4f,0x79,0x01,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x04,0x14,0x08,
+/* 13538 0x34e2 "㓢" */
+0x10,0x10,0x1f,0x21,0x61,0x92,0x0c,0x12,0x21,0xc0,0x3f,0x21,0x21,0x21,0x3f,0x21,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13539 0x34e3 "㓣" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13540 0x34e4 "㓤" */
+0x08,0x08,0x08,0xff,0x08,0x08,0x7f,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,0x00,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13541 0x34e5 "㓥" */
+0x08,0x49,0x29,0x29,0x2a,0x08,0xff,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0xff,0x01,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13542 0x34e6 "㓦" */
+0x00,0xff,0x08,0x08,0x10,0x7f,0x41,0x41,0x41,0x7f,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x04,0xc4,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13543 0x34e7 "㓧" */
+0x08,0x08,0x14,0x22,0x51,0x88,0x7e,0x02,0x04,0x08,0x7f,0x41,0x41,0x41,0x7f,0x41,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13544 0x34e8 "㓨" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x14,0x12,0x21,0x41,0x80,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13545 0x34e9 "㓩" */
+0x10,0x10,0x1f,0x21,0x42,0xbf,0x24,0x24,0x3f,0x24,0x24,0x3f,0x24,0x44,0x42,0x81,
+0x04,0x04,0x04,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 13546 0x34ea "㓪" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x48,0x44,0x4a,0x52,0x60,0x41,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 13547 0x34eb "㓫" */
+0x08,0x08,0xff,0x12,0x21,0x40,0xbf,0x12,0x12,0x12,0x7f,0x12,0x12,0x22,0x22,0x42,
+0x04,0x04,0xc4,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0xa4,0x24,0x04,0x04,0x14,0x08,
+/* 13548 0x34ec "㓬" */
+0x08,0x49,0x2a,0x7f,0x08,0x10,0xff,0x22,0x41,0x80,0x7f,0x11,0x11,0x21,0x4a,0x84,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13549 0x34ed "㓭" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x20,0x7f,0x88,0x48,0x54,0x40,0x7e,0x00,0x05,0x02,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x14,0x08,
+/* 13550 0x34ee "㓮" */
+0x00,0x3f,0x24,0x24,0x2e,0x24,0x3f,0x20,0x2e,0x2a,0x2a,0x2e,0x20,0x40,0x42,0x81,
+0x04,0x84,0x84,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 13551 0x34ef "㓯" */
+0x24,0x24,0x49,0x92,0x49,0x24,0x24,0x00,0x7f,0x48,0x48,0x7f,0x48,0x48,0x7f,0x40,
+0x84,0x84,0x04,0x24,0x24,0xa4,0xa4,0x24,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x88,
+/* 13552 0x34f0 "㓰" */
+0x00,0xff,0x08,0x08,0x3e,0xaa,0xaa,0xbe,0xaa,0xaa,0xaa,0xbe,0x80,0x8f,0xf0,0x00,
+0x04,0x84,0x04,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 13553 0x34f1 "㓱" */
+0x08,0x14,0x22,0x41,0xbe,0x00,0x78,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x48,0x4a,0x59,
+0x04,0x04,0x04,0x24,0xa4,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 13554 0x34f2 "㓲" */
+0x08,0x04,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x35,0x35,0x5f,0x55,0x55,0x94,0x10,
+0x02,0x02,0xc2,0x42,0x52,0xd2,0x12,0x12,0xd2,0x52,0x52,0xd2,0x42,0x42,0x4a,0xc4,
+/* 13555 0x34f3 "㓳" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x08,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,0x00,0xfe,0x00,
+/* 13556 0x34f4 "㓴" */
+0x00,0xff,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x4b,0x08,0xff,0x14,0x22,0x41,0x80,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x04,0x04,0x14,0x88,
+/* 13557 0x34f5 "㓵" */
+0x00,0xf7,0x94,0x94,0xf7,0x00,0x7f,0x00,0xff,0x20,0x40,0x7f,0x01,0x01,0x0a,0x04,
+0x04,0x84,0x84,0xa4,0xa4,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13558 0x34f6 "㓶" */
+0x20,0x2f,0xf5,0x25,0x75,0x25,0xf5,0x29,0x23,0x08,0x08,0xff,0x14,0x22,0x41,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x04,0x04,0x14,0x88,
+/* 13559 0x34f7 "㓷" */
+0x08,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x04,0x04,0x14,0x08,
+/* 13560 0x34f8 "㓸" */
+0x00,0x77,0x55,0x55,0x77,0x14,0x14,0x77,0x41,0x41,0x77,0x14,0x14,0x1f,0xf0,0x40,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13561 0x34f9 "㓹" */
+0x00,0x7f,0x44,0x54,0x65,0x44,0x4a,0x51,0x60,0x44,0x54,0x65,0x44,0x4a,0x91,0x20,
+0x04,0xc4,0x04,0xa4,0x24,0x24,0x24,0x24,0xa4,0x24,0xa4,0x24,0x04,0x04,0x14,0x88,
+/* 13562 0x34fa "㓺" */
+0x08,0x0f,0x08,0x7f,0x48,0x4f,0x78,0x47,0x48,0x44,0x7f,0x41,0x5a,0x44,0x8a,0x31,
+0x04,0x84,0x04,0xa4,0xa4,0x24,0xa4,0xa4,0x24,0x24,0xa4,0x24,0x04,0x04,0x14,0x08,
+/* 13563 0x34fb "㓻" */
+0x00,0xff,0x94,0x94,0xff,0x00,0x00,0xff,0x08,0x08,0x4f,0x48,0x48,0x4f,0xf8,0x00,
+0x04,0x84,0x84,0xa4,0xa4,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 13564 0x34fc "㓼" */
+0x08,0x08,0xff,0x1c,0x2b,0xc8,0x14,0x22,0x49,0x88,0x49,0x2a,0x49,0x88,0x28,0x10,
+0x04,0x04,0x84,0x24,0x24,0xa4,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 13565 0x34fd "㓽" */
+0x08,0x49,0x49,0x7f,0x10,0x08,0xff,0x80,0x3f,0x00,0xff,0x08,0x2a,0x49,0xa8,0x10,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0xa4,0x24,0x24,0xa4,0x24,0x04,0x04,0x94,0x08,
+/* 13566 0x34fe "㓾" */
+0x00,0x7f,0x40,0x7f,0x42,0x4a,0x47,0x4a,0x50,0x4a,0x4f,0x52,0x42,0xbf,0x82,0x02,
+0x02,0xc2,0x42,0xc2,0x12,0x92,0x12,0x92,0x52,0x12,0xd2,0x12,0x02,0xe2,0x0a,0x04,
+/* 13567 0x34ff "㓿" */
+0x07,0x78,0x08,0xff,0x2a,0x49,0x94,0x22,0x49,0x88,0x49,0x2a,0x49,0x88,0x28,0x10,
+0x04,0x04,0x04,0xa4,0x24,0x24,0xa4,0x24,0x24,0xa4,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 13568 0x3500 "㔀" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x00,0x7f,0x41,0x7f,0x08,0x49,0x88,0x18,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x94,0x08,
+/* 13569 0x3501 "㔁" */
+0x05,0x72,0x12,0x51,0x21,0x5e,0x80,0x3f,0x21,0x21,0x3f,0x21,0x12,0x07,0x78,0x20,
+0x04,0x04,0x84,0x24,0x24,0xa4,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 13570 0x3502 "㔂" */
+0x04,0x24,0x15,0x7f,0x15,0x24,0x44,0x20,0x20,0x3b,0x48,0xaa,0x13,0x20,0x40,0x80,
+0x04,0x84,0x04,0xd4,0x14,0x94,0x54,0x94,0x94,0xf4,0x94,0x84,0xe4,0x84,0x94,0x88,
+/* 13571 0x3503 "㔃" */
+0x10,0x10,0x25,0x7b,0x11,0x25,0x7d,0x01,0x55,0x94,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x80,0xf8,0x10,0xfc,0x24,0x24,0xfc,0x02,0x02,0xfe,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 13572 0x3504 "㔄" */
+0x00,0x7f,0x0a,0x7f,0x4a,0x4a,0x7f,0x04,0x24,0x15,0xff,0x0e,0x15,0x24,0x44,0x04,
+0x02,0xc2,0x02,0xc2,0x52,0x52,0xd2,0x12,0x92,0x12,0xd2,0x12,0x02,0x82,0x4a,0x04,
+/* 13573 0x3505 "㔅" */
+0x04,0x3f,0x04,0x7f,0x04,0x3f,0x04,0x55,0x75,0x44,0x7f,0x44,0x75,0x55,0x55,0x84,
+0x02,0x82,0x82,0xc2,0x92,0x92,0x12,0x52,0xd2,0x52,0xd2,0x52,0xc2,0x42,0x4a,0x44,
+/* 13574 0x3506 "㔆" */
+0x00,0xf7,0x21,0xa5,0xf7,0x63,0xb5,0x21,0x7f,0x40,0x40,0x7f,0x40,0x40,0x7f,0x40,
+0x04,0x84,0x04,0x24,0xa4,0x24,0xa4,0x24,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x88,
+/* 13575 0x3507 "㔇" */
+0x09,0xf6,0x12,0xa1,0x40,0xf7,0x15,0x15,0x79,0x40,0x8f,0xf1,0x15,0x12,0x55,0x29,
+0x04,0x44,0x84,0x24,0xa4,0x64,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 13576 0x3508 "㔈" */
+0x22,0x22,0xff,0x22,0x14,0x14,0xf7,0x14,0x14,0x77,0x14,0x14,0xf7,0x14,0x14,0x14,
+0x04,0x04,0x84,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x84,0x04,0x14,0x08,
+/* 13577 0x3509 "㔉" */
+0x00,0x7f,0x40,0x7f,0x40,0x5f,0x42,0x5f,0x52,0x5f,0x42,0x7f,0x62,0x6f,0xa0,0x20,
+0x02,0xc2,0x42,0xca,0x0a,0xca,0x0a,0xca,0x4a,0xca,0x0a,0xea,0xa2,0xa2,0xaa,0x64,
+/* 13578 0x350a "㔊" */
+0x04,0xff,0x00,0x7f,0x40,0x5f,0x51,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x00,0xff,
+0x02,0xe2,0x02,0xc2,0x52,0x52,0x52,0xd2,0x12,0x92,0x92,0x92,0x82,0x82,0x0a,0xe4,
+/* 13579 0x350b "㔋" */
+0x00,0x7a,0x52,0x7b,0x4a,0x7b,0x54,0x78,0x00,0x7f,0x55,0x55,0x55,0x57,0xfc,0x00,
+0x04,0x04,0x04,0xa4,0x24,0x24,0xa4,0xa4,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 13580 0x350c "㔌" */
+0xfc,0x4b,0x78,0x4a,0x79,0x4d,0xfa,0x0c,0x07,0xf8,0x28,0x4d,0x1a,0x29,0xc8,0x08,
+0x04,0x84,0x84,0xa4,0x24,0x24,0xa4,0xa4,0xa4,0x24,0xa4,0x24,0x04,0x04,0x94,0x08,
+/* 13581 0x350d "㔍" */
+0x42,0x7b,0xa5,0x10,0x7f,0x40,0x7f,0x40,0x7f,0x40,0x7f,0x21,0xff,0x21,0x41,0x81,
+0x04,0xc4,0x04,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0xc4,0x04,0x14,0x08,
+/* 13582 0x350e "㔎" */
+0x52,0x7e,0x28,0x7e,0xa2,0x3e,0x20,0x3e,0x22,0x3e,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 13583 0x350f "㔏" */
+0x00,0x7f,0x10,0x3f,0x50,0x10,0x1f,0x00,0xfb,0x20,0x79,0x49,0xcb,0x49,0x79,0x49,
+0x02,0xc2,0x02,0x8a,0x8a,0x8a,0x8a,0x0a,0xea,0x8a,0xea,0x2a,0x22,0x22,0xea,0x24,
+/* 13584 0x3510 "㔐" */
+0x21,0x21,0x3d,0x52,0x88,0x7f,0x0a,0x7b,0x0a,0x3b,0x0a,0x7b,0x0a,0x0f,0xf8,0x40,
+0x02,0x02,0xe2,0x82,0x52,0xd2,0x12,0xd2,0x12,0x92,0x12,0xd2,0x02,0xc2,0x0a,0x04,
+/* 13585 0x3511 "㔑" */
+0x08,0xff,0x28,0x7d,0x44,0x7c,0x41,0x7c,0x45,0x7c,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x20,0xfe,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 13586 0x3512 "㔒" */
+0x44,0x7f,0x12,0x3f,0x62,0xbf,0x22,0x3f,0x22,0x3f,0x20,0x7f,0x51,0x6e,0x4a,0x4e,
+0x42,0xc2,0x02,0xc2,0x12,0xd2,0x12,0xd2,0x12,0xd2,0x12,0xd2,0x42,0xc2,0x4a,0xc4,
+/* 13587 0x3513 "㔓" */
+0x04,0x0e,0x78,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0a,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 13588 0x3514 "㔔" */
+0x10,0x10,0x7e,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,0x1f,0x20,0x20,0x20,0x1f,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0xf0,0x08,0x08,0x08,0xf0,0x00,
+/* 13589 0x3515 "㔕" */
+0x20,0x20,0x3f,0x40,0x80,0x7e,0x00,0x00,0x7c,0x04,0x05,0x05,0x03,0x01,0x00,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 13590 0x3516 "㔖" */
+0x10,0x10,0x7e,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,
+/* 13591 0x3517 "㔗" */
+0x12,0x12,0x12,0x7f,0x12,0x12,0x7f,0x52,0x52,0x7f,0x12,0x12,0x23,0x22,0x42,0x82,
+0x10,0x10,0x10,0x90,0xfe,0x92,0x92,0x12,0x12,0xd2,0x52,0x52,0x52,0xa2,0x2a,0x44,
+/* 13592 0x3518 "㔘" */
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x9e,0xf2,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 13593 0x3519 "㔙" */
+0x42,0x24,0x00,0x7e,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x44,0x44,0x85,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 13594 0x351a "㔚" */
+0x04,0x0e,0x38,0x08,0x08,0xff,0x08,0x08,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 13595 0x351b "㔛" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x1f,0x10,0x10,0x1f,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 13596 0x351c "㔜" */
+0x02,0x0f,0xf0,0x01,0x91,0x4a,0x00,0xfe,0x04,0x08,0x0f,0xf8,0x48,0x08,0x29,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 13597 0x351d "㔝" */
+0x00,0xff,0x08,0x08,0xff,0x88,0x88,0xcc,0xaa,0xaa,0xdd,0x99,0x88,0x88,0x8a,0x81,
+0x10,0x90,0x10,0x10,0x90,0xfe,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xa2,0xaa,0x44,
+/* 13598 0x351e "㔞" */
+0x02,0x0f,0x78,0x08,0xff,0x08,0x2a,0x2a,0xeb,0x2a,0x2a,0x6b,0xaa,0x08,0x08,0x09,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0xa4,0x24,0xa4,0x24,0x44,0x44,0x94,0x08,
+/* 13599 0x351f "㔟" */
+0x08,0x28,0x3e,0x48,0x08,0x3e,0x08,0x0e,0x79,0x02,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x20,0x20,0xf8,0x28,0xa8,0x48,0x4a,0xaa,0x26,0x02,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 13600 0x3520 "㔠" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x20,0x7f,0x89,0x49,0x55,0x41,0x7d,0x01,0x0a,0x05,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 13601 0x3521 "㔡" */
+0x08,0x10,0x7f,0x55,0x49,0x55,0x41,0x7f,0x00,0x44,0x77,0x44,0x55,0x66,0x44,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 13602 0x3522 "㔢" */
+0x10,0x10,0x25,0x7b,0x11,0x25,0x7d,0x01,0x55,0x94,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x80,0xf8,0x10,0xfc,0x24,0x24,0xfc,0x02,0x02,0xfe,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 13603 0x3523 "㔣" */
+0x00,0x3f,0x24,0x3f,0x24,0x3f,0x00,0xfb,0xaa,0xaa,0xfb,0xaa,0xaa,0xfb,0x00,0x00,
+0x08,0x88,0x88,0x88,0xbe,0x8a,0x0a,0xea,0xaa,0xaa,0xea,0xaa,0xb2,0xf2,0x2a,0x44,
+/* 13604 0x3524 "㔤" */
+0x10,0x08,0x7f,0x41,0x86,0x78,0x49,0x2a,0xff,0x2a,0x41,0xbe,0x2a,0x3e,0x2a,0x3f,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 13605 0x3525 "㔥" */
+0x00,0xff,0xa5,0xa5,0xff,0x44,0x94,0xf7,0x04,0xf3,0x90,0xf4,0x97,0xf4,0x94,0xb3,
+0x10,0x10,0x10,0x10,0x7e,0x12,0x92,0x12,0x92,0x92,0x12,0x92,0x12,0x22,0xaa,0xc4,
+/* 13606 0x3526 "㔦" */
+0x22,0xff,0x08,0x7f,0x10,0xff,0x22,0x49,0xbe,0x22,0x3e,0x22,0x3e,0x25,0x2a,0x31,
+0x10,0x90,0x10,0x10,0x7e,0x92,0x12,0x12,0x92,0x12,0x12,0x12,0x92,0x22,0x2a,0x44,
+/* 13607 0x3527 "㔧" */
+0x08,0x0f,0x08,0x7f,0x48,0x7e,0x48,0x5f,0x55,0x5f,0x55,0x5f,0x40,0xbf,0x2a,0x7f,
+0x10,0x90,0x10,0x90,0xfe,0x12,0x92,0x92,0x12,0x12,0x12,0x12,0x12,0xa2,0xaa,0xc4,
+/* 13608 0x3528 "㔨" */
+0x10,0x10,0x3f,0x45,0xbd,0x05,0x1c,0x64,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x11,0x10,
+0x00,0x00,0xfc,0x24,0xc4,0x14,0xf4,0x04,0xc4,0x44,0xc4,0x44,0xc4,0x44,0x54,0x88,
+/* 13609 0x3529 "㔩" */
+0x10,0x10,0x3f,0x22,0x5f,0x82,0x3f,0x04,0x08,0x1f,0x00,0x1f,0x15,0x15,0x3f,0x00,
+0x00,0x00,0xfc,0x04,0xc4,0x04,0xe4,0x04,0x84,0xc4,0x04,0xc4,0x44,0x44,0xe8,0x10,
+/* 13610 0x352a "㔪" */
+0x10,0x10,0x3f,0x22,0x42,0x83,0x02,0x3f,0x2a,0x25,0x32,0x25,0x2a,0x3f,0x20,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xf4,0x04,0xe4,0xa4,0x24,0x64,0x24,0xa4,0xe4,0x28,0x10,
+/* 13611 0x352b "㔫" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0xfe,0x80,0x80,0x84,0x88,0x90,0xe0,0x82,0x82,0x82,0x7e,0x00,
+/* 13612 0x352c "㔬" */
+0x20,0x21,0x3e,0x20,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,0x01,
+0x30,0xc0,0x08,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,0x00,
+/* 13613 0x352d "㔭" */
+0x00,0x43,0x42,0x42,0x43,0x7a,0x42,0x43,0x40,0x47,0x40,0x4a,0x52,0x62,0x45,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x40,0x40,0x78,0x40,0x40,0xfe,
+/* 13614 0x352e "㔮" */
+0x51,0x51,0xfa,0x53,0x70,0x20,0xfb,0xaa,0xfa,0x23,0xfa,0x22,0xfb,0x22,0x52,0x8a,
+0x10,0x12,0x54,0xd8,0x10,0x12,0xd2,0x4e,0x40,0xd2,0x54,0x58,0xd0,0x52,0x52,0xce,
+/* 13615 0x352f "㔯" */
+0x00,0x7f,0x40,0x47,0x44,0x44,0x48,0x50,0x47,0x44,0x44,0x44,0x47,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0xf0,0x10,0x10,0x0c,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0xfe,0x00,
+/* 13616 0x3530 "㔰" */
+0x00,0x7f,0x42,0x42,0x43,0x44,0x44,0x44,0x4a,0x51,0x41,0x42,0x44,0x48,0x7f,0x00,
+0x00,0xfc,0x20,0x20,0xa0,0xb0,0xa8,0xa4,0xa4,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 13617 0x3531 "㔱" */
+0x00,0x7f,0x40,0x42,0x4c,0x48,0x4e,0x48,0x4f,0x41,0x42,0x44,0x58,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x80,0xb8,0x88,0xb8,0x88,0xf8,0x40,0x20,0x10,0x08,0x00,0xfe,0x00,
+/* 13618 0x3532 "㔲" */
+0x00,0x7f,0x42,0x45,0x4a,0x5f,0x69,0x4f,0x49,0x4f,0x48,0x4a,0x4d,0x48,0x7f,0x00,
+0x00,0xfc,0x20,0x20,0xa0,0x78,0x28,0x28,0x28,0x28,0x2a,0x2a,0x46,0x80,0xfe,0x00,
+/* 13619 0x3533 "㔳" */
+0x00,0x7f,0x42,0x45,0x4a,0x5f,0x69,0x4f,0x49,0x4f,0x48,0x4a,0x4d,0x48,0x7f,0x00,
+0x00,0xfc,0x00,0x38,0xa8,0x68,0x28,0x28,0x28,0x2a,0x2a,0x4a,0x46,0x80,0xfe,0x00,
+/* 13620 0x3534 "㔴" */
+0x00,0x7f,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x42,0x4f,0x42,0x5f,0x44,0x48,0x7f,0x00,
+0x00,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x20,0xf8,0x20,0xfc,0x10,0x08,0xfe,0x00,
+/* 13621 0x3535 "㔵" */
+0x7f,0x40,0x5e,0x52,0x5e,0x51,0x4f,0x42,0x4f,0x42,0x42,0x5f,0x42,0x44,0x48,0x7f,
+0xfe,0x00,0x78,0x48,0x78,0x44,0x3c,0x20,0xf8,0x20,0x20,0xfc,0x20,0x10,0x08,0xfe,
+/* 13622 0x3536 "㔶" */
+0x7f,0x44,0x7f,0x4a,0x7f,0x40,0x5f,0x51,0x5f,0x51,0x5f,0x44,0x7f,0x44,0x44,0x7f,
+0xfe,0x20,0xbc,0x64,0x98,0x66,0x7c,0x10,0xfe,0x44,0x7c,0x44,0xfc,0x28,0x44,0xfe,
+/* 13623 0x3537 "㔷" */
+0x00,0x7f,0x40,0x4f,0x40,0x40,0x4f,0x48,0x49,0x4a,0x4c,0x48,0x48,0x48,0x7f,0x00,
+0x00,0xfc,0x00,0xf8,0x80,0x80,0xf8,0x88,0x48,0x28,0x28,0x08,0x28,0x10,0xfe,0x00,
+/* 13624 0x3538 "㔸" */
+0x7f,0x40,0x40,0x4f,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x52,0x54,0x64,0x49,0x7f,
+0xfe,0x00,0x3e,0xc0,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xf0,0x94,0x0c,0xfe,
+/* 13625 0x3539 "㔹" */
+0x10,0x10,0x10,0x10,0x11,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 13626 0x353a "㔺" */
+0x01,0x01,0x01,0x7f,0x01,0x11,0x11,0x10,0xff,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x20,0x20,0xfe,0x20,0x20,0x22,0x02,0x02,0xfe,0x00,
+/* 13627 0x353b "㔻" */
+0x00,0x7f,0x01,0x03,0x05,0x19,0x61,0x01,0x00,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0xfc,0x00,0x00,0x60,0x18,0x04,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 13628 0x353c "㔼" */
+0x10,0x10,0xfd,0x13,0x1d,0x31,0xd1,0x11,0x51,0x21,0x00,0x01,0xff,0x01,0x01,0x01,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 13629 0x353d "㔽" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x08,0x08,0xf8,0x08,
+/* 13630 0x353e "㔾" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 13631 0x353f "㔿" */
+0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x11,0x16,0x18,0x00,0x00,0x00,
+0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x90,0x10,0x10,0x10,0x10,0x10,
+/* 13632 0x3540 "㕀" */
+0x01,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0x10,0x52,0x22,0x02,0xfe,0x00,
+/* 13633 0x3541 "㕁" */
+0x01,0x32,0x0c,0x12,0x69,0x08,0xff,0x10,0x24,0x24,0x48,0x8a,0x11,0x3f,0x11,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 13634 0x3542 "㕂" */
+0x00,0x3f,0x20,0x20,0x21,0x22,0x24,0x29,0x30,0x20,0x2f,0x20,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x80,0x80,0x40,0x20,0x10,0x08,0x86,0x80,0xf0,0x10,0x20,0x20,0x40,0x80,
+/* 13635 0x3543 "㕃" */
+0x00,0x3f,0x20,0x20,0x27,0x21,0x21,0x21,0x21,0x2f,0x21,0x21,0x22,0x42,0x44,0x88,
+0x00,0xfe,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 13636 0x3544 "㕄" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x21,0x22,0x24,0x2f,0x20,0x21,0x22,0x44,0x4f,0x84,
+0x00,0xfe,0x00,0x00,0xfc,0x80,0x00,0x10,0x20,0xc0,0x80,0x00,0x10,0x08,0xfc,0x04,
+/* 13637 0x3545 "㕅" */
+0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x24,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x00,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x40,
+/* 13638 0x3546 "㕆" */
+0x00,0x3f,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x27,0x24,0x24,0x24,0x44,0x47,0x84,
+0x00,0xfe,0x00,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 13639 0x3547 "㕇" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x2f,0x20,0x24,0x22,0x22,0x21,0x21,0x40,0x5f,0x80,
+0x00,0xfe,0x00,0x80,0x40,0x40,0xfc,0x00,0x08,0x08,0x10,0x10,0x20,0x00,0xfe,0x00,
+/* 13640 0x3548 "㕈" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x21,0x22,0x26,0x2a,0x32,0x22,0x42,0x43,0x82,
+0x00,0xfe,0x80,0x40,0x00,0xfe,0x80,0x00,0x84,0x88,0x50,0x20,0x10,0x88,0x06,0x00,
+/* 13641 0x3549 "㕉" */
+0x00,0x3f,0x20,0x20,0x21,0x22,0x24,0x2b,0x30,0x20,0x27,0x24,0x24,0x44,0x47,0x84,
+0x00,0xfe,0x80,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 13642 0x354a "㕊" */
+0x00,0x3f,0x20,0x20,0x20,0x2f,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x44,0x44,0x84,
+0x00,0xfe,0x00,0x48,0x44,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 13643 0x354b "㕋" */
+0x00,0x3f,0x20,0x21,0x22,0x24,0x28,0x37,0x20,0x20,0x2f,0x20,0x24,0x42,0x5f,0x80,
+0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0xf6,0x80,0x80,0xf8,0x80,0x90,0xa0,0xfe,0x00,
+/* 13644 0x354c "㕌" */
+0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x20,0x2f,0x20,0x3f,0x24,0x42,0x42,0x80,
+0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 13645 0x354d "㕍" */
+0x00,0x3f,0x22,0x22,0x22,0x27,0x24,0x2c,0x37,0x24,0x24,0x27,0x24,0x44,0x47,0x84,
+0x00,0xfe,0x80,0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,
+/* 13646 0x354e "㕎" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x3f,0x22,0x24,0x2f,0x20,0x2f,0x29,0x49,0x7f,0x80,
+0x00,0xfe,0x80,0x80,0xfc,0x80,0xfe,0x00,0x08,0xfc,0x00,0xfc,0x24,0x24,0xfe,0x00,
+/* 13647 0x354f "㕏" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x29,0x29,0x29,0x2f,0x20,0x29,0x26,0x43,0x5c,0x88,
+0x00,0xfe,0x00,0x88,0x48,0x28,0x08,0x48,0x28,0x0e,0x78,0x08,0x08,0x88,0x08,0x08,
+/* 13648 0x3550 "㕐" */
+0x00,0x3f,0x21,0x26,0x24,0x27,0x24,0x27,0x22,0x27,0x28,0x25,0x25,0x48,0x40,0x80,
+0x00,0xfe,0x00,0x38,0x08,0x38,0x08,0xf8,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 13649 0x3551 "㕑" */
+0x00,0x3f,0x22,0x22,0x3f,0x22,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x25,0x43,0x5c,0x88,
+0x00,0xfe,0x04,0x04,0xc4,0x04,0xbe,0x04,0xa4,0x94,0x94,0x84,0x04,0x84,0x14,0x08,
+/* 13650 0x3552 "㕒" */
+0x3f,0x24,0x22,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x22,0x3f,0x42,0x5f,0x82,0x06,
+0xfe,0x08,0x10,0xfe,0x80,0xfc,0x80,0xfe,0xa0,0x28,0x24,0xfe,0x28,0x12,0x2a,0xc6,
+/* 13651 0x3553 "㕓" */
+0x00,0x3f,0x20,0x27,0x25,0x24,0x27,0x20,0x27,0x20,0x2f,0x24,0x28,0x47,0x40,0x8f,
+0x00,0xfe,0x00,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,0xfc,0x40,0xfe,
+/* 13652 0x3554 "㕔" */
+0x3f,0x20,0x3f,0x2a,0x2e,0x2a,0x2e,0x2a,0x3e,0x22,0x3e,0x2a,0x5e,0x4a,0xbf,0x02,
+0xfe,0x10,0x10,0xfe,0x10,0xfe,0xaa,0xaa,0xfe,0x00,0xfe,0x20,0x14,0xa2,0x28,0x18,
+/* 13653 0x3555 "㕕" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x3f,0x10,0x01,0x01,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x00,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,0x00,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,
+/* 13654 0x3556 "㕖" */
+0x04,0x08,0x10,0x3f,0x08,0x10,0x24,0x7e,0x02,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x20,0x10,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 13655 0x3557 "㕗" */
+0x41,0x22,0xff,0x08,0x7f,0x08,0xff,0x10,0x10,0x3e,0x42,0x84,0x08,0x14,0x23,0xc0,
+0x00,0x10,0x90,0x10,0x20,0x20,0xa0,0x40,0x48,0x84,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 13656 0x3558 "㕘" */
+0x04,0x08,0x10,0x3f,0x08,0x10,0x24,0x7e,0x01,0x06,0x18,0xe1,0x09,0x11,0x25,0x02,
+0x00,0x20,0x10,0xf8,0x10,0x20,0x48,0xfc,0x00,0xc0,0x30,0x0e,0x20,0x10,0x08,0x00,
+/* 13657 0x3559 "㕙" */
+0x10,0x10,0x20,0x45,0xfe,0x29,0x45,0xa3,0x3d,0x45,0x44,0xa8,0x10,0x28,0x45,0x82,
+0x80,0x80,0xf0,0x10,0x20,0xfc,0x24,0x24,0x24,0xfc,0x50,0x58,0x94,0x92,0x12,0x0e,
+/* 13658 0x355a "㕚" */
+0x00,0x3f,0x10,0x12,0x11,0x09,0x08,0x44,0x24,0x22,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 13659 0x355b "㕛" */
+0x00,0x3f,0x00,0x1e,0x01,0x06,0x18,0xe0,0x3f,0x10,0x08,0x04,0x03,0x0c,0x30,0xc0,
+0x00,0xf0,0x20,0x40,0x80,0x60,0x18,0x04,0xf0,0x10,0x20,0x40,0x80,0x60,0x18,0x06,
+/* 13660 0x355c "㕜" */
+0x01,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x3f,0x10,0x08,0x04,0x03,0x0c,0x30,0xc0,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x60,0x18,0x06,
+/* 13661 0x355d "㕝" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 13662 0x355e "㕞" */
+0x00,0x3f,0x21,0x21,0x3f,0x24,0x24,0x24,0x3f,0x35,0x35,0x55,0x55,0x97,0x04,0x04,
+0x00,0x00,0x7c,0x24,0x24,0x24,0x24,0x28,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 13663 0x355f "㕟" */
+0x08,0x08,0x0f,0x08,0x08,0x7f,0x55,0x55,0x55,0x7f,0x55,0x55,0x55,0x51,0x45,0x42,
+0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 13664 0x3560 "㕠" */
+0x41,0x21,0x03,0x0a,0x17,0xea,0x23,0x22,0x23,0x02,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 13665 0x3561 "㕡" */
+0x08,0x0f,0x08,0xff,0x80,0x7f,0x14,0x22,0x49,0x16,0x21,0xfe,0x22,0x22,0x3e,0x22,
+0x00,0x00,0x7c,0xa4,0xa4,0x24,0x24,0x28,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 13666 0x3562 "㕢" */
+0x10,0x1e,0x10,0xff,0x81,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 13667 0x3563 "㕣" */
+0x00,0x08,0x08,0x10,0x10,0x20,0x40,0x9f,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x40,0x40,0x20,0x20,0x10,0x08,0x04,0xf2,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,
+/* 13668 0x3564 "㕤" */
+0x01,0x01,0x79,0x49,0x4b,0x49,0x49,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,0x08,0x10,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 13669 0x3565 "㕥" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x45,0x01,0x02,0x04,0x08,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 13670 0x3566 "㕦" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x10,0x20,0xc0,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 13671 0x3567 "㕧" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 13672 0x3568 "㕨" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 13673 0x3569 "㕩" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x49,0x48,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 13674 0x356a "㕪" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x48,0x48,0x48,0x48,0x78,0x49,0x01,0x02,0x04,0x08,
+0x40,0x40,0x40,0xfc,0x44,0x48,0x40,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 13675 0x356b "㕫" */
+0x00,0x00,0x78,0x4f,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x80,0x40,0x40,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 13676 0x356c "㕬" */
+0x00,0x01,0x79,0x49,0x49,0x4a,0x4a,0x4c,0x48,0x48,0x79,0x49,0x02,0x07,0x02,0x00,
+0x20,0x20,0x20,0x10,0x10,0x48,0x48,0x44,0x82,0x80,0x10,0x08,0x08,0xfc,0x04,0x00,
+/* 13677 0x356d "㕭" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x4f,0x48,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 13678 0x356e "㕮" */
+0x00,0x01,0x79,0x4a,0x4a,0x4c,0x49,0x49,0x48,0x48,0x78,0x48,0x01,0x02,0x04,0x08,
+0x20,0x10,0x08,0x04,0x04,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x04,0x02,
+/* 13679 0x356f "㕯" */
+0x01,0x01,0x01,0x7f,0x41,0x42,0x44,0x48,0x57,0x44,0x44,0x44,0x47,0x44,0x40,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x84,0x44,0x24,0xd4,0x44,0x44,0x44,0xc4,0x44,0x14,0x08,
+/* 13680 0x3570 "㕰" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 13681 0x3571 "㕱" */
+0x00,0x00,0x78,0x48,0x4f,0x48,0x48,0x48,0x48,0x48,0x79,0x49,0x01,0x02,0x02,0x04,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 13682 0x3572 "㕲" */
+0x00,0x00,0xf0,0x90,0x97,0x90,0x90,0x90,0x91,0x91,0xf2,0x94,0x08,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 13683 0x3573 "㕳" */
+0x00,0x00,0x79,0x48,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x03,0x00,0x00,
+0x00,0x08,0x08,0x88,0x52,0x52,0x22,0x22,0x52,0x92,0x0a,0x0a,0x02,0xfe,0x02,0x00,
+/* 13684 0x3574 "㕴" */
+0x00,0x00,0x7b,0x4a,0x4c,0x48,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 13685 0x3575 "㕵" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x78,0x48,0x00,0x07,0x00,
+0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 13686 0x3576 "㕶" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x4b,0x48,0x48,0x48,0x78,0x49,0x01,0x01,0x07,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xf8,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0xfe,0x00,
+/* 13687 0x3577 "㕷" */
+0x00,0x00,0x78,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 13688 0x3578 "㕸" */
+0x00,0x00,0x78,0x48,0x4f,0x48,0x48,0x4a,0x4a,0x49,0x79,0x49,0x01,0x00,0x0f,0x00,
+0x80,0x40,0x40,0x00,0xfc,0x00,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0xfe,0x00,
+/* 13689 0x3579 "㕹" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x49,0x49,0x79,0x4a,0x02,0x04,0x08,0x03,
+0x40,0x48,0x44,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 13690 0x357a "㕺" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0xff,0x08,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 13691 0x357b "㕻" */
+0x02,0x01,0x00,0x7f,0x01,0x03,0x0d,0x31,0xc1,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x60,0x18,0x04,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 13692 0x357c "㕼" */
+0x01,0x01,0x79,0x4a,0x4a,0x4c,0x48,0x4a,0x4a,0x4a,0x7a,0x4b,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x02,0x02,0x8a,0x52,0x22,0x52,0x8a,0x02,0xfe,0x02,0x02,0x14,0x08,
+/* 13693 0x357d "㕽" */
+0x00,0x00,0x78,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x00,0x00,
+0x08,0x88,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x10,0x98,0x24,0x24,0x42,0x82,
+/* 13694 0x357e "㕾" */
+0x01,0x01,0x09,0x09,0x11,0x21,0x41,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x20,0x20,0x3c,0xe0,0x20,0x22,0x22,0x1e,
+/* 13695 0x357f "㕿" */
+0x00,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc0,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x70,0x80,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 13696 0x3580 "㖀" */
+0x00,0x00,0x7b,0x48,0x4f,0x48,0x4b,0x48,0x48,0x4b,0x78,0x48,0x07,0x00,0x00,0x00,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,
+/* 13697 0x3581 "㖁" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x48,0x4f,0x48,0x48,0x79,0x49,0x02,0x04,0x09,0x00,
+0x08,0x90,0x60,0x98,0x04,0x40,0x40,0xfe,0x80,0x90,0x10,0x20,0x48,0x84,0xfc,0x84,
+/* 13698 0x3582 "㖂" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x78,0x48,0x00,0x01,0x06,0x00,
+0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0x48,0x30,0x64,0x94,0x0c,0x04,
+/* 13699 0x3583 "㖃" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x08,0x00,
+0x08,0x3c,0xc0,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 13700 0x3584 "㖄" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x4b,0x4b,0x4d,0x49,0x79,0x49,0x01,0x02,0x02,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0xb4,0x6c,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 13701 0x3585 "㖅" */
+0x00,0x00,0x78,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 13702 0x3586 "㖆" */
+0x00,0x00,0x78,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x50,0x50,0x50,0x50,0xfe,0x52,0x52,0x52,0x52,0xfe,0x52,0x52,0x52,0x52,0xfe,0x02,
+/* 13703 0x3587 "㖇" */
+0x00,0x03,0x78,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x00,0xfe,0x20,0x20,0x40,0xfe,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x42,0x0a,0x04,
+/* 13704 0x3588 "㖈" */
+0x02,0x3f,0x02,0xff,0x02,0x0c,0x3f,0xc8,0x07,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x08,0xd0,0x20,0xfe,0x00,0x70,0x84,0x04,0xfc,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 13705 0x3589 "㖉" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x4c,0x49,0x49,0x49,0x79,0x49,0x01,0x07,0x00,0x00,
+0x20,0x20,0x50,0x88,0x24,0x22,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 13706 0x358a "㖊" */
+0x00,0x03,0x78,0x48,0x49,0x48,0x48,0x4b,0x48,0x48,0x4f,0x79,0x48,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x08,0x08,0xfe,0x08,0x88,0x88,0x28,0x10,
+/* 13707 0x358b "㖋" */
+0x01,0x02,0x04,0x18,0xe4,0x04,0x04,0x04,0x08,0x10,0x00,0x7c,0x45,0x44,0x7c,0x44,
+0x00,0x80,0x40,0x30,0x4e,0x40,0x40,0x40,0x40,0x00,0x40,0x78,0xc0,0x40,0x44,0x3c,
+/* 13708 0x358c "㖌" */
+0x08,0x08,0x13,0x30,0x50,0x90,0x11,0x12,0x14,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x80,0x80,0xf0,0x90,0x90,0x92,0x12,0x0e,0x00,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13709 0x358d "㖍" */
+0x00,0x04,0x02,0x12,0x08,0x09,0x7e,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13710 0x358e "㖎" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x01,0x02,0x04,0x18,0xe4,0x04,0x04,0x04,0x08,0x10,
+0x40,0x78,0xc0,0x40,0x44,0x3c,0x00,0x80,0x40,0x30,0x4e,0x40,0x40,0x40,0x40,0x40,
+/* 13711 0x358f "㖏" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x48,0x48,0x79,0x48,0x00,0x00,0x03,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 13712 0x3590 "㖐" */
+0x7c,0x44,0x44,0x7c,0x00,0x3f,0x02,0x02,0xff,0x02,0x04,0x3f,0x08,0x10,0x20,0xc0,
+0xf8,0x88,0x88,0xf8,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xf0,0x10,0x00,0x00,0x00,
+/* 13713 0x3591 "㖑" */
+0x00,0x00,0x78,0x4f,0x48,0x4a,0x4a,0x4a,0x4f,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xd2,0x94,0x94,0x88,0x8a,0x9a,0x26,0x42,
+/* 13714 0x3592 "㖒" */
+0x01,0x00,0x78,0x4b,0x48,0x48,0x4b,0x4a,0x4a,0x4b,0x78,0x48,0x01,0x02,0x04,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 13715 0x3593 "㖓" */
+0x01,0x01,0x7b,0x4c,0x48,0x49,0x4e,0x48,0x4b,0x48,0x7b,0x48,0x07,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x40,0x40,0x40,
+/* 13716 0x3594 "㖔" */
+0x00,0x01,0x78,0x48,0x48,0x4b,0x48,0x48,0x49,0x4a,0x7c,0x48,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 13717 0x3595 "㖕" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x48,0x48,0x48,0x79,0x48,0x00,0x00,0x00,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 13718 0x3596 "㖖" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x01,0x01,0x3f,0x01,0x01,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13719 0x3597 "㖗" */
+0x00,0x02,0x7a,0x4a,0x4b,0x48,0x48,0x49,0x4a,0x4c,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x40,0x48,0x48,0x48,0xf8,0x40,0xa0,0x10,0x88,0x46,0x40,0xf0,0x10,0x20,0x20,0x40,
+/* 13720 0x3598 "㖘" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 13721 0x3599 "㖙" */
+0x10,0x10,0x7e,0x12,0x12,0x12,0x22,0x4a,0x84,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13722 0x359a "㖚" */
+0x08,0x08,0x17,0x30,0x52,0x91,0x11,0x10,0x10,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13723 0x359b "㖛" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x10,0x10,0x1f,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13724 0x359c "㖜" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13725 0x359d "㖝" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x09,0x31,0xc1,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x20,0x18,0x06,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13726 0x359e "㖞" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x48,0x48,0x4b,0x4a,0x7a,0x4a,0x03,0x02,0x02,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 13727 0x359f "㖟" */
+0x00,0x03,0xf0,0x92,0x91,0x91,0x97,0x94,0x90,0x93,0xf1,0x91,0x00,0x00,0x01,0x06,
+0x1c,0xe0,0x84,0x44,0x48,0x10,0xfe,0x02,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 13728 0x35a0 "㖠" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x4a,0x48,0x48,0x4b,0x78,0x49,0x01,0x02,0x00,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0x24,0x22,0x22,0xa0,0x40,
+/* 13729 0x35a1 "㖡" */
+0x00,0x00,0xf7,0x91,0x91,0x92,0x92,0x96,0x92,0x93,0xf2,0x92,0x02,0x02,0x02,0x03,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 13730 0x35a2 "㖢" */
+0x00,0x00,0xef,0xa8,0xa8,0xa8,0xaa,0xaa,0xaa,0xaa,0xea,0xaa,0x12,0x12,0x27,0x00,
+0x80,0x40,0xfe,0x00,0x90,0x90,0x90,0x92,0xdc,0x90,0x90,0x92,0x92,0xd2,0x0e,0x00,
+/* 13731 0x35a3 "㖣" */
+0x00,0x00,0x79,0x48,0x49,0x48,0x48,0x4b,0x48,0x48,0x79,0x49,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 13732 0x35a4 "㖤" */
+0x00,0x01,0x78,0x48,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x03,0x00,
+0x00,0xfc,0x08,0x10,0x22,0xaa,0x72,0x22,0x72,0xaa,0x26,0xa2,0x42,0x02,0xfe,0x02,
+/* 13733 0x35a5 "㖥" */
+0x00,0x07,0xf4,0x94,0x95,0x94,0x94,0x97,0x94,0x94,0xf5,0x96,0x04,0x04,0x07,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0x44,0xfc,0x44,0xe4,0x54,0x4c,0x44,0x44,0xfc,0x04,
+/* 13734 0x35a6 "㖦" */
+0x00,0x00,0xf7,0x90,0x93,0x92,0x93,0x92,0x93,0x90,0xf0,0x91,0x02,0x0c,0x00,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 13735 0x35a7 "㖧" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4a,0x4b,0x4a,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 13736 0x35a8 "㖨" */
+0x00,0x01,0x78,0x48,0x49,0x48,0x48,0x4b,0x48,0x4a,0x79,0x48,0x01,0x02,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 13737 0x35a9 "㖩" */
+0x00,0x0f,0xf4,0x94,0x94,0x97,0x94,0x94,0x97,0x94,0xf4,0x95,0x0e,0x00,0x00,0x00,
+0x00,0xc0,0xbc,0xa4,0xa4,0xa4,0xa4,0xa8,0xa8,0xa8,0x90,0xd0,0xa8,0xa8,0xc4,0x82,
+/* 13738 0x35aa "㖪" */
+0x00,0x00,0x78,0x4f,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x7b,0x48,0x00,0x07,0x02,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 13739 0x35ab "㖫" */
+0x00,0x00,0x79,0x48,0x48,0x4b,0x48,0x49,0x4a,0x48,0x79,0x4a,0x00,0x00,0x01,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 13740 0x35ac "㖬" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x48,0x7b,0x49,0x00,0x00,0x01,0x06,
+0x80,0x1c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x00,0x00,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 13741 0x35ad "㖭" */
+0x00,0x03,0xf0,0x90,0x97,0x90,0x91,0x92,0x94,0x90,0xf0,0x92,0x02,0x04,0x01,0x00,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 13742 0x35ae "㖮" */
+0x00,0x00,0xf0,0x91,0x92,0x9d,0x90,0x97,0x94,0x94,0xf7,0x94,0x04,0x04,0x04,0x04,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 13743 0x35af "㖯" */
+0x3f,0x20,0x2f,0x20,0x27,0x24,0x27,0x20,0x20,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0xf8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x28,0x10,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13744 0x35b0 "㖰" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x27,0x20,0x20,
+0x40,0x78,0xc0,0x40,0x42,0x3e,0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x28,0x10,
+/* 13745 0x35b1 "㖱" */
+0x01,0xff,0x08,0x10,0x31,0xd3,0x14,0x10,0x11,0x16,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0xfe,0x80,0xf8,0x48,0x28,0x90,0x60,0x98,0x06,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13746 0x35b2 "㖲" */
+0x10,0x10,0xfe,0x22,0x44,0x34,0x08,0x14,0x22,0xc0,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13747 0x35b3 "㖳" */
+0x10,0x08,0x47,0x21,0x0a,0x11,0x70,0x10,0x13,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x80,0x80,0xfc,0x10,0x10,0xa0,0x60,0x90,0x08,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13748 0x35b4 "㖴" */
+0x01,0x01,0x7b,0x49,0x48,0x48,0x49,0x49,0x4a,0x4c,0x78,0x49,0x02,0x00,0x01,0x02,
+0x10,0x10,0xfe,0x10,0x80,0x80,0xfc,0x54,0x54,0x94,0xa4,0x24,0x44,0x84,0x28,0x10,
+/* 13749 0x35b5 "㖵" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x4f,0x00,0x01,0x02,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,0x10,0x08,0x04,
+/* 13750 0x35b6 "㖶" */
+0x00,0x07,0xf0,0x90,0x97,0x94,0x94,0x94,0x97,0x90,0xf0,0x97,0x00,0x00,0x0f,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 13751 0x35b7 "㖷" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x48,0x4b,0x78,0x49,0x01,0x01,0x02,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 13752 0x35b8 "㖸" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x04,0x04,0x08,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc0,0x44,0x3c,0x00,0xfc,0x80,0xfe,0x80,0x80,0xfc,
+/* 13753 0x35b9 "㖹" */
+0x00,0x01,0x79,0x4a,0x4d,0x48,0x49,0x4a,0x4c,0x4b,0x7a,0x4a,0x02,0x02,0x0f,0x00,
+0x10,0x10,0x08,0x04,0xfa,0x88,0x08,0x28,0x10,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 13754 0x35ba "㖺" */
+0x00,0x00,0xf7,0x90,0x93,0x90,0x97,0x91,0x92,0x95,0xf1,0x91,0x01,0x01,0x01,0x01,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 13755 0x35bb "㖻" */
+0x00,0x03,0xf0,0x90,0x97,0x90,0x91,0x92,0x94,0x90,0xf7,0x90,0x01,0x02,0x0c,0x00,
+0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0x20,0x60,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 13756 0x35bc "㖼" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x7b,0x48,0x00,0x01,0x02,0x00,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 13757 0x35bd "㖽" */
+0x00,0x03,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x00,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 13758 0x35be "㖾" */
+0x00,0x7e,0x42,0x42,0x7e,0x10,0x08,0xff,0x01,0x21,0x21,0x3f,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x84,0x84,0xfc,0x10,0x20,0xfe,0x00,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 13759 0x35bf "㖿" */
+0x00,0x0f,0xf4,0x94,0x94,0x97,0x94,0x94,0x97,0x94,0xf4,0x95,0x0e,0x00,0x00,0x00,
+0x00,0xde,0x92,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0x92,0xda,0x94,0x90,0x90,0x90,
+/* 13760 0x35c0 "㗀" */
+0x00,0x00,0xe1,0xa1,0xa9,0xaa,0xaa,0xab,0xa9,0xaa,0xed,0xaf,0x09,0x08,0x0f,0x00,
+0x40,0x40,0x48,0x48,0x4a,0x52,0xd6,0x5a,0x4a,0x52,0x6a,0x7a,0x4a,0x42,0xfe,0x02,
+/* 13761 0x35c1 "㗁" */
+0x00,0x03,0x7a,0x4a,0x4b,0x48,0x49,0x48,0x4b,0x48,0x79,0x49,0x00,0x00,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 13762 0x35c2 "㗂" */
+0x00,0x00,0x79,0x49,0x4a,0x48,0x48,0x4f,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x20,0x24,0x22,0x2a,0x30,0xc0,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 13763 0x35c3 "㗃" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x7b,0x4a,0x03,0x02,0x03,0x02,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 13764 0x35c4 "㗄" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x48,0x48,0x4f,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x00,0xfc,0x94,0x94,0x94,0xfc,0x80,0x40,0xfe,0x80,0xf8,0x88,0x08,0x08,0x28,0x10,
+/* 13765 0x35c5 "㗅" */
+0x01,0x01,0x79,0x4f,0x49,0x49,0x49,0x4b,0x4a,0x4a,0x7a,0x4a,0x03,0x00,0x00,0x00,
+0x00,0x3c,0x24,0xe4,0x24,0x3c,0x24,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0x44,0x54,0x88,
+/* 13766 0x35c6 "㗆" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x49,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 13767 0x35c7 "㗇" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4b,0x02,0x02,0x02,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 13768 0x35c8 "㗈" */
+0x00,0x03,0x78,0x48,0x4b,0x4a,0x4b,0x4a,0x4b,0x4a,0x78,0x4b,0x00,0x00,0x01,0x02,
+0x00,0xfc,0x88,0x50,0xfe,0x22,0xfe,0x22,0xfe,0x22,0x40,0xfe,0x42,0x82,0x14,0x08,
+/* 13769 0x35c9 "㗉" */
+0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x04,0x0f,0x14,0x03,0x1c,0xef,0x08,0x0f,0x08,
+0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xe0,0x40,0x80,0x70,0xee,0x20,0xe0,0x20,
+/* 13770 0x35ca "㗊" */
+0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,
+0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 13771 0x35cb "㗋" */
+0x00,0x00,0x79,0x4a,0x4c,0x4b,0x4a,0x4a,0x4a,0x4b,0x7a,0x4b,0x04,0x04,0x08,0x13,
+0x80,0x80,0xfc,0x04,0x08,0xfe,0x00,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 13772 0x35cc "㗌" */
+0x00,0x00,0x79,0x49,0x4a,0x49,0x48,0x48,0x49,0x48,0x78,0x49,0x00,0x00,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 13773 0x35cd "㗍" */
+0x00,0x03,0xf0,0x90,0x97,0x91,0x92,0x94,0x93,0x92,0xf2,0x93,0x02,0x02,0x03,0x02,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x46,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 13774 0x35ce "㗎" */
+0x02,0x02,0xf7,0x92,0x92,0x94,0x95,0x98,0x90,0x97,0xf0,0x91,0x02,0x04,0x08,0x00,
+0x00,0x00,0xbc,0xa4,0xa4,0xa4,0xbc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 13775 0x35cf "㗏" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x4b,0x48,0x48,0x4b,0x78,0x49,0x01,0x01,0x01,0x07,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfe,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 13776 0x35d0 "㗐" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x4a,0x4c,0x48,0x4b,0x7a,0x4a,0x02,0x02,0x0f,0x00,
+0x40,0x40,0xfc,0x40,0xa0,0x10,0x88,0x46,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 13777 0x35d1 "㗑" */
+0x01,0x03,0xee,0xa2,0xa2,0xaf,0xa2,0xa2,0xa2,0xaf,0xe2,0xa2,0x02,0x02,0x04,0x08,
+0x00,0xbc,0x10,0x10,0x3c,0x90,0x10,0x3c,0x10,0x90,0x7e,0x10,0x10,0x10,0x10,0x10,
+/* 13778 0x35d2 "㗒" */
+0x00,0x00,0xf7,0x90,0x93,0x92,0x92,0x92,0x93,0x90,0xf1,0x93,0x05,0x09,0x01,0x01,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0x08,0x08,0xf8,0xa4,0x28,0x10,0x10,0x48,0x86,0x00,
+/* 13779 0x35d3 "㗓" */
+0x00,0x04,0xf2,0x92,0x90,0x90,0x9e,0x92,0x92,0x92,0xf2,0x92,0x02,0x05,0x08,0x00,
+0x10,0x20,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 13780 0x35d4 "㗔" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x04,0x04,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x40,0x20,0xfe,0x88,0x50,0x20,0x58,0x86,
+/* 13781 0x35d5 "㗕" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x49,0x49,0x79,0x49,0x03,0x01,0x01,0x01,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 13782 0x35d6 "㗖" */
+0x00,0x03,0x78,0x4a,0x49,0x49,0x48,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x03,0x02,
+0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 13783 0x35d7 "㗗" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x21,0x21,0x7d,0x24,0x25,0x27,0x44,0x44,0x94,0x08,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 13784 0x35d8 "㗘" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 13785 0x35d9 "㗙" */
+0x00,0x00,0x79,0x4a,0x49,0x49,0x48,0x49,0x4a,0x49,0x7a,0x4d,0x01,0x00,0x01,0x02,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 13786 0x35da "㗚" */
+0x00,0x07,0xf0,0x90,0x97,0x94,0x94,0x97,0x90,0x90,0xf7,0x90,0x01,0x02,0x0c,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 13787 0x35db "㗛" */
+0x02,0x02,0xf3,0x95,0x98,0x90,0x93,0x90,0x90,0x97,0xf0,0x90,0x00,0x01,0x02,0x0c,
+0x10,0x10,0xde,0x28,0x84,0x38,0xc0,0x40,0x40,0xfc,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 13788 0x35dc "㗜" */
+0x00,0x00,0xf7,0x90,0x91,0x93,0x90,0x91,0x97,0x90,0xf7,0x94,0x07,0x04,0x07,0x04,
+0x80,0x40,0xfc,0x80,0x08,0xf0,0x60,0x84,0xfe,0x02,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 13789 0x35dd "㗝" */
+0x01,0x00,0x78,0x48,0x4b,0x48,0x48,0x49,0x48,0x48,0x7b,0x48,0x02,0x02,0x04,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 13790 0x35de "㗞" */
+0x00,0x00,0x77,0x52,0x52,0x54,0x57,0x5d,0x55,0x55,0x75,0x57,0x05,0x00,0x01,0x00,
+0x08,0x08,0x88,0x7e,0x4a,0x4a,0x48,0x7c,0x54,0x54,0x54,0x54,0x48,0x88,0x14,0x22,
+/* 13791 0x35df "㗟" */
+0x20,0x10,0x87,0x40,0x10,0x23,0xe0,0x20,0x27,0x20,0x00,0x7c,0x44,0x45,0x7c,0x44,
+0x80,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0x00,0x40,0x78,0xc0,0x42,0x3e,
+/* 13792 0x35e0 "㗠" */
+0x08,0x08,0x7e,0x13,0x22,0x14,0x08,0x14,0x62,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x40,0x40,0x84,0xfe,0x02,0xfc,0x84,0x84,0xfc,0x00,0x20,0x3c,0xe0,0x20,0x22,0x1e,
+/* 13793 0x35e1 "㗡" */
+0x04,0xff,0x04,0x10,0x27,0x61,0xa1,0x21,0x22,0x24,0x00,0x7c,0x44,0x45,0x7c,0x44,
+0x40,0xfe,0x40,0x00,0xf8,0x10,0x3c,0x04,0x14,0x08,0x00,0x40,0x78,0xc0,0x42,0x3e,
+/* 13794 0x35e2 "㗢" */
+0x01,0x07,0x71,0x5f,0x51,0x57,0x55,0x57,0x55,0x57,0x71,0x57,0x01,0x01,0x0e,0x04,
+0xc8,0x08,0x08,0xe8,0x1e,0xca,0x4a,0xca,0x4a,0xca,0x0a,0xca,0x12,0xd2,0x2a,0x44,
+/* 13795 0x35e3 "㗣" */
+0x02,0x02,0x77,0x52,0x52,0x54,0x58,0x57,0x54,0x50,0x73,0x52,0x02,0x02,0x02,0x00,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 13796 0x35e4 "㗤" */
+0x00,0x00,0x3f,0x22,0x23,0x22,0x2f,0x22,0x2a,0x52,0x46,0x80,0x0f,0x08,0x0f,0x08,
+0x28,0x24,0xfe,0x20,0x24,0x24,0xa8,0x18,0x92,0x2a,0x46,0x82,0xf8,0x08,0xf8,0x08,
+/* 13797 0x35e5 "㗥" */
+0x02,0x01,0x77,0x50,0x57,0x54,0x57,0x50,0x57,0x50,0x71,0x51,0x07,0x01,0x05,0x02,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 13798 0x35e6 "㗦" */
+0x00,0x1f,0xea,0xaa,0xae,0xaa,0xaa,0xae,0xaa,0xaa,0xeb,0xae,0x1a,0x02,0x02,0x02,
+0x10,0x20,0xce,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xea,0xac,0x28,0x48,0x48,0x88,
+/* 13799 0x35e7 "㗧" */
+0x00,0x00,0x7b,0x4a,0x49,0x4b,0x48,0x48,0x49,0x48,0x78,0x49,0x00,0x00,0x03,0x00,
+0x40,0x20,0xfe,0x8a,0x04,0xfe,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 13800 0x35e8 "㗨" */
+0x00,0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13801 0x35e9 "㗩" */
+0x00,0x03,0x78,0x4a,0x49,0x4a,0x48,0x48,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 13802 0x35ea "㗪" */
+0x00,0x00,0x7a,0x4a,0x4a,0x4f,0x48,0x49,0x48,0x48,0x7b,0x48,0x01,0x02,0x04,0x00,
+0x90,0x92,0xd4,0x9a,0xd2,0x4e,0x88,0xf0,0x20,0x44,0xfe,0x22,0x28,0x24,0xa2,0x40,
+/* 13803 0x35eb "㗫" */
+0x01,0x01,0x7b,0x4a,0x4d,0x4a,0x49,0x4a,0x4c,0x48,0x7b,0x48,0x01,0x02,0x05,0x00,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 13804 0x35ec "㗬" */
+0x11,0x09,0x7f,0x40,0x9f,0x10,0x1f,0x02,0x0f,0x34,0x07,0x38,0x03,0x1d,0x01,0x3e,
+0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xe0,0xc0,0x00,0x80,0xf8,0x30,0xc0,0x00,
+/* 13805 0x35ed "㗭" */
+0x00,0x01,0x78,0x49,0x48,0x4b,0x48,0x48,0x49,0x4a,0x78,0x48,0x02,0x02,0x04,0x00,
+0x1c,0xe0,0x20,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 13806 0x35ee "㗮" */
+0x20,0x20,0x3d,0x45,0x45,0xa9,0x19,0x11,0x21,0x7d,0xa5,0x25,0x25,0x3e,0x02,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0x14,0x7e,0x14,0x14,0x7c,0x10,0x28,0x28,0x44,0x82,
+/* 13807 0x35ef "㗯" */
+0x01,0x1f,0x01,0x7f,0x02,0x0f,0x38,0xcf,0x08,0x0f,0x00,0x7c,0x44,0x45,0x7c,0x44,
+0x08,0xd0,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x40,0x78,0xc0,0x42,0x3e,
+/* 13808 0x35f0 "㗰" */
+0x01,0x01,0x72,0x54,0x59,0x51,0x52,0x56,0x5a,0x52,0x72,0x52,0x02,0x02,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 13809 0x35f1 "㗱" */
+0x01,0x01,0x7b,0x4e,0x4b,0x4a,0x4b,0x4a,0x4b,0x4a,0x78,0x4f,0x01,0x02,0x0c,0x00,
+0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x40,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 13810 0x35f2 "㗲" */
+0x00,0x03,0x78,0x4f,0x48,0x4b,0x48,0x4f,0x48,0x4b,0x7a,0x4b,0x02,0x03,0x00,0x07,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfe,
+/* 13811 0x35f3 "㗳" */
+0x02,0x02,0x7b,0x4a,0x4d,0x48,0x49,0x4a,0x4d,0x48,0x78,0x4b,0x02,0x02,0x03,0x02,
+0x10,0x10,0xde,0x28,0x44,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13812 0x35f4 "㗴" */
+0x07,0x04,0xf7,0x94,0x97,0x94,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x05,0x04,0x04,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 13813 0x35f5 "㗵" */
+0x02,0x02,0xea,0xab,0xb2,0xa5,0xa8,0xb2,0xa2,0xab,0xea,0xb2,0x05,0x08,0x10,0x00,
+0x10,0x90,0x90,0x3e,0x22,0x44,0x90,0x10,0x90,0x10,0x28,0x28,0x28,0xc4,0x44,0x82,
+/* 13814 0x35f6 "㗶" */
+0x00,0x03,0x78,0x4d,0x4a,0x4c,0x4b,0x48,0x48,0x4b,0x7a,0x4b,0x00,0x00,0x02,0x01,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 13815 0x35f7 "㗷" */
+0x00,0x03,0x7a,0x49,0x48,0x49,0x48,0x4b,0x48,0x49,0x79,0x49,0x01,0x00,0x00,0x03,
+0x20,0xfe,0x52,0xfc,0x50,0xfc,0x50,0xfe,0x00,0xfc,0x04,0x24,0x24,0x58,0x84,0x02,
+/* 13816 0x35f8 "㗸" */
+0x02,0x04,0xe8,0xb1,0xa0,0xa2,0xa5,0xac,0xb4,0xa5,0xe5,0xa5,0x05,0x04,0x04,0x04,
+0x80,0x8e,0xe0,0x40,0x40,0x4e,0xf4,0x44,0x44,0x54,0x54,0x74,0x94,0x04,0x14,0x08,
+/* 13817 0x35f9 "㗹" */
+0x01,0x01,0x73,0x56,0x5b,0x52,0x53,0x52,0x52,0x53,0x72,0x50,0x05,0x05,0x08,0x00,
+0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x40,0x24,0x22,0x0a,0xf8,0x00,
+/* 13818 0x35fa "㗺" */
+0x00,0x03,0x70,0x57,0x51,0x52,0x5c,0x50,0x57,0x50,0x73,0x50,0x07,0x00,0x00,0x00,
+0x00,0xf8,0x80,0xfc,0x10,0x08,0xa6,0xa0,0xbc,0xa0,0xb8,0xa0,0xbc,0xa0,0xa0,0xa0,
+/* 13819 0x35fb "㗻" */
+0x00,0x04,0x72,0x52,0x50,0x50,0x5d,0x55,0x55,0x55,0x75,0x55,0x05,0x05,0x0a,0x11,
+0x00,0xf8,0x88,0xe8,0xa8,0xa8,0xfc,0x04,0x74,0x54,0x74,0x04,0x14,0x08,0x00,0xfe,
+/* 13820 0x35fc "㗼" */
+0x00,0x04,0xf2,0x90,0x97,0x91,0x90,0x97,0x90,0x93,0xf0,0x97,0x01,0x02,0x0c,0x00,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0x50,0x48,0x46,0x40,
+/* 13821 0x35fd "㗽" */
+0x11,0x2b,0x4a,0x73,0x2a,0x4b,0x7a,0x12,0x23,0xc2,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0xde,0x52,0xd4,0x52,0xd2,0x1a,0x94,0x50,0x40,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13822 0x35fe "㗾" */
+0x05,0x05,0xef,0xa5,0xa7,0xa2,0xaf,0xaa,0xaa,0xaf,0xe2,0xaf,0x02,0x02,0x02,0x02,
+0x10,0x18,0xa8,0x28,0x6a,0xaa,0xaa,0xac,0xac,0xa8,0x38,0xaa,0x2a,0x2a,0x26,0x20,
+/* 13823 0x35ff "㗿" */
+0x00,0x07,0x74,0x57,0x54,0x57,0x54,0x55,0x54,0x55,0x75,0x55,0x04,0x04,0x04,0x04,
+0x00,0x9e,0x92,0x9e,0x92,0x9e,0x02,0xfa,0x12,0xd2,0x52,0xd2,0x12,0x52,0x2a,0x04,
+/* 13824 0x3600 "㘀" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4a,0x4b,0x48,0x4a,0x49,0x4f,0x78,0x49,0x02,0x0c,0x00,
+0x80,0x38,0x08,0xb8,0x08,0x08,0xf8,0x40,0x48,0x50,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 13825 0x3601 "㘁" */
+0x00,0x07,0xf4,0x97,0x90,0x93,0x90,0x97,0x91,0x90,0xf3,0x90,0x0f,0x00,0x00,0x00,
+0x00,0xfc,0xa4,0xfc,0x40,0xf8,0x40,0xfc,0x10,0xa0,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 13826 0x3602 "㘂" */
+0x01,0x00,0x7b,0x49,0x49,0x4a,0x4b,0x49,0x4a,0x4b,0x78,0x48,0x02,0x02,0x04,0x00,
+0x08,0x90,0xfe,0x08,0x08,0x52,0x9c,0x08,0x52,0xde,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 13827 0x3603 "㘃" */
+0x00,0x03,0x78,0x48,0x4b,0x48,0x48,0x49,0x4a,0x48,0x78,0x48,0x02,0x02,0x04,0x00,
+0x88,0xfe,0x88,0x20,0xfe,0x40,0xf8,0x88,0x88,0xf8,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 13828 0x3604 "㘄" */
+0x02,0x02,0xe2,0xa2,0xaf,0xa2,0xa6,0xa7,0xaa,0xaa,0xf2,0xa2,0x02,0x02,0x02,0x02,
+0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0x20,0x10,0xfe,0x20,0x20,0x3c,0x24,0x44,0x54,0x88,
+/* 13829 0x3605 "㘅" */
+0x02,0x02,0xe4,0xa8,0xb3,0xa2,0xa4,0xac,0xb5,0xa4,0xe5,0xa4,0x04,0x04,0x05,0x04,
+0x40,0x40,0xae,0x90,0x00,0xe0,0x5e,0x44,0xe4,0x44,0x54,0xe4,0x44,0x64,0x84,0x0c,
+/* 13830 0x3606 "㘆" */
+0x00,0x0f,0xe0,0xa7,0xa0,0xa3,0xa2,0xaf,0xa8,0xa7,0xe1,0xa3,0x00,0x07,0x00,0x0f,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xfc,0x40,0xfe,
+/* 13831 0x3607 "㘇" */
+0x01,0x05,0xf5,0x99,0x92,0x94,0x90,0x97,0x94,0x90,0xf7,0x90,0x01,0x02,0x0c,0x00,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0x00,0xfc,0x44,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 13832 0x3608 "㘈" */
+0x04,0x05,0xf6,0x94,0x93,0x90,0x94,0x97,0x9a,0x92,0x9f,0xf2,0x95,0x04,0x08,0x01,
+0x00,0x7c,0x04,0xa8,0x90,0x7c,0x14,0x94,0x50,0x50,0xdc,0x50,0x50,0xb0,0x9e,0x00,
+/* 13833 0x3609 "㘉" */
+0x02,0x02,0xf3,0x95,0x90,0x90,0x97,0x94,0x97,0x94,0xf7,0x94,0x05,0x06,0x04,0x00,
+0x10,0x10,0xde,0x28,0x84,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0x34,0x28,0xa0,0x20,0x20,
+/* 13834 0x360a "㘊" */
+0x07,0x00,0xef,0xa8,0xa3,0xa0,0xa3,0xa0,0xa0,0xaf,0xe0,0xa7,0x00,0x07,0x04,0x07,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x80,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0xfc,
+/* 13835 0x360b "㘋" */
+0x07,0x05,0x77,0x54,0x57,0x55,0x57,0x50,0x53,0x52,0x73,0x52,0x03,0x02,0x03,0x01,
+0xde,0x12,0xd2,0x54,0xc8,0x14,0xe2,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,
+/* 13836 0x360c "㘌" */
+0x02,0x03,0xe2,0xaf,0xaa,0xab,0xae,0xa9,0xa8,0xaf,0xea,0xad,0x0a,0x0d,0x12,0x25,
+0x02,0xc2,0x02,0xea,0x2a,0x8a,0x4a,0xca,0x0a,0xea,0x0a,0x4a,0x82,0xc2,0xaa,0x84,
+/* 13837 0x360d "㘍" */
+0x01,0x01,0xe5,0xa5,0xa8,0xa1,0xa2,0xa7,0xbc,0xa7,0xe4,0xa7,0x04,0x07,0x04,0x04,
+0x08,0x4c,0x2a,0x48,0x8e,0x38,0x88,0xea,0x8a,0xec,0x8c,0xe8,0x8a,0xfa,0x26,0x42,
+/* 13838 0x360e "㘎" */
+0x04,0x02,0xe2,0xa8,0xab,0xa8,0xaf,0xaa,0xab,0xaa,0xeb,0xaa,0x0f,0x08,0x08,0x08,
+0x00,0xfe,0x02,0x02,0x92,0x92,0xde,0xaa,0xca,0xaa,0x92,0xd2,0xaa,0xc6,0x82,0x06,
+/* 13839 0x360f "㘏" */
+0x21,0x17,0x10,0x03,0xf2,0x13,0x12,0x13,0x12,0x13,0x28,0x47,0x00,0x3e,0x22,0x3e,
+0x10,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x70,0xc2,0x3e,
+/* 13840 0x3610 "㘐" */
+0x00,0x07,0x75,0x57,0x55,0x57,0x55,0x55,0x57,0x50,0x75,0x55,0x05,0x04,0x00,0x01,
+0x10,0xc8,0x3e,0xc0,0x14,0xd2,0x22,0x00,0xd4,0x54,0x54,0x48,0x48,0x54,0x54,0xa2,
+/* 13841 0x3611 "㘑" */
+0x04,0x04,0x1f,0xe4,0xa4,0xae,0xa0,0xae,0xa0,0xbf,0xe4,0x04,0x16,0x25,0x14,0x08,
+0x10,0x10,0x7c,0x14,0x14,0xfe,0x14,0x14,0x7c,0x10,0x54,0x38,0x54,0x12,0x50,0x20,
+/* 13842 0x3612 "㘒" */
+0x0c,0x71,0x10,0x13,0xfd,0x31,0x39,0x55,0x50,0x93,0x10,0x7c,0x44,0x45,0x7c,0x44,
+0x38,0xe0,0x20,0xfe,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x00,0x40,0x78,0xc0,0x44,0x3c,
+/* 13843 0x3613 "㘓" */
+0x07,0x04,0xf7,0x94,0x97,0x94,0x95,0x94,0x95,0x95,0xf5,0x95,0x05,0x04,0x05,0x04,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xf4,0x44,0xf4,0x54,0xf4,0x54,0xf4,0xe4,0x54,0x4c,
+/* 13844 0x3614 "㘔" */
+0x00,0x07,0x74,0x53,0x50,0x53,0x50,0x57,0x51,0x53,0x75,0x51,0x01,0x01,0x00,0x01,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x90,0x08,
+/* 13845 0x3615 "㘕" */
+0x00,0x07,0x78,0x4b,0x4a,0x4b,0x4a,0x4b,0x4a,0x4b,0x78,0x4b,0x02,0x02,0x07,0x00,
+0x90,0xfe,0x90,0xe8,0x88,0xce,0x50,0xd4,0xa2,0xe2,0x00,0xfc,0x94,0x94,0xfe,0x00,
+/* 13846 0x3616 "㘖" */
+0x02,0x01,0xef,0xa4,0xa2,0xaf,0xa9,0xaa,0xac,0xa9,0xea,0xac,0x08,0x09,0x12,0x04,
+0x00,0x1e,0xc4,0x48,0x9e,0xd2,0x12,0x1e,0x92,0x1e,0x12,0x52,0x9e,0x00,0x0c,0x12,
+/* 13847 0x3617 "㘗" */
+0x07,0x04,0xf7,0x94,0x97,0x94,0x97,0x91,0x93,0x92,0xf7,0x9a,0x03,0x02,0x03,0x02,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 13848 0x3618 "㘘" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13849 0x3619 "㘙" */
+0x07,0x04,0x77,0x50,0x57,0x54,0x55,0x54,0x57,0x55,0x75,0x55,0x05,0x05,0x0b,0x10,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 13850 0x361a "㘚" */
+0x0f,0x08,0xef,0xa8,0xaf,0xa8,0xab,0xa8,0xaf,0xaa,0xeb,0xaa,0x0b,0x0a,0x0f,0x08,
+0xbe,0xa2,0xbe,0xa2,0xbe,0x02,0x92,0x92,0xde,0xaa,0xca,0xaa,0x92,0xd2,0xaa,0xc4,
+/* 13851 0x361b "㘛" */
+0x00,0x00,0x73,0x5d,0x50,0x53,0x52,0x53,0x51,0x57,0x72,0x4f,0x04,0x07,0x04,0x04,
+0x40,0xa0,0x18,0xf6,0x00,0xf8,0x08,0xf8,0x10,0xdc,0x84,0xfc,0x50,0xdc,0x52,0xce,
+/* 13852 0x361c "㘜" */
+0x51,0x4b,0x7c,0xd3,0x7c,0x53,0x7c,0x53,0x7e,0x43,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x18,0x94,0x3e,0xa8,0x7e,0xa8,0x3e,0xa8,0xbe,0xa0,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13853 0x361d "㘝" */
+0x00,0x7f,0x40,0x40,0x4f,0x40,0x48,0x44,0x42,0x41,0x42,0x44,0x48,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xc4,0x44,0x44,0x84,0x84,0x04,0x84,0x44,0x44,0x04,0xfc,0x04,
+/* 13854 0x361e "㘞" */
+0x00,0x7f,0x42,0x42,0x42,0x5f,0x42,0x42,0x42,0x44,0x44,0x48,0x49,0x50,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x84,0xfc,0x04,
+/* 13855 0x361f "㘟" */
+0x00,0x7f,0x40,0x44,0x44,0x44,0x5f,0x44,0x44,0x44,0x48,0x48,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x44,0x44,0x44,0xf4,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0xfc,0x04,
+/* 13856 0x3620 "㘠" */
+0x00,0x7f,0x40,0x42,0x41,0x41,0x44,0x54,0x55,0x66,0x44,0x4b,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x44,0x44,0x84,0xa4,0x14,0x54,0x44,0xc4,0x04,0x04,0xfc,0x04,
+/* 13857 0x3621 "㘡" */
+0x00,0x7f,0x40,0x40,0x5f,0x51,0x51,0x5f,0x51,0x51,0x5f,0x51,0x41,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x14,0xf4,0x14,0x04,0x04,0xfc,0x04,
+/* 13858 0x3622 "㘢" */
+0x00,0x7f,0x41,0x49,0x45,0x45,0x5f,0x42,0x42,0x42,0x44,0x48,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x24,0x24,0x44,0xf4,0x84,0x84,0x84,0x94,0x94,0x74,0x04,0xfc,0x04,
+/* 13859 0x3623 "㘣" */
+0x7f,0x40,0x47,0x44,0x47,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x48,0x48,0x7f,0x40,
+0xfc,0x04,0xc4,0x44,0xc4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xa4,0x44,0xfc,0x04,
+/* 13860 0x3624 "㘤" */
+0x00,0x7f,0x41,0x65,0x55,0x47,0x64,0x57,0x44,0x57,0x65,0x45,0x49,0x50,0x7f,0x40,
+0x00,0xfc,0x44,0x54,0x54,0x74,0x14,0xf4,0x14,0x74,0x54,0x54,0x54,0x14,0xfc,0x04,
+/* 13861 0x3625 "㘥" */
+0xff,0x80,0x86,0xf8,0xaa,0x94,0x90,0xbe,0xc8,0xbe,0x88,0xab,0xbe,0x80,0xff,0x80,
+0xfe,0x02,0x1a,0xe2,0x42,0x92,0xe2,0x4a,0xfa,0x22,0xaa,0x26,0x62,0x02,0xfe,0x02,
+/* 13862 0x3626 "㘦" */
+0x10,0x10,0x10,0x10,0x11,0xfe,0x10,0x10,0x10,0x10,0x16,0x18,0xe1,0x41,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 13863 0x3627 "㘧" */
+0x10,0x11,0x10,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 13864 0x3628 "㘨" */
+0x20,0x20,0x20,0x20,0x23,0xfa,0x22,0x22,0x22,0x22,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 13865 0x3629 "㘩" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 13866 0x362a "㘪" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x11,0x10,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 13867 0x362b "㘫" */
+0x10,0x10,0x10,0x10,0x11,0xfc,0x10,0x10,0x13,0x10,0x10,0x1c,0xe0,0x41,0x01,0x02,
+0x88,0x88,0x88,0x88,0xfc,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 13868 0x362c "㘬" */
+0x21,0x21,0x21,0x21,0xfa,0x24,0x20,0x21,0x21,0x22,0x27,0x3a,0xe0,0x40,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x84,0x84,0x04,0x44,0x24,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 13869 0x362d "㘭" */
+0x20,0x20,0x21,0x21,0x22,0xfa,0x27,0x20,0x20,0x21,0x21,0x3a,0xe7,0x42,0x00,0x00,
+0x80,0x80,0x3e,0x02,0x42,0x42,0xc2,0x82,0x82,0x02,0x42,0x22,0xe2,0x22,0x0a,0x04,
+/* 13870 0x362e "㘮" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 13871 0x362f "㘯" */
+0x10,0x10,0x11,0x11,0x12,0xfc,0x10,0x13,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x80,0x80,0x00,0xfe,0x00,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 13872 0x3630 "㘰" */
+0x10,0x11,0x10,0x10,0x10,0xfd,0x10,0x10,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 13873 0x3631 "㘱" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x13,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 13874 0x3632 "㘲" */
+0x20,0x23,0x22,0x22,0x23,0xfa,0x22,0x22,0x23,0x22,0x22,0x3a,0xe4,0x44,0x09,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x88,0x8a,0x0a,0x06,
+/* 13875 0x3633 "㘳" */
+0x04,0x04,0x7c,0x04,0x04,0x0c,0x34,0xc4,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 13876 0x3634 "㘴" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x49,0x79,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x10,0x10,0x10,0x10,0x28,0x24,0x44,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 13877 0x3635 "㘵" */
+0x10,0x10,0x10,0x17,0x10,0xfc,0x11,0x11,0x13,0x15,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 13878 0x3636 "㘶" */
+0x08,0x08,0x1e,0x22,0x52,0x0c,0x08,0x10,0x20,0x41,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x10,0x10,0xfc,0x10,0x90,0x90,0xfe,0x10,0x10,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13879 0x3637 "㘷" */
+0x11,0x11,0x13,0x11,0x11,0xfc,0x12,0x12,0x11,0x11,0x10,0x1c,0xe0,0x41,0x02,0x0c,
+0x10,0x10,0xfc,0x10,0x10,0x00,0x08,0x08,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 13880 0x3638 "㘸" */
+0x00,0xff,0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x21,0xc1,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfe,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13881 0x3639 "㘹" */
+0x08,0x08,0x28,0x2e,0x28,0x28,0x2e,0xf0,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x7c,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 13882 0x363a "㘺" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x2b,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 13883 0x363b "㘻" */
+0x20,0x23,0x22,0x22,0x22,0xfa,0x23,0x22,0x22,0x22,0x22,0x3a,0xe3,0x42,0x03,0x02,
+0x00,0xfe,0x02,0x22,0x22,0x22,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0xfe,0x02,
+/* 13884 0x363c "㘼" */
+0x10,0x10,0x11,0x10,0x10,0xfd,0x10,0x10,0x11,0x12,0x14,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 13885 0x363d "㘽" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,0x00,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 13886 0x363e "㘾" */
+0x20,0x20,0x23,0x22,0x24,0xf8,0x21,0x20,0x20,0x20,0x23,0x38,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 13887 0x363f "㘿" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x10,0x11,0x1c,0xe0,0x40,0x03,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 13888 0x3640 "㙀" */
+0x20,0x20,0x27,0x24,0x21,0xfa,0x24,0x20,0x23,0x20,0x20,0x39,0xe1,0x42,0x04,0x08,
+0x80,0x40,0xfc,0x04,0x10,0x08,0x84,0x80,0xf0,0x90,0x90,0x10,0x12,0x12,0x0e,0x00,
+/* 13889 0x3641 "㙁" */
+0x10,0x10,0x10,0x11,0x12,0xfc,0x10,0x10,0x13,0x10,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 13890 0x3642 "㙂" */
+0x11,0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x11,0x10,0x10,0x1c,0xe0,0x41,0x02,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 13891 0x3643 "㙃" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x13,0x1c,0xe0,0x41,0x02,0x04,
+0x10,0x38,0xc0,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,0x02,
+/* 13892 0x3644 "㙄" */
+0x11,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x10,0x11,0x1c,0xe0,0x40,0x03,0x00,
+0x10,0x12,0x14,0xd8,0x10,0x12,0x52,0x8e,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 13893 0x3645 "㙅" */
+0x20,0x23,0x22,0x22,0x22,0xfb,0x20,0x20,0x27,0x20,0x21,0x3a,0xe4,0x48,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x40,0x40,0xfc,0xe0,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 13894 0x3646 "㙆" */
+0x20,0x20,0x23,0x22,0x24,0xf8,0x23,0x20,0x20,0x20,0x21,0x39,0xe2,0x42,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x90,0x90,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 13895 0x3647 "㙇" */
+0x10,0x13,0x10,0x10,0x11,0xfe,0x10,0x12,0x11,0x12,0x10,0x1c,0xe1,0x42,0x00,0x00,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 13896 0x3648 "㙈" */
+0x20,0x20,0x20,0x20,0x23,0xfa,0x22,0x23,0x22,0x22,0x22,0x3a,0xe4,0x44,0x09,0x12,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 13897 0x3649 "㙉" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x1d,0xe3,0x40,0x00,0x01,0x02,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x88,0x04,0x02,
+/* 13898 0x364a "㙊" */
+0x20,0x21,0x21,0x21,0x21,0xf9,0x21,0x2f,0x22,0x22,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x80,0x48,0x50,0x20,0x10,0x88,0x06,0x00,
+/* 13899 0x364b "㙋" */
+0x10,0x10,0x13,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0x1c,0xe3,0x40,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 13900 0x364c "㙌" */
+0x10,0x10,0x11,0x10,0x13,0xfc,0x11,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x02,0x04,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0x24,0x74,0xac,0x24,0x24,0x24,0x24,
+/* 13901 0x364d "㙍" */
+0x20,0x27,0x20,0x22,0x21,0xfa,0x24,0x28,0x20,0x27,0x20,0x3a,0xe1,0x42,0x04,0x08,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 13902 0x364e "㙎" */
+0x20,0x20,0x27,0x24,0xf4,0x27,0x24,0x24,0x27,0x25,0x35,0xe4,0x45,0x0a,0x08,0x10,
+0x14,0x12,0xfe,0x10,0x10,0xf0,0x92,0x92,0xd2,0x54,0x54,0x88,0x4a,0x1a,0x26,0x42,
+/* 13903 0x364f "㙏" */
+0x11,0x11,0x11,0x12,0x15,0xfd,0x11,0x11,0x11,0x10,0x10,0x1d,0xe2,0x40,0x01,0x06,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 13904 0x3650 "㙐" */
+0x10,0x11,0x11,0x11,0x11,0xfc,0x13,0x10,0x10,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 13905 0x3651 "㙑" */
+0x00,0x3f,0x01,0x1f,0x11,0x1f,0x01,0x7f,0x41,0x41,0x5e,0x40,0x01,0x3f,0x01,0xff,
+0xf0,0x00,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x24,0xf4,0x14,0x08,0x00,0xf8,0x00,0xfe,
+/* 13906 0x3652 "㙒" */
+0x00,0x7e,0x4a,0x4a,0x7e,0x4a,0x4a,0x7e,0x00,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0xf8,0x08,0x50,0x20,0xfc,0x24,0x28,0x20,0xa0,0x40,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13907 0x3653 "㙓" */
+0x01,0x01,0x3f,0x01,0xff,0x08,0x3e,0x08,0x0e,0x78,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x00,0xf8,0x00,0xfe,0x20,0xf8,0x20,0x20,0xfc,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13908 0x3654 "㙔" */
+0x10,0x10,0x11,0x10,0x13,0xfc,0x11,0x11,0x11,0x10,0x13,0x1c,0xe2,0x43,0x00,0x00,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 13909 0x3655 "㙕" */
+0x20,0x23,0x22,0x23,0x22,0xfb,0x20,0x21,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 13910 0x3656 "㙖" */
+0x10,0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x10,0x13,0x12,0x1e,0xe2,0x42,0x02,0x02,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 13911 0x3657 "㙗" */
+0x20,0x23,0x22,0x22,0x23,0xfa,0x22,0x23,0x20,0x27,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 13912 0x3658 "㙘" */
+0x20,0x23,0x20,0x20,0x23,0xfa,0x22,0x23,0x20,0x20,0x27,0x38,0xe1,0x40,0x00,0x03,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 13913 0x3659 "㙙" */
+0x21,0x11,0x97,0x41,0x49,0x09,0x11,0xe1,0x22,0x22,0x25,0x01,0x3f,0x01,0x01,0xff,
+0x20,0x10,0xfe,0x28,0x34,0x28,0x32,0x24,0x3a,0x62,0x9e,0x00,0xf8,0x00,0x00,0xfe,
+/* 13914 0x365a "㙚" */
+0x10,0x10,0x13,0x10,0x11,0xfc,0x13,0x10,0x10,0x10,0x11,0x1c,0xe3,0x40,0x00,0x00,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 13915 0x365b "㙛" */
+0x10,0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x00,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 13916 0x365c "㙜" */
+0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x01,0x3f,0x01,0xff,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xec,0x00,0xf8,0x00,0xfe,
+/* 13917 0x365d "㙝" */
+0x20,0x21,0x20,0x20,0x21,0xfb,0x21,0x21,0x22,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0xfc,0x44,0x94,0x08,0xde,0x4a,0x4a,0x94,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 13918 0x365e "㙞" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x10,0x13,0x1c,0xe0,0x41,0x02,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 13919 0x365f "㙟" */
+0x21,0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x23,0x22,0x22,0x3a,0xe2,0x43,0x02,0x00,
+0x00,0x9e,0xd2,0x52,0x52,0xde,0x52,0x52,0xd2,0x1e,0x92,0x52,0xd2,0x52,0x2a,0x44,
+/* 13920 0x3660 "㙠" */
+0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x00,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13921 0x3661 "㙡" */
+0x21,0x21,0x22,0x24,0x29,0xf9,0x22,0x26,0x2a,0x22,0x22,0x3a,0xe2,0x42,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 13922 0x3662 "㙢" */
+0x20,0x20,0x23,0x20,0x20,0xf8,0x20,0x23,0x22,0x23,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 13923 0x3663 "㙣" */
+0x20,0x2f,0x21,0x21,0xf1,0x2f,0x28,0x28,0x28,0x2f,0x31,0xe1,0x41,0x01,0x0a,0x04,
+0x00,0x3e,0x20,0x3c,0x20,0x3c,0x20,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x62,0x40,
+/* 13924 0x3664 "㙤" */
+0x20,0x20,0x20,0x23,0x22,0xfa,0x23,0x22,0x22,0x22,0x23,0x3a,0xe5,0x44,0x08,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 13925 0x3665 "㙥" */
+0x20,0x20,0x27,0x21,0xfa,0x24,0x21,0x23,0x20,0x20,0x21,0x3b,0xe5,0x49,0x01,0x01,
+0x80,0x40,0xfc,0x10,0x48,0x84,0x20,0xf0,0x10,0x88,0x50,0x20,0x10,0x48,0x86,0x00,
+/* 13926 0x3666 "㙦" */
+0x08,0x14,0x22,0x5c,0x88,0x7f,0x08,0x2a,0x49,0x18,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x08,0x48,0x28,0x88,0x48,0x0e,0xf8,0x08,0x08,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13927 0x3667 "㙧" */
+0x20,0x23,0x20,0x23,0x22,0xfa,0x23,0x20,0x23,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x00,0xfe,0x50,0xde,0x52,0x52,0xde,0x50,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 13928 0x3668 "㙨" */
+0x22,0x22,0x25,0x27,0x22,0xfd,0x27,0x22,0x2f,0x22,0x22,0x3a,0xe5,0x44,0x04,0x08,
+0x48,0x48,0x54,0x5c,0x48,0x54,0x5c,0x48,0xfe,0x20,0x28,0x28,0x14,0x94,0x2c,0x44,
+/* 13929 0x3669 "㙩" */
+0x20,0x20,0x27,0x20,0x25,0xfa,0x27,0x2a,0x23,0x22,0x23,0x38,0xe2,0x44,0x09,0x00,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 13930 0x366a "㙪" */
+0x20,0x23,0x20,0x21,0x20,0xfb,0x22,0x21,0x20,0x21,0x21,0x39,0xe1,0x40,0x03,0x00,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 13931 0x366b "㙫" */
+0x10,0x10,0x11,0x13,0x11,0xfd,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x03,0x00,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 13932 0x366c "㙬" */
+0x08,0x08,0x7f,0x2a,0x2a,0x5d,0x1c,0x2a,0x49,0x88,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0x28,0x28,0x44,0x82,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 13933 0x366d "㙭" */
+0x20,0x2f,0x28,0x2a,0xf9,0x2b,0x28,0x28,0x2a,0x2a,0x3b,0xe8,0x48,0x09,0x09,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 13934 0x366e "㙮" */
+0x22,0x22,0x23,0x22,0x25,0xf8,0x21,0x22,0x25,0x20,0x20,0x3b,0xe2,0x42,0x03,0x02,
+0x10,0x10,0xde,0x28,0x44,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 13935 0x366f "㙯" */
+0x08,0x3e,0x08,0x7f,0x22,0x49,0x3e,0x08,0x7e,0x00,0x3f,0x00,0xff,0x08,0x10,0x3f,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x00,0xf8,0x00,0xfe,0x20,0x10,0xf8,
+/* 13936 0x3670 "㙰" */
+0x10,0x1e,0x22,0x7f,0xa9,0x3f,0x29,0x3f,0x29,0x29,0x45,0x82,0x01,0x3f,0x01,0xff,
+0x00,0xfc,0x24,0x44,0x9c,0x50,0x7c,0x90,0xfe,0x10,0x10,0x10,0x00,0xf8,0x00,0xfe,
+/* 13937 0x3671 "㙱" */
+0x00,0x7c,0x44,0x7d,0x01,0xfd,0x41,0x7d,0x05,0x2a,0x14,0x01,0x3f,0x01,0x01,0xff,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x70,0x54,0x8c,0x00,0xf8,0x00,0x00,0xfe,
+/* 13938 0x3672 "㙲" */
+0x20,0x20,0x27,0x20,0x22,0xf2,0x24,0x27,0x21,0x22,0x24,0x37,0xe1,0x42,0x04,0x08,
+0x40,0x20,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x7e,0x40,
+/* 13939 0x3673 "㙳" */
+0x20,0x20,0x27,0x24,0xf5,0x24,0x25,0x25,0x25,0x24,0x34,0xe8,0x42,0x02,0x04,0x00,
+0x14,0x12,0xfe,0x10,0xd0,0x14,0xd4,0x58,0xca,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 13940 0x3674 "㙴" */
+0x21,0x21,0x22,0x27,0x22,0xfb,0x23,0x22,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 13941 0x3675 "㙵" */
+0x10,0x13,0x10,0x10,0x10,0xfc,0x10,0x13,0x12,0x12,0x12,0x1e,0xe2,0x41,0x00,0x03,
+0x20,0xfe,0x00,0xf8,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x26,0xf8,0x20,0xfe,
+/* 13942 0x3676 "㙶" */
+0x01,0xff,0x10,0x1f,0x00,0x11,0x09,0x7f,0x40,0x9f,0x10,0x1f,0x01,0x3f,0x01,0xff,
+0x00,0xfe,0x10,0xf0,0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 13943 0x3677 "㙷" */
+0x20,0x23,0x22,0x23,0x22,0xfb,0x21,0x22,0x23,0x21,0x22,0x3b,0xe0,0x42,0x02,0x04,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 13944 0x3678 "㙸" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x26,0x2a,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 13945 0x3679 "㙹" */
+0x20,0x20,0x23,0x20,0x23,0xfa,0x23,0x20,0x23,0x22,0x20,0x39,0xe2,0x40,0x00,0x07,
+0x88,0x88,0xfe,0x88,0xfe,0x52,0xfe,0x00,0xfe,0x42,0xf8,0x08,0x90,0x60,0xc0,0x00,
+/* 13946 0x367a "㙺" */
+0x27,0x24,0x25,0x25,0x25,0xfc,0x27,0x25,0x25,0x25,0x25,0x3d,0xe5,0x44,0x05,0x07,
+0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0xfe,
+/* 13947 0x367b "㙻" */
+0x20,0x27,0x24,0x25,0x25,0xf5,0x25,0x25,0x24,0x25,0x24,0x37,0xe5,0x4a,0x08,0x13,
+0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x24,0xfa,0x20,0xfe,
+/* 13948 0x367c "㙼" */
+0x23,0x22,0x22,0x23,0x22,0xfa,0x23,0x20,0x2f,0x2a,0x2a,0x3f,0xea,0x4a,0x0f,0x08,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 13949 0x367d "㙽" */
+0x20,0x20,0x27,0x20,0x23,0xf9,0x23,0x22,0x23,0x22,0x23,0x38,0xe0,0x40,0x01,0x06,
+0x20,0x20,0xfe,0x20,0xae,0x24,0xae,0xaa,0xae,0xaa,0xae,0x50,0x50,0x88,0x04,0x02,
+/* 13950 0x367e "㙾" */
+0x22,0x24,0x24,0x26,0xf4,0x26,0x24,0x2f,0x28,0x23,0x30,0xe0,0x47,0x00,0x01,0x00,
+0xa0,0x4c,0xa4,0x0c,0xa4,0x4c,0xa4,0xfe,0x02,0xf0,0x20,0x40,0xfc,0x40,0x40,0x80,
+/* 13951 0x367f "㙿" */
+0x21,0x27,0x20,0x23,0x20,0xf7,0x20,0x23,0x21,0x27,0x23,0x35,0xe7,0x42,0x04,0x08,
+0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xd4,0x12,0xfe,0x50,0x34,0x8c,0xca,0x56,0xc2,
+/* 13952 0x3680 "㚀" */
+0x21,0x21,0x21,0x27,0xf5,0x25,0x27,0x24,0x24,0x27,0x34,0xe7,0x4a,0x0b,0x11,0x07,
+0x08,0xec,0x0a,0xe8,0x28,0xde,0x28,0xea,0x0a,0xea,0x0c,0xec,0x2a,0xea,0x56,0xe2,
+/* 13953 0x3681 "㚁" */
+0x10,0x10,0x7c,0x10,0xfe,0x44,0xee,0x44,0x64,0xde,0x00,0xfe,0x28,0x2a,0x4c,0x88,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0xee,0x44,0x64,0xde,0x00,0xfe,0x28,0x28,0x4a,0x86,
+/* 13954 0x3682 "㚂" */
+0x20,0x27,0x22,0x23,0xf0,0x2f,0x2a,0x23,0x21,0x27,0x31,0xef,0x41,0x03,0x0d,0x01,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 13955 0x3683 "㚃" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x7f,0x40,0x84,0x23,0x24,0x20,0x3f,0x08,0x04,0x7f,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x02,0x44,0x88,0x48,0x08,0xf8,0x20,0x40,0xfc,
+/* 13956 0x3684 "㚄" */
+0x01,0x7f,0x01,0x1f,0x00,0x7f,0x51,0x9f,0x11,0x1f,0x00,0x7f,0x01,0x11,0x29,0x47,
+0x00,0xfc,0x00,0xf0,0x00,0xfe,0x12,0xf4,0x10,0xf0,0x00,0xfc,0x04,0xf0,0x00,0xfe,
+/* 13957 0x3685 "㚅" */
+0x02,0x07,0x08,0x14,0x03,0x1c,0xe0,0x1f,0x01,0x11,0x1f,0x21,0x5f,0x01,0xff,0x00,
+0x00,0xe0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x00,0x00,0xf8,0x00,0xf0,0x00,0xfe,0x00,
+/* 13958 0x3686 "㚆" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x0f,0x14,0x22,0x41,0x0e,0x70,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x20,0x40,0x80,0x60,0x1c,
+/* 13959 0x3687 "㚇" */
+0x04,0x22,0x21,0x22,0x24,0x3f,0x12,0x22,0x47,0x08,0x14,0x22,0x01,0x06,0x18,0xe0,
+0x40,0x88,0x08,0x88,0x48,0xf8,0x10,0x08,0xe4,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 13960 0x3688 "㚈" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x8a,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 13961 0x3689 "㚉" */
+0x00,0x3f,0x08,0x08,0x08,0x12,0x17,0x38,0x45,0x06,0x39,0x06,0x19,0x00,0x03,0x3c,
+0x00,0xf0,0x10,0x20,0x3c,0x04,0xe4,0x54,0x88,0x80,0xf8,0x10,0x20,0xc0,0x00,0x00,
+/* 13962 0x368a "㚊" */
+0x20,0x20,0x3c,0x45,0x48,0xa8,0x10,0x28,0x4e,0x12,0x24,0x55,0x08,0x10,0x20,0xc1,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 13963 0x368b "㚋" */
+0x20,0x21,0x3d,0x45,0x49,0xa9,0x11,0x29,0x4f,0x13,0x25,0x55,0x09,0x12,0x22,0xc4,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 13964 0x368c "㚌" */
+0x20,0x21,0x3d,0x45,0x49,0xa9,0x11,0x29,0x4e,0x13,0x24,0x54,0x09,0x12,0x20,0xc0,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 13965 0x368d "㚍" */
+0x20,0x21,0x3d,0x45,0x48,0xab,0x10,0x29,0x4f,0x13,0x25,0x55,0x09,0x11,0x20,0xc1,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 13966 0x368e "㚎" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,0x00,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 13967 0x368f "㚏" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,0x08,0x08,0x7f,0x08,0x08,0x10,0x10,0x20,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 13968 0x3690 "㚐" */
+0x01,0x01,0x7f,0x01,0x02,0x04,0x18,0x60,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x00,0xc0,0x20,0x10,0x08,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 13969 0x3691 "㚑" */
+0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 13970 0x3692 "㚒" */
+0x01,0x01,0x01,0x7f,0x01,0x21,0x11,0x11,0x29,0x45,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfc,0x00,0x20,0x10,0x10,0x28,0x44,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 13971 0x3693 "㚓" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x31,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 13972 0x3694 "㚔" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc8,0x04,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x26,0x40,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 13973 0x3695 "㚕" */
+0x02,0x02,0x7f,0x04,0x08,0x34,0xc4,0x7f,0x04,0x3f,0x24,0x3f,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfc,0x40,0x20,0x58,0x46,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0x48,0x40,
+/* 13974 0x3696 "㚖" */
+0x01,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 13975 0x3697 "㚗" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xdf,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 13976 0x3698 "㚘" */
+0x10,0x10,0x10,0x10,0x7d,0x10,0x10,0x10,0xfd,0x10,0x10,0x10,0x28,0x24,0x45,0x82,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 13977 0x3699 "㚙" */
+0x10,0x10,0x7e,0x12,0x12,0x12,0x22,0x4a,0x85,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 13978 0x369a "㚚" */
+0x02,0x02,0x7f,0x04,0x08,0x32,0xc7,0x08,0x34,0x02,0x03,0x1f,0xe8,0x08,0x0f,0x08,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x20,0x40,0x80,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 13979 0x369b "㚛" */
+0x02,0x02,0x7f,0x04,0x08,0x38,0xcf,0x08,0x07,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x40,0x20,0xd8,0x06,0x10,0xf0,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 13980 0x369c "㚜" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc0,0x3f,0x00,0x3e,0x22,0x3e,0x00,0x0e,0x71,0x06,
+0x00,0x00,0xfc,0x40,0x20,0x98,0xa6,0xf8,0x80,0x80,0x48,0x50,0x24,0x54,0x8c,0x04,
+/* 13981 0x369d "㚝" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc8,0x08,0x13,0x30,0x57,0x90,0x13,0x10,0x17,0x10,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x40,0xf8,0x40,0xfc,0x40,0xf8,0x40,0xfc,0x00,
+/* 13982 0x369e "㚞" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc8,0x08,0x7e,0x08,0x1c,0x2a,0x48,0x89,0x08,0x08,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x26,0x20,0xfc,0x20,0x70,0x68,0xa4,0x22,0x20,0x20,
+/* 13983 0x369f "㚟" */
+0x08,0x1f,0x20,0x7f,0xa0,0x3f,0x20,0x3c,0x20,0x3d,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x00,0xc0,0x80,0xf0,0x10,0xf0,0x88,0xf4,0x84,0x7c,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 13984 0x36a0 "㚠" */
+0x02,0x02,0x7f,0x04,0x08,0x34,0xc2,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x24,0x22,0x42,
+0x00,0x00,0xfc,0x40,0x20,0x58,0x86,0xf8,0x00,0xf0,0x00,0xfc,0x00,0x88,0x44,0x44,
+/* 13985 0x36a1 "㚡" */
+0x10,0x10,0xfe,0x10,0x28,0x44,0xfe,0x04,0x74,0x54,0x54,0x74,0x54,0x04,0x14,0x08,
+0x10,0x10,0xfe,0x10,0x28,0x44,0xfe,0x04,0x74,0x54,0x54,0x74,0x54,0x04,0x14,0x08,
+/* 13986 0x36a2 "㚢" */
+0x10,0x10,0x10,0x20,0x2f,0x61,0x61,0xa2,0x22,0x26,0x21,0x20,0x20,0x21,0x22,0x2c,
+0x80,0x80,0x80,0x80,0xfe,0x08,0x08,0x08,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x04,
+/* 13987 0x36a3 "㚣" */
+0x02,0x02,0xff,0x08,0x1c,0x03,0x04,0x18,0x62,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x00,0xfe,0x40,0x80,0x80,0x70,0x08,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 13988 0x36a4 "㚤" */
+0x10,0x10,0x10,0x10,0xfe,0x23,0x22,0x22,0x42,0x24,0x14,0x08,0x14,0x22,0x42,0x80,
+0x48,0x44,0x44,0x40,0x4e,0xf0,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 13989 0x36a5 "㚥" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 13990 0x36a6 "㚦" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x85,0x02,
+0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,0x08,
+/* 13991 0x36a7 "㚧" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x85,0x02,
+0x20,0x10,0x10,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 13992 0x36a8 "㚨" */
+0x10,0x13,0x10,0x10,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 13993 0x36a9 "㚩" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x24,0x24,0x24,0x49,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 13994 0x36aa "㚪" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x25,0x24,0x24,0x48,0x2b,0x10,0x28,0x44,0x84,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 13995 0x36ab "㚫" */
+0x20,0x23,0x20,0x20,0xf8,0x48,0x48,0x48,0x89,0x49,0x31,0x11,0x2a,0x4a,0x84,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 13996 0x36ac "㚬" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x24,0x24,0x48,0x28,0x10,0x29,0x44,0x84,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 13997 0x36ad "㚭" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x85,0x02,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 13998 0x36ae "㚮" */
+0x10,0x10,0x11,0x11,0xfd,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x01,
+0x00,0x00,0xfe,0x02,0x02,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 13999 0x36af "㚯" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4a,0x4a,0x8a,0x4a,0x32,0x13,0x2c,0x44,0x88,0x10,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 14000 0x36b0 "㚰" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x24,0x25,0x4a,0x28,0x10,0x28,0x44,0x83,0x00,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 14001 0x36b1 "㚱" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x85,0x00,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 14002 0x36b2 "㚲" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14003 0x36b3 "㚳" */
+0x21,0x21,0x21,0x21,0xfb,0x49,0x49,0x49,0x89,0x49,0x31,0x11,0x29,0x4a,0x83,0x04,
+0x00,0x00,0x00,0x1c,0xd4,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x54,0x80,
+/* 14004 0x36b4 "㚴" */
+0x20,0x20,0x20,0x23,0xf8,0x48,0x49,0x49,0x8b,0x4d,0x31,0x11,0x29,0x49,0x80,0x00,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 14005 0x36b5 "㚵" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x24,0x24,0x4b,0x28,0x10,0x28,0x44,0x84,0x00,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 14006 0x36b6 "㚶" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14007 0x36b7 "㚷" */
+0x20,0x20,0x20,0x20,0xf8,0x49,0x4a,0x48,0x48,0x90,0x51,0x21,0x32,0x48,0x48,0x80,
+0x20,0x20,0x50,0x50,0x88,0x04,0x22,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 14008 0x36b8 "㚸" */
+0x10,0x11,0x10,0x10,0xfd,0x24,0x24,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 14009 0x36b9 "㚹" */
+0x20,0x20,0x23,0x22,0xfa,0x4a,0x4a,0x4a,0x4a,0x92,0x53,0x22,0x30,0x48,0x49,0x82,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 14010 0x36ba "㚺" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x25,0x26,0x24,0x48,0x2b,0x10,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x44,0x48,0x8e,0x82,0x7a,0x14,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 14011 0x36bb "㚻" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x04,0x04,0xff,0x08,0x1c,0x03,0x0c,0x30,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14012 0x36bc "㚼" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 14013 0x36bd "㚽" */
+0x00,0x7d,0x10,0x10,0x11,0x10,0x1e,0xe0,0x42,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14014 0x36be "㚾" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x82,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 14015 0x36bf "㚿" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 14016 0x36c0 "㛀" */
+0x10,0x10,0x10,0x11,0xfe,0x24,0x25,0x24,0x24,0x48,0x29,0x10,0x28,0x44,0x85,0x00,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 14017 0x36c1 "㛁" */
+0x10,0x11,0x10,0x10,0xfd,0x24,0x24,0x24,0x27,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 14018 0x36c2 "㛂" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x7c,0x54,0x54,0x54,0x54,0x7c,0x40,0x40,0x42,0x42,0x3e,
+/* 14019 0x36c3 "㛃" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x0a,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x00,0x7c,0x24,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14020 0x36c4 "㛄" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x24,0x24,0x25,0x4a,0x2c,0x10,0x28,0x44,0x84,0x00,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x88,0xa4,0xc2,0x80,
+/* 14021 0x36c5 "㛅" */
+0x10,0x13,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x13,0x28,0x44,0x84,0x00,
+0x00,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x8e,0xf8,0x08,0x08,0x08,0x08,
+/* 14022 0x36c6 "㛆" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x25,0x24,0x4b,0x28,0x10,0x28,0x45,0x82,0x00,
+0x00,0xfc,0x44,0x48,0x5e,0x82,0x8a,0x24,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 14023 0x36c7 "㛇" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 14024 0x36c8 "㛈" */
+0x10,0x10,0x11,0x10,0xfc,0x25,0x24,0x24,0x25,0x4a,0x2c,0x10,0x28,0x44,0x84,0x00,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 14025 0x36c9 "㛉" */
+0x10,0x13,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x54,0x8c,0x04,0x04,0x04,0xfc,0x04,
+/* 14026 0x36ca "㛊" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x26,0x25,0x48,0x28,0x10,0x29,0x46,0x84,0x00,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x26,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 14027 0x36cb "㛋" */
+0x20,0x20,0x20,0x20,0xf9,0x4a,0x4c,0x48,0x49,0x91,0x52,0x24,0x30,0x48,0x49,0x80,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x46,0x40,0x44,0x52,0x4a,0x4a,0x48,0x40,0x40,0x80,
+/* 14028 0x36cc "㛌" */
+0x20,0x20,0x20,0x21,0xfb,0x48,0x49,0x49,0x49,0x92,0x50,0x27,0x30,0x48,0x48,0x80,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 14029 0x36cd "㛍" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x25,0x25,0x25,0x4a,0x28,0x10,0x28,0x44,0x81,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 14030 0x36ce "㛎" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfe,0x02,
+/* 14031 0x36cf "㛏" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x25,0x24,0x24,0x48,0x28,0x11,0x2a,0x44,0x84,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 14032 0x36d0 "㛐" */
+0x10,0x13,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x80,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 14033 0x36d1 "㛑" */
+0x08,0x0f,0x28,0x3f,0x61,0x92,0x0c,0x31,0xc0,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x7c,0x44,0x44,0x28,0x10,0x68,0x86,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14034 0x36d2 "㛒" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x85,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 14035 0x36d3 "㛓" */
+0x21,0x20,0x20,0x20,0xfb,0x48,0x4b,0x48,0x49,0x93,0x55,0x21,0x31,0x49,0x48,0x80,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 14036 0x36d4 "㛔" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x2b,0x44,0x80,0x00,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 14037 0x36d5 "㛕" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 14038 0x36d6 "㛖" */
+0x20,0x20,0x20,0x21,0xfb,0x48,0x48,0x49,0x8a,0x48,0x31,0x12,0x28,0x48,0x81,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 14039 0x36d7 "㛗" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x26,0x24,0x24,0x49,0x28,0x10,0x28,0x44,0x83,0x00,
+0x20,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 14040 0x36d8 "㛘" */
+0x20,0x20,0x23,0x20,0xf8,0x4b,0x4a,0x4c,0x49,0x90,0x50,0x23,0x30,0x48,0x48,0x80,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 14041 0x36d9 "㛙" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x27,0x24,0x24,0x48,0x29,0x10,0x28,0x44,0x84,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 14042 0x36da "㛚" */
+0x10,0x11,0x10,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 14043 0x36db "㛛" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x4b,0x28,0x10,0x28,0x45,0x86,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xfa,0x0a,0x0c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 14044 0x36dc "㛜" */
+0x10,0x10,0x24,0x64,0xa5,0x24,0x24,0x24,0x22,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x40,0x40,0xfe,0x88,0x48,0x50,0x20,0x50,0x8c,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14045 0x36dd "㛝" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x10,0x28,0x44,0x81,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 14046 0x36de "㛞" */
+0x10,0x13,0x10,0x10,0xfd,0x24,0x24,0x27,0x24,0x48,0x2b,0x10,0x28,0x45,0x81,0x02,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,
+/* 14047 0x36df "㛟" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x2b,0x10,0x28,0x44,0x81,0x06,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 14048 0x36e0 "㛠" */
+0x21,0x20,0x22,0x22,0xfa,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x00,0xbe,0x82,0x02,0x02,0xfa,0x8a,0x8a,0xfa,0x8a,0x8a,0xfa,0x02,0x02,0x0a,0x04,
+/* 14049 0x36e1 "㛡" */
+0x10,0x10,0x13,0x12,0xfc,0x25,0x24,0x24,0x27,0x48,0x28,0x10,0x29,0x45,0x82,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 14050 0x36e2 "㛢" */
+0x20,0x21,0x20,0x20,0xfb,0x48,0x49,0x4a,0x89,0x48,0x30,0x10,0x29,0x49,0x82,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 14051 0x36e3 "㛣" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x80,0x03,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 14052 0x36e4 "㛤" */
+0x20,0x23,0x20,0x20,0xfb,0x4a,0x4a,0x4a,0x4b,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x00,0xfe,0x00,0x00,0xde,0x52,0x52,0x52,0x5a,0xd6,0x52,0x52,0x52,0x52,0x52,0xd6,
+/* 14053 0x36e5 "㛥" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x26,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14054 0x36e6 "㛦" */
+0x21,0x21,0x21,0x21,0xf7,0x51,0x51,0x53,0x53,0x95,0x55,0x29,0x21,0x51,0x51,0x81,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 14055 0x36e7 "㛧" */
+0x10,0x11,0x11,0x11,0xfd,0x24,0x24,0x27,0x24,0x48,0x28,0x11,0x2a,0x44,0x84,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0x00,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 14056 0x36e8 "㛨" */
+0x21,0x20,0x20,0x23,0xf8,0x48,0x4b,0x48,0x88,0x4f,0x30,0x10,0x29,0x49,0x82,0x04,
+0x08,0x88,0x90,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0xa0,0xa0,0x20,0x22,0x22,0x1e,
+/* 14057 0x36e9 "㛩" */
+0x10,0x10,0x13,0x10,0xfd,0x27,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 14058 0x36ea "㛪" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x26,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x84,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 14059 0x36eb "㛫" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x29,0x12,0x28,0x45,0x84,0x00,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 14060 0x36ec "㛬" */
+0x20,0x20,0x21,0x20,0xf8,0x4b,0x48,0x49,0x4a,0x90,0x51,0x20,0x30,0x48,0x4b,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 14061 0x36ed "㛭" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x27,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14062 0x36ee "㛮" */
+0x10,0x10,0x13,0x12,0xfc,0x25,0x24,0x24,0x25,0x48,0x28,0x10,0x28,0x44,0x80,0x03,
+0x40,0x20,0xfe,0x22,0xa4,0x28,0x50,0x88,0x04,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 14063 0x36ef "㛯" */
+0x22,0x22,0x23,0x24,0xf9,0x57,0x55,0x55,0x55,0x97,0x52,0x22,0x22,0x54,0x54,0x88,
+0x10,0x10,0x90,0xbc,0x14,0xd4,0x54,0x54,0x54,0xd4,0xa4,0xac,0xc2,0x82,0x7e,0x00,
+/* 14064 0x36f0 "㛰" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 14065 0x36f1 "㛱" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x4b,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 14066 0x36f2 "㛲" */
+0x10,0x13,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 14067 0x36f3 "㛳" */
+0x01,0x7f,0x08,0x04,0x7f,0x41,0x1f,0x11,0x11,0x11,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x00,0xfc,0x20,0x40,0xfc,0x04,0xf0,0x10,0x50,0x20,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 14068 0x36f4 "㛴" */
+0x20,0x21,0x22,0x21,0xf8,0x48,0x48,0x4b,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4b,0x82,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 14069 0x36f5 "㛵" */
+0x10,0x13,0x10,0x11,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x2b,0x45,0x85,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfe,0x04,0x14,0x08,
+/* 14070 0x36f6 "㛶" */
+0x10,0x11,0x11,0x11,0xfd,0x24,0x24,0x27,0x24,0x49,0x29,0x12,0x2a,0x44,0x88,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x80,0x80,0xfe,0x90,0x10,0x52,0x54,0xa8,0x28,0x44,0x82,
+/* 14071 0x36f7 "㛷" */
+0x0c,0x70,0x13,0xfc,0x30,0x58,0x94,0x11,0x12,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x48,0x44,0xfe,0x50,0x50,0x92,0x92,0x0e,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14072 0x36f8 "㛸" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x24,0x24,0x25,0x49,0x29,0x11,0x28,0x44,0x84,0x03,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x88,0x50,0xfe,
+/* 14073 0x36f9 "㛹" */
+0x21,0x21,0x21,0x22,0xfa,0x4a,0x4e,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x00,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x90,0x50,0x20,0x58,0x86,
+/* 14074 0x36fa "㛺" */
+0x10,0x10,0x13,0x10,0xfd,0x24,0x27,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfe,0x00,0x04,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14075 0x36fb "㛻" */
+0x20,0x20,0x23,0x20,0xf8,0x4b,0x49,0x48,0x48,0x93,0x50,0x20,0x31,0x48,0x48,0x83,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 14076 0x36fc "㛼" */
+0x10,0x10,0x11,0x10,0xfc,0x27,0x24,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 14077 0x36fd "㛽" */
+0x20,0x20,0x23,0x22,0xf8,0x49,0x48,0x48,0x4b,0x90,0x50,0x20,0x31,0x4a,0x48,0x80,
+0x40,0x20,0xfe,0x02,0x20,0x24,0xa8,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 14078 0x36fe "㛾" */
+0x20,0x20,0x20,0x23,0xfa,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x84,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 14079 0x36ff "㛿" */
+0x20,0x20,0x23,0x20,0xf8,0x48,0x4b,0x4a,0x88,0x49,0x31,0x11,0x29,0x49,0x80,0x00,
+0xa8,0xa8,0xfe,0xa8,0xa8,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 14080 0x3700 "㜀" */
+0x21,0x21,0x21,0x21,0xfb,0x49,0x49,0x4b,0x4b,0x95,0x59,0x21,0x31,0x49,0x49,0x81,
+0x00,0x00,0x3c,0x24,0xa4,0x24,0x3c,0xa4,0x64,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,
+/* 14081 0x3701 "㜁" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x26,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x83,0x00,
+0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 14082 0x3702 "㜂" */
+0x08,0x7e,0x08,0xfe,0x08,0x7e,0x08,0x0f,0xf0,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14083 0x3703 "㜃" */
+0x20,0x20,0x20,0x21,0xf9,0x4b,0x4d,0x49,0x49,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x90,0x88,0xfe,0x00,0x00,0x3c,0x00,0x00,0x3c,0x00,0x00,0x3c,0x24,0x24,0x3c,0x24,
+/* 14084 0x3704 "㜄" */
+0x20,0x27,0x24,0x24,0xf5,0x54,0x55,0x55,0x55,0x95,0x54,0x24,0x25,0x54,0x58,0x90,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 14085 0x3705 "㜅" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x24,0x24,0x25,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfe,0x40,0x88,0xf0,0x20,0x44,0xfe,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 14086 0x3706 "㜆" */
+0x20,0x20,0x24,0x22,0xfa,0x48,0x48,0x4e,0x8a,0x4a,0x33,0x12,0x2a,0x45,0x88,0x00,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 14087 0x3707 "㜇" */
+0x20,0x20,0x21,0x20,0xfb,0x48,0x49,0x48,0x8b,0x48,0x30,0x10,0x2a,0x4a,0x84,0x00,
+0x20,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 14088 0x3708 "㜈" */
+0x00,0x7e,0x14,0x08,0xfe,0x2a,0x48,0xa8,0x12,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x7c,0xc4,0x38,0xc6,0x20,0xfc,0x44,0x8c,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14089 0x3709 "㜉" */
+0x21,0x22,0x22,0x21,0xfb,0x4a,0x4b,0x48,0x4b,0x92,0x52,0x23,0x32,0x4a,0x49,0x80,
+0x24,0x48,0x48,0x24,0xf8,0x08,0xf8,0x00,0xf8,0x48,0x48,0xf8,0x02,0x02,0xfe,0x00,
+/* 14090 0x370a "㜊" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4a,0x4a,0x8a,0x4a,0x33,0x12,0x2a,0x44,0x84,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x48,0x48,0xfc,0x48,0x48,0xfe,0xa4,0xa8,0x90,0xc8,0x86,
+/* 14091 0x370b "㜋" */
+0x21,0x20,0x20,0x20,0xfb,0x48,0x48,0x49,0x8a,0x49,0x31,0x11,0x29,0x49,0x87,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 14092 0x370c "㜌" */
+0x10,0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x10,0xfc,0x24,0x68,0x30,0x48,0x85,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14093 0x370d "㜍" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 14094 0x370e "㜎" */
+0x10,0x13,0x11,0x10,0xfc,0x24,0x25,0x24,0x24,0x49,0x28,0x10,0x2b,0x44,0x84,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 14095 0x370f "㜏" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0xfe,0x02,0xfe,0x02,0xfe,0x48,0x84,0x02,
+/* 14096 0x3710 "㜐" */
+0x10,0x11,0x11,0x11,0xfd,0x24,0x27,0x24,0x25,0x49,0x29,0x11,0x28,0x44,0x83,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 14097 0x3711 "㜑" */
+0x40,0x2f,0x00,0x87,0x54,0x17,0xe4,0x27,0x24,0x20,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x48,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x00,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 14098 0x3712 "㜒" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x48,0x2b,0x10,0x28,0x44,0x85,0x02,
+0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x88,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 14099 0x3713 "㜓" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x25,0x26,0x48,0x28,0x11,0x29,0x45,0x85,0x01,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 14100 0x3714 "㜔" */
+0x10,0x10,0x13,0x11,0xfc,0x27,0x24,0x25,0x25,0x49,0x29,0x10,0x28,0x45,0x82,0x04,
+0x80,0x40,0xfc,0x08,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 14101 0x3715 "㜕" */
+0x20,0x20,0x22,0x21,0xf9,0x48,0x48,0x4b,0x89,0x49,0x31,0x11,0x29,0x4a,0x84,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 14102 0x3716 "㜖" */
+0x20,0x20,0x27,0x20,0xfb,0x4a,0x4b,0x4a,0x4b,0x90,0x51,0x21,0x31,0x49,0x49,0x81,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 14103 0x3717 "㜗" */
+0x20,0x20,0x21,0x21,0xfa,0x4b,0x48,0x49,0x4e,0x90,0x53,0x20,0x33,0x48,0x48,0x87,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 14104 0x3718 "㜘" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x02,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,
+/* 14105 0x3719 "㜙" */
+0x20,0x20,0x23,0x22,0xfa,0x4b,0x4a,0x4a,0x8b,0x4a,0x32,0x12,0x2a,0x44,0x84,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 14106 0x371a "㜚" */
+0x20,0x20,0x27,0x24,0xf9,0x49,0x4a,0x4e,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x40,0x20,0xfe,0x02,0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 14107 0x371b "㜛" */
+0x21,0x21,0x21,0x27,0xf1,0x57,0x55,0x57,0x55,0x97,0x51,0x27,0x21,0x51,0x51,0x81,
+0x08,0x08,0x08,0xc8,0x1e,0xd2,0x64,0xc0,0x48,0xc8,0x08,0xc8,0x14,0x14,0x24,0x42,
+/* 14108 0x371c "㜜" */
+0x21,0x21,0x21,0x27,0xf1,0x57,0x51,0x5f,0x52,0x93,0x52,0x22,0x22,0x54,0x54,0x88,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 14109 0x371d "㜝" */
+0x20,0x20,0x20,0x21,0xfa,0x48,0x48,0x4b,0x48,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x20,0x50,0x88,0x24,0xfa,0x10,0x20,0xfe,0x50,0xfc,0x54,0x8c,0x04,0xfc,0x04,0xfc,
+/* 14110 0x371e "㜞" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x0a,0xff,0x08,0x1c,0x03,0x3c,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0xfe,0x20,0x40,0xc0,0x38,
+/* 14111 0x371f "㜟" */
+0x20,0x23,0x20,0x21,0xf7,0x52,0x52,0x53,0x52,0x93,0x52,0x22,0x23,0x56,0x50,0x80,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 14112 0x3720 "㜠" */
+0x10,0x12,0x13,0x10,0xfc,0x25,0x27,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 14113 0x3721 "㜡" */
+0x21,0x21,0x22,0x24,0xf9,0x49,0x4a,0x4e,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x83,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 14114 0x3722 "㜢" */
+0x10,0x11,0x11,0x13,0xfd,0x25,0x24,0x25,0x25,0x49,0x28,0x13,0x28,0x45,0x84,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 14115 0x3723 "㜣" */
+0x21,0x21,0x21,0x22,0xfa,0x4d,0x48,0x4a,0x49,0x91,0x52,0x24,0x30,0x4a,0x4a,0x84,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 14116 0x3724 "㜤" */
+0x20,0x23,0x20,0x23,0xfa,0x4b,0x48,0x49,0x49,0x91,0x51,0x21,0x30,0x4b,0x48,0x80,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 14117 0x3725 "㜥" */
+0x20,0x23,0x22,0x22,0xfb,0x48,0x49,0x49,0x49,0x91,0x51,0x21,0x31,0x48,0x49,0x82,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 14118 0x3726 "㜦" */
+0x20,0x23,0x20,0x23,0xf8,0x4b,0x48,0x4b,0x49,0x97,0x50,0x23,0x31,0x48,0x48,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 14119 0x3727 "㜧" */
+0x20,0x27,0x24,0x26,0xf5,0x57,0x54,0x54,0x56,0x96,0x57,0x24,0x24,0x55,0x59,0x92,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 14120 0x3728 "㜨" */
+0x20,0x23,0x22,0x23,0xfa,0x4a,0x4a,0x4a,0x8a,0x4a,0x32,0x12,0x2a,0x45,0x84,0x08,
+0x00,0xfe,0x02,0xfe,0x10,0x54,0x38,0x54,0x82,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,
+/* 14121 0x3729 "㜩" */
+0x20,0x20,0x23,0x22,0xfa,0x4a,0x4b,0x4a,0x4a,0x92,0x50,0x23,0x30,0x48,0x48,0x83,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 14122 0x372a "㜪" */
+0x08,0x7f,0x22,0xff,0x08,0x7f,0x2a,0x49,0xa8,0x14,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 14123 0x372b "㜫" */
+0x22,0x22,0x26,0x2b,0xf0,0x52,0x55,0x5c,0x54,0x95,0x55,0x25,0x25,0x55,0x56,0x84,
+0x88,0xa8,0xa8,0xf0,0x1e,0x24,0xd4,0x14,0x14,0xd4,0x54,0x48,0x68,0x54,0x14,0x22,
+/* 14124 0x372c "㜬" */
+0x21,0x21,0x22,0x27,0xfa,0x4b,0x4b,0x4a,0x8a,0x4a,0x32,0x12,0x2a,0x44,0x84,0x08,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 14125 0x372d "㜭" */
+0x10,0x11,0x10,0x13,0xfe,0x24,0x24,0x24,0x24,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 14126 0x372e "㜮" */
+0x20,0x23,0x22,0x23,0xfa,0x4b,0x4a,0x4b,0x88,0x49,0x31,0x11,0x29,0x49,0x87,0x00,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 14127 0x372f "㜯" */
+0x20,0x27,0x24,0x24,0xf5,0x55,0x55,0x55,0x54,0x94,0x57,0x20,0x20,0x55,0x54,0x88,
+0x00,0xde,0x92,0x92,0xd2,0x5e,0x50,0xd0,0x92,0x92,0xce,0x00,0x00,0x24,0x92,0x92,
+/* 14128 0x3730 "㜰" */
+0x21,0x21,0x22,0x22,0xfb,0x49,0x4a,0x4b,0x88,0x48,0x33,0x10,0x28,0x49,0x82,0x00,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 14129 0x3731 "㜱" */
+0x20,0x23,0x22,0x23,0xfa,0x4a,0x4c,0x4b,0x4a,0x93,0x52,0x23,0x32,0x4b,0x49,0x82,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 14130 0x3732 "㜲" */
+0x20,0x2f,0x24,0x27,0xf0,0x57,0x54,0x57,0x50,0x9c,0x57,0x3d,0x35,0x5c,0x55,0xae,
+0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x80,0x9c,0xd4,0x54,0x5c,0x96,0x56,0x22,
+/* 14131 0x3733 "㜳" */
+0x20,0x20,0x27,0x20,0xfb,0x4a,0x4b,0x48,0x4a,0x91,0x52,0x20,0x31,0x4a,0x4c,0x80,
+0x80,0x40,0xfc,0x00,0xf8,0xa8,0xf8,0x40,0x44,0x18,0x44,0xa8,0x90,0x88,0xa6,0xc0,
+/* 14132 0x3734 "㜴" */
+0x21,0x27,0x21,0x23,0xfa,0x4b,0x48,0x4f,0x4c,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x08,0xfe,0x08,0xfc,0x94,0xfc,0x00,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,
+/* 14133 0x3735 "㜵" */
+0x20,0x27,0x20,0x23,0xfa,0x4b,0x4a,0x4b,0x4a,0x93,0x50,0x25,0x30,0x4b,0x4d,0x81,
+0x40,0xfe,0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0xa8,0x10,0x48,0x86,
+/* 14134 0x3736 "㜶" */
+0x21,0x22,0x27,0x22,0xfb,0x4a,0x4b,0x4a,0x49,0x92,0x57,0x22,0x33,0x48,0x49,0x86,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 14135 0x3737 "㜷" */
+0xf7,0x12,0x17,0xfc,0x86,0xf5,0x16,0x15,0x56,0x24,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x44,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 14136 0x3738 "㜸" */
+0x08,0xff,0x28,0x7d,0x44,0x7c,0x41,0x7c,0x45,0x7c,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x20,0xfe,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 14137 0x3739 "㜹" */
+0x23,0x22,0x23,0x22,0xfb,0x4a,0x4b,0x48,0x49,0x91,0x53,0x25,0x31,0x49,0x49,0x81,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 14138 0x373a "㜺" */
+0x25,0x27,0x29,0x27,0xfb,0x4d,0x49,0x4b,0x4a,0x93,0x52,0x23,0x32,0x4b,0x49,0x82,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 14139 0x373b "㜻" */
+0x24,0x24,0x2a,0x2e,0xf4,0x5a,0x5e,0x50,0x5a,0x9a,0x50,0x20,0x25,0x55,0x59,0x80,
+0x44,0xe4,0x0a,0xee,0x04,0xea,0x0e,0xe0,0xaa,0xea,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 14140 0x373c "㜼" */
+0x21,0x21,0x21,0x21,0xfb,0x4a,0x4b,0x4a,0x4b,0x90,0x53,0x22,0x30,0x48,0x48,0x83,
+0xfc,0x24,0xfc,0x24,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x8a,0xf8,0x88,0x88,0xfe,
+/* 14141 0x373d "㜽" */
+0x08,0x11,0x22,0x11,0x08,0x00,0x1f,0x00,0x00,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0x88,0x10,0x20,0x10,0x88,0x00,0xe0,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 14142 0x373e "㜾" */
+0x00,0xfc,0x04,0x08,0x10,0x11,0x16,0x18,0x30,0xd0,0x10,0x10,0x10,0x11,0x51,0x22,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 14143 0x373f "㜿" */
+0x00,0xfd,0x04,0x08,0x10,0x10,0x15,0x18,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 14144 0x3740 "㝀" */
+0x00,0x3e,0x22,0x2a,0x26,0x22,0x22,0xff,0x42,0x52,0x4a,0x42,0x7f,0x02,0x14,0x08,
+0x00,0x7c,0x04,0x08,0x08,0x10,0x10,0x7e,0x10,0x10,0x10,0x10,0x90,0x10,0x50,0x20,
+/* 14145 0x3741 "㝁" */
+0x10,0x1f,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x00,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xe8,0x10,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 14146 0x3742 "㝂" */
+0x01,0xfd,0x05,0x09,0x17,0x11,0x15,0x19,0x31,0xd7,0x11,0x11,0x11,0x11,0x55,0x22,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 14147 0x3743 "㝃" */
+0x00,0xfc,0x04,0x09,0x12,0x11,0x15,0x19,0x31,0xd1,0x10,0x10,0x10,0x10,0x51,0x22,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 14148 0x3744 "㝄" */
+0x20,0x10,0xfe,0x01,0x7c,0x44,0x7c,0x00,0x7c,0x04,0x08,0x1e,0xf0,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0xa8,0xa8,0xf8,0x22,0x22,0x22,0x1e,0x00,
+/* 14149 0x3745 "㝅" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x08,0x1e,0xf0,0x10,0x50,0x21,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14150 0x3746 "㝆" */
+0x00,0xfd,0x04,0x09,0x10,0x11,0x15,0x19,0x30,0xd3,0x10,0x11,0x11,0x11,0x51,0x21,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 14151 0x3747 "㝇" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0x7c,0x08,0x10,0x1e,0xf0,0x10,0x50,0x20,
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0x7c,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 14152 0x3748 "㝈" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x00,0x7c,0x08,0xfe,0x10,0x30,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0x7c,0x08,0xfe,0x10,0x30,
+/* 14153 0x3749 "㝉" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 14154 0x374a "㝊" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x00,0x3f,0x10,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 14155 0x374b "㝋" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0x00,0xfe,0x02,0x04,0xe0,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 14156 0x374c "㝌" */
+0x02,0x01,0x01,0x7f,0x42,0x82,0x07,0x04,0x08,0x10,0x00,0x01,0x02,0x04,0x18,0x60,
+0x00,0x00,0x00,0xfe,0x02,0x04,0xe0,0x20,0x40,0x40,0x80,0x80,0x40,0x20,0x10,0x0c,
+/* 14157 0x374d "㝍" */
+0x02,0x01,0x7f,0x50,0x90,0x1f,0x10,0x20,0x3f,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0xf8,0x08,0x08,0xc8,0x08,0x08,0x50,0x20,
+/* 14158 0x374e "㝎" */
+0x02,0x01,0x7f,0x40,0x82,0x01,0x01,0x7f,0x00,0x00,0x03,0x0c,0x30,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0xf8,0x30,0xc0,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 14159 0x374f "㝏" */
+0x02,0x01,0x7f,0x40,0x81,0x02,0x04,0x08,0x34,0xc4,0x04,0x04,0x08,0x08,0x10,0x20,
+0x00,0x00,0xfe,0x02,0x04,0x80,0x40,0x20,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 14160 0x3750 "㝐" */
+0x02,0x01,0x01,0x7f,0x40,0x84,0x04,0x08,0x10,0x22,0x42,0x84,0x08,0x10,0x3f,0x10,
+0x00,0x00,0x00,0xfe,0x82,0x84,0x40,0x40,0x20,0x10,0x08,0x06,0x40,0x20,0xf0,0x10,
+/* 14161 0x3751 "㝑" */
+0x02,0x01,0x7f,0x40,0x82,0x01,0x7f,0x04,0x04,0x07,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 14162 0x3752 "㝒" */
+0x02,0x01,0x01,0x7f,0x40,0x81,0x01,0x7f,0x01,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 14163 0x3753 "㝓" */
+0x02,0x01,0x7f,0x40,0x81,0x02,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x04,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 14164 0x3754 "㝔" */
+0x02,0x01,0x7f,0x40,0x82,0x01,0x7f,0x08,0x10,0x24,0x44,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x20,0x10,0x48,0x44,0x80,0x00,0xc0,0x30,0x0e,
+/* 14165 0x3755 "㝕" */
+0x02,0x01,0x7f,0x42,0x81,0x09,0x28,0x28,0x47,0x00,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x28,0x24,0xe4,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 14166 0x3756 "㝖" */
+0x02,0x01,0x7f,0x42,0x87,0x18,0x64,0x03,0x0c,0x71,0x06,0x1a,0x01,0x00,0x07,0x78,
+0x00,0x00,0xfe,0x02,0xe4,0x40,0x80,0x20,0x40,0xf8,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 14167 0x3757 "㝗" */
+0x02,0x01,0x7f,0x42,0x81,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x10,0x10,0x12,0x14,0x18,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x04,0x88,0x50,0x20,0x18,0x06,
+/* 14168 0x3758 "㝘" */
+0x02,0x01,0x7f,0x42,0x81,0x3f,0x00,0x1f,0x00,0x1f,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 14169 0x3759 "㝙" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x01,0x1f,0x01,0x7f,0x00,0xff,0x00,0x08,0x10,0x20,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xfe,0x00,0x20,0x10,0x08,
+/* 14170 0x375a "㝚" */
+0x02,0x01,0x7f,0x40,0x80,0x7b,0x08,0x10,0x22,0x7a,0x0a,0x2b,0x10,0x28,0x47,0x80,
+0x00,0x00,0xfe,0x02,0x1c,0xe0,0x40,0x40,0x78,0x40,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 14171 0x375b "㝛" */
+0x02,0x01,0x7f,0x40,0x88,0x0f,0x10,0x30,0x53,0x92,0x12,0x12,0x13,0x12,0x13,0x12,
+0x00,0x00,0xfe,0x02,0x04,0xfc,0x40,0x40,0xf8,0x48,0x48,0xa8,0x18,0x08,0xf8,0x08,
+/* 14172 0x375c "㝜" */
+0x02,0x01,0x7f,0x44,0x84,0x3f,0x04,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x42,0x44,0xf8,0x40,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 14173 0x375d "㝝" */
+0x02,0x01,0x7f,0x40,0x88,0x08,0x08,0x7e,0x08,0x1c,0x1a,0x2a,0x48,0x89,0x08,0x08,
+0x00,0x00,0xfe,0x02,0x24,0x20,0x20,0xfc,0x20,0x30,0x70,0x68,0xa4,0x22,0x20,0x20,
+/* 14174 0x375e "㝞" */
+0x02,0x01,0x7f,0x40,0x80,0x7f,0x04,0x04,0x3c,0x20,0x20,0x3c,0x04,0x04,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xfc,0x40,0x40,0x78,0x08,0x08,0x78,0x40,0x40,0xfe,0x00,
+/* 14175 0x375f "㝟" */
+0x02,0x01,0x7f,0x40,0xbf,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x02,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 14176 0x3760 "㝠" */
+0x02,0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x12,0x01,0xff,0x00,0x08,0x10,0x20,
+0x00,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x00,0xfe,0x00,0x20,0x10,0x08,
+/* 14177 0x3761 "㝡" */
+0x02,0x01,0x7f,0x40,0x80,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2f,0xf2,0x42,0x02,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14178 0x3762 "㝢" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x01,0x1f,0x11,0x1f,0x01,0x7f,0x41,0x41,0x5e,0x40,
+0x00,0x00,0xfe,0x02,0xf4,0x00,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x24,0xf4,0x14,0x08,
+/* 14179 0x3763 "㝣" */
+0x02,0x01,0x7f,0x40,0x88,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x02,0xff,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x02,0x04,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x40,0x30,0x0e,
+/* 14180 0x3764 "㝤" */
+0x01,0x7f,0x48,0xbf,0x08,0x3f,0x08,0xff,0x01,0x3f,0x21,0x3f,0x21,0xff,0x20,0x20,
+0x00,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x08,0x18,
+/* 14181 0x3765 "㝥" */
+0x02,0x01,0x7f,0x40,0x84,0x24,0x25,0x24,0x3c,0x07,0x04,0xfc,0x25,0x26,0x24,0x44,
+0x00,0x00,0xfe,0x02,0x24,0x20,0x24,0xa8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 14182 0x3766 "㝦" */
+0x01,0x7f,0x49,0x9f,0x31,0x5f,0x91,0x1f,0x11,0x1f,0x10,0x3f,0x08,0x08,0x10,0x60,
+0x00,0xfe,0x02,0xfc,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x00,0xe0,0x40,0xf8,0x08,0x30,
+/* 14183 0x3767 "㝧" */
+0x01,0x7f,0x44,0xbf,0x08,0x07,0x78,0x11,0x11,0x29,0x45,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfe,0x02,0xfc,0x20,0xc0,0x38,0x10,0x10,0x28,0x44,0xf8,0x00,0x00,0xfe,0x00,
+/* 14184 0x3768 "㝨" */
+0x02,0x01,0x7f,0x41,0x9f,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x04,0x08,0x38,0xcb,0x0c,
+0x00,0x00,0xfe,0x02,0xf4,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x88,0x50,0x20,0x18,0x06,
+/* 14185 0x3769 "㝩" */
+0x01,0x7f,0x40,0x81,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x24,0x22,0x44,0x58,0x81,
+0x00,0xfe,0x02,0x04,0xf8,0x80,0xf8,0x88,0xfe,0x88,0xf8,0xc4,0xa8,0x98,0x86,0x80,
+/* 14186 0x376a "㝪" */
+0x02,0x01,0x7f,0x40,0x90,0x10,0x7c,0x11,0xfe,0x44,0x28,0x7c,0x10,0xfe,0x11,0x12,
+0x00,0x00,0xfe,0x02,0x44,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,
+/* 14187 0x376b "㝫" */
+0x01,0x7f,0x40,0x81,0x79,0x4a,0x50,0x61,0x56,0x49,0x4a,0x6b,0x54,0x43,0x40,0x47,
+0x00,0xfe,0x02,0x04,0xf0,0x90,0x60,0x98,0x06,0xf0,0x40,0xf8,0x40,0xf8,0x40,0xfc,
+/* 14188 0x376c "㝬" */
+0x20,0x10,0xfe,0x82,0x11,0x7c,0x10,0x7c,0x11,0xfe,0x10,0x7c,0x44,0x44,0x7d,0x46,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 14189 0x376d "㝭" */
+0x01,0x7f,0x40,0x90,0x13,0x12,0x5b,0x56,0x53,0x91,0x13,0x14,0x11,0x10,0x17,0x10,
+0x00,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xf8,0x40,0xf0,0x40,0xfc,0x00,
+/* 14190 0x376e "㝮" */
+0x01,0x7f,0x40,0x88,0x2a,0x3e,0x49,0x7f,0x00,0x3e,0x00,0x7f,0x08,0x2a,0x49,0x18,
+0x00,0xfe,0x02,0x04,0x00,0x7c,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 14191 0x376f "㝯" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x02,0xff,0x08,0x37,0xc4,0x3f,0x20,0x27,0x24,0x27,
+0x00,0x00,0xfe,0x02,0x74,0x80,0x00,0xfe,0x20,0xd8,0x46,0xf8,0x08,0xc8,0x48,0xd8,
+/* 14192 0x3770 "㝰" */
+0x01,0x7f,0x42,0x9f,0x14,0x12,0x11,0x1f,0x01,0xff,0x92,0x2f,0x44,0x07,0x08,0x30,
+0x00,0xfe,0x02,0xf4,0x90,0x50,0x30,0xf0,0x00,0xfe,0x12,0xe8,0x04,0xe0,0x20,0x60,
+/* 14193 0x3771 "㝱" */
+0x01,0x7f,0x40,0x8b,0x48,0x49,0x49,0x79,0x08,0x0b,0xfa,0x48,0x48,0x49,0x88,0x09,
+0x00,0xfe,0x8a,0xfc,0x88,0xfc,0x54,0xfc,0x00,0xfe,0x42,0x78,0x88,0x50,0x60,0x80,
+/* 14194 0x3772 "㝲" */
+0x01,0x7f,0x41,0x97,0x51,0x53,0x52,0x77,0x14,0x11,0xf0,0x57,0x54,0x53,0x92,0x12,
+0x00,0xfe,0x12,0xfc,0x10,0xf8,0xa8,0xfc,0x14,0xf0,0x10,0xfc,0x44,0xf8,0x48,0x58,
+/* 14195 0x3773 "㝳" */
+0x02,0x02,0x02,0x02,0xff,0x02,0x02,0x12,0x12,0x12,0x22,0x22,0x42,0x82,0x0a,0x04,
+0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x90,0x48,0x24,0x24,0x12,0x12,0x00,0x00,0x00,
+/* 14196 0x3774 "㝴" */
+0x00,0x7c,0x00,0x01,0x00,0xfe,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x08,0x08,0x08,0xfe,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x12,0x02,0xfe,0x00,
+/* 14197 0x3775 "㝵" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x00,0x00,0xff,0x08,0x04,0x04,0x00,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 14198 0x3776 "㝶" */
+0x3f,0x24,0x24,0x3f,0x00,0x04,0x04,0x08,0x30,0xc0,0x00,0xff,0x08,0x04,0x04,0x00,
+0xf8,0x48,0x48,0xf8,0x00,0x40,0x42,0x42,0x3e,0x00,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 14199 0x3777 "㝷" */
+0x3f,0x00,0x1f,0x00,0x3f,0x00,0x7d,0x11,0x1c,0xe1,0x00,0xff,0x08,0x04,0x04,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x40,0xf0,0x50,0x94,0x4c,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 14200 0x3778 "㝸" */
+0x01,0x11,0x21,0x45,0x08,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x04,0x08,0x10,0x60,
+0x00,0x10,0x08,0x04,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x42,0x42,0x3e,
+/* 14201 0x3779 "㝹" */
+0x01,0x11,0x21,0x43,0x1c,0xe8,0x1f,0x20,0x40,0xbf,0x21,0x21,0x3f,0x04,0x18,0xe0,
+0x00,0x10,0x68,0x84,0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x92,0x8a,0x7e,
+/* 14202 0x377a "㝺" */
+0x22,0x14,0xff,0x14,0x14,0x7f,0x15,0xff,0x15,0x7f,0x14,0x36,0x55,0x94,0x14,0x15,
+0x10,0x10,0x90,0x10,0x14,0x52,0x52,0x92,0x10,0x14,0x04,0x08,0x10,0xa0,0x40,0x80,
+/* 14203 0x377b "㝻" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x10,0x10,0x90,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 14204 0x377c "㝼" */
+0x20,0x21,0x20,0x20,0xfc,0x28,0x2b,0x28,0x28,0x28,0x28,0x28,0x28,0x48,0x47,0x80,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x42,0x02,0xfe,0x00,
+/* 14205 0x377d "㝽" */
+0x20,0x20,0x20,0x20,0xfd,0x28,0x28,0x29,0x29,0x2a,0x28,0x28,0x28,0x48,0x47,0x80,
+0x20,0x20,0x20,0x24,0xa8,0xb0,0xb0,0x28,0x24,0x24,0xa0,0x40,0x02,0x02,0xfe,0x00,
+/* 14206 0x377e "㝾" */
+0x20,0x20,0x20,0x23,0xfc,0x28,0x28,0x29,0x29,0x2a,0x28,0x29,0x28,0x48,0x47,0x80,
+0x40,0x40,0x40,0xfc,0x80,0x80,0xf8,0x20,0x20,0x20,0x20,0xfc,0x02,0x02,0xfe,0x00,
+/* 14207 0x377f "㝿" */
+0x20,0x20,0x21,0x21,0xfd,0x29,0x29,0x29,0x29,0x29,0x2a,0x2a,0x2d,0x48,0x47,0x80,
+0x20,0x20,0xfc,0x24,0x28,0x20,0xf8,0x08,0x50,0x20,0x50,0x88,0x0a,0x02,0xfe,0x00,
+/* 14208 0x3780 "㞀" */
+0x20,0x20,0x20,0x23,0xfc,0x28,0x29,0x29,0x2a,0x2c,0x28,0x28,0x29,0x48,0x47,0x80,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x12,0x54,0x90,0x28,0x24,0x44,0x82,0x02,0xfe,0x00,
+/* 14209 0x3781 "㞁" */
+0x20,0x21,0x21,0x21,0xfd,0x29,0x28,0x29,0x29,0x29,0x29,0x28,0x28,0x48,0x47,0x80,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x18,0xe0,0x04,0x04,0xfc,0x02,0x02,0xfe,0x00,
+/* 14210 0x3782 "㞂" */
+0x20,0x21,0x20,0x21,0xfc,0x28,0x28,0x2b,0x28,0x28,0x28,0x28,0x29,0x48,0x47,0x80,
+0x1c,0xe0,0x44,0x24,0x88,0x20,0x20,0xfe,0x48,0xc8,0x30,0x68,0x86,0x02,0xfe,0x00,
+/* 14211 0x3783 "㞃" */
+0x28,0x24,0x42,0x92,0x10,0x29,0x44,0x82,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x01,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 14212 0x3784 "㞄" */
+0x20,0x20,0x23,0x20,0xfd,0x2a,0x2d,0x29,0x29,0x29,0x29,0x28,0x28,0x48,0x47,0x80,
+0x40,0x40,0xfc,0xa0,0x10,0x48,0xf4,0x50,0xf0,0x50,0xf4,0x44,0x3e,0x02,0xfe,0x00,
+/* 14213 0x3785 "㞅" */
+0x20,0x21,0x21,0x21,0xfd,0x29,0x28,0x29,0x28,0x28,0x29,0x2a,0x28,0x48,0x47,0x80,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x20,0x22,0x02,0xfe,0x00,
+/* 14214 0x3786 "㞆" */
+0x20,0x20,0x21,0x20,0xfc,0x2b,0x28,0x29,0x29,0x29,0x29,0x29,0x28,0x48,0x48,0x87,
+0x20,0x20,0xfc,0x50,0x88,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x1a,0x02,0xfe,
+/* 14215 0x3787 "㞇" */
+0x20,0x21,0x21,0x21,0xfd,0x29,0x28,0x2b,0x29,0x29,0x29,0x29,0x29,0x48,0x47,0x80,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x22,0x14,0x48,0x84,0x02,0x02,0xfe,0x00,
+/* 14216 0x3788 "㞈" */
+0x20,0x20,0x21,0x21,0xfd,0x29,0x29,0x29,0x2b,0x2b,0x2d,0x29,0x29,0x49,0x48,0x87,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x0e,0x02,0xfe,
+/* 14217 0x3789 "㞉" */
+0x20,0x20,0x23,0x20,0xfd,0x28,0x2b,0x28,0x29,0x2a,0x2c,0x2b,0x28,0x48,0x47,0x80,
+0x88,0x50,0xfe,0x20,0xfc,0x40,0xfe,0x80,0xfc,0x20,0x20,0xfe,0x02,0x02,0xfe,0x00,
+/* 14218 0x378a "㞊" */
+0x10,0x54,0x54,0x7c,0x92,0x92,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x51,0x22,
+0x40,0x40,0x40,0x40,0xfc,0x50,0x50,0x50,0x50,0x50,0x50,0x52,0x92,0x92,0x0e,0x00,
+/* 14219 0x378b "㞋" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x24,0x24,0x22,0x21,0x20,0x41,0x46,0x98,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xf8,0x08,0x10,0x20,0x40,0x80,0x40,0x30,0x0e,
+/* 14220 0x378c "㞌" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x27,0x20,0x20,0x20,0x2f,0x20,0x20,0x40,0x41,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xf8,0x10,0x20,0x40,0xfe,0x40,0x40,0x40,0x40,0x80,
+/* 14221 0x378d "㞍" */
+0x00,0x3f,0x20,0x20,0x3f,0x21,0x21,0x2f,0x21,0x25,0x22,0x23,0x24,0x44,0x48,0x90,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0xa2,0x22,0x1e,0x00,
+/* 14222 0x378e "㞎" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x2f,0x28,0x28,0x28,0x2f,0x28,0x28,0x48,0x48,0x87,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xf8,0x88,0x88,0x88,0xf8,0x00,0x02,0x02,0x02,0xfe,
+/* 14223 0x378f "㞏" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,0x20,0x41,0x46,0x99,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x78,0x80,0x80,0x40,0xf8,0x10,0x60,0x80,0x00,0xfe,
+/* 14224 0x3790 "㞐" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x2f,0x20,0x24,0x22,0x21,0x40,0x5f,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x80,0x40,0xfc,0x00,0x08,0x10,0x20,0x00,0xfe,0x00,
+/* 14225 0x3791 "㞑" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x28,0x24,0x22,0x20,0x22,0x24,0x28,0x40,0x40,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x88,0x90,0xa0,0x80,0xa0,0x92,0x8a,0x82,0x7e,0x00,
+/* 14226 0x3792 "㞒" */
+0x00,0x3f,0x20,0x3f,0x21,0x22,0x2f,0x28,0x28,0x2f,0x28,0x28,0x4f,0x48,0x88,0x0f,
+0x00,0xfc,0x04,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 14227 0x3793 "㞓" */
+0x00,0x3f,0x20,0x3f,0x20,0x28,0x2f,0x28,0x27,0x20,0x2f,0x28,0x4f,0x48,0x8f,0x08,
+0x00,0xfc,0x04,0xfc,0x00,0x60,0x88,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 14228 0x3794 "㞔" */
+0x00,0x3f,0x20,0x3f,0x21,0x23,0x2c,0x22,0x21,0x22,0x2c,0x21,0x46,0x40,0x81,0x0e,
+0x00,0xfc,0x04,0xfc,0x00,0xf0,0x20,0x40,0x80,0x40,0xf8,0x08,0x90,0x60,0x80,0x00,
+/* 14229 0x3795 "㞕" */
+0x00,0x3f,0x20,0x3f,0x22,0x24,0x28,0x37,0x24,0x27,0x24,0x27,0x44,0x44,0x84,0x04,
+0x00,0xfc,0x04,0xfc,0x20,0x10,0x08,0xf6,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 14230 0x3796 "㞖" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x28,0x29,0x22,0x44,0x58,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x80,0xfc,0x80,0xf8,0x88,0xa8,0xd0,0xa0,0x90,0x8c,0x80,
+/* 14231 0x3797 "㞗" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x20,0x28,0x25,0x22,0x24,0x48,0x42,0x81,
+0x00,0xfc,0x04,0x04,0xfc,0x90,0x88,0xfc,0x80,0x88,0xd0,0xa0,0x90,0x8c,0x80,0x00,
+/* 14232 0x3798 "㞘" */
+0x3f,0x20,0x3f,0x20,0x2f,0x21,0x23,0x24,0x2d,0x22,0x25,0x29,0x42,0x44,0x99,0x00,
+0xfc,0x04,0xfc,0x00,0xfc,0x00,0x08,0x88,0x50,0x60,0xe0,0x50,0x50,0x48,0x44,0x80,
+/* 14233 0x3799 "㞙" */
+0x3f,0x20,0x3f,0x20,0x20,0x3f,0x21,0x2f,0x21,0x3f,0x20,0x20,0x4e,0x42,0x84,0x19,
+0xfc,0x04,0xfc,0x00,0xf0,0x00,0xe0,0x00,0xf4,0x04,0xfc,0x88,0xd0,0xa0,0x98,0x86,
+/* 14234 0x379a "㞚" */
+0x3f,0x20,0x3f,0x20,0x20,0x27,0x20,0x2f,0x20,0x21,0x26,0x24,0x47,0x44,0x87,0x04,
+0xfc,0x04,0xfc,0x00,0x38,0xc0,0x40,0xfe,0x40,0x40,0x5c,0x44,0x5c,0x44,0xfc,0x04,
+/* 14235 0x379b "㞛" */
+0x00,0x3f,0x20,0x3f,0x22,0x24,0x28,0x32,0x24,0x2c,0x34,0x24,0x44,0x44,0x84,0x04,
+0x00,0xfc,0x04,0xfc,0x88,0x90,0xe4,0x84,0x7c,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 14236 0x379c "㞜" */
+0x3f,0x20,0x3f,0x22,0x24,0x28,0x30,0x22,0x24,0x2c,0x34,0x25,0x44,0x44,0x84,0x05,
+0xfc,0x04,0xfc,0x0c,0x70,0x10,0xfe,0x38,0x54,0x92,0x20,0xfe,0x44,0xc8,0x38,0xc6,
+/* 14237 0x379d "㞝" */
+0x00,0x3f,0x22,0x23,0x22,0x3f,0x2b,0x52,0x46,0x80,0x1f,0x10,0x1f,0x10,0x20,0x40,
+0x24,0xfe,0x20,0xa4,0x24,0xa8,0x10,0x9a,0x26,0x42,0xf8,0x08,0xf8,0x00,0x00,0x00,
+/* 14238 0x379e "㞞" */
+0x00,0x3f,0x20,0x3f,0x24,0x28,0x30,0x22,0x25,0x2c,0x34,0x24,0x44,0x45,0x86,0x04,
+0x00,0xfc,0x04,0xfc,0x48,0x48,0x54,0xa4,0x00,0x10,0x90,0x9c,0x90,0x50,0x3e,0x00,
+/* 14239 0x379f "㞟" */
+0x3f,0x20,0x3f,0x22,0x2f,0x21,0x2f,0x2a,0x2d,0x28,0x2f,0x20,0x5f,0x41,0x86,0x18,
+0xfc,0x04,0xfc,0x20,0xf8,0x40,0xf8,0x28,0xd8,0x08,0xf8,0x80,0xfc,0x40,0x30,0x0c,
+/* 14240 0x37a0 "㞠" */
+0x3f,0x20,0x3f,0x20,0x2f,0x21,0x2a,0x27,0x2c,0x37,0x24,0x27,0x40,0x48,0x92,0x01,
+0xfc,0x04,0xfc,0x80,0xf8,0x40,0x28,0xf0,0x18,0xf4,0x10,0xf0,0x80,0x88,0x84,0x00,
+/* 14241 0x37a1 "㞡" */
+0x3f,0x20,0x3f,0x20,0x27,0x22,0x2f,0x20,0x27,0x22,0x23,0x2e,0x41,0x43,0x8d,0x01,
+0xfc,0x04,0xfc,0x00,0x38,0x10,0x7c,0x00,0x38,0x10,0xbc,0xc8,0x30,0x10,0x48,0x86,
+/* 14242 0x37a2 "㞢" */
+0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 14243 0x37a3 "㞣" */
+0x01,0x21,0x21,0x21,0x3f,0x01,0x05,0x08,0x30,0xdf,0x02,0x02,0x02,0x04,0x08,0x10,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x40,0x20,0x18,0xf6,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 14244 0x37a4 "㞤" */
+0x01,0x01,0x21,0x21,0x21,0x3f,0x00,0x01,0x01,0x01,0x02,0x04,0x08,0x30,0xc0,0x00,
+0x00,0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 14245 0x37a5 "㞥" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x06,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 14246 0x37a6 "㞦" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x01,0x01,0x02,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 14247 0x37a7 "㞧" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x3f,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf0,0x10,0x20,0x7c,0x04,0x04,0x04,0x28,0x10,
+/* 14248 0x37a8 "㞨" */
+0x10,0x11,0x10,0x10,0x54,0x54,0x54,0x57,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 14249 0x37a9 "㞩" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x0f,0x08,0x08,0x0a,0x09,0x09,0x10,0x10,0x20,0x40,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 14250 0x37aa "㞪" */
+0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0xff,0x01,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 14251 0x37ab "㞫" */
+0x01,0x21,0x21,0x21,0x3f,0x02,0x01,0x01,0x7f,0x00,0x00,0x03,0x0c,0x30,0x48,0x87,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xf8,0x30,0xc0,0x00,0x00,0x00,0x00,0xfe,
+/* 14252 0x37ac "㞬" */
+0x01,0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 14253 0x37ad "㞭" */
+0x01,0x01,0x7f,0x01,0x02,0x04,0x08,0x30,0xc1,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfc,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 14254 0x37ae "㞮" */
+0x01,0x21,0x21,0x21,0x3f,0x08,0x08,0x1f,0x10,0x20,0x40,0x00,0x0c,0x03,0x00,0x00,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x40,
+/* 14255 0x37af "㞯" */
+0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x01,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x04,0x04,0xfc,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 14256 0x37b0 "㞰" */
+0x10,0x10,0x10,0x11,0x55,0x56,0x54,0x54,0x57,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 14257 0x37b1 "㞱" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 14258 0x37b2 "㞲" */
+0x10,0x10,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5c,0x64,0x00,0x00,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 14259 0x37b3 "㞳" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x55,0x5c,0x64,0x00,0x00,0x00,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 14260 0x37b4 "㞴" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 14261 0x37b5 "㞵" */
+0x01,0x21,0x21,0x21,0x3f,0x02,0x01,0x7f,0x08,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x20,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 14262 0x37b6 "㞶" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x01,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 14263 0x37b7 "㞷" */
+0x01,0x21,0x21,0x21,0x3f,0x01,0x01,0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 14264 0x37b8 "㞸" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x7f,0x01,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,0x00,0x60,0x10,0x08,0x04,0x00,0x00,
+/* 14265 0x37b9 "㞹" */
+0x10,0x10,0x13,0x10,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x64,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 14266 0x37ba "㞺" */
+0x01,0x21,0x21,0x21,0x3f,0x08,0x08,0x1f,0x21,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf0,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,
+/* 14267 0x37bb "㞻" */
+0x01,0x21,0x21,0x3f,0x00,0x1f,0x10,0x1f,0x00,0xff,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 14268 0x37bc "㞼" */
+0x00,0x3f,0x00,0x00,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,0x01,0x21,0x21,0x3f,0x00,
+0x00,0xf0,0x20,0xc0,0x04,0x88,0x50,0x20,0x18,0x06,0x00,0x00,0x08,0x08,0xf8,0x08,
+/* 14269 0x37bd "㞽" */
+0x20,0x20,0x20,0x20,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xcb,0x02,0x00,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 14270 0x37be "㞾" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 14271 0x37bf "㞿" */
+0x01,0x21,0x21,0x3f,0x00,0x01,0x3f,0x01,0x01,0xff,0x10,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,0x10,0x20,0x40,0x80,0x70,0x0e,
+/* 14272 0x37c0 "㟀" */
+0x00,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc0,0x01,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x70,0x80,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 14273 0x37c1 "㟁" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0xfe,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 14274 0x37c2 "㟂" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x57,0x55,0x55,0x55,0x5d,0x65,0x00,0x00,0x00,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 14275 0x37c3 "㟃" */
+0x10,0x11,0x10,0x10,0x55,0x54,0x54,0x55,0x55,0x55,0x55,0x5d,0x64,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 14276 0x37c4 "㟄" */
+0x10,0x10,0x10,0x10,0x55,0x54,0x54,0x54,0x54,0x54,0x55,0x5c,0x64,0x00,0x00,0x00,
+0x84,0x44,0x48,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 14277 0x37c5 "㟅" */
+0x10,0x10,0x10,0x11,0x55,0x55,0x55,0x55,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x00,0x88,0x50,0x24,0x54,0x8c,0x04,0xfc,0x00,0x90,0x90,0x90,0x10,0x12,0x12,0x0e,
+/* 14278 0x37c6 "㟆" */
+0x20,0x20,0x21,0x21,0xab,0xad,0xa9,0xa9,0xa9,0xa8,0xab,0xb8,0xc8,0x00,0x00,0x00,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 14279 0x37c7 "㟇" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x56,0x54,0x54,0x54,0x55,0x5c,0x64,0x00,0x03,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xaa,0x72,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 14280 0x37c8 "㟈" */
+0x10,0x10,0x10,0x10,0x55,0x54,0x55,0x54,0x54,0x54,0x54,0x5d,0x62,0x00,0x00,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 14281 0x37c9 "㟉" */
+0x20,0x20,0x23,0x22,0xac,0xa9,0xa9,0xa9,0xaa,0xa8,0xab,0xb8,0xc8,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x24,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 14282 0x37ca "㟊" */
+0x10,0x10,0x11,0x10,0x55,0x54,0x54,0x55,0x54,0x54,0x57,0x5c,0x64,0x00,0x00,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 14283 0x37cb "㟋" */
+0x11,0x10,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x54,0x54,0x5c,0x64,0x01,0x02,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 14284 0x37cc "㟌" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x54,0x54,0x54,0x54,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 14285 0x37cd "㟍" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 14286 0x37ce "㟎" */
+0x20,0x20,0x23,0x20,0xaa,0xa9,0xa9,0xa8,0xab,0xa8,0xa9,0xbb,0xc8,0x00,0x01,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 14287 0x37cf "㟏" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x54,0x54,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 14288 0x37d0 "㟐" */
+0x10,0x10,0x11,0x10,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x48,0x48,0xfe,0x48,0x48,0x20,0x10,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 14289 0x37d1 "㟑" */
+0x20,0x20,0x23,0x20,0xa8,0xab,0xaa,0xac,0xa9,0xa8,0xa8,0xbb,0xc8,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 14290 0x37d2 "㟒" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x04,0xff,0x04,0x3f,0x08,0x1f,0x28,0x48,0x8f,0x08,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 14291 0x37d3 "㟓" */
+0x21,0x20,0x20,0x20,0xab,0xa8,0xab,0xa8,0xa9,0xab,0xad,0xb9,0xc9,0x01,0x00,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 14292 0x37d4 "㟔" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x0c,0x31,0xcf,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x60,0x18,0xe6,0x40,0x80,0xf0,0x10,0x10,0xf0,0x10,
+/* 14293 0x37d5 "㟕" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x79,0x48,0x4a,0x49,0x48,0x4b,0x78,0x48,0x00,0x00,
+0x00,0x08,0x08,0xf8,0x00,0x20,0x20,0xa0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x20,0x20,
+/* 14294 0x37d6 "㟖" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x08,0xff,0x08,0x10,0x20,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,0x20,0xfe,0x20,0x20,0x20,
+/* 14295 0x37d7 "㟗" */
+0x01,0x01,0x41,0x51,0x55,0x63,0x41,0x7d,0x55,0x55,0x55,0x65,0x4d,0x41,0x7f,0x00,
+0x00,0x00,0x04,0x44,0x54,0x8c,0x04,0xf4,0x54,0x54,0x54,0x94,0x34,0x04,0xfc,0x04,
+/* 14296 0x37d8 "㟘" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 14297 0x37d9 "㟙" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x57,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14298 0x37da "㟚" */
+0x10,0x10,0xfd,0x10,0x30,0x39,0x54,0x90,0x10,0x10,0x11,0x01,0x21,0x21,0x3f,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xf8,0x88,0x50,0x20,0x50,0x8c,0x00,0x08,0x08,0xf8,0x08,
+/* 14299 0x37db "㟛" */
+0x01,0x21,0x21,0x3f,0x00,0x10,0x10,0xfb,0x10,0x10,0x1c,0xf0,0x10,0x10,0x50,0x20,
+0x00,0x08,0x08,0xf8,0x00,0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,
+/* 14300 0x37dc "㟜" */
+0x01,0x21,0x21,0x3f,0x00,0x7c,0x04,0x04,0x7d,0x40,0x40,0x7c,0x04,0x05,0x28,0x10,
+0x00,0x08,0x08,0xf8,0x40,0x40,0xfc,0x84,0x28,0x20,0xa8,0xa4,0xa4,0x24,0xa0,0x40,
+/* 14301 0x37dd "㟝" */
+0x10,0x10,0x11,0x10,0x55,0x54,0x54,0x57,0x54,0x54,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 14302 0x37de "㟞" */
+0x10,0x10,0x10,0x11,0x54,0x54,0x54,0x55,0x54,0x54,0x55,0x5c,0x64,0x00,0x00,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 14303 0x37df "㟟" */
+0x01,0x21,0x21,0x3f,0x00,0x08,0x7f,0x08,0xff,0x10,0x2f,0x48,0x8f,0x08,0x08,0x07,
+0x00,0x08,0x08,0xf8,0x00,0x20,0xfc,0x20,0xfe,0x10,0xc8,0x44,0xc2,0x10,0x10,0xf0,
+/* 14304 0x37e0 "㟠" */
+0x20,0x23,0x22,0x22,0xaa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x02,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 14305 0x37e1 "㟡" */
+0x01,0x21,0x21,0x3f,0x00,0x11,0x09,0x7f,0x04,0xff,0x10,0x2f,0xc8,0x08,0x08,0x07,
+0x00,0x08,0x08,0xf8,0x00,0x10,0x20,0xfc,0x00,0xfe,0x10,0xe8,0x26,0xa0,0x48,0xf8,
+/* 14306 0x37e2 "㟢" */
+0x01,0x21,0x21,0x3f,0x02,0x3f,0x04,0x08,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x80,0x40,0xfe,0x10,0x90,0x90,0x90,0x90,0x50,0x20,
+/* 14307 0x37e3 "㟣" */
+0x21,0x21,0x21,0x21,0xab,0xa9,0xa9,0xab,0xab,0xad,0xad,0xb9,0xc9,0x01,0x01,0x01,
+0x04,0x14,0x14,0x14,0xd2,0x22,0x2a,0x48,0x88,0x50,0x10,0x14,0x22,0x7e,0x22,0x00,
+/* 14308 0x37e4 "㟤" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x00,0x1f,0x00,0xff,0x11,0x09,0x05,0x19,0xe5,0x02,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xa0,0x40,0x30,0x0e,0x00,
+/* 14309 0x37e5 "㟥" */
+0x01,0x21,0x21,0x3f,0x04,0x08,0x1f,0x02,0xff,0x08,0x33,0xcc,0x03,0x1c,0x01,0x3e,
+0x00,0x08,0x08,0xf8,0x00,0x20,0xf0,0x10,0xfe,0xa0,0x18,0x46,0x80,0x30,0xc0,0x00,
+/* 14310 0x37e6 "㟦" */
+0x01,0x41,0x7f,0x00,0x7f,0x41,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x00,0x04,0xfc,0x00,0xfc,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 14311 0x37e7 "㟧" */
+0x01,0x41,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x3f,0x00,0xff,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x04,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xa0,0x40,
+/* 14312 0x37e8 "㟨" */
+0x10,0x11,0x11,0x11,0x55,0x54,0x57,0x54,0x54,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 14313 0x37e9 "㟩" */
+0x00,0x7f,0x41,0x7f,0x48,0x7f,0x48,0x45,0x53,0x61,0x00,0x01,0x21,0x21,0x3f,0x00,
+0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,0x00,0x00,0x08,0x08,0xf8,0x08,
+/* 14314 0x37ea "㟪" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x54,0x57,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 14315 0x37eb "㟫" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x54,0x54,0x57,0x54,0x5d,0x65,0x02,0x04,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 14316 0x37ec "㟬" */
+0x01,0x41,0x7f,0x05,0x39,0x21,0x3d,0x21,0x3f,0x01,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x04,0xfc,0x00,0x78,0x08,0x78,0x08,0xf8,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 14317 0x37ed "㟭" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x54,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 14318 0x37ee "㟮" */
+0x10,0x10,0x13,0x12,0x54,0x55,0x56,0x54,0x54,0x57,0x54,0x5c,0x64,0x00,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 14319 0x37ef "㟯" */
+0x01,0x41,0x7f,0x02,0x01,0x7f,0x48,0x9f,0x28,0x07,0x18,0xe0,0x1f,0x10,0x1f,0x10,
+0x00,0x04,0xfc,0x00,0x00,0xfe,0x02,0xf4,0x20,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x10,
+/* 14320 0x37f0 "㟰" */
+0x20,0x23,0x22,0x20,0xa9,0xa9,0xa9,0xa9,0xa9,0xa8,0xa8,0xbb,0xc8,0x00,0x01,0x02,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 14321 0x37f1 "㟱" */
+0x21,0x20,0x20,0x20,0xab,0xa8,0xa8,0xa9,0xa8,0xa8,0xab,0xb8,0xca,0x02,0x04,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 14322 0x37f2 "㟲" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 14323 0x37f3 "㟳" */
+0x20,0x23,0x20,0x20,0xab,0xaa,0xaa,0xab,0xa8,0xa8,0xab,0xb8,0xc8,0x01,0x06,0x00,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 14324 0x37f4 "㟴" */
+0x20,0x20,0x23,0x22,0xaa,0xab,0xaa,0xaa,0xab,0xa8,0xa8,0xb8,0xc9,0x01,0x02,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 14325 0x37f5 "㟵" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x24,0x3f,0x00,0x7f,0x01,0x11,0x11,0x11,0xff,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x48,0xf8,0x00,0xfc,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 14326 0x37f6 "㟶" */
+0x01,0x41,0x7f,0x00,0x3f,0x20,0x21,0x27,0x24,0x27,0x24,0x27,0x40,0x44,0x8a,0x11,
+0x00,0x04,0xfc,0x00,0xfc,0x80,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x80,0x90,0x88,0x04,
+/* 14327 0x37f7 "㟷" */
+0x10,0x10,0x13,0x10,0x54,0x54,0x54,0x55,0x56,0x54,0x54,0x5d,0x65,0x01,0x01,0x01,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 14328 0x37f8 "㟸" */
+0x20,0x20,0x21,0x21,0xa9,0xa9,0xa9,0xa8,0xab,0xa8,0xa9,0xba,0xcd,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,
+/* 14329 0x37f9 "㟹" */
+0x20,0x3f,0x2a,0x2a,0xae,0xaa,0xaa,0xae,0xaa,0xaa,0xab,0xbe,0xda,0x02,0x02,0x02,
+0x10,0x20,0xce,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xea,0xac,0x28,0x48,0x48,0x88,
+/* 14330 0x37fa "㟺" */
+0x01,0x41,0x7f,0x01,0x3f,0x21,0xff,0x21,0x3f,0x11,0x1f,0x04,0xff,0x08,0x07,0x78,
+0x00,0x04,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x10,0xf0,0x00,0xfe,0x20,0xc0,0x38,
+/* 14331 0x37fb "㟻" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x01,0x21,0x21,0x3f,0x00,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0x08,0x08,0xf8,0x08,
+/* 14332 0x37fc "㟼" */
+0x01,0x21,0x21,0x3f,0x08,0x08,0x7f,0x08,0x3e,0x08,0xff,0x10,0x1e,0x22,0x4a,0x84,
+0x00,0x08,0x08,0xf8,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14333 0x37fd "㟽" */
+0x10,0x13,0x10,0x11,0x55,0x55,0x55,0x54,0x55,0x54,0x57,0x5c,0x64,0x01,0x02,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 14334 0x37fe "㟾" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 14335 0x37ff "㟿" */
+0x20,0x20,0x23,0x20,0xa8,0xab,0xa8,0xa8,0xa9,0xaa,0xa8,0xbb,0xc8,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x24,0xfe,0x50,0x88,0x04,0x8a,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 14336 0x3800 "㠀" */
+0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x84,0x01,0x21,0x21,0x3f,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x9c,0x00,0x08,0x08,0xf8,
+/* 14337 0x3801 "㠁" */
+0x20,0x20,0x21,0x21,0xaa,0xab,0xa8,0xa9,0xae,0xa8,0xab,0xb8,0xcb,0x00,0x00,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 14338 0x3802 "㠂" */
+0x21,0x21,0x21,0x27,0xa9,0xaf,0xa9,0xaf,0xaa,0xab,0xaa,0xba,0xca,0x04,0x04,0x08,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 14339 0x3803 "㠃" */
+0x20,0x20,0x23,0x20,0xa8,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x02,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 14340 0x3804 "㠄" */
+0x01,0x21,0x21,0x3f,0x00,0x7e,0x22,0x1a,0x62,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x08,0x08,0xf8,0x00,0xfc,0x44,0x34,0xc4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 14341 0x3805 "㠅" */
+0x01,0x41,0x7f,0x02,0x13,0x24,0x43,0x8a,0x13,0x32,0x53,0x91,0x13,0x15,0x10,0x17,
+0x00,0x04,0xfc,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x10,0xe0,0x1c,
+/* 14342 0x3806 "㠆" */
+0x20,0x23,0x22,0x22,0xab,0xa8,0xa9,0xa9,0xa9,0xa9,0xa9,0xb8,0xcb,0x00,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 14343 0x3807 "㠇" */
+0x01,0x21,0x21,0x3f,0x20,0x10,0xfe,0x01,0x7c,0x44,0x7c,0x10,0x54,0x52,0x92,0x31,
+0x00,0x08,0x08,0xf8,0x50,0x48,0x48,0xfe,0x50,0x50,0x50,0x50,0x50,0x92,0x92,0x0e,
+/* 14344 0x3808 "㠈" */
+0x20,0x23,0x22,0x23,0xaa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x02,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x22,0x72,0x22,0x22,0xfa,0x02,0x0a,0x04,
+/* 14345 0x3809 "㠉" */
+0x10,0x11,0x10,0x10,0x55,0x54,0x55,0x55,0x55,0x55,0x55,0x5c,0x65,0x00,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 14346 0x380a "㠊" */
+0x20,0x20,0x20,0x23,0xaa,0xaa,0xab,0xaa,0xaa,0xaa,0xaa,0xbb,0xc4,0x04,0x09,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0x50,0x54,0x54,0xd8,0x50,0xfe,0x00,
+/* 14347 0x380b "㠋" */
+0x21,0x3f,0x00,0x1f,0x10,0x7f,0x44,0x7c,0x00,0x3f,0x00,0xff,0x10,0x1f,0x00,0x00,
+0x08,0xf8,0x00,0xf0,0x10,0xfc,0x44,0x7c,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x08,0x70,
+/* 14348 0x380c "㠌" */
+0x01,0x21,0x21,0x3f,0x00,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0xff,0x24,0x42,0x82,
+0x00,0x08,0x08,0xf8,0x20,0x20,0xbe,0x42,0x94,0x10,0x10,0x10,0xa8,0x28,0x44,0x82,
+/* 14349 0x380d "㠍" */
+0x01,0x41,0x7f,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x11,0x7f,0x05,0x19,0xe1,
+0x00,0x04,0xfc,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xfc,0x40,0x30,0x0e,
+/* 14350 0x380e "㠎" */
+0x20,0x20,0x21,0x23,0xa9,0xa9,0xa9,0xa9,0xa9,0xa9,0xa8,0xbb,0xc8,0x00,0x03,0x00,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 14351 0x380f "㠏" */
+0x10,0x13,0x10,0x10,0x55,0x54,0x54,0x57,0x54,0x54,0x55,0x5c,0x63,0x00,0x00,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 14352 0x3810 "㠐" */
+0x01,0x41,0x7f,0x00,0x00,0x1f,0x02,0xff,0x08,0x37,0xc4,0x3f,0x20,0x27,0x24,0x27,
+0x00,0x04,0xfc,0x00,0x70,0x80,0x00,0xfe,0x20,0xd8,0x46,0xf8,0x08,0xc8,0x48,0xd8,
+/* 14353 0x3811 "㠑" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x24,0x3f,0x02,0x7e,0x02,0x3e,0x02,0x7e,0x02,0x02,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x48,0xf8,0x80,0xfc,0x80,0xf8,0x80,0xfc,0x80,0x80,
+/* 14354 0x3812 "㠒" */
+0x20,0x2f,0x22,0x2f,0xaa,0xaa,0xaf,0xa8,0xab,0xa8,0xaf,0xb9,0xc5,0x05,0x09,0x03,
+0x02,0xe2,0x82,0xea,0xaa,0xaa,0xea,0x0a,0xca,0x0a,0xea,0x0a,0x42,0x22,0x2a,0x04,
+/* 14355 0x3813 "㠓" */
+0x20,0x23,0x20,0x23,0xaa,0xa9,0xa8,0xab,0xa8,0xa8,0xab,0xb8,0xcb,0x00,0x03,0x00,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 14356 0x3814 "㠔" */
+0x01,0x21,0x21,0x3f,0x00,0x3e,0x22,0x22,0x3e,0x21,0x20,0x3e,0x52,0x52,0x9e,0x12,
+0x00,0x08,0x08,0xf8,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,
+/* 14357 0x3815 "㠕" */
+0x01,0x41,0x7f,0x00,0x78,0x4b,0x52,0x63,0x52,0x4b,0x48,0x68,0x50,0x41,0x42,0x44,
+0x00,0x04,0xfc,0x40,0x80,0xf8,0x48,0xf8,0x48,0xf8,0x48,0xb4,0xbc,0x22,0x22,0x1e,
+/* 14358 0x3816 "㠖" */
+0x41,0x7f,0x08,0x7f,0x01,0x3f,0x01,0xff,0x02,0x3c,0x08,0xff,0x08,0x7e,0x08,0x19,
+0x04,0xfc,0x20,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x50,0x48,0xfe,0x50,0x24,0x54,0x8c,
+/* 14359 0x3817 "㠗" */
+0x20,0x20,0x23,0x22,0xaa,0xaa,0xab,0xaa,0xaa,0xaa,0xa8,0xbb,0xc8,0x00,0x01,0x06,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 14360 0x3818 "㠘" */
+0x01,0x21,0x21,0x3f,0x0a,0x33,0x22,0x3a,0x23,0x20,0x3a,0x22,0xff,0x08,0x10,0x20,
+0x00,0x08,0x08,0xf8,0x00,0xb8,0x08,0x38,0x88,0x88,0xb8,0x88,0xfe,0x20,0x10,0x08,
+/* 14361 0x3819 "㠙" */
+0x20,0x23,0x20,0x21,0xa9,0xa9,0xa8,0xab,0xaa,0xa9,0xa8,0xbb,0xc8,0x03,0x00,0x03,
+0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x40,0xa4,0xd8,0x34,0xd2,0x30,
+/* 14362 0x381a "㠚" */
+0x21,0x21,0x25,0x23,0xa9,0xab,0xa8,0xaa,0xa9,0xab,0xa8,0xbb,0xc8,0x00,0x07,0x00,
+0x44,0x44,0x54,0x64,0x4e,0xe4,0x04,0x2c,0x44,0xe4,0x84,0xe4,0x84,0xe4,0x14,0x08,
+/* 14363 0x381b "㠛" */
+0x10,0x13,0x10,0x10,0x55,0x57,0x55,0x55,0x55,0x55,0x55,0x5d,0x63,0x00,0x00,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 14364 0x381c "㠜" */
+0x22,0x22,0x23,0x22,0xa9,0xa8,0xaa,0xab,0xad,0xa9,0xaf,0xb9,0xca,0x02,0x04,0x00,
+0x00,0xbe,0x02,0x54,0xc8,0x3e,0x0a,0xca,0x28,0x28,0xee,0x28,0xa8,0x58,0x4e,0x80,
+/* 14365 0x381d "㠝" */
+0x10,0x11,0x10,0x13,0x54,0x55,0x56,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x00,0x01,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 14366 0x381e "㠞" */
+0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x22,0x27,0x22,0x2f,0x01,0x21,0x21,0x3f,
+0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,0x00,0x08,0x08,0xf8,
+/* 14367 0x381f "㠟" */
+0x10,0x11,0x10,0x13,0x54,0x55,0x56,0x54,0x54,0x54,0x57,0x5c,0x64,0x00,0x01,0x00,
+0x50,0x90,0x9e,0xea,0x8a,0xd2,0x8a,0xa4,0x50,0x88,0x26,0xa8,0x70,0xa8,0x24,0x60,
+/* 14368 0x3820 "㠠" */
+0x20,0x20,0x20,0x23,0xaa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x05,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 14369 0x3821 "㠡" */
+0x20,0x23,0x20,0x23,0xaa,0xab,0xaa,0xab,0xaa,0xab,0xa8,0xba,0xc8,0x01,0x06,0x00,
+0x20,0xfe,0x00,0xfc,0x20,0xf8,0x20,0xf8,0x20,0xfe,0x02,0xaa,0x54,0x88,0xa4,0xc2,
+/* 14370 0x3822 "㠢" */
+0x21,0x3f,0x02,0x1f,0x11,0x1f,0x12,0x1f,0x04,0x08,0x30,0xc2,0x01,0x7f,0x0c,0x76,
+0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0xa8,0xba,0x82,0x7e,0x00,0xfc,0x48,0x3e,
+/* 14371 0x3823 "㠣" */
+0x20,0x23,0x22,0x22,0xaa,0xab,0xaa,0xaa,0xab,0xaa,0xaa,0xba,0xca,0x04,0x04,0x0b,
+0x00,0xfe,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x44,0x10,0x90,0x9e,0x90,0x90,0xfe,
+/* 14372 0x3824 "㠤" */
+0x20,0x23,0x20,0x21,0xa9,0xa9,0xa8,0xab,0xa8,0xab,0xa8,0xbb,0xc8,0x01,0x02,0x00,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 14373 0x3825 "㠥" */
+0x27,0x24,0x27,0x24,0xaf,0xa8,0xaf,0xaa,0xaf,0xaa,0xaf,0xb8,0xc8,0x07,0x00,0x0f,
+0xfc,0x44,0xfc,0x44,0xfc,0x00,0xbe,0xaa,0xbe,0xaa,0xbe,0x40,0x40,0xfc,0x40,0xfe,
+/* 14374 0x3826 "㠦" */
+0x20,0x21,0x22,0x23,0xaa,0xab,0xaa,0xab,0xa8,0xab,0xa8,0xb9,0xc9,0x01,0x00,0x03,
+0xa8,0xfc,0xaa,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x88,0xfe,
+/* 14375 0x3827 "㠧" */
+0x20,0x23,0x22,0x23,0xaa,0xaa,0xab,0xaa,0xaa,0xab,0xaa,0xbb,0xca,0x05,0x04,0x08,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 14376 0x3828 "㠨" */
+0x21,0x21,0x23,0x21,0xab,0xad,0xaf,0xac,0xaf,0xaa,0xab,0xba,0xcb,0x02,0x02,0x03,
+0x54,0x24,0xde,0x54,0xae,0x54,0xfe,0x92,0xfe,0x44,0xde,0x44,0xd4,0x0c,0x84,0x4c,
+/* 14377 0x3829 "㠩" */
+0x00,0x00,0x21,0x22,0x24,0x20,0x3f,0x00,0x09,0x09,0x09,0x11,0x11,0x21,0x41,0x80,
+0x80,0x80,0x40,0x20,0x10,0x00,0xfc,0x00,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 14378 0x382a "㠪" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 14379 0x382b "㠫" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x01,0x3f,0x01,0xff,0x02,0x04,0x18,0x60,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x0c,
+/* 14380 0x382c "㠬" */
+0x00,0x7c,0x10,0x10,0x10,0x1c,0xe0,0x41,0x3f,0x01,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 14381 0x382d "㠭" */
+0x00,0x7c,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,0x7c,0x10,0x10,0x10,0x1e,0xf0,0x40,
+0x00,0x7c,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 14382 0x382e "㠮" */
+0x22,0x14,0x7f,0x14,0x55,0x36,0xff,0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 14383 0x382f "㠯" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 14384 0x3830 "㠰" */
+0x10,0x7e,0x12,0x12,0x12,0x22,0x4a,0x84,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0xf0,0x10,0x10,0xf0,0x00,0x04,0x04,0xfc,
+/* 14385 0x3831 "㠱" */
+0x3f,0x00,0x3f,0x20,0x1f,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x08,0x10,0x20,
+0xf0,0x10,0xf0,0x04,0xfc,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x20,0x10,0x08,
+/* 14386 0x3832 "㠲" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x4b,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 14387 0x3833 "㠳" */
+0x06,0x01,0x02,0x04,0x08,0x31,0xc1,0x01,0x1f,0x11,0x11,0x11,0x11,0x11,0x01,0x01,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0xf0,0x10,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 14388 0x3834 "㠴" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x55,0x54,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 14389 0x3835 "㠵" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x1f,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 14390 0x3836 "㠶" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x11,0x11,0x12,
+0x20,0x20,0x40,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x8a,0x8a,0x0a,0x06,0x00,
+/* 14391 0x3837 "㠷" */
+0x10,0x13,0x10,0x7c,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x12,0x12,0x14,0x11,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14392 0x3838 "㠸" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x57,0x54,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 14393 0x3839 "㠹" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x54,0x54,0x54,0x5c,0x10,0x11,0x11,0x12,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 14394 0x383a "㠺" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x55,0x55,0x56,0x54,0x54,0x5c,0x10,0x10,0x10,0x13,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 14395 0x383b "㠻" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x0c,0x1f,0x28,0x48,0x88,0x08,0x00,0x00,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x80,0x80,0xf8,0x88,0x88,0xa8,0x90,0x80,0x80,
+/* 14396 0x383c "㠼" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x11,0x11,0x12,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 14397 0x383d "㠽" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x54,0x57,0x54,0x5c,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 14398 0x383e "㠾" */
+0x10,0x1e,0x22,0x62,0x94,0x08,0x30,0xc1,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0xf8,0x88,0xa8,0x92,0x82,0x7e,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 14399 0x383f "㠿" */
+0x08,0x08,0x28,0x2e,0x28,0x28,0x2e,0xf1,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x7c,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 14400 0x3840 "㡀" */
+0x01,0x21,0x11,0x09,0x09,0x01,0x7f,0x41,0x41,0x43,0x45,0x49,0x41,0x41,0x41,0x40,
+0x00,0x08,0x08,0x10,0x20,0x00,0xfc,0x04,0x04,0x84,0x44,0x24,0x04,0x04,0x14,0x08,
+/* 14401 0x3841 "㡁" */
+0x10,0x10,0x13,0x7c,0x54,0x55,0x56,0x54,0x57,0x54,0x54,0x5d,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 14402 0x3842 "㡂" */
+0x00,0x7f,0x10,0x3f,0x51,0x0a,0x0c,0x31,0xc1,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x04,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 14403 0x3843 "㡃" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x10,0x10,0x10,0x28,0x44,0x00,0xfe,0x00,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 14404 0x3844 "㡄" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfe,0x02,0x02,0xf2,0x12,0x12,0xf2,0x12,0x12,0xf2,0x02,0x14,0x08,
+/* 14405 0x3845 "㡅" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x5d,0x10,0x10,0x10,0x11,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 14406 0x3846 "㡆" */
+0x10,0x10,0x13,0x7d,0x55,0x55,0x55,0x54,0x55,0x55,0x55,0x5d,0x12,0x12,0x14,0x18,
+0x80,0x40,0xfc,0x00,0x00,0x00,0xf8,0x00,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 14407 0x3847 "㡇" */
+0x10,0x13,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x13,0x10,0x10,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 14408 0x3848 "㡈" */
+0x10,0x10,0x10,0x7d,0x56,0x55,0x55,0x55,0x55,0x55,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 14409 0x3849 "㡉" */
+0x20,0x23,0x20,0xf8,0xa8,0xab,0xaa,0xaa,0xaa,0xab,0xa8,0xb8,0x20,0x20,0x22,0x21,
+0x10,0x88,0x88,0xfe,0x90,0x90,0x24,0x24,0x38,0x88,0x90,0x90,0xa4,0xbe,0x82,0x00,
+/* 14410 0x384a "㡊" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 14411 0x384b "㡋" */
+0x10,0x10,0x13,0x7c,0x54,0x55,0x56,0x55,0x55,0x55,0x55,0x5d,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 14412 0x384c "㡌" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 14413 0x384d "㡍" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x02,0xff,0x08,0x31,0xdf,0x11,0x11,0x11,0x01,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x18,0xf6,0x10,0x50,0x20,0x00,0x00,
+/* 14414 0x384e "㡎" */
+0x10,0x10,0x10,0x7d,0x54,0x57,0x54,0x55,0x56,0x55,0x54,0x5c,0x11,0x10,0x10,0x13,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x62,0x84,0x18,0x60,0x80,
+/* 14415 0x384f "㡏" */
+0x20,0x20,0x21,0xfa,0xad,0xa8,0xab,0xaa,0xaa,0xab,0xaa,0xba,0x23,0x22,0x22,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 14416 0x3850 "㡐" */
+0x21,0x20,0x20,0xfb,0xa8,0xab,0xaa,0xaa,0xab,0xaa,0xaa,0xbb,0x22,0x22,0x22,0x22,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 14417 0x3851 "㡑" */
+0x06,0x38,0x08,0x7e,0x08,0x1c,0x2a,0x48,0x08,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,
+0x10,0x10,0x52,0x54,0x90,0x28,0x28,0x44,0x82,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,
+/* 14418 0x3852 "㡒" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 14419 0x3853 "㡓" */
+0x20,0x23,0x22,0xf8,0xab,0xa8,0xa9,0xa9,0xa9,0xa9,0xa9,0xb8,0x23,0x20,0x20,0x20,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 14420 0x3854 "㡔" */
+0x00,0x7f,0x12,0x0c,0xff,0x19,0x2a,0x48,0xa8,0x11,0x01,0x3f,0x21,0x21,0x21,0x01,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0x00,0xf8,0x08,0x28,0x10,0x00,
+/* 14421 0x3855 "㡕" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x55,0x55,0x55,0x55,0x57,0x5c,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 14422 0x3856 "㡖" */
+0x10,0x10,0x11,0x7c,0x57,0x54,0x55,0x55,0x55,0x55,0x55,0x5c,0x11,0x10,0x13,0x10,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 14423 0x3857 "㡗" */
+0x20,0x20,0x23,0xfa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x24,0x25,0x2a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 14424 0x3858 "㡘" */
+0x10,0x10,0x10,0x7d,0x54,0x55,0x54,0x57,0x54,0x55,0x54,0x5c,0x11,0x12,0x10,0x10,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 14425 0x3859 "㡙" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x54,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 14426 0x385a "㡚" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x57,0x54,0x55,0x55,0x55,0x5d,0x13,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 14427 0x385b "㡛" */
+0x10,0x10,0x13,0x7c,0x54,0x57,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0xa8,0x10,0xfe,0x80,0x80,0xfc,0x00,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 14428 0x385c "㡜" */
+0x21,0x21,0x23,0xfa,0xad,0xaa,0xa9,0xaa,0xac,0xa8,0xab,0xb8,0x21,0x22,0x25,0x20,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 14429 0x385d "㡝" */
+0x20,0x24,0x22,0xf9,0xa8,0xa8,0xae,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x22,0x25,0x28,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 14430 0x385e "㡞" */
+0x20,0x21,0x21,0xfb,0xa9,0xa9,0xa8,0xa9,0xa9,0xa9,0xa8,0xbb,0x20,0x21,0x20,0x23,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 14431 0x385f "㡟" */
+0x20,0x20,0x27,0xf8,0xab,0xaa,0xab,0xaa,0xab,0xa8,0xa9,0xb9,0x21,0x21,0x21,0x21,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 14432 0x3860 "㡠" */
+0x20,0x27,0x20,0xfa,0xa9,0xaa,0xad,0xa8,0xab,0xaa,0xaa,0xbb,0x22,0x21,0x2f,0x20,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 14433 0x3861 "㡡" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x22,0x25,0x20,
+0x00,0xfe,0x00,0x04,0xf4,0x04,0xee,0xa4,0xa4,0xec,0x04,0xa4,0x44,0x74,0x94,0x08,
+/* 14434 0x3862 "㡢" */
+0x21,0x21,0x21,0xf9,0xa9,0xa8,0xab,0xaa,0xab,0xa8,0xab,0xb8,0x20,0x20,0x21,0x22,
+0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x52,0xfe,0x00,0xfe,0x80,0xfc,0x84,0x14,0x08,
+/* 14435 0x3863 "㡣" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x88,0x09,0x7f,0x49,0x49,0x4d,0x4a,0x08,0x08,
+0x20,0x20,0x3e,0x20,0x3e,0x02,0xbe,0xa0,0x3e,0x20,0x3e,0x20,0x3e,0x20,0x22,0x1e,
+/* 14436 0x3864 "㡤" */
+0x20,0x22,0x21,0xf8,0xab,0xa8,0xa8,0xab,0xa8,0xa9,0xa8,0xbb,0x20,0x21,0x26,0x20,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 14437 0x3865 "㡥" */
+0x20,0x27,0x22,0xf9,0xab,0xa8,0xaf,0xa8,0xab,0xa8,0xab,0xb8,0x23,0x25,0x25,0x28,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 14438 0x3866 "㡦" */
+0x10,0x10,0x11,0x7d,0x54,0x54,0x55,0x54,0x55,0x54,0x54,0x5c,0x10,0x10,0x10,0x10,
+0x20,0x10,0xfe,0x02,0xfc,0xa8,0x30,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 14439 0x3867 "㡧" */
+0x20,0x20,0x23,0xfa,0xa9,0xa8,0xab,0xa8,0xaa,0xa9,0xaa,0xb9,0x21,0x21,0x20,0x23,
+0x40,0x20,0xfe,0x8a,0x04,0x12,0xd4,0x48,0x8a,0x74,0x02,0xfc,0x04,0xfc,0x88,0xfe,
+/* 14440 0x3868 "㡨" */
+0x21,0x21,0x22,0xf8,0xaf,0xa9,0xab,0xa9,0xab,0xa9,0xab,0xb9,0x21,0x23,0x20,0x20,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 14441 0x3869 "㡩" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x3f,0x21,0x21,0x21,0x01,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf8,0x08,0x28,0x10,0x00,
+/* 14442 0x386a "㡪" */
+0x20,0x27,0x21,0xfb,0xaa,0xab,0xaa,0xaa,0xaa,0xaa,0xab,0xba,0x22,0x25,0x24,0x29,
+0x3e,0xc4,0x28,0xfe,0x02,0xfe,0xa0,0xee,0xaa,0xee,0xa8,0x46,0xf8,0x48,0x30,0xce,
+/* 14443 0x386b "㡫" */
+0x10,0x11,0x21,0x21,0x45,0x45,0xf8,0x09,0x12,0x11,0x29,0x45,0xfd,0x44,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 14444 0x386c "㡬" */
+0x11,0x21,0x45,0x79,0x11,0x25,0x7d,0x05,0x01,0xff,0x20,0x3e,0x22,0x22,0x4a,0x85,
+0x10,0x20,0x44,0x78,0x10,0x24,0x7c,0x24,0x10,0xfe,0x80,0x88,0x52,0x22,0x5a,0x86,
+/* 14445 0x386d "㡭" */
+0x44,0x49,0x5e,0x44,0x4a,0x5f,0x40,0x7f,0x44,0x49,0x5e,0x44,0x4a,0x5f,0x40,0x7f,
+0x10,0x24,0x78,0x10,0x28,0x7c,0x00,0xfe,0x10,0x24,0x78,0x10,0x28,0x7c,0x00,0xfe,
+/* 14446 0x386e "㡮" */
+0x49,0x49,0xaa,0xeb,0x49,0xaa,0xeb,0x29,0xff,0x24,0x25,0x25,0x22,0x52,0x45,0x88,
+0x20,0x20,0xbe,0xa0,0x40,0xbc,0x80,0x00,0xb8,0x08,0x08,0x08,0x8a,0x8a,0x86,0x82,
+/* 14447 0x386f "㡯" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x27,0x20,0x20,0x20,0x3f,0x20,0x40,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x10,0xf8,0x80,0x80,0x80,0xfe,0x80,0x80,0x82,0x82,0x82,0x7e,
+/* 14448 0x3870 "㡰" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x20,0x20,0x20,0x3f,0x20,0x20,0x40,0x40,0x82,0x01,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x80,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 14449 0x3871 "㡱" */
+0x01,0x00,0x3f,0x21,0x21,0x21,0x23,0x22,0x24,0x28,0x20,0x20,0x41,0x42,0x8c,0x30,
+0x00,0x80,0xfe,0x00,0x00,0x00,0xf0,0x10,0x20,0x20,0x40,0xc0,0x20,0x10,0x08,0x06,
+/* 14450 0x3872 "㡲" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x41,0x4e,0x80,
+0x00,0x80,0xfe,0x00,0x90,0x88,0xfe,0x80,0x80,0x88,0x90,0x60,0x42,0xa2,0x1a,0x06,
+/* 14451 0x3873 "㡳" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x24,0x24,0x45,0x46,0x84,
+0x00,0x80,0xfe,0x00,0x3c,0xc0,0x40,0x40,0x40,0xfe,0x20,0x20,0x12,0x0a,0x06,0x02,
+/* 14452 0x3874 "㡴" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x2f,0x20,0x24,0x22,0x22,0x21,0x41,0x40,0x9f,0x00,
+0x00,0x80,0xfe,0x80,0x40,0x40,0xfc,0x00,0x08,0x08,0x10,0x10,0x20,0x00,0xfe,0x00,
+/* 14453 0x3875 "㡵" */
+0x01,0x00,0x3f,0x20,0x21,0x22,0x24,0x28,0x30,0x27,0x20,0x20,0x43,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x80,0x40,0x20,0x90,0x48,0x46,0xf0,0x10,0x20,0x40,0x80,0x40,0x20,
+/* 14454 0x3876 "㡶" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x27,0x24,0x41,0x42,0x84,0x08,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x20,0x10,0x08,0x04,
+/* 14455 0x3877 "㡷" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x2f,0x21,0x22,0x22,0x24,0x28,0x57,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x80,0x80,0xfc,0xc0,0xa0,0xa0,0x90,0x88,0xf4,0x80,0x80,0x80,
+/* 14456 0x3878 "㡸" */
+0x01,0x00,0x3f,0x22,0x22,0x23,0x25,0x29,0x31,0x21,0x21,0x21,0x41,0x41,0x81,0x01,
+0x00,0x80,0xfe,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,
+/* 14457 0x3879 "㡹" */
+0x01,0x00,0x3f,0x20,0x20,0x23,0x22,0x22,0x23,0x22,0x22,0x23,0x42,0x42,0x8f,0x00,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 14458 0x387a "㡺" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x40,0x40,0x9f,0x00,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 14459 0x387b "㡻" */
+0x01,0x00,0x3f,0x20,0x21,0x26,0x24,0x24,0x24,0x24,0x25,0x26,0x25,0x41,0x42,0x84,
+0x00,0x80,0xfe,0x00,0x80,0x3c,0xa4,0xa4,0xa4,0xa4,0xa4,0xb4,0x28,0x20,0x20,0x20,
+/* 14460 0x387c "㡼" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x20,0x20,0x41,0x5e,0x80,
+0x00,0x80,0xfe,0x80,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x84,0x48,0x30,0xd4,0x0c,0x04,
+/* 14461 0x387d "㡽" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x20,0x3f,0x20,0x27,0x20,0x27,0x40,0x5f,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,
+/* 14462 0x387e "㡾" */
+0x01,0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x24,0x24,0x24,0x45,0x46,0x84,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x84,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 14463 0x387f "㡿" */
+0x01,0x00,0x3f,0x22,0x21,0x21,0x2f,0x20,0x24,0x24,0x24,0x27,0x20,0x41,0x46,0x98,
+0x00,0x80,0xfe,0x08,0x08,0x10,0xfe,0x40,0x44,0x44,0x44,0xfc,0x84,0x00,0x00,0x00,
+/* 14464 0x3880 "㢀" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x27,0x24,0x24,0x24,0x21,0x42,0x4c,0x80,0x00,
+0x00,0x80,0xfe,0x40,0x40,0xfe,0x40,0xfc,0x44,0x54,0xe8,0x50,0x48,0x46,0x40,0x40,
+/* 14465 0x3881 "㢁" */
+0x01,0x00,0x3f,0x20,0x21,0x22,0x2d,0x20,0x23,0x2c,0x21,0x26,0x40,0x40,0x81,0x0e,
+0x00,0x80,0xfe,0x80,0xf0,0x10,0x20,0xd0,0x20,0x7c,0x84,0x88,0x50,0x60,0x80,0x00,
+/* 14466 0x3882 "㢂" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x44,0x44,0x87,0x04,
+0x00,0x80,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 14467 0x3883 "㢃" */
+0x01,0x00,0x3f,0x21,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x24,0x24,0x45,0x46,0x84,
+0x00,0x80,0xfe,0x00,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x82,0x44,0x28,0x10,0x08,0x06,
+/* 14468 0x3884 "㢄" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x23,0x22,0x22,0x22,0x23,0x20,0x42,0x41,0x9f,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x10,0xfe,
+/* 14469 0x3885 "㢅" */
+0x01,0x00,0x3f,0x20,0x27,0x20,0x23,0x20,0x2f,0x21,0x21,0x2f,0x21,0x42,0x42,0x84,
+0x00,0x80,0xfe,0x00,0xfc,0x40,0xf8,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 14470 0x3886 "㢆" */
+0x01,0x00,0x3f,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x20,0x27,0x40,0x40,0x8f,
+0x00,0x80,0xfe,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0xfc,0x40,0x40,0xfe,
+/* 14471 0x3887 "㢇" */
+0x01,0x00,0x3f,0x21,0x20,0x2f,0x20,0x27,0x20,0x27,0x20,0x27,0x24,0x44,0x47,0x84,
+0x00,0x80,0xfe,0x00,0x80,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 14472 0x3888 "㢈" */
+0x01,0x00,0x3f,0x22,0x22,0x27,0x24,0x2c,0x37,0x24,0x24,0x27,0x44,0x44,0x87,0x04,
+0x00,0x80,0xfe,0x80,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 14473 0x3889 "㢉" */
+0x01,0x00,0x3f,0x20,0x21,0x2e,0x22,0x22,0x3f,0x26,0x27,0x2a,0x2a,0x52,0x42,0x82,
+0x00,0x80,0xfe,0x00,0x8c,0x70,0x10,0x10,0x90,0x1e,0x70,0x90,0x12,0x12,0x12,0x0e,
+/* 14474 0x388a "㢊" */
+0x01,0x00,0x3f,0x20,0x2f,0x21,0x22,0x24,0x3f,0x20,0x27,0x24,0x47,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x80,0xf8,0x40,0x20,0x10,0xfe,0x10,0xd0,0x50,0xd0,0x10,0x50,0x20,
+/* 14475 0x388b "㢋" */
+0x01,0x00,0x3f,0x22,0x22,0x24,0x25,0x2c,0x34,0x25,0x24,0x24,0x25,0x44,0x44,0x85,
+0x00,0x80,0xfe,0x20,0x78,0x88,0x50,0x24,0x48,0x9e,0x22,0x64,0x98,0x10,0x60,0x80,
+/* 14476 0x388c "㢌" */
+0x01,0x00,0x3f,0x20,0x2e,0x2a,0x2a,0x2c,0x2a,0x2a,0x2a,0x2a,0x4e,0x48,0x88,0x08,
+0x00,0x80,0xfe,0x00,0xfc,0x08,0xe8,0xa8,0xa8,0xa8,0xa8,0xe8,0xa8,0x08,0x28,0x10,
+/* 14477 0x388d "㢍" */
+0x01,0x00,0x3f,0x20,0x21,0x2f,0x21,0x20,0x23,0x22,0x22,0x2f,0x20,0x41,0x46,0x98,
+0x00,0x80,0xfe,0x00,0x10,0xfe,0x10,0x40,0xf8,0x48,0x48,0xfe,0xa0,0x10,0x08,0x06,
+/* 14478 0x388e "㢎" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x20,0x2f,0x20,0x21,0x26,0x24,0x27,0x44,0x47,0x84,
+0x00,0x80,0xfe,0x00,0x38,0xc0,0x40,0xfe,0x40,0x40,0x5c,0x44,0x5c,0x44,0xfc,0x04,
+/* 14479 0x388f "㢏" */
+0x01,0x00,0x3f,0x20,0x20,0x23,0x2d,0x20,0x27,0x24,0x27,0x24,0x27,0x44,0x44,0x85,
+0x00,0x80,0xfe,0x40,0xa0,0x18,0xf6,0x00,0x84,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x88,
+/* 14480 0x3890 "㢐" */
+0x01,0x00,0x3f,0x20,0x23,0x22,0x23,0x22,0x22,0x2f,0x28,0x29,0x29,0x49,0x48,0x88,
+0x00,0x80,0xfe,0x00,0xf0,0x10,0xd0,0x50,0x50,0xfc,0x04,0xe4,0x24,0xe4,0x14,0x08,
+/* 14481 0x3891 "㢑" */
+0x00,0x3f,0x22,0x22,0x27,0x24,0x2f,0x34,0x27,0x24,0x27,0x24,0x40,0x5f,0x80,0x00,
+0x80,0xfe,0x80,0x40,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x80,0x80,0xfe,0x80,0x80,
+/* 14482 0x3892 "㢒" */
+0x00,0x3f,0x20,0x20,0x20,0x2f,0x28,0x2b,0x28,0x29,0x29,0x29,0x49,0x51,0x91,0x27,
+0x80,0xfe,0x40,0x7e,0x40,0xfe,0x42,0xf8,0x42,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfe,
+/* 14483 0x3893 "㢓" */
+0x00,0x3f,0x20,0x27,0x21,0x2f,0x20,0x23,0x22,0x23,0x22,0x23,0x40,0x4f,0x80,0x00,
+0x80,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,0x40,
+/* 14484 0x3894 "㢔" */
+0x01,0x00,0x3f,0x22,0x24,0x28,0x30,0x22,0x25,0x2c,0x34,0x24,0x44,0x45,0x86,0x04,
+0x00,0x80,0xfe,0x00,0x48,0x48,0x54,0xa4,0x00,0x10,0x90,0x9c,0x90,0x50,0x3e,0x00,
+/* 14485 0x3895 "㢕" */
+0x01,0x00,0x3f,0x22,0x22,0x25,0x29,0x2e,0x22,0x25,0x29,0x2f,0x42,0x44,0x88,0x10,
+0x00,0x80,0xfe,0x28,0x24,0x7e,0x48,0x48,0xfe,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,
+/* 14486 0x3896 "㢖" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x24,0x22,0x3f,0x24,0x28,0x37,0x44,0x47,0x84,0x07,
+0x00,0x80,0xfe,0x00,0x78,0x80,0x90,0xa0,0xfe,0x90,0x08,0xf6,0x90,0xf0,0x90,0xf0,
+/* 14487 0x3897 "㢗" */
+0x00,0x3f,0x20,0x27,0x20,0x2f,0x21,0x27,0x39,0x21,0x20,0x2f,0x48,0x49,0x89,0x09,
+0x80,0xfe,0x38,0xc0,0x80,0xfc,0x10,0xf8,0x16,0xf0,0x00,0xfe,0x02,0xf2,0x12,0xf6,
+/* 14488 0x3898 "㢘" */
+0x01,0x00,0x3f,0x22,0x21,0x2f,0x21,0x2f,0x21,0x3f,0x21,0x2f,0x20,0x4a,0x49,0x91,
+0x00,0x80,0xfe,0x10,0x20,0xfc,0x20,0xf8,0x28,0xfe,0x28,0xf8,0x00,0x48,0x24,0x24,
+/* 14489 0x3899 "㢙" */
+0x00,0x3f,0x25,0x25,0x3f,0x25,0x27,0x22,0x2f,0x2a,0x2f,0x22,0x4f,0x42,0x83,0x1c,
+0x80,0xfe,0x10,0x10,0xd0,0x3c,0x14,0x14,0x94,0x94,0x94,0x14,0xa4,0x24,0x54,0x88,
+/* 14490 0x389a "㢚" */
+0x00,0x3f,0x20,0x20,0x20,0x2f,0x28,0x2b,0x28,0x2b,0x2a,0x2b,0x4a,0x57,0x90,0x23,
+0x80,0xfe,0x80,0xf8,0x80,0xfc,0x84,0xf0,0x88,0xf8,0x48,0xf8,0x48,0xfc,0x84,0x0c,
+/* 14491 0x389b "㢛" */
+0x00,0x3f,0x20,0x20,0x21,0x22,0x2d,0x20,0x27,0x24,0x24,0x27,0x41,0x42,0x84,0x08,
+0x80,0xfe,0x40,0xa0,0x10,0x08,0xf6,0x00,0xbc,0xa4,0xa4,0xbc,0x10,0xa8,0x44,0x82,
+/* 14492 0x389c "㢜" */
+0x00,0x3f,0x22,0x3f,0x22,0x23,0x20,0x27,0x24,0x27,0x24,0x27,0x40,0x45,0x85,0x08,
+0x80,0xfe,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x40,0x24,0x0a,0xfa,
+/* 14493 0x389d "㢝" */
+0x01,0x00,0x3f,0x24,0x27,0x29,0x32,0x2f,0x2a,0x2f,0x2a,0x2f,0x40,0x55,0x95,0x20,
+0x00,0x80,0xfe,0x00,0x06,0x38,0x08,0x88,0xbe,0x88,0x9c,0xaa,0x08,0x48,0x48,0x08,
+/* 14494 0x389e "㢞" */
+0x00,0x7f,0x40,0x7e,0x52,0x4a,0x52,0x4f,0x48,0x4f,0x48,0x4f,0x42,0x5f,0x44,0x88,
+0x80,0xfe,0x00,0x7c,0x24,0x14,0x24,0xf8,0x88,0xf8,0x88,0xf8,0x20,0xfc,0x10,0x08,
+/* 14495 0x389f "㢟" */
+0x00,0x00,0xf8,0x08,0x10,0x11,0x21,0x79,0x09,0x09,0x49,0x31,0x10,0x2c,0x43,0x80,
+0x00,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 14496 0x38a0 "㢠" */
+0x00,0x03,0xfa,0x0a,0x12,0x12,0x22,0x7a,0x0a,0x0a,0x4a,0x32,0x12,0x2c,0x43,0x80,
+0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x94,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 14497 0x38a1 "㢡" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x84,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 14498 0x38a2 "㢢" */
+0x08,0x49,0x2a,0x7f,0x41,0x5d,0x55,0x5d,0x42,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0x28,0x46,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 14499 0x38a3 "㢣" */
+0x24,0xff,0x24,0x7e,0x82,0x7a,0x4a,0x7a,0x04,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 14500 0x38a4 "㢤" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x10,0x10,0x1f,0x11,0x11,0x21,0x21,0x41,0x4a,0x84,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 14501 0x38a5 "㢥" */
+0x00,0x7f,0x41,0x41,0x5d,0x41,0x41,0x5d,0x55,0x55,0x55,0x5d,0x41,0x41,0x45,0x42,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x20,0x20,0x20,0x20,0x24,0x14,0x14,0x0c,0x04,
+/* 14502 0x38a6 "㢦" */
+0x00,0xff,0x02,0x7a,0x4a,0x7a,0x00,0xff,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+0x20,0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x20,0x20,0x20,0x10,0x12,0x0a,0x06,0x02,
+/* 14503 0x38a7 "㢧" */
+0x00,0x7f,0x00,0x00,0x3f,0x20,0x20,0x3f,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0xe8,0x08,0x08,0x08,0x50,0x20,
+/* 14504 0x38a8 "㢨" */
+0x00,0x7d,0x04,0x04,0x04,0x7c,0x40,0x43,0x40,0x7c,0x04,0x04,0x04,0x04,0x28,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 14505 0x38a9 "㢩" */
+0x00,0x7c,0x04,0x04,0x05,0x7e,0x40,0x41,0x40,0x7c,0x04,0x04,0x04,0x04,0x28,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 14506 0x38aa "㢪" */
+0x00,0xf9,0x08,0x08,0x08,0x7b,0x40,0x40,0x41,0x79,0x08,0x08,0x08,0x08,0x50,0x20,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 14507 0x38ab "㢫" */
+0x00,0xf8,0x08,0x08,0x09,0x79,0x41,0x41,0x41,0x79,0x09,0x09,0x09,0x09,0x50,0x20,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 14508 0x38ac "㢬" */
+0x00,0xf8,0x08,0x08,0x0b,0x78,0x40,0x40,0x40,0x79,0x09,0x0a,0x0a,0x0c,0x51,0x20,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 14509 0x38ad "㢭" */
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x40,0x41,0x40,0x7c,0x04,0x04,0x04,0x04,0x29,0x16,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 14510 0x38ae "㢮" */
+0x00,0xf8,0x08,0x09,0x0a,0x79,0x41,0x41,0x43,0x79,0x09,0x09,0x09,0x09,0x50,0x20,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 14511 0x38af "㢯" */
+0x00,0xfb,0x0a,0x0a,0x0a,0x7b,0x42,0x42,0x43,0x7a,0x0a,0x0a,0x0a,0x0a,0x53,0x22,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 14512 0x38b0 "㢰" */
+0x00,0xf8,0x08,0x09,0x09,0x79,0x41,0x41,0x41,0x79,0x09,0x09,0x09,0x0a,0x52,0x24,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14513 0x38b1 "㢱" */
+0x00,0xf8,0x08,0x09,0x0b,0x78,0x40,0x40,0x41,0x79,0x0a,0x0a,0x0c,0x08,0x50,0x20,
+0x20,0x40,0x88,0x04,0xfe,0x02,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 14514 0x38b2 "㢲" */
+0x00,0x7c,0x04,0x7c,0x40,0x7c,0x04,0x04,0x28,0x10,0x00,0xff,0x00,0x08,0x10,0x20,
+0x00,0xf8,0x08,0xf8,0x80,0xf8,0x08,0x08,0x50,0x20,0x00,0xfe,0x00,0x20,0x10,0x08,
+/* 14515 0x38b3 "㢳" */
+0x00,0x7c,0x04,0x05,0x06,0x7c,0x41,0x41,0x41,0x7d,0x05,0x05,0x05,0x05,0x29,0x11,
+0x80,0x80,0xfe,0x00,0x00,0x1c,0xe0,0x20,0x22,0x24,0x28,0x10,0x10,0x48,0x84,0x02,
+/* 14516 0x38b4 "㢴" */
+0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x3f,0x00,0x3f,0x2a,0x24,0x2b,0x24,0x3f,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0xe4,0xa4,0xa4,0x24,0xa4,0xe8,0x10,
+/* 14517 0x38b5 "㢵" */
+0x00,0xf8,0x08,0x08,0x09,0x7a,0x41,0x40,0x40,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14518 0x38b6 "㢶" */
+0x00,0xfb,0x08,0x08,0x08,0x79,0x41,0x41,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14519 0x38b7 "㢷" */
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x40,0x40,0x40,0x7d,0x04,0x04,0x04,0x04,0x28,0x11,
+0x10,0x92,0x92,0x92,0xfe,0x20,0x20,0x7e,0x82,0x42,0x24,0x28,0x10,0x20,0x40,0x80,
+/* 14520 0x38b8 "㢸" */
+0x00,0xf7,0x11,0x11,0x11,0xf7,0x84,0x84,0x84,0xf7,0x11,0x11,0x11,0x11,0xaa,0x45,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 14521 0x38b9 "㢹" */
+0x00,0x7c,0x05,0x04,0x04,0x7c,0x43,0x40,0x40,0x7c,0x05,0x04,0x04,0x04,0x28,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 14522 0x38ba "㢺" */
+0x00,0xf8,0x09,0x08,0x08,0x78,0x43,0x40,0x40,0x7b,0x08,0x09,0x08,0x08,0x50,0x23,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x40,0x40,0xfe,0x88,0x88,0x50,0x30,0xc8,0x04,
+/* 14523 0x38bb "㢻" */
+0x00,0xf9,0x08,0x08,0x0b,0x78,0x41,0x42,0x40,0x7b,0x08,0x09,0x08,0x08,0x50,0x21,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 14524 0x38bc "㢼" */
+0x00,0x7d,0x04,0x04,0x04,0x7d,0x41,0x41,0x41,0x7d,0x05,0x05,0x05,0x05,0x29,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x24,0x24,0x74,0xac,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 14525 0x38bd "㢽" */
+0x00,0xf7,0x12,0x12,0x12,0xf3,0x82,0x82,0x83,0xf2,0x12,0x12,0x17,0x10,0xa0,0x40,
+0x00,0xee,0x42,0x42,0x42,0xce,0x48,0x48,0xc8,0x4e,0x42,0xe2,0x42,0x42,0x54,0x48,
+/* 14526 0x38be "㢾" */
+0x00,0xfb,0x08,0x08,0x09,0x79,0x41,0x41,0x41,0x78,0x08,0x09,0x08,0x08,0x53,0x20,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 14527 0x38bf "㢿" */
+0x00,0xf8,0x08,0x09,0x09,0x7b,0x45,0x41,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 14528 0x38c0 "㣀" */
+0x00,0xf8,0x0b,0x08,0x09,0x79,0x41,0x41,0x41,0x79,0x09,0x09,0x0b,0x08,0x51,0x22,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 14529 0x38c1 "㣁" */
+0x00,0xf8,0x0b,0x08,0x08,0x7b,0x40,0x41,0x43,0x7d,0x09,0x09,0x09,0x09,0x51,0x21,
+0x88,0x88,0xfe,0x88,0x88,0xfe,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 14530 0x38c2 "㣂" */
+0x00,0xfb,0x08,0x09,0x09,0x79,0x41,0x40,0x43,0x7a,0x0a,0x0b,0x0a,0x0a,0x52,0x22,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 14531 0x38c3 "㣃" */
+0x02,0xf1,0x17,0x12,0x14,0xf7,0x80,0x87,0x84,0xf7,0x14,0x17,0x14,0x14,0xa4,0x45,
+0x00,0x1e,0xc2,0x02,0x82,0xde,0x50,0x90,0x90,0x9e,0x82,0x82,0x82,0x82,0x94,0x88,
+/* 14532 0x38c4 "㣄" */
+0x02,0xf9,0x08,0x0c,0x0a,0x78,0x41,0x46,0x42,0x78,0x0b,0x08,0x08,0x09,0x52,0x20,
+0x00,0x7e,0x40,0x7c,0x44,0xfc,0x40,0x7e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 14533 0x38c5 "㣅" */
+0x00,0xfb,0x08,0x0a,0x0b,0x79,0x42,0x44,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 14534 0x38c6 "㣆" */
+0x07,0xf2,0x17,0x1c,0x16,0xf5,0x86,0x85,0x86,0xf4,0x14,0x17,0x10,0x13,0xa0,0x4f,
+0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x54,0x08,0xfc,0x40,0xf8,0x40,0xfe,
+/* 14535 0x38c7 "㣇" */
+0x08,0x0f,0x10,0x1f,0x00,0x7f,0x09,0x32,0xcc,0x30,0xcf,0x08,0x08,0x08,0x08,0x00,
+0x00,0xe0,0x20,0xc0,0x40,0xfc,0x00,0x00,0x80,0x80,0xf8,0x88,0x88,0xa8,0x90,0x80,
+/* 14536 0x38c8 "㣈" */
+0x20,0x3c,0x44,0x78,0x08,0xfe,0x50,0xa8,0x48,0xbe,0x2a,0x2a,0x2a,0x2e,0x08,0x08,
+0x20,0x3c,0x44,0x78,0x08,0xfe,0x50,0xa8,0x48,0xbe,0x2a,0x2a,0x2a,0x2e,0x08,0x08,
+/* 14537 0x38c9 "㣉" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0xf0,0x40,0x00,0x01,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x60,0x80,
+/* 14538 0x38ca "㣊" */
+0x04,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe1,0x06,0x38,0x01,0x06,0x38,0x00,0x07,0x78,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0x00,0x40,0x88,0x10,0x20,0xc0,0x00,0x00,
+/* 14539 0x38cb "㣋" */
+0x11,0x11,0x11,0x11,0x7f,0x11,0x19,0x15,0x11,0xff,0x11,0x11,0x11,0x21,0x21,0x41,
+0x00,0x04,0x04,0x08,0xd0,0x22,0x02,0x04,0x08,0xd0,0x22,0x02,0x04,0x08,0x10,0x60,
+/* 14540 0x38cc "㣌" */
+0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x00,0x04,0x04,0x08,0x90,0x22,0x02,0x04,0x08,0x10,0x22,0x02,0x04,0x08,0x10,0x60,
+/* 14541 0x38cd "㣍" */
+0x08,0x08,0x10,0x22,0x41,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x00,0x04,0x04,0x08,0x10,0xa2,0x82,0x04,0x08,0x10,0x22,0x02,0x04,0x08,0x10,0x60,
+/* 14542 0x38ce "㣎" */
+0x01,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x11,0x21,0x46,0x19,0x06,0x18,0x07,0x38,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x50,0x88,0x44,0x90,0x20,0xc0,0x00,0x00,
+/* 14543 0x38cf "㣏" */
+0x08,0x08,0xff,0x14,0x22,0x41,0xbe,0x22,0x3e,0x22,0x3e,0x08,0xff,0x08,0x08,0x08,
+0x00,0x04,0x84,0x08,0x10,0x22,0x82,0x04,0x08,0x10,0x22,0x02,0x84,0x08,0x10,0x60,
+/* 14544 0x38d0 "㣐" */
+0x08,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x08,0x08,0xe8,0x2d,0x2a,0x49,0x88,0x28,0x10,
+0x00,0x04,0x04,0x08,0x10,0x22,0x02,0x04,0x08,0x90,0x22,0x02,0x04,0x88,0x10,0x60,
+/* 14545 0x38d1 "㣑" */
+0x02,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x22,0x2f,0x2a,0x2f,0x4a,0x4f,0x8a,0x09,
+0x02,0xc2,0x04,0x88,0x90,0xc2,0x82,0x84,0x08,0x90,0x82,0x82,0x84,0x88,0x90,0xa0,
+/* 14546 0x38d2 "㣒" */
+0x41,0x22,0x00,0xff,0x88,0xaa,0x9c,0x88,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,
+0x00,0x04,0x04,0x88,0x90,0xa2,0x82,0x84,0x88,0x10,0x22,0x02,0x04,0x08,0x10,0x60,
+/* 14547 0x38d3 "㣓" */
+0x08,0x0d,0x28,0x3d,0x44,0xa9,0x32,0xc4,0x24,0x15,0x7f,0x0e,0x15,0x24,0xc4,0x04,
+0x02,0xc2,0x44,0x48,0x90,0x42,0x42,0x04,0x88,0x10,0xc2,0x02,0x04,0x88,0x50,0x20,
+/* 14548 0x38d4 "㣔" */
+0x08,0x08,0x13,0x20,0x48,0x08,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 14549 0x38d5 "㣕" */
+0x08,0x08,0x10,0x20,0x48,0x0f,0x10,0x30,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 14550 0x38d6 "㣖" */
+0x08,0x08,0x10,0x20,0x4b,0x08,0x10,0x30,0x50,0x90,0x11,0x11,0x12,0x12,0x14,0x18,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x88,0x48,0x44,0x02,
+/* 14551 0x38d7 "㣗" */
+0x08,0x08,0x10,0x21,0x49,0x09,0x11,0x31,0x51,0x91,0x11,0x11,0x11,0x12,0x12,0x14,
+0x40,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 14552 0x38d8 "㣘" */
+0x08,0x08,0x11,0x21,0x4a,0x0c,0x11,0x31,0x51,0x91,0x11,0x11,0x10,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 14553 0x38d9 "㣙" */
+0x10,0x10,0x20,0x40,0x97,0x14,0x24,0x64,0xa4,0x27,0x24,0x24,0x24,0x24,0x27,0x24,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 14554 0x38da "㣚" */
+0x08,0x0b,0x12,0x22,0x4a,0x0a,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 14555 0x38db "㣛" */
+0x08,0x08,0x10,0x21,0x4a,0x0c,0x13,0x30,0x50,0x93,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 14556 0x38dc "㣜" */
+0x10,0x17,0x22,0x42,0x92,0x12,0x22,0x67,0xa2,0x22,0x22,0x22,0x22,0x24,0x24,0x28,
+0x02,0xe2,0x42,0x4a,0x4a,0x4a,0x4a,0xea,0x4a,0x4a,0x4a,0x4a,0x42,0x42,0x4a,0x44,
+/* 14557 0x38dd "㣝" */
+0x08,0x08,0x10,0x20,0x4b,0x08,0x11,0x31,0x51,0x93,0x11,0x11,0x12,0x12,0x14,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14558 0x38de "㣞" */
+0x08,0x08,0x11,0x21,0x4a,0x0c,0x11,0x33,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x94,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 14559 0x38df "㣟" */
+0x08,0x08,0x10,0x23,0x48,0x08,0x11,0x30,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14560 0x38e0 "㣠" */
+0x10,0x10,0x20,0x40,0x95,0x16,0x24,0x64,0xa4,0x27,0x24,0x24,0x24,0x20,0x20,0x20,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 14561 0x38e1 "㣡" */
+0x11,0x11,0x21,0x42,0x92,0x16,0x26,0x6a,0xa2,0x22,0x22,0x22,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,
+/* 14562 0x38e2 "㣢" */
+0x09,0x08,0x10,0x23,0x48,0x08,0x13,0x32,0x52,0x93,0x10,0x10,0x11,0x12,0x14,0x10,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 14563 0x38e3 "㣣" */
+0x10,0x10,0x20,0x47,0x90,0x14,0x22,0x62,0xa5,0x28,0x20,0x21,0x21,0x22,0x24,0x28,
+0x40,0x40,0x40,0xfe,0x40,0x50,0x48,0x48,0x54,0xa2,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 14564 0x38e4 "㣤" */
+0x08,0x08,0x10,0x23,0x48,0x08,0x10,0x37,0x50,0x90,0x10,0x13,0x10,0x10,0x10,0x17,
+0x50,0x48,0x5e,0xe4,0x28,0x32,0xca,0x06,0x50,0x48,0x5e,0xe4,0x28,0x32,0xca,0x06,
+/* 14565 0x38e5 "㣥" */
+0x11,0x11,0x21,0x42,0x92,0x16,0x2a,0x62,0xa2,0x22,0x22,0x22,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 14566 0x38e6 "㣦" */
+0x08,0x0b,0x10,0x20,0x4f,0x09,0x12,0x34,0x50,0x97,0x11,0x12,0x11,0x10,0x10,0x13,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x86,0x80,0xfc,0x10,0x10,0xa0,0x60,0x90,0x08,
+/* 14567 0x38e7 "㣧" */
+0x11,0x12,0x24,0x47,0x91,0x12,0x27,0x60,0xa7,0x24,0x27,0x24,0x27,0x24,0x24,0x24,
+0x00,0x08,0x48,0x88,0x08,0x48,0xc8,0x08,0xc8,0x48,0xc8,0x48,0xca,0x4a,0x4a,0xc6,
+/* 14568 0x38e8 "㣨" */
+0x12,0x12,0x22,0x42,0x9f,0x15,0x25,0x65,0xa5,0x29,0x25,0x22,0x22,0x25,0x25,0x28,
+0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 14569 0x38e9 "㣩" */
+0x11,0x11,0x21,0x41,0x97,0x11,0x21,0x63,0xa3,0x25,0x25,0x29,0x21,0x21,0x21,0x21,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 14570 0x38ea "㣪" */
+0x08,0x0f,0x12,0x21,0x48,0x0b,0x10,0x30,0x57,0x91,0x11,0x12,0x12,0x14,0x18,0x13,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 14571 0x38eb "㣫" */
+0x08,0x08,0x11,0x20,0x4b,0x08,0x11,0x31,0x51,0x91,0x11,0x10,0x11,0x10,0x13,0x10,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 14572 0x38ec "㣬" */
+0x08,0x09,0x11,0x21,0x49,0x08,0x17,0x31,0x51,0x91,0x11,0x11,0x11,0x17,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 14573 0x38ed "㣭" */
+0x08,0x08,0x12,0x22,0x4a,0x0a,0x12,0x33,0x50,0x91,0x12,0x10,0x11,0x10,0x10,0x17,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 14574 0x38ee "㣮" */
+0x08,0x08,0x13,0x20,0x48,0x0b,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 14575 0x38ef "㣯" */
+0x08,0x0b,0x12,0x22,0x4b,0x0a,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x54,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x8a,0x84,
+/* 14576 0x38f0 "㣰" */
+0x08,0x09,0x10,0x21,0x48,0x0b,0x10,0x30,0x51,0x92,0x10,0x10,0x12,0x12,0x14,0x10,
+0x1c,0xe0,0x20,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 14577 0x38f1 "㣱" */
+0x08,0x0b,0x10,0x21,0x48,0x0b,0x10,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 14578 0x38f2 "㣲" */
+0x12,0x12,0x2a,0x4a,0x9f,0x10,0x20,0x6f,0xa0,0x20,0x2f,0x28,0x28,0x2f,0x28,0x20,
+0x10,0x10,0x90,0x90,0xbe,0x24,0x54,0x94,0x14,0x14,0x94,0x88,0x88,0x94,0x94,0x22,
+/* 14579 0x38f3 "㣳" */
+0x11,0x11,0x23,0x46,0x9a,0x12,0x27,0x62,0xa2,0x22,0x2f,0x20,0x22,0x22,0x24,0x20,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 14580 0x38f4 "㣴" */
+0x11,0x11,0x27,0x41,0x91,0x1f,0x20,0x67,0xa4,0x27,0x24,0x27,0x20,0x21,0x22,0x24,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x10,0x08,0x04,
+/* 14581 0x38f5 "㣵" */
+0x10,0x14,0x22,0x40,0x90,0x10,0x26,0x62,0xa2,0x22,0x22,0x22,0x22,0x22,0x25,0x28,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 14582 0x38f6 "㣶" */
+0x10,0x1f,0x20,0x47,0x94,0x15,0x25,0x67,0xa0,0x23,0x22,0x23,0x22,0x23,0x20,0x2f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 14583 0x38f7 "㣷" */
+0x10,0x10,0x27,0x44,0x92,0x12,0x24,0x60,0xa3,0x22,0x2f,0x20,0x27,0x20,0x21,0x20,
+0x80,0x40,0xfc,0x44,0xa8,0x94,0x74,0x00,0xf8,0xa8,0xfe,0x00,0xfc,0x40,0x40,0x80,
+/* 14584 0x38f8 "㣸" */
+0x15,0x15,0x2d,0x45,0x9f,0x12,0x24,0x6a,0xa3,0x25,0x29,0x23,0x25,0x29,0x25,0x22,
+0x08,0x48,0xa8,0x3e,0xa8,0x48,0x48,0xbe,0x08,0x88,0x88,0x7e,0x40,0x20,0x1e,0x00,
+/* 14585 0x38f9 "㣹" */
+0x10,0x10,0x27,0x44,0x94,0x15,0x27,0x65,0xa5,0x25,0x25,0x25,0x28,0x2a,0x32,0x24,
+0x40,0x20,0xfe,0xa8,0xfe,0x50,0x7c,0x50,0x7c,0x50,0x7e,0x40,0xa4,0x8a,0x8a,0x78,
+/* 14586 0x38fa "㣺" */
+0x04,0x04,0x04,0x04,0x25,0x24,0x24,0x44,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x10,0x88,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 14587 0x38fb "㣻" */
+0x10,0x08,0x04,0x02,0x01,0x02,0x0c,0x30,0xc0,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x10,0x20,0x40,0x80,0x00,0x80,0x60,0x18,0x06,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14588 0x38fc "㣼" */
+0x10,0x10,0x11,0x10,0x18,0x55,0x51,0x51,0x91,0x12,0x10,0x10,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 14589 0x38fd "㣽" */
+0x02,0x02,0xff,0x04,0x08,0x1c,0x03,0x0c,0x70,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x80,0x70,0x08,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14590 0x38fe "㣾" */
+0x10,0x13,0x11,0x11,0x19,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x04,0x44,0x24,0xa8,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 14591 0x38ff "㣿" */
+0x10,0x10,0x10,0x18,0x55,0x52,0x50,0x91,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 14592 0x3900 "㤀" */
+0x03,0x00,0x21,0x22,0x24,0x28,0x30,0x20,0x3f,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0xfc,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14593 0x3901 "㤁" */
+0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc1,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14594 0x3902 "㤂" */
+0x00,0x3f,0x08,0x08,0x0c,0x0a,0x12,0x11,0x20,0x43,0x8c,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xe0,0x20,0x40,0x78,0x08,0x10,0x20,0xc0,0x30,0x0e,0x00,0x04,0x12,0x12,0xf0,
+/* 14595 0x3903 "㤃" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 14596 0x3904 "㤄" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 14597 0x3905 "㤅" */
+0x7f,0x02,0x42,0x42,0x7f,0x04,0x08,0x10,0x20,0xc0,0x01,0x08,0x48,0x48,0x87,0x00,
+0xf8,0x00,0x00,0x00,0xfc,0x80,0x80,0x84,0x84,0x7c,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14598 0x3906 "㤆" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 14599 0x3907 "㤇" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x57,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 14600 0x3908 "㤈" */
+0x10,0x10,0x10,0x10,0x18,0x54,0x50,0x52,0x92,0x12,0x12,0x14,0x10,0x10,0x10,0x10,
+0x00,0x40,0x20,0x10,0x90,0x80,0x80,0x84,0x82,0x82,0x82,0x88,0x88,0x88,0x78,0x00,
+/* 14601 0x3909 "㤉" */
+0x10,0x13,0x10,0x19,0x55,0x51,0x52,0x93,0x10,0x10,0x10,0x11,0x12,0x14,0x10,0x10,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 14602 0x390a "㤊" */
+0x10,0x13,0x10,0x10,0x18,0x54,0x51,0x50,0x90,0x11,0x10,0x10,0x10,0x10,0x11,0x16,
+0x04,0x08,0xd0,0x20,0x50,0x88,0x04,0x00,0x04,0x04,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 14603 0x390b "㤋" */
+0x10,0x10,0x10,0x18,0x55,0x51,0x52,0x95,0x10,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 14604 0x390c "㤌" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 14605 0x390d "㤍" */
+0x00,0x7d,0x10,0x10,0x11,0x10,0x1e,0xe0,0x40,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14606 0x390e "㤎" */
+0x10,0x10,0x7e,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14607 0x390f "㤏" */
+0x10,0x10,0x10,0x11,0x1b,0x54,0x50,0x50,0x93,0x1c,0x10,0x10,0x10,0x11,0x10,0x10,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xc0,0x20,0x10,0x80,0x60,0x10,
+/* 14608 0x3910 "㤐" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x20,0x3f,0x20,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14609 0x3911 "㤑" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x11,0x12,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfe,0x40,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 14610 0x3912 "㤒" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x51,0x92,0x10,0x11,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x50,0x50,0x88,0x24,0x22,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 14611 0x3913 "㤓" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x91,0x11,0x12,0x15,0x18,0x10,0x10,0x10,
+0x40,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0xf4,0x42,0x40,0x40,0x40,
+/* 14612 0x3914 "㤔" */
+0x10,0x10,0x10,0x19,0x55,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 14613 0x3915 "㤕" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x50,0x90,0x11,0x11,0x11,0x11,0x11,0x11,0x10,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 14614 0x3916 "㤖" */
+0x10,0x10,0x10,0x13,0x1a,0x54,0x50,0x50,0x93,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 14615 0x3917 "㤗" */
+0x01,0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x12,0x22,0xc2,0x12,0x12,0x22,0x0a,0x04,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x10,0x08,0x26,0x90,0x48,0x48,0x00,0x00,
+/* 14616 0x3918 "㤘" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x53,0x50,0x90,0x10,0x11,0x10,0x10,0x10,0x13,0x10,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 14617 0x3919 "㤙" */
+0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x01,0x08,0x48,0x48,0x87,0x00,
+0xf8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x08,0x08,0xf8,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14618 0x391a "㤚" */
+0x10,0x10,0x11,0x1a,0x54,0x50,0x51,0x93,0x15,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 14619 0x391b "㤛" */
+0x10,0x10,0x10,0x19,0x55,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 14620 0x391c "㤜" */
+0x20,0x20,0x20,0x20,0x33,0xaa,0xa2,0xa2,0xa3,0x22,0x22,0x22,0x22,0x24,0x24,0x28,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14621 0x391d "㤝" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x53,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 14622 0x391e "㤞" */
+0x10,0x10,0x13,0x1a,0x54,0x50,0x53,0x90,0x10,0x10,0x17,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x00,0x38,0xc0,0x40,0x40,0x7c,0xc0,0x40,0x42,0x42,0x3e,0x00,
+/* 14623 0x391f "㤟" */
+0x04,0x04,0x3f,0x24,0x24,0x3f,0x24,0x24,0x3f,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14624 0x3920 "㤠" */
+0x7f,0x08,0x10,0x3f,0x51,0x0a,0x04,0x08,0x30,0xc0,0x01,0x08,0x48,0x48,0x87,0x00,
+0x84,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14625 0x3921 "㤡" */
+0x20,0x20,0x2f,0x22,0x32,0xab,0xa2,0xa4,0xa6,0x25,0x28,0x20,0x21,0x22,0x24,0x28,
+0x04,0x04,0xc4,0x14,0x14,0xd4,0x54,0x54,0x54,0x54,0x94,0x94,0x04,0x04,0x14,0x08,
+/* 14626 0x3922 "㤢" */
+0x10,0x10,0x17,0x10,0x19,0x55,0x53,0x55,0x99,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 14627 0x3923 "㤣" */
+0x10,0x08,0x7f,0x08,0x08,0xff,0x08,0x10,0x20,0x41,0x08,0x48,0x48,0x48,0x87,0x00,
+0x10,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14628 0x3924 "㤤" */
+0x10,0x10,0x13,0x12,0x1a,0x57,0x52,0x52,0x93,0x10,0x11,0x10,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x20,0x20,0xa0,0x40,0xa0,0x18,0x06,
+/* 14629 0x3925 "㤥" */
+0x10,0x10,0x10,0x17,0x18,0x54,0x51,0x53,0x90,0x10,0x11,0x16,0x10,0x10,0x11,0x16,
+0x40,0x20,0x20,0xfe,0x40,0x84,0x08,0xf0,0x22,0x44,0x88,0x10,0x20,0x50,0x88,0x04,
+/* 14630 0x3926 "㤦" */
+0x20,0x20,0x2f,0x30,0xa8,0xa7,0xa4,0xa4,0x27,0x20,0x22,0x21,0x20,0x21,0x22,0x2c,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x40,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 14631 0x3927 "㤧" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 14632 0x3928 "㤨" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x17,0x10,0x10,0x10,0x11,0x12,0x14,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 14633 0x3929 "㤩" */
+0x08,0x0f,0x10,0x2c,0x03,0x1c,0xe0,0x1f,0x10,0x10,0x1f,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x00,0x04,0x12,0x12,0xf0,
+/* 14634 0x392a "㤪" */
+0x00,0xff,0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x20,0xc1,0x08,0x48,0x48,0x87,0x00,
+0x00,0xfe,0x00,0xf8,0x88,0x88,0xa8,0x94,0x84,0x7c,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14635 0x392b "㤫" */
+0x04,0x04,0x7f,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x08,0x0a,0x51,0x51,0x90,0x0f,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,0x04,0x12,0x12,0xf0,
+/* 14636 0x392c "㤬" */
+0x10,0x10,0x11,0x18,0x54,0x50,0x53,0x90,0x10,0x10,0x11,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 14637 0x392d "㤭" */
+0x10,0x10,0x13,0x10,0x18,0x57,0x50,0x51,0x92,0x15,0x11,0x11,0x11,0x12,0x12,0x14,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 14638 0x392e "㤮" */
+0x22,0x14,0x19,0x24,0x4c,0x14,0x24,0x44,0x05,0x28,0x11,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0xfc,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14639 0x392f "㤯" */
+0x10,0x13,0x12,0x12,0x1a,0x57,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x52,0x8a,0x06,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 14640 0x3930 "㤰" */
+0x09,0x09,0x11,0x12,0x34,0x50,0x90,0x10,0x10,0x10,0x10,0x02,0x51,0x51,0x90,0x0f,
+0x00,0x00,0xfe,0x80,0x80,0xfc,0x80,0x80,0xfc,0x80,0x80,0x00,0x04,0x12,0x12,0xf0,
+/* 14641 0x3931 "㤱" */
+0x10,0x13,0x10,0x10,0x19,0x55,0x51,0x51,0x91,0x10,0x11,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x88,0x90,0x00,0xfe,0x00,
+/* 14642 0x3932 "㤲" */
+0x01,0x01,0x7f,0x11,0x11,0x29,0x45,0x02,0x04,0x08,0x30,0xc1,0x08,0x28,0x28,0x47,
+0x00,0x00,0xfc,0x10,0x10,0x28,0x44,0x80,0x40,0x20,0x18,0x06,0x88,0xa4,0x24,0xe0,
+/* 14643 0x3933 "㤳" */
+0x10,0x13,0x10,0x18,0x54,0x50,0x53,0x90,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14644 0x3934 "㤴" */
+0x20,0x2f,0x24,0x24,0x34,0xaf,0xa4,0xa4,0xa4,0x27,0x24,0x24,0x24,0x2f,0x20,0x20,
+0x00,0xfe,0x80,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0xd2,0x92,0x8e,0x80,
+/* 14645 0x3935 "㤵" */
+0x00,0x7e,0x04,0x08,0x0e,0x19,0xe8,0x08,0x08,0x28,0x13,0x02,0x51,0x51,0x90,0x0f,
+0x40,0x40,0x7e,0x88,0x88,0x48,0x50,0x20,0x50,0x88,0x06,0x00,0x04,0x12,0x12,0xf0,
+/* 14646 0x3936 "㤶" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x50,0x90,0x10,0x11,0x11,0x11,0x12,0x12,0x14,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 14647 0x3937 "㤷" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x51,0x50,0x90,0x10,0x13,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf0,0x10,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 14648 0x3938 "㤸" */
+0x10,0x10,0x13,0x18,0x54,0x50,0x57,0x90,0x12,0x12,0x14,0x19,0x11,0x12,0x14,0x18,
+0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x90,0x94,0x92,0x92,0x12,0x10,0x10,0x50,0x20,
+/* 14649 0x3939 "㤹" */
+0x10,0x10,0x10,0x18,0x57,0x50,0x52,0x91,0x11,0x10,0x11,0x12,0x14,0x10,0x11,0x10,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x44,0x64,0x68,0xd0,0x50,0x48,0x44,0x42,0x40,0x80,
+/* 14650 0x393a "㤺" */
+0x20,0x20,0x2f,0x22,0x32,0xaa,0xa3,0xa0,0xa2,0x22,0x22,0x22,0x22,0x24,0x24,0x28,
+0x80,0x40,0xfe,0x00,0x00,0x00,0xf8,0x00,0x48,0x48,0x48,0x48,0x48,0x4a,0x4a,0x06,
+/* 14651 0x393b "㤻" */
+0x06,0x38,0x22,0x32,0x2a,0x22,0x2a,0x32,0x04,0x18,0x61,0x08,0x48,0x48,0x87,0x00,
+0x00,0x7c,0x44,0x64,0x54,0x44,0x54,0x48,0x40,0x40,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14652 0x393c "㤼" */
+0x11,0x11,0x11,0x13,0x19,0x55,0x51,0x57,0x91,0x11,0x12,0x12,0x17,0x12,0x10,0x10,
+0x10,0x10,0x10,0x90,0x3c,0x14,0x14,0xd4,0x14,0x14,0x14,0x94,0xd4,0x24,0x54,0x88,
+/* 14653 0x393d "㤽" */
+0x10,0x10,0x13,0x18,0x55,0x50,0x53,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 14654 0x393e "㤾" */
+0x10,0x13,0x12,0x12,0x18,0x55,0x50,0x50,0x93,0x10,0x10,0x10,0x11,0x16,0x10,0x10,
+0x00,0xfe,0x02,0x52,0x88,0x04,0x20,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 14655 0x393f "㤿" */
+0x10,0x10,0x17,0x11,0x1a,0x54,0x53,0x52,0x92,0x13,0x12,0x12,0x13,0x10,0x10,0x10,
+0x40,0x80,0xfe,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 14656 0x3940 "㥀" */
+0x10,0x10,0x13,0x10,0x18,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x17,0x10,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 14657 0x3941 "㥁" */
+0x01,0x01,0x7f,0x01,0x1f,0x12,0x12,0x52,0x5f,0x40,0x7f,0x02,0x51,0x51,0x90,0x0f,
+0x00,0x00,0xfc,0x00,0xf0,0x90,0x90,0x90,0xf0,0x00,0xfc,0x00,0x04,0x12,0x12,0xf0,
+/* 14658 0x3942 "㥂" */
+0x10,0x13,0x12,0x13,0x1a,0x57,0x50,0x53,0x90,0x17,0x10,0x12,0x11,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 14659 0x3943 "㥃" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x04,
+/* 14660 0x3944 "㥄" */
+0x10,0x10,0x11,0x18,0x54,0x53,0x50,0x91,0x12,0x10,0x11,0x12,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 14661 0x3945 "㥅" */
+0x10,0x13,0x10,0x1a,0x55,0x51,0x57,0x94,0x10,0x13,0x11,0x11,0x10,0x10,0x11,0x16,
+0x1c,0xe0,0x84,0x44,0x48,0x10,0xfe,0x02,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 14662 0x3946 "㥆" */
+0x10,0x10,0x13,0x18,0x54,0x57,0x50,0x90,0x13,0x14,0x12,0x11,0x12,0x14,0x11,0x10,
+0x40,0x40,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x44,0xe8,0x50,0x48,0x46,0x40,0x80,
+/* 14663 0x3947 "㥇" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x57,0x90,0x10,0x10,0x13,0x10,0x10,0x10,0x17,
+0x50,0x48,0x5e,0xe4,0x28,0x32,0xca,0x06,0x50,0x48,0x5e,0xe4,0x28,0x32,0xca,0x06,
+/* 14664 0x3948 "㥈" */
+0x10,0x10,0xfe,0x92,0x92,0x92,0x9a,0x94,0x10,0x11,0x08,0x48,0x48,0x48,0x87,0x00,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x84,0x84,0xfc,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 14665 0x3949 "㥉" */
+0x10,0x10,0x11,0x10,0x19,0x54,0x50,0x53,0x90,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 14666 0x394a "㥊" */
+0x20,0x27,0x24,0x24,0x34,0xaf,0xa4,0xa4,0xa4,0x27,0x24,0x24,0x24,0x24,0x2a,0x31,
+0x00,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0x4c,
+/* 14667 0x394b "㥋" */
+0x08,0x08,0x17,0x10,0x30,0x51,0x92,0x14,0x10,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x40,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc4,0x82,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14668 0x394c "㥌" */
+0x11,0x11,0x11,0x1a,0x54,0x54,0x52,0x90,0x17,0x10,0x11,0x12,0x14,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x04,0x84,0x94,0xa4,0x84,0xfc,0x84,0xc4,0xa4,0x94,0x84,0xa8,0x10,
+/* 14669 0x394d "㥍" */
+0x11,0x11,0x17,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x17,0x10,0x10,0x11,0x12,
+0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 14670 0x394e "㥎" */
+0x0c,0x70,0x11,0xfd,0x32,0x38,0x54,0x50,0x91,0x12,0x11,0x08,0x48,0x48,0x87,0x00,
+0x80,0x80,0xfc,0x24,0x24,0x44,0x44,0x84,0x04,0x28,0x10,0x84,0x92,0x12,0xf0,0x00,
+/* 14671 0x394f "㥏" */
+0x10,0x10,0x10,0x13,0x1a,0x56,0x52,0x53,0x92,0x12,0x12,0x17,0x10,0x10,0x11,0x12,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 14672 0x3950 "㥐" */
+0x01,0x02,0x0c,0x30,0xc7,0x00,0x3e,0x22,0x22,0x3e,0x00,0x02,0x51,0x51,0x90,0x0f,
+0x00,0x80,0x60,0x18,0xc6,0x00,0xf8,0x88,0x88,0xa8,0x90,0x00,0x04,0x12,0x12,0xf0,
+/* 14673 0x3951 "㥑" */
+0x00,0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x7f,0x41,0x88,0x48,0x48,0x87,0x00,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x02,0x84,0x92,0x12,0xf0,0x00,
+/* 14674 0x3952 "㥒" */
+0x10,0x10,0x13,0x10,0x1a,0x55,0x51,0x50,0x93,0x10,0x10,0x10,0x11,0x12,0x14,0x10,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 14675 0x3953 "㥓" */
+0x10,0x10,0x13,0x18,0x55,0x52,0x57,0x90,0x13,0x12,0x12,0x12,0x13,0x10,0x10,0x10,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 14676 0x3954 "㥔" */
+0x10,0x10,0x13,0x18,0x55,0x53,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 14677 0x3955 "㥕" */
+0x01,0x09,0x09,0x12,0x04,0x19,0x69,0x09,0x12,0x04,0x18,0x60,0x01,0x48,0x48,0x87,
+0x00,0x10,0x20,0xc0,0x30,0x08,0x14,0x10,0xa0,0x40,0x30,0x0c,0x00,0x84,0x12,0xf2,
+/* 14678 0x3956 "㥖" */
+0x00,0x78,0x49,0x49,0x6a,0x5c,0x48,0xfd,0x48,0x48,0x48,0x4a,0x4a,0x4c,0x88,0x18,
+0x90,0x90,0x08,0x08,0x44,0x52,0x88,0xf8,0x08,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 14679 0x3957 "㥗" */
+0x11,0x11,0x11,0x11,0x19,0x55,0x51,0x50,0x90,0x13,0x10,0x10,0x10,0x10,0x10,0x17,
+0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x40,0x20,0xfe,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 14680 0x3958 "㥘" */
+0x22,0x22,0x22,0x27,0x32,0xaa,0xa2,0xaf,0xa2,0x22,0x24,0x25,0x2f,0x24,0x20,0x20,
+0x00,0x00,0x7e,0x12,0x12,0x52,0x52,0xd2,0x52,0x92,0x12,0x12,0xa2,0xa2,0x4a,0x84,
+/* 14681 0x3959 "㥙" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x50,0x90,0x10,0x10,0x12,0x12,0x12,0x14,0x10,
+0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x20,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 14682 0x395a "㥚" */
+0x20,0x21,0x26,0x34,0xac,0xa7,0xa4,0xa4,0x27,0x24,0x20,0x20,0x21,0x22,0x24,0x28,
+0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x44,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 14683 0x395b "㥛" */
+0x10,0x13,0x10,0x18,0x54,0x53,0x52,0x92,0x12,0x12,0x13,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x08,0x10,0x20,0xae,0xa2,0xaa,0xa4,0xa4,0xaa,0x32,0xa0,0x40,0xfe,0x00,
+/* 14684 0x395c "㥜" */
+0x10,0x13,0x12,0x1b,0x56,0x53,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 14685 0x395d "㥝" */
+0x20,0x27,0x21,0x31,0xa9,0xa7,0xa4,0xa4,0x24,0x27,0x21,0x21,0x21,0x21,0x2a,0x24,
+0x00,0x7e,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x26,0x7c,0x04,0x04,0x04,0x04,
+/* 14686 0x395e "㥞" */
+0x11,0x10,0x10,0x13,0x18,0x54,0x51,0x52,0x90,0x11,0x12,0x10,0x11,0x16,0x10,0x10,
+0x04,0x88,0x00,0xfe,0x40,0xc2,0x22,0x54,0x98,0x38,0x54,0x94,0x12,0x10,0x50,0x20,
+/* 14687 0x395f "㥟" */
+0x11,0x11,0x12,0x13,0x18,0x57,0x50,0x51,0x96,0x10,0x11,0x16,0x10,0x11,0x16,0x10,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 14688 0x3960 "㥠" */
+0x10,0x13,0x10,0x19,0x55,0x51,0x52,0x94,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 14689 0x3961 "㥡" */
+0x10,0x13,0x12,0x13,0x1a,0x56,0x52,0x52,0x92,0x12,0x13,0x12,0x14,0x15,0x1a,0x10,
+0x00,0xfc,0x04,0xfc,0x00,0x98,0xe0,0x84,0x7c,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 14690 0x3962 "㥢" */
+0x11,0x10,0x10,0x17,0x18,0x54,0x53,0x52,0x92,0x13,0x12,0x13,0x12,0x12,0x13,0x12,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14691 0x3963 "㥣" */
+0x02,0x02,0x7f,0x04,0x09,0x37,0xc1,0x1f,0x01,0x0f,0x01,0x3f,0x01,0x48,0x48,0x87,
+0x00,0x00,0xfc,0x40,0x20,0xd8,0x06,0xf0,0x00,0xe0,0x00,0xf8,0x00,0x84,0x12,0xf2,
+/* 14692 0x3964 "㥤" */
+0x00,0x7e,0x14,0x08,0x7f,0x2a,0x49,0x88,0x28,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14693 0x3965 "㥥" */
+0x11,0x11,0x11,0x11,0x19,0x55,0x51,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x12,0x12,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 14694 0x3966 "㥦" */
+0x3f,0x20,0x2f,0x20,0x24,0x24,0x2a,0x31,0x22,0x24,0x3f,0x02,0x51,0x51,0x90,0x0f,
+0xfc,0x80,0xf8,0x80,0x90,0x90,0xa8,0x44,0x20,0x10,0xfe,0x00,0x04,0x12,0x12,0xf0,
+/* 14695 0x3967 "㥧" */
+0x10,0x13,0x10,0x10,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x10,0x10,0x11,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 14696 0x3968 "㥨" */
+0x10,0x10,0xfc,0x24,0x25,0x48,0x28,0x10,0x28,0x44,0x81,0x02,0x51,0x51,0x90,0x0f,
+0x20,0xf8,0x20,0x20,0xfc,0x00,0x20,0xf8,0x20,0x20,0xfc,0x00,0x04,0x12,0x12,0xf0,
+/* 14697 0x3969 "㥩" */
+0x10,0x10,0x13,0x18,0x54,0x57,0x50,0x90,0x11,0x13,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 14698 0x396a "㥪" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x51,0x52,0x90,0x17,0x10,0x11,0x11,0x10,0x11,0x16,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 14699 0x396b "㥫" */
+0x10,0x10,0x17,0x10,0x19,0x55,0x51,0x50,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14700 0x396c "㥬" */
+0x20,0x20,0x27,0x32,0xa9,0xa7,0xa4,0xa8,0x20,0x27,0x21,0x21,0x21,0x22,0x22,0x24,
+0x80,0x40,0xfc,0x08,0x10,0xfe,0x02,0x84,0x40,0xfc,0x00,0xf8,0x08,0x08,0x28,0x10,
+/* 14701 0x396d "㥭" */
+0x10,0x10,0x13,0x10,0x19,0x54,0x53,0x50,0x91,0x12,0x11,0x10,0x11,0x12,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0x24,0xa8,0x24,0x22,0xa0,0x40,
+/* 14702 0x396e "㥮" */
+0x10,0x10,0x11,0x12,0x19,0x55,0x50,0x51,0x92,0x11,0x12,0x15,0x11,0x10,0x11,0x12,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 14703 0x396f "㥯" */
+0x00,0x7f,0x11,0x08,0x3f,0x01,0xff,0x00,0x3f,0x00,0x1f,0x00,0x3f,0x02,0x51,0x9f,
+0x7c,0x80,0x08,0x90,0xf8,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x24,0xe4,
+/* 14704 0x3970 "㥰" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x90,0x13,0x11,0x10,0x10,0x10,0x10,0x13,
+0xa0,0x2e,0x22,0x22,0xae,0x22,0x22,0xfe,0x20,0xfe,0x04,0x88,0x50,0x20,0xd8,0x06,
+/* 14705 0x3971 "㥱" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x28,0x28,0xee,0x28,0x28,0xee,0x28,0x28,0xee,0x28,0x28,0x28,0xfe,0x00,
+/* 14706 0x3972 "㥲" */
+0x01,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x10,0x20,0x01,0x48,0x48,0x87,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x10,0x08,0x00,0x84,0x12,0xf2,
+/* 14707 0x3973 "㥳" */
+0x20,0x27,0x24,0x24,0x35,0xad,0xa5,0xa5,0xa5,0x25,0x24,0x24,0x29,0x2a,0x30,0x20,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 14708 0x3974 "㥴" */
+0x20,0x20,0x27,0x34,0xac,0xa5,0xa5,0xa5,0x25,0x25,0x25,0x29,0x2a,0x32,0x24,0x29,
+0x04,0x3e,0xe0,0x3e,0x20,0xfe,0x22,0x38,0xe2,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 14709 0x3975 "㥵" */
+0x20,0x27,0x24,0x25,0x34,0xac,0xa5,0xa4,0xa4,0x25,0x24,0x24,0x25,0x24,0x27,0x24,
+0x00,0xfe,0x02,0xfa,0x42,0xc2,0x2a,0x6a,0xb2,0x2a,0x6a,0xaa,0x22,0x42,0xfe,0x02,
+/* 14710 0x3976 "㥶" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x12,0x21,0xc9,0x28,0x28,0x47,0x00,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0x08,0x06,0x28,0x24,0xe4,0x00,
+/* 14711 0x3977 "㥷" */
+0x01,0x00,0x3f,0x20,0x2f,0x22,0x22,0x25,0x28,0x23,0x2c,0x20,0x4a,0x4a,0x92,0x01,
+0x00,0x80,0xfe,0x40,0xfe,0x48,0x48,0x54,0xa2,0x18,0x06,0x80,0x44,0x4a,0x0a,0xf8,
+/* 14712 0x3978 "㥸" */
+0x00,0xfd,0x85,0x85,0xfd,0x91,0x91,0x91,0xfd,0x90,0x90,0x90,0x95,0xb5,0xce,0x84,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,0x00,0x20,0x14,0x52,0x42,0x48,0x38,
+/* 14713 0x3979 "㥹" */
+0x10,0x54,0x38,0x11,0xfe,0x10,0x38,0x54,0x91,0x12,0x01,0x08,0x48,0x48,0x87,0x00,
+0x10,0x50,0x88,0x04,0xfa,0x48,0x48,0x88,0x28,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14714 0x397a "㥺" */
+0x10,0x10,0x11,0x18,0x54,0x53,0x50,0x91,0x13,0x10,0x13,0x12,0x12,0x12,0x17,0x10,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 14715 0x397b "㥻" */
+0x00,0x00,0x3f,0x20,0x2f,0x22,0x2f,0x22,0x2b,0x52,0x4a,0x84,0x01,0x48,0x48,0x87,
+0x28,0x24,0xfe,0xa0,0x24,0x24,0xa8,0x18,0x12,0xaa,0x46,0x82,0x00,0x84,0x12,0xf2,
+/* 14716 0x397c "㥼" */
+0x20,0x27,0x20,0x32,0xaa,0xaf,0xa1,0xa1,0x22,0x23,0x20,0x25,0x25,0x28,0x20,0x20,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 14717 0x397d "㥽" */
+0x10,0x13,0x10,0x19,0x54,0x53,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 14718 0x397e "㥾" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x92,0x12,0x13,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x48,0x48,0xfe,0x48,0x20,0xfe,0x40,0xfc,0x44,0x44,0x7c,0x00,0xfe,0x00,
+/* 14719 0x397f "㥿" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x81,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 14720 0x3980 "㦀" */
+0x20,0x24,0x22,0x31,0xa8,0xa0,0xa6,0xa2,0x22,0x22,0x22,0x22,0x22,0x22,0x25,0x28,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 14721 0x3981 "㦁" */
+0x00,0x27,0x10,0x13,0x02,0x73,0x12,0x13,0x10,0x17,0x28,0x47,0x01,0x48,0x48,0x87,
+0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x00,0x84,0x12,0xf2,
+/* 14722 0x3982 "㦂" */
+0x11,0x09,0x3f,0x20,0x4f,0x08,0x0f,0x01,0x3f,0x21,0x21,0x02,0x51,0x51,0x90,0x0f,
+0x10,0x20,0xfc,0x04,0xe8,0x20,0xe0,0x00,0xf8,0x08,0x18,0x00,0x04,0x12,0x12,0xf0,
+/* 14723 0x3983 "㦃" */
+0x10,0x10,0x13,0x18,0x55,0x50,0x53,0x92,0x12,0x12,0x13,0x12,0x12,0x14,0x14,0x19,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 14724 0x3984 "㦄" */
+0x01,0x00,0x3f,0x22,0x22,0x2f,0x22,0x27,0x2a,0x32,0x20,0x20,0x4a,0x4a,0x91,0x00,
+0x00,0x80,0xfe,0x20,0x20,0x7c,0x20,0x70,0xa8,0x24,0x80,0x48,0x44,0x14,0xf0,0x00,
+/* 14725 0x3985 "㦅" */
+0x22,0x22,0x27,0x32,0xaa,0xa4,0xa8,0xa7,0x24,0x20,0x23,0x22,0x22,0x22,0x22,0x20,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 14726 0x3986 "㦆" */
+0x10,0x10,0x10,0x1b,0x56,0x52,0x53,0x92,0x12,0x12,0x13,0x12,0x15,0x14,0x18,0x10,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 14727 0x3987 "㦇" */
+0x10,0x10,0x13,0x12,0x1a,0x57,0x52,0x52,0x93,0x12,0x12,0x12,0x12,0x14,0x14,0x18,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 14728 0x3988 "㦈" */
+0x22,0x21,0x20,0x27,0x30,0xab,0xa0,0xa7,0xa0,0x23,0x22,0x22,0x22,0x22,0x2f,0x20,
+0x08,0x10,0x00,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 14729 0x3989 "㦉" */
+0x10,0x13,0x10,0x19,0x54,0x53,0x52,0x91,0x10,0x11,0x11,0x11,0x11,0x10,0x13,0x10,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 14730 0x398a "㦊" */
+0x10,0x13,0x10,0x10,0x19,0x54,0x50,0x53,0x90,0x10,0x11,0x10,0x13,0x10,0x10,0x10,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 14731 0x398b "㦋" */
+0x20,0x20,0x27,0x31,0xaa,0xa4,0xa3,0xa0,0x27,0x20,0x23,0x2d,0x21,0x21,0x21,0x21,
+0x40,0x40,0xfc,0x10,0x48,0x46,0xf8,0x50,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 14732 0x398c "㦌" */
+0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,0x0c,0x70,0x1d,0xf0,0x1c,0x01,0x48,0x48,0x87,
+0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,0x20,0x3c,0xe2,0x22,0x1e,0x00,0x84,0x12,0xf2,
+/* 14733 0x398d "㦍" */
+0x10,0x13,0x12,0x12,0x1b,0x54,0x50,0x53,0x90,0x11,0x11,0x11,0x10,0x10,0x10,0x11,
+0x00,0xde,0x52,0x52,0xde,0x88,0x50,0xfe,0x20,0x24,0x24,0xfc,0x24,0x40,0x80,0x00,
+/* 14734 0x398e "㦎" */
+0x10,0x11,0x10,0x13,0x18,0x55,0x50,0x53,0x90,0x11,0x11,0x11,0x11,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 14735 0x398f "㦏" */
+0x20,0x27,0x24,0x27,0x34,0xac,0xa3,0xa0,0xa1,0x27,0x21,0x21,0x2f,0x21,0x22,0x24,
+0x00,0xbc,0xa4,0xbc,0x20,0xa4,0x9c,0x00,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0x04,
+/* 14736 0x3990 "㦐" */
+0x10,0x17,0x10,0x1b,0x54,0x53,0x50,0x93,0x12,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x14,0xfe,0x10,0xd0,0x10,0xd0,0x10,0xd0,0x50,0xd0,0x50,0xc8,0x4a,0xca,0x86,0x42,
+/* 14737 0x3991 "㦑" */
+0x20,0x27,0x20,0x31,0xaf,0xa4,0xa4,0xa7,0x24,0x27,0x24,0x24,0x27,0x2c,0x20,0x20,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 14738 0x3992 "㦒" */
+0x10,0x13,0x12,0x12,0x1b,0x54,0x53,0x50,0x91,0x10,0x11,0x10,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x52,0x52,0xfe,0x20,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x04,
+/* 14739 0x3993 "㦓" */
+0x11,0x11,0x11,0x12,0x1a,0x55,0x50,0x52,0x91,0x11,0x12,0x14,0x10,0x12,0x12,0x14,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 14740 0x3994 "㦔" */
+0x3e,0x22,0x3e,0x22,0x3e,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x27,0x48,0x48,0x87,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 14741 0x3995 "㦕" */
+0x20,0x27,0x25,0x25,0x35,0xae,0xa5,0xa5,0xa5,0x25,0x25,0x26,0x24,0x24,0x24,0x24,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0x46,0x38,0x10,0x50,0x7e,0x90,0x7c,0x10,0xfe,
+/* 14742 0x3996 "㦖" */
+0x20,0x27,0x24,0x27,0x34,0xaf,0xa4,0xa4,0xa4,0x25,0x25,0x25,0x26,0x24,0x24,0x24,
+0x00,0x9e,0x92,0x9e,0x92,0x9e,0x42,0x22,0x0a,0x46,0x42,0x52,0x32,0x02,0x0a,0x04,
+/* 14743 0x3997 "㦗" */
+0x21,0x21,0x27,0x31,0xab,0xa5,0xa9,0xa0,0x23,0x20,0x27,0x20,0x22,0x24,0x29,0x20,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 14744 0x3998 "㦘" */
+0x10,0x7e,0x42,0x7e,0x42,0x7e,0x10,0xff,0x20,0x3e,0x42,0x86,0x01,0x48,0x48,0x87,
+0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 14745 0x3999 "㦙" */
+0x11,0x11,0x11,0x19,0x55,0x50,0x53,0x92,0x12,0x12,0x12,0x10,0x10,0x12,0x12,0x14,
+0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x2a,0xfa,0x0a,0x46,0x20,0xa4,0x8a,0x8a,0x78,
+/* 14746 0x399a "㦚" */
+0x40,0x20,0x21,0xf8,0x00,0x50,0x22,0xfa,0x22,0x2a,0x7a,0x2a,0x2a,0x52,0x41,0x80,
+0x10,0x08,0x08,0xbe,0x80,0x14,0x08,0x3e,0x08,0x48,0x3c,0xa8,0xa8,0x88,0x88,0x08,
+/* 14747 0x399b "㦛" */
+0x0a,0x33,0x22,0x3b,0x20,0x3a,0x22,0xff,0x08,0x12,0x21,0xc9,0x28,0x28,0x47,0x00,
+0x00,0xb8,0x08,0xb8,0x88,0xb8,0x88,0xfe,0x20,0x10,0x08,0x06,0x28,0x24,0xe4,0x00,
+/* 14748 0x399c "㦜" */
+0x21,0x27,0x21,0x22,0x37,0xaa,0xa3,0xa2,0xa3,0x22,0x23,0x22,0x27,0x21,0x20,0x2f,
+0x08,0xfe,0x48,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x10,0xe0,0x1e,
+/* 14749 0x399d "㦝" */
+0x3c,0xd0,0x4d,0x31,0xc9,0x15,0x25,0xcc,0x14,0x24,0xd5,0x0a,0x01,0x48,0x48,0x87,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x50,0x50,0x92,0x0e,0x00,0x00,0x84,0x12,0xf2,
+/* 14750 0x399e "㦞" */
+0x01,0x7f,0x01,0x3f,0x00,0xff,0x00,0x3f,0x01,0xff,0x00,0x7d,0x44,0x7d,0x48,0x87,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x02,0xf0,0x00,0xfe,0x10,0xfc,0x90,0x30,0x94,0xf2,
+/* 14751 0x399f "㦟" */
+0x31,0xcb,0x2d,0x31,0xc9,0x15,0x25,0xcc,0x15,0x24,0xd4,0x0b,0x01,0x48,0x48,0x87,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,0x84,0x12,0xf2,
+/* 14752 0x39a0 "㦠" */
+0x22,0x22,0x2a,0x26,0x32,0xaf,0xa0,0xa4,0xa2,0x2f,0x21,0x27,0x21,0x21,0x2e,0x20,
+0x84,0x84,0xa4,0xc4,0x9e,0xe4,0x04,0x54,0x8c,0xe4,0x04,0xc4,0x04,0xc4,0x14,0x08,
+/* 14753 0x39a1 "㦡" */
+0x24,0x24,0x28,0x3a,0xae,0xa4,0xaa,0xae,0x22,0x20,0x2f,0x20,0x21,0x22,0x2c,0x20,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 14754 0x39a2 "㦢" */
+0x11,0x11,0x11,0x12,0x18,0x54,0x53,0x52,0x93,0x12,0x13,0x12,0x12,0x13,0x12,0x10,
+0x08,0x08,0xee,0x94,0x42,0x00,0xde,0x52,0xd2,0x52,0xd2,0x1a,0x94,0x50,0x10,0x10,
+/* 14755 0x39a3 "㦣" */
+0x21,0x47,0x82,0x17,0x20,0x67,0xa4,0x27,0x21,0x27,0x29,0x2f,0x21,0x48,0x48,0x87,
+0x00,0x9c,0x80,0xc0,0x3e,0x88,0x88,0x88,0x08,0xc8,0x08,0xe8,0x10,0x84,0x12,0xf2,
+/* 14756 0x39a4 "㦤" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7d,0x44,0x7c,0x45,0x2f,0xf2,0x40,
+0x40,0x40,0x7c,0x84,0x28,0x20,0x20,0x50,0x88,0x26,0x10,0x54,0x42,0x4a,0x38,0x00,
+/* 14757 0x39a5 "㦥" */
+0x20,0x2f,0x28,0x27,0x30,0xab,0xa0,0xa7,0xa0,0x27,0x24,0x27,0x20,0x25,0x25,0x28,
+0x40,0xfe,0x42,0xfc,0x40,0xf8,0x40,0xfc,0x40,0xfc,0xa4,0xfc,0x40,0x24,0x2a,0xfa,
+/* 14758 0x39a6 "㦦" */
+0x20,0x27,0x24,0x37,0xac,0xa7,0xa4,0xa5,0x25,0x25,0x25,0x25,0x24,0x25,0x26,0x24,
+0x00,0x9e,0x92,0x9e,0x92,0x9e,0x82,0x32,0x12,0xb2,0x12,0xf2,0xa2,0x2a,0x1a,0x04,
+/* 14759 0x39a7 "㦧" */
+0x21,0x25,0x27,0x29,0x37,0xab,0xa5,0xa9,0xa3,0x22,0x22,0x23,0x22,0x22,0x23,0x22,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 14760 0x39a8 "㦨" */
+0x27,0x24,0x27,0x24,0x37,0xac,0xa5,0xa4,0xa5,0x25,0x25,0x25,0x25,0x24,0x25,0x24,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xf4,0x44,0xf4,0x54,0xf4,0x54,0xf4,0xe4,0x54,0x4c,
+/* 14761 0x39a9 "㦩" */
+0x20,0x2e,0x2a,0x2a,0x3a,0xac,0xaa,0xaa,0xaa,0x2a,0x2a,0x2c,0x28,0x28,0x29,0x2a,
+0x1c,0xe0,0x54,0x28,0x7c,0x10,0xfe,0x00,0xfc,0x04,0x7c,0x04,0xfc,0x14,0x4a,0x38,
+/* 14762 0x39aa "㦪" */
+0x22,0x22,0x23,0x36,0xaa,0xa2,0xa2,0xa2,0x25,0x28,0x20,0x23,0x21,0x20,0x23,0x2c,
+0x48,0xe8,0x08,0xea,0x1c,0xe8,0x08,0xe8,0xb4,0xe2,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 14763 0x39ab "㦫" */
+0x25,0x27,0x29,0x37,0xab,0xa5,0xa9,0xa3,0x22,0x23,0x22,0x23,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 14764 0x39ac "㦬" */
+0x20,0x27,0x24,0x24,0x37,0xaa,0xa2,0xa4,0xaf,0x22,0x24,0x2f,0x20,0x2a,0x2a,0x20,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 14765 0x39ad "㦭" */
+0x27,0x20,0x2f,0x28,0x33,0xa8,0xa3,0xa0,0xae,0x2a,0x2e,0x20,0x2f,0x22,0x25,0x2f,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xee,0xaa,0xee,0x00,0xfe,0x48,0x54,0xfe,
+/* 14766 0x39ae "㦮" */
+0x02,0x02,0x03,0x7e,0x02,0x03,0x3e,0x02,0x02,0x7f,0x01,0x01,0x01,0x0e,0x70,0x00,
+0x40,0x20,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfc,0x10,0x20,0x40,0x84,0x44,0x34,0x0c,
+/* 14767 0x39af "㦯" */
+0x00,0x00,0x00,0xff,0x00,0x08,0x08,0x10,0x22,0x7f,0x01,0x00,0x0f,0xf0,0x40,0x03,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 14768 0x39b0 "㦰" */
+0x22,0x22,0x22,0x55,0x88,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,
+0x50,0x48,0x48,0x40,0xc0,0x40,0xfe,0x40,0x40,0x24,0x28,0x12,0x32,0xca,0x06,0x02,
+/* 14769 0x39b1 "㦱" */
+0x00,0x00,0x7f,0x00,0x00,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,0x00,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 14770 0x39b2 "㦲" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x10,0x10,0x1f,0x11,0x11,0x11,0x21,0x25,0x42,0x80,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 14771 0x39b3 "㦳" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,0x00,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 14772 0x39b4 "㦴" */
+0x00,0x00,0x00,0xff,0x20,0x3e,0x42,0xb4,0x0c,0x32,0xc1,0x7e,0x42,0x42,0x7e,0x43,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 14773 0x39b5 "㦵" */
+0x08,0x48,0x48,0x7f,0x48,0x88,0x08,0xff,0x18,0x1c,0x2a,0x29,0x49,0x88,0x08,0x08,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0xa4,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14774 0x39b6 "㦶" */
+0x00,0x00,0x00,0xff,0x00,0x7f,0x10,0x22,0x7f,0x09,0x3e,0x08,0x0f,0xf0,0x00,0x03,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 14775 0x39b7 "㦷" */
+0x00,0xfc,0x04,0x68,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14776 0x39b8 "㦸" */
+0x08,0x08,0x0f,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x49,0x08,0xff,0x08,0x08,0x08,0x08,
+0x28,0x24,0xa4,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 14777 0x39b9 "㦹" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x01,0xfe,0x40,0x7e,0xaa,0x2a,0x4a,0x92,0x2a,0x45,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 14778 0x39ba "㦺" */
+0x00,0x7f,0x40,0x5f,0x40,0x7f,0x55,0x52,0x59,0x50,0x42,0x7f,0x52,0x4a,0x82,0x06,
+0x28,0xa4,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0xa8,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 14779 0x39bb "㦻" */
+0x00,0xef,0x21,0xa9,0x65,0xa9,0x21,0x10,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14780 0x39bc "㦼" */
+0x08,0x08,0x7f,0x10,0x3e,0x10,0xff,0x22,0x41,0x90,0x26,0x22,0x36,0x22,0x3e,0x22,
+0x28,0x24,0x24,0x20,0x2e,0x70,0xa0,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14781 0x39bd "㦽" */
+0x20,0x20,0xfc,0x23,0x40,0x7b,0x4a,0xcb,0x78,0x4b,0x48,0x7a,0x4d,0x4a,0x48,0x58,
+0x14,0x12,0x10,0xfe,0x10,0xd0,0x50,0xd2,0x12,0xd2,0x14,0xac,0x4a,0xaa,0x16,0x22,
+/* 14782 0x39be "㦾" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x24,0x24,0x27,0x3c,0x24,0x44,0x44,0x83,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x80,0x80,0xf0,0x90,0x90,0x92,0xb2,0x02,0xfe,0x00,
+/* 14783 0x39bf "㦿" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x21,0x22,0x22,0x44,0x48,0x90,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x80,0x80,0xf8,0xc0,0xa0,0xa0,0x90,0x88,0x84,0x80,
+/* 14784 0x39c0 "㧀" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x2f,0x22,0x22,0x23,0x22,0x44,0x44,0x88,0x13,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0xf0,0x10,0x20,0x38,0x88,0x50,0x20,0xd8,0x06,
+/* 14785 0x39c1 "㧁" */
+0x01,0x00,0x3f,0x20,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x21,0x42,0x44,0x8f,0x04,
+0x00,0x80,0xfc,0x04,0xfc,0x80,0x80,0xfc,0x80,0x80,0xfe,0x00,0x10,0x08,0xfc,0x04,
+/* 14786 0x39c2 "㧂" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x28,0x28,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x04,
+/* 14787 0x39c3 "㧃" */
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x12,0x1c,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0xb4,0xc4,0x84,0x04,0x04,0x04,0x04,
+/* 14788 0x39c4 "㧄" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 14789 0x39c5 "㧅" */
+0x10,0x10,0x11,0x10,0xfe,0x10,0x10,0x12,0x1c,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 14790 0x39c6 "㧆" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x10,0x50,0x20,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 14791 0x39c7 "㧇" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x74,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 14792 0x39c8 "㧈" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x10,0x14,0x19,0x31,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 14793 0x39c9 "㧉" */
+0x11,0x11,0x11,0x12,0xfc,0x11,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 14794 0x39ca "㧊" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 14795 0x39cb "㧋" */
+0x10,0x10,0x10,0x10,0xfc,0x13,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 14796 0x39cc "㧌" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x11,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x50,0x20,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 14797 0x39cd "㧍" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 14798 0x39ce "㧎" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x11,0x15,0x18,0x30,0xd0,0x10,0x11,0x12,0x50,0x20,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 14799 0x39cf "㧏" */
+0x20,0x23,0x22,0x22,0xfa,0x22,0x22,0x2a,0x32,0xe2,0x22,0x23,0x22,0x22,0xa2,0x42,
+0x00,0xfc,0x04,0x04,0x94,0x54,0x24,0x24,0x54,0x54,0x94,0x04,0x04,0x04,0x14,0x08,
+/* 14800 0x39d0 "㧐" */
+0x20,0x20,0x27,0x20,0xf8,0x24,0x22,0x2a,0x31,0xe1,0x22,0x22,0x24,0x28,0xa0,0x40,
+0x00,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa8,0x28,0x28,0x90,0x90,0xa8,0x28,0x44,0x82,
+/* 14801 0x39d1 "㧑" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x20,0x20,0xa0,0xa0,0x20,0xfe,0x22,0x22,0x42,0x52,0x4a,0x8a,0x82,0x02,0x14,0x08,
+/* 14802 0x39d2 "㧒" */
+0x20,0x20,0x20,0x23,0xfa,0x24,0x20,0x28,0x30,0xe0,0x20,0x21,0x21,0x21,0xa2,0x44,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 14803 0x39d3 "㧓" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x14,0x54,0x28,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 14804 0x39d4 "㧔" */
+0x20,0x20,0x20,0x20,0xfb,0x22,0x22,0x2a,0x32,0xe2,0x22,0x22,0x22,0x24,0xa4,0x48,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 14805 0x39d5 "㧕" */
+0x20,0x20,0x23,0x22,0xfa,0x22,0x22,0x2a,0x32,0xe2,0x23,0x22,0x20,0x20,0xa1,0x42,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 14806 0x39d6 "㧖" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x08,0x10,0x20,0x42,0x82,0x7e,0x00,
+/* 14807 0x39d7 "㧗" */
+0x10,0x10,0x10,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x17,0x52,0x20,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 14808 0x39d8 "㧘" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x80,0x88,0x90,0xe4,0x84,0x7c,0x00,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14809 0x39d9 "㧙" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x14,0x1a,0x32,0xd2,0x14,0x10,0x11,0x12,0x54,0x20,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 14810 0x39da "㧚" */
+0x10,0x10,0x13,0x11,0xfd,0x11,0x11,0x15,0x19,0x32,0xd2,0x12,0x12,0x12,0x53,0x22,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x90,0x50,0x50,0x10,0x12,0x92,0x12,0x0e,
+/* 14811 0x39db "㧛" */
+0x04,0x24,0x24,0x24,0x24,0x25,0x04,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x40,0x40,0x7c,0x80,0x90,0x08,0x08,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14812 0x39dc "㧜" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x53,0x20,
+0x00,0xfe,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,0xfe,0x00,
+/* 14813 0x39dd "㧝" */
+0x10,0x10,0x7e,0x12,0x22,0x2a,0x44,0x80,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x00,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14814 0x39de "㧞" */
+0x10,0x10,0x11,0x10,0xfc,0x11,0x10,0x14,0x18,0x30,0xd0,0x11,0x11,0x12,0x54,0x20,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x40,0x40,0x7c,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 14815 0x39df "㧟" */
+0x22,0x21,0x21,0x24,0xfa,0x22,0x20,0x29,0x31,0xe2,0x26,0x22,0x22,0x22,0xa2,0x40,
+0x00,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,
+/* 14816 0x39e0 "㧠" */
+0x10,0x10,0x10,0x11,0xfb,0x10,0x14,0x18,0x31,0xd1,0x12,0x12,0x14,0x10,0x50,0x20,
+0x20,0x40,0x88,0x04,0xfe,0x02,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 14817 0x39e1 "㧡" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x15,0x18,0x30,0xd0,0x13,0x10,0x10,0x50,0x23,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 14818 0x39e2 "㧢" */
+0x20,0x27,0x24,0x24,0xfc,0x24,0x27,0x2c,0x34,0xe4,0x24,0x25,0x26,0x24,0xa7,0x44,
+0x00,0xfc,0x04,0x44,0x44,0x44,0xfc,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0xfc,0x04,
+/* 14819 0x39e3 "㧣" */
+0x10,0x11,0x11,0x11,0xfd,0x12,0x10,0x13,0x18,0x30,0xd0,0x11,0x11,0x12,0x50,0x20,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 14820 0x39e4 "㧤" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x15,0x1b,0x30,0xd0,0x10,0x10,0x11,0x11,0x52,0x24,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 14821 0x39e5 "㧥" */
+0x10,0x11,0x11,0x11,0xfd,0x12,0x10,0x13,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 14822 0x39e6 "㧦" */
+0x20,0x20,0x21,0x21,0xfa,0x24,0x23,0x2a,0x32,0xe3,0x22,0x22,0x23,0x20,0xa0,0x40,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 14823 0x39e7 "㧧" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x13,0x10,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 14824 0x39e8 "㧨" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 14825 0x39e9 "㧩" */
+0x20,0x27,0x24,0x24,0xf5,0x24,0x24,0x25,0x35,0xe5,0x25,0x25,0x25,0x24,0xa4,0x48,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0x44,0xf4,0x54,0x54,0x54,0x54,0x74,0x46,0x46,0x42,
+/* 14826 0x39ea "㧪" */
+0x10,0x10,0x10,0x11,0xfa,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x12,0x52,0x24,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 14827 0x39eb "㧫" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 14828 0x39ec "㧬" */
+0x00,0x7d,0x11,0x11,0x1d,0xf2,0x44,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x00,0xf0,0x10,0x90,0x52,0x0e,0x00,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14829 0x39ed "㧭" */
+0x7c,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0xfc,0x88,0x90,0x88,0x84,0x94,0x88,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14830 0x39ee "㧮" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x00,0x40,0x9c,0x04,0x04,0x04,0x04,0xdc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 14831 0x39ef "㧯" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x13,0x10,0x18,0x31,0xd2,0x14,0x10,0x10,0x50,0x20,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 14832 0x39f0 "㧰" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x13,0x18,0x30,0xd1,0x11,0x12,0x14,0x50,0x20,
+0x08,0x3c,0xc0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 14833 0x39f1 "㧱" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x08,0x1c,0x70,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 14834 0x39f2 "㧲" */
+0x20,0x20,0x27,0x24,0xf8,0x20,0x20,0x2b,0x30,0xe1,0x21,0x22,0x24,0x28,0xa0,0x40,
+0x80,0x40,0xfc,0x04,0x48,0x40,0x40,0xfc,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 14835 0x39f3 "㧳" */
+0x10,0xfd,0x12,0x1c,0xf0,0x11,0x32,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x88,0x04,0xfa,0x48,0x88,0x28,0x10,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14836 0x39f4 "㧴" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x10,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x52,0x21,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 14837 0x39f5 "㧵" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x13,0x10,0x18,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 14838 0x39f6 "㧶" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x33,0xd0,0x10,0x10,0x11,0x56,0x20,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xfa,0x0a,0x0c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 14839 0x39f7 "㧷" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x20,0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 14840 0x39f8 "㧸" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x18,0x33,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x08,0x30,0x20,0x20,0xa0,0x40,
+/* 14841 0x39f9 "㧹" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x15,0x18,0x33,0xd0,0x11,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x08,0xfe,0x08,0x08,0x88,0x08,0x28,0x10,
+/* 14842 0x39fa "㧺" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x12,0x10,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14843 0x39fb "㧻" */
+0x10,0x13,0x10,0x10,0xfd,0x12,0x10,0x12,0x19,0x32,0xd0,0x10,0x11,0x12,0x50,0x20,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 14844 0x39fc "㧼" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x10,0x14,0x1b,0x30,0xd0,0x11,0x12,0x14,0x50,0x20,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 14845 0x39fd "㧽" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 14846 0x39fe "㧾" */
+0x10,0x10,0x10,0x11,0xfa,0x10,0x15,0x1a,0x30,0xd1,0x10,0x10,0x12,0x12,0x54,0x20,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 14847 0x39ff "㧿" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x14,0x10,0x18,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x88,0x88,0x88,0x88,0x54,0x22,0x42,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 14848 0x3a00 "㨀" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x14,0x1b,0x30,0xd1,0x10,0x10,0x11,0x16,0x50,0x20,
+0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 14849 0x3a01 "㨁" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x57,0x20,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 14850 0x3a02 "㨂" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x19,0x30,0xd0,0x10,0x11,0x16,0x50,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 14851 0x3a03 "㨃" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x14,0x19,0x30,0xd0,0x13,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 14852 0x3a04 "㨄" */
+0x20,0x27,0x24,0x24,0xfd,0x24,0x24,0x2f,0x34,0xe5,0x25,0x25,0x25,0x24,0xa4,0x48,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 14853 0x3a05 "㨅" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x54,0x4c,0x84,0x04,0x04,0x14,0x08,
+/* 14854 0x3a06 "㨆" */
+0x21,0x21,0x21,0x21,0xf7,0x21,0x21,0x23,0x33,0xe5,0x25,0x29,0x21,0x21,0xa1,0x41,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 14855 0x3a07 "㨇" */
+0x10,0x49,0x21,0x09,0x71,0x12,0x14,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x20,0xfc,0x24,0xf8,0x48,0x30,0x4c,0xe0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 14856 0x3a08 "㨈" */
+0x10,0x10,0x17,0x11,0xf8,0x10,0x11,0x1e,0x31,0xd1,0x11,0x11,0x11,0x11,0x52,0x24,
+0x40,0x20,0xfe,0x08,0x90,0x60,0x98,0x06,0x08,0xf8,0x08,0xf8,0x08,0x08,0x08,0x08,
+/* 14857 0x3a09 "㨉" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x12,0x12,0x1b,0x30,0xd3,0x12,0x13,0x12,0x53,0x22,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 14858 0x3a0a "㨊" */
+0x10,0x10,0x13,0x10,0xfd,0x12,0x15,0x10,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 14859 0x3a0b "㨋" */
+0x10,0x10,0x13,0x10,0xf8,0x17,0x10,0x18,0x31,0xd3,0x15,0x11,0x11,0x11,0x51,0x21,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 14860 0x3a0c "㨌" */
+0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0x82,0x3c,0x08,0x7e,0x08,0x7f,0x08,0x28,0x11,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14861 0x3a0d "㨍" */
+0x08,0x3e,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 14862 0x3a0e "㨎" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd0,0x13,0x10,0x10,0x51,0x22,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 14863 0x3a0f "㨏" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x14,0x1b,0x30,0xd1,0x11,0x12,0x12,0x14,0x58,0x20,
+0x20,0x24,0x24,0x24,0xfc,0x80,0x80,0xfe,0x90,0x10,0x52,0x54,0xa8,0x28,0x44,0x82,
+/* 14864 0x3a10 "㨐" */
+0x21,0x21,0x21,0x22,0xf2,0x26,0x2a,0x22,0x32,0xe2,0x22,0x22,0x22,0x23,0xa2,0x42,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 14865 0x3a11 "㨑" */
+0x10,0x10,0x12,0x12,0xfe,0x12,0x12,0x17,0x18,0x31,0xd2,0x10,0x11,0x10,0x50,0x27,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 14866 0x3a12 "㨒" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x11,0x14,0x18,0x33,0xd0,0x10,0x11,0x10,0x50,0x23,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 14867 0x3a13 "㨓" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x12,0x11,0x19,0x32,0xd0,0x17,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 14868 0x3a14 "㨔" */
+0x20,0x20,0x20,0x27,0xf4,0x24,0x25,0x24,0x34,0xe5,0x25,0x25,0x25,0x24,0xa8,0x50,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 14869 0x3a15 "㨕" */
+0x10,0x13,0x11,0x11,0xf9,0x12,0x12,0x1a,0x34,0xd1,0x13,0x12,0x12,0x12,0x57,0x20,
+0x00,0xf8,0x08,0x10,0x1c,0xe4,0xa4,0x54,0xa8,0x00,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 14870 0x3a16 "㨖" */
+0x20,0x20,0x27,0x22,0xfa,0x24,0x27,0x29,0x31,0xe7,0x21,0x21,0x21,0x2e,0xa4,0x40,
+0x08,0x08,0xc8,0x10,0x1e,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x08,0xc8,0x14,0x14,0x22,
+/* 14871 0x3a17 "㨗" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x15,0x18,0x33,0xd0,0x12,0x12,0x12,0x15,0x54,0x28,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 14872 0x3a18 "㨘" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x14,0x19,0x36,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0xa4,0xa2,0x2a,0x10,0x60,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 14873 0x3a19 "㨙" */
+0x10,0x13,0x11,0x10,0xfc,0x10,0x11,0x14,0x18,0x31,0xd0,0x10,0x13,0x10,0x50,0x23,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 14874 0x3a1a "㨚" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x12,0x11,0x19,0x31,0xd1,0x11,0x11,0x10,0x50,0x20,
+0x90,0x90,0xfe,0x90,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 14875 0x3a1b "㨛" */
+0x10,0x13,0x12,0x13,0xfa,0x13,0x12,0x1a,0x32,0xd2,0x12,0x12,0x12,0x12,0x52,0x22,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x0a,0x04,
+/* 14876 0x3a1c "㨜" */
+0x10,0x10,0x10,0x13,0xfa,0x12,0x13,0x1a,0x32,0xd2,0x13,0x12,0x12,0x14,0x54,0x29,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x40,0x20,0xfe,0x88,0x50,0x20,0x58,0x86,
+/* 14877 0x3a1d "㨝" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x12,0x1a,0x32,0xd2,0x12,0x12,0x12,0x14,0x54,0x28,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x54,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x8a,0x84,
+/* 14878 0x3a1e "㨞" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x18,0x31,0xd0,0x13,0x10,0x11,0x52,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 14879 0x3a1f "㨟" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x13,0x14,0x19,0x31,0xd1,0x11,0x10,0x10,0x53,0x20,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 14880 0x3a20 "㨠" */
+0x10,0x13,0x12,0x10,0xfd,0x11,0x11,0x15,0x19,0x30,0xd0,0x13,0x10,0x10,0x51,0x22,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 14881 0x3a21 "㨡" */
+0x20,0x27,0x24,0x25,0xfc,0x24,0x25,0x2c,0x34,0xe5,0x24,0x24,0x25,0x24,0xa7,0x44,
+0x00,0xfe,0x02,0xfa,0x42,0xc2,0x2a,0x6a,0xb2,0x2a,0x6a,0xaa,0x22,0x42,0xfe,0x02,
+/* 14882 0x3a22 "㨢" */
+0x21,0x22,0x24,0x27,0xf8,0x20,0x27,0x2c,0x34,0xe7,0x24,0x24,0x27,0x24,0xa5,0x44,
+0x10,0x12,0x54,0xd8,0x10,0x12,0xd2,0x4e,0x40,0xd2,0x54,0x58,0xd0,0x52,0x52,0x8e,
+/* 14883 0x3a23 "㨣" */
+0x21,0x21,0x22,0x24,0xf9,0x23,0x20,0x28,0x37,0xe0,0x24,0x22,0x24,0x20,0xa2,0x41,
+0x20,0x10,0x08,0x86,0x10,0xf8,0x08,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 14884 0x3a24 "㨤" */
+0x20,0x27,0x24,0x24,0xfd,0x26,0x24,0x2c,0x34,0xe4,0x24,0x24,0x24,0x24,0xa7,0x40,
+0x00,0xfe,0x50,0x88,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,0x00,0xfe,0x00,
+/* 14885 0x3a25 "㨥" */
+0x20,0x21,0x21,0x22,0xf2,0x24,0x2f,0x21,0x32,0xe4,0x2f,0x20,0x20,0x2a,0xaa,0x48,
+0x08,0x08,0x08,0x08,0xbe,0xaa,0x2a,0x2a,0x2a,0xaa,0xb6,0xa2,0x22,0xa2,0xaa,0x24,
+/* 14886 0x3a26 "㨦" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x11,0x15,0x19,0x31,0xd3,0x11,0x10,0x10,0x51,0x26,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 14887 0x3a27 "㨧" */
+0x10,0x10,0x10,0x11,0xfc,0x13,0x10,0x15,0x1b,0x35,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x04,0xfe,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 14888 0x3a28 "㨨" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x13,0x10,0x1b,0x32,0xd2,0x13,0x12,0x12,0x53,0x22,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 14889 0x3a29 "㨩" */
+0x10,0x10,0x13,0x12,0xfa,0x12,0x12,0x1a,0x32,0xd2,0x12,0x12,0x12,0x14,0x54,0x29,
+0x40,0x20,0xfe,0x02,0xec,0x24,0x44,0x44,0xee,0x24,0xa4,0xa4,0x4e,0x60,0x9e,0x00,
+/* 14890 0x3a2a "㨪" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x15,0x18,0x30,0xd3,0x10,0x10,0x11,0x52,0x24,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 14891 0x3a2b "㨫" */
+0x20,0x22,0x22,0x22,0xfa,0x22,0x22,0x28,0x30,0xe3,0x22,0x22,0x22,0x22,0xaf,0x40,
+0x90,0x90,0x9c,0xa0,0xd0,0x88,0x88,0x80,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 14892 0x3a2c "㨬" */
+0x20,0x20,0x23,0x20,0xf7,0x20,0x23,0x22,0x32,0xe3,0x20,0x21,0x23,0x2d,0xa1,0x41,
+0x40,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x08,0xf8,0xa4,0x28,0x10,0x48,0x86,0x00,
+/* 14893 0x3a2d "㨭" */
+0x10,0x10,0x13,0x12,0xfb,0x12,0x12,0x1a,0x32,0xd2,0x13,0x13,0x15,0x15,0x59,0x20,
+0x40,0x20,0xfc,0x04,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x02,0x02,0xfe,
+/* 14894 0x3a2e "㨮" */
+0x20,0x22,0x24,0x24,0xf4,0x24,0x24,0x24,0x36,0xe4,0x21,0x21,0x21,0x21,0xa2,0x44,
+0x20,0x40,0xec,0xa4,0xa4,0xe4,0xa4,0xa4,0xe4,0x0c,0x10,0x10,0x10,0x12,0x12,0x0e,
+/* 14895 0x3a2f "㨯" */
+0x22,0x21,0x27,0x20,0xf7,0x24,0x27,0x20,0x37,0xe0,0x21,0x21,0x27,0x21,0xa5,0x42,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 14896 0x3a30 "㨰" */
+0x10,0x10,0x13,0x10,0xfd,0x12,0x10,0x15,0x18,0x30,0xd0,0x11,0x12,0x14,0x50,0x20,
+0x40,0x20,0xfe,0x88,0x24,0x42,0x90,0xf8,0x08,0x44,0xa8,0x90,0x88,0xa4,0xc2,0x80,
+/* 14897 0x3a31 "㨱" */
+0x20,0x20,0x21,0x26,0xf9,0x20,0x23,0x2f,0x30,0xe3,0x20,0x23,0x20,0x23,0xa2,0x43,
+0x40,0xfc,0x08,0x50,0x20,0xc0,0x20,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,
+/* 14898 0x3a32 "㨲" */
+0x21,0x21,0x27,0x21,0xf8,0x20,0x27,0x2c,0x34,0xe0,0x27,0x20,0x21,0x22,0xac,0x40,
+0x10,0x10,0xfc,0x10,0x40,0x20,0xfc,0x04,0x44,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 14899 0x3a33 "㨳" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x10,0x14,0x1b,0x30,0xd1,0x11,0x11,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x20,0xfc,0x50,0x88,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x28,0x10,
+/* 14900 0x3a34 "㨴" */
+0x21,0x21,0x21,0x2f,0xf1,0x27,0x24,0x27,0x34,0xe7,0x21,0x2f,0x21,0x21,0xa1,0x41,
+0x10,0x10,0x10,0xde,0x20,0xc0,0x5c,0xc4,0x48,0xc8,0x10,0xd0,0x22,0x22,0x1e,0x00,
+/* 14901 0x3a35 "㨵" */
+0x11,0x10,0x17,0x10,0xfb,0x12,0x13,0x1a,0x33,0xd2,0x12,0x10,0x13,0x10,0x51,0x26,
+0x08,0x90,0xfe,0x00,0xc4,0x54,0xd4,0x54,0xd4,0x44,0xcc,0x00,0xfc,0x84,0x14,0x08,
+/* 14902 0x3a36 "㨶" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x10,0x12,0x12,0x52,0x20,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 14903 0x3a37 "㨷" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x11,0x15,0x19,0x30,0xd3,0x10,0x11,0x10,0x53,0x20,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 14904 0x3a38 "㨸" */
+0x10,0x10,0x13,0x12,0xfc,0x12,0x12,0x14,0x18,0x33,0xd0,0x11,0x11,0x11,0x51,0x20,
+0x40,0x20,0xfe,0x42,0x28,0x94,0xaa,0xca,0xf8,0x00,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 14905 0x3a39 "㨹" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x10,0x14,0x1b,0x30,0xd0,0x11,0x10,0x10,0x53,0x20,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 14906 0x3a3a "㨺" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x14,0x1b,0x32,0xd3,0x12,0x13,0x12,0x12,0x52,0x22,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 14907 0x3a3b "㨻" */
+0x08,0x7f,0x08,0x3e,0x2a,0x3e,0x2a,0xff,0x08,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0xa8,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 14908 0x3a3c "㨼" */
+0x00,0x7c,0x55,0x54,0x7d,0x54,0x54,0x7c,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x40,0xf8,0x48,0x30,0xce,0xf8,0x88,0xf8,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 14909 0x3a3d "㨽" */
+0x20,0x27,0x20,0x23,0xfa,0x23,0x20,0x2f,0x35,0xe5,0x27,0x25,0x25,0x27,0xa4,0x40,
+0x04,0xc4,0x04,0x94,0x94,0x94,0x14,0xd4,0x54,0x54,0xd4,0x54,0x44,0xc4,0x54,0x08,
+/* 14910 0x3a3e "㨾" */
+0x22,0x21,0x27,0x20,0xfb,0x20,0x27,0x28,0x30,0xe1,0x20,0x27,0x21,0x22,0xad,0x40,
+0x08,0x10,0xfc,0x40,0xf8,0x40,0xfc,0x40,0x20,0xc0,0x44,0x68,0x50,0x48,0x46,0x80,
+/* 14911 0x3a3f "㨿" */
+0x20,0x20,0x20,0x27,0xf4,0x24,0x25,0x24,0x35,0xe5,0x25,0x26,0x2a,0x29,0xb2,0x44,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc2,0x3e,0x00,0x38,0xa8,0xaa,0xa6,0x40,0xfe,0x00,
+/* 14912 0x3a40 "㩀" */
+0x20,0x20,0x20,0x27,0xf4,0x24,0x25,0x24,0x34,0xe5,0x25,0x26,0x24,0x29,0xaa,0x50,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc2,0xbe,0x80,0xfc,0x54,0xd4,0xb4,0x2e,0x24,0x4c,
+/* 14913 0x3a41 "㩁" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x11,0x15,0x1b,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x20,0xfe,0x02,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 14914 0x3a42 "㩂" */
+0x22,0x22,0x27,0xf4,0x29,0x27,0x25,0x35,0xe7,0x25,0x25,0x27,0x25,0x25,0xa4,0x48,
+0x04,0x04,0x84,0x94,0x0c,0xc4,0x64,0x54,0xc4,0x46,0x7c,0xc4,0x44,0x44,0x44,0xc4,
+/* 14915 0x3a43 "㩃" */
+0x20,0x20,0x27,0x24,0xfb,0x20,0x23,0x28,0x37,0xe1,0x22,0x24,0x20,0x21,0xa0,0x40,
+0x40,0x20,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0x04,0x62,0x10,0x80,0x60,0x10,
+/* 14916 0x3a44 "㩄" */
+0x10,0x11,0x11,0x11,0xfc,0x11,0x11,0x15,0x19,0x31,0xd0,0x10,0x12,0x12,0x54,0x20,
+0x20,0x24,0x24,0xfc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 14917 0x3a45 "㩅" */
+0x10,0x13,0x10,0x13,0xfe,0x12,0x13,0x10,0x1b,0x32,0xd2,0x13,0x12,0x12,0x53,0x22,
+0x00,0xfe,0x50,0xde,0x52,0x52,0xde,0x50,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 14918 0x3a46 "㩆" */
+0x22,0x21,0x2f,0x20,0xf0,0x27,0x24,0x24,0x37,0xe1,0x25,0x25,0x29,0x21,0xa5,0x42,
+0x14,0x12,0xd2,0x10,0x7e,0x90,0x90,0x90,0x90,0x28,0xa8,0x68,0x28,0x4a,0x4a,0x86,
+/* 14919 0x3a47 "㩇" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x14,0x1b,0x30,0xd1,0x11,0x11,0x11,0x11,0x50,0x23,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 14920 0x3a48 "㩈" */
+0x10,0x10,0x13,0x12,0xfd,0x11,0x14,0x1b,0x30,0xd1,0x10,0x11,0x12,0x14,0x50,0x20,
+0x40,0x20,0xfe,0x8a,0x04,0xfc,0x44,0xfe,0x44,0xfc,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 14921 0x3a49 "㩉" */
+0x20,0x20,0x21,0x26,0xf8,0x23,0x22,0x2b,0x30,0xe7,0x20,0x24,0x22,0x24,0xa2,0x41,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 14922 0x3a4a "㩊" */
+0x10,0x13,0x10,0x11,0xfc,0x11,0x11,0x15,0x19,0x30,0xd7,0x11,0x10,0x10,0x50,0x20,
+0x1c,0xe0,0x44,0x24,0x88,0xfc,0x54,0x54,0xfc,0x08,0xfe,0x08,0x88,0x88,0x28,0x10,
+/* 14923 0x3a4b "㩋" */
+0x20,0x23,0x20,0x27,0xf0,0x23,0x20,0x25,0x37,0xe4,0x27,0x24,0x27,0x25,0xa5,0x48,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 14924 0x3a4c "㩌" */
+0x10,0x17,0x10,0x13,0xfa,0x13,0x11,0x1b,0x35,0xd1,0x11,0x11,0x11,0x11,0x50,0x21,
+0x90,0xfc,0x94,0xfc,0x90,0xfe,0x12,0xfa,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,
+/* 14925 0x3a4d "㩍" */
+0x12,0x12,0x13,0x15,0xfc,0x10,0x13,0x10,0x1b,0x32,0xd2,0x12,0x10,0x11,0x56,0x20,
+0x10,0x10,0xde,0x28,0xa4,0x20,0xfe,0x20,0xfe,0x22,0x2a,0x74,0xa8,0x24,0x22,0x20,
+/* 14926 0x3a4e "㩎" */
+0x20,0x27,0x24,0x27,0xf4,0x27,0x20,0x27,0x34,0xe7,0x24,0x27,0x24,0x24,0xa4,0x45,
+0x08,0x88,0x8c,0x8a,0x88,0xbe,0x08,0x88,0x88,0x88,0x94,0x94,0x94,0x94,0x94,0xa2,
+/* 14927 0x3a4f "㩏" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x14,0x19,0x30,0xd3,0x10,0x12,0x12,0x54,0x20,
+0x00,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 14928 0x3a50 "㩐" */
+0x22,0x22,0x23,0x25,0xf8,0x20,0x23,0x28,0x37,0xe0,0x2f,0x20,0x22,0x21,0xa0,0x40,
+0x10,0x10,0xde,0x28,0xc4,0x40,0xfc,0x40,0xfc,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 14929 0x3a51 "㩑" */
+0x20,0x23,0x20,0x27,0xf1,0x22,0x2c,0x20,0x37,0xe0,0x23,0x20,0x27,0x20,0xa0,0x40,
+0x00,0xf8,0x80,0xfc,0x10,0x08,0xa6,0xa0,0xbc,0xa0,0xb8,0xa0,0xbc,0xa0,0xa0,0xa0,
+/* 14930 0x3a52 "㩒" */
+0x21,0x21,0x27,0x21,0xfb,0x25,0x29,0x28,0x33,0xe0,0x27,0x20,0x22,0x24,0xa9,0x40,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 14931 0x3a53 "㩓" */
+0x2c,0x44,0x6c,0x44,0x7d,0x00,0x7c,0x10,0xfc,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xa4,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 14932 0x3a54 "㩔" */
+0x40,0x4f,0x48,0x48,0xef,0x4a,0x4a,0x4f,0x6a,0xca,0x4f,0x48,0x52,0x52,0x64,0xc8,
+0x00,0xdc,0x54,0x54,0xd4,0x94,0xa6,0xc0,0x9c,0x94,0xd4,0x14,0x88,0x48,0x54,0x22,
+/* 14933 0x3a55 "㩕" */
+0x10,0x11,0x10,0x13,0xfa,0x11,0x14,0x19,0x30,0xd0,0x13,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x50,0xc8,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 14934 0x3a56 "㩖" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x15,0x1b,0x30,0xd1,0x11,0x11,0x11,0x11,0x50,0x23,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 14935 0x3a57 "㩗" */
+0x24,0x27,0x21,0x23,0xf6,0x2b,0x22,0x23,0x32,0xe3,0x22,0x27,0x21,0x21,0xa2,0x4c,
+0x44,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x08,0x1e,0x02,0x1c,
+/* 14936 0x3a58 "㩘" */
+0x11,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x30,0xd3,0x10,0x10,0x13,0x50,0x21,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 14937 0x3a59 "㩙" */
+0x20,0x20,0x27,0x25,0xfb,0x21,0x27,0x29,0x37,0xe1,0x22,0x25,0x28,0x20,0xa7,0x40,
+0x80,0x40,0xfe,0x12,0xfc,0x10,0xfc,0x10,0xfe,0x10,0x48,0xf4,0x42,0x40,0xfc,0x00,
+/* 14938 0x3a5a "㩚" */
+0x21,0x27,0x21,0x27,0xf4,0x23,0x20,0x27,0x30,0xe1,0x26,0x21,0x26,0x21,0xa6,0x40,
+0x10,0xfc,0x10,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x44,0xa8,0x70,0xa8,0x26,0xa0,0x40,
+/* 14939 0x3a5b "㩛" */
+0x27,0x24,0x27,0xf4,0x25,0x25,0x25,0x35,0xe5,0x24,0x27,0x24,0x27,0x25,0xa4,0x47,
+0xfc,0x44,0xfc,0x44,0xf4,0x54,0xf4,0x54,0xf4,0x4c,0xfc,0x14,0xfc,0x14,0xb4,0xfc,
+/* 14940 0x3a5c "㩜" */
+0x20,0x27,0x25,0x27,0xf4,0x27,0x25,0x27,0x30,0xe3,0x22,0x22,0x22,0x22,0xaf,0x40,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 14941 0x3a5d "㩝" */
+0x20,0x27,0x20,0x21,0xf9,0x21,0x20,0x2f,0x34,0xe3,0x21,0x26,0x21,0x26,0xa1,0x4e,
+0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x80,0x44,0xb8,0x68,0xa6,0x60,
+/* 14942 0x3a5e "㩞" */
+0x21,0x25,0x25,0x29,0xf2,0x24,0x20,0x27,0x34,0xe0,0x27,0x20,0x21,0x22,0xac,0x40,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0x00,0xfc,0x44,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 14943 0x3a5f "㩟" */
+0x10,0x10,0x13,0x12,0xfd,0x10,0x11,0x14,0x1b,0x30,0xd1,0x12,0x10,0x11,0x52,0x20,
+0x40,0x20,0xfe,0x52,0xfc,0x50,0xfc,0x50,0xfe,0x88,0x24,0xfa,0x20,0x24,0xa2,0x40,
+/* 14944 0x3a60 "㩠" */
+0x20,0x20,0x27,0x24,0xf7,0x24,0x27,0x24,0x35,0xe5,0x25,0x25,0x25,0x28,0xaa,0x54,
+0x80,0x40,0xfc,0xa0,0xfc,0xa4,0xfc,0x00,0x24,0xa8,0x30,0xa4,0x1c,0x00,0xa4,0x52,
+/* 14945 0x3a61 "㩡" */
+0x20,0x27,0x21,0xf3,0x25,0x21,0x21,0x30,0xef,0x22,0x27,0x24,0x2c,0x24,0xa7,0x44,
+0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xbe,0x08,0x9e,0x92,0xb2,0x92,0x9e,0x92,
+/* 14946 0x3a62 "㩢" */
+0x21,0x27,0x21,0x20,0xfb,0x22,0x22,0x2b,0x30,0xe3,0x22,0x23,0x22,0x22,0xa4,0x48,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 14947 0x3a63 "㩣" */
+0x27,0x24,0x22,0xf4,0x2f,0x28,0x27,0x30,0xe3,0x22,0x23,0x22,0x23,0x20,0xa7,0x40,
+0xbc,0xa4,0x94,0xa4,0xfe,0x42,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,
+/* 14948 0x3a64 "㩤" */
+0x21,0x27,0x21,0x27,0xf5,0x27,0x25,0x27,0x35,0xe1,0x27,0x22,0x23,0x22,0xa5,0x48,
+0x48,0xc8,0x08,0xd0,0x5e,0xe4,0x54,0xd4,0x54,0x14,0xd4,0x08,0xc8,0x54,0x54,0xa2,
+/* 14949 0x3a65 "㩥" */
+0x21,0x21,0x27,0x21,0xf1,0x2f,0x22,0x26,0x32,0xe6,0x22,0x26,0x22,0x22,0xaf,0x40,
+0x14,0x12,0xd2,0x10,0x10,0xfe,0x90,0xd2,0x92,0xd2,0x94,0xd4,0x8a,0xca,0x16,0x22,
+/* 14950 0x3a66 "㩦" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x11,0x15,0x19,0x31,0xd3,0x12,0x12,0x13,0x52,0x22,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfe,0x52,0x8a,0x76,0x52,0x76,
+/* 14951 0x3a67 "㩧" */
+0x11,0x11,0x11,0x11,0xfd,0x10,0x11,0x14,0x1b,0x30,0xd1,0x12,0x10,0x10,0x51,0x20,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 14952 0x3a68 "㩨" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x10,0x17,0x18,0x31,0xd0,0x13,0x10,0x12,0x52,0x24,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 14953 0x3a69 "㩩" */
+0x24,0x24,0x25,0x26,0xf4,0x24,0x23,0x21,0x31,0xed,0x25,0x25,0x29,0x29,0xb5,0x42,
+0x00,0x9e,0x04,0x08,0x5e,0x52,0xd2,0x1e,0x12,0x5e,0x52,0x92,0x5e,0x20,0x2c,0x12,
+/* 14954 0x3a6a "㩪" */
+0x21,0x21,0x22,0x22,0xf4,0x2f,0x21,0x22,0x34,0xef,0x20,0x20,0x2a,0x2a,0xa8,0x40,
+0x00,0x3e,0x08,0x90,0xbe,0x22,0x22,0x3e,0xa2,0xbe,0xa2,0x22,0xbe,0x80,0x14,0x22,
+/* 14955 0x3a6b "㩫" */
+0x20,0x23,0x22,0x23,0xfa,0x22,0x24,0x2b,0x32,0xe3,0x22,0x23,0x22,0x23,0xa1,0x42,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 14956 0x3a6c "㩬" */
+0x21,0x21,0x21,0x27,0xf5,0x25,0x27,0x24,0x34,0xe5,0x27,0x25,0x25,0x29,0xa7,0x40,
+0x08,0xcc,0x0a,0xe8,0x2e,0xd8,0x48,0xca,0x0a,0x4c,0x6c,0x48,0x4a,0x7a,0xa6,0x42,
+/* 14957 0x3a6d "㩭" */
+0x22,0x24,0x24,0x26,0xf4,0x26,0x24,0x2f,0x38,0xe3,0x20,0x20,0x27,0x20,0xa1,0x40,
+0xa0,0x4c,0xa4,0x0c,0xa4,0x4c,0xa4,0xfe,0x02,0xf0,0x20,0x40,0xfc,0x40,0x40,0x80,
+/* 14958 0x3a6e "㩮" */
+0x21,0x22,0x22,0x23,0xfa,0x23,0x22,0x2f,0x31,0xe2,0x24,0x23,0x20,0x27,0xa0,0x40,
+0x40,0x6c,0x44,0x6c,0xa4,0xac,0xa4,0xfe,0x08,0xf4,0x42,0xf8,0x40,0xfc,0x40,0xc0,
+/* 14959 0x3a6f "㩯" */
+0x22,0x23,0x24,0x2f,0xf5,0x2f,0x25,0x27,0x31,0xe2,0x27,0x20,0x27,0x20,0xa3,0x44,
+0x10,0xd0,0x1e,0xe4,0x54,0xf4,0x48,0xd4,0xb2,0x20,0xc0,0x88,0xfc,0x44,0x50,0x88,
+/* 14960 0x3a70 "㩰" */
+0x21,0x27,0x21,0x23,0xfa,0x23,0x20,0x2f,0x34,0xe7,0x20,0x2f,0x21,0x22,0xac,0x40,
+0x10,0xfe,0x10,0xf8,0x08,0xf8,0x00,0xbc,0xa4,0xbc,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 14961 0x3a71 "㩱" */
+0x10,0x13,0x11,0x10,0xfb,0x12,0x17,0x18,0x33,0xd2,0x13,0x12,0x13,0x12,0x52,0x23,
+0x1e,0xe0,0x22,0x94,0xfe,0x52,0xfe,0x04,0xc4,0x7e,0xc4,0x54,0xcc,0x84,0xd4,0x48,
+/* 14962 0x3a72 "㩲" */
+0x21,0x2f,0x21,0x27,0xfc,0x27,0x21,0x29,0x33,0xe2,0x27,0x2a,0x23,0x22,0xa3,0x42,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 14963 0x3a73 "㩳" */
+0x21,0x22,0x23,0x26,0xfb,0x22,0x23,0x2a,0x33,0xe2,0x27,0x21,0x20,0x20,0xa1,0x46,
+0x08,0x94,0xde,0xb4,0xde,0x94,0xde,0x94,0xde,0x10,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 14964 0x3a74 "㩴" */
+0x27,0x24,0x27,0x24,0xf7,0x24,0x27,0x21,0x33,0xe2,0x27,0x2a,0x23,0x22,0xa3,0x42,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 14965 0x3a75 "㩵" */
+0x21,0x21,0x21,0x2f,0xf9,0x2b,0x29,0x2f,0x39,0xeb,0x2a,0x2b,0x2a,0x2b,0xaa,0x52,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 14966 0x3a76 "㩶" */
+0x22,0x23,0x25,0x20,0xf7,0x22,0x27,0x2c,0x36,0xe5,0x26,0x25,0x26,0x24,0xa4,0x44,
+0x10,0xde,0x28,0x84,0xfe,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 14967 0x3a77 "㩷" */
+0x20,0x27,0x24,0x23,0xf8,0x23,0x20,0x2f,0x31,0xe3,0x25,0x21,0x21,0x21,0xa0,0x45,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0xfc,0x22,0xf8,0x20,0xfe,0x02,0x56,
+/* 14968 0x3a78 "㩸" */
+0x11,0x11,0x11,0x11,0xfb,0x12,0x17,0x1a,0x33,0xd0,0x13,0x12,0x10,0x11,0x50,0x23,
+0xfc,0x24,0xfc,0x24,0xfe,0xaa,0xfe,0xaa,0xfe,0x20,0xfe,0x42,0xf8,0x50,0x20,0xfe,
+/* 14969 0x3a79 "㩹" */
+0x11,0x11,0x11,0x11,0xfb,0x12,0x17,0x1a,0x33,0xd0,0x13,0x12,0x10,0x10,0x50,0x23,
+0xfc,0x24,0xfc,0x24,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x8a,0xf8,0x88,0x88,0xfe,
+/* 14970 0x3a7a "㩺" */
+0x00,0x04,0x44,0x44,0x44,0x44,0x44,0x77,0x44,0x44,0x44,0x44,0x55,0x66,0x44,0x01,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14971 0x3a7b "㩻" */
+0x20,0x20,0x7e,0x42,0x84,0x7f,0x40,0x5e,0x52,0x52,0x5a,0x54,0x50,0x94,0x98,0x11,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14972 0x3a7c "㩼" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x24,0xc8,0x1f,0x21,0xd2,0x0c,0x08,0x30,0xc1,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14973 0x3a7d "㩽" */
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x11,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14974 0x3a7e "㩾" */
+0x02,0x0f,0x78,0x08,0xff,0x2a,0x2a,0xff,0x2a,0x2a,0xff,0x08,0x08,0x0e,0x70,0x21,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14975 0x3a7f "㩿" */
+0x10,0x10,0x20,0x3f,0x40,0x80,0x3e,0x02,0x04,0x08,0x10,0x20,0x21,0x21,0x1f,0x00,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 14976 0x3a80 "㪀" */
+0x00,0x7c,0x10,0x10,0x10,0x11,0x12,0xfc,0x10,0x10,0x10,0x10,0x10,0x10,0x51,0x22,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 14977 0x3a81 "㪁" */
+0x08,0x08,0x14,0x14,0x22,0x52,0x88,0x08,0x00,0x7e,0x02,0x04,0x04,0x08,0x08,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14978 0x3a82 "㪂" */
+0x20,0x20,0x7f,0x80,0x00,0x7e,0x00,0x00,0xfc,0x04,0x04,0x05,0x05,0x03,0x01,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14979 0x3a83 "㪃" */
+0x00,0x00,0xff,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x04,
+0x10,0x10,0x90,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14980 0x3a84 "㪄" */
+0x28,0x28,0x28,0xfe,0x2a,0x2a,0xfe,0xa8,0xa8,0xff,0x29,0x29,0x2d,0x4a,0x48,0x89,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 14981 0x3a85 "㪅" */
+0x7f,0x01,0x3f,0x21,0x22,0x24,0x21,0x01,0x01,0x01,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0xfc,0x00,0xf8,0x08,0x88,0x48,0x18,0x00,0xfc,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 14982 0x3a86 "㪆" */
+0x02,0x07,0x78,0x48,0x48,0x48,0x7e,0x48,0x48,0x48,0x48,0x44,0x45,0x63,0x49,0x04,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14983 0x3a87 "㪇" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0x08,0x7f,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x81,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 14984 0x3a88 "㪈" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 14985 0x3a89 "㪉" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x3e,0x44,0xc4,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 14986 0x3a8a "㪊" */
+0x00,0x7e,0x12,0x12,0xff,0x12,0x12,0x7e,0x20,0x20,0x7e,0x62,0xa2,0x22,0x3e,0x22,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14987 0x3a8b "㪋" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x00,0x00,0x7f,0x08,0x08,0xff,0x08,0x08,0x08,0x08,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 14988 0x3a8c "㪌" */
+0x00,0xfc,0x04,0x68,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14989 0x3a8d "㪍" */
+0x08,0x08,0x7f,0x08,0x08,0x7f,0x41,0x82,0x3c,0x04,0x08,0x0f,0x78,0x08,0x28,0x10,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 14990 0x3a8e "㪎" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x14,0x12,0x21,0x41,0x80,
+0x10,0x10,0x10,0x9e,0x10,0x10,0xfc,0x44,0x44,0xc4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14991 0x3a8f "㪏" */
+0x10,0x20,0x7f,0x49,0x49,0x7f,0x49,0x51,0x7f,0x24,0x44,0xff,0x04,0x04,0x04,0x04,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 14992 0x3a90 "㪐" */
+0x08,0x04,0x3f,0x21,0x21,0x3f,0x24,0x26,0x25,0x3f,0x24,0x24,0x4a,0x49,0x91,0x20,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14993 0x3a91 "㪑" */
+0x08,0x08,0xff,0x14,0x22,0x49,0x88,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x0a,0x0c,0x08,
+0x10,0x10,0x90,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14994 0x3a92 "㪒" */
+0x10,0x67,0x41,0x41,0x77,0x41,0x41,0x7f,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14995 0x3a93 "㪓" */
+0x02,0x0f,0x78,0x08,0xff,0x08,0x2a,0x2a,0xeb,0x2a,0x2a,0x6b,0xaa,0x08,0x08,0x08,
+0x10,0x10,0x10,0x1e,0x90,0x10,0xfc,0x44,0xc4,0x44,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 14996 0x3a94 "㪔" */
+0x22,0x22,0x22,0x22,0xf7,0x22,0x22,0x66,0x77,0xaa,0xaa,0x32,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0x1e,0x90,0x10,0xfc,0x44,0x44,0xc4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14997 0x3a95 "㪕" */
+0x08,0x08,0x0f,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x49,0x08,0xff,0x08,0x08,0x08,0x08,
+0x10,0x10,0x9e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x90,0x10,0x28,0x44,0x82,
+/* 14998 0x3a96 "㪖" */
+0x00,0x7e,0x02,0x3e,0x02,0xff,0x08,0x09,0x49,0x2a,0x1c,0x2a,0xc9,0x09,0x28,0x10,
+0x10,0x10,0x10,0x1e,0x10,0x90,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 14999 0x3a97 "㪗" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 15000 0x3a98 "㪘" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x14,0x22,0x41,
+0x20,0x20,0x20,0x3e,0x44,0xc4,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 15001 0x3a99 "㪙" */
+0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x09,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 15002 0x3a9a "㪚" */
+0x24,0x24,0x7e,0x24,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x01,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 15003 0x3a9b "㪛" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15004 0x3a9c "㪜" */
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0x86,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15005 0x3a9d "㪝" */
+0x08,0x08,0xff,0x08,0x7f,0x49,0x6b,0x5d,0x49,0x7f,0x08,0x1c,0x2a,0x49,0x88,0x08,
+0x10,0x10,0x90,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15006 0x3a9e "㪞" */
+0x00,0xff,0x81,0xbd,0x81,0xbd,0x81,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15007 0x3a9f "㪟" */
+0x10,0x08,0xff,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 15008 0x3aa0 "㪠" */
+0x44,0x28,0x00,0xff,0x28,0xfe,0x2a,0xff,0x2a,0xfe,0x28,0x6c,0xaa,0x29,0x28,0x28,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15009 0x3aa1 "㪡" */
+0x10,0x08,0x7f,0x41,0x08,0x3e,0x08,0x3e,0x08,0x7f,0x08,0x3e,0x22,0x22,0x3e,0x22,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15010 0x3aa2 "㪢" */
+0x28,0x4b,0x49,0x49,0x6b,0x49,0x49,0x7f,0x08,0x7f,0x01,0x32,0x0c,0x12,0x61,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15011 0x3aa3 "㪣" */
+0x10,0x08,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x45,0x42,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 15012 0x3aa4 "㪤" */
+0x00,0x7f,0x49,0x7f,0x49,0x7f,0x2a,0x2a,0xff,0x2a,0x2a,0x7f,0x08,0xff,0x08,0x08,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0xa8,0x28,0x10,0x10,0x28,0xa8,0x44,0x82,
+/* 15013 0x3aa5 "㪥" */
+0x10,0x1e,0x10,0x7f,0x51,0x5c,0x72,0x4e,0x40,0x5f,0x51,0x5f,0x51,0x5f,0x51,0xbf,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15014 0x3aa6 "㪦" */
+0x10,0x08,0xff,0x81,0x00,0x7e,0x08,0x7e,0x4a,0x7e,0x4a,0x7e,0x00,0x24,0x42,0x81,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 15015 0x3aa7 "㪧" */
+0x08,0x14,0x22,0x5d,0x80,0x3e,0x22,0x3e,0x00,0x77,0x11,0x55,0x33,0x55,0x11,0x33,
+0x10,0x10,0x10,0x1e,0x90,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15016 0x3aa8 "㪨" */
+0x22,0x14,0xff,0x08,0x7f,0x08,0xff,0x49,0x2a,0xff,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x10,0x9e,0x10,0x10,0xfc,0xc4,0x44,0x44,0xa8,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 15017 0x3aa9 "㪩" */
+0x04,0x3f,0x04,0x7f,0x04,0x3f,0x04,0x55,0x75,0x44,0x7f,0x44,0x75,0x55,0x55,0x84,
+0x08,0x88,0x88,0xee,0x88,0x88,0x3c,0x54,0xd4,0x54,0xd4,0x48,0xc8,0x54,0x54,0x62,
+/* 15018 0x3aaa "㪪" */
+0x00,0x7f,0x10,0xff,0x22,0x41,0x94,0x14,0xf7,0x14,0x77,0x14,0xf7,0x14,0x14,0x14,
+0x10,0x10,0x10,0x9e,0x10,0x10,0xfc,0x44,0xc4,0x44,0x28,0x28,0x90,0x28,0x44,0x82,
+/* 15019 0x3aab "㪫" */
+0x10,0x1f,0x10,0xff,0x80,0x7f,0x2a,0x55,0xa2,0x7f,0xa2,0x3e,0x22,0x3e,0x22,0x3e,
+0x10,0x10,0x10,0x9e,0x90,0x10,0xfc,0x44,0x44,0x44,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 15020 0x3aac "㪬" */
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x00,0x24,0x7f,0xc8,0x7e,0x48,0x7e,0x48,0x7f,0x40,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15021 0x3aad "㪭" */
+0x10,0x1f,0x10,0xff,0x91,0xfc,0x91,0xbf,0xaa,0xbe,0xaa,0xbe,0x80,0x7f,0x55,0xff,
+0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 15022 0x3aae "㪮" */
+0x00,0x7f,0x04,0xff,0x84,0x35,0x04,0x35,0x00,0x00,0xee,0xaa,0xaa,0xaa,0xee,0xaa,
+0x08,0xc8,0x08,0xee,0x28,0x88,0x1c,0x94,0x14,0x14,0xf4,0xa8,0xa8,0xb4,0xf4,0xa2,
+/* 15023 0x3aaf "㪯" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe1,0x01,0x1f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 15024 0x3ab0 "㪰" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe1,0x11,0x09,0x05,0x7f,0x05,0x09,0x31,0xc1,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0x10,0x20,0x40,0xfc,0x40,0x20,0x18,0x06,
+/* 15025 0x3ab1 "㪱" */
+0x00,0x20,0x10,0x01,0xfe,0x09,0x09,0x49,0x29,0x11,0x13,0x28,0x28,0x48,0x81,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 15026 0x3ab2 "㪲" */
+0x00,0x04,0x02,0x12,0x08,0x08,0x01,0x7e,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,
+/* 15027 0x3ab3 "㪳" */
+0x00,0x04,0x02,0x12,0x08,0x09,0x7e,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,
+0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x00,0xf0,0x08,0x08,0x08,0xf0,0x00,
+/* 15028 0x3ab4 "㪴" */
+0x00,0x7c,0x00,0x00,0x00,0xfe,0x28,0x28,0x28,0x29,0x28,0x2a,0x4c,0x48,0x80,0x00,
+0x10,0x10,0x90,0x50,0x10,0x90,0x50,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15029 0x3ab5 "㪵" */
+0x10,0x10,0x94,0x58,0x10,0x7c,0x10,0x10,0xfe,0x11,0x10,0x10,0x20,0x20,0x40,0x80,
+0x10,0x10,0x90,0x50,0x10,0x90,0x50,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15030 0x3ab6 "㪶" */
+0x00,0xfe,0x10,0x10,0x20,0x7c,0x44,0x44,0x44,0x7d,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x10,0x10,0x90,0x50,0x10,0x90,0x50,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15031 0x3ab7 "㪷" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x01,0x44,0x24,0x28,0x0e,0xf0,0x40,
+0x10,0x10,0x90,0x50,0x10,0x90,0x50,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15032 0x3ab8 "㪸" */
+0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0xff,0x00,0x14,0x22,0x41,
+0x08,0x48,0xa8,0x28,0x08,0x48,0x28,0x28,0x0e,0x78,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 15033 0x3ab9 "㪹" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x08,0x48,0x28,0xa8,0x08,0x48,0x28,0x28,0x0e,0x78,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 15034 0x3aba "㪺" */
+0x08,0x08,0xff,0x08,0xeb,0xaa,0xeb,0xaa,0xeb,0xaa,0xeb,0x14,0x12,0x22,0x41,0x81,
+0x08,0x48,0xa8,0x28,0x88,0xc8,0xa8,0xa8,0x8e,0xf8,0x88,0x08,0x08,0x08,0x08,0x08,
+/* 15035 0x3abb "㪻" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x04,0x12,0x08,0xff,0x00,0x00,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x40,0x40,0x7e,0xc0,0x40,0x40,
+/* 15036 0x3abc "㪼" */
+0x00,0x00,0xff,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x14,0x09,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 15037 0x3abd "㪽" */
+0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x45,0x01,0x02,
+0x00,0xfe,0x00,0x0c,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 15038 0x3abe "㪾" */
+0x10,0x10,0x1e,0x22,0x62,0x94,0x08,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x3e,0x23,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 15039 0x3abf "㪿" */
+0x08,0x49,0x49,0x49,0x7f,0x10,0x20,0x48,0x88,0x49,0x49,0x7f,0x08,0x10,0x20,0x41,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 15040 0x3ac0 "㫀" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x01,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 15041 0x3ac1 "㫁" */
+0x11,0x91,0xaa,0xbb,0x91,0xaa,0xbb,0x80,0xff,0x92,0x92,0xa1,0x80,0xff,0x00,0x00,
+0x00,0x02,0xbc,0xa0,0x20,0xa0,0xbe,0x24,0xa4,0x24,0x24,0xa4,0x24,0xc4,0x44,0x84,
+/* 15042 0x3ac2 "㫂" */
+0x10,0x08,0x7f,0x40,0x52,0x52,0x7f,0x52,0x52,0x5e,0x40,0x55,0x55,0x55,0x80,0x01,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 15043 0x3ac3 "㫃" */
+0x20,0x10,0x10,0xff,0x20,0x20,0x3e,0x22,0x22,0x22,0x22,0x22,0x42,0x4a,0x85,0x02,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15044 0x3ac4 "㫄" */
+0x02,0x01,0xff,0x10,0x10,0x3f,0x48,0x84,0x7f,0x10,0x1f,0x10,0x20,0x20,0x42,0x81,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xe8,0x08,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 15045 0x3ac5 "㫅" */
+0x20,0x10,0x10,0x00,0xfd,0x22,0x20,0x3c,0x24,0x27,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,
+/* 15046 0x3ac6 "㫆" */
+0x20,0x10,0x00,0xfe,0x20,0x21,0x3e,0x24,0x24,0x24,0x25,0x25,0x46,0x54,0x88,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0x22,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 15047 0x3ac7 "㫇" */
+0x10,0x08,0xff,0x20,0x3e,0x22,0x22,0x42,0x4a,0x84,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x10,0x10,0x28,0x44,0x82,0x10,0x08,0x20,0x10,0x08,0x00,0xf8,0x08,0x08,0x08,0x08,
+/* 15048 0x3ac8 "㫈" */
+0x10,0x08,0xff,0x20,0x3e,0x22,0x22,0x42,0x4a,0x84,0x1f,0x20,0x20,0x20,0x1f,0x00,
+0x10,0x10,0x28,0x44,0x82,0x10,0x08,0x20,0x10,0x08,0xf0,0x08,0x08,0x08,0xf0,0x00,
+/* 15049 0x3ac9 "㫉" */
+0x20,0x10,0x10,0x01,0xfe,0x21,0x21,0x3d,0x25,0x25,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 15050 0x3aca "㫊" */
+0x21,0x11,0x11,0x02,0xfc,0x21,0x20,0x3c,0x25,0x25,0x25,0x25,0x25,0x44,0x54,0x88,
+0x00,0x00,0xfe,0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0xe8,0x08,0x28,0x10,
+/* 15051 0x3acb "㫋" */
+0x20,0x10,0x10,0x01,0xfe,0x21,0x21,0x3d,0x25,0x25,0x25,0x27,0x25,0x45,0x55,0x89,
+0x80,0x80,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfe,0x04,0x04,0x14,0x08,
+/* 15052 0x3acc "㫌" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x21,0x3c,0x24,0x24,0x24,0x24,0x24,0x44,0x55,0x88,
+0x80,0x80,0xfe,0x00,0x00,0x00,0xfe,0x10,0x10,0x90,0x9c,0x90,0x90,0x90,0xfe,0x00,
+/* 15053 0x3acd "㫍" */
+0x21,0x11,0x11,0x02,0xfc,0x20,0x21,0x3d,0x27,0x25,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0x00,0xfe,0x00,0x90,0x90,0x5e,0x64,0x54,0x54,0x54,0x48,0x48,0x54,0x14,0x22,
+/* 15054 0x3ace "㫎" */
+0x21,0x11,0x13,0xfc,0x23,0x22,0x39,0x28,0x29,0x29,0x29,0x29,0x29,0x48,0x5b,0x80,
+0x00,0x00,0xfe,0x00,0xfe,0x22,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,
+/* 15055 0x3acf "㫏" */
+0x21,0x11,0x11,0x02,0xfd,0x20,0x21,0x3d,0x25,0x25,0x24,0x27,0x24,0x45,0x54,0x8b,
+0x00,0x00,0xfe,0x00,0xfc,0x50,0xfc,0x54,0x54,0xfc,0x40,0xfe,0x88,0x90,0x70,0x8c,
+/* 15056 0x3ad0 "㫐" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0x20,0x23,0x3c,0x20,0x20,0x1f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x38,0xc0,0x04,0x04,0x04,0xfc,0x00,
+/* 15057 0x3ad1 "㫑" */
+0x00,0x00,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 15058 0x3ad2 "㫒" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 15059 0x3ad3 "㫓" */
+0x00,0x00,0x7c,0x44,0x45,0x46,0x44,0x7c,0x44,0x44,0x44,0x44,0x7d,0x45,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 15060 0x3ad4 "㫔" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x02,0x03,0x02,0x02,0x02,0xff,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 15061 0x3ad5 "㫕" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0x7f,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 15062 0x3ad6 "㫖" */
+0x02,0x02,0x03,0x02,0x02,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 15063 0x3ad7 "㫗" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x1f,0x00,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 15064 0x3ad8 "㫘" */
+0x00,0x7f,0x01,0x03,0x05,0x19,0xe1,0x01,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x00,0x00,0x70,0x0c,0x02,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 15065 0x3ad9 "㫙" */
+0x00,0x00,0x7c,0x44,0x45,0x44,0x44,0x7c,0x47,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15066 0x3ada "㫚" */
+0x08,0x1f,0x22,0x44,0x08,0x11,0x22,0x04,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x48,0x48,0x88,0x08,0x28,0x10,0xf0,0x10,0x10,0xd0,0x10,0x10,0xf0,0x10,
+/* 15067 0x3adb "㫛" */
+0x00,0x01,0x7d,0x45,0x45,0x45,0x45,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 15068 0x3adc "㫜" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x79,0x48,0x00,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 15069 0x3add "㫝" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 15070 0x3ade "㫞" */
+0x00,0x01,0x79,0x49,0x49,0x48,0x48,0x7b,0x49,0x48,0x48,0x48,0x78,0x48,0x01,0x06,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x20,0xfc,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 15071 0x3adf "㫟" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x45,0x7e,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x06,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 15072 0x3ae0 "㫠" */
+0x00,0x00,0x7d,0x44,0x44,0x44,0x45,0x7c,0x44,0x44,0x47,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 15073 0x3ae1 "㫡" */
+0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe3,0x00,0x0e,0x01,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xc0,0x00,0x80,0x40,
+/* 15074 0x3ae2 "㫢" */
+0x00,0x00,0x78,0x49,0x48,0x48,0x48,0x7b,0x48,0x48,0x48,0x48,0x79,0x4b,0x01,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 15075 0x3ae3 "㫣" */
+0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x01,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfa,0x02,0x02,0xfe,
+/* 15076 0x3ae4 "㫤" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x00,0x1f,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x80,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 15077 0x3ae5 "㫥" */
+0x00,0x00,0x7c,0x45,0x46,0x44,0x44,0x7c,0x44,0x45,0x46,0x44,0x7c,0x44,0x00,0x00,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 15078 0x3ae6 "㫦" */
+0x08,0x08,0x10,0x10,0x35,0x54,0x94,0x17,0x14,0x14,0x14,0x14,0x14,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,
+/* 15079 0x3ae7 "㫧" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x09,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x20,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 15080 0x3ae8 "㫨" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x78,0x4b,0x48,0x48,0x49,0x78,0x48,0x00,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 15081 0x3ae9 "㫩" */
+0x01,0x01,0x7f,0x01,0x08,0xff,0x08,0x08,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x00,0x20,0xfe,0x20,0x20,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 15082 0x3aea "㫪" */
+0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x30,0xd3,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 15083 0x3aeb "㫫" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x04,0x04,0x24,0x14,0x14,0x04,0xff,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x00,
+/* 15084 0x3aec "㫬" */
+0x00,0x00,0x79,0x49,0x4a,0x4c,0x7b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4b,0x00,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 15085 0x3aed "㫭" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3f,0x01,0xff,0x00,0x7f,0x08,0x04,0x01,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x40,0xfc,0x40,0x40,0x40,0x80,
+/* 15086 0x3aee "㫮" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 15087 0x3aef "㫯" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x04,0x18,0xe0,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0x42,0x3e,
+/* 15088 0x3af0 "㫰" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x80,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 15089 0x3af1 "㫱" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3f,0x01,0xff,0x04,0x24,0x44,0x88,0x11,0x20,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x40,0x48,0x44,0x42,0x40,0x80,
+/* 15090 0x3af2 "㫲" */
+0x00,0x00,0x7b,0x48,0x48,0x4b,0x7a,0x4c,0x49,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 15091 0x3af3 "㫳" */
+0x00,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x25,0x26,0x20,0x2f,0x28,0x4f,0x48,0x8f,0x08,
+0x00,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 15092 0x3af4 "㫴" */
+0x00,0x00,0x7b,0x48,0x48,0x4f,0x78,0x48,0x4b,0x49,0x4a,0x7d,0x48,0x00,0x00,0x00,
+0x40,0x44,0xf4,0x48,0x48,0xfe,0x20,0x40,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 15093 0x3af5 "㫵" */
+0x00,0x00,0x78,0x4f,0x48,0x48,0x48,0x7b,0x48,0x48,0x48,0x4f,0x78,0x48,0x00,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 15094 0x3af6 "㫶" */
+0x00,0x01,0x78,0x48,0x48,0x49,0x78,0x4b,0x4a,0x48,0x49,0x79,0x49,0x01,0x01,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 15095 0x3af7 "㫷" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x10,0x20,0xdf,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x10,0xf0,0x10,
+/* 15096 0x3af8 "㫸" */
+0x00,0x00,0xf7,0x90,0x93,0x90,0x97,0xf0,0x93,0x90,0x92,0x92,0xf2,0x95,0x04,0x08,
+0x40,0x40,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 15097 0x3af9 "㫹" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x06,0x38,0x20,0x3e,0x22,0x3e,0x20,0x20,0x40,0x81,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0x18,0xe0,0x80,0x80,0xfc,0x90,0x90,0x90,0x90,0x10,
+/* 15098 0x3afa "㫺" */
+0x08,0x08,0x08,0x14,0x22,0x49,0x08,0x14,0x22,0x41,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0x20,0x50,0x88,0x24,0x20,0x50,0x88,0x06,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 15099 0x3afb "㫻" */
+0x00,0x00,0xf0,0x91,0x92,0x9d,0x90,0xf7,0x94,0x94,0x97,0x94,0xf4,0x94,0x04,0x04,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 15100 0x3afc "㫼" */
+0x00,0x00,0x7a,0x4b,0x4c,0x48,0x4f,0x78,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x00,0x00,
+0x82,0x82,0x82,0xea,0x8a,0x8a,0xfa,0x8a,0xea,0xaa,0xaa,0xaa,0xa2,0xe2,0x8a,0x84,
+/* 15101 0x3afd "㫽" */
+0x00,0x01,0x78,0x48,0x49,0x48,0x48,0x7b,0x48,0x4a,0x49,0x48,0x79,0x4a,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 15102 0x3afe "㫾" */
+0x00,0x01,0x78,0x48,0x48,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 15103 0x3aff "㫿" */
+0x00,0x00,0x78,0x49,0x49,0x4b,0x4d,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 15104 0x3b00 "㬀" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x79,0x48,0x49,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 15105 0x3b01 "㬁" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x10,0x81,0x42,0x14,0x23,0xe2,0x22,0x23,0x22,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0xa0,0x10,0xe8,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 15106 0x3b02 "㬂" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x48,0x4b,0x4a,0x7a,0x4a,0x02,0x02,0x02,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 15107 0x3b03 "㬃" */
+0x3f,0x20,0x3f,0x20,0x3f,0x10,0x20,0x7f,0x00,0x3f,0x20,0x3f,0x11,0x22,0x0c,0xf0,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x08,0x90,0x60,0x1e,
+/* 15108 0x3b04 "㬄" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x22,0x4a,0x54,0xa4,0x08,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x80,0xf8,0x80,0xfc,0x20,0x28,0x24,0xa2,0x40,
+/* 15109 0x3b05 "㬅" */
+0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x44,0x7f,0x00,0xff,0x08,0x0f,0x10,0x20,0xc0,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x00,0xfe,0x00,0xf8,0x08,0x28,0x10,
+/* 15110 0x3b06 "㬆" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4b,0x4a,0x7a,0x4b,0x48,0x4b,0x4a,0x7b,0x4a,0x03,0x02,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 15111 0x3b07 "㬇" */
+0x00,0x00,0x78,0x49,0x4a,0x4d,0x79,0x49,0x49,0x49,0x4b,0x78,0x48,0x00,0x01,0x06,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 15112 0x3b08 "㬈" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x48,0x4b,0x4a,0x7a,0x4a,0x02,0x07,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 15113 0x3b09 "㬉" */
+0x00,0x03,0x78,0x48,0x49,0x49,0x79,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 15114 0x3b0a "㬊" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x11,0x3f,0x02,0xff,0x08,0x17,0x22,0xc1,0x0e,
+0xf0,0x10,0xf0,0x10,0xf0,0xfc,0x08,0x10,0xf8,0x00,0xfe,0x00,0xf0,0x20,0xc0,0x3c,
+/* 15115 0x3b0b "㬋" */
+0x00,0x00,0x78,0x49,0x49,0x4b,0x4d,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 15116 0x3b0c "㬌" */
+0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x09,0x11,0x23,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0x08,
+/* 15117 0x3b0d "㬍" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 15118 0x3b0e "㬎" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x12,0x3c,0x08,0x14,0x3e,0x00,0x24,0x22,0x42,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x48,0xf0,0x20,0x50,0xf8,0x00,0x88,0x44,0x44,
+/* 15119 0x3b0f "㬏" */
+0x00,0x03,0x78,0x49,0x49,0x49,0x79,0x48,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 15120 0x3b10 "㬐" */
+0x00,0x03,0x78,0x4a,0x49,0x48,0x4f,0x78,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 15121 0x3b11 "㬑" */
+0x02,0x01,0xf7,0x90,0x97,0x94,0x97,0xf0,0x97,0x90,0x91,0x91,0xf7,0x91,0x05,0x02,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 15122 0x3b12 "㬒" */
+0x00,0x00,0x7b,0x48,0x48,0x4b,0x78,0x48,0x49,0x4a,0x48,0x7b,0x48,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x24,0xfe,0x50,0x88,0x04,0x8a,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 15123 0x3b13 "㬓" */
+0x00,0x03,0x78,0x49,0x49,0x49,0x49,0x78,0x49,0x48,0x4b,0x48,0x78,0x49,0x02,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 15124 0x3b14 "㬔" */
+0x00,0x07,0xf0,0x94,0x92,0x94,0x90,0xf1,0x96,0x90,0x93,0x90,0xf3,0x90,0x00,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 15125 0x3b15 "㬕" */
+0x02,0x01,0x79,0x48,0x4f,0x48,0x49,0x79,0x4b,0x4d,0x49,0x49,0x79,0x49,0x01,0x01,
+0x22,0x12,0x14,0x3e,0x88,0x88,0x08,0x3e,0x88,0x48,0x08,0x3e,0x08,0x08,0x08,0x08,
+/* 15126 0x3b16 "㬖" */
+0x02,0x01,0xf7,0x94,0x94,0x97,0x94,0xf4,0x94,0x98,0x93,0x92,0xf2,0x92,0x03,0x02,
+0x10,0x10,0x9e,0xa4,0xd4,0x94,0x08,0x14,0x62,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 15127 0x3b17 "㬗" */
+0x01,0x01,0x79,0x4a,0x4a,0x4d,0x48,0x7a,0x49,0x49,0x4a,0x4c,0x78,0x4a,0x02,0x04,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 15128 0x3b18 "㬘" */
+0x00,0x01,0x78,0x4b,0x48,0x49,0x48,0x7a,0x4b,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x04,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 15129 0x3b19 "㬙" */
+0x00,0x03,0x78,0x4a,0x49,0x4b,0x7a,0x4b,0x4a,0x4b,0x4a,0x7a,0x4a,0x05,0x04,0x08,
+0x0e,0xf0,0x44,0x24,0x08,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 15130 0x3b1a "㬚" */
+0x02,0x01,0xf7,0x92,0x94,0x9f,0x90,0xf7,0x94,0x97,0x94,0x97,0xf4,0x94,0x04,0x05,
+0x08,0x08,0xc8,0x10,0x9e,0xd4,0x64,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0xa4,0xc2,
+/* 15131 0x3b1b "㬛" */
+0x00,0x00,0xf1,0x96,0x90,0x93,0x92,0xf3,0x90,0x97,0x90,0x94,0xf2,0x94,0x02,0x01,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 15132 0x3b1c "㬜" */
+0x00,0xfe,0x20,0x44,0xfe,0x12,0x7c,0x10,0x1e,0xe0,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xfe,0x20,0x44,0xfe,0x12,0x7c,0x10,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 15133 0x3b1d "㬝" */
+0x01,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x7a,0x4b,0x48,0x49,0x49,0x79,0x49,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 15134 0x3b1e "㬞" */
+0x00,0x02,0x7b,0x48,0x49,0x49,0x49,0x79,0x49,0x48,0x49,0x4a,0x7d,0x49,0x01,0x00,
+0x20,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x06,
+/* 15135 0x3b1f "㬟" */
+0x40,0x40,0x40,0x7e,0xaa,0x2a,0x2a,0x4a,0x4a,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+0x44,0x24,0x28,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+/* 15136 0x3b20 "㬠" */
+0x02,0x02,0xf3,0x94,0x98,0x93,0x90,0xf0,0x93,0x90,0x90,0x97,0xf0,0x92,0x02,0x04,
+0x10,0x10,0xd0,0x5e,0xa4,0xd4,0x54,0x54,0xc8,0x48,0x54,0xe2,0x00,0xa4,0x52,0x52,
+/* 15137 0x3b21 "㬡" */
+0x00,0x01,0x78,0x4b,0x4a,0x49,0x78,0x49,0x48,0x48,0x4b,0x78,0x48,0x00,0x00,0x00,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x50,0xc8,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 15138 0x3b22 "㬢" */
+0x01,0x00,0x7b,0x48,0x49,0x48,0x7b,0x48,0x49,0x48,0x4b,0x78,0x48,0x03,0x00,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 15139 0x3b23 "㬣" */
+0x02,0x02,0xfa,0x96,0x92,0x97,0x90,0xf4,0x92,0x97,0x91,0x97,0xf1,0x91,0x0e,0x00,
+0x84,0x84,0xa4,0xc4,0x9e,0xc4,0x04,0x54,0x8c,0xc4,0x04,0xc4,0x04,0xc4,0x14,0x08,
+/* 15140 0x3b24 "㬤" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4b,0x79,0x4a,0x4b,0x49,0x4a,0x7b,0x48,0x02,0x02,0x04,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 15141 0x3b25 "㬥" */
+0x3f,0x20,0x3f,0x20,0x3f,0x11,0x1f,0x41,0x7f,0x02,0xff,0x09,0x35,0xdf,0x05,0x09,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xf0,0x04,0xfc,0x00,0xfe,0x20,0x58,0xf6,0x40,0x20,
+/* 15142 0x3b26 "㬦" */
+0x00,0x03,0x78,0x48,0x49,0x4b,0x79,0x49,0x49,0x49,0x49,0x79,0x4b,0x00,0x00,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 15143 0x3b27 "㬧" */
+0x3f,0x20,0x3f,0x20,0x3f,0x11,0x1f,0x01,0xff,0x0a,0x34,0xcf,0x01,0x1f,0x09,0x13,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xf0,0x00,0xfe,0x20,0x58,0x86,0x20,0xf0,0x50,0x20,
+/* 15144 0x3b28 "㬨" */
+0x01,0x01,0xf1,0x97,0x91,0x91,0x9f,0xf2,0x92,0x96,0x9a,0x92,0xf2,0x95,0x04,0x08,
+0x10,0x10,0x10,0xbc,0x10,0x10,0xfe,0xa8,0xa8,0xec,0xaa,0xaa,0xa8,0xa8,0x48,0x98,
+/* 15145 0x3b29 "㬩" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x48,0x7b,0x48,0x49,0x48,0x4b,0x78,0x4a,0x02,0x04,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 15146 0x3b2a "㬪" */
+0x0f,0x08,0x0f,0x08,0x0f,0x7c,0x44,0x7c,0x45,0xff,0x88,0x0f,0x10,0x1f,0x00,0xff,
+0xe0,0x20,0xe0,0x20,0xe0,0x7c,0x44,0x7c,0x44,0xfe,0x02,0xf0,0x10,0xe0,0x20,0xfe,
+/* 15147 0x3b2b "㬫" */
+0x04,0xff,0x04,0x17,0xf0,0x17,0x34,0xd7,0x00,0x44,0x82,0x1f,0x10,0x1f,0x10,0x1f,
+0x40,0xfe,0x40,0xd2,0x1c,0xd0,0x52,0xce,0x00,0x44,0x22,0xf0,0x10,0xf0,0x10,0xf0,
+/* 15148 0x3b2c "㬬" */
+0x07,0x04,0xf7,0x94,0x97,0x94,0x97,0xf1,0x93,0x92,0x97,0x9a,0xf3,0x92,0x03,0x02,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 15149 0x3b2d "㬭" */
+0x00,0x03,0x79,0x48,0x4b,0x4a,0x7b,0x48,0x4b,0x4a,0x4b,0x7a,0x4b,0x02,0x02,0x03,
+0x1e,0xe0,0x22,0x94,0xfe,0x52,0xfe,0x04,0xc4,0x7e,0xc4,0x54,0xcc,0x84,0xd4,0x48,
+/* 15150 0x3b2e "㬮" */
+0x3f,0x20,0x3f,0x20,0x3f,0x44,0xfe,0x44,0x7d,0x10,0xfe,0x92,0xfe,0x10,0xfe,0x28,
+0xf8,0x08,0xf8,0x08,0xf8,0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,
+/* 15151 0x3b2f "㬯" */
+0x00,0x3f,0x08,0xef,0xa0,0xaf,0xa8,0xef,0xa2,0xbd,0xb7,0xbc,0xf5,0x1c,0x17,0x2c,
+0x80,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x20,0x5c,0xf4,0x94,0xdc,0x96,0xf6,0xa2,
+/* 15152 0x3b30 "㬰" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 15153 0x3b31 "㬱" */
+0x28,0x3e,0x48,0xfe,0x14,0x15,0x26,0x44,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x50,0x7c,0x90,0xfe,0x28,0x28,0x4a,0x86,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 15154 0x3b32 "㬲" */
+0x00,0x7c,0x10,0x11,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7d,0x93,0x60,0x20,0x5f,0x80,
+0x88,0x50,0x00,0xfc,0x50,0x88,0x04,0xfc,0x54,0x54,0x54,0xfe,0x00,0x00,0xfe,0x00,
+/* 15155 0x3b33 "㬳" */
+0x00,0x3c,0x24,0x25,0x25,0x3e,0x24,0x24,0x27,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 15156 0x3b34 "㬴" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x48,0x48,0x7b,0x48,0x48,0x48,0x49,0x49,0x9a,
+0x90,0x90,0x90,0x90,0xfc,0x90,0x90,0x90,0x90,0xfe,0x00,0x90,0x88,0x08,0x04,0x04,
+/* 15157 0x3b35 "㬵" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x25,0x26,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x8b,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 15158 0x3b36 "㬶" */
+0x00,0x79,0x49,0x49,0x49,0x7a,0x48,0x4b,0x48,0x78,0x49,0x49,0x49,0x49,0x49,0x99,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 15159 0x3b37 "㬷" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x4a,0x4b,0x9a,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 15160 0x3b38 "㬸" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x24,0x44,0x54,0x88,
+0x88,0x88,0xfe,0x88,0x88,0x50,0x50,0x94,0x94,0x98,0x90,0xb2,0xd2,0x92,0x8e,0x80,
+/* 15161 0x3b39 "㬹" */
+0x00,0x3c,0x24,0x25,0x26,0x3d,0x24,0x24,0x25,0x3c,0x24,0x25,0x24,0x44,0x54,0x88,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 15162 0x3b3a "㬺" */
+0x00,0x79,0x48,0x49,0x48,0x7b,0x49,0x4a,0x4c,0x79,0x49,0x49,0x49,0x49,0x48,0x98,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x08,0x24,0x22,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 15163 0x3b3b "㬻" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x48,0x48,0x48,0x78,0x48,0x48,0x48,0x48,0x49,0x9a,
+0x88,0x88,0xfe,0xa8,0x10,0xfe,0x80,0x80,0xfc,0x00,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 15164 0x3b3c "㬼" */
+0x10,0x10,0x7e,0x10,0x21,0x3e,0x24,0x64,0xbc,0x24,0x24,0x3c,0x25,0x24,0x24,0x2d,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 15165 0x3b3d "㬽" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x25,0x25,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xf8,0x88,0xf8,0x00,0xdc,0x54,0xdc,0x00,0xfe,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 15166 0x3b3e "㬾" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x70,
+/* 15167 0x3b3f "㬿" */
+0x01,0x78,0x4b,0x48,0x4b,0x7a,0x4b,0x48,0x4b,0x78,0x48,0x48,0x4b,0x48,0x4a,0x99,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 15168 0x3b40 "㭀" */
+0x01,0x79,0x49,0x4a,0x4c,0x78,0x4b,0x48,0x49,0x79,0x49,0x4a,0x4c,0x48,0x4b,0x98,
+0x10,0x10,0xde,0xa8,0x44,0x00,0xfc,0x20,0x28,0x28,0x28,0xb4,0x62,0x20,0xfe,0x00,
+/* 15169 0x3b41 "㭁" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 15170 0x3b42 "㭂" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x38,0x55,0x51,0x92,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0x20,0xa8,0xa4,0xa4,0x22,0x22,0x22,0x20,0x20,0x20,0xa0,0x40,
+/* 15171 0x3b43 "㭃" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x31,0x3b,0x55,0x54,0x90,0x10,0x10,0x11,0x13,0x11,
+0x20,0x20,0x40,0x40,0x84,0x84,0x08,0xf8,0x10,0x10,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 15172 0x3b44 "㭄" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 15173 0x3b45 "㭅" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x10,0x10,0x17,0x10,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 15174 0x3b46 "㭆" */
+0x00,0x3f,0x04,0x04,0x08,0x30,0xc1,0x01,0x7f,0x01,0x3f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xe0,0x20,0x7c,0x04,0x14,0x08,0x00,0xfc,0x00,0xf8,0x40,0x20,0x18,0x06,0x00,
+/* 15175 0x3b47 "㭇" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 15176 0x3b48 "㭈" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x38,0x57,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 15177 0x3b49 "㭉" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 15178 0x3b4a "㭊" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x10,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 15179 0x3b4b "㭋" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 15180 0x3b4c "㭌" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x32,0x38,0x54,0x53,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 15181 0x3b4d "㭍" */
+0x40,0x20,0x08,0x17,0xe0,0x20,0x20,0x20,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x80,0x80,0x9c,0xe0,0x80,0x84,0x84,0x7c,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 15182 0x3b4e "㭎" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x04,0x04,0x94,0x54,0x24,0x24,0x54,0x54,0x94,0x04,0x04,0x04,0x14,0x08,
+/* 15183 0x3b4f "㭏" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x30,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 15184 0x3b50 "㭐" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc1,0x01,0x7f,0x01,0x3f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,0xfc,0x00,0xf8,0x40,0x20,0x18,0x06,0x00,
+/* 15185 0x3b51 "㭑" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 15186 0x3b52 "㭒" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15187 0x3b53 "㭓" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x30,0x38,0x54,0x53,0x90,0x10,0x11,0x11,0x12,0x14,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 15188 0x3b54 "㭔" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x30,0x38,0x57,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 15189 0x3b55 "㭕" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x11,0x13,0x11,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 15190 0x3b56 "㭖" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x3b,0x35,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0xa0,0xa8,0xa4,0x24,0x20,0x3e,0xe0,0x20,0x20,0x20,0x20,0x20,0x14,0x14,0x0c,0x04,
+/* 15191 0x3b57 "㭗" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 15192 0x3b58 "㭘" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x31,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15193 0x3b59 "㭙" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x33,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 15194 0x3b5a "㭚" */
+0x10,0x10,0x10,0x11,0xfe,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xfe,0x00,0x00,0x1c,0xe0,0x20,0x22,0x24,0x28,0x10,0x10,0x48,0x84,0x02,
+/* 15195 0x3b5b "㭛" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x04,0x1e,0xe0,0x00,0x06,0x78,0x50,0x50,0x52,0x54,0x48,0x48,0x44,0x54,0x62,0x40,
+/* 15196 0x3b5c "㭜" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x31,0x39,0x55,0x53,0x91,0x11,0x12,0x12,0x14,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 15197 0x3b5d "㭝" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x02,0x02,0x1f,0x04,0x04,0x08,0x10,0x20,0x40,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x26,0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 15198 0x3b5e "㭞" */
+0x10,0x10,0x11,0x11,0xfa,0x10,0x30,0x3b,0x54,0x50,0x93,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x24,0x22,0x2a,0x10,0x60,0x80,0x40,0x40,0xfc,0x44,0x84,0x84,0x14,0x08,
+/* 15199 0x3b5f "㭟" */
+0x04,0x04,0x3f,0x04,0x04,0x04,0xff,0x08,0x31,0xc1,0x1f,0x03,0x05,0x19,0x61,0x01,
+0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x20,0x18,0x06,0xf0,0x00,0xc0,0x30,0x08,0x00,
+/* 15200 0x3b60 "㭠" */
+0x10,0x11,0x11,0x11,0xfd,0x12,0x30,0x3b,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 15201 0x3b61 "㭡" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x94,0x54,0x24,0x24,0x54,0x94,0x04,0x04,0xfc,0x04,
+/* 15202 0x3b62 "㭢" */
+0x20,0x27,0x22,0x22,0xfa,0x22,0x22,0x77,0x6a,0xa2,0xa2,0x22,0x22,0x24,0x24,0x28,
+0x04,0xc4,0x84,0x94,0x94,0x94,0x94,0xd4,0x94,0x94,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 15203 0x3b63 "㭣" */
+0x11,0x10,0x10,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0x80,0xbc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 15204 0x3b64 "㭤" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x13,0x10,0x10,0x10,
+0x20,0x40,0xfc,0x04,0x44,0x24,0x24,0x0c,0x00,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 15205 0x3b65 "㭥" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x31,0x39,0x55,0x51,0x91,0x11,0x10,0x10,0x11,0x12,
+0x40,0x40,0xf8,0x88,0x10,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x88,0x04,0x02,
+/* 15206 0x3b66 "㭦" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x33,0x38,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x00,0x38,0xc0,0x40,0x40,0x7c,0xc0,0x40,0x42,0x42,0x3e,0x00,
+/* 15207 0x3b67 "㭧" */
+0x02,0x04,0x1f,0x11,0x10,0xff,0x10,0x12,0x21,0x40,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x00,0xf0,0x10,0x90,0xfe,0x10,0x10,0x50,0x20,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15208 0x3b68 "㭨" */
+0x20,0x27,0x20,0x24,0xfc,0x24,0x27,0x70,0x69,0xa1,0xa2,0x22,0x24,0x28,0x22,0x21,
+0x00,0xde,0x92,0x92,0x94,0x94,0xd8,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x90,0x10,
+/* 15209 0x3b69 "㭩" */
+0x10,0x10,0x11,0x10,0xfd,0x10,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 15210 0x3b6a "㭪" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 15211 0x3b6b "㭫" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x32,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 15212 0x3b6c "㭬" */
+0x10,0x13,0x10,0x10,0xfd,0x12,0x30,0x38,0x55,0x52,0x90,0x10,0x11,0x12,0x10,0x10,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0x28,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 15213 0x3b6d "㭭" */
+0x20,0x23,0x22,0x22,0xfa,0x23,0x21,0x71,0x6b,0xa1,0xa1,0x21,0x22,0x22,0x24,0x28,
+0x02,0xe2,0x22,0x2a,0x2a,0xea,0x0a,0x0a,0xea,0x2a,0x2a,0x2a,0x22,0x22,0xaa,0x44,
+/* 15214 0x3b6e "㭮" */
+0x21,0x21,0x22,0x22,0xf9,0x21,0x20,0x77,0x68,0xa1,0xa1,0x22,0x24,0x20,0x20,0x27,
+0x24,0x24,0x48,0x48,0x24,0x24,0x00,0xfe,0x80,0xfc,0x04,0x88,0x50,0x20,0xc0,0x00,
+/* 15215 0x3b6f "㭯" */
+0x10,0x13,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x13,0x10,0x10,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 15216 0x3b70 "㭰" */
+0x08,0x28,0x2e,0x28,0x2e,0xf1,0x01,0xff,0x01,0x3f,0x21,0x23,0x25,0x09,0x11,0x61,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x00,0xfe,0x00,0xf8,0x08,0x88,0x58,0x20,0x10,0x0c,
+/* 15217 0x3b71 "㭱" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x00,0xfe,0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 15218 0x3b72 "㭲" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x55,0x52,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 15219 0x3b73 "㭳" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x38,0x55,0x54,0x91,0x12,0x14,0x10,0x10,0x10,
+0x20,0x22,0xfa,0x24,0x24,0xfe,0x10,0x20,0xfc,0x88,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 15220 0x3b74 "㭴" */
+0x10,0x12,0x12,0x12,0xfe,0x12,0x32,0x38,0x54,0x54,0x91,0x10,0x10,0x10,0x13,0x10,
+0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 15221 0x3b75 "㭵" */
+0x11,0x11,0x11,0x12,0xfa,0x15,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xf4,0x54,0x54,0xf4,0x54,0x54,0xf4,0x14,0x04,0x28,0x10,
+/* 15222 0x3b76 "㭶" */
+0x11,0x11,0x17,0x11,0xfd,0x10,0x37,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x04,0x04,0xfe,0x04,0x44,0x20,0xfe,0x80,0x80,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 15223 0x3b77 "㭷" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x53,0x90,0x10,0x10,0x11,0x12,0x14,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x40,0xfe,0x42,0x82,0x82,0x02,0x14,0x08,
+/* 15224 0x3b78 "㭸" */
+0x10,0x10,0x10,0x11,0xfa,0x11,0x31,0x39,0x55,0x51,0x90,0x10,0x10,0x10,0x11,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x58,0x94,0x92,0x12,0x0e,
+/* 15225 0x3b79 "㭹" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x53,0x90,0x10,0x10,0x10,0x12,0x11,
+0x10,0x88,0x88,0xfe,0x90,0x90,0x24,0x24,0x38,0x88,0x90,0x90,0xa4,0xbe,0x82,0x00,
+/* 15226 0x3b7a "㭺" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x32,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 15227 0x3b7b "㭻" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 15228 0x3b7c "㭼" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x32,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 15229 0x3b7d "㭽" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x14,0x18,
+0x40,0x20,0xfe,0x00,0x1c,0xf0,0x90,0x90,0xfe,0x90,0x90,0x90,0xaa,0xca,0xa6,0x12,
+/* 15230 0x3b7e "㭾" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 15231 0x3b7f "㭿" */
+0x20,0x23,0x22,0x23,0xfa,0x23,0x20,0x71,0x6e,0xa4,0xa4,0x24,0x25,0x26,0x24,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x80,0x3e,0x22,0x22,0x22,0xa2,0x2a,0x24,0x20,
+/* 15232 0x3b80 "㮀" */
+0x10,0x11,0x10,0x10,0xfa,0x12,0x32,0x3a,0x56,0x52,0x93,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfc,0x08,0x10,0x22,0xaa,0x72,0x22,0x72,0xaa,0x26,0xa2,0x42,0x02,0xfe,0x02,
+/* 15233 0x3b81 "㮁" */
+0x11,0x10,0x10,0x10,0xfb,0x10,0x33,0x38,0x54,0x51,0x92,0x10,0x10,0x10,0x10,0x10,
+0x84,0x68,0x30,0xc8,0x24,0x20,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 15234 0x3b82 "㮂" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x31,0xc1,0x1f,0x05,0x09,0x11,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x18,0x06,0xf0,0x40,0x20,0x10,
+/* 15235 0x3b83 "㮃" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x3a,0x54,0x53,0x90,0x11,0x10,0x10,0x10,0x11,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 15236 0x3b84 "㮄" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x3a,0x55,0x50,0x90,0x10,0x11,0x11,0x12,0x10,
+0x40,0x20,0xfe,0x80,0x80,0xfe,0x42,0x22,0xfa,0x82,0xf2,0x92,0x12,0x52,0x2a,0x04,
+/* 15237 0x3b85 "㮅" */
+0x01,0x01,0x7f,0x05,0x09,0x31,0xc9,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 15238 0x3b86 "㮆" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x39,0x54,0x54,0x90,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x88,0x04,0x8a,0x50,0xfc,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 15239 0x3b87 "㮇" */
+0x10,0x13,0x10,0x10,0xfb,0x10,0x31,0x3a,0x54,0x50,0x90,0x12,0x12,0x14,0x11,0x10,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 15240 0x3b88 "㮈" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x32,0x38,0x54,0x53,0x90,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0x24,0x22,0x22,0xa0,0x40,
+/* 15241 0x3b89 "㮉" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x36,0x6a,0x62,0xa2,0xa2,0x22,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0x7c,0x10,0x92,0x54,0x10,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15242 0x3b8a "㮊" */
+0x20,0x27,0x20,0x22,0xf9,0x20,0x27,0x71,0x69,0xa1,0xa1,0x21,0x21,0x21,0x25,0x22,
+0x08,0xc8,0x48,0x88,0x3e,0x88,0xd8,0x5c,0x2c,0x2a,0x48,0x08,0x08,0x08,0x08,0x08,
+/* 15243 0x3b8b "㮋" */
+0x21,0x21,0x27,0x21,0xfa,0x23,0x22,0x76,0x6b,0xa2,0xa2,0x23,0x22,0x22,0x22,0x22,
+0x00,0x1e,0xf2,0x12,0x14,0xd4,0x58,0x54,0xd2,0x52,0x52,0xda,0x54,0x50,0x50,0xd0,
+/* 15244 0x3b8c "㮌" */
+0x10,0x17,0x10,0x10,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 15245 0x3b8d "㮍" */
+0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x20,0xfe,0x00,0x08,0x48,0x48,0x48,0x48,0x08,0x18,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15246 0x3b8e "㮎" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x51,0x91,0x11,0x11,0x11,0x17,0x10,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 15247 0x3b8f "㮏" */
+0x20,0x20,0x27,0x20,0xf9,0x22,0x2c,0x73,0x68,0xa0,0xa7,0x20,0x22,0x24,0x29,0x20,
+0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf8,0x00,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 15248 0x3b90 "㮐" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x38,0x35,0x56,0x50,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0xa4,0xa2,0x2a,0x10,0x60,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 15249 0x3b91 "㮑" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 15250 0x3b92 "㮒" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 15251 0x3b93 "㮓" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x3b,0x35,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0x7e,0x10,0x10,0x90,0x5e,0x22,0x2a,0x26,0x42,0x52,0x0c,0x04,0x04,0x7e,0x00,
+/* 15252 0x3b94 "㮔" */
+0x10,0x10,0x11,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x10,0x11,0x10,0x13,0x10,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 15253 0x3b95 "㮕" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x13,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 15254 0x3b96 "㮖" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x31,0x39,0x55,0x55,0x90,0x13,0x10,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 15255 0x3b97 "㮗" */
+0x00,0x7e,0x14,0x08,0x7f,0x2a,0x49,0x88,0x28,0x10,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15256 0x3b98 "㮘" */
+0x20,0x27,0x20,0x22,0xf9,0x21,0x27,0x71,0x6b,0xa3,0xa5,0x25,0x29,0x21,0x25,0x22,
+0x08,0x88,0x88,0x90,0x1e,0x14,0xe4,0x54,0x14,0x14,0x14,0x08,0x08,0x14,0x24,0x42,
+/* 15257 0x3b99 "㮙" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x31,0x38,0x57,0x50,0x91,0x11,0x10,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 15258 0x3b9a "㮚" */
+0x01,0x01,0x01,0x3f,0x21,0x22,0x2d,0x22,0x24,0x3f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0xf8,0x00,0xf8,0x08,0xc8,0x28,0x88,0x48,0xf8,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15259 0x3b9b "㮛" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x53,0x90,0x11,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 15260 0x3b9c "㮜" */
+0x10,0x13,0x12,0x12,0xfa,0x12,0x32,0x3a,0x57,0x52,0x92,0x12,0x13,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x24,0xa4,0xa4,0xe4,0x3e,0xe4,0xa4,0xa4,0xa4,0x2e,0x00,0xfe,0x00,
+/* 15261 0x3b9d "㮝" */
+0x20,0x22,0x22,0x22,0xf5,0x21,0x22,0x72,0x6c,0xa3,0xa2,0x22,0x22,0x22,0x23,0x22,
+0x00,0x9e,0x52,0x52,0x54,0x14,0x98,0x54,0x32,0xd2,0x52,0x5a,0x54,0x50,0xd0,0x50,
+/* 15262 0x3b9e "㮞" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0xbe,0x42,0x84,0x10,0x10,0x28,0x44,0x82,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 15263 0x3b9f "㮟" */
+0x20,0x20,0x27,0x21,0xf9,0x22,0x23,0x76,0x6a,0xa2,0xa2,0x22,0x23,0x22,0x20,0x20,
+0x08,0x08,0xe8,0x08,0x3e,0x08,0xd8,0x5c,0x6c,0x6a,0x48,0x48,0xc8,0x48,0x08,0x08,
+/* 15264 0x3ba0 "㮠" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x3a,0x34,0x50,0x53,0x90,0x10,0x10,0x11,0x12,0x10,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x24,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,
+/* 15265 0x3ba1 "㮡" */
+0x08,0x08,0x2a,0x2c,0x48,0x08,0x14,0x22,0x40,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x80,0xf8,0x88,0xf8,0x80,0xfc,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 15266 0x3ba2 "㮢" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x35,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 15267 0x3ba3 "㮣" */
+0x00,0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 15268 0x3ba4 "㮤" */
+0x02,0x01,0x7f,0x49,0x12,0x24,0x18,0x6f,0x08,0x08,0x0f,0x01,0x7f,0x05,0x19,0xe1,
+0x00,0x00,0xfc,0x24,0x90,0x48,0x30,0xec,0x20,0x20,0xe0,0x00,0xfc,0x40,0x30,0x0e,
+/* 15269 0x3ba5 "㮥" */
+0x10,0x10,0x10,0x11,0xfc,0x13,0x38,0x35,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x04,0xfe,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 15270 0x3ba6 "㮦" */
+0x10,0x10,0x13,0x10,0xfb,0x12,0x34,0x39,0x54,0x50,0x93,0x10,0x11,0x12,0x14,0x10,
+0x20,0x20,0xfe,0x20,0xfe,0x42,0x8c,0xf0,0x20,0x44,0xfe,0x22,0x28,0x24,0xa4,0x40,
+/* 15271 0x3ba7 "㮧" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x12,0x12,0x14,0x10,0x10,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 15272 0x3ba8 "㮨" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x38,0x35,0x52,0x50,0x91,0x12,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 15273 0x3ba9 "㮩" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x12,0x12,0x14,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 15274 0x3baa "㮪" */
+0x10,0x13,0x11,0x11,0xfd,0x11,0x37,0x3a,0x54,0x50,0x93,0x10,0x10,0x11,0x12,0x10,
+0x00,0xb8,0x28,0x28,0x3a,0xaa,0x26,0x40,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 15275 0x3bab "㮫" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x38,0x35,0x50,0x53,0x90,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 15276 0x3bac "㮬" */
+0x10,0x10,0x11,0x12,0xfc,0x11,0x38,0x34,0x53,0x50,0x92,0x11,0x12,0x10,0x11,0x10,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 15277 0x3bad "㮭" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfc,0x08,0xd0,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 15278 0x3bae "㮮" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x30,0x38,0x54,0x54,0x91,0x10,0x13,0x10,0x10,0x10,
+0x80,0xde,0x8a,0xca,0x8a,0xd2,0xa6,0x08,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 15279 0x3baf "㮯" */
+0x20,0x27,0x24,0x25,0xfc,0x24,0x25,0x74,0x6c,0xa5,0xa4,0x24,0x25,0x24,0x27,0x24,
+0x00,0xfe,0x02,0xfa,0x42,0xc2,0x2a,0x6a,0xb2,0x2a,0x6a,0xaa,0x22,0x42,0xfe,0x02,
+/* 15280 0x3bb0 "㮰" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 15281 0x3bb1 "㮱" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x38,0x35,0x50,0x53,0x90,0x10,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x20,0xa0,0xfc,0x20,0x20,0xfe,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 15282 0x3bb2 "㮲" */
+0x10,0x10,0x11,0x12,0xfd,0x11,0x38,0x35,0x52,0x51,0x92,0x15,0x11,0x10,0x11,0x12,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 15283 0x3bb3 "㮳" */
+0x20,0x27,0x25,0x25,0xfd,0x27,0x25,0x75,0x6d,0xa7,0xa5,0x25,0x25,0x25,0x2b,0x20,
+0x44,0x24,0x28,0x00,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 15284 0x3bb4 "㮴" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x55,0x90,0x10,0x10,0x10,0x10,0x13,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 15285 0x3bb5 "㮵" */
+0x22,0x21,0x21,0x27,0xfa,0x22,0x23,0x72,0x6a,0xa2,0xa2,0x22,0x24,0x24,0x29,0x30,
+0x20,0x20,0x3e,0xa0,0x40,0x3c,0xa4,0xb4,0xac,0xa4,0xfe,0xa4,0xa4,0xa4,0xa4,0x4c,
+/* 15286 0x3bb6 "㮶" */
+0x24,0x22,0x22,0x20,0xf7,0x21,0x25,0x75,0x6d,0xa7,0xa1,0x21,0x22,0x22,0x24,0x28,
+0x40,0x5e,0x92,0x12,0xd2,0x1e,0x52,0x52,0x52,0xde,0x52,0x12,0x12,0x22,0x2a,0x44,
+/* 15287 0x3bb7 "㮷" */
+0x10,0x10,0x13,0x10,0xfd,0x12,0x31,0x39,0x55,0x54,0x90,0x11,0x11,0x11,0x11,0x11,
+0x50,0x48,0xfc,0xa0,0x22,0x1e,0x10,0xe0,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,
+/* 15288 0x3bb8 "㮸" */
+0x10,0x10,0x12,0x11,0xfd,0x10,0x30,0x3b,0x55,0x51,0x91,0x11,0x11,0x12,0x14,0x10,
+0x44,0x24,0x28,0x00,0x7c,0x10,0x10,0x7e,0x10,0x10,0x28,0x24,0x44,0x80,0x7e,0x00,
+/* 15289 0x3bb9 "㮹" */
+0x20,0x20,0x27,0x22,0xfa,0x24,0x27,0x71,0x69,0xa7,0xa1,0x21,0x21,0x2e,0x24,0x20,
+0x08,0x08,0xc8,0x10,0x1e,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x08,0xc8,0x14,0x14,0x22,
+/* 15290 0x3bba "㮺" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x37,0xc1,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,
+0x00,0x00,0xfc,0x80,0x40,0x20,0xd8,0x06,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,
+/* 15291 0x3bbb "㮻" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x51,0x91,0x11,0x11,0x10,0x13,0x10,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 15292 0x3bbc "㮼" */
+0x10,0x10,0x13,0x12,0xfa,0x13,0x32,0x3b,0x56,0x53,0x92,0x12,0x12,0x15,0x14,0x18,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0xdc,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0xcc,
+/* 15293 0x3bbd "㮽" */
+0x21,0x22,0x27,0x24,0xf6,0x25,0x24,0x7f,0x6c,0xa4,0xa6,0x25,0x24,0x24,0x24,0x29,
+0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xc2,0x80,0xbc,0xa4,0xa4,0xa4,0x94,0x88,0x94,0xa2,
+/* 15294 0x3bbe "㮾" */
+0x10,0x7e,0x42,0x7e,0x42,0x7e,0x48,0x44,0x5a,0x61,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x94,0x08,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15295 0x3bbf "㮿" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x57,0x54,0x90,0x11,0x10,0x13,0x10,0x10,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 15296 0x3bc0 "㯀" */
+0x22,0x21,0x21,0x27,0xfa,0x22,0x23,0x72,0x6a,0xa2,0xa2,0x22,0x24,0x25,0x28,0x30,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 15297 0x3bc1 "㯁" */
+0x20,0x27,0x25,0x25,0xfd,0x26,0x25,0x75,0x6d,0xa5,0xa5,0x26,0x24,0x24,0x24,0x24,
+0x20,0x10,0x7c,0x00,0x44,0x28,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 15298 0x3bc2 "㯂" */
+0x22,0x22,0x27,0x22,0xfa,0x24,0x28,0x77,0x6c,0xa0,0xa3,0x22,0x22,0x22,0x22,0x20,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 15299 0x3bc3 "㯃" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x38,0x34,0x51,0x52,0x91,0x10,0x11,0x12,0x10,0x10,
+0x20,0x20,0xfe,0x70,0xac,0x22,0x50,0x88,0x24,0x22,0x24,0xa8,0x24,0x22,0xa0,0x40,
+/* 15300 0x3bc4 "㯄" */
+0x08,0x7e,0x08,0x1c,0x2b,0xc8,0x08,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x4f,0x48,0x87,
+0x20,0xfc,0x70,0xa8,0x26,0x20,0x7c,0x80,0x00,0xfc,0x00,0xf8,0x88,0xf8,0x02,0xfe,
+/* 15301 0x3bc5 "㯅" */
+0x20,0x20,0x27,0x24,0xfc,0x25,0x25,0x75,0x6d,0xa5,0xa4,0x24,0x2b,0x28,0x30,0x20,
+0x40,0x20,0xfe,0x20,0x40,0xfc,0x24,0xfc,0x44,0xfc,0x50,0x90,0xfe,0x10,0x10,0x10,
+/* 15302 0x3bc6 "㯆" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x3a,0x56,0x52,0x93,0x12,0x12,0x14,0x14,0x19,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 15303 0x3bc7 "㯇" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x54,0x54,0x90,0x11,0x10,0x10,0x13,0x10,
+0x50,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 15304 0x3bc8 "㯈" */
+0x20,0x20,0x24,0x22,0xfa,0x20,0x20,0x76,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0xfe,
+/* 15305 0x3bc9 "㯉" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,0x10,
+0x20,0x3e,0x20,0xfe,0x20,0x3c,0xe2,0x1e,0x04,0x78,0x92,0x54,0xfe,0x10,0x50,0x20,
+/* 15306 0x3bca "㯊" */
+0x20,0x27,0x20,0x22,0xf2,0x2f,0x21,0x71,0x6a,0xa3,0xa0,0x25,0x25,0x28,0x20,0x20,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 15307 0x3bcb "㯋" */
+0x40,0x4c,0x70,0x42,0x42,0x3e,0x10,0x10,0xfe,0x30,0x38,0x54,0x52,0x90,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 15308 0x3bcc "㯌" */
+0x20,0x22,0x21,0x21,0xf8,0x20,0x26,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x25,0x28,0x20,
+0x00,0x7e,0x10,0x30,0x4a,0x9a,0x2c,0x4c,0x9a,0x2a,0x4a,0x88,0x28,0x10,0xfe,0x00,
+/* 15309 0x3bcd "㯍" */
+0x20,0x22,0x22,0x22,0xfa,0x23,0x20,0x70,0x6f,0xa2,0xa2,0x22,0x22,0x22,0x24,0x28,
+0x90,0x90,0x9e,0xa2,0xd4,0xa8,0x94,0xa4,0xfe,0x84,0xa4,0x94,0x94,0x84,0x94,0x88,
+/* 15310 0x3bce "㯎" */
+0x22,0x21,0x21,0x27,0xf8,0x27,0x20,0x77,0x68,0xa7,0xa4,0x24,0x24,0x27,0x24,0x20,
+0x08,0x08,0x08,0xc8,0x3e,0x88,0x18,0x9c,0x2c,0xaa,0xc8,0x88,0x88,0x88,0x88,0x08,
+/* 15311 0x3bcf "㯏" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x80,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15312 0x3bd0 "㯐" */
+0x00,0x7b,0x48,0x49,0x52,0x4d,0x48,0x68,0x50,0x40,0x40,0x01,0x7f,0x05,0x19,0xe1,
+0x40,0xfc,0x80,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x88,0x00,0xfc,0x40,0x30,0x0e,
+/* 15313 0x3bd1 "㯑" */
+0x20,0x2f,0x21,0x21,0xf1,0x2f,0x28,0x78,0x68,0xaf,0xa1,0x21,0x21,0x21,0x2a,0x24,
+0x00,0x3e,0x20,0x3c,0x20,0x3c,0x20,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x62,0x40,
+/* 15314 0x3bd2 "㯒" */
+0x20,0x27,0x20,0x22,0xf9,0x23,0x22,0x73,0x6a,0xa3,0xa2,0x23,0x20,0x21,0x22,0x2c,
+0x0e,0xf0,0x44,0x24,0x08,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x10,0x12,0x0e,
+/* 15315 0x3bd3 "㯓" */
+0x20,0x20,0x21,0x26,0xf8,0x23,0x22,0x73,0x68,0xa7,0xa0,0x24,0x22,0x24,0x22,0x21,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 15316 0x3bd4 "㯔" */
+0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,0x0c,0x70,0x1d,0xf0,0x1c,0x01,0xff,0x09,0x71,
+0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,0x20,0x3c,0xe2,0x22,0x1e,0x00,0xfe,0x20,0x1c,
+/* 15317 0x3bd5 "㯕" */
+0x22,0x22,0x22,0x27,0xfa,0x23,0x22,0x73,0x6a,0xa2,0xa7,0x20,0x22,0x24,0x28,0x20,
+0x40,0x42,0x5c,0xf0,0x50,0xd0,0x5e,0xd4,0x54,0x54,0xf4,0x14,0x94,0x64,0x24,0x44,
+/* 15318 0x3bd6 "㯖" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x54,0x53,0x90,0x10,0x12,0x12,0x14,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 15319 0x3bd7 "㯗" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x24,0x74,0x6d,0xa4,0xa4,0x25,0x26,0x24,0x24,0x24,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0x44,0xf4,0x44,0xe4,0x54,0x4c,0x44,0x54,0x08,
+/* 15320 0x3bd8 "㯘" */
+0x21,0x21,0x27,0x21,0xf9,0x23,0x20,0x73,0x68,0xa7,0xa1,0x21,0x25,0x29,0x25,0x22,
+0x08,0x08,0xc8,0x08,0x1e,0x92,0x24,0x80,0x08,0xc8,0x08,0x08,0x94,0x54,0x24,0x42,
+/* 15321 0x3bd9 "㯙" */
+0x22,0x21,0x27,0x22,0xf4,0x2f,0x20,0x77,0x6c,0xa7,0xa4,0x27,0x24,0x24,0x24,0x25,
+0x08,0x08,0xc8,0x10,0x9e,0xd4,0x64,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0xa4,0xc2,
+/* 15322 0x3bda "㯚" */
+0x12,0x12,0x13,0x12,0xfd,0x10,0x31,0x3a,0x55,0x50,0x90,0x13,0x12,0x12,0x13,0x12,
+0x10,0x10,0xde,0x28,0x44,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 15323 0x3bdb "㯛" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x3a,0x54,0x51,0x91,0x11,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0x50,0xdc,0x04,0xdc,0x50,0x50,0xfe,0x00,
+/* 15324 0x3bdc "㯜" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x30,0x38,0x55,0x52,0x90,0x17,0x10,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x20,0xfe,0x88,0x88,0x54,0x22,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 15325 0x3bdd "㯝" */
+0x20,0x27,0x24,0x24,0xf4,0x27,0x21,0x71,0x69,0xa5,0xa5,0x25,0x25,0x25,0x2e,0x20,
+0x10,0x90,0xbc,0xa4,0xc4,0xa8,0x10,0x28,0x46,0xc0,0x3c,0x24,0x24,0xa4,0x3c,0x24,
+/* 15326 0x3bde "㯞" */
+0x20,0x20,0x21,0x21,0xfa,0x27,0x20,0x71,0x6a,0xa7,0xa0,0x20,0x25,0x25,0x24,0x20,
+0x80,0x9e,0x12,0x52,0x5e,0x80,0x9e,0x12,0x52,0xde,0x52,0x1e,0x52,0x52,0x12,0x16,
+/* 15327 0x3bdf "㯟" */
+0x10,0x10,0xfe,0x38,0x54,0x92,0x3f,0x00,0x1f,0x00,0xff,0x11,0x09,0x05,0x19,0xe3,
+0x10,0x10,0xfe,0x38,0x54,0x82,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xa0,0x40,0x30,0x0e,
+/* 15328 0x3be0 "㯠" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x32,0x38,0x55,0x50,0x91,0x11,0x12,0x17,0x10,0x10,
+0x20,0xfe,0x48,0xf0,0x20,0xfe,0x42,0x90,0xf8,0x28,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 15329 0x3be1 "㯡" */
+0x10,0x10,0xfe,0x38,0x55,0x92,0x28,0x44,0x92,0x10,0x54,0x38,0x54,0x92,0x50,0x20,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 15330 0x3be2 "㯢" */
+0x10,0x13,0x12,0x13,0xfe,0x12,0x31,0x38,0x54,0x53,0x90,0x10,0x13,0x10,0x11,0x12,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 15331 0x3be3 "㯣" */
+0x21,0x2f,0x21,0x20,0xf1,0x23,0x2c,0x71,0x6a,0xa0,0xa7,0x20,0x21,0x22,0x2c,0x20,
+0x08,0xfe,0x08,0x90,0x08,0xfc,0x8a,0x28,0x50,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 15332 0x3be4 "㯤" */
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0xba,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0xba,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 15333 0x3be5 "㯥" */
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 15334 0x3be6 "㯦" */
+0x21,0x27,0x21,0x21,0xf9,0x21,0x21,0x77,0x69,0xa2,0xa4,0x23,0x20,0x21,0x26,0x20,
+0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xfc,0x10,0x48,0x46,0xf8,0xe0,0x58,0x44,0x40,
+/* 15335 0x3be7 "㯧" */
+0x21,0x21,0x21,0x27,0xf9,0x21,0x2f,0x71,0x69,0xa5,0xa5,0x25,0x27,0x25,0x24,0x28,
+0x00,0x3c,0x14,0xd4,0x14,0x24,0xcc,0x00,0x3c,0x24,0xe4,0x3c,0x24,0x00,0xfe,0x00,
+/* 15336 0x3be8 "㯨" */
+0x10,0x13,0x10,0x10,0xfb,0x12,0x32,0x3b,0x55,0x50,0x93,0x10,0x10,0x11,0x16,0x10,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 15337 0x3be9 "㯩" */
+0x00,0x7e,0x22,0x1c,0x22,0x77,0x55,0x22,0x55,0x08,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x10,0x10,0xfe,0x10,0x7c,0x14,0x7c,0x50,0x7e,0x12,0x12,0x16,0x28,0x28,0x44,0x82,
+/* 15338 0x3bea "㯪" */
+0x10,0x11,0x10,0x13,0xfa,0x11,0x30,0x39,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x50,0xc8,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 15339 0x3beb "㯫" */
+0x10,0x10,0x10,0x13,0xfa,0x12,0x33,0x3a,0x56,0x53,0x92,0x13,0x12,0x15,0x14,0x19,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 15340 0x3bec "㯬" */
+0x10,0xfe,0x54,0x92,0x00,0x7b,0x08,0x17,0x20,0x7b,0x08,0x0b,0x50,0x27,0x58,0x87,
+0x10,0xfe,0x54,0x92,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x40,0xfc,0x40,0xfe,
+/* 15341 0x3bed "㯭" */
+0x10,0x10,0x10,0x13,0xfa,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x15,0x14,0x19,
+0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x20,0xfc,0x44,0x8c,
+/* 15342 0x3bee "㯮" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x31,0x3a,0x55,0x51,0x91,0x11,0x10,0x13,0x10,0x10,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfe,0x42,0xf2,0x52,0x52,0xf2,0x4a,0xfa,0x0a,0x04,
+/* 15343 0x3bef "㯯" */
+0x10,0x11,0x12,0x10,0xfb,0x10,0x31,0x39,0x54,0x51,0x91,0x11,0x11,0x11,0x10,0x11,
+0x80,0xfc,0x88,0x70,0xae,0xf8,0x20,0xfc,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 15344 0x3bf0 "㯰" */
+0x11,0x11,0x11,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x17,
+0xfc,0x54,0x54,0xfc,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,
+/* 15345 0x3bf1 "㯱" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x90,0x1f,0x21,0x7f,0x11,0x1f,0x01,0xff,0x09,0x71,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x02,0xf8,0x00,0xfc,0x10,0xf0,0x00,0xfe,0x20,0x1c,
+/* 15346 0x3bf2 "㯲" */
+0x21,0x21,0x27,0x21,0xfb,0x25,0x29,0x70,0x6b,0xa0,0xa7,0x20,0x22,0x24,0x29,0x20,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 15347 0x3bf3 "㯳" */
+0x22,0x22,0x27,0xfa,0x24,0x27,0x74,0x68,0xaf,0xa5,0x25,0x27,0x25,0x20,0x22,0x21,
+0x88,0x88,0xe8,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x94,0x22,
+/* 15348 0x3bf4 "㯴" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x32,0x38,0x55,0x54,0x90,0x11,0x12,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x20,0xfe,0x02,0x88,0x24,0x50,0x88,0xfc,0x8a,0x88,0xf8,0x88,
+/* 15349 0x3bf5 "㯵" */
+0x21,0x27,0x21,0x23,0xf8,0x27,0x20,0x73,0x6a,0xa3,0xa2,0x23,0x20,0x27,0x20,0x2f,
+0x10,0xfe,0x10,0xf8,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,
+/* 15350 0x3bf6 "㯶" */
+0x10,0x10,0x12,0x13,0xfe,0x12,0x32,0x3b,0x54,0x51,0x92,0x10,0x11,0x10,0x10,0x17,
+0x20,0x88,0x52,0x26,0x52,0x8a,0x22,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 15351 0x3bf7 "㯷" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x36,0x6a,0x62,0xa2,0xa2,0x22,0x22,0x22,0x22,0x22,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 15352 0x3bf8 "㯸" */
+0x20,0x23,0x20,0x27,0xf8,0x23,0x20,0x77,0x68,0xa2,0xa4,0x23,0x22,0x22,0x2f,0x20,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 15353 0x3bf9 "㯹" */
+0x20,0x2f,0x22,0x2f,0xfa,0x2a,0x2f,0x70,0x6f,0xa0,0xaf,0x21,0x25,0x25,0x29,0x23,
+0x04,0xe4,0x84,0xe4,0xbe,0xa4,0xe4,0x04,0xd4,0x0c,0xec,0x04,0x44,0x24,0x24,0x0c,
+/* 15354 0x3bfa "㯺" */
+0x00,0x7e,0x48,0x7e,0x43,0x7e,0x48,0x48,0x7e,0x00,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x40,0x40,0x7e,0xa0,0x10,0xfe,0xaa,0xaa,0xfe,0x00,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15355 0x3bfb "㯻" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x82,0x0d,0x32,0x0d,0x32,0x0d,0x31,0xff,0x09,0x71,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x12,0x20,0xc0,0xa0,0x90,0x88,0x00,0xfe,0x20,0x1c,
+/* 15356 0x3bfc "㯼" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x33,0x38,0x54,0x55,0x90,0x11,0x11,0x11,0x17,0x10,
+0x88,0xfe,0x88,0x20,0xfc,0x20,0xfe,0x40,0x88,0xfc,0x00,0xfc,0x54,0x54,0xfe,0x00,
+/* 15357 0x3bfd "㯽" */
+0x10,0x17,0x14,0x13,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x20,0xfe,0x02,0xfc,0x24,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 15358 0x3bfe "㯾" */
+0x20,0x24,0x22,0x22,0xf8,0x20,0x2e,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x28,0xfe,0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,
+/* 15359 0x3bff "㯿" */
+0x11,0x12,0x11,0x10,0xfb,0x12,0x32,0x3a,0x57,0x52,0x93,0x12,0x13,0x12,0x12,0x13,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 15360 0x3c00 "㰀" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x32,0x38,0x54,0x50,0x93,0x10,0x10,0x10,0x11,0x10,
+0x50,0x90,0x9e,0xea,0x8a,0xd2,0x8a,0xa4,0x50,0x88,0x26,0xa8,0x70,0xa8,0x24,0x60,
+/* 15361 0x3c01 "㰁" */
+0x20,0x27,0x21,0xfb,0x25,0x21,0x71,0x68,0xaf,0xa2,0x27,0x24,0x2c,0x24,0x27,0x24,
+0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xbe,0x08,0x9e,0x92,0xb2,0x92,0x9e,0x92,
+/* 15362 0x3c02 "㰂" */
+0x20,0x23,0x22,0x24,0xfb,0x21,0x20,0x73,0x69,0xa2,0xa5,0x21,0x21,0x21,0x21,0x21,
+0x20,0xfe,0x02,0x1c,0xe0,0x24,0xa8,0xfe,0x24,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 15363 0x3c03 "㰃" */
+0x22,0x24,0x2f,0x28,0xff,0x28,0x2f,0x72,0x6f,0xaa,0xaa,0x2a,0x2a,0x2b,0x22,0x22,
+0x06,0x38,0x88,0x92,0xa4,0xbc,0x88,0x14,0xbe,0x8a,0x88,0xac,0xaa,0xca,0x28,0x10,
+/* 15364 0x3c04 "㰄" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x24,0x77,0x6c,0xa4,0xa7,0x20,0x25,0x24,0x28,0x20,
+0x14,0x92,0x9e,0xf0,0x94,0x8a,0x96,0xe2,0x94,0x92,0x9e,0x70,0x14,0x8a,0x96,0x62,
+/* 15365 0x3c05 "㰅" */
+0x20,0x20,0x24,0x22,0xfa,0x20,0x20,0x76,0x6a,0xa2,0xa2,0x22,0x22,0x25,0x28,0x20,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x92,0xfe,0x92,0xba,0xaa,0xba,0x86,0x00,0xfe,0x00,
+/* 15366 0x3c06 "㰆" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x82,0x3e,0x02,0x7e,0x02,0x01,0x7f,0x05,0x19,0xe1,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x82,0xf8,0x80,0xfc,0x80,0x00,0xfc,0x40,0x30,0x0e,
+/* 15367 0x3c07 "㰇" */
+0x21,0x21,0x27,0x21,0xf1,0x2f,0x22,0x76,0x6a,0xa6,0xa2,0x26,0x22,0x22,0x2f,0x20,
+0x14,0x12,0xd2,0x10,0x10,0xfe,0x90,0xd2,0x92,0xd2,0x94,0xd4,0x8a,0xca,0x16,0x22,
+/* 15368 0x3c08 "㰈" */
+0x10,0xfe,0x54,0x92,0x00,0x27,0x10,0x13,0x02,0x73,0x12,0x13,0x10,0x17,0x28,0x47,
+0x10,0xfe,0x54,0x92,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,
+/* 15369 0x3c09 "㰉" */
+0x20,0x20,0x2f,0x24,0xf4,0x29,0x2f,0x72,0x6a,0xaf,0xa2,0x22,0x23,0x2e,0x24,0x20,
+0x10,0x10,0x7e,0x10,0x3c,0x10,0x7e,0x24,0x4a,0x30,0x10,0x7e,0x38,0x54,0x92,0x10,
+/* 15370 0x3c0a "㰊" */
+0x21,0x21,0x27,0x21,0xf1,0x2f,0x20,0x74,0x69,0xa1,0xa7,0x21,0x21,0x21,0x2e,0x24,
+0x08,0x08,0xaa,0x2c,0x08,0xd4,0x12,0xa2,0x48,0x08,0xaa,0x2c,0x08,0x94,0x24,0x42,
+/* 15371 0x3c0b "㰋" */
+0x21,0x21,0x25,0x25,0xf5,0x25,0x2f,0x70,0x69,0xa5,0xa5,0x25,0x28,0x21,0x22,0x2c,
+0x00,0x3e,0x08,0xd0,0x3e,0x22,0xe2,0x3e,0x22,0x7e,0x62,0xa2,0xbe,0x00,0x14,0x22,
+/* 15372 0x3c0c "㰌" */
+0x11,0x10,0x13,0x12,0xfd,0x10,0x31,0x38,0x55,0x53,0x95,0x11,0x11,0x11,0x11,0x11,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 15373 0x3c0d "㰍" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 15374 0x3c0e "㰎" */
+0x10,0x12,0x13,0x10,0xfd,0x13,0x35,0x39,0x55,0x55,0x91,0x11,0x13,0x12,0x12,0x12,
+0x20,0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xde,0x52,0x72,0x06,
+/* 15375 0x3c0f "㰏" */
+0x11,0x11,0x12,0x10,0xfb,0x10,0x30,0x38,0x54,0x50,0x93,0x12,0x12,0x12,0x12,0x12,
+0x08,0xee,0x94,0x20,0xfe,0x00,0xf8,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x06,
+/* 15376 0x3c10 "㰐" */
+0x20,0x27,0x25,0x25,0xfd,0x26,0x25,0x75,0x6d,0xa5,0xa5,0x26,0x24,0x24,0x24,0x25,
+0x08,0x3e,0x90,0x5e,0x64,0x5e,0x00,0xde,0x52,0x5e,0x52,0x5e,0x52,0x56,0xa0,0x1e,
+/* 15377 0x3c11 "㰑" */
+0x20,0x22,0x22,0x24,0xf8,0x22,0x31,0x6a,0x6a,0xa1,0xa0,0x2f,0x21,0x22,0x2c,0x20,
+0x20,0x94,0x8a,0x7a,0x00,0x8a,0x44,0x28,0xaa,0x86,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 15378 0x3c12 "㰒" */
+0x22,0x24,0x24,0x26,0xfc,0x26,0x34,0x6f,0x68,0xa3,0xa0,0x20,0x27,0x20,0x21,0x20,
+0xa0,0x4c,0xa4,0x0c,0xa4,0x4c,0xa4,0xfe,0x02,0xf0,0x20,0x40,0xfc,0x40,0x40,0x80,
+/* 15379 0x3c13 "㰓" */
+0x27,0x25,0x27,0x24,0xf7,0x25,0x27,0x73,0x6a,0xa3,0xa2,0x23,0x22,0x23,0x21,0x22,
+0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 15380 0x3c14 "㰔" */
+0x22,0x22,0x23,0x26,0xfa,0x22,0x32,0x6a,0x65,0xa8,0xa0,0x23,0x21,0x20,0x23,0x2c,
+0x48,0xe8,0x08,0xea,0x1c,0xe8,0x08,0xe8,0xb4,0xe2,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 15381 0x3c15 "㰕" */
+0x21,0x27,0x20,0x23,0xf8,0x27,0x20,0x73,0x69,0xa7,0xa3,0x25,0x23,0x20,0x22,0x21,
+0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xd4,0x12,0xfe,0x50,0x34,0x8c,0x8a,0x96,0x02,
+/* 15382 0x3c16 "㰖" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x33,0x39,0x55,0x51,0x91,0x11,0x11,0x10,0x11,0x16,
+0xd0,0x90,0xde,0x68,0xc4,0x84,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x12,0x0e,
+/* 15383 0x3c17 "㰗" */
+0x20,0x27,0x24,0x24,0xfc,0x27,0x35,0x6a,0x61,0xa3,0xa2,0x23,0x20,0x22,0x25,0x28,
+0x14,0xfe,0x90,0xd4,0x94,0xfa,0xaa,0x96,0xa2,0xf8,0x08,0xf8,0x40,0x7c,0x40,0xfe,
+/* 15384 0x3c18 "㰘" */
+0x20,0x20,0x21,0x21,0xf8,0x27,0x25,0x73,0x6f,0xa1,0xa3,0x25,0x20,0x27,0x20,0x21,
+0x80,0xf8,0x08,0xf0,0x10,0xfe,0x54,0xbc,0xca,0x3e,0x88,0x6a,0x88,0xfe,0x88,0x08,
+/* 15385 0x3c19 "㰙" */
+0x25,0x25,0x2f,0x25,0xf7,0x22,0x2f,0x7a,0x6f,0xa2,0xaf,0x22,0x3f,0x25,0x28,0x30,
+0x18,0x14,0x90,0x3e,0x28,0x68,0xbe,0xa8,0xa8,0x3e,0xa8,0x28,0xe8,0x3e,0xa0,0x60,
+/* 15386 0x3c1a "㰚" */
+0x22,0x21,0x27,0x22,0xf5,0x26,0x24,0x77,0x69,0xa7,0xa5,0x25,0x25,0x24,0x25,0x24,
+0x0c,0x0a,0xc8,0x9e,0x54,0xf4,0x5e,0xd4,0x14,0xde,0x54,0x54,0xd4,0x5e,0x50,0x90,
+/* 15387 0x3c1b "㰛" */
+0x21,0x2f,0x25,0x24,0xf8,0x2a,0x2e,0x74,0x6a,0xae,0xa2,0x2f,0x21,0x22,0x2c,0x20,
+0x10,0xfe,0x54,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0xfe,0x50,0x48,0x46,0x40,
+/* 15388 0x3c1c "㰜" */
+0x22,0x22,0x2f,0x22,0xf7,0x24,0x27,0x74,0x6f,0xa4,0xa7,0x24,0x2f,0x25,0x24,0x28,
+0x00,0x1e,0xc4,0x08,0x9e,0x92,0x92,0x9e,0x92,0x9e,0x92,0x92,0xde,0x00,0x8c,0x92,
+/* 15389 0x3c1d "㰝" */
+0x00,0x3e,0x22,0x22,0x22,0x22,0x23,0x3e,0x20,0x20,0x20,0x22,0x2c,0x30,0x21,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15390 0x3c1e "㰞" */
+0x08,0x08,0x08,0x08,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x4f,0x79,0x00,0x00,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15391 0x3c1f "㰟" */
+0x20,0x20,0x7f,0x80,0x00,0x7e,0x00,0x00,0xfc,0x04,0x04,0x05,0x05,0x03,0x01,0x00,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15392 0x3c20 "㰠" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x80,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15393 0x3c21 "㰡" */
+0x08,0x08,0x14,0x12,0x21,0x40,0x92,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x82,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15394 0x3c22 "㰢" */
+0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x85,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15395 0x3c23 "㰣" */
+0x14,0x14,0x14,0x54,0x55,0x5e,0x54,0x54,0x54,0x54,0x54,0x54,0x5d,0x76,0xc4,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15396 0x3c24 "㰤" */
+0x00,0x00,0xff,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x05,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15397 0x3c25 "㰥" */
+0x12,0x52,0x52,0x52,0x52,0xff,0x52,0x52,0x52,0x5e,0x40,0x40,0x40,0x7f,0x00,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0xc4,0x84,0x02,
+/* 15398 0x3c26 "㰦" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x10,0x10,0x24,0x42,0xff,0x41,0x00,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x90,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15399 0x3c27 "㰧" */
+0x10,0x10,0x20,0x28,0x44,0xfe,0x43,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15400 0x3c28 "㰨" */
+0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x00,0x24,0x22,0x42,0x42,0x80,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15401 0x3c29 "㰩" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15402 0x3c2a "㰪" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x41,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15403 0x3c2b "㰫" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0x08,0x7f,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x81,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15404 0x3c2c "㰬" */
+0x20,0x20,0x20,0x7f,0x41,0x81,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x0a,0x04,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15405 0x3c2d "㰭" */
+0x10,0x10,0xfe,0x28,0x44,0x82,0x7d,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x29,0x12,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15406 0x3c2e "㰮" */
+0x00,0x7f,0x40,0x40,0x5e,0x40,0x40,0x7f,0x50,0x51,0x5a,0x54,0x52,0x91,0x98,0x10,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15407 0x3c2f "㰯" */
+0x00,0xff,0x00,0x00,0x7e,0x42,0x42,0x42,0x7e,0x00,0x42,0x22,0x24,0x0f,0xf0,0x40,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15408 0x3c30 "㰰" */
+0x08,0x08,0x7f,0x08,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x14,0x14,0x22,0x42,0x80,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x90,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15409 0x3c31 "㰱" */
+0x07,0x78,0x08,0x08,0x7f,0x08,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0x08,0x08,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15410 0x3c32 "㰲" */
+0x04,0x05,0x04,0xff,0x04,0x04,0x75,0x55,0x55,0x73,0x02,0x32,0xc5,0x08,0x10,0x00,
+0x20,0x20,0xa0,0xbe,0x22,0x44,0x50,0x90,0x10,0x10,0x90,0xa8,0xa8,0xc4,0x44,0x82,
+/* 15411 0x3c33 "㰳" */
+0x00,0xfe,0x28,0x28,0x28,0xee,0x83,0x82,0x82,0xee,0x28,0x28,0x2e,0xf0,0x41,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15412 0x3c34 "㰴" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15413 0x3c35 "㰵" */
+0x10,0x08,0x00,0x7f,0x00,0x22,0x22,0x55,0x88,0x08,0xff,0x08,0x08,0x08,0x08,0x09,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x90,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15414 0x3c36 "㰶" */
+0x22,0x22,0x3a,0x4b,0x4a,0xaa,0x12,0x28,0x47,0x80,0x3f,0x21,0x21,0x21,0x3f,0x21,
+0x20,0x20,0x20,0x3e,0xa2,0x44,0x50,0x90,0x90,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 15415 0x3c37 "㰷" */
+0x00,0x00,0xff,0x22,0x22,0x3a,0x4a,0x4b,0x4a,0xaa,0x12,0x12,0x22,0x23,0x42,0x80,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x90,0x10,0x10,0x28,0x28,0xa8,0x44,0x44,0x82,
+/* 15416 0x3c38 "㰸" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x14,0x22,0x41,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15417 0x3c39 "㰹" */
+0x01,0x01,0x01,0x7f,0x41,0x41,0x5d,0x41,0x41,0x5d,0x55,0x55,0x5d,0x41,0x42,0x84,
+0x10,0x90,0x50,0x9e,0x12,0x22,0x08,0x48,0x48,0x48,0x88,0x94,0x54,0x54,0xd4,0x62,
+/* 15418 0x3c3a "㰺" */
+0x00,0x77,0x51,0x51,0x51,0x77,0x40,0x40,0x77,0x41,0x49,0x75,0x42,0x42,0x45,0x49,
+0x20,0x20,0x20,0x3e,0x22,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 15419 0x3c3b "㰻" */
+0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,0x40,
+0x20,0x20,0x20,0x3e,0x22,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 15420 0x3c3c "㰼" */
+0x00,0xff,0x88,0x88,0xfe,0x88,0xaa,0xaa,0xdd,0x88,0x94,0x92,0xa1,0xc0,0xff,0x00,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15421 0x3c3d "㰽" */
+0x00,0xff,0x80,0xbf,0xa1,0xbf,0xa1,0xbf,0x88,0xff,0x92,0xb2,0x8c,0x92,0xa1,0xff,
+0x20,0xa0,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x90,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15422 0x3c3e "㰾" */
+0x08,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x10,0x08,0xff,0x20,0x3e,0x22,0x42,0x4a,0x85,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15423 0x3c3f "㰿" */
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x45,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x45,0x82,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15424 0x3c40 "㱀" */
+0x20,0x20,0x7f,0x91,0x55,0x7d,0x21,0x4a,0xa4,0x7f,0x91,0x55,0x7d,0x21,0x4a,0x84,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15425 0x3c41 "㱁" */
+0x08,0x2a,0x2a,0x3e,0x49,0x49,0x7f,0x00,0x3e,0x00,0x7f,0x08,0x2a,0x49,0x28,0x11,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15426 0x3c42 "㱂" */
+0x04,0x02,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x22,0x32,0x2a,0x27,0x4a,0x52,0x86,
+0x10,0x10,0xd0,0x1e,0x92,0xa4,0xc8,0x88,0x88,0x08,0x48,0x94,0x14,0x94,0x54,0x22,
+/* 15427 0x3c43 "㱃" */
+0x08,0x14,0x22,0x49,0xbe,0x04,0x08,0xff,0x14,0x7f,0x55,0x63,0x41,0x7f,0x41,0x7f,
+0x20,0x20,0x20,0x7e,0xc2,0x84,0x10,0x90,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15428 0x3c44 "㱄" */
+0x00,0x7f,0x49,0x6b,0x5d,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x01,0x55,0x54,0x40,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15429 0x3c45 "㱅" */
+0x08,0xff,0x08,0x7f,0x00,0xff,0x80,0x7f,0x00,0x7f,0x41,0x7f,0x41,0x22,0x0f,0xf0,
+0x20,0xa0,0x20,0x7e,0x42,0x84,0x90,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0xc4,0x82,
+/* 15430 0x3c46 "㱆" */
+0x08,0x0f,0x08,0x7f,0x49,0x4c,0x79,0x47,0x40,0x5f,0x40,0x5f,0x51,0x5f,0x8a,0x3f,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15431 0x3c47 "㱇" */
+0x08,0x7f,0x2a,0x2a,0x5d,0x08,0xff,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x7f,0x41,
+0x20,0x20,0x20,0x3e,0x22,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 15432 0x3c48 "㱈" */
+0x22,0x22,0xf7,0x22,0x77,0xaa,0x22,0x00,0x7f,0x00,0xff,0x08,0x49,0x88,0x28,0x10,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x50,0x10,0x10,0x10,0xa8,0x28,0x28,0xc4,0x44,0x82,
+/* 15433 0x3c49 "㱉" */
+0x14,0x55,0x36,0x14,0xff,0x22,0x14,0x7f,0x08,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x08,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15434 0x3c4a "㱊" */
+0xff,0x10,0x7e,0x42,0x7e,0x42,0xff,0x91,0x4a,0xa5,0x1c,0x20,0x7e,0xa2,0x1c,0xe2,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15435 0x3c4b "㱋" */
+0x3f,0x04,0x7f,0x44,0xb5,0x04,0x35,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x90,0x10,0xd0,0x5e,0x92,0x24,0x88,0x08,0xc8,0x08,0x88,0x14,0x94,0x14,0xd4,0x22,
+/* 15436 0x3c4c "㱌" */
+0x7f,0x21,0x3f,0x21,0x3f,0x21,0xff,0x01,0xff,0x52,0x73,0x52,0x73,0x5a,0xf7,0x10,
+0x88,0x08,0x08,0x08,0x1e,0xd2,0x24,0x00,0xc8,0x88,0x88,0x88,0x94,0xd4,0xa4,0xc2,
+/* 15437 0x3c4d "㱍" */
+0x48,0x44,0x40,0x5e,0xa0,0xae,0xc0,0x4e,0x40,0x8e,0xaa,0xea,0x0a,0xae,0xaa,0x00,
+0x48,0x48,0x48,0x4e,0xaa,0xb2,0xc4,0x44,0x44,0x84,0xa4,0xea,0x0a,0xaa,0xaa,0x10,
+/* 15438 0x3c4e "㱎" */
+0x7f,0x55,0x7f,0x2a,0x49,0x2a,0x61,0x3e,0x44,0xff,0x49,0x7f,0x49,0x7f,0x00,0xaa,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 15439 0x3c4f "㱏" */
+0x00,0x1f,0x00,0x00,0x00,0x7f,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0xf0,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 15440 0x3c50 "㱐" */
+0x00,0x00,0x3f,0x00,0x00,0xff,0x00,0x04,0x04,0x27,0x24,0x24,0x24,0x27,0xf8,0x40,
+0x00,0x10,0x08,0x08,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 15441 0x3c51 "㱑" */
+0x01,0x01,0x11,0x11,0x11,0xff,0x02,0x04,0x0f,0x10,0x68,0x04,0x02,0x03,0x1c,0xe0,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 15442 0x3c52 "㱒" */
+0x01,0x01,0x11,0x11,0x11,0xff,0x00,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0xfe,0x10,0x90,0x90,0x90,0x90,0x10,0x50,0x20,
+/* 15443 0x3c53 "㱓" */
+0x08,0x08,0x08,0x48,0x4e,0x49,0x4a,0x48,0x49,0x48,0x48,0x48,0x4e,0xf0,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 15444 0x3c54 "㱔" */
+0x04,0x04,0x17,0x14,0x14,0x17,0x78,0x02,0x07,0x08,0x34,0x02,0x00,0x03,0x0c,0x70,
+0x40,0x44,0x48,0x70,0x42,0x42,0x3e,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 15445 0x3c55 "㱕" */
+0x10,0x11,0x10,0x10,0x50,0x5d,0x50,0x53,0x52,0x50,0x51,0x5d,0x71,0xc1,0x01,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 15446 0x3c56 "㱖" */
+0x10,0x10,0x13,0x10,0x50,0x5c,0x51,0x52,0x50,0x50,0x53,0x5c,0x70,0xc0,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 15447 0x3c57 "㱗" */
+0x10,0x10,0x11,0x11,0x51,0x5d,0x51,0x51,0x51,0x50,0x50,0x5d,0x70,0xc0,0x01,0x02,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x88,0x04,0x02,
+/* 15448 0x3c58 "㱘" */
+0x3f,0x29,0x2f,0x29,0x2f,0x20,0x2f,0x29,0x2f,0x29,0x2f,0x29,0x4b,0x44,0x84,0x1f,
+0xfe,0x14,0x12,0x10,0x7e,0x10,0x28,0x28,0x28,0x44,0x44,0x82,0x40,0x7c,0x40,0xfe,
+/* 15449 0x3c59 "㱙" */
+0x00,0x03,0xfc,0x20,0x20,0x3c,0x45,0x45,0x64,0x94,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0xfe,0x40,0x40,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 15450 0x3c5a "㱚" */
+0x00,0x00,0xfc,0x20,0x20,0x3c,0x44,0x44,0x64,0x94,0x08,0x08,0x11,0x21,0x42,0x84,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 15451 0x3c5b "㱛" */
+0x00,0x00,0xfd,0x20,0x20,0x3c,0x44,0x44,0x64,0x95,0x0a,0x08,0x10,0x20,0x40,0x80,
+0x00,0x00,0xfe,0x20,0x20,0x7c,0x44,0x84,0x84,0x48,0x28,0x10,0x10,0x20,0x40,0x80,
+/* 15452 0x3c5c "㱜" */
+0x00,0x00,0xfc,0x20,0x20,0x3c,0x45,0x45,0x65,0x95,0x09,0x09,0x12,0x22,0x44,0x88,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 15453 0x3c5d "㱝" */
+0x00,0x00,0xff,0x22,0x22,0x3a,0x4a,0x4b,0x4a,0xaa,0x12,0x12,0x22,0x23,0x42,0x80,
+0x10,0x10,0x90,0x10,0x7e,0x12,0x12,0x92,0x12,0x12,0x12,0x12,0x92,0x22,0x2a,0x44,
+/* 15454 0x3c5e "㱞" */
+0x00,0x00,0xfc,0x20,0x23,0x3c,0x44,0x45,0x65,0x94,0x08,0x08,0x10,0x20,0x47,0x80,
+0x80,0x40,0x40,0x00,0xfc,0x00,0x08,0x08,0x08,0x90,0x90,0x90,0xa0,0x20,0xfe,0x00,
+/* 15455 0x3c5f "㱟" */
+0x00,0x00,0xfc,0x21,0x21,0x3d,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x22,0x42,0x84,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15456 0x3c60 "㱠" */
+0x00,0x00,0xfc,0x20,0x23,0x3c,0x44,0x44,0x65,0x95,0x09,0x09,0x11,0x21,0x41,0x81,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15457 0x3c61 "㱡" */
+0x00,0x01,0xfd,0x21,0x21,0x3e,0x44,0x47,0x64,0x94,0x08,0x08,0x11,0x21,0x42,0x84,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 15458 0x3c62 "㱢" */
+0x00,0x00,0xfd,0x21,0x21,0x3d,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x21,0x41,0x81,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 15459 0x3c63 "㱣" */
+0x00,0x00,0xfd,0x20,0x21,0x3c,0x44,0x44,0x65,0x94,0x08,0x09,0x10,0x20,0x40,0x83,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xfe,0x44,0x84,0xc8,0x30,0x28,0xc4,0x02,
+/* 15460 0x3c64 "㱤" */
+0x00,0x00,0xf8,0x20,0x23,0x38,0x48,0x49,0x69,0x9a,0x0a,0x14,0x10,0x20,0x40,0x80,
+0x80,0x86,0x98,0x90,0xd0,0x90,0x9e,0x94,0xd4,0xb4,0x94,0x94,0x94,0x94,0x94,0xa4,
+/* 15461 0x3c65 "㱥" */
+0x00,0x00,0xf9,0x20,0x20,0x3b,0x48,0x49,0x6a,0x98,0x09,0x12,0x10,0x20,0x41,0x86,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 15462 0x3c66 "㱦" */
+0x00,0x00,0xfd,0x20,0x20,0x3d,0x47,0x44,0x65,0x95,0x09,0x09,0x11,0x20,0x40,0x80,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 15463 0x3c67 "㱧" */
+0x00,0x00,0xfb,0x22,0x25,0x39,0x49,0x4a,0x6a,0x9b,0x0c,0x10,0x11,0x21,0x42,0x84,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 15464 0x3c68 "㱨" */
+0x00,0x00,0xfb,0x22,0x24,0x38,0x4b,0x48,0x68,0x99,0x09,0x11,0x12,0x22,0x44,0x88,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 15465 0x3c69 "㱩" */
+0x00,0x00,0xf9,0x20,0x20,0x3b,0x48,0x48,0x68,0x99,0x08,0x13,0x10,0x20,0x40,0x83,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x10,0x90,0xfe,0x28,0x44,0x82,0x02,
+/* 15466 0x3c6a "㱪" */
+0x00,0x01,0xfd,0x21,0x21,0x3d,0x45,0x45,0x65,0x94,0x09,0x09,0x11,0x21,0x41,0x81,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 15467 0x3c6b "㱫" */
+0x00,0xfc,0x23,0x20,0x21,0x3d,0x45,0x45,0x65,0x95,0x08,0x08,0x10,0x21,0x42,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 15468 0x3c6c "㱬" */
+0x00,0x03,0xfa,0x22,0x23,0x3a,0x4a,0x4b,0x68,0x9f,0x0a,0x12,0x12,0x22,0x43,0x82,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 15469 0x3c6d "㱭" */
+0x00,0x03,0xfa,0x22,0x23,0x3a,0x4a,0x4a,0x6b,0x9a,0x0a,0x13,0x16,0x22,0x42,0x82,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 15470 0x3c6e "㱮" */
+0x00,0x00,0xfd,0x21,0x21,0x3c,0x47,0x44,0x65,0x95,0x09,0x09,0x11,0x20,0x40,0x83,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 15471 0x3c6f "㱯" */
+0x00,0x01,0xfd,0x21,0x21,0x3c,0x47,0x44,0x65,0x95,0x09,0x09,0x10,0x20,0x43,0x80,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 15472 0x3c70 "㱰" */
+0x00,0xfc,0x23,0x22,0x20,0x3d,0x44,0x44,0x67,0x94,0x08,0x09,0x10,0x20,0x40,0x80,
+0x40,0x20,0xfe,0x42,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 15473 0x3c71 "㱱" */
+0x00,0x00,0xfb,0x22,0x22,0x3b,0x4a,0x4a,0x6b,0x98,0x08,0x10,0x11,0x21,0x42,0x84,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 15474 0x3c72 "㱲" */
+0x02,0x01,0xf9,0x20,0x27,0x38,0x49,0x4a,0x6c,0x9b,0x0a,0x12,0x12,0x22,0x4f,0x80,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 15475 0x3c73 "㱳" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x10,0x2f,0xc2,0x0f,0x04,0x3f,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xe8,0x06,0xe0,0x40,0x80,
+/* 15476 0x3c74 "㱴" */
+0x00,0x03,0xf8,0x21,0x20,0x3b,0x48,0x49,0x69,0x99,0x09,0x11,0x11,0x21,0x40,0x81,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 15477 0x3c75 "㱵" */
+0x00,0x01,0xfc,0x20,0x23,0x3c,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x20,0x41,0x82,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 15478 0x3c76 "㱶" */
+0x00,0x00,0xfb,0x20,0x20,0x3b,0x48,0x4b,0x6a,0x9a,0x0b,0x12,0x11,0x20,0x47,0x82,
+0x82,0x82,0xf4,0x88,0x80,0xe2,0x02,0xe4,0x28,0x20,0xe0,0x22,0x42,0x74,0x88,0x10,
+/* 15479 0x3c77 "㱷" */
+0x00,0x00,0xfd,0x23,0x21,0x3d,0x45,0x45,0x65,0x95,0x08,0x0b,0x10,0x20,0x43,0x80,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 15480 0x3c78 "㱸" */
+0x00,0x03,0xfa,0x22,0x22,0x3b,0x4a,0x4a,0x6b,0x9a,0x0e,0x12,0x12,0x23,0x42,0x80,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 15481 0x3c79 "㱹" */
+0x00,0x03,0xfa,0x22,0x22,0x3b,0x4a,0x4a,0x6b,0x9a,0x0a,0x12,0x12,0x24,0x44,0x8b,
+0x00,0xfe,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x44,0x10,0x90,0x9e,0x90,0x90,0xfe,
+/* 15482 0x3c7a "㱺" */
+0x00,0x00,0xf8,0x23,0x22,0x3b,0x4a,0x4a,0x6a,0x9a,0x0a,0x12,0x12,0x25,0x45,0x8b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 15483 0x3c7b "㱻" */
+0x00,0x1f,0xe4,0x47,0x40,0x77,0x54,0x97,0x51,0x2e,0x2b,0x2e,0x4a,0x4e,0x8b,0x16,
+0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x10,0xae,0xfa,0x4a,0xee,0x4a,0xfa,0x50,
+/* 15484 0x3c7c "㱼" */
+0x00,0x3e,0x22,0x22,0x22,0x22,0x22,0x3e,0x20,0x20,0x20,0x22,0x2c,0x30,0x20,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15485 0x3c7d "㱽" */
+0x08,0x08,0x08,0x7f,0x49,0x08,0x08,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15486 0x3c7e "㱾" */
+0x10,0x08,0x08,0xff,0x08,0x10,0x22,0x7c,0x09,0x12,0x24,0xc8,0x14,0x22,0xc0,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15487 0x3c7f "㱿" */
+0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0xfe,0x82,0x82,0xba,0x82,0x82,0x8a,0x85,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15488 0x3c80 "㲀" */
+0x00,0x7f,0x40,0x40,0x5e,0x40,0x40,0x7e,0x50,0x51,0x5a,0x54,0x52,0x51,0x98,0x11,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15489 0x3c81 "㲁" */
+0x20,0x10,0xfe,0x82,0x28,0x44,0x82,0x00,0x7c,0x10,0x10,0x10,0x1e,0xf0,0x40,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15490 0x3c82 "㲂" */
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xba,0x82,0x8a,0x85,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15491 0x3c83 "㲃" */
+0x10,0x10,0x1e,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x00,0x20,0x3e,0x20,0x22,0x2c,0x31,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15492 0x3c84 "㲄" */
+0x10,0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x00,0x7c,0x10,0x7c,0x10,0x1e,0xf0,0x41,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15493 0x3c85 "㲅" */
+0x20,0x10,0xfe,0x82,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x7c,0x44,0x44,0x7c,0x45,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15494 0x3c86 "㲆" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x41,0x82,0x0c,0x31,0xcf,0x00,0x06,0x01,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0x60,0x18,0xe6,0x40,0x80,0x80,
+/* 15495 0x3c87 "㲇" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x48,0x9f,0x28,0x07,0x18,0xe1,0x0c,0x03,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xf4,0x20,0xc0,0x30,0x8e,0x40,0x00,
+/* 15496 0x3c88 "㲈" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x80,0x7f,0x08,0x10,0x3f,0xd0,0x1f,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x86,0xf8,0x08,0x30,0xf8,0x08,0xf8,
+/* 15497 0x3c89 "㲉" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x20,0xce,0xaa,0xee,0xaa,0xee,0x28,0x49,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15498 0x3c8a "㲊" */
+0x10,0x1f,0x10,0xff,0x80,0x7f,0x2a,0x55,0xa2,0x7f,0xa2,0x3e,0x22,0x3e,0x22,0x3e,
+0x00,0x38,0x28,0xa8,0xa8,0x46,0x00,0x7c,0x24,0x24,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 15499 0x3c8b "㲋" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x20,0x20,0x3f,0x00,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x00,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 15500 0x3c8c "㲌" */
+0x08,0x1d,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1d,0xf1,0x12,0x10,0x10,0x0f,0x00,
+0x00,0xf8,0x48,0x48,0x50,0x5c,0x84,0x84,0x84,0x04,0x28,0x12,0x02,0x02,0xfe,0x00,
+/* 15501 0x3c8d "㲍" */
+0x10,0x10,0x11,0xfe,0x10,0x11,0xfc,0x44,0x47,0x28,0x28,0x10,0x18,0x24,0x43,0x80,
+0x10,0x38,0xc0,0x40,0x78,0xc0,0x40,0x7c,0xc0,0x44,0x44,0x44,0x3c,0x00,0xfe,0x00,
+/* 15502 0x3c8e "㲎" */
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0xf0,0x10,0x14,0x18,0x10,0x00,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15503 0x3c8f "㲏" */
+0x04,0x24,0x25,0x24,0x24,0x3e,0x21,0x20,0x3c,0x24,0x27,0x24,0x24,0x44,0x44,0x84,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 15504 0x3c90 "㲐" */
+0x08,0x1c,0x70,0x10,0x10,0x1d,0x72,0x10,0x10,0x1c,0xf0,0x10,0x10,0x10,0x0f,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x10,0x22,0x22,0x02,0xfe,0x00,
+/* 15505 0x3c91 "㲑" */
+0x08,0x1c,0x70,0x10,0x11,0x1c,0x70,0x11,0x11,0x1d,0xf2,0x10,0x10,0x10,0x0f,0x00,
+0x20,0x20,0x20,0x24,0xa8,0xb0,0xb0,0x28,0x28,0x24,0x24,0xa0,0x40,0x02,0xfe,0x00,
+/* 15506 0x3c92 "㲒" */
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x14,0x08,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15507 0x3c93 "㲓" */
+0x08,0x1c,0x70,0x11,0x11,0x1d,0x71,0x11,0x11,0x1d,0xf1,0x11,0x12,0x10,0x0f,0x00,
+0x28,0x24,0x24,0xfe,0x20,0x28,0xa8,0x50,0x14,0x34,0x4c,0x04,0x00,0x02,0xfe,0x00,
+/* 15508 0x3c94 "㲔" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15509 0x3c95 "㲕" */
+0x04,0x1e,0xe0,0x22,0x92,0x54,0x40,0x04,0xff,0x04,0x44,0x24,0x24,0x04,0x14,0x08,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15510 0x3c96 "㲖" */
+0x08,0x49,0x29,0x2a,0x08,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x41,0x45,0x42,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15511 0x3c97 "㲗" */
+0x04,0x1e,0xe0,0x02,0x92,0x4c,0x00,0xfe,0x04,0x08,0x0e,0xf8,0x48,0x08,0x28,0x10,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15512 0x3c98 "㲘" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x00,0x24,0x22,0x41,0x81,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15513 0x3c99 "㲙" */
+0x08,0x1c,0x71,0x10,0x10,0x1d,0x70,0x10,0x10,0x1c,0xf1,0x12,0x10,0x10,0x0f,0x00,
+0x40,0x20,0xfe,0x40,0x88,0xfc,0x04,0xa8,0xa8,0xa8,0x2a,0x26,0x00,0x02,0xfe,0x00,
+/* 15514 0x3c9a "㲚" */
+0x10,0x08,0x40,0x24,0x09,0x72,0x10,0x17,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x20,0x20,0xa8,0xa4,0x2a,0x30,0xc0,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 15515 0x3c9b "㲛" */
+0x20,0x3e,0x48,0x08,0xff,0x14,0x22,0x40,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 15516 0x3c9c "㲜" */
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x10,0x52,0x54,0x90,0x28,0x24,0x42,0x80,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15517 0x3c9d "㲝" */
+0x08,0x1c,0x70,0x11,0x12,0x1c,0x70,0x10,0x10,0x1c,0xf0,0x10,0x10,0x10,0x0f,0x00,
+0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,0x02,0xfe,0x00,
+/* 15518 0x3c9e "㲞" */
+0x10,0x08,0x00,0x7f,0x00,0x22,0x22,0x55,0x88,0x08,0xff,0x08,0x08,0x08,0x08,0x08,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x90,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15519 0x3c9f "㲟" */
+0x22,0x22,0x7f,0x22,0x2a,0x08,0x3e,0x2a,0x2a,0x2a,0xff,0x08,0x14,0x12,0x22,0x40,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15520 0x3ca0 "㲠" */
+0x08,0x08,0x7e,0x08,0xff,0x1c,0x2a,0x48,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 15521 0x3ca1 "㲡" */
+0x08,0x08,0x7f,0x1c,0x2a,0x49,0x00,0x7e,0x00,0xff,0x08,0x4a,0x49,0x89,0x28,0x10,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15522 0x3ca2 "㲢" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x40,0x7f,0x55,0x55,0x7f,0xd5,0x55,0x55,0x43,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15523 0x3ca3 "㲣" */
+0x50,0x96,0x92,0x92,0xd6,0x92,0x92,0xfe,0x10,0xfe,0x02,0x64,0x18,0x24,0xc2,0x00,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15524 0x3ca4 "㲤" */
+0x10,0x08,0x7f,0x00,0x3e,0x22,0xff,0x22,0x3e,0x18,0x35,0x52,0x91,0x14,0x18,0x10,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x9e,0x70,0x10,0x12,0x92,0x12,0x0e,
+/* 15525 0x3ca5 "㲥" */
+0x10,0x08,0x7f,0x48,0x5e,0x4a,0x7f,0x4a,0x5e,0x48,0x5e,0x52,0x52,0x52,0x5e,0x92,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15526 0x3ca6 "㲦" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x11,0x10,0x10,0x10,
+0x20,0x20,0x50,0x88,0x06,0x18,0xe0,0x20,0x38,0xe0,0x20,0x3c,0xe0,0x22,0x22,0x1e,
+/* 15527 0x3ca7 "㲧" */
+0x10,0x3b,0xe1,0x21,0x20,0x38,0xe1,0x26,0x21,0x39,0xe1,0x20,0x23,0x20,0x20,0x1f,
+0x00,0xf0,0x50,0x10,0xa0,0x40,0xb0,0x4e,0xf0,0x50,0xf0,0x48,0xfa,0x0a,0x02,0xfe,
+/* 15528 0x3ca8 "㲨" */
+0x24,0x24,0xfe,0x24,0x00,0xfe,0x24,0x3c,0x24,0x3c,0x24,0x2e,0xf4,0x04,0x04,0x04,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15529 0x3ca9 "㲩" */
+0x10,0x3b,0xe2,0x23,0x22,0x3b,0xe0,0x27,0x20,0x3c,0xe2,0x24,0x22,0x21,0x20,0x1f,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x96,0x0a,0x02,0xfe,
+/* 15530 0x3caa "㲪" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x5d,0x80,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15531 0x3cab "㲫" */
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15532 0x3cac "㲬" */
+0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0xaa,0xaa,0x00,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 15533 0x3cad "㲭" */
+0x08,0x29,0x29,0x4a,0x14,0x22,0x41,0x00,0x22,0x2a,0xb7,0x62,0x22,0x52,0x45,0x88,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x9e,0x70,0x10,0x12,0x12,0x12,0x8e,
+/* 15534 0x3cae "㲮" */
+0x12,0x3a,0xe3,0x25,0x20,0x38,0xe0,0x21,0x22,0x3c,0xe1,0x21,0x21,0x21,0x20,0x1f,
+0x10,0x10,0xde,0x28,0x84,0x40,0xa0,0x10,0xe8,0x04,0xf0,0x10,0x12,0xf2,0x02,0xfe,
+/* 15535 0x3caf "㲯" */
+0x00,0x7a,0x52,0x7b,0x4a,0x7b,0x54,0x78,0x00,0x7f,0x55,0x55,0x55,0x57,0xfc,0x00,
+0x04,0x0e,0x70,0x90,0x10,0x1c,0xf0,0x90,0x10,0x1e,0x70,0x10,0x12,0x92,0x12,0x0e,
+/* 15536 0x3cb0 "㲰" */
+0x08,0xff,0x91,0x4a,0xa5,0x1c,0x00,0x7f,0x55,0xff,0x00,0x7f,0x08,0x08,0x28,0x10,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x9e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 15537 0x3cb1 "㲱" */
+0x11,0x3a,0xe1,0x23,0x22,0x3a,0xe2,0x23,0x22,0x3b,0xe2,0x23,0x22,0x23,0x20,0x1f,
+0x24,0x48,0x24,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x46,0x62,0x02,0xfe,
+/* 15538 0x3cb2 "㲲" */
+0x7f,0x49,0x7f,0x49,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0xa2,0x3e,0x22,0x27,0xf8,
+0x04,0x0e,0x70,0x10,0x90,0x9c,0xf0,0x90,0x90,0x1e,0xf0,0x90,0x12,0x12,0x92,0x0e,
+/* 15539 0x3cb3 "㲳" */
+0x08,0x1c,0xf1,0x91,0x91,0x91,0xfe,0x90,0x93,0x90,0x90,0x8a,0xa6,0xd2,0x09,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15540 0x3cb4 "㲴" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x04,0x7f,0x44,0x44,0x7f,0x44,0x04,0x04,0x04,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0xd0,0x50,0x50,0xd2,0x4a,0x0a,0x06,0x02,
+/* 15541 0x3cb5 "㲵" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x24,0x15,0x7f,0x40,0x7f,0x40,0x7f,0x40,0x41,0x40,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x90,0x10,0xd0,0x50,0xd0,0x52,0xca,0x4a,0x46,0x82,
+/* 15542 0x3cb6 "㲶" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x07,0x04,0x7f,0x55,0x4a,0x64,0x4a,0x55,0x7f,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xf0,0x10,0xd0,0x50,0x52,0xca,0x4a,0x46,0xc2,
+/* 15543 0x3cb7 "㲷" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x2a,0x3b,0x00,0x3f,0x24,0x3f,0x24,0xff,0x04,0x04,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x90,0x90,0x10,0x90,0x90,0x92,0x8a,0xea,0x06,0x02,
+/* 15544 0x3cb8 "㲸" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x48,0x08,0x10,0x11,0xe1,0x22,0x22,0x22,0x21,0x00,
+0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x80,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 15545 0x3cb9 "㲹" */
+0x00,0x21,0x11,0x11,0x81,0x41,0x49,0x09,0x11,0x11,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 15546 0x3cba "㲺" */
+0x00,0x20,0x10,0x10,0x80,0x40,0x48,0x0f,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x40,0x40,0x40,0x40,0x40,0x4e,0x70,0xc0,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 15547 0x3cbb "㲻" */
+0x08,0x08,0x08,0x10,0x17,0x31,0x31,0x51,0x91,0x12,0x12,0x14,0x18,0x10,0x11,0x10,
+0x40,0x40,0x40,0x44,0x68,0x70,0x60,0x50,0x50,0x48,0x48,0x44,0x42,0x40,0x40,0x80,
+/* 15548 0x3cbc "㲼" */
+0x00,0x20,0x12,0x12,0x82,0x41,0x49,0x09,0x10,0x10,0xe0,0x20,0x20,0x21,0x22,0x0c,
+0x00,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 15549 0x3cbd "㲽" */
+0x00,0x23,0x10,0x10,0x80,0x42,0x4a,0x0a,0x14,0x10,0xe0,0x20,0x21,0x21,0x22,0x04,
+0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 15550 0x3cbe "㲾" */
+0x02,0x01,0x7f,0x40,0x81,0x01,0x01,0x3d,0x05,0x09,0x09,0x11,0x21,0xc1,0x05,0x02,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0x84,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 15551 0x3cbf "㲿" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x40,0x20,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 15552 0x3cc0 "㳀" */
+0x00,0x20,0x10,0x10,0x80,0x47,0x40,0x10,0x10,0x20,0xe0,0x20,0x20,0x21,0x26,0x00,
+0x90,0x88,0x88,0x80,0xbe,0xc0,0x80,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 15553 0x3cc1 "㳁" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x29,0x12,
+0x00,0xfe,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15554 0x3cc2 "㳂" */
+0x00,0x21,0x11,0x11,0x81,0x42,0x42,0x14,0x18,0x20,0xe1,0x21,0x22,0x27,0x22,0x00,
+0x20,0x20,0x20,0x10,0x10,0x48,0x48,0x44,0x82,0x80,0x10,0x08,0x08,0xfc,0x04,0x00,
+/* 15555 0x3cc3 "㳃" */
+0x00,0x20,0x13,0x10,0x80,0x41,0x49,0x0a,0x14,0x10,0xef,0x20,0x20,0x20,0x20,0x00,
+0x80,0x80,0xf0,0x90,0x90,0x12,0x12,0x4e,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 15556 0x3cc4 "㳄" */
+0x00,0x20,0x10,0x10,0x81,0x41,0x42,0x14,0x10,0x20,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 15557 0x3cc5 "㳅" */
+0x00,0x20,0x17,0x10,0x80,0x40,0x48,0x08,0x11,0x12,0xe4,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x42,0x40,0x40,0x40,0x40,0x40,
+/* 15558 0x3cc6 "㳆" */
+0x00,0x21,0x10,0x10,0x80,0x42,0x49,0x09,0x10,0x17,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15559 0x3cc7 "㳇" */
+0x00,0x21,0x11,0x12,0x82,0x44,0x41,0x11,0x10,0x20,0xe0,0x20,0x21,0x22,0x24,0x08,
+0x20,0x10,0x08,0x04,0x04,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x04,0x02,
+/* 15560 0x3cc8 "㳈" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x49,0x09,0x11,0x11,0xe1,0x22,0x22,0x24,0x20,0x00,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x50,0x50,0x50,0x50,0x52,0x52,0x4e,0x40,0x40,0x40,
+/* 15561 0x3cc9 "㳉" */
+0x00,0x21,0x11,0x11,0x81,0x41,0x49,0x09,0x11,0x11,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 15562 0x3cca "㳊" */
+0x00,0x20,0x11,0x11,0x82,0x42,0x45,0x11,0x11,0x20,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x80,0x80,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 15563 0x3ccb "㳋" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x08,0x3c,0xc0,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 15564 0x3ccc "㳌" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x44,0x14,0x14,0x27,0xe4,0x20,0x20,0x20,0x20,0x00,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 15565 0x3ccd "㳍" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x49,0x09,0x13,0x15,0xe1,0x21,0x21,0x21,0x20,0x00,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 15566 0x3cce "㳎" */
+0x00,0x20,0x10,0x11,0x82,0x47,0x40,0x11,0x11,0x27,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x40,0x80,0x10,0x08,0xfc,0x04,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15567 0x3ccf "㳏" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x44,0x14,0x17,0x20,0xe2,0x21,0x20,0x21,0x22,0x0c,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x40,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 15568 0x3cd0 "㳐" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x43,0x13,0x15,0x25,0xe9,0x21,0x21,0x21,0x21,0x01,
+0x10,0x10,0x10,0x10,0xd0,0x10,0x10,0x90,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 15569 0x3cd1 "㳑" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x2f,0x20,0x00,
+0x00,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,0x00,
+/* 15570 0x3cd2 "㳒" */
+0x00,0x20,0x10,0x17,0x80,0x41,0x42,0x14,0x10,0x20,0xe0,0x21,0x22,0x27,0x22,0x00,
+0x40,0x40,0x40,0xfe,0xa0,0x10,0x08,0x26,0x20,0x40,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 15571 0x3cd3 "㳓" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x09,0x13,0x15,0xe9,0x21,0x21,0x21,0x21,0x01,
+0x40,0x40,0x40,0x40,0xfe,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15572 0x3cd4 "㳔" */
+0x00,0x20,0x17,0x10,0x80,0x44,0x42,0x12,0x11,0x21,0xe2,0x22,0x24,0x28,0x20,0x00,
+0x04,0x04,0x84,0x84,0xbe,0x84,0x84,0xa4,0x14,0x14,0x84,0x84,0x84,0x04,0x14,0x08,
+/* 15573 0x3cd5 "㳕" */
+0x00,0x21,0x10,0x10,0x80,0x43,0x48,0x08,0x10,0x11,0xe0,0x20,0x20,0x20,0x23,0x00,
+0x00,0x08,0x88,0x90,0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 15574 0x3cd6 "㳖" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x49,0x09,0x13,0x15,0xe9,0x21,0x21,0x21,0x21,0x01,
+0x80,0x40,0x40,0xfe,0x80,0x80,0x40,0x44,0x48,0x30,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 15575 0x3cd7 "㳗" */
+0x00,0x23,0x11,0x11,0x80,0x40,0x41,0x16,0x10,0x20,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x00,0xf8,0x08,0x50,0xa0,0x40,0xb0,0x0e,0x40,0x40,0xf8,0x40,0x40,0x40,0xfc,0x00,
+/* 15576 0x3cd8 "㳘" */
+0x00,0x20,0x10,0x17,0x80,0x41,0x42,0x17,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x40,0x40,0xfe,0x80,0x10,0x08,0xfc,0x24,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 15577 0x3cd9 "㳙" */
+0x00,0x20,0x11,0x12,0x87,0x40,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x40,0x80,0x08,0x04,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 15578 0x3cda "㳚" */
+0x00,0x20,0x10,0x10,0x83,0x42,0x4a,0x0a,0x13,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 15579 0x3cdb "㳛" */
+0x00,0x21,0x16,0x14,0x84,0x47,0x44,0x14,0x17,0x24,0xe0,0x20,0x21,0x22,0x24,0x08,
+0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x44,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 15580 0x3cdc "㳜" */
+0x00,0x20,0x10,0x11,0x81,0x43,0x4d,0x09,0x11,0x11,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 15581 0x3cdd "㳝" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x4a,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x00,0x08,0x1c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 15582 0x3cde "㳞" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x56,0x1a,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,
+/* 15583 0x3cdf "㳟" */
+0x04,0x04,0x3f,0x04,0x04,0xff,0x08,0x11,0x29,0xc5,0x03,0x05,0x09,0x31,0x05,0x02,
+0x40,0x40,0xf8,0x40,0x40,0xfe,0x20,0x10,0x28,0x46,0x80,0x40,0x20,0x10,0x00,0x00,
+/* 15584 0x3ce0 "㳠" */
+0x00,0x24,0x12,0x12,0x80,0x40,0x46,0x12,0x12,0x22,0xe2,0x22,0x22,0x25,0x28,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x24,0x44,0x42,0x82,0x00,0x00,0xfe,0x00,
+/* 15585 0x3ce1 "㳡" */
+0x04,0x42,0x22,0x20,0x00,0x8e,0x42,0x52,0x12,0x22,0xe2,0x22,0x22,0x25,0x28,0x00,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,0x00,0xfe,0x00,
+/* 15586 0x3ce2 "㳢" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x48,0x09,0x12,0x15,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15587 0x3ce3 "㳣" */
+0x00,0x20,0x10,0x13,0x80,0x40,0x47,0x10,0x10,0x21,0xe2,0x24,0x28,0x20,0x20,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 15588 0x3ce4 "㳤" */
+0x01,0x49,0x25,0x25,0x01,0x8f,0x41,0x51,0x15,0x25,0xe9,0x22,0x22,0x24,0x28,0x10,
+0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x98,0x54,0x54,0x10,0x10,0x10,0x10,0x10,
+/* 15589 0x3ce5 "㳥" */
+0x00,0x27,0x10,0x10,0x83,0x40,0x40,0x17,0x11,0x21,0xef,0x21,0x21,0x22,0x22,0x04,
+0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 15590 0x3ce6 "㳦" */
+0x00,0x40,0x20,0x2f,0x00,0x82,0x42,0x52,0x1f,0x22,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xd2,0x94,0x94,0x88,0x8a,0x9a,0x26,0x42,
+/* 15591 0x3ce7 "㳧" */
+0x00,0x2f,0x14,0x14,0x84,0x47,0x44,0x14,0x14,0x27,0xe4,0x24,0x24,0x2f,0x20,0x00,
+0x00,0xfe,0x80,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0xd2,0x92,0x8e,0x80,
+/* 15592 0x3ce8 "㳨" */
+0x01,0x21,0x12,0x12,0x81,0x41,0x40,0x17,0x10,0x21,0xe1,0x22,0x24,0x20,0x20,0x07,
+0x24,0x24,0x48,0x48,0x24,0x24,0x00,0xfe,0x80,0xfc,0x04,0x88,0x50,0x20,0xc0,0x00,
+/* 15593 0x3ce9 "㳩" */
+0x00,0x40,0x20,0x2e,0x04,0x84,0x44,0x54,0x15,0x24,0xe7,0x3c,0x20,0x20,0x20,0x01,
+0x00,0x7c,0x44,0x44,0x64,0x54,0x54,0x44,0xfe,0x44,0x44,0x44,0x44,0x84,0x94,0x08,
+/* 15594 0x3cea "㳪" */
+0x00,0x27,0x10,0x10,0x80,0x41,0x52,0x14,0x10,0x20,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x20,0x40,0xd0,0x48,0x44,0x44,0x40,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 15595 0x3ceb "㳫" */
+0x01,0x01,0x7d,0x05,0x09,0x31,0xc5,0x02,0x0c,0x30,0x20,0x3c,0x20,0x20,0x3f,0x20,
+0x00,0x08,0x10,0xa0,0x60,0x18,0x06,0x00,0x00,0x78,0x08,0x78,0x08,0x08,0xf8,0x08,
+/* 15596 0x3cec "㳬" */
+0x01,0x21,0x11,0x12,0x84,0x41,0x48,0x08,0x11,0x11,0xe1,0x21,0x21,0x22,0x24,0x08,
+0x00,0x00,0xfe,0x00,0x00,0xfe,0x22,0x24,0x20,0x3c,0x20,0x20,0x20,0xa0,0x7e,0x00,
+/* 15597 0x3ced "㳭" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x40,0x10,0x17,0x20,0xe1,0x22,0x24,0x28,0x20,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x40,0x40,0xfc,0xe0,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 15598 0x3cee "㳮" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x13,0x12,0xe2,0x22,0x25,0x25,0x2a,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x20,0x22,0xb2,0xb4,0xa8,0xa8,0x24,0x24,0xa2,0x40,
+/* 15599 0x3cef "㳯" */
+0x00,0x20,0x17,0x10,0x81,0x40,0x4f,0x10,0x10,0x20,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x80,0x40,0xfc,0x00,0x10,0xa0,0xfe,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,
+/* 15600 0x3cf0 "㳰" */
+0x00,0x20,0x13,0x10,0x80,0x41,0x4b,0x08,0x11,0x11,0xe7,0x21,0x21,0x21,0x22,0x04,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 15601 0x3cf1 "㳱" */
+0x00,0x27,0x14,0x15,0x85,0x46,0x45,0x14,0x14,0x24,0xe6,0x25,0x24,0x24,0x24,0x04,
+0x00,0x80,0xbc,0x24,0x24,0x24,0x24,0xbc,0xa4,0xa4,0xa4,0x24,0x3c,0x24,0x00,0x00,
+/* 15602 0x3cf2 "㳲" */
+0x00,0x48,0x24,0x20,0x08,0x85,0x44,0x50,0x12,0x24,0xec,0x24,0x24,0x24,0x25,0x02,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 15603 0x3cf3 "㳳" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x4b,0x0a,0x12,0x13,0xe0,0x20,0x21,0x21,0x22,0x04,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 15604 0x3cf4 "㳴" */
+0x00,0x20,0x10,0x12,0x82,0x42,0x44,0x11,0x16,0x20,0xe0,0x27,0x20,0x20,0x2f,0x00,
+0x40,0x28,0x88,0x90,0xa4,0xc2,0x8a,0x88,0x78,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 15605 0x3cf5 "㳵" */
+0x00,0x23,0x10,0x17,0x80,0x41,0x52,0x1c,0x13,0x20,0xe0,0x27,0x20,0x20,0x21,0x00,
+0x38,0xc0,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf0,0x20,0x40,0xfc,0x40,0x40,0x40,0x80,
+/* 15606 0x3cf6 "㳶" */
+0x00,0x4f,0x22,0x29,0x05,0x80,0x47,0x50,0x11,0x21,0xe1,0x2f,0x21,0x21,0x25,0x02,
+0xe8,0x08,0x28,0x28,0x48,0x08,0xc8,0x88,0x08,0x08,0xe8,0x08,0x0a,0x0a,0x0a,0x06,
+/* 15607 0x3cf7 "㳷" */
+0x01,0x21,0x11,0x12,0x84,0x41,0x4a,0x08,0x11,0x10,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x00,0x00,0xfc,0xa4,0xa4,0x24,0x44,0x94,0x08,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 15608 0x3cf8 "㳸" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x48,0x08,0x11,0x13,0xe5,0x21,0x21,0x21,0x21,0x01,
+0x08,0x08,0xfe,0x08,0x08,0x00,0x90,0x92,0x14,0x18,0x10,0x32,0x52,0x12,0x0e,0x00,
+/* 15609 0x3cf9 "㳹" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x46,0x57,0x16,0x2a,0xea,0x32,0x22,0x22,0x22,0x02,
+0x00,0x00,0xfe,0x10,0x90,0x10,0x10,0x7c,0x90,0x90,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 15610 0x3cfa "㳺" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x53,0x12,0x26,0xea,0x22,0x22,0x22,0x2a,0x04,
+0x40,0x40,0x7e,0x80,0x00,0x78,0x08,0x08,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 15611 0x3cfb "㳻" */
+0x01,0x21,0x11,0x17,0x81,0x41,0x4f,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x10,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 15612 0x3cfc "㳼" */
+0x00,0x00,0xff,0x00,0x3e,0x22,0x3e,0x00,0x0e,0x70,0x03,0x7d,0x09,0x11,0x25,0xc2,
+0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x0a,0x90,0x60,0x20,0x18,0x06,
+/* 15613 0x3cfd "㳽" */
+0x00,0x27,0x11,0x11,0x81,0x47,0x44,0x14,0x14,0x27,0xe1,0x21,0x21,0x21,0x25,0x02,
+0x20,0x20,0x20,0x3e,0x40,0x40,0x90,0x10,0x10,0x54,0x52,0x52,0x92,0x10,0x50,0x20,
+/* 15614 0x3cfe "㳾" */
+0x02,0x21,0x11,0x17,0x80,0x40,0x43,0x10,0x10,0x2f,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x08,0x08,0x10,0xfc,0x40,0x40,0xf8,0x40,0x80,0xfe,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 15615 0x3cff "㳿" */
+0x00,0x20,0x13,0x10,0x80,0x41,0x4b,0x08,0x10,0x17,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x44,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 15616 0x3d00 "㴀" */
+0x01,0x21,0x17,0x11,0x80,0x40,0x4b,0x08,0x10,0x13,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x08,0x08,0xfe,0x08,0x00,0x3c,0xc0,0x20,0x10,0xfc,0x08,0x10,0x60,0x80,0x40,0x3e,
+/* 15617 0x3d01 "㴁" */
+0x00,0x23,0x10,0x10,0x8f,0x41,0x42,0x15,0x13,0x21,0xe1,0x27,0x21,0x21,0x22,0x04,
+0x00,0xf8,0x40,0x40,0xfe,0x10,0x08,0x16,0xf8,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,
+/* 15618 0x3d02 "㴂" */
+0x00,0x40,0x20,0x2e,0x04,0x84,0x44,0x54,0x14,0x24,0xe5,0x26,0x38,0x20,0x20,0x00,
+0x20,0x20,0x20,0xf8,0xa8,0xa8,0xf8,0xa8,0xa8,0xa8,0xfe,0x88,0x88,0x88,0xa8,0x90,
+/* 15619 0x3d03 "㴃" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x42,0x12,0x13,0x22,0xe2,0x24,0x25,0x29,0x32,0x00,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x20,0x20,0xb2,0xb4,0xa8,0xa8,0x24,0x24,0xa2,0x40,
+/* 15620 0x3d04 "㴄" */
+0x00,0x27,0x14,0x14,0x84,0x45,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x24,0x27,0x04,
+0x00,0xfe,0x02,0x92,0x8a,0x0a,0x02,0x02,0xf2,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,
+/* 15621 0x3d05 "㴅" */
+0x01,0x01,0x7d,0x05,0x09,0x31,0xc5,0x02,0x3f,0x24,0x28,0x37,0x24,0x27,0x20,0x3f,
+0x00,0x08,0x10,0xa0,0x60,0x18,0x06,0x00,0xf8,0x48,0x28,0xd8,0x48,0xc8,0x08,0xf8,
+/* 15622 0x3d06 "㴆" */
+0x00,0x23,0x10,0x11,0x80,0x43,0x40,0x17,0x14,0x28,0xe3,0x22,0x22,0x22,0x22,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x42,0x44,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 15623 0x3d07 "㴇" */
+0x10,0x10,0x10,0x10,0xd6,0x52,0x52,0x5a,0x56,0x52,0x52,0x94,0x10,0x10,0x52,0x21,
+0x88,0x88,0x88,0x88,0xea,0xac,0xa8,0xa8,0xec,0xaa,0xaa,0xc8,0x88,0x88,0xa8,0x10,
+/* 15624 0x3d08 "㴈" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x42,0x12,0x1f,0x20,0xe0,0x24,0x24,0x24,0x27,0x00,
+0x10,0x38,0xc0,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 15625 0x3d09 "㴉" */
+0x00,0x20,0x11,0x13,0x81,0x42,0x44,0x17,0x10,0x20,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x40,0x90,0x08,0xfc,0x08,0x10,0xa4,0xbe,0x82,0x00,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 15626 0x3d0a "㴊" */
+0x04,0x22,0x12,0x10,0x87,0x41,0x45,0x15,0x15,0x27,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x44,0x44,0x84,0x14,0xd4,0x14,0x54,0x54,0x54,0xd4,0x54,0x14,0x04,0x04,0x14,0x08,
+/* 15627 0x3d0b "㴋" */
+0x00,0x20,0x13,0x10,0x87,0x40,0x4b,0x08,0x12,0x12,0xe2,0x23,0x22,0x22,0x24,0x08,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x48,0x48,0xe8,0x58,0x48,0x48,0x48,0x48,
+/* 15628 0x3d0c "㴌" */
+0x02,0x42,0x22,0x22,0x0f,0x85,0x45,0x55,0x15,0x29,0xe5,0x22,0x22,0x25,0x25,0x08,
+0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 15629 0x3d0d "㴍" */
+0x03,0x40,0x20,0x20,0x0e,0x83,0x42,0x52,0x15,0x24,0xe4,0x2b,0x30,0x20,0x21,0x00,
+0xf0,0x10,0x20,0x44,0x58,0xf0,0x50,0x48,0xe8,0x48,0x44,0xf4,0x42,0x40,0x40,0x80,
+/* 15630 0x3d0e "㴎" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x45,0x10,0x10,0x27,0xe0,0x22,0x22,0x24,0x21,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0x00,0xfc,0x40,0x48,0x44,0x44,0x40,0x80,
+/* 15631 0x3d0f "㴏" */
+0x00,0x20,0x17,0x14,0x81,0x42,0x44,0x13,0x10,0x20,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x80,0x40,0xfc,0x04,0x10,0x08,0x04,0xf8,0x40,0x40,0xf8,0x40,0x40,0x40,0xfc,0x00,
+/* 15632 0x3d10 "㴐" */
+0x00,0x40,0x2f,0x29,0x09,0x89,0x4f,0x49,0x19,0x2f,0xe9,0x29,0x29,0x2f,0x29,0x00,
+0x00,0xfe,0x10,0x10,0x50,0x5e,0x52,0x52,0x52,0x7e,0x02,0x02,0x02,0x02,0x14,0x08,
+/* 15633 0x3d11 "㴑" */
+0x00,0x20,0x17,0x14,0x85,0x44,0x47,0x14,0x15,0x25,0xe5,0x25,0x28,0x28,0x31,0x02,
+0x40,0x20,0xfe,0x00,0x04,0x88,0xfe,0x20,0x24,0x24,0x24,0xfc,0x44,0x80,0x00,0x00,
+/* 15634 0x3d12 "㴒" */
+0x00,0x20,0x17,0x10,0x82,0x44,0x41,0x12,0x14,0x21,0xe1,0x2f,0x21,0x21,0x22,0x04,
+0x80,0x40,0xfe,0x90,0x98,0x94,0x14,0x30,0x00,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 15635 0x3d13 "㴓" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x10,0x10,0xe0,0x25,0x25,0x29,0x20,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x40,0x24,0x22,0x0a,0x08,0xf8,0x00,
+/* 15636 0x3d14 "㴔" */
+0x00,0x20,0x11,0x12,0x84,0x43,0x48,0x09,0x10,0x13,0xe0,0x20,0x21,0x25,0x25,0x08,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x40,0x24,0x2a,0x0a,0xf8,
+/* 15637 0x3d15 "㴕" */
+0x01,0x21,0x17,0x11,0x80,0x40,0x4b,0x08,0x10,0x17,0xe0,0x21,0x22,0x24,0x28,0x00,
+0x08,0x08,0xfe,0x08,0x00,0x38,0xc0,0x40,0x40,0xfc,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 15638 0x3d16 "㴖" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x43,0x12,0x12,0x23,0xe0,0x2f,0x20,0x20,0x20,0x00,
+0x10,0x10,0xfc,0x10,0xf0,0x40,0xf8,0x48,0x48,0xf8,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 15639 0x3d17 "㴗" */
+0x00,0x23,0x10,0x10,0x83,0x42,0x4a,0x0b,0x10,0x10,0xe7,0x20,0x21,0x20,0x20,0x03,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 15640 0x3d18 "㴘" */
+0x00,0x27,0x14,0x15,0x84,0x45,0x44,0x10,0x13,0x22,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x00,0xfe,0x02,0xfa,0x02,0xfa,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 15641 0x3d19 "㴙" */
+0x00,0x20,0x17,0x10,0x80,0x4f,0x40,0x11,0x16,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x08,0x3c,0xc0,0x40,0x40,0xfe,0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x04,
+/* 15642 0x3d1a "㴚" */
+0x02,0x21,0x10,0x17,0x80,0x41,0x42,0x14,0x11,0x22,0xe4,0x21,0x22,0x2c,0x20,0x00,
+0x08,0x10,0x00,0xfe,0x80,0x84,0x44,0xa8,0x30,0x70,0xa8,0x28,0x24,0x22,0xa0,0x40,
+/* 15643 0x3d1b "㴛" */
+0x00,0x20,0x17,0x12,0x82,0x44,0x47,0x11,0x11,0x27,0xe1,0x21,0x21,0x2e,0x24,0x00,
+0x08,0x08,0xc8,0x10,0x1e,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x08,0xc8,0x14,0x14,0x22,
+/* 15644 0x3d1c "㴜" */
+0x00,0x20,0x17,0x14,0x84,0x47,0x44,0x14,0x17,0x26,0xea,0x2b,0x2a,0x2a,0x32,0x02,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 15645 0x3d1d "㴝" */
+0x06,0x78,0x08,0xff,0x1c,0x2a,0xc9,0x0a,0x0c,0x31,0xc9,0x05,0x09,0x11,0x25,0x02,
+0x04,0x44,0x44,0x44,0x44,0x44,0x14,0x88,0x60,0x18,0x26,0x40,0x20,0x10,0x08,0x00,
+/* 15646 0x3d1e "㴞" */
+0x00,0x20,0x13,0x10,0x82,0x41,0x49,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 15647 0x3d1f "㴟" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x23,0x24,0x24,0x08,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x10,0x50,0x20,
+/* 15648 0x3d20 "㴠" */
+0x00,0x8f,0x40,0x00,0x80,0x57,0x55,0x15,0x35,0x55,0xd7,0x50,0x51,0x50,0x5f,0x00,
+0x00,0xf8,0x10,0x20,0x40,0x7a,0x4a,0x6a,0x52,0x52,0x6a,0x4a,0x42,0x82,0xfe,0x02,
+/* 15649 0x3d21 "㴡" */
+0x00,0x23,0x10,0x10,0x87,0x41,0x52,0x14,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x46,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 15650 0x3d22 "㴢" */
+0x00,0x90,0x48,0x01,0x91,0x49,0x49,0x03,0x25,0x49,0xd9,0x49,0x49,0x49,0x49,0x01,
+0x90,0x90,0x90,0x90,0x7c,0x54,0x54,0x54,0x54,0x7c,0x54,0x10,0x10,0x10,0x10,0x10,
+/* 15651 0x3d23 "㴣" */
+0x00,0x90,0x4b,0x00,0x91,0x48,0x49,0x01,0x25,0x48,0xd8,0x48,0x48,0x48,0x49,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 15652 0x3d24 "㴤" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x57,0x16,0x2a,0xea,0x22,0x22,0x22,0x22,0x02,
+0x10,0x08,0x00,0x7e,0x90,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 15653 0x3d25 "㴥" */
+0x04,0x84,0x44,0x04,0x95,0x55,0x55,0x15,0x35,0x55,0xd5,0x57,0x59,0x40,0x40,0x00,
+0x10,0x10,0x54,0x38,0x10,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x54,0x48,
+/* 15654 0x3d26 "㴦" */
+0x00,0x20,0x17,0x14,0x80,0x41,0x49,0x09,0x11,0x10,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 15655 0x3d27 "㴧" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x43,0x12,0x13,0x20,0xe0,0x20,0x25,0x25,0x28,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x40,0x24,0x22,0x0a,0xf8,0x00,
+/* 15656 0x3d28 "㴨" */
+0x00,0x27,0x15,0x15,0x85,0x47,0x45,0x15,0x15,0x27,0xe5,0x25,0x25,0x25,0x2b,0x00,
+0x44,0x24,0x28,0x00,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 15657 0x3d29 "㴩" */
+0x01,0x22,0x12,0x11,0x83,0x42,0x4b,0x08,0x13,0x12,0xe2,0x23,0x22,0x22,0x21,0x00,
+0x24,0x48,0x48,0x24,0xf8,0x08,0xf8,0x00,0xf8,0x48,0x48,0xf8,0x02,0x02,0xfe,0x00,
+/* 15658 0x3d2a "㴪" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x4b,0x0a,0x13,0x10,0xe7,0x20,0x21,0x22,0x24,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 15659 0x3d2b "㴫" */
+0x40,0x2f,0x22,0x82,0x5f,0x42,0x02,0x2f,0x24,0x47,0xcc,0x4c,0x54,0x67,0x44,0x00,
+0x00,0xde,0x52,0x52,0xf4,0x54,0x58,0xd4,0x12,0xd2,0x52,0x5a,0x54,0xd0,0x50,0x10,
+/* 15660 0x3d2c "㴬" */
+0x01,0x22,0x17,0x14,0x87,0x44,0x47,0x14,0x14,0x2f,0xe1,0x22,0x24,0x28,0x22,0x01,
+0x08,0x08,0x88,0x88,0xbe,0x88,0x88,0xc8,0xa8,0xa8,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 15661 0x3d2d "㴭" */
+0x00,0x20,0x17,0x14,0x80,0x41,0x4a,0x08,0x13,0x12,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x80,0x40,0xfc,0x04,0xa0,0x10,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 15662 0x3d2e "㴮" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x45,0x14,0x15,0x25,0xe5,0x25,0x25,0x29,0x29,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x24,0xa8,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 15663 0x3d2f "㴯" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x44,0x14,0x14,0x27,0xe4,0x24,0x24,0x28,0x2a,0x11,
+0x20,0xa4,0xa8,0xb0,0xa2,0xa2,0x9e,0x80,0xbe,0xa2,0xa2,0xbe,0xa2,0xa2,0xbe,0x22,
+/* 15664 0x3d30 "㴰" */
+0x01,0x22,0x14,0x17,0x80,0x40,0x47,0x14,0x14,0x27,0xe4,0x24,0x27,0x24,0x25,0x04,
+0x10,0x12,0x54,0xd8,0x10,0x12,0xd2,0x4e,0x40,0xd2,0x54,0x58,0xd0,0x52,0x52,0x8e,
+/* 15665 0x3d31 "㴱" */
+0x00,0x20,0x17,0x14,0x80,0x41,0x42,0x10,0x17,0x20,0xe4,0x22,0x20,0x21,0x22,0x0c,
+0x80,0x40,0xfc,0x04,0xa0,0x10,0x48,0x40,0xfc,0x40,0x44,0xa8,0xa0,0x10,0x08,0x06,
+/* 15666 0x3d32 "㴲" */
+0x00,0x20,0x17,0x14,0x84,0x45,0x45,0x15,0x15,0x25,0xe5,0x29,0x2a,0x32,0x24,0x09,
+0x04,0x3e,0xe0,0x3e,0x20,0xfe,0x22,0x38,0xe2,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 15667 0x3d33 "㴳" */
+0x04,0x44,0x24,0x24,0x04,0x9f,0x44,0x54,0x14,0x24,0xe4,0x27,0x3c,0x20,0x21,0x02,
+0x48,0x44,0x40,0xfe,0x50,0x54,0x58,0x52,0x54,0x58,0x52,0x54,0x9a,0x92,0x2e,0x40,
+/* 15668 0x3d34 "㴴" */
+0x00,0x24,0x14,0x15,0x84,0x44,0x45,0x17,0x14,0x24,0xe5,0x24,0x24,0x25,0x27,0x00,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0xfe,0x20,0xa4,0x28,0x50,0x88,0x04,0xfe,0x00,
+/* 15669 0x3d35 "㴵" */
+0x00,0x20,0x10,0x12,0x82,0x44,0x41,0x16,0x10,0x23,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x40,0x28,0x90,0xa4,0xc2,0x8a,0x88,0x78,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 15670 0x3d36 "㴶" */
+0x00,0x20,0x17,0x15,0x81,0x43,0x56,0x1a,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x80,0x80,0xfe,0x22,0x10,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 15671 0x3d37 "㴷" */
+0x00,0x4f,0x25,0x25,0x07,0x85,0x47,0x55,0x15,0x25,0xe7,0x2d,0x21,0x21,0x21,0x01,
+0x10,0x90,0x10,0x10,0x7c,0x54,0x54,0x10,0x10,0xa8,0x28,0x28,0x4a,0x4a,0x86,0x00,
+/* 15672 0x3d38 "㴸" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x44,0x14,0x14,0x24,0xe4,0x24,0x25,0x24,0x24,0x04,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0x44,0x44,0x44,0xa4,0x94,0x14,0x04,0x14,0x08,
+/* 15673 0x3d39 "㴹" */
+0x00,0x20,0x14,0x12,0x82,0x40,0x40,0x16,0x12,0x22,0xe3,0x22,0x22,0x25,0x28,0x00,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 15674 0x3d3a "㴺" */
+0x00,0x88,0x44,0x05,0x90,0x48,0x48,0x04,0x25,0x4a,0xd8,0x48,0x48,0x48,0x49,0x02,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 15675 0x3d3b "㴻" */
+0x00,0x4f,0x20,0x20,0x07,0x84,0x44,0x54,0x17,0x20,0xe8,0x24,0x25,0x21,0x2e,0x00,
+0x04,0xc4,0x04,0x04,0xbe,0x84,0x84,0xa4,0x94,0x14,0x84,0x84,0x04,0xc4,0x14,0x08,
+/* 15676 0x3d3c "㴼" */
+0x00,0x20,0x17,0x14,0x81,0x41,0x42,0x16,0x1a,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 15677 0x3d3d "㴽" */
+0x00,0x40,0x27,0x20,0x02,0x81,0x4f,0x51,0x12,0x2c,0xe0,0x20,0x2a,0x2a,0x31,0x00,
+0x08,0x3c,0xc0,0x40,0x48,0x50,0xfe,0x50,0x48,0x46,0x80,0x44,0x42,0x12,0xf0,0x00,
+/* 15678 0x3d3e "㴾" */
+0x01,0x41,0x2f,0x21,0x01,0x8f,0x48,0x40,0x17,0x20,0xe1,0x21,0x2f,0x21,0x25,0x02,
+0x08,0x08,0xc8,0x10,0x1e,0xd4,0x64,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 15679 0x3d3f "㴿" */
+0x00,0x40,0x2f,0x22,0x02,0x82,0x42,0x52,0x12,0x22,0xe2,0x22,0x22,0x2a,0x24,0x00,
+0x00,0x7e,0x90,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 15680 0x3d40 "㵀" */
+0x04,0x42,0x22,0x2f,0x04,0x84,0x47,0x55,0x15,0x25,0xe5,0x25,0x25,0x29,0x2b,0x10,
+0x20,0x20,0x3e,0x40,0xa0,0x20,0x3c,0x50,0x10,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 15681 0x3d41 "㵁" */
+0x01,0x21,0x17,0x11,0x80,0x47,0x48,0x09,0x13,0x10,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x08,0x08,0xfe,0x48,0x20,0xfe,0x80,0x08,0xfc,0x04,0x50,0x50,0x50,0x52,0x52,0x4e,
+/* 15682 0x3d42 "㵂" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe2,0x22,0x25,0x25,0x2a,0x10,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 15683 0x3d43 "㵃" */
+0x04,0x84,0x44,0x1f,0x95,0x55,0x55,0x15,0x3f,0x44,0xc4,0x45,0x47,0x5c,0x48,0x00,
+0x10,0x08,0x08,0x7e,0x42,0x42,0x20,0x24,0x28,0x30,0x20,0x22,0xa2,0xa2,0x1e,0x00,
+/* 15684 0x3d44 "㵄" */
+0x00,0x20,0x10,0x17,0x80,0x43,0x4a,0x0b,0x10,0x17,0xe1,0x27,0x21,0x22,0x24,0x08,
+0x14,0x12,0x12,0xfe,0x10,0xd0,0x50,0xd4,0x14,0xd4,0x14,0xf8,0x0a,0x8a,0x56,0x22,
+/* 15685 0x3d45 "㵅" */
+0x00,0x20,0x11,0x12,0x8d,0x40,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x40,0xa0,0x10,0x48,0xf6,0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 15686 0x3d46 "㵆" */
+0x00,0x40,0x2f,0x29,0x09,0x89,0x49,0x4f,0x19,0x29,0xe9,0x29,0x2f,0x29,0x20,0x00,
+0x08,0x28,0x28,0x3e,0x28,0x48,0x08,0x7e,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+/* 15687 0x3d47 "㵇" */
+0x01,0x4e,0x22,0x22,0x02,0x8f,0x42,0x52,0x12,0x2f,0xe8,0x28,0x28,0x2f,0x28,0x00,
+0xa4,0x24,0x24,0x24,0x7e,0xa4,0x24,0x24,0x24,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0x24,
+/* 15688 0x3d48 "㵈" */
+0x00,0x90,0x48,0x00,0x93,0x49,0x49,0x01,0x25,0x4a,0xd9,0x48,0x48,0x49,0x49,0x02,
+0x88,0x88,0x88,0x88,0xde,0x48,0x48,0x48,0x5e,0x52,0x52,0x92,0x92,0x5e,0x52,0x00,
+/* 15689 0x3d49 "㵉" */
+0x00,0x90,0x48,0x00,0x93,0x48,0x48,0x01,0x25,0x4a,0xda,0x4c,0x48,0x48,0x48,0x00,
+0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x9c,0xdc,0xaa,0xaa,0xc8,0x88,0x88,0x88,0x88,
+/* 15690 0x3d4a "㵊" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x50,0x1f,0x14,0x27,0xe4,0x27,0x24,0x2f,0x20,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x80,0xbc,0x94,0x94,0xd4,0x88,0x94,0xa2,
+/* 15691 0x3d4b "㵋" */
+0x00,0x27,0x14,0x14,0x87,0x40,0x4b,0x0a,0x13,0x12,0xe3,0x22,0x23,0x21,0x22,0x04,
+0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0x04,
+/* 15692 0x3d4c "㵌" */
+0x04,0x84,0x49,0x11,0xa5,0x45,0x49,0x19,0x29,0x49,0xc9,0x49,0x49,0x4a,0x4a,0x0c,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 15693 0x3d4d "㵍" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x44,0x14,0x14,0x25,0xe5,0x25,0x26,0x24,0x24,0x04,
+0x00,0x9e,0x92,0x9e,0x92,0x9e,0x42,0x22,0x0a,0x46,0x42,0x52,0x32,0x02,0x0a,0x04,
+/* 15694 0x3d4e "㵎" */
+0x07,0x24,0x17,0x14,0x87,0x44,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x25,0x24,0x04,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 15695 0x3d4f "㵏" */
+0x01,0x21,0x17,0x11,0x80,0x47,0x41,0x11,0x12,0x24,0xe0,0x2f,0x20,0x20,0x20,0x00,
+0x10,0x10,0xfc,0x10,0x40,0xfc,0x10,0x10,0xa8,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 15696 0x3d50 "㵐" */
+0x40,0x2f,0x28,0x8a,0x49,0x4b,0x08,0x28,0x2a,0x4a,0xcb,0x48,0x48,0x49,0x49,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 15697 0x3d51 "㵑" */
+0x02,0x42,0x27,0x22,0x04,0x85,0x48,0x53,0x12,0x23,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x00,0x00,0xbc,0xa4,0xa4,0xbc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 15698 0x3d52 "㵒" */
+0x00,0x27,0x10,0x13,0x82,0x43,0x49,0x0b,0x15,0x11,0xe1,0x21,0x21,0x21,0x20,0x01,
+0x90,0xfc,0x94,0xfc,0x90,0xfe,0x12,0xfa,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,
+/* 15699 0x3d53 "㵓" */
+0x00,0x40,0x2f,0x28,0x03,0x82,0x43,0x52,0x13,0x20,0xef,0x22,0x22,0x25,0x24,0x08,
+0x80,0x40,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0x7c,0x40,0xfe,0x00,
+/* 15700 0x3d54 "㵔" */
+0x00,0x20,0x17,0x11,0x82,0x44,0x43,0x10,0x17,0x20,0xe3,0x2d,0x21,0x21,0x21,0x01,
+0x40,0x40,0xfc,0x10,0x48,0x46,0xf8,0x50,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 15701 0x3d55 "㵕" */
+0x00,0x21,0x13,0x12,0x84,0x47,0x40,0x10,0x13,0x2c,0xe0,0x22,0x22,0x24,0x21,0x00,
+0x80,0x10,0xf8,0x10,0xa4,0xbc,0x40,0xa0,0x58,0x46,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 15702 0x3d56 "㵖" */
+0x01,0x21,0x17,0x12,0x86,0x41,0x42,0x14,0x11,0x23,0xe0,0x27,0x22,0x24,0x29,0x00,
+0x00,0x00,0xde,0x52,0x92,0x12,0x9e,0xc0,0x10,0xe0,0x48,0xfc,0x54,0x48,0x44,0x80,
+/* 15703 0x3d57 "㵗" */
+0x43,0x22,0x0b,0x0a,0x13,0x22,0xe3,0x20,0x25,0x20,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0x08,0x08,0x90,0x60,0x20,0x18,0x06,
+/* 15704 0x3d58 "㵘" */
+0x08,0x0a,0x6a,0x2c,0x2a,0x4a,0xa9,0x10,0x08,0x0a,0x6a,0x2c,0x2a,0x4a,0xa9,0x10,
+0x10,0x14,0xd4,0x58,0x54,0x94,0x50,0x20,0x10,0x14,0xd4,0x58,0x54,0x94,0x52,0x20,
+/* 15705 0x3d59 "㵙" */
+0x00,0x27,0x10,0x13,0x80,0x43,0x42,0x13,0x11,0x2f,0xe0,0x23,0x22,0x22,0x23,0x02,
+0x40,0xfc,0x40,0xf8,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 15706 0x3d5a "㵚" */
+0x01,0x22,0x14,0x11,0x80,0x41,0x46,0x10,0x13,0x2d,0xe0,0x27,0x22,0x21,0x2f,0x00,
+0x10,0x08,0x14,0xa0,0x60,0x98,0x44,0xa0,0x18,0xf6,0x40,0xfc,0x48,0x50,0xfe,0x00,
+/* 15707 0x3d5b "㵛" */
+0x01,0x20,0x17,0x10,0x83,0x40,0x47,0x12,0x11,0x2f,0xe0,0x23,0x22,0x22,0x23,0x02,
+0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0x48,0x50,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 15708 0x3d5c "㵜" */
+0x00,0x24,0x12,0x12,0x80,0x48,0x44,0x14,0x11,0x22,0xee,0x22,0x22,0x22,0x22,0x00,
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x82,0xaa,0x92,0xba,0x92,0xfe,0x92,0x92,0x8a,0x84,
+/* 15709 0x3d5d "㵝" */
+0x00,0x80,0x5f,0x01,0x82,0x46,0x5b,0x02,0x27,0x45,0xc6,0x45,0x45,0x45,0x44,0x04,
+0x80,0x40,0xfe,0x48,0x30,0x90,0x08,0x06,0xfc,0x24,0x14,0xec,0x24,0xe4,0x14,0x08,
+/* 15710 0x3d5e "㵞" */
+0x00,0x47,0x21,0x21,0x0f,0x81,0x43,0x55,0x19,0x21,0xe0,0x20,0x25,0x25,0x29,0x00,
+0xc8,0x08,0x2a,0x2c,0xc8,0x08,0x88,0x54,0x14,0x22,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 15711 0x3d5f "㵟" */
+0x02,0x42,0x26,0x2b,0x00,0x82,0x45,0x5c,0x14,0x25,0xe5,0x25,0x25,0x25,0x26,0x04,
+0x88,0xa8,0xa8,0xf0,0x1e,0x24,0xd4,0x14,0x14,0xd4,0x54,0x48,0x68,0x54,0x14,0x22,
+/* 15712 0x3d60 "㵠" */
+0x00,0x47,0x24,0x29,0x02,0x87,0x44,0x57,0x14,0x25,0xe5,0x25,0x24,0x29,0x29,0x11,
+0x40,0xfe,0x02,0x14,0x08,0xfc,0x04,0xfc,0x20,0x24,0x24,0xfc,0x20,0x24,0x24,0xfc,
+/* 15713 0x3d61 "㵡" */
+0x03,0x20,0x17,0x14,0x83,0x40,0x43,0x12,0x13,0x24,0xeb,0x22,0x23,0x22,0x22,0x01,
+0xf8,0x40,0xfc,0x44,0x58,0x40,0x58,0x00,0xf8,0x08,0xc8,0x48,0xe8,0x12,0x02,0xfe,
+/* 15714 0x3d62 "㵢" */
+0x00,0x47,0x20,0x2f,0x08,0x83,0x40,0x53,0x10,0x27,0xe4,0x24,0x27,0x24,0x24,0x07,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,
+/* 15715 0x3d63 "㵣" */
+0x00,0x9f,0x51,0x1f,0x91,0x5f,0x48,0x1f,0x24,0x54,0xda,0x50,0x5e,0x40,0x45,0x02,
+0x10,0x10,0x10,0x3e,0x22,0x44,0x10,0x90,0x90,0x90,0xa8,0xa8,0xa8,0xc4,0x44,0x82,
+/* 15716 0x3d64 "㵤" */
+0x00,0x27,0x10,0x14,0x82,0x44,0x40,0x17,0x10,0x22,0xe2,0x25,0x20,0x21,0x22,0x0c,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x40,0xfc,0x40,0x48,0x48,0x54,0xa0,0x10,0x08,0x06,
+/* 15717 0x3d65 "㵥" */
+0x00,0x20,0x17,0x14,0x80,0x45,0x55,0x19,0x16,0x20,0xe3,0x22,0x22,0x22,0x2f,0x00,
+0x80,0x40,0xfc,0x84,0x50,0x28,0x54,0x94,0xf0,0x00,0xf8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 15718 0x3d66 "㵦" */
+0x00,0x21,0x14,0x12,0x81,0x42,0x40,0x16,0x12,0x22,0xe2,0x22,0x22,0x22,0x25,0x08,
+0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,0x00,0xfe,
+/* 15719 0x3d67 "㵧" */
+0x01,0x27,0x11,0x13,0x82,0x43,0x4a,0x0b,0x11,0x13,0xe4,0x2a,0x22,0x23,0x20,0x00,
+0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0x04,0xf4,0x14,0x08,
+/* 15720 0x3d68 "㵨" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x08,0x90,0x60,0x20,0x18,0x06,
+/* 15721 0x3d69 "㵩" */
+0x01,0x27,0x11,0x10,0x84,0x4f,0x44,0x14,0x14,0x27,0xe0,0x2f,0x21,0x22,0x2c,0x00,
+0x08,0xfe,0x08,0x00,0x88,0xfe,0x88,0xf8,0x00,0xfc,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 15722 0x3d6a "㵪" */
+0x02,0x21,0x17,0x10,0x83,0x40,0x47,0x10,0x14,0x22,0xe0,0x22,0x2c,0x24,0x24,0x01,
+0x08,0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0x40,0x7c,0x84,0x28,0x20,0x50,0x88,0x06,
+/* 15723 0x3d6b "㵫" */
+0x01,0x20,0x17,0x10,0x80,0x47,0x40,0x11,0x17,0x21,0xe3,0x27,0x24,0x27,0x24,0x07,
+0xf8,0x10,0xfe,0xa0,0x40,0xbc,0x84,0xce,0x38,0x08,0x18,0xfc,0x04,0xfc,0x04,0xfc,
+/* 15724 0x3d6c "㵬" */
+0x00,0x9d,0x54,0x14,0x14,0x1d,0x95,0x55,0x16,0x1c,0x15,0x55,0x95,0x25,0x27,0x4c,
+0x00,0xf8,0x88,0x90,0xfc,0x54,0x24,0x54,0x88,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 15725 0x3d6d "㵭" */
+0x00,0x20,0x13,0x10,0x87,0x40,0x51,0x17,0x11,0x21,0xe1,0x20,0x25,0x24,0x28,0x00,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x24,0x92,0x92,0x00,
+/* 15726 0x3d6e "㵮" */
+0x00,0x27,0x10,0x13,0x8d,0x43,0x41,0x11,0x10,0x23,0xe2,0x23,0x20,0x27,0x20,0x00,
+0x40,0xfc,0xa0,0x18,0x16,0xf8,0x10,0xf0,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x40,0x40,
+/* 15727 0x3d6f "㵯" */
+0x40,0x2f,0x28,0x8b,0x49,0x4b,0x0a,0x2b,0x2a,0x4b,0xca,0x4b,0x4a,0x53,0x55,0x20,
+0x00,0xf8,0x08,0xe8,0x08,0xe8,0x28,0xe8,0x28,0xe8,0x08,0xfa,0x0a,0xfa,0x56,0x32,
+/* 15728 0x3d70 "㵰" */
+0x01,0x22,0x12,0x12,0x83,0x42,0x4a,0x0b,0x12,0x12,0xe7,0x20,0x21,0x21,0x22,0x04,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 15729 0x3d71 "㵱" */
+0x00,0x4f,0x22,0x2f,0x0a,0x8a,0x4f,0x50,0x17,0x20,0xef,0x21,0x25,0x25,0x29,0x03,
+0x04,0xe4,0x84,0xe4,0xbe,0xa4,0xe4,0x04,0xd4,0x0c,0xec,0x04,0x44,0x24,0x24,0x0c,
+/* 15730 0x3d72 "㵲" */
+0x01,0x42,0x27,0x2a,0x02,0x8f,0x42,0x52,0x1f,0x22,0xe3,0x24,0x2a,0x21,0x22,0x0c,
+0x00,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,
+/* 15731 0x3d73 "㵳" */
+0x00,0x4f,0x28,0x27,0x04,0x82,0x44,0x50,0x13,0x2c,0xe0,0x23,0x20,0x23,0x20,0x03,
+0x40,0xfe,0x02,0xbc,0xa4,0x94,0xe4,0xa0,0x18,0x46,0x90,0x20,0xc8,0x10,0x60,0x80,
+/* 15732 0x3d74 "㵴" */
+0x00,0x80,0x57,0x14,0x95,0x5d,0x45,0x05,0x3d,0x55,0xd5,0x55,0x65,0x49,0x48,0x10,
+0x0c,0x0a,0xfe,0x08,0xe8,0x48,0x4a,0xea,0x2a,0x2c,0xec,0x4c,0x4a,0xea,0x16,0x22,
+/* 15733 0x3d75 "㵵" */
+0x07,0x22,0x13,0x12,0x83,0x42,0x47,0x10,0x10,0x27,0xe1,0x22,0x20,0x21,0x26,0x00,
+0xe0,0x5c,0xc4,0x54,0xc8,0x68,0xd4,0x64,0x3c,0xc0,0x44,0x68,0xd0,0x48,0x46,0x40,
+/* 15734 0x3d76 "㵶" */
+0x01,0x41,0x27,0x21,0x0f,0x82,0x44,0x5f,0x14,0x27,0xe4,0x27,0x24,0x27,0x24,0x00,
+0x10,0x14,0xd2,0x10,0xfe,0x90,0x50,0xf4,0x94,0xf4,0x94,0xe8,0x8a,0xfa,0x26,0x42,
+/* 15735 0x3d77 "㵷" */
+0x20,0x11,0x10,0x7c,0x02,0x29,0x11,0xfc,0x10,0x10,0x7d,0x13,0x11,0x21,0x21,0x40,
+0x10,0x08,0x88,0xbe,0x00,0x14,0x08,0x3e,0x88,0x88,0x1c,0x08,0x08,0x08,0x08,0x08,
+/* 15736 0x3d78 "㵸" */
+0x00,0x20,0x11,0x12,0x85,0x48,0x43,0x12,0x13,0x20,0xe7,0x24,0x27,0x24,0x24,0x04,
+0x40,0xa0,0x10,0x08,0xf4,0x02,0xb8,0xa8,0xb8,0x00,0xfc,0xa4,0xfc,0xa4,0xa4,0x0c,
+/* 15737 0x3d79 "㵹" */
+0x04,0x84,0x44,0x04,0x95,0x55,0x55,0x15,0x35,0x55,0xd5,0x57,0x59,0x40,0x40,0x00,
+0x28,0x28,0xfe,0x28,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x7e,0x10,0x28,0x44,0x82,
+/* 15738 0x3d7a "㵺" */
+0x02,0x22,0x17,0x15,0x88,0x40,0x4b,0x0a,0x13,0x12,0xe3,0x21,0x22,0x27,0x20,0x00,
+0x10,0x10,0xde,0x28,0xc4,0x80,0xfc,0x24,0xfc,0x44,0xfc,0x20,0x20,0xfe,0x20,0x20,
+/* 15739 0x3d7b "㵻" */
+0x40,0x2e,0x2a,0x8a,0x4a,0x4e,0x0a,0x2a,0x2a,0x4e,0xca,0x4a,0x4a,0x52,0x52,0x26,
+0x50,0x96,0x92,0x92,0xd6,0x92,0x92,0xfe,0x10,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 15740 0x3d7c "㵼" */
+0x00,0x27,0x14,0x10,0x83,0x42,0x43,0x12,0x13,0x22,0xe7,0x28,0x25,0x25,0x28,0x00,
+0x00,0xfc,0x04,0x80,0x38,0x08,0xb8,0x08,0xf8,0x00,0xfc,0x04,0x54,0x54,0x28,0x10,
+/* 15741 0x3d7d "㵽" */
+0x03,0x22,0x12,0x13,0x82,0x42,0x43,0x10,0x1f,0x2a,0xea,0x2f,0x2a,0x2a,0x2f,0x08,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 15742 0x3d7e "㵾" */
+0x02,0x82,0x5f,0x02,0x8f,0x42,0x5f,0x00,0x2f,0x48,0xcf,0x48,0x4f,0x48,0x48,0x09,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xe4,0x3c,0xa4,0xa4,0xbc,0x90,0x98,0xa8,0xaa,0xc6,
+/* 15743 0x3d7f "㵿" */
+0x00,0x21,0x13,0x12,0x83,0x42,0x43,0x12,0x14,0x2f,0xe8,0x28,0x2f,0x28,0x28,0x0f,
+0x80,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x10,0xbe,0xa2,0xa2,0xbe,0xa2,0xa2,0xbe,
+/* 15744 0x3d80 "㶀" */
+0x00,0x4e,0x2a,0x2a,0x0a,0x8e,0x4a,0x4a,0x1a,0x2f,0xea,0x2a,0x2a,0x2a,0x2a,0x16,
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x10,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x18,0xe0,
+/* 15745 0x3d81 "㶁" */
+0x03,0x9c,0x41,0x15,0x8a,0x48,0x42,0x02,0x3f,0x42,0xd2,0x4a,0x42,0x4a,0x44,0x01,
+0x90,0x10,0x1e,0x10,0x7e,0x52,0x5c,0x70,0x52,0x4e,0x40,0x5c,0x54,0x54,0x96,0x22,
+/* 15746 0x3d82 "㶂" */
+0x00,0x90,0x49,0x00,0x90,0x4b,0x48,0x01,0x25,0x49,0xd9,0x49,0x48,0x48,0x49,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 15747 0x3d83 "㶃" */
+0x00,0x90,0x49,0x03,0x91,0x49,0x4b,0x01,0x25,0x49,0xdb,0x48,0x49,0x49,0x4a,0x00,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 15748 0x3d84 "㶄" */
+0x07,0x24,0x17,0x14,0x87,0x44,0x44,0x15,0x16,0x25,0xe5,0x25,0x25,0x25,0x24,0x04,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x84,0xf4,0x14,0x24,0xb4,0x14,0xb4,0x14,0xf4,0x14,0x08,
+/* 15749 0x3d85 "㶅" */
+0x42,0x24,0x24,0x86,0x44,0x46,0x04,0x2f,0x28,0x43,0xc0,0x40,0x47,0x40,0x41,0x00,
+0xa0,0x4c,0xa4,0x0c,0xa4,0x4c,0xa4,0xfe,0x02,0xf0,0x20,0x40,0xfc,0x40,0x40,0x80,
+/* 15750 0x3d86 "㶆" */
+0x04,0x42,0x22,0x2f,0x00,0x8f,0x40,0x4f,0x10,0x2f,0xe9,0x29,0x29,0x2f,0x29,0x00,
+0x10,0x10,0x7a,0x12,0x14,0x7e,0x08,0x10,0x3c,0x64,0xa4,0x3c,0x24,0x24,0x3c,0x24,
+/* 15751 0x3d87 "㶇" */
+0x42,0x22,0x22,0x82,0x4f,0x42,0x06,0x27,0x2a,0x4a,0xd2,0x42,0x42,0x42,0x42,0x02,
+0x28,0x28,0x7c,0x28,0x28,0xfe,0x10,0x7c,0xd4,0x7c,0x54,0x7c,0x00,0x28,0x44,0x82,
+/* 15752 0x3d88 "㶈" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x4f,0x48,0x10,0x23,0xe2,0x22,0x23,0x20,0x27,0x00,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0xfe,0x42,0x40,0xf8,0x48,0x48,0xf8,0x44,0xfc,0x04,
+/* 15753 0x3d89 "㶉" */
+0x03,0xbc,0x44,0x11,0x84,0x49,0x5e,0x04,0x29,0x5f,0xc4,0x5f,0x44,0x4a,0x51,0x20,
+0x08,0x10,0xbe,0x22,0x32,0x2a,0x22,0x26,0x20,0x3e,0x02,0x02,0x7a,0x02,0x0a,0x84,
+/* 15754 0x3d8a "㶊" */
+0x00,0x4f,0x2a,0x2a,0x0a,0x8f,0x48,0x48,0x18,0x2f,0xea,0x2a,0x2a,0x2a,0x2f,0x00,
+0x00,0xbe,0x08,0x10,0x3e,0xa2,0xa2,0xbe,0xa2,0xbe,0x22,0x22,0x3e,0x00,0x94,0x22,
+/* 15755 0x3d8b "㶋" */
+0x05,0x55,0x2d,0x25,0x0f,0x82,0x44,0x4a,0x13,0x25,0xe9,0x23,0x25,0x29,0x25,0x02,
+0x08,0x48,0xa8,0x3e,0xa8,0x48,0x48,0xbe,0x08,0x88,0x88,0x7e,0x40,0x20,0x1e,0x00,
+/* 15756 0x3d8c "㶌" */
+0x00,0x9f,0x4a,0x0a,0x8e,0x4a,0x4a,0x0e,0x2a,0x4a,0xcb,0x4e,0x5a,0x42,0x42,0x02,
+0x44,0x44,0xaa,0xee,0x44,0xaa,0xee,0x00,0x28,0xaa,0xaa,0xee,0x28,0x28,0x48,0x88,
+/* 15757 0x3d8d "㶍" */
+0x02,0x42,0x27,0x24,0x09,0x87,0x45,0x55,0x17,0x25,0xe5,0x27,0x20,0x2a,0x2a,0x00,
+0x00,0x22,0x92,0x94,0x3e,0xc8,0x48,0x5e,0xc8,0x48,0x7e,0xc8,0x08,0xa8,0xa8,0x08,
+/* 15758 0x3d8e "㶎" */
+0x01,0x49,0x25,0x24,0x01,0x80,0x5c,0x44,0x14,0x24,0xe4,0x25,0x24,0x2b,0x30,0x00,
+0xfc,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x84,0xfc,0x52,0xcc,0x48,0x64,0x00,0xfe,0x00,
+/* 15759 0x3d8f "㶏" */
+0x00,0x4e,0x2a,0x2a,0x0a,0x8c,0x4a,0x4a,0x1a,0x2a,0xea,0x2c,0x28,0x28,0x29,0x0a,
+0x1c,0xe0,0x54,0x28,0x7c,0x10,0xfe,0x00,0xfc,0x04,0x7c,0x04,0xfc,0x14,0x4a,0x38,
+/* 15760 0x3d90 "㶐" */
+0x00,0x20,0x17,0x14,0x84,0x45,0x47,0x15,0x15,0x25,0xe5,0x25,0x28,0x2a,0x32,0x04,
+0x40,0x20,0xfe,0xa8,0xfe,0x50,0x7c,0x50,0x7c,0x50,0x7e,0x40,0xa4,0x8a,0x8a,0x78,
+/* 15761 0x3d91 "㶑" */
+0x02,0x82,0x45,0x08,0x90,0x6f,0x40,0x00,0x3d,0x55,0xd5,0x5d,0x48,0x48,0x55,0x22,
+0x10,0x10,0x10,0x9e,0x52,0xa2,0x08,0x08,0xc8,0x48,0x48,0xd4,0x94,0x94,0x54,0x22,
+/* 15762 0x3d92 "㶒" */
+0x1f,0x91,0x5f,0x11,0x9f,0x50,0x57,0x14,0x37,0x54,0xd7,0x54,0x57,0x50,0x5a,0x10,
+0x3e,0x22,0x3e,0x22,0x3e,0x02,0xfa,0x82,0xf2,0x82,0xf2,0x82,0xfa,0x0a,0xaa,0x14,
+/* 15763 0x3d93 "㶓" */
+0x02,0x9f,0x42,0x00,0x07,0x14,0x95,0x5d,0x05,0x3d,0x15,0x55,0xa5,0x09,0x08,0x10,
+0x10,0xfe,0x14,0x0a,0xfe,0x08,0xe8,0x48,0xea,0x2a,0xec,0x4c,0x4a,0xea,0x16,0x22,
+/* 15764 0x3d94 "㶔" */
+0x00,0x43,0x22,0x22,0x03,0x80,0x4f,0x4a,0x1a,0x2f,0xe0,0x2f,0x20,0x21,0x22,0x0c,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 15765 0x3d95 "㶕" */
+0x02,0x43,0x25,0x28,0x07,0x84,0x47,0x54,0x17,0x24,0xe5,0x25,0x25,0x25,0x25,0x04,
+0x10,0xde,0x28,0x84,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x0c,
+/* 15766 0x3d96 "㶖" */
+0x08,0x89,0x4a,0x10,0x13,0x34,0xb5,0x55,0x15,0x15,0x14,0x55,0x94,0x13,0x11,0x12,
+0x80,0xf8,0x88,0x70,0x8e,0x00,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,
+/* 15767 0x3d97 "㶗" */
+0x20,0x7f,0xaa,0x7f,0x2a,0x3f,0x06,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3d,0x09,0x73,
+0x28,0x78,0x14,0x7c,0x54,0xb2,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x84,0x48,0x30,0x0e,
+/* 15768 0x3d98 "㶘" */
+0x02,0x43,0x25,0x28,0x07,0x80,0x47,0x54,0x17,0x22,0xe3,0x22,0x23,0x20,0x2f,0x00,
+0x10,0xde,0x28,0x84,0xfc,0xa0,0xfc,0xa4,0xfc,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,
+/* 15769 0x3d99 "㶙" */
+0x02,0xaa,0x56,0x02,0xa7,0x51,0x52,0x05,0x29,0x52,0xf4,0x51,0x52,0x54,0x52,0x01,
+0x84,0xa4,0xd4,0x9e,0xd4,0x24,0x24,0x5e,0x84,0xc4,0xc4,0xbe,0xa0,0x90,0x8e,0x00,
+/* 15770 0x3d9a "㶚" */
+0x07,0x20,0x17,0x14,0x87,0x42,0x47,0x12,0x13,0x21,0xe7,0x25,0x27,0x21,0x2f,0x01,
+0xfe,0x90,0xfe,0x92,0xfe,0x80,0xde,0x92,0x92,0x1e,0xd2,0x52,0xde,0x12,0xd2,0x26,
+/* 15771 0x3d9b "㶛" */
+0x10,0x88,0x49,0x3d,0x12,0x11,0x9d,0x55,0x15,0x15,0x15,0x55,0xa7,0x24,0x4d,0x82,
+0x80,0x80,0xfe,0x00,0xa0,0x2c,0x34,0xac,0x34,0x54,0xdc,0x54,0xfe,0x88,0x04,0x02,
+/* 15772 0x3d9c "㶜" */
+0x00,0xbe,0x62,0x3e,0x20,0x31,0xaa,0x60,0x3f,0x2a,0x2a,0x7f,0xaa,0x2a,0x32,0x41,
+0x02,0xfa,0x8a,0xfa,0x82,0xc6,0xaa,0x82,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xca,0x04,
+/* 15773 0x3d9d "㶝" */
+0x00,0x90,0x4b,0x02,0x92,0x4b,0x4a,0x02,0x26,0x4a,0xda,0x4a,0x4a,0x4b,0x4d,0x0a,
+0x40,0x20,0xfe,0xa4,0xbe,0xe8,0xbe,0xa8,0xbe,0xa8,0xbe,0xa0,0x14,0x52,0x4a,0x38,
+/* 15774 0x3d9e "㶞" */
+0x03,0x22,0x13,0x12,0x83,0x40,0x4f,0x14,0x17,0x21,0xe7,0x21,0x2f,0x21,0x23,0x0d,
+0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0xa4,0xbc,0x10,0xfc,0x10,0xfe,0x24,0x18,0x86,
+/* 15775 0x3d9f "㶟" */
+0x47,0x24,0x27,0x84,0x4f,0x4a,0x0f,0x2a,0x2f,0x42,0xc7,0x40,0x4f,0x40,0x45,0x08,
+0xfc,0x44,0xfc,0x44,0xfe,0xaa,0xbe,0xaa,0xbe,0x20,0xc0,0x84,0xfe,0x42,0x48,0x84,
+/* 15776 0x3da0 "㶠" */
+0x00,0x9e,0x54,0x1e,0x94,0x5e,0x54,0x14,0x3f,0x41,0xd5,0x55,0x55,0x51,0x41,0x06,
+0x00,0xfe,0xaa,0xaa,0xfe,0x10,0x7c,0x10,0xfe,0x28,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 15777 0x3da1 "㶡" */
+0x00,0x3f,0x21,0x21,0x21,0x29,0x29,0x29,0x31,0x22,0x22,0x24,0x24,0x48,0x50,0x80,
+0x00,0xf8,0x08,0x08,0x08,0x28,0x28,0x48,0x08,0x88,0x48,0x4a,0x2a,0x2a,0x06,0x02,
+/* 15778 0x3da2 "㶢" */
+0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc2,0x02,0x3f,0x02,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,0x00,0xe0,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 15779 0x3da3 "㶣" */
+0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x00,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15780 0x3da4 "㶤" */
+0x10,0x10,0x10,0x10,0x55,0x59,0x52,0x94,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x86,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x84,0x48,0x28,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 15781 0x3da5 "㶥" */
+0x10,0x11,0x10,0x10,0x54,0x58,0x50,0x93,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 15782 0x3da6 "㶦" */
+0x10,0x11,0x10,0x10,0x54,0x58,0x53,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 15783 0x3da7 "㶧" */
+0x10,0x10,0x10,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 15784 0x3da8 "㶨" */
+0x00,0x7f,0x00,0x01,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,0x00,0x24,0x22,0x42,0x80,
+0x00,0xfc,0x80,0x00,0x00,0x60,0x18,0x04,0x02,0x00,0x00,0x00,0x88,0x44,0x44,0x04,
+/* 15785 0x3da9 "㶩" */
+0x10,0x10,0x10,0x11,0x55,0x5a,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x82,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 15786 0x3daa "㶪" */
+0x00,0x7f,0x01,0x03,0x05,0x19,0x61,0x00,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x00,0x00,0x60,0x18,0x04,0x00,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15787 0x3dab "㶫" */
+0x01,0x01,0x7f,0x01,0x21,0x12,0x0c,0xf0,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x00,0x04,0xc8,0x30,0x0c,0x02,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15788 0x3dac "㶬" */
+0x10,0x10,0x10,0x15,0x58,0x50,0x50,0x91,0x10,0x10,0x10,0x29,0x25,0x42,0x40,0x80,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 15789 0x3dad "㶭" */
+0x10,0x10,0x10,0x11,0x55,0x5a,0x53,0x90,0x11,0x11,0x12,0x2b,0x24,0x44,0x40,0x80,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 15790 0x3dae "㶮" */
+0x00,0x7f,0x01,0x01,0x3f,0x21,0x22,0x24,0x20,0x20,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x88,0x48,0x08,0x18,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 15791 0x3daf "㶯" */
+0x10,0x10,0x13,0x12,0x56,0x5a,0x52,0x92,0x12,0x12,0x13,0x2a,0x24,0x44,0x41,0x82,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 15792 0x3db0 "㶰" */
+0x10,0x10,0x10,0x14,0x5b,0x50,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 15793 0x3db1 "㶱" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x90,0x10,0x10,0x11,0x2a,0x24,0x44,0x40,0x80,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0xfa,0x20,0x20,0x20,0x20,
+/* 15794 0x3db2 "㶲" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x82,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x04,0x0c,
+/* 15795 0x3db3 "㶳" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x3f,0x01,0xff,0x00,0x01,0x11,0x22,0x0c,0x70,
+0x00,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,0x00,0x10,0xa0,0x60,0x1c,
+/* 15796 0x3db4 "㶴" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x90,0x11,0x10,0x10,0x29,0x24,0x44,0x40,0x81,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 15797 0x3db5 "㶵" */
+0x08,0x08,0x13,0x30,0x50,0x9f,0x10,0x10,0x10,0x17,0x10,0x00,0x24,0x22,0x42,0x80,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x00,0x00,0x88,0x44,0x44,0x04,
+/* 15798 0x3db6 "㶶" */
+0x10,0x10,0x10,0x17,0x5a,0x54,0x50,0x90,0x11,0x12,0x14,0x28,0x24,0x44,0x40,0x80,
+0x20,0x20,0x20,0xfe,0x42,0x44,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 15799 0x3db7 "㶷" */
+0x10,0x10,0x11,0x15,0x5a,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x44,0x40,0x80,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 15800 0x3db8 "㶸" */
+0x10,0x10,0x11,0x14,0x58,0x50,0x51,0x92,0x11,0x13,0x11,0x29,0x25,0x42,0x43,0x84,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 15801 0x3db9 "㶹" */
+0x10,0x11,0x10,0x14,0x5b,0x50,0x50,0x90,0x13,0x10,0x10,0x29,0x25,0x42,0x44,0x80,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0x20,0x22,0xb2,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 15802 0x3dba "㶺" */
+0x10,0x11,0x10,0x10,0x54,0x5b,0x50,0x90,0x11,0x12,0x14,0x28,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x20,0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 15803 0x3dbb "㶻" */
+0x08,0x1f,0x28,0x07,0x18,0xe1,0x1f,0x01,0x1f,0x01,0x7f,0x01,0x01,0x48,0x44,0x84,
+0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x00,0xf0,0x00,0xfc,0x00,0x00,0x88,0x44,0x44,
+/* 15804 0x3dbc "㶼" */
+0x10,0x10,0x10,0x15,0x5b,0x50,0x50,0x91,0x12,0x10,0x13,0x28,0x24,0x44,0x41,0x86,
+0x20,0x40,0x88,0x04,0xfe,0x82,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 15805 0x3dbd "㶽" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x50,0x90,0x13,0x12,0x12,0x2a,0x27,0x42,0x42,0x82,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 15806 0x3dbe "㶾" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x00,0x7f,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0xfc,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 15807 0x3dbf "㶿" */
+0x10,0x10,0x13,0x10,0x54,0x5b,0x52,0x94,0x11,0x10,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 15808 0x3dc0 "㷀" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x41,0x7f,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0xf0,0x10,0x10,0x10,0xd0,0x12,0x0a,0x06,0x02,
+/* 15809 0x3dc1 "㷁" */
+0x10,0x11,0x10,0x10,0x54,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 15810 0x3dc2 "㷂" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x7c,0x04,0x44,0x28,0x10,0x28,0xc4,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15811 0x3dc3 "㷃" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xef,0x08,0x0f,0x08,0x0f,0x08,0xff,0x11,0x14,0x18,
+0x00,0x08,0x08,0x90,0x40,0x30,0xee,0x00,0xe0,0x00,0xe0,0x00,0xfe,0x10,0xe0,0x1c,
+/* 15812 0x3dc4 "㷄" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x10,0x13,0x10,0x28,0x25,0x42,0x40,0x80,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 15813 0x3dc5 "㷅" */
+0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x7c,0x04,0x28,0x10,0xa8,0x44,0x00,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15814 0x3dc6 "㷆" */
+0x10,0x10,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x10,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x20,0x40,0xfc,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 15815 0x3dc7 "㷇" */
+0x20,0x20,0x3c,0x45,0xa8,0x10,0x20,0xc8,0x11,0x3d,0x46,0x84,0x28,0x10,0x20,0xc1,
+0x40,0x40,0x40,0xfe,0x40,0x90,0x90,0x92,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 15816 0x3dc8 "㷈" */
+0x10,0x10,0x13,0x10,0x54,0x59,0x52,0x91,0x11,0x11,0x11,0x29,0x24,0x44,0x40,0x80,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 15817 0x3dc9 "㷉" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x2f,0x20,0x3f,0x22,0x2a,0x2a,0x52,0x45,0x88,0x10,
+0x04,0x84,0x84,0x84,0xbe,0x04,0x84,0x24,0xd4,0x14,0x44,0x84,0x04,0x04,0x94,0x48,
+/* 15818 0x3dca "㷊" */
+0x08,0x08,0x08,0x7e,0x08,0x1c,0x1a,0x2a,0x48,0x89,0x08,0x08,0x00,0x48,0x44,0x84,
+0x20,0x20,0x20,0xfc,0x20,0x30,0x70,0x68,0xa4,0x22,0x20,0x20,0x00,0x88,0x44,0x44,
+/* 15819 0x3dcb "㷋" */
+0x10,0x10,0x10,0x11,0x54,0x58,0x53,0x90,0x10,0x10,0x10,0x29,0x24,0x44,0x41,0x82,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 15820 0x3dcc "㷌" */
+0x10,0x11,0x10,0x14,0x58,0x51,0x50,0x93,0x12,0x10,0x11,0x29,0x25,0x45,0x41,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 15821 0x3dcd "㷍" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 15822 0x3dce "㷎" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x50,0x91,0x12,0x11,0x11,0x29,0x25,0x44,0x40,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 15823 0x3dcf "㷏" */
+0x06,0x38,0x08,0x7e,0x08,0x1c,0x2a,0x48,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x40,0x7c,0x90,0x10,0xfe,0x10,0x10,0x10,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15824 0x3dd0 "㷐" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x10,0x10,0x11,0x28,0x24,0x44,0x43,0x80,
+0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 15825 0x3dd1 "㷑" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xe0,0x3f,0x04,0x3f,0x24,0x3f,0x01,0x3f,0x01,0xff,
+0x00,0x08,0x08,0x90,0x40,0x30,0x0e,0xf8,0x40,0xf8,0x48,0xf8,0x00,0xf8,0x00,0xfe,
+/* 15826 0x3dd2 "㷒" */
+0x11,0x11,0x11,0x15,0x59,0x51,0x51,0x90,0x10,0x13,0x12,0x2a,0x26,0x42,0x42,0x82,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 15827 0x3dd3 "㷓" */
+0x10,0x10,0x10,0x15,0x5a,0x50,0x51,0x92,0x10,0x11,0x10,0x28,0x26,0x42,0x44,0x80,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 15828 0x3dd4 "㷔" */
+0x10,0x10,0x13,0x14,0x5a,0x51,0x51,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 15829 0x3dd5 "㷕" */
+0x22,0x12,0x14,0xff,0x14,0x14,0x7f,0x55,0x55,0x63,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x10,0x10,0x92,0x52,0x54,0x58,0x90,0x10,0x28,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 15830 0x3dd6 "㷖" */
+0x00,0x7d,0x44,0x44,0x7c,0x44,0x44,0x7c,0x11,0x14,0x58,0x50,0x90,0x28,0x44,0x80,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 15831 0x3dd7 "㷗" */
+0x00,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x4f,0x81,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xbc,0xa4,0xa4,0x3c,0xa2,0xa2,0x9e,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15832 0x3dd8 "㷘" */
+0x10,0x10,0x11,0x13,0x54,0x59,0x51,0x91,0x11,0x10,0x13,0x28,0x24,0x45,0x42,0x80,
+0x40,0x88,0x04,0xfe,0x02,0xfc,0x04,0x04,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 15833 0x3dd9 "㷙" */
+0x11,0x10,0x10,0x17,0x58,0x53,0x52,0x92,0x13,0x12,0x12,0x2b,0x26,0x42,0x42,0x82,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 15834 0x3dda "㷚" */
+0x10,0x10,0x13,0x10,0x55,0x59,0x51,0x90,0x13,0x12,0x11,0x28,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 15835 0x3ddb "㷛" */
+0x08,0x0b,0x12,0x32,0x53,0x90,0x17,0x10,0x11,0x12,0x1c,0x10,0x00,0x48,0x44,0x84,
+0x00,0xf8,0x08,0x08,0xf8,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,0x00,0x88,0x44,0x44,
+/* 15836 0x3ddc "㷜" */
+0x20,0x20,0x27,0x20,0xaa,0xb4,0xa1,0xa2,0x24,0x20,0x27,0x20,0x50,0x49,0x42,0x8c,
+0x80,0x40,0xfe,0x90,0x98,0x94,0x14,0x30,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 15837 0x3ddd "㷝" */
+0x10,0x10,0x13,0x12,0x54,0x59,0x52,0x90,0x10,0x13,0x10,0x28,0x24,0x44,0x41,0x82,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 15838 0x3dde "㷞" */
+0x20,0x23,0x22,0x22,0xaa,0xb2,0xa2,0xa2,0x22,0x22,0x22,0x22,0x53,0x4c,0x44,0x88,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x10,0x50,0x20,
+/* 15839 0x3ddf "㷟" */
+0x10,0x12,0x11,0x15,0x58,0x50,0x57,0x91,0x11,0x11,0x11,0x29,0x25,0x42,0x44,0x80,
+0x08,0x10,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7e,0x42,0x42,0x7e,0x42,0x80,0x7e,0x00,
+/* 15840 0x3de0 "㷠" */
+0x01,0x09,0x12,0x0c,0x71,0x09,0x12,0x0c,0x70,0x10,0x3e,0x42,0x14,0x08,0x30,0xc0,
+0x10,0x20,0xe0,0x18,0x04,0x10,0xa0,0x60,0x1c,0x10,0xfc,0x10,0x90,0xfe,0x10,0x10,
+/* 15841 0x3de1 "㷡" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xfe,0x80,0xfc,0x84,0xfc,0x80,0xfe,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 15842 0x3de2 "㷢" */
+0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x08,0x37,0xc0,0x1f,0x01,0x11,0x22,0x0c,0x70,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x80,0xfc,0x00,0x10,0xa0,0x60,0x1c,
+/* 15843 0x3de3 "㷣" */
+0x10,0x10,0x13,0x10,0x55,0x58,0x53,0x90,0x10,0x10,0x11,0x28,0x27,0x44,0x40,0x80,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 15844 0x3de4 "㷤" */
+0x10,0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x10,0x12,0x54,0xa8,0x24,0x44,0x81,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 15845 0x3de5 "㷥" */
+0x10,0x15,0x54,0x58,0x90,0x29,0x44,0x90,0x15,0x59,0x52,0x90,0x28,0x44,0x81,0x00,
+0x00,0xf8,0x10,0x20,0x24,0xa8,0xb0,0xa8,0x28,0x24,0x22,0xa0,0x40,0x00,0xfc,0x00,
+/* 15846 0x3de6 "㷦" */
+0x00,0xff,0x24,0x3c,0x24,0x3d,0x24,0x24,0x2f,0xf4,0x05,0x06,0x04,0x48,0x44,0x84,
+0x20,0x20,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x00,0x88,0x44,0x44,
+/* 15847 0x3de7 "㷧" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 15848 0x3de8 "㷨" */
+0x10,0x12,0x13,0x14,0x59,0x52,0x50,0x93,0x10,0x11,0x10,0x29,0x24,0x43,0x40,0x80,
+0x20,0x22,0xfe,0x80,0xf8,0x88,0x70,0x8e,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 15849 0x3de9 "㷩" */
+0x00,0x27,0x25,0x27,0x24,0x27,0x25,0x47,0x00,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xdc,0x04,0x84,0x9c,0x90,0x12,0xce,0x00,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 15850 0x3dea "㷪" */
+0x10,0x10,0x11,0x13,0x55,0x59,0x51,0x91,0x11,0x11,0x13,0x28,0x24,0x45,0x42,0x84,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 15851 0x3deb "㷫" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x80,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 15852 0x3dec "㷬" */
+0x10,0x10,0x13,0x10,0x54,0x59,0x51,0x91,0x11,0x11,0x10,0x2b,0x24,0x44,0x41,0x82,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 15853 0x3ded "㷭" */
+0x21,0x13,0x15,0x00,0x77,0x11,0x10,0x13,0x28,0x47,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xf0,0x10,0xe0,0x5c,0xf0,0x40,0xfc,0x40,0xfe,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 15854 0x3dee "㷮" */
+0x10,0x10,0x17,0x10,0x57,0x5a,0x53,0x92,0x13,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 15855 0x3def "㷯" */
+0x10,0x10,0x55,0x58,0x90,0x10,0x2b,0x44,0x91,0x12,0x7c,0x10,0x11,0x1e,0xf0,0x40,
+0x20,0x20,0xfc,0x40,0xf8,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfc,0x20,0x20,0x20,
+/* 15856 0x3df0 "㷰" */
+0x10,0x10,0x13,0x14,0x59,0x51,0x51,0x91,0x10,0x13,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 15857 0x3df1 "㷱" */
+0x10,0x10,0x22,0x7f,0x01,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2a,0x24,0x00,0x24,0x42,
+0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x20,0x44,0xfe,0x42,0x00,0x88,0x44,
+/* 15858 0x3df2 "㷲" */
+0x21,0x27,0x21,0x2f,0xa9,0xb7,0xa5,0xa7,0x25,0x27,0x21,0x27,0x51,0x49,0x4e,0x84,
+0xc8,0x08,0x08,0xe8,0x1e,0xca,0x4a,0xca,0x4a,0xca,0x0a,0xca,0x12,0xd2,0x2a,0x44,
+/* 15859 0x3df3 "㷳" */
+0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x24,0x24,0x24,0x20,0x22,0x44,0x40,0x83,0x0c,
+0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0x40,0x48,0x50,0xa0,0x18,0x06,
+/* 15860 0x3df4 "㷴" */
+0x3f,0x21,0x2e,0x22,0x2f,0x27,0x2a,0x32,0x20,0x20,0x24,0x28,0x21,0x42,0x4c,0xb0,
+0xfe,0x04,0x38,0x10,0xbc,0x18,0xb4,0x52,0x00,0x80,0x88,0x90,0x40,0x20,0x18,0x06,
+/* 15861 0x3df5 "㷵" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x90,0x11,0x10,0x13,0x28,0x26,0x42,0x44,0x80,
+0x00,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 15862 0x3df6 "㷶" */
+0x11,0x17,0x21,0x2f,0x61,0xa3,0x26,0x2b,0x22,0x23,0x22,0x22,0x00,0x48,0x44,0x84,
+0x10,0xfc,0x10,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x48,0x58,0x00,0x88,0x44,0x44,
+/* 15863 0x3df7 "㷷" */
+0x10,0x13,0x12,0x17,0x5a,0x52,0x51,0x90,0x10,0x13,0x10,0x28,0x27,0x44,0x41,0x82,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 15864 0x3df8 "㷸" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x50,0x91,0x10,0x13,0x10,0x29,0x24,0x43,0x40,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfc,0xa8,0xfe,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 15865 0x3df9 "㷹" */
+0x10,0x13,0x10,0x10,0x54,0x58,0x51,0x91,0x11,0x11,0x11,0x28,0x27,0x44,0x40,0x80,
+0x88,0xfe,0x88,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 15866 0x3dfa "㷺" */
+0x20,0x3e,0x44,0xa8,0x46,0x42,0x76,0x42,0x7e,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x20,0x20,0x3e,0x44,0x84,0x28,0x10,0x28,0x44,0x02,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 15867 0x3dfb "㷻" */
+0x10,0x10,0x11,0x13,0x55,0x59,0x53,0x91,0x11,0x11,0x17,0x28,0x25,0x45,0x42,0x80,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 15868 0x3dfc "㷼" */
+0x04,0xff,0x04,0x04,0x17,0x10,0xf7,0x14,0x34,0xd7,0x10,0x01,0x11,0x22,0x0c,0x70,
+0x40,0xfe,0x40,0x40,0xd0,0x12,0xdc,0x50,0x52,0xd2,0x0e,0x00,0x10,0xa0,0x60,0x1c,
+/* 15869 0x3dfd "㷽" */
+0x10,0x10,0x13,0x10,0x55,0x58,0x53,0x91,0x10,0x13,0x10,0x29,0x25,0x45,0x41,0x81,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 15870 0x3dfe "㷾" */
+0x20,0x20,0x20,0x23,0xaa,0xb2,0xa3,0xa2,0x22,0x23,0x22,0x23,0x52,0x4d,0x44,0x89,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 15871 0x3dff "㷿" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x50,0x90,0x11,0x11,0x11,0x29,0x24,0x44,0x41,0x82,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 15872 0x3e00 "㸀" */
+0x10,0x13,0x10,0x14,0x58,0x50,0x50,0x93,0x12,0x12,0x12,0x2a,0x26,0x41,0x40,0x83,
+0x20,0xfe,0x00,0xf8,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x26,0xf8,0x20,0xfe,
+/* 15873 0x3e01 "㸁" */
+0x10,0x12,0x11,0x14,0x5b,0x50,0x50,0x93,0x10,0x11,0x10,0x2b,0x24,0x41,0x46,0x80,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 15874 0x3e02 "㸂" */
+0x01,0x27,0x10,0x03,0x70,0x13,0x10,0x13,0x10,0x2f,0x41,0x11,0x22,0x04,0x18,0xe0,
+0x10,0xfc,0x80,0x48,0xb0,0x68,0xa4,0x20,0x40,0xfe,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 15875 0x3e03 "㸃" */
+0x00,0x7f,0x49,0x6b,0x5d,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x00,0x48,0x44,0x84,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x88,0x44,0x44,
+/* 15876 0x3e04 "㸄" */
+0x20,0x20,0x23,0x20,0xa8,0xb7,0xa2,0xa2,0x25,0x20,0x21,0x21,0x51,0x49,0x41,0x82,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 15877 0x3e05 "㸅" */
+0x22,0x22,0x23,0x25,0xa8,0xb0,0xa7,0xa4,0x27,0x24,0x27,0x24,0x55,0x4e,0x44,0x80,
+0x10,0x10,0xde,0x28,0x84,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0x34,0x28,0xa0,0x20,0x20,
+/* 15878 0x3e06 "㸆" */
+0x11,0x11,0x12,0x17,0x58,0x51,0x51,0x91,0x10,0x13,0x10,0x29,0x24,0x43,0x40,0x80,
+0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 15879 0x3e07 "㸇" */
+0x10,0x11,0x10,0x13,0x54,0x59,0x52,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x40,0x81,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 15880 0x3e08 "㸈" */
+0x08,0x24,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x10,0x48,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,0x40,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 15881 0x3e09 "㸉" */
+0x21,0x27,0xaa,0xb1,0xaf,0x21,0x57,0x49,0x89,0x00,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x08,0xc8,0xaa,0x2c,0xe8,0x08,0xd4,0x12,0x22,0x00,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 15882 0x3e0a "㸊" */
+0x21,0x21,0x27,0x21,0xa9,0xb7,0xa5,0xa5,0x27,0x21,0x23,0x25,0x59,0x49,0x41,0x81,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 15883 0x3e0b "㸋" */
+0x20,0x21,0x3d,0x44,0xa9,0x50,0x21,0x42,0x91,0x55,0x55,0x59,0x91,0x29,0x25,0x45,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 15884 0x3e0c "㸌" */
+0x11,0x10,0x13,0x12,0x55,0x58,0x51,0x90,0x11,0x13,0x15,0x29,0x25,0x45,0x41,0x81,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 15885 0x3e0d "㸍" */
+0x21,0x21,0x21,0x27,0xad,0xb5,0xa7,0xa4,0x24,0x27,0x24,0x27,0x5a,0x4b,0x51,0x87,
+0x08,0xec,0x0a,0xe8,0x28,0xde,0x28,0xea,0x0a,0xea,0x0c,0xec,0x2a,0xea,0x56,0xe2,
+/* 15886 0x3e0e "㸎" */
+0x13,0x11,0x11,0x15,0x59,0x51,0x57,0x90,0x17,0x12,0x13,0x2a,0x27,0x42,0x47,0x80,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 15887 0x3e0f "㸏" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x35,0x2f,0x21,0x27,0x21,0x2f,0x24,0x49,0x46,0xb8,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x32,0x3c,0x20,0x38,0x20,0x3c,0x88,0x50,0x30,0x0e,
+/* 15888 0x3e10 "㸐" */
+0x28,0xfe,0x28,0x39,0x12,0x7c,0x54,0x7c,0x10,0x7c,0x10,0xfe,0x28,0x44,0x24,0x42,
+0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,0x00,0x88,0x44,
+/* 15889 0x3e11 "㸑" */
+0x2f,0x48,0x6b,0x48,0x6b,0x4a,0xff,0x88,0x7e,0x2c,0x4a,0x01,0x11,0x22,0x0c,0x70,
+0xec,0x24,0xac,0x24,0xac,0xa4,0xfe,0x22,0xfc,0x68,0xa4,0x00,0x10,0xa0,0x60,0x1c,
+/* 15890 0x3e12 "㸒" */
+0x00,0x7f,0x02,0x21,0x11,0x10,0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x3f,0x00,
+0xfc,0x00,0x08,0x08,0x10,0x20,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,
+/* 15891 0x3e13 "㸓" */
+0x00,0x7f,0x02,0x21,0x11,0x10,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0xfc,0x00,0x08,0x08,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 15892 0x3e14 "㸔" */
+0x00,0x7f,0x21,0x11,0x12,0xff,0x04,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x0f,0x08,
+0xf8,0x00,0x10,0x10,0x20,0xfe,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 15893 0x3e15 "㸕" */
+0x02,0x07,0x38,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x48,0x48,0x88,
+0x28,0x7e,0x48,0xfe,0x48,0x7e,0x48,0x7e,0x40,0x7e,0x22,0x9c,0x62,0x30,0x0e,0x00,
+/* 15894 0x3e16 "㸖" */
+0x00,0x28,0x24,0x42,0x40,0x84,0x04,0x48,0x28,0x10,0x18,0x24,0x24,0x40,0x83,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 15895 0x3e17 "㸗" */
+0x08,0x10,0x28,0x44,0x03,0x1c,0xe0,0x3f,0x20,0x2f,0x20,0x27,0x24,0x27,0x20,0x20,
+0x40,0x20,0x50,0x88,0x00,0xe0,0x1e,0xf8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x28,0x10,
+/* 15896 0x3e18 "㸘" */
+0x08,0x10,0x28,0x44,0x03,0x1c,0xe0,0x1f,0x12,0x1f,0x00,0x7f,0x01,0x01,0x05,0x02,
+0x40,0x20,0x50,0x88,0x00,0xe0,0x1e,0xf0,0x90,0xf0,0x00,0xfc,0x00,0x00,0x00,0x00,
+/* 15897 0x3e19 "㸙" */
+0x08,0x10,0x28,0x44,0x03,0x1c,0xe2,0x1f,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,
+0x40,0x20,0x50,0x88,0x00,0xe0,0x1e,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 15898 0x3e1a "㸚" */
+0x00,0x84,0x44,0x28,0x10,0x28,0x45,0x84,0x00,0x04,0x44,0x28,0x10,0x28,0x44,0x85,
+0x08,0x88,0x50,0x20,0x50,0x88,0x00,0x08,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 15899 0x3e1b "㸛" */
+0x04,0x25,0x24,0x24,0x24,0x3c,0x04,0x04,0xfd,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 15900 0x3e1c "㸜" */
+0x04,0x24,0x24,0x25,0x25,0x3e,0x04,0x05,0xfc,0x24,0x24,0x24,0x24,0x44,0x45,0x84,
+0x20,0x10,0x10,0xfe,0x02,0x54,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 15901 0x3e1d "㸝" */
+0x04,0x24,0x24,0x24,0x24,0x3e,0x20,0x21,0x3c,0x24,0x24,0x24,0x24,0x44,0x45,0x86,
+0x40,0x40,0x40,0x7c,0x44,0x88,0xa0,0x20,0x20,0x50,0x50,0x48,0x88,0x84,0x04,0x02,
+/* 15902 0x3e1e "㸞" */
+0x04,0x24,0x24,0x24,0x24,0x3e,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x44,0x85,
+0x10,0x90,0x90,0x90,0x90,0xfe,0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 15903 0x3e1f "㸟" */
+0x04,0x24,0x24,0x24,0x24,0x3e,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 15904 0x3e20 "㸠" */
+0x08,0x48,0x48,0x4a,0x49,0x7c,0x40,0x41,0x7a,0x4c,0x48,0x48,0x49,0x49,0x4a,0x8c,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 15905 0x3e21 "㸡" */
+0x08,0x49,0x49,0x49,0x49,0x7e,0x40,0x43,0x78,0x48,0x48,0x49,0x49,0x4a,0x48,0x88,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 15906 0x3e22 "㸢" */
+0x08,0x48,0x49,0x48,0x48,0x7d,0x40,0x40,0x79,0x4a,0x48,0x48,0x48,0x48,0x48,0x88,
+0x44,0x44,0xfe,0x44,0x44,0xfe,0x40,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 15907 0x3e23 "㸣" */
+0x08,0x4a,0x49,0x48,0x4b,0x7c,0x40,0x43,0x78,0x49,0x48,0x4b,0x48,0x49,0x4e,0x88,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 15908 0x3e24 "㸤" */
+0x40,0x22,0x22,0xfa,0x02,0x53,0x22,0xfa,0x23,0x22,0x72,0x22,0x22,0x44,0x44,0x88,
+0x90,0x88,0x88,0xbe,0x80,0xd4,0x08,0x3e,0x88,0x88,0x9c,0x88,0x88,0x88,0x88,0x88,
+/* 15909 0x3e25 "㸥" */
+0x09,0x4a,0x4f,0x4a,0x4b,0x7e,0x43,0x42,0x79,0x4a,0x4f,0x4a,0x4b,0x48,0x49,0x8e,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 15910 0x3e26 "㸦" */
+0x00,0x3f,0x00,0x10,0x10,0x20,0x3f,0x00,0x10,0x08,0x06,0x01,0x00,0x00,0x02,0x01,
+0x00,0xf8,0x80,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,0x80,0xf0,0x8e,0x80,0x00,
+/* 15911 0x3e27 "㸧" */
+0x00,0x7e,0x04,0x24,0x24,0x24,0x44,0x7e,0x0c,0x14,0x14,0x24,0x44,0x84,0x14,0x08,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x92,0x92,0x94,0x88,0x88,0xa4,0xc2,0x80,
+/* 15912 0x3e28 "㸨" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x08,0x08,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0x94,0xe4,0x84,0x04,0x04,0x04,0x04,
+/* 15913 0x3e29 "㸩" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x09,0x0e,0xf8,0x48,0x08,0x08,0x08,0x08,0x08,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 15914 0x3e2a "㸪" */
+0x11,0x11,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x12,0x12,0x14,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 15915 0x3e2b "㸫" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0x0e,0xf8,0x48,0x08,0x08,0x09,0x09,0x0a,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 15916 0x3e2c "㸬" */
+0x10,0x10,0x50,0x53,0x7c,0x50,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 15917 0x3e2d "㸭" */
+0x10,0x10,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,0x10,0x10,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 15918 0x3e2e "㸮" */
+0x10,0x10,0x50,0x50,0x7d,0x51,0x92,0x15,0x1c,0xf0,0x50,0x10,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 15919 0x3e2f "㸯" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0x0e,0xf8,0x49,0x08,0x08,0x08,0x08,0x08,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 15920 0x3e30 "㸰" */
+0x10,0x10,0x50,0x51,0x7d,0x52,0x90,0x10,0x1c,0xf0,0x50,0x10,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 15921 0x3e31 "㸱" */
+0x10,0x10,0x50,0x51,0x7a,0x51,0x91,0x11,0x1b,0x31,0xd1,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 15922 0x3e32 "㸲" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x89,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x7e,0xa0,0xa0,0x20,0x3c,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 15923 0x3e33 "㸳" */
+0x10,0x10,0x50,0x50,0x7c,0x51,0x92,0x10,0x1d,0xf0,0x50,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 15924 0x3e34 "㸴" */
+0x00,0xff,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15925 0x3e35 "㸵" */
+0x10,0x10,0x50,0x53,0x7c,0x50,0x91,0x10,0x1c,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15926 0x3e36 "㸶" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 15927 0x3e37 "㸷" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x09,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x00,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15928 0x3e38 "㸸" */
+0x10,0x10,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 15929 0x3e39 "㸹" */
+0x10,0x10,0x51,0x50,0x7d,0x50,0x90,0x10,0x1d,0xf0,0x50,0x10,0x10,0x10,0x10,0x10,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 15930 0x3e3a "㸺" */
+0x10,0x08,0x40,0x24,0x09,0x72,0x10,0x17,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x20,0x20,0xa8,0xa4,0x2a,0x30,0xc0,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15931 0x3e3b "㸻" */
+0x10,0x10,0x50,0x51,0x7d,0x50,0x90,0x10,0x1d,0xf0,0x53,0x10,0x10,0x10,0x11,0x12,
+0x20,0x40,0x88,0x04,0xfe,0x02,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 15932 0x3e3c "㸼" */
+0x10,0x10,0x50,0x50,0x7d,0x50,0x90,0x13,0x1c,0xf0,0x50,0x10,0x13,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 15933 0x3e3d "㸽" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x08,0x09,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x48,0x44,0x82,0x02,
+/* 15934 0x3e3e "㸾" */
+0x10,0x13,0x50,0x51,0x79,0x52,0x90,0x11,0x1a,0x30,0xd0,0x12,0x12,0x12,0x14,0x10,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 15935 0x3e3f "㸿" */
+0x10,0x10,0x53,0x50,0x7d,0x50,0x93,0x12,0x1c,0xf0,0x50,0x10,0x10,0x11,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0x04,0xf0,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 15936 0x3e40 "㹀" */
+0x10,0x10,0x53,0x50,0x78,0x53,0x92,0x14,0x19,0x30,0xd0,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 15937 0x3e41 "㹁" */
+0x10,0x10,0x53,0x50,0x7c,0x51,0x91,0x11,0x1d,0xf0,0x51,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 15938 0x3e42 "㹂" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15939 0x3e43 "㹃" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x05,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15940 0x3e44 "㹄" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x90,0x11,0x1e,0xf0,0x51,0x12,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 15941 0x3e45 "㹅" */
+0x10,0x10,0x50,0x51,0x7a,0x50,0x91,0x12,0x18,0x31,0xd0,0x10,0x12,0x12,0x14,0x10,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 15942 0x3e46 "㹆" */
+0x10,0x13,0x52,0x50,0x7d,0x50,0x91,0x11,0x1d,0xf1,0x51,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 15943 0x3e47 "㹇" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x90,0x11,0x1e,0xf1,0x51,0x11,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 15944 0x3e48 "㹈" */
+0x08,0x08,0x7e,0x08,0xff,0x1c,0x2a,0x48,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15945 0x3e49 "㹉" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 15946 0x3e4a "㹊" */
+0x10,0x10,0x53,0x52,0x7c,0x51,0x91,0x13,0x1d,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0xa2,0x90,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 15947 0x3e4b "㹋" */
+0x11,0x11,0x51,0x52,0x7a,0x56,0x9a,0x12,0x1a,0x32,0xd2,0x12,0x12,0x12,0x12,0x12,
+0x20,0x3c,0x44,0xa8,0x10,0xa8,0xc6,0x80,0x88,0xb0,0x84,0x88,0x32,0x04,0x18,0x60,
+/* 15948 0x3e4c "㹌" */
+0x10,0x10,0x53,0x50,0x7d,0x50,0x93,0x12,0x1e,0xf2,0x53,0x12,0x12,0x14,0x14,0x19,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 15949 0x3e4d "㹍" */
+0x10,0x10,0x53,0x50,0x7c,0x53,0x92,0x12,0x1e,0xf2,0x52,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 15950 0x3e4e "㹎" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x90,0x10,0x1d,0xf0,0x50,0x13,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 15951 0x3e4f "㹏" */
+0x10,0x10,0x53,0x50,0x7c,0x50,0x91,0x11,0x1d,0xf0,0x53,0x10,0x11,0x10,0x13,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 15952 0x3e50 "㹐" */
+0x11,0x21,0xca,0x14,0x32,0xd2,0x15,0x14,0x09,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x10,0x10,0xa8,0x44,0x40,0x7c,0x40,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 15953 0x3e51 "㹑" */
+0x10,0x17,0x50,0x53,0x78,0x53,0x90,0x13,0x1a,0x33,0xd2,0x13,0x12,0x13,0x11,0x12,
+0x14,0xfe,0x10,0xd0,0x10,0xd0,0x10,0xd0,0x50,0xd0,0x50,0xc8,0x4a,0xca,0x86,0x42,
+/* 15954 0x3e52 "㹒" */
+0x10,0x12,0x51,0x50,0x7b,0x50,0x90,0x13,0x18,0x31,0xd0,0x13,0x10,0x10,0x11,0x16,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 15955 0x3e53 "㹓" */
+0x10,0x10,0x51,0x50,0x7b,0x51,0x93,0x11,0x19,0x36,0xd0,0x13,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 15956 0x3e54 "㹔" */
+0x10,0x13,0x50,0x51,0x7d,0x51,0x91,0x13,0x1c,0xf1,0x51,0x11,0x11,0x11,0x10,0x13,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 15957 0x3e55 "㹕" */
+0x7d,0x00,0x00,0xfe,0x28,0x28,0x28,0x4a,0x4c,0x88,0x11,0x1f,0x21,0xff,0x01,0x01,
+0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,0xf8,0x00,0xfe,0x00,0x00,
+/* 15958 0x3e56 "㹖" */
+0x10,0x11,0x50,0x51,0x78,0x53,0x90,0x11,0x1a,0x30,0xd1,0x10,0x11,0x10,0x13,0x10,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x40,0xa4,0x58,0xb4,0x52,0x90,0x30,
+/* 15959 0x3e57 "㹗" */
+0x10,0x13,0x50,0x51,0x7c,0x53,0x90,0x11,0x1c,0xf3,0x50,0x13,0x10,0x13,0x12,0x13,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 15960 0x3e58 "㹘" */
+0x10,0x11,0x50,0x53,0x7e,0x51,0x90,0x11,0x1c,0xf3,0x50,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 15961 0x3e59 "㹙" */
+0x10,0x12,0x52,0x54,0x79,0x52,0x93,0x12,0x1d,0x31,0xd1,0x11,0x11,0x11,0x11,0x11,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 15962 0x3e5a "㹚" */
+0x10,0x12,0x52,0x54,0x79,0x52,0x93,0x12,0x18,0x30,0xd0,0x10,0x11,0x11,0x11,0x11,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xf8,0x88,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 15963 0x3e5b "㹛" */
+0x20,0x27,0xa0,0xa2,0xfa,0xab,0xaa,0x2a,0x3b,0xec,0x22,0x25,0x22,0x20,0x21,0x26,
+0x00,0xfe,0x40,0xee,0xaa,0xea,0xae,0xe8,0xaa,0xe6,0x88,0xf4,0x90,0x60,0x98,0x06,
+/* 15964 0x3e5c "㹜" */
+0x08,0x0a,0x09,0x09,0x08,0x7e,0x08,0x08,0x08,0x14,0x12,0x12,0x20,0x21,0x42,0x84,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x04,0x02,
+/* 15965 0x3e5d "㹝" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 15966 0x3e5e "㹞" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 15967 0x3e5f "㹟" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x88,0x08,0x1f,0x28,0x48,0x88,0x09,0x09,0x52,0x24,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 15968 0x3e60 "㹠" */
+0x00,0x44,0x28,0x13,0x28,0x49,0x89,0x09,0x19,0x29,0x48,0x88,0x08,0x08,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 15969 0x3e61 "㹡" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x88,0x09,0x1b,0x28,0x48,0x88,0x09,0x0b,0x51,0x20,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x88,0x08,0xf0,0x20,0x40,0x88,0x04,0xfc,0x04,0x00,
+/* 15970 0x3e62 "㹢" */
+0x02,0x8a,0x52,0x22,0x57,0x92,0x12,0x12,0x32,0x52,0x92,0x12,0x14,0x14,0xa9,0x50,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x80,
+/* 15971 0x3e63 "㹣" */
+0x00,0x88,0x50,0x21,0x53,0x94,0x10,0x10,0x33,0x5c,0x90,0x10,0x10,0x11,0xa0,0x40,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xc0,0x20,0x10,0x80,0x60,0x10,
+/* 15972 0x3e64 "㹤" */
+0x00,0x44,0x28,0x11,0x28,0x48,0x88,0x0b,0x18,0x28,0x48,0x88,0x09,0x0b,0x51,0x20,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 15973 0x3e65 "㹥" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x88,0x08,0x19,0x28,0x48,0x88,0x08,0x08,0x53,0x20,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 15974 0x3e66 "㹦" */
+0x00,0x8b,0x50,0x20,0x50,0x91,0x11,0x12,0x34,0x51,0x91,0x11,0x11,0x11,0xa1,0x41,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15975 0x3e67 "㹧" */
+0x00,0x44,0x28,0x11,0x29,0x49,0x89,0x09,0x19,0x2b,0x48,0x88,0x08,0x08,0x51,0x22,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 15976 0x3e68 "㹨" */
+0x00,0x44,0x28,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 15977 0x3e69 "㹩" */
+0x00,0x45,0x28,0x10,0x28,0x48,0x88,0x08,0x1b,0x28,0x49,0x88,0x08,0x08,0x53,0x20,
+0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x26,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 15978 0x3e6a "㹪" */
+0x00,0x97,0x54,0x24,0x54,0x94,0x14,0x1f,0x34,0x54,0x94,0x14,0x14,0x15,0xa8,0x50,
+0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0xfe,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x54,0x88,
+/* 15979 0x3e6b "㹫" */
+0x00,0x44,0x2b,0x10,0x29,0x48,0x89,0x09,0x19,0x28,0x48,0x88,0x08,0x08,0x51,0x22,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 15980 0x3e6c "㹬" */
+0x00,0x88,0x5f,0x20,0x50,0x97,0x14,0x14,0x37,0x50,0x92,0x11,0x10,0x11,0xa2,0x4c,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x40,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 15981 0x3e6d "㹭" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x28,0x48,0x88,0x08,0x08,0x53,0x20,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 15982 0x3e6e "㹮" */
+0x00,0x45,0x28,0x10,0x28,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 15983 0x3e6f "㹯" */
+0x00,0x44,0x28,0x11,0x29,0x4b,0x8d,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 15984 0x3e70 "㹰" */
+0x00,0x44,0x2a,0x11,0x29,0x48,0x8f,0x08,0x18,0x28,0x48,0x88,0x09,0x09,0x52,0x24,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 15985 0x3e71 "㹱" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x88,0x08,0x19,0x29,0x49,0x89,0x0a,0x0a,0x54,0x28,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 15986 0x3e72 "㹲" */
+0x00,0x44,0x29,0x10,0x28,0x4b,0x88,0x08,0x19,0x28,0x49,0x8a,0x0c,0x08,0x50,0x20,
+0x20,0x22,0xfa,0x24,0x24,0xfe,0x10,0x20,0xfc,0x88,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 15987 0x3e73 "㹳" */
+0x00,0x47,0x28,0x10,0x29,0x48,0x88,0x0b,0x18,0x28,0x49,0x89,0x09,0x09,0x51,0x21,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 15988 0x3e74 "㹴" */
+0x00,0x45,0x28,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x08,0x08,0x50,0x23,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 15989 0x3e75 "㹵" */
+0x00,0x45,0x28,0x10,0x29,0x4a,0x89,0x08,0x18,0x29,0x48,0x88,0x08,0x08,0x53,0x20,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 15990 0x3e76 "㹶" */
+0x00,0x88,0x53,0x20,0x50,0x91,0x11,0x13,0x30,0x52,0x92,0x11,0x11,0x12,0xa4,0x48,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 15991 0x3e77 "㹷" */
+0x42,0x24,0x18,0x24,0x52,0x10,0xff,0x20,0x28,0x7e,0xaa,0x2a,0x2a,0x2e,0x08,0x09,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 15992 0x3e78 "㹸" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x28,0x48,0x88,0x08,0x08,0x51,0x22,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 15993 0x3e79 "㹹" */
+0x00,0x88,0x53,0x22,0x52,0x92,0x12,0x13,0x32,0x52,0x92,0x12,0x12,0x14,0xa4,0x49,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x20,0x50,0x50,0x88,0x06,
+/* 15994 0x3e7a "㹺" */
+0x00,0x44,0x2b,0x10,0x28,0x49,0x8a,0x08,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 15995 0x3e7b "㹻" */
+0x00,0x45,0x28,0x10,0x2b,0x48,0x89,0x0a,0x18,0x2b,0x48,0x89,0x08,0x08,0x50,0x21,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 15996 0x3e7c "㹼" */
+0x00,0x44,0x28,0x11,0x2a,0x4a,0x89,0x08,0x1b,0x28,0x48,0x89,0x0a,0x08,0x50,0x20,
+0x80,0x80,0xfe,0x02,0x42,0x4a,0x52,0x42,0xfe,0x42,0xe2,0x52,0x4a,0x42,0x54,0x08,
+/* 15997 0x3e7d "㹽" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x88,0x0f,0x18,0x28,0x48,0x8b,0x08,0x08,0x50,0x27,
+0x50,0x48,0x5e,0xe4,0x28,0x32,0xca,0x06,0x50,0x48,0x5e,0xe4,0x28,0x32,0xca,0x06,
+/* 15998 0x3e7e "㹾" */
+0x01,0x89,0x53,0x22,0x54,0x9a,0x11,0x12,0x3c,0x50,0x93,0x12,0x12,0x12,0xa3,0x42,
+0x10,0x10,0xd8,0x54,0x52,0x90,0x10,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 15999 0x3e7f "㹿" */
+0x00,0x44,0x28,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x48,0x8b,0x08,0x08,0x50,0x20,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16000 0x3e80 "㺀" */
+0x00,0x44,0x28,0x11,0x2a,0x48,0x89,0x0a,0x18,0x29,0x48,0x88,0x0a,0x0a,0x54,0x20,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 16001 0x3e81 "㺁" */
+0x00,0x45,0x2a,0x11,0x28,0x48,0x88,0x0b,0x1a,0x2a,0x4a,0x8a,0x0a,0x0a,0x53,0x22,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 16002 0x3e82 "㺂" */
+0x00,0x88,0x50,0x27,0x54,0x94,0x15,0x14,0x34,0x55,0x95,0x15,0x15,0x14,0xa8,0x50,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 16003 0x3e83 "㺃" */
+0x00,0x44,0x2b,0x10,0x29,0x49,0x89,0x0a,0x19,0x29,0x49,0x89,0x09,0x08,0x50,0x20,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x28,0x10,
+/* 16004 0x3e84 "㺄" */
+0x00,0x44,0x29,0x12,0x2d,0x48,0x8b,0x0a,0x1a,0x2b,0x4a,0x8a,0x0b,0x0a,0x52,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 16005 0x3e85 "㺅" */
+0x00,0x88,0x51,0x22,0x54,0x9b,0x12,0x12,0x32,0x53,0x92,0x13,0x14,0x14,0xa8,0x53,
+0x80,0x80,0xfc,0x04,0x08,0xfe,0x00,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 16006 0x3e86 "㺆" */
+0x02,0x45,0x28,0x13,0x29,0x49,0x89,0x08,0x19,0x29,0x49,0x89,0x09,0x08,0x50,0x23,
+0x10,0x10,0x7e,0x10,0x28,0xa8,0x44,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 16007 0x3e87 "㺇" */
+0x00,0x90,0x5f,0x29,0x69,0xa9,0x2b,0x2a,0x6a,0xab,0x29,0x29,0x29,0x2f,0xa0,0x40,
+0x10,0x14,0xd2,0x12,0x10,0x7e,0x90,0x90,0x90,0x98,0x28,0x28,0x24,0xc4,0x44,0x82,
+/* 16008 0x3e88 "㺈" */
+0x00,0x45,0x29,0x11,0x28,0x4b,0x88,0x08,0x19,0x29,0x49,0x89,0x08,0x08,0x53,0x21,
+0x20,0x24,0x24,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 16009 0x3e89 "㺉" */
+0x10,0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x14,0xfe,0x10,0x28,0x44,0x81,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 16010 0x3e8a "㺊" */
+0x01,0x44,0x28,0x13,0x28,0x48,0x89,0x08,0x18,0x2b,0x48,0x88,0x0a,0x0a,0x54,0x20,
+0x04,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 16011 0x3e8b "㺋" */
+0x01,0x89,0x52,0x24,0x59,0x93,0x10,0x10,0x37,0x50,0x94,0x12,0x14,0x10,0xa2,0x41,
+0x20,0x10,0x08,0x86,0x10,0xf8,0x08,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 16012 0x3e8c "㺌" */
+0x01,0x88,0x50,0x27,0x50,0x93,0x10,0x17,0x30,0x53,0x90,0x11,0x12,0x14,0xa0,0x40,
+0x10,0xa0,0x00,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 16013 0x3e8d "㺍" */
+0x00,0x88,0x53,0x22,0x54,0x91,0x11,0x11,0x31,0x51,0x91,0x17,0x10,0x10,0xa1,0x42,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 16014 0x3e8e "㺎" */
+0x00,0x97,0x54,0x25,0x54,0x97,0x14,0x15,0x34,0x55,0x95,0x15,0x15,0x19,0xa9,0x51,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 16015 0x3e8f "㺏" */
+0x00,0x45,0x29,0x13,0x29,0x49,0x88,0x09,0x19,0x29,0x48,0x8b,0x08,0x09,0x50,0x23,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 16016 0x3e90 "㺐" */
+0x01,0x46,0x29,0x10,0x29,0x49,0x89,0x09,0x19,0x28,0x4b,0x88,0x08,0x09,0x56,0x20,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16017 0x3e91 "㺑" */
+0x00,0x44,0x29,0x11,0x2a,0x4b,0x88,0x09,0x1e,0x28,0x4b,0x88,0x0b,0x08,0x50,0x27,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 16018 0x3e92 "㺒" */
+0x00,0x97,0x50,0x24,0x52,0x94,0x10,0x11,0x36,0x50,0x93,0x10,0x13,0x10,0xa0,0x47,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 16019 0x3e93 "㺓" */
+0x00,0x47,0x28,0x11,0x28,0x4b,0x88,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x50,0x21,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 16020 0x3e94 "㺔" */
+0x00,0x8b,0x50,0x22,0x51,0x93,0x12,0x13,0x32,0x53,0x92,0x12,0x12,0x15,0xa4,0x48,
+0x0e,0xf0,0x44,0x24,0x08,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 16021 0x3e95 "㺕" */
+0x00,0x97,0x52,0x21,0x57,0x91,0x12,0x14,0x33,0x52,0x92,0x13,0x12,0x12,0xa3,0x42,
+0x78,0xc0,0x48,0x50,0xfc,0x50,0x48,0x06,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x08,
+/* 16022 0x3e96 "㺖" */
+0x00,0x97,0x50,0x21,0x6f,0xa4,0x24,0x27,0x64,0xa7,0x24,0x24,0x27,0x2c,0xa0,0x40,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 16023 0x3e97 "㺗" */
+0x00,0x47,0x2a,0x12,0x2b,0x48,0x89,0x09,0x19,0x29,0x49,0x88,0x0b,0x08,0x50,0x20,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 16024 0x3e98 "㺘" */
+0x00,0x44,0x29,0x11,0x2b,0x4d,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 16025 0x3e99 "㺙" */
+0x00,0x88,0x57,0x24,0x51,0x91,0x17,0x12,0x33,0x50,0x93,0x12,0x12,0x12,0xa1,0x46,
+0x80,0x40,0xfe,0x02,0xf8,0x48,0xfe,0x28,0xfc,0x10,0xf8,0x48,0x48,0xa8,0x10,0x08,
+/* 16026 0x3e9a "㺚" */
+0x00,0x94,0x52,0x20,0x50,0x90,0x16,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0xa5,0x48,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 16027 0x3e9b "㺛" */
+0x03,0x8a,0x53,0x22,0x53,0x92,0x13,0x10,0x35,0x50,0x91,0x1f,0x11,0x11,0xa2,0x44,
+0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0x08,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 16028 0x3e9c "㺜" */
+0x00,0x8b,0x52,0x23,0x52,0x93,0x10,0x13,0x32,0x52,0x92,0x13,0x15,0x15,0xa5,0x49,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 16029 0x3e9d "㺝" */
+0x00,0x97,0x55,0x27,0x54,0x97,0x15,0x17,0x30,0x53,0x92,0x12,0x12,0x12,0xaf,0x40,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 16030 0x3e9e "㺞" */
+0x01,0x8a,0x52,0x22,0x53,0x92,0x12,0x13,0x32,0x52,0x97,0x10,0x11,0x11,0xa2,0x44,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 16031 0x3e9f "㺟" */
+0x00,0x97,0x50,0x24,0x52,0x94,0x11,0x12,0x37,0x5a,0x93,0x12,0x13,0x12,0xa3,0x42,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 16032 0x3ea0 "㺠" */
+0x00,0x90,0x5f,0x29,0x62,0xa5,0x2e,0x2a,0x6a,0xab,0x2a,0x2a,0x2a,0x2d,0xb7,0x40,
+0x80,0x40,0xfe,0x12,0x08,0x84,0x0e,0x74,0x54,0x54,0xd4,0x54,0x52,0x54,0x5c,0x84,
+/* 16033 0x3ea1 "㺡" */
+0x00,0x97,0x54,0x25,0x64,0xa7,0x24,0x25,0x66,0xa4,0x24,0x25,0x25,0x29,0xa9,0x57,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 16034 0x3ea2 "㺢" */
+0x07,0x90,0x57,0x24,0x5b,0x90,0x17,0x11,0x33,0x56,0x9b,0x12,0x13,0x12,0xa3,0x42,
+0xfc,0x40,0xfe,0x42,0x5c,0x40,0x5c,0x20,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 16035 0x3ea3 "㺣" */
+0x01,0x91,0x51,0x27,0x65,0xa5,0x27,0x24,0x64,0xa7,0x24,0x27,0x2a,0x2b,0xb1,0x47,
+0x08,0xec,0x0a,0xe8,0x28,0xde,0x28,0xea,0x0a,0xea,0x0c,0xec,0x2a,0xea,0x56,0xe2,
+/* 16036 0x3ea4 "㺤" */
+0x01,0x89,0x52,0x20,0x57,0x91,0x13,0x11,0x33,0x51,0x93,0x11,0x11,0x13,0xa0,0x40,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 16037 0x3ea5 "㺥" */
+0x01,0x8a,0x57,0x22,0x53,0x92,0x13,0x12,0x31,0x52,0x97,0x12,0x13,0x10,0xa1,0x46,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 16038 0x3ea6 "㺦" */
+0x00,0x9f,0x5a,0x2a,0x6e,0xaa,0x2a,0x2e,0x6a,0xaa,0x2b,0x2e,0x3a,0x22,0xa2,0x42,
+0x44,0x44,0xaa,0xee,0x44,0xaa,0xee,0x00,0x28,0xaa,0xaa,0xee,0x28,0x28,0x48,0x88,
+/* 16039 0x3ea7 "㺧" */
+0x07,0x94,0x57,0x20,0x57,0x90,0x13,0x12,0x33,0x52,0x93,0x11,0x12,0x17,0xa4,0x47,
+0xbc,0xa4,0xbc,0x00,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0xbc,0xa4,0xbc,
+/* 16040 0x3ea8 "㺨" */
+0x00,0x00,0xfc,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1d,0xe3,0x41,0x00,0x00,
+0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x40,0x80,0x88,0x84,0x04,0xfe,0x02,0x02,0x00,
+/* 16041 0x3ea9 "㺩" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0x94,0xe4,0x84,0x04,0x04,0x04,0x04,
+/* 16042 0x3eaa "㺪" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 16043 0x3eab "㺫" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x08,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x28,0x10,
+/* 16044 0x3eac "㺬" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 16045 0x3ead "㺭" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x13,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 16046 0x3eae "㺮" */
+0x00,0x01,0xfc,0x10,0x10,0x13,0x10,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 16047 0x3eaf "㺯" */
+0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 16048 0x3eb0 "㺰" */
+0x00,0x03,0xfc,0x10,0x10,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 16049 0x3eb1 "㺱" */
+0x10,0x17,0x21,0x61,0xa1,0x22,0x24,0x28,0x20,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xf8,0x10,0x3c,0x04,0x04,0x14,0x08,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16050 0x3eb2 "㺲" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x11,0x10,0x10,0x10,0x1c,0xe0,0x40,0x03,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 16051 0x3eb3 "㺳" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x11,0x10,0x10,0x10,0x1e,0xf0,0x40,0x01,0x06,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 16052 0x3eb4 "㺴" */
+0x00,0x00,0xfe,0x10,0x10,0x11,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x01,0x02,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 16053 0x3eb5 "㺵" */
+0x00,0x00,0xfc,0x10,0x11,0x11,0x12,0x7c,0x10,0x10,0x10,0x11,0x1d,0xe2,0x44,0x08,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 16054 0x3eb6 "㺶" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x11,0x1e,0xf0,0x40,0x00,0x00,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 16055 0x3eb7 "㺷" */
+0x00,0x00,0xfc,0x10,0x11,0x10,0x7c,0x10,0x10,0x10,0x11,0x1d,0xe2,0x40,0x00,0x00,
+0x20,0x28,0x24,0x20,0xfc,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 16056 0x3eb8 "㺸" */
+0x08,0x09,0x11,0x31,0x51,0x91,0x11,0x12,0x04,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xf0,0x10,0x90,0x50,0x52,0x12,0x0e,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16057 0x3eb9 "㺹" */
+0x00,0x00,0xfc,0x10,0x11,0x13,0x7c,0x10,0x10,0x13,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 16058 0x3eba "㺺" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16059 0x3ebb "㺻" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 16060 0x3ebc "㺼" */
+0x00,0x03,0xfc,0x10,0x10,0x10,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0xfe,0x22,0x24,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 16061 0x3ebd "㺽" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x10,0x11,0x12,0x10,0x1c,0xe0,0x40,0x03,0x00,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 16062 0x3ebe "㺾" */
+0x00,0x03,0xfa,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 16063 0x3ebf "㺿" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,
+0x00,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 16064 0x3ec0 "㻀" */
+0x00,0x00,0xfb,0x22,0x22,0x23,0x22,0xfa,0x23,0x20,0x21,0x38,0xe0,0x40,0x01,0x06,
+0x20,0x20,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x20,0x20,0xa0,0x40,0xa0,0x18,0x06,
+/* 16065 0x3ec1 "㻁" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,0x00,
+/* 16066 0x3ec2 "㻂" */
+0x01,0x00,0xfc,0x10,0x13,0x10,0x7c,0x10,0x10,0x17,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 16067 0x3ec3 "㻃" */
+0x04,0x04,0x3f,0x24,0x3f,0x24,0x3f,0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfc,0x00,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16068 0x3ec4 "㻄" */
+0x00,0x00,0xfd,0x10,0x10,0x13,0x7c,0x10,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x08,0x3c,0xc0,0x00,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 16069 0x3ec5 "㻅" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x10,0x7c,0x10,0x13,0x10,0x10,0x1c,0xe1,0x43,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 16070 0x3ec6 "㻆" */
+0x00,0x00,0xf9,0x22,0x27,0x20,0x20,0xfb,0x22,0x23,0x22,0x23,0x3a,0xe2,0x02,0x02,
+0x40,0x80,0x08,0x04,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 16071 0x3ec7 "㻇" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x7d,0x10,0x10,0x10,0x11,0x1c,0xe0,0x40,0x03,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 16072 0x3ec8 "㻈" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 16073 0x3ec9 "㻉" */
+0x00,0x00,0xf9,0x21,0x21,0x21,0x27,0xf8,0x20,0x21,0x21,0x3a,0xe4,0x40,0x00,0x07,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x24,0x24,0x28,0x10,0x20,0xc0,0x00,
+/* 16074 0x3eca "㻊" */
+0x00,0x00,0xfc,0x11,0x12,0x11,0x11,0x7d,0x11,0x11,0x10,0x10,0x1c,0xe0,0x41,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 16075 0x3ecb "㻋" */
+0x00,0x00,0xfd,0x10,0x10,0x11,0x7d,0x11,0x11,0x10,0x10,0x1c,0xe1,0x42,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 16076 0x3ecc "㻌" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x7c,0x10,0x13,0x10,0x11,0x1d,0xe2,0x44,0x00,0x00,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 16077 0x3ecd "㻍" */
+0x00,0x01,0xfd,0x11,0x11,0x10,0x7c,0x11,0x10,0x10,0x13,0x1c,0xe0,0x40,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 16078 0x3ece "㻎" */
+0x01,0x01,0x7f,0x01,0xfd,0x11,0x11,0x7d,0x11,0x1d,0xe2,0x42,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x00,0x7c,0x10,0x10,0x7c,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 16079 0x3ecf "㻏" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x11,0x10,0x10,0x10,0x1d,0xe0,0x40,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 16080 0x3ed0 "㻐" */
+0x00,0x00,0xfc,0x11,0x13,0x10,0x10,0x7d,0x12,0x10,0x11,0x12,0x1c,0xe0,0x41,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 16081 0x3ed1 "㻑" */
+0x00,0x00,0xfc,0x11,0x10,0x10,0x7d,0x12,0x10,0x10,0x10,0x1d,0xe0,0x40,0x00,0x00,
+0x1c,0xe0,0x20,0xfe,0x70,0xa8,0x24,0x22,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 16082 0x3ed2 "㻒" */
+0x00,0x03,0xfa,0x22,0x22,0x22,0x22,0xfb,0x22,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x00,0xfe,0x02,0x1a,0xe2,0x22,0x22,0xfe,0x22,0x72,0xaa,0x26,0x22,0x22,0xfe,0x02,
+/* 16083 0x3ed3 "㻓" */
+0x00,0x07,0xfa,0x22,0x22,0x23,0x22,0xfa,0x23,0x22,0x22,0x3a,0xe7,0x40,0x00,0x00,
+0x00,0xe0,0x5e,0x52,0x52,0xd2,0x52,0x54,0xd4,0x54,0x48,0xe8,0x54,0x54,0x62,0x40,
+/* 16084 0x3ed4 "㻔" */
+0x00,0x00,0xfd,0x10,0x13,0x10,0x10,0x7c,0x13,0x10,0x10,0x13,0x1c,0xe0,0x41,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 16085 0x3ed5 "㻕" */
+0x00,0x03,0xfa,0x22,0x23,0x22,0x22,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 16086 0x3ed6 "㻖" */
+0x00,0x00,0xfb,0x20,0x20,0x27,0x20,0xf8,0x23,0x24,0x22,0x39,0xe2,0x44,0x01,0x00,
+0x40,0x40,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x44,0xe8,0x50,0x48,0x46,0x40,0x80,
+/* 16087 0x3ed7 "㻗" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16088 0x3ed8 "㻘" */
+0x00,0x00,0xfb,0x22,0x20,0x21,0x21,0xf9,0x21,0x21,0x21,0x39,0xe1,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x22,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 16089 0x3ed9 "㻙" */
+0x00,0x00,0xfb,0x20,0x21,0x23,0xf8,0x21,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 16090 0x3eda "㻚" */
+0x00,0x03,0xfa,0x22,0x22,0x23,0x22,0xfa,0x22,0x23,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 16091 0x3edb "㻛" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x10,0x11,0x12,0x1c,0xe1,0x42,0x00,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x54,0x94,0x24,0x44,0x94,0x08,
+/* 16092 0x3edc "㻜" */
+0x00,0x00,0xf8,0x20,0x21,0x22,0x24,0xf8,0x20,0x21,0x21,0x39,0xe2,0x42,0x04,0x08,
+0x88,0x88,0x88,0x88,0x54,0x22,0x42,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 16093 0x3edd "㻝" */
+0x00,0x00,0xfb,0x20,0x20,0x23,0x22,0xfa,0x23,0x20,0x21,0x3a,0xe4,0x40,0x00,0x00,
+0x82,0x82,0xe2,0x82,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xaa,0xa2,0x82,0x8a,0x84,
+/* 16094 0x3ede "㻞" */
+0x00,0x00,0xfb,0x22,0x22,0x23,0x22,0xfa,0x23,0x23,0x25,0x3d,0xe5,0x45,0x09,0x01,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0x52,0x52,0xfe,0x52,0x52,0x52,0x06,
+/* 16095 0x3edf "㻟" */
+0x00,0x00,0xfb,0x20,0x21,0x22,0x25,0xf8,0x21,0x21,0x21,0x21,0x39,0xe1,0x01,0x01,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 16096 0x3ee0 "㻠" */
+0x00,0x00,0xfb,0x22,0x20,0x21,0xfa,0x20,0x20,0x23,0x20,0x38,0xe0,0x40,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 16097 0x3ee1 "㻡" */
+0x00,0x01,0xfd,0x13,0x11,0x11,0x7d,0x11,0x11,0x10,0x13,0x1c,0xe0,0x41,0x06,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16098 0x3ee2 "㻢" */
+0x02,0x01,0xf9,0x27,0x22,0x22,0x23,0xfa,0x22,0x22,0x22,0x3a,0xe4,0x44,0x09,0x10,
+0x10,0x10,0x10,0xbe,0x28,0x48,0xaa,0xae,0xba,0xea,0xae,0xa8,0xaa,0xa2,0xa2,0x1e,
+/* 16099 0x3ee3 "㻣" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x20,0xf8,0x20,0x23,0x21,0x39,0xe1,0x41,0x01,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 16100 0x3ee4 "㻤" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0x21,0xfa,0x21,0x21,0x21,0x39,0xe1,0x40,0x00,0x00,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x28,0x10,
+/* 16101 0x3ee5 "㻥" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16102 0x3ee6 "㻦" */
+0x01,0x01,0xfd,0x11,0x11,0x11,0x7d,0x10,0x10,0x13,0x12,0x1e,0xe2,0x42,0x02,0x02,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 16103 0x3ee7 "㻧" */
+0x01,0x01,0xf9,0x22,0x25,0x20,0x21,0xfa,0x24,0x23,0x20,0x38,0xe1,0x46,0x00,0x00,
+0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x24,0x24,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 16104 0x3ee8 "㻨" */
+0x00,0x7e,0x48,0x7e,0x43,0x7e,0x48,0x7e,0x00,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x44,0x54,0x28,0x90,0x28,0xc6,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16105 0x3ee9 "㻩" */
+0x01,0x00,0xf8,0x27,0x20,0x23,0xf8,0x27,0x20,0x23,0x20,0x39,0xe2,0x4c,0x00,0x00,
+0x10,0xa0,0x00,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 16106 0x3eea "㻪" */
+0x00,0x00,0xfd,0x13,0x15,0x11,0x7d,0x11,0x11,0x11,0x13,0x1c,0xe0,0x41,0x02,0x04,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 16107 0x3eeb "㻫" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7c,0x10,0x13,0x10,0x10,0x1d,0xe0,0x43,0x00,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 16108 0x3eec "㻬" */
+0x01,0x00,0xfb,0x22,0x21,0x20,0xf9,0x20,0x21,0x20,0x23,0x38,0xe0,0x40,0x00,0x00,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,
+/* 16109 0x3eed "㻭" */
+0x00,0x00,0xfb,0x20,0x20,0x22,0xf9,0x22,0x20,0x20,0x20,0x3b,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x20,0x48,0xf2,0x24,0x52,0xf8,0x08,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16110 0x3eee "㻮" */
+0x01,0x01,0xfb,0x22,0x25,0x22,0xf9,0x22,0x24,0x20,0x23,0x38,0xe1,0x42,0x05,0x00,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 16111 0x3eef "㻯" */
+0x00,0x00,0xf8,0x23,0x22,0x22,0xfb,0x22,0x22,0x22,0x23,0x3a,0xe5,0x44,0x08,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 16112 0x3ef0 "㻰" */
+0x00,0x03,0xfc,0x11,0x10,0x13,0x7c,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x03,0x00,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16113 0x3ef1 "㻱" */
+0x00,0x04,0xfa,0x21,0x20,0x20,0x26,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 16114 0x3ef2 "㻲" */
+0x00,0x01,0xfd,0x13,0x11,0x11,0x7c,0x11,0x11,0x11,0x10,0x1d,0xe0,0x41,0x00,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 16115 0x3ef3 "㻳" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0xfb,0x20,0x20,0x27,0x21,0x39,0xe2,0x44,0x00,0x00,
+0x88,0x88,0xfe,0x88,0x42,0xe2,0x82,0x8a,0x8a,0xea,0x8a,0xca,0xaa,0x82,0x8a,0x84,
+/* 16116 0x3ef4 "㻴" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7c,0x13,0x12,0x13,0x10,0x1d,0xe0,0x40,0x01,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 16117 0x3ef5 "㻵" */
+0x03,0x02,0xfb,0x22,0x22,0x22,0x23,0xfa,0x22,0x23,0x22,0x3a,0xe4,0x47,0x08,0x01,
+0xfe,0x02,0xfe,0x00,0xfc,0x08,0xfe,0x10,0x30,0xce,0x42,0x84,0xee,0x84,0x84,0x8c,
+/* 16118 0x3ef6 "㻶" */
+0x01,0x01,0xfa,0x20,0x20,0x21,0x20,0xfb,0x20,0x21,0x20,0x39,0xe0,0x43,0x00,0x00,
+0x08,0xee,0x94,0x42,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x20,0xfe,0x20,0x20,
+/* 16119 0x3ef7 "㻷" */
+0x02,0x02,0xef,0x42,0x42,0x4f,0x4a,0xea,0x4a,0x4b,0x42,0x67,0xca,0x12,0x02,0x02,
+0x08,0x08,0xbe,0x08,0x08,0xbe,0xaa,0xaa,0xaa,0xae,0x08,0x1c,0xaa,0x48,0x08,0x08,
+/* 16120 0x3ef8 "㻸" */
+0x00,0x07,0xf9,0x25,0x27,0x23,0x25,0xf9,0x20,0x23,0x22,0x3a,0xe3,0x42,0x02,0x03,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 16121 0x3ef9 "㻹" */
+0xfd,0x10,0x21,0x7c,0xa5,0x24,0x3d,0x24,0x00,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0xfc,0x40,0xa2,0x54,0xb8,0x54,0x92,0x60,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16122 0x3efa "㻺" */
+0x3f,0x21,0x2e,0x22,0x2f,0x27,0x2a,0x32,0x20,0x2f,0x20,0x27,0x20,0x40,0x5f,0x80,
+0xfe,0x04,0x38,0x10,0xbc,0x18,0xb4,0x52,0x00,0xfc,0x80,0xf8,0xa0,0x90,0xfe,0x00,
+/* 16123 0x3efb "㻻" */
+0x01,0x00,0xfb,0x20,0x23,0x22,0x23,0xf8,0x23,0x20,0x20,0x38,0xe3,0x40,0x02,0x01,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 16124 0x3efc "㻼" */
+0x00,0x03,0xfc,0x13,0x12,0x13,0x7c,0x11,0x11,0x11,0x11,0x1d,0xe0,0x43,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 16125 0x3efd "㻽" */
+0x00,0x00,0xfd,0x13,0x11,0x11,0x7d,0x11,0x11,0x11,0x13,0x1e,0xe2,0x42,0x02,0x02,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xde,0x52,0x52,0x72,0x02,0x06,
+/* 16126 0x3efe "㻾" */
+0x01,0xff,0x10,0x24,0x79,0x10,0x22,0x7c,0x08,0x30,0xc0,0x7f,0x01,0x3f,0x01,0xff,
+0x00,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xfc,0x00,0xf8,0x20,0xfe,
+/* 16127 0x3eff "㻿" */
+0x00,0x03,0xfa,0x22,0x23,0x21,0xfb,0x24,0x23,0x22,0x22,0x3b,0xe0,0x47,0x00,0x00,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xfc,0x84,0xe4,0xa4,0xa4,0xe4,0x94,0xf4,0x14,0x08,
+/* 16128 0x3f00 "㼀" */
+0x00,0x04,0xfa,0x20,0x20,0x20,0x26,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 16129 0x3f01 "㼁" */
+0x01,0x00,0xfb,0x20,0x21,0x20,0xfb,0x20,0x21,0x20,0x23,0x38,0xe0,0x43,0x00,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 16130 0x3f02 "㼂" */
+0x0a,0x33,0x22,0x3b,0x20,0x3a,0x22,0xff,0x80,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xb8,0x08,0xb8,0x88,0xb8,0x88,0xfe,0x02,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 16131 0x3f03 "㼃" */
+0x01,0x02,0xf9,0x20,0x23,0x22,0x22,0xfa,0x23,0x22,0x23,0x3a,0xe3,0x42,0x02,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 16132 0x3f04 "㼄" */
+0x01,0x01,0xfa,0x23,0x21,0x22,0xfb,0x20,0x27,0x20,0x27,0x3d,0xe7,0x45,0x07,0x00,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0xd4,0x54,0xca,0x4a,0xd6,0x22,
+/* 16133 0x3f05 "㼅" */
+0x00,0x00,0xfb,0x22,0x22,0x22,0x23,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x04,
+0x20,0x10,0xfe,0x44,0xfe,0x44,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x00,0x44,0x82,
+/* 16134 0x3f06 "㼆" */
+0x00,0x02,0xfa,0x24,0x21,0x22,0x27,0xfc,0x21,0x20,0x20,0x39,0xe0,0x40,0x03,0x00,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xf8,0x40,0x40,0xf8,0x50,0x48,0xfe,0x00,
+/* 16135 0x3f07 "㼇" */
+0x00,0x02,0xfb,0x20,0x21,0x23,0x25,0xf9,0x21,0x21,0x21,0x21,0x3b,0xe2,0x02,0x02,
+0x20,0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xde,0x52,0x72,0x06,
+/* 16136 0x3f08 "㼈" */
+0x00,0x07,0xf4,0x24,0x27,0x22,0x22,0xf4,0x2f,0x22,0x24,0x2f,0x30,0xca,0x0a,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 16137 0x3f09 "㼉" */
+0x02,0x07,0x38,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x4a,0x4d,0x89,
+0x10,0x10,0x10,0x7c,0x54,0x54,0x10,0x28,0x28,0x48,0x4a,0x86,0x40,0x30,0x0e,0x00,
+/* 16138 0x3f0a "㼊" */
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0x54,0x7c,0x10,0x10,0x14,0x19,0x11,0x02,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16139 0x3f0b "㼋" */
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16140 0x3f0c "㼌" */
+0x08,0x1c,0x70,0x50,0x50,0x50,0x58,0x54,0x54,0x54,0x50,0x50,0x58,0x55,0x9d,0x06,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16141 0x3f0d "㼍" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x30,0x38,0x54,0x54,0x90,0x11,0x11,0x12,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16142 0x3f0e "㼎" */
+0x02,0x07,0x38,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x4a,0x4d,0x89,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x82,0x28,0x10,0x28,0x44,0x84,0x40,0x30,0x0e,0x00,
+/* 16143 0x3f0f "㼏" */
+0x04,0x1e,0xe0,0x22,0x92,0x54,0x48,0x10,0xfc,0x24,0x44,0x28,0x10,0x29,0x45,0x82,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16144 0x3f10 "㼐" */
+0x08,0x04,0x7f,0x41,0x41,0x7f,0x40,0x7f,0x55,0x55,0x7f,0x55,0x55,0x55,0x81,0x03,
+0x04,0x0e,0x74,0x54,0x54,0x54,0x54,0x54,0x54,0x52,0x52,0x52,0x50,0x94,0x9a,0x12,
+/* 16145 0x3f11 "㼑" */
+0x10,0x10,0xfe,0x10,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0x38,0x54,0x93,0x11,0x12,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16146 0x3f12 "㼒" */
+0x02,0x07,0x38,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x4a,0x4d,0x89,
+0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x52,0xaa,0x44,0x30,0x0e,0x00,
+/* 16147 0x3f13 "㼓" */
+0x08,0x1c,0x70,0x53,0x50,0x51,0x58,0x57,0x54,0x55,0x50,0x50,0x59,0x56,0x9c,0x04,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 16148 0x3f14 "㼔" */
+0x00,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x7c,0x54,0x54,0x54,0x56,0xf9,0x01,0x02,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16149 0x3f15 "㼕" */
+0x10,0x92,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x00,0x7c,0x54,0x7c,0x54,0x55,0x7d,0x46,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 16150 0x3f16 "㼖" */
+0x11,0x3a,0xe3,0xa0,0xa7,0xa1,0xb6,0xa9,0xae,0xa9,0xa2,0xaf,0xba,0xaf,0x3a,0x0f,
+0xf0,0x10,0xe0,0x20,0xfc,0x88,0x50,0xa8,0x64,0xa0,0x48,0xbe,0xaa,0xbe,0x8a,0xbe,
+/* 16151 0x3f17 "㼗" */
+0x00,0x01,0xfe,0x10,0x10,0x10,0x10,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 16152 0x3f18 "㼘" */
+0x10,0x11,0x10,0x10,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 16153 0x3f19 "㼙" */
+0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16154 0x3f1a "㼚" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x80,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16155 0x3f1b "㼛" */
+0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16156 0x3f1c "㼜" */
+0x01,0x1f,0x11,0x11,0xff,0x02,0x1c,0xe0,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0xf0,0x10,0x10,0xfe,0x80,0x70,0x0e,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16157 0x3f1d "㼝" */
+0x10,0x1e,0x22,0x62,0x94,0x08,0x30,0xc0,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0xf8,0x88,0xa8,0x92,0x82,0x7e,0x00,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16158 0x3f1e "㼞" */
+0x00,0x7e,0x08,0x08,0x4a,0x2a,0x2c,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16159 0x3f1f "㼟" */
+0x10,0x10,0x20,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16160 0x3f20 "㼠" */
+0x10,0x08,0x08,0x7f,0x41,0x82,0x20,0x20,0x3e,0x20,0x20,0x20,0x26,0x38,0x20,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16161 0x3f21 "㼡" */
+0x08,0x28,0x28,0x3e,0x48,0x88,0x08,0x7f,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16162 0x3f22 "㼢" */
+0x00,0xfe,0x90,0x90,0x90,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0x90,0x90,0x90,0xfe,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16163 0x3f23 "㼣" */
+0x00,0xfe,0x10,0x10,0x20,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16164 0x3f24 "㼤" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16165 0x3f25 "㼥" */
+0x10,0x12,0x7a,0x14,0x14,0xff,0x10,0x20,0x7e,0x90,0x20,0x3c,0x04,0x04,0x14,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16166 0x3f26 "㼦" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16167 0x3f27 "㼧" */
+0x00,0xfc,0x04,0x68,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16168 0x3f28 "㼨" */
+0x08,0x08,0x14,0x22,0x51,0x88,0x7e,0x02,0x04,0x08,0x7e,0x42,0x42,0x7e,0x42,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16169 0x3f29 "㼩" */
+0x04,0x05,0x04,0x7f,0x44,0x44,0x74,0x55,0x55,0x56,0x56,0x54,0x65,0x4d,0x93,0x01,
+0x00,0x7c,0xa0,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16170 0x3f2a "㼪" */
+0x08,0x08,0x7f,0x08,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x14,0x14,0x22,0x42,0x80,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16171 0x3f2b "㼫" */
+0x00,0x7e,0x4a,0x4a,0x7e,0x4a,0x4a,0x7e,0x08,0xff,0x18,0x2c,0x2a,0x4a,0x88,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16172 0x3f2c "㼬" */
+0x10,0x10,0x7c,0x10,0x10,0xfe,0x44,0x28,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16173 0x3f2d "㼭" */
+0x10,0x10,0x7c,0x11,0x11,0x1d,0xe1,0x01,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x20,0x3e,0x20,0xfc,0x04,0x04,0xfc,0x04,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16174 0x3f2e "㼮" */
+0x10,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0xfc,0x24,0x44,0x28,0x30,0xc8,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16175 0x3f2f "㼯" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x1c,0x2a,0x49,0x88,0x08,
+0x00,0x7c,0xa0,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16176 0x3f30 "㼰" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x14,0x24,0xff,0x04,0x04,0x04,0x04,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16177 0x3f31 "㼱" */
+0x04,0x7c,0x04,0x1c,0xe4,0x00,0x7f,0x48,0x10,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x44,0x58,0x62,0x42,0x3e,0x00,0xfc,0x24,0x10,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16178 0x3f32 "㼲" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xa2,0x96,0x10,0xfe,0x10,0x28,0x44,0x82,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16179 0x3f33 "㼳" */
+0x10,0x10,0x52,0x51,0x95,0x08,0x30,0xc0,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16180 0x3f34 "㼴" */
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x92,0x96,0xbe,0x82,0x8a,0x84,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16181 0x3f35 "㼵" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfc,0x20,0x20,0x38,0x28,0x48,0x68,0x58,0x4a,0x4a,0x6a,0x46,0x00,0xfe,0x00,
+/* 16182 0x3f36 "㼶" */
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xe2,0xaa,0xaa,0xea,0xaa,0xaa,0xe2,0xaa,0xa4,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16183 0x3f37 "㼷" */
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0x86,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16184 0x3f38 "㼸" */
+0x10,0x08,0xff,0x80,0x14,0x22,0x49,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x7c,0xa0,0xa0,0x20,0x38,0x28,0x28,0x58,0x48,0xc8,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16185 0x3f39 "㼹" */
+0x44,0x44,0xff,0x54,0x08,0xff,0x40,0x40,0x7e,0x00,0x54,0x54,0x55,0x56,0x94,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16186 0x3f3a "㼺" */
+0x10,0x08,0x7f,0x48,0x5e,0x4a,0x7f,0x4a,0x5e,0x48,0x5e,0x52,0x52,0x52,0x5e,0x92,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16187 0x3f3b "㼻" */
+0x11,0x21,0xca,0x14,0x32,0xd2,0x15,0x14,0x08,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x10,0x10,0xa8,0x44,0x40,0x7c,0x40,0xfe,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16188 0x3f3c "㼼" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x20,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16189 0x3f3d "㼽" */
+0x10,0x10,0xfe,0x10,0xba,0x54,0xba,0x10,0xba,0x54,0xba,0x10,0x28,0x24,0x42,0x80,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16190 0x3f3e "㼾" */
+0x08,0x04,0x7f,0x52,0x52,0x7f,0x52,0x52,0x7f,0x52,0x52,0x5b,0x52,0x52,0x9b,0x12,
+0x00,0x7c,0xa0,0x20,0x20,0xb8,0xa8,0xa8,0xd8,0x48,0x48,0xc8,0x5a,0xea,0x4a,0x06,
+/* 16191 0x3f3f "㼿" */
+0x10,0x08,0x7f,0x22,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16192 0x3f40 "㽀" */
+0x22,0x14,0xff,0x14,0x7f,0x55,0x63,0x5d,0x41,0x7f,0x08,0xff,0x14,0x22,0x41,0x80,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16193 0x3f41 "㽁" */
+0x3f,0x21,0x2e,0x22,0x2f,0x27,0x2a,0x32,0x20,0x3f,0x24,0x27,0x24,0x48,0x4b,0x8c,
+0xfe,0x04,0x38,0x10,0xbc,0x18,0xb4,0x52,0x00,0xfe,0x00,0xf0,0x90,0x52,0x12,0x0e,
+/* 16194 0x3f42 "㽂" */
+0x08,0x14,0x22,0x5d,0x80,0x3e,0x22,0x3e,0x00,0x77,0x11,0x55,0x33,0x55,0x11,0x33,
+0x00,0x7c,0x20,0x20,0xa0,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16195 0x3f43 "㽃" */
+0x0e,0xf0,0x92,0x54,0xfe,0x38,0x54,0x82,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x44,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16196 0x3f44 "㽄" */
+0x24,0xff,0x24,0x3c,0x24,0x3c,0x24,0xff,0x24,0x42,0x00,0x7f,0x08,0x0f,0x11,0x1c,
+0x0c,0x70,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x00,0xfc,0x00,0xe0,0x24,0x9c,
+/* 16197 0x3f45 "㽅" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x5d,0x80,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16198 0x3f46 "㽆" */
+0x10,0x92,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x00,0x7c,0x54,0x7c,0x54,0x54,0x7c,0x44,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16199 0x3f47 "㽇" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x40,0xbf,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0xf4,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16200 0x3f48 "㽈" */
+0x48,0x70,0x44,0x3d,0x20,0x7c,0x90,0x7d,0x2a,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0xf8,0x50,0x20,0xfc,0x24,0xb8,0xa0,0x7e,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16201 0x3f49 "㽉" */
+0x00,0x7e,0x48,0x7e,0x43,0x7e,0x48,0x7e,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0x40,0x7e,0x90,0x08,0xfe,0xaa,0xfe,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 16202 0x3f4a "㽊" */
+0x49,0x5d,0x61,0xdd,0x43,0x5d,0x41,0x5d,0xb6,0x9c,0x00,0x7f,0x02,0x34,0x1c,0x63,
+0x00,0x7c,0x20,0xa0,0x20,0x38,0x28,0x28,0xd8,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16203 0x3f4b "㽋" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x00,0x7f,0x08,0x0f,0x11,0x1c,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xfc,0x00,0xe0,0x24,0x9c,
+/* 16204 0x3f4c "㽌" */
+0x7f,0x08,0xff,0x88,0x6b,0x10,0x6f,0x45,0x55,0x6b,0x10,0x7f,0x49,0x7f,0x49,0x7f,
+0x00,0x7c,0xa0,0xa0,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 16205 0x3f4d "㽍" */
+0x22,0x22,0x22,0x22,0xff,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 16206 0x3f4e "㽎" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x01,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 16207 0x3f4f "㽏" */
+0x20,0x10,0x83,0x4d,0x10,0xe3,0x22,0x23,0x00,0x10,0xff,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0xa0,0x18,0xf6,0x00,0xf8,0x08,0xf8,0x00,0x10,0xfe,0x10,0xf0,0x10,0xf0,0x10,
+/* 16208 0x3f50 "㽐" */
+0x48,0x48,0x48,0x49,0xfc,0x49,0x48,0x4b,0x48,0x79,0x48,0x48,0x49,0x7a,0x48,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 16209 0x3f51 "㽑" */
+0x4b,0x48,0x4b,0x4a,0xfe,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,
+0xfe,0x50,0xfe,0x52,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 16210 0x3f52 "㽒" */
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x55,0x7c,0x10,0xfe,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x10,0x10,0x90,0x90,0xfc,0x90,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 16211 0x3f53 "㽓" */
+0x01,0x11,0x1f,0x21,0x5f,0x01,0xff,0x08,0x48,0x7e,0x48,0x88,0x7e,0x08,0x0f,0xf0,
+0x00,0x00,0xf8,0x00,0xf0,0x00,0xfe,0x10,0x50,0x7c,0x90,0x10,0x7c,0x10,0x10,0xfe,
+/* 16212 0x3f54 "㽔" */
+0x28,0x28,0xaa,0x6c,0x28,0xfe,0x10,0x30,0x4a,0x9c,0x2c,0xda,0x29,0xc8,0x28,0x10,
+0x10,0x10,0x50,0x7c,0x50,0x90,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0xc0,0x3e,0x00,
+/* 16213 0x3f55 "㽕" */
+0x01,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x7f,0x00,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xfe,0x02,0x02,0x14,0x08,
+/* 16214 0x3f56 "㽖" */
+0x00,0x00,0x7c,0x54,0x55,0x54,0x54,0x7c,0x54,0x54,0x54,0x54,0x7d,0x45,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 16215 0x3f57 "㽗" */
+0x00,0x00,0x7c,0x54,0x54,0x54,0x54,0x7c,0x54,0x54,0x54,0x54,0x7c,0x45,0x02,0x04,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x04,0x02,
+/* 16216 0x3f58 "㽘" */
+0x00,0x00,0x7c,0x55,0x54,0x54,0x54,0x7c,0x54,0x54,0x54,0x54,0x7c,0x45,0x01,0x02,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 16217 0x3f59 "㽙" */
+0x00,0x00,0x7c,0x54,0x55,0x57,0x54,0x7c,0x54,0x54,0x54,0x54,0x7d,0x45,0x02,0x04,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 16218 0x3f5a "㽚" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x11,0x3f,0x41,0x01,0xff,0x01,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 16219 0x3f5b "㽛" */
+0x00,0x00,0x7d,0x55,0x56,0x54,0x55,0x7d,0x55,0x55,0x55,0x55,0x7c,0x44,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 16220 0x3f5c "㽜" */
+0x10,0x1e,0x22,0x62,0x94,0x08,0x30,0xc0,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0xf8,0x88,0xa8,0x92,0x82,0x7e,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16221 0x3f5d "㽝" */
+0x7f,0x08,0x1e,0x22,0x54,0x08,0x30,0xc0,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x10,
+0x04,0x44,0x44,0x44,0x44,0x44,0x0c,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 16222 0x3f5e "㽞" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16223 0x3f5f "㽟" */
+0x00,0x00,0x7d,0x54,0x55,0x54,0x54,0x7c,0x55,0x54,0x54,0x54,0x7c,0x44,0x00,0x00,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 16224 0x3f60 "㽠" */
+0x00,0x00,0x7c,0x57,0x54,0x54,0x55,0x7d,0x55,0x56,0x54,0x54,0x7c,0x44,0x01,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 16225 0x3f61 "㽡" */
+0x00,0x00,0xf9,0xa9,0xa9,0xa9,0xf9,0xa9,0xa9,0xa8,0xa9,0xfb,0x88,0x00,0x00,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 16226 0x3f62 "㽢" */
+0x00,0x00,0xfb,0xa9,0xaa,0xac,0xfb,0xaa,0xaa,0xab,0xaa,0xfa,0x8b,0x00,0x00,0x00,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 16227 0x3f63 "㽣" */
+0x00,0x00,0xf8,0xaf,0xa8,0xa8,0xfb,0xaa,0xaa,0xaa,0xab,0xf8,0x88,0x07,0x02,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 16228 0x3f64 "㽤" */
+0x00,0x00,0x7c,0x55,0x56,0x54,0x54,0x7c,0x55,0x54,0x54,0x54,0x7d,0x44,0x00,0x00,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 16229 0x3f65 "㽥" */
+0x00,0x00,0x7c,0x54,0x55,0x54,0x54,0x7d,0x56,0x54,0x55,0x54,0x7c,0x45,0x02,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16230 0x3f66 "㽦" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x80,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16231 0x3f67 "㽧" */
+0x00,0x00,0xf8,0xab,0xa8,0xa8,0xf9,0xa9,0xaa,0xab,0xa8,0xf9,0x89,0x02,0x03,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 16232 0x3f68 "㽨" */
+0x01,0x00,0xf8,0xab,0xa8,0xa9,0xf8,0xab,0xa8,0xa9,0xa9,0xfa,0x8c,0x08,0x03,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 16233 0x3f69 "㽩" */
+0x00,0x00,0xf9,0xa9,0xaa,0xab,0xf8,0xa9,0xae,0xa8,0xab,0xf8,0x8b,0x00,0x00,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 16234 0x3f6a "㽪" */
+0x01,0x00,0xf8,0xab,0xaa,0xaa,0xfa,0xaa,0xab,0xa8,0xa9,0xf9,0x89,0x01,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16235 0x3f6b "㽫" */
+0x01,0xff,0x10,0x24,0x79,0x10,0x22,0x7c,0x08,0x30,0xc0,0x3f,0x21,0x3f,0x21,0x3f,
+0x00,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,
+/* 16236 0x3f6c "㽬" */
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 16237 0x3f6d "㽭" */
+0x00,0x01,0xf8,0xab,0xaa,0xa9,0xf8,0xa9,0xa8,0xab,0xa8,0xf9,0x89,0x01,0x01,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 16238 0x3f6e "㽮" */
+0x0f,0x09,0x0f,0x09,0x0f,0x7c,0x54,0x7c,0x54,0x7d,0x11,0x1f,0x21,0x5f,0x01,0xff,
+0xe0,0x20,0xe0,0x20,0xe0,0x7c,0x54,0x7c,0x54,0x7c,0x00,0xf8,0x00,0xf0,0x00,0xfe,
+/* 16239 0x3f6f "㽯" */
+0x02,0x03,0xf8,0xa9,0xab,0xad,0xf9,0xa9,0xa9,0xa9,0xa9,0xfb,0x8a,0x03,0x02,0x02,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 16240 0x3f70 "㽰" */
+0x00,0x77,0x55,0x55,0x55,0x77,0x55,0x55,0x55,0x77,0x55,0x55,0x55,0xb5,0x89,0x13,
+0x00,0x7c,0x14,0x14,0x10,0x10,0x50,0x5c,0x50,0x50,0x50,0x50,0x50,0x50,0xbe,0x00,
+/* 16241 0x3f71 "㽱" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x52,0x12,0x32,0x52,0x92,0x13,0x22,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x38,0xc8,0x08,0x08,0x08,0x08,
+/* 16242 0x3f72 "㽲" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x11,0x32,0x53,0x90,0x10,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfe,0x80,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 16243 0x3f73 "㽳" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x30,0x5f,0x90,0x10,0x20,0x20,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 16244 0x3f74 "㽴" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x52,0x91,0x10,0x20,0x20,0x43,0x8c,
+0x80,0x40,0xfe,0x00,0x10,0x10,0xfe,0x10,0x10,0x10,0x20,0xa0,0x40,0xa0,0x18,0x06,
+/* 16245 0x3f75 "㽵" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x50,0x10,0x37,0x50,0x90,0x10,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 16246 0x3f76 "㽶" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x50,0x10,0x30,0x53,0x92,0x12,0x22,0x22,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 16247 0x3f77 "㽷" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x11,0x31,0x51,0x92,0x12,0x24,0x28,0x41,0x80,
+0x80,0x40,0xfe,0x40,0x40,0x44,0x68,0x70,0x60,0x50,0x50,0x48,0x44,0x42,0x40,0x80,
+/* 16248 0x3f78 "㽸" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x53,0x12,0x34,0x50,0x90,0x11,0x21,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xfc,0x44,0x48,0xa0,0xa0,0x20,0x20,0x22,0x22,0x1e,
+/* 16249 0x3f79 "㽹" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x33,0x52,0x92,0x12,0x24,0x24,0x48,0x93,
+0x80,0x40,0xfe,0x00,0x1c,0xe0,0x00,0x00,0xf8,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 16250 0x3f7a "㽺" */
+0x00,0x00,0x1f,0x10,0x97,0x51,0x51,0x11,0x31,0x52,0x92,0x12,0x24,0x24,0x48,0x93,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0x10,0x20,0x3c,0x04,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 16251 0x3f7b "㽻" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x37,0x52,0x91,0x10,0x20,0x20,0x43,0x8c,
+0x80,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 16252 0x3f7c "㽼" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x33,0x52,0x94,0x17,0x20,0x20,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x04,0xe4,0x24,0x24,0xe4,0x04,0x04,0xe4,0x24,0x24,0x44,0x84,
+/* 16253 0x3f7d "㽽" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x53,0x92,0x12,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x40,0x40,0x40,0xfe,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 16254 0x3f7e "㽾" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x52,0x12,0x33,0x50,0x90,0x14,0x24,0x24,0x47,0x80,
+0x80,0x40,0xfe,0x00,0x40,0x48,0x48,0x48,0xf8,0x48,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 16255 0x3f7f "㽿" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x32,0x52,0x92,0x12,0x24,0x24,0x48,0x90,
+0x80,0x40,0xfe,0x00,0x1c,0xe0,0x90,0x90,0x90,0x90,0x90,0x88,0xc8,0xa4,0xd4,0x92,
+/* 16256 0x3f80 "㾀" */
+0x01,0x00,0x3f,0x20,0x20,0xa0,0x6f,0x20,0x20,0x60,0xbf,0x21,0x22,0x44,0x4f,0x84,
+0x00,0x80,0xfe,0x00,0x80,0x80,0xfc,0x80,0x80,0x80,0xfe,0x00,0x10,0x08,0xfc,0x04,
+/* 16257 0x3f81 "㾁" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x50,0x17,0x30,0x51,0x91,0x12,0x24,0x28,0x40,0x80,
+0x80,0x40,0xfe,0x40,0x50,0x48,0x40,0xfc,0xe0,0x60,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 16258 0x3f82 "㾂" */
+0x00,0x00,0x1f,0x10,0x90,0x51,0x52,0x17,0x32,0x50,0x93,0x12,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x80,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 16259 0x3f83 "㾃" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x18,0x32,0x52,0x92,0x13,0x22,0x22,0x42,0x81,
+0x80,0x40,0xfe,0x80,0x40,0xfc,0x04,0x08,0x00,0x10,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 16260 0x3f84 "㾄" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x14,0x34,0x54,0x97,0x14,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x04,
+/* 16261 0x3f85 "㾅" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x33,0x50,0x90,0x11,0x22,0x2c,0x40,0x80,
+0x80,0x40,0xfe,0x40,0x5c,0xe0,0x40,0x40,0xfc,0x44,0xc4,0x54,0x48,0x40,0x40,0x40,
+/* 16262 0x3f86 "㾆" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x33,0x52,0x92,0x1f,0x22,0x22,0x42,0x82,
+0x80,0x40,0xfe,0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfe,0x08,0x08,0x28,0x10,
+/* 16263 0x3f87 "㾇" */
+0x01,0x00,0x3f,0x20,0x20,0xa7,0x64,0x24,0x27,0x64,0xa4,0x27,0x24,0x44,0x47,0x84,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16264 0x3f88 "㾈" */
+0x00,0x00,0x1f,0x10,0x91,0x51,0x51,0x12,0x32,0x56,0x9a,0x12,0x22,0x22,0x42,0x82,
+0x80,0x40,0xfe,0x00,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 16265 0x3f89 "㾉" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x51,0x12,0x34,0x50,0x93,0x10,0x21,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x40,0x40,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0xa0,0x40,0x20,
+/* 16266 0x3f8a "㾊" */
+0x01,0x00,0x3f,0x20,0x20,0xaf,0x60,0x27,0x24,0x64,0xa4,0x21,0x22,0x4c,0x40,0x80,
+0x00,0x80,0xfe,0x40,0x40,0xfe,0x40,0xfc,0x44,0x54,0xe8,0x50,0x48,0x46,0x40,0x40,
+/* 16267 0x3f8b "㾋" */
+0x00,0x00,0x1f,0x11,0x91,0x52,0x52,0x16,0x3a,0x52,0x92,0x12,0x22,0x22,0x42,0x82,
+0x80,0x40,0xfe,0x10,0x10,0x10,0xfe,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,
+/* 16268 0x3f8c "㾌" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x53,0x14,0x30,0x5f,0x91,0x11,0x21,0x22,0x44,0x98,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xfc,0x40,0x40,0xfe,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 16269 0x3f8d "㾍" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x50,0x10,0x37,0x54,0x94,0x14,0x24,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x94,0x08,
+/* 16270 0x3f8e "㾎" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x34,0x54,0x94,0x14,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xe4,0x04,0x04,0x04,0xfc,0x04,
+/* 16271 0x3f8f "㾏" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x3f,0x50,0x90,0x17,0x20,0x20,0x5f,0x80,
+0x80,0x40,0xfe,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 16272 0x3f90 "㾐" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x52,0x12,0x37,0x54,0x9a,0x11,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x00,0x04,0xc4,0x14,0x14,0xd4,0x54,0x54,0x94,0x84,0x04,0x14,0x08,
+/* 16273 0x3f91 "㾑" */
+0x00,0x00,0x1f,0x10,0x90,0x51,0x52,0x1d,0x30,0x50,0x93,0x12,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 16274 0x3f92 "㾒" */
+0x00,0x00,0x1f,0x11,0x91,0x51,0x5f,0x12,0x32,0x54,0x94,0x12,0x21,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x92,0x92,0x12,0x9e,0x52,0x40,
+/* 16275 0x3f93 "㾓" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x10,0x37,0x54,0x97,0x14,0x27,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 16276 0x3f94 "㾔" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x33,0x50,0x97,0x14,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 16277 0x3f95 "㾕" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x52,0x11,0x3f,0x50,0x90,0x17,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x80,0x40,0xfc,0x08,0x10,0xfe,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,
+/* 16278 0x3f96 "㾖" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x17,0x34,0x57,0x90,0x17,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 16279 0x3f97 "㾗" */
+0x00,0x00,0x1f,0x11,0x90,0x57,0x54,0x17,0x34,0x57,0x94,0x14,0x24,0x25,0x46,0x84,
+0x80,0x40,0xfe,0x00,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x82,0x44,0x28,0x10,0x08,0x06,
+/* 16280 0x3f98 "㾘" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x53,0x12,0x33,0x52,0x93,0x12,0x21,0x20,0x43,0x8c,
+0x80,0x40,0xfe,0x00,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0x40,0x80,0x60,0x1e,
+/* 16281 0x3f99 "㾙" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x51,0x16,0x3f,0x51,0x92,0x17,0x2a,0x22,0x42,0x80,
+0x80,0x40,0xfe,0x10,0x20,0xc0,0x30,0x88,0xfe,0x00,0x40,0xf8,0x48,0x68,0x50,0x40,
+/* 16282 0x3f9a "㾚" */
+0x00,0x00,0x1f,0x11,0x91,0x55,0x55,0x15,0x35,0x5e,0x90,0x13,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x20,0x24,0xe8,0x30,0x22,0xa2,0x1e,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 16283 0x3f9b "㾛" */
+0x00,0x00,0x1f,0x10,0x93,0x50,0x51,0x10,0x33,0x50,0x97,0x14,0x23,0x21,0x40,0x87,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 16284 0x3f9c "㾜" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x32,0x52,0x95,0x18,0x20,0x21,0x46,0x98,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xfc,0x40,0x48,0x48,0x54,0x42,0xa0,0x10,0x08,0x06,
+/* 16285 0x3f9d "㾝" */
+0x01,0x00,0x3f,0x20,0x3f,0xa0,0x6f,0x28,0x2f,0x68,0xaf,0x20,0x3f,0x40,0x40,0x80,
+0x00,0x80,0xfe,0x80,0xfc,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfe,0x80,0x80,0x80,
+/* 16286 0x3f9e "㾞" */
+0x01,0x00,0x3f,0x20,0x2f,0xa1,0x6f,0x29,0x29,0x6a,0xac,0x2f,0x28,0x48,0x4f,0x88,
+0x00,0x80,0xfe,0x00,0xfc,0x20,0xfc,0x24,0x24,0x1c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16287 0x3f9f "㾟" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x52,0x12,0x3f,0x50,0x91,0x12,0x24,0x20,0x43,0x9c,
+0x80,0x40,0xfe,0x00,0x40,0x7c,0x40,0x40,0xfe,0x40,0x44,0x48,0x10,0x60,0x80,0x00,
+/* 16288 0x3fa0 "㾠" */
+0x00,0x00,0x1f,0x10,0x98,0x55,0x52,0x1d,0x31,0x51,0x93,0x1d,0x21,0x21,0x4a,0x84,
+0x80,0x40,0xfe,0x00,0x80,0x7c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x7e,0x00,
+/* 16289 0x3fa1 "㾡" */
+0x00,0x00,0x1f,0x11,0x91,0x57,0x51,0x11,0x3f,0x51,0x92,0x14,0x2f,0x24,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x1e,0xd2,0x12,0x12,0xf2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 16290 0x3fa2 "㾢" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x50,0x12,0x32,0x55,0x98,0x11,0x22,0x2c,0x40,0x80,
+0x80,0x40,0xfe,0x40,0x40,0xfe,0x40,0x48,0x48,0x54,0xe2,0x50,0x48,0x46,0x40,0x40,
+/* 16291 0x3fa3 "㾣" */
+0x00,0x3f,0x20,0x21,0xa2,0x64,0x28,0x37,0x60,0xa0,0x2f,0x20,0x24,0x42,0x5f,0x80,
+0x80,0xfe,0x80,0x40,0x20,0x10,0x08,0xf6,0x80,0x80,0xf8,0x80,0x90,0xa0,0xfe,0x00,
+/* 16292 0x3fa4 "㾤" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x11,0x32,0x54,0x93,0x10,0x20,0x20,0x47,0x80,
+0x80,0x40,0xfe,0x80,0x40,0xfc,0x04,0x10,0x08,0x04,0xf8,0x40,0x40,0x40,0xfc,0x00,
+/* 16293 0x3fa5 "㾥" */
+0x00,0x00,0x1f,0x10,0x92,0x53,0x52,0x12,0x3f,0x50,0x92,0x16,0x2a,0x22,0x4a,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xbc,0x14,0x14,0xd4,0x14,0x08,0x88,0x48,0x14,0x14,0x22,
+/* 16294 0x3fa6 "㾦" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x52,0x11,0x3f,0x50,0x93,0x12,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x80,0x40,0xfc,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 16295 0x3fa7 "㾧" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x50,0x97,0x10,0x21,0x22,0x4c,0x80,
+0x80,0x40,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 16296 0x3fa8 "㾨" */
+0x01,0x00,0x3f,0x20,0x2f,0xa1,0x62,0x24,0x3f,0x60,0xa7,0x24,0x27,0x40,0x40,0x80,
+0x00,0x80,0xfe,0x80,0xf8,0x40,0x20,0x10,0xfe,0x10,0xd0,0x50,0xd0,0x10,0x50,0x20,
+/* 16297 0x3fa9 "㾩" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x50,0x1f,0x31,0x51,0x97,0x11,0x23,0x25,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x38,0xc0,0x40,0xfe,0x50,0x54,0x58,0x54,0x54,0x4c,0x40,0x40,
+/* 16298 0x3faa "㾪" */
+0x00,0x00,0x1f,0x10,0x92,0x54,0x58,0x13,0x3f,0x52,0x93,0x12,0x23,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x40,0x48,0x54,0x62,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 16299 0x3fab "㾫" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x52,0x13,0x32,0x53,0x93,0x15,0x25,0x29,0x41,0x81,
+0x80,0x40,0xfe,0x40,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x54,0x54,0xfc,0x54,0x44,0x0c,
+/* 16300 0x3fac "㾬" */
+0x00,0x00,0x1f,0x10,0x94,0x57,0x54,0x15,0x36,0x51,0x93,0x12,0x23,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x00,0x24,0xa8,0x32,0x22,0x1e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16301 0x3fad "㾭" */
+0x01,0x00,0x3f,0x20,0x23,0xae,0x62,0x22,0x3f,0x66,0xa6,0x2b,0x2a,0x52,0x42,0x82,
+0x00,0x80,0xfe,0x00,0x10,0x10,0x54,0x54,0x58,0x90,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 16302 0x3fae "㾮" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x13,0x32,0x53,0x90,0x17,0x20,0x23,0x40,0x8f,
+0x80,0x40,0xfe,0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0xfc,0x40,0xfe,
+/* 16303 0x3faf "㾯" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x50,0x97,0x12,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfe,0x44,0x28,0x90,0x08,0x06,
+/* 16304 0x3fb0 "㾰" */
+0x01,0x00,0x3f,0x22,0x22,0xa2,0x6f,0x22,0x22,0x6f,0xa8,0x28,0x2f,0x48,0x40,0x80,
+0x00,0x80,0xfe,0x00,0x3c,0x24,0xa4,0x3c,0x24,0xa4,0xbc,0xa4,0xa4,0xc4,0x54,0x88,
+/* 16305 0x3fb1 "㾱" */
+0x01,0x00,0x3f,0x20,0x2f,0xa1,0x6a,0x24,0x3b,0x61,0xa1,0x2f,0x21,0x42,0x44,0x88,
+0x00,0x80,0xfe,0x40,0x50,0x24,0x18,0x08,0xf6,0x20,0x20,0xfc,0x20,0x24,0x24,0x1c,
+/* 16306 0x3fb2 "㾲" */
+0x01,0x00,0x3f,0x22,0x2f,0xa2,0x6f,0x22,0x3f,0x64,0xa7,0x24,0x24,0x48,0x4a,0x91,
+0x00,0x80,0xfe,0x10,0x90,0x1e,0xa4,0x24,0xd4,0x14,0x94,0x88,0x88,0x94,0xa4,0x42,
+/* 16307 0x3fb3 "㾳" */
+0x01,0x00,0x3f,0x28,0x24,0xa1,0x64,0x38,0x29,0x61,0xbf,0x22,0x27,0x40,0x43,0x8c,
+0x00,0x80,0xfe,0x80,0xfc,0x24,0x20,0x50,0x8c,0x00,0xfe,0x10,0x20,0xc0,0x30,0x08,
+/* 16308 0x3fb4 "㾴" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x51,0x12,0x34,0x53,0x92,0x13,0x22,0x23,0x42,0x8f,
+0x80,0x40,0xfe,0x40,0x40,0xfc,0x50,0x48,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,
+/* 16309 0x3fb5 "㾵" */
+0x00,0x00,0x1f,0x12,0x91,0x5f,0x50,0x17,0x30,0x57,0x90,0x17,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0x08,0xc8,0x08,0x88,0x3e,0x88,0x08,0x88,0x88,0x88,0x88,0x88,
+/* 16310 0x3fb6 "㾶" */
+0x00,0x3f,0x20,0x23,0xa2,0x63,0x22,0x2f,0x68,0xb3,0x22,0x23,0x22,0x43,0x42,0x82,
+0x80,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xfe,0x02,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 16311 0x3fb7 "㾷" */
+0x00,0x3f,0x20,0x20,0xaf,0x68,0x28,0x2b,0x6a,0xaa,0x2a,0x2a,0x32,0x54,0x64,0x89,
+0x80,0xfe,0x00,0x3e,0xc0,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xf0,0x94,0x0c,
+/* 16312 0x3fb8 "㾸" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x51,0x11,0x31,0x50,0x97,0x14,0x25,0x25,0x45,0x84,
+0x80,0x40,0xfe,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xfa,0x0a,0xfa,0x06,
+/* 16313 0x3fb9 "㾹" */
+0x01,0x00,0x3f,0x21,0x21,0xa5,0x65,0x25,0x25,0x6e,0xa0,0x27,0x20,0x41,0x42,0x8c,
+0x00,0x80,0xfe,0x20,0x28,0xb0,0x24,0x24,0x9c,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,
+/* 16314 0x3fba "㾺" */
+0x01,0x00,0x3f,0x20,0x27,0xa4,0x67,0x24,0x27,0x64,0xa7,0x20,0x2a,0x4a,0x50,0x80,
+0x00,0x80,0xfe,0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0xa4,0xa4,0x14,0x08,
+/* 16315 0x3fbb "㾻" */
+0x00,0x00,0x1f,0x10,0x97,0x55,0x55,0x16,0x35,0x55,0x95,0x15,0x27,0x24,0x45,0x84,
+0x80,0x40,0xfe,0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0xfe,0x10,0x54,0x92,0x52,0x20,
+/* 16316 0x3fbc "㾼" */
+0x01,0x00,0x3f,0x20,0x29,0xa5,0x65,0x21,0x3d,0x65,0xa5,0x25,0x25,0x45,0x4a,0x91,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x24,0x18,0x48,0x84,0x04,0x00,0xfe,
+/* 16317 0x3fbd "㾽" */
+0x01,0x00,0x3f,0x20,0x28,0xa5,0x61,0x21,0x2d,0x65,0xa5,0x25,0x25,0x45,0x4a,0x91,
+0x00,0x80,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,
+/* 16318 0x3fbe "㾾" */
+0x00,0x00,0x1f,0x12,0x91,0x5f,0x51,0x17,0x31,0x5f,0x91,0x17,0x23,0x25,0x59,0x81,
+0x80,0x40,0xfe,0x08,0x10,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x30,0x28,0x26,0x20,
+/* 16319 0x3fbf "㾿" */
+0x01,0x00,0x3f,0x22,0x21,0xaf,0x68,0x2f,0x28,0x6f,0xaa,0x29,0x2a,0x4c,0x48,0x80,
+0x00,0x80,0xfe,0x00,0x00,0xbe,0xa2,0xa4,0xa8,0xa4,0x22,0x22,0xaa,0xa4,0x20,0x20,
+/* 16320 0x3fc0 "㿀" */
+0x01,0x00,0x3f,0x20,0x2e,0xa4,0x64,0x24,0x24,0x6e,0xa4,0x24,0x24,0x46,0x58,0x81,
+0x00,0x80,0xfe,0x20,0x2e,0x24,0xa4,0xa4,0xa4,0xae,0x24,0x24,0x44,0x44,0x8e,0x00,
+/* 16321 0x3fc1 "㿁" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x50,0x97,0x12,0x24,0x29,0x40,0x80,
+0x80,0x40,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xfc,0x10,0x48,0xf6,0x40,0x40,
+/* 16322 0x3fc2 "㿂" */
+0x00,0x00,0x1f,0x11,0x95,0x55,0x57,0x10,0x37,0x51,0x91,0x17,0x21,0x21,0x4f,0x80,
+0x80,0x40,0xfe,0x10,0x50,0x50,0xde,0x24,0xd4,0x14,0x14,0xd4,0x08,0x08,0xd4,0x22,
+/* 16323 0x3fc3 "㿃" */
+0x00,0x00,0x1f,0x12,0x92,0x57,0x52,0x14,0x38,0x57,0x94,0x13,0x22,0x22,0x42,0x80,
+0x80,0x40,0xfe,0xa8,0xa8,0xfc,0xaa,0xe6,0x00,0xfc,0x44,0xf8,0x48,0x48,0x58,0x40,
+/* 16324 0x3fc4 "㿄" */
+0x01,0x00,0x3f,0x20,0x2f,0xaa,0x6b,0x2d,0x29,0x6f,0xa9,0x2a,0x2c,0x48,0x4f,0x80,
+0x00,0x80,0xfe,0x00,0xdc,0x14,0xd4,0x16,0x20,0xdc,0x14,0x94,0x54,0x08,0xd4,0x22,
+/* 16325 0x3fc5 "㿅" */
+0x01,0x00,0x3f,0x22,0x24,0xa8,0x70,0x22,0x25,0x6c,0xb4,0x24,0x24,0x45,0x46,0x84,
+0x00,0x80,0xfe,0x10,0x10,0x9c,0x90,0x90,0xfe,0x10,0x90,0x9c,0x90,0x50,0x3e,0x00,
+/* 16326 0x3fc6 "㿆" */
+0x00,0x1f,0x10,0x10,0x93,0x50,0x17,0x31,0x52,0x94,0x10,0x17,0x20,0x23,0x4d,0x81,
+0x80,0xfe,0x00,0x38,0xc0,0x40,0xfc,0x50,0x48,0x86,0x40,0xfc,0xa2,0x14,0x48,0x86,
+/* 16327 0x3fc7 "㿇" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x54,0x12,0x34,0x51,0x93,0x12,0x23,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16328 0x3fc8 "㿈" */
+0x01,0x00,0x3f,0x22,0x22,0xa5,0x69,0x2e,0x22,0x65,0xa9,0x2f,0x22,0x44,0x48,0x90,
+0x00,0x80,0xfe,0x28,0x24,0x7e,0x48,0x48,0xfe,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,
+/* 16329 0x3fc9 "㿉" */
+0x00,0x3f,0x20,0x27,0xa4,0x67,0x20,0x3f,0x64,0xa7,0x24,0x27,0x24,0x47,0x42,0x84,
+0x80,0xfe,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 16330 0x3fca "㿊" */
+0x00,0x3f,0x20,0x2f,0xa2,0x6a,0x2f,0x26,0x6b,0xb2,0x27,0x24,0x27,0x44,0x47,0x84,
+0x80,0xfe,0x00,0x78,0x10,0x50,0x7c,0x30,0x54,0x8c,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 16331 0x3fcb "㿋" */
+0x00,0x1f,0x10,0x13,0x92,0x53,0x10,0x37,0x54,0x97,0x10,0x1f,0x21,0x22,0x4c,0x80,
+0x80,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xbc,0xa4,0xbc,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 16332 0x3fcc "㿌" */
+0x00,0x3f,0x20,0x21,0xa2,0x64,0x3b,0x20,0x6f,0xa9,0x29,0x2f,0x22,0x45,0x48,0x91,
+0x80,0xfe,0x80,0x40,0x20,0x10,0xec,0x00,0x78,0x48,0x48,0x78,0x20,0x50,0x88,0x04,
+/* 16333 0x3fcd "㿍" */
+0x01,0x00,0x3f,0x20,0x28,0xaf,0x71,0x2f,0x2a,0x6f,0xaa,0x2f,0x2a,0x4a,0x50,0xa1,
+0x00,0x80,0xfe,0x00,0x7c,0x14,0x24,0xcc,0xa8,0xbe,0xc8,0x88,0xfe,0x88,0x88,0x88,
+/* 16334 0x3fce "㿎" */
+0x00,0x1f,0x10,0x17,0x91,0x5f,0x11,0x37,0x54,0x97,0x14,0x17,0x24,0x27,0x41,0x82,
+0x80,0xfe,0x40,0xfc,0x50,0xfe,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x10,0x08,
+/* 16335 0x3fcf "㿏" */
+0x00,0x3f,0x20,0x27,0xa0,0x6f,0x21,0x27,0x63,0xa4,0x2f,0x30,0x23,0x40,0x4f,0x80,
+0x80,0xfe,0x00,0xf8,0x88,0xfe,0x08,0xf8,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfe,0x40,
+/* 16336 0x3fd0 "㿐" */
+0x00,0x3f,0x22,0x22,0xaf,0x62,0x22,0x3f,0x62,0xa2,0x2a,0x2b,0x2a,0x4a,0x56,0xa3,
+0x80,0xfe,0x10,0x3e,0x44,0xa8,0x10,0xa8,0x5e,0x22,0x54,0x08,0x10,0x60,0x00,0xfe,
+/* 16337 0x3fd1 "㿑" */
+0x00,0x3f,0x20,0x2f,0xa4,0x62,0x24,0x22,0x67,0xac,0x37,0x24,0x27,0x44,0x47,0x84,
+0x80,0xfe,0x00,0xbe,0x92,0x8a,0x92,0x20,0xfe,0x20,0xfe,0x20,0xfe,0x20,0xfe,0x00,
+/* 16338 0x3fd2 "㿒" */
+0x00,0x3f,0x20,0x2f,0xa0,0x67,0x20,0x3f,0x60,0xa7,0x20,0x3f,0x20,0x4f,0x49,0x8f,
+0x80,0xfe,0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x08,0x7e,0x48,0x18,
+/* 16339 0x3fd3 "㿓" */
+0x00,0x3f,0x20,0x27,0xa2,0x62,0x25,0x28,0x63,0xad,0x21,0x21,0x22,0x42,0x45,0x88,
+0x80,0xfe,0x40,0xfc,0x48,0x48,0x54,0xa2,0x18,0xf6,0x10,0xf0,0x40,0x7c,0x40,0xfe,
+/* 16340 0x3fd4 "㿔" */
+0x01,0x00,0x3f,0x20,0x27,0xa4,0x67,0x24,0x27,0x60,0xaf,0x2a,0x2f,0x4a,0x4f,0x88,
+0x00,0x80,0xfe,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xbe,0xaa,0xbe,0xaa,0xbe,0xa2,
+/* 16341 0x3fd5 "㿕" */
+0x00,0x3f,0x20,0x2f,0xa9,0x6f,0x29,0x2f,0x69,0xaa,0x2c,0x2b,0x2a,0x4b,0x4a,0x8b,
+0x80,0xfe,0x00,0x3c,0x24,0x3c,0x24,0x3c,0xe4,0x24,0x44,0x64,0x24,0x64,0x24,0xec,
+/* 16342 0x3fd6 "㿖" */
+0x00,0x3f,0x20,0x20,0xa0,0x67,0x24,0x25,0x64,0xa4,0x24,0x24,0x24,0x49,0x49,0x93,
+0x80,0xfe,0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0xa8,0xf8,0xa8,0xfc,0x54,0xfe,
+/* 16343 0x3fd7 "㿗" */
+0x00,0x3f,0x20,0x23,0xbc,0x64,0x3f,0x2e,0x75,0xa4,0x2e,0x2a,0x2a,0x53,0x52,0xa0,
+0x80,0xfe,0x00,0x00,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x82,
+/* 16344 0x3fd8 "㿘" */
+0x00,0x3f,0x22,0x2a,0xa2,0x65,0x28,0x2f,0x68,0xa3,0x22,0x23,0x20,0x47,0x44,0x87,
+0x80,0xfe,0x08,0xaa,0x48,0x14,0xa2,0xfe,0x02,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,
+/* 16345 0x3fd9 "㿙" */
+0x01,0x00,0x3f,0x20,0x23,0xa2,0x63,0x20,0x2f,0x6a,0xaf,0x20,0x2f,0x40,0x43,0x8c,
+0x00,0x80,0xfe,0x00,0xf8,0xa8,0xf8,0x00,0xbe,0xaa,0xbe,0x40,0xfe,0xa0,0x18,0x06,
+/* 16346 0x3fda "㿚" */
+0x00,0x3f,0x20,0x2f,0xa9,0x6f,0x22,0x24,0x69,0xaf,0x22,0x25,0x2f,0x40,0x55,0x95,
+0x80,0xfe,0x00,0xfe,0x12,0xfe,0x28,0x44,0xfe,0x48,0x7e,0x48,0x7e,0x48,0x7e,0x40,
+/* 16347 0x3fdb "㿛" */
+0x00,0x3f,0x20,0x2f,0xa5,0x67,0x25,0x2f,0x69,0xaf,0x29,0x2f,0x2a,0x4b,0x52,0xa3,
+0x80,0xfe,0x00,0xbe,0x14,0x1c,0x54,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xb8,0x22,0x9e,
+/* 16348 0x3fdc "㿜" */
+0x00,0x3f,0x21,0x27,0xa5,0x64,0x27,0x22,0x67,0xbd,0x27,0x20,0x2f,0x49,0x4f,0x89,
+0x80,0xfe,0x00,0xf8,0x48,0xa8,0xf8,0x10,0xf8,0x2e,0xf8,0x00,0xfc,0x24,0xfc,0x24,
+/* 16349 0x3fdd "㿝" */
+0x04,0x08,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x02,0x04,0x08,0x10,0x20,0x7f,0x20,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,
+/* 16350 0x3fde "㿞" */
+0x10,0x10,0x21,0x7c,0x44,0x44,0x45,0x44,0x7c,0x44,0x47,0x44,0x44,0x7c,0x44,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 16351 0x3fdf "㿟" */
+0x10,0x10,0x20,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x40,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 16352 0x3fe0 "㿠" */
+0x10,0x10,0x22,0x79,0x49,0x48,0x4f,0x48,0x78,0x48,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 16353 0x3fe1 "㿡" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x24,0x14,0x0c,0x14,0x64,0x08,0x10,0x60,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x48,0x50,0x60,0x50,0x48,0x42,0x42,0x3e,
+/* 16354 0x3fe2 "㿢" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x02,0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x14,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 16355 0x3fe3 "㿣" */
+0x10,0x13,0x22,0x7b,0x4a,0x4b,0x49,0x4b,0x7c,0x4a,0x4a,0x4a,0x4b,0x78,0x48,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 16356 0x3fe4 "㿤" */
+0x10,0x10,0x23,0x78,0x49,0x48,0x4b,0x49,0x7a,0x4d,0x49,0x49,0x49,0x79,0x49,0x01,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 16357 0x3fe5 "㿥" */
+0x10,0x10,0x23,0x7a,0x48,0x49,0x49,0x4b,0x7d,0x49,0x49,0x49,0x49,0x79,0x49,0x01,
+0x40,0x40,0xfe,0xa2,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 16358 0x3fe6 "㿦" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x84,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x86,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16359 0x3fe7 "㿧" */
+0x10,0x13,0x20,0x79,0x48,0x4b,0x48,0x49,0x78,0x4b,0x48,0x4b,0x48,0x7b,0x4a,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 16360 0x3fe8 "㿨" */
+0x10,0x13,0x22,0x7a,0x4a,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x05,
+0x00,0xfe,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x44,0x10,0x10,0x5e,0x50,0x50,0xfe,
+/* 16361 0x3fe9 "㿩" */
+0x11,0x10,0x23,0x7a,0x48,0x48,0x4b,0x4a,0x7a,0x4b,0x48,0x4b,0x48,0x7f,0x4a,0x04,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xfe,0xaa,0x72,0xfe,0x20,0xfe,0x20,0xfe,0xa4,0x52,
+/* 16362 0x3fea "㿪" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x21,
+0x20,0x20,0x20,0x78,0x28,0x28,0x28,0xa8,0x68,0x28,0x58,0x48,0x4a,0x8a,0x86,0x02,
+/* 16363 0x3feb "㿫" */
+0x20,0x20,0x3e,0x20,0x26,0x38,0x00,0x1f,0x10,0x10,0x17,0x12,0x21,0x20,0x43,0x1c,
+0x80,0x84,0x98,0xe4,0x84,0x7c,0x80,0xfc,0x84,0x88,0xf0,0x10,0x20,0xc0,0x30,0x0e,
+/* 16364 0x3fec "㿬" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x20,
+0x00,0x00,0x7c,0x54,0x54,0x54,0x54,0x54,0x7c,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 16365 0x3fed "㿭" */
+0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x58,0x48,0x4c,0x4a,0x48,0x49,0x89,0x02,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16366 0x3fee "㿮" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0xfe,0x10,0x10,0x28,0x25,0x45,0x82,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16367 0x3fef "㿯" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x01,0x3f,0x21,0x2f,0x24,0x42,0x41,0x9e,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe8,0x20,0x40,0x80,0x7c,
+/* 16368 0x3ff0 "㿰" */
+0x20,0x10,0x00,0xfe,0x00,0x28,0x44,0x82,0x04,0x44,0x28,0x10,0x28,0x45,0x85,0x02,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16369 0x3ff1 "㿱" */
+0x10,0x11,0xfd,0x11,0x1d,0xf2,0x12,0x34,0x01,0x3f,0x21,0x2f,0x24,0x42,0x41,0x9e,
+0x0c,0xf0,0x00,0xfe,0x10,0x10,0x10,0x10,0x00,0xfc,0x04,0xe8,0x20,0x40,0x80,0x7c,
+/* 16370 0x3ff2 "㿲" */
+0x10,0x10,0xfe,0x10,0x28,0x44,0xfe,0x04,0x74,0x54,0x54,0x74,0x54,0x05,0x15,0x0a,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16371 0x3ff3 "㿳" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x20,
+0x2a,0x2a,0x54,0x54,0x2a,0x2a,0x2a,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 16372 0x3ff4 "㿴" */
+0x10,0x10,0xff,0x24,0x42,0x81,0x7e,0x24,0x3c,0x24,0x3c,0x24,0x2e,0xf5,0x05,0x06,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16373 0x3ff5 "㿵" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x20,
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xa2,0x96,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 16374 0x3ff6 "㿶" */
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0xa2,0x10,0xfe,0x20,0x3c,0x24,0x45,0x55,0x8a,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16375 0x3ff7 "㿷" */
+0x44,0x24,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x20,0x3e,0x48,0x48,0x8e,0x79,0x21,0x02,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 16376 0x3ff8 "㿸" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x21,
+0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0xaa,0xfe,0x00,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 16377 0x3ff9 "㿹" */
+0x10,0x12,0x11,0x7c,0x54,0x50,0x53,0x7d,0x45,0x65,0x59,0x49,0x55,0x95,0x22,0x04,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 16378 0x3ffa "㿺" */
+0x7f,0x41,0x7f,0x41,0x7f,0x22,0x7f,0x22,0xff,0x22,0x49,0xaa,0x1c,0x2a,0x49,0x18,
+0x08,0x08,0x08,0x7e,0x4a,0x4a,0x48,0x7c,0xd4,0x54,0x54,0xd4,0x48,0x88,0x14,0x22,
+/* 16379 0x3ffb "㿻" */
+0x00,0x1f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf0,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 16380 0x3ffc "㿼" */
+0x00,0x3f,0x08,0x08,0xff,0x08,0x10,0x20,0x40,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16381 0x3ffd "㿽" */
+0x04,0x08,0x10,0x2f,0xc4,0x08,0x0f,0x00,0x01,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x20,0x10,0xe8,0x06,0x00,0xe0,0x20,0x40,0x80,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16382 0x3ffe "㿾" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x01,0x01,0x05,0x02,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0x00,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16383 0x3fff "㿿" */
+0x00,0x7f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0xfc,0x04,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 16384 0x4000 "䀀" */
+0x10,0x09,0x41,0x25,0x09,0x11,0x71,0x11,0x10,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf8,0x08,0x08,0x28,0x10,0x02,0x02,0xfe,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16385 0x4001 "䀁" */
+0x02,0xff,0x04,0x0f,0x18,0x2f,0xc8,0x0f,0x08,0x08,0x00,0x3f,0x24,0x24,0xff,0x00,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 16386 0x4002 "䀂" */
+0x01,0x7f,0x40,0x04,0xff,0x08,0x1e,0x03,0x3c,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xfc,0x04,0x00,0xfe,0x20,0x40,0xc0,0x38,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16387 0x4003 "䀃" */
+0x00,0x7f,0x02,0x0d,0x71,0x02,0x0c,0x71,0x06,0x1a,0xe1,0x3f,0x24,0x24,0xff,0x00,
+0x00,0xfc,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 16388 0x4004 "䀄" */
+0x02,0x01,0x7f,0x42,0x89,0x28,0x49,0x0e,0x77,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x24,0x48,0x94,0x10,0xf0,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16389 0x4005 "䀅" */
+0x20,0x10,0xfc,0x09,0x10,0x38,0x54,0x90,0x13,0x10,0x00,0x3f,0x24,0x24,0xff,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 16390 0x4006 "䀆" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7f,0x00,0x11,0x26,0x18,0xe0,0x3f,0x24,0xff,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x00,0x08,0xd0,0x30,0x0e,0xf8,0x48,0xfe,
+/* 16391 0x4007 "䀇" */
+0x10,0x10,0x11,0xfe,0x10,0x11,0x7c,0x45,0x45,0x7d,0x00,0x3f,0x24,0x24,0xff,0x00,
+0x80,0x80,0xfc,0x20,0x20,0xfc,0x20,0x24,0x24,0xfc,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 16392 0x4008 "䀈" */
+0x7d,0x44,0x7d,0x45,0x7d,0x50,0x48,0x55,0x62,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0xfc,0x20,0x20,0x20,0xfe,0x50,0x90,0x12,0x0e,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 16393 0x4009 "䀉" */
+0x00,0x1f,0x02,0xff,0x08,0x37,0xc4,0x3f,0x20,0x27,0x24,0x27,0x00,0x3f,0x24,0xff,
+0x70,0x80,0x00,0xfe,0x20,0xd8,0x46,0xf8,0x08,0xc8,0x48,0xd8,0x00,0xf8,0x48,0xfe,
+/* 16394 0x400a "䀊" */
+0x27,0x14,0x92,0x44,0x40,0x11,0x2e,0xe3,0x20,0x23,0x20,0x03,0x00,0x3f,0x24,0xff,
+0xbc,0xa4,0x94,0xa4,0x40,0xb0,0x4e,0x90,0x60,0x88,0x70,0x80,0x00,0xf8,0x48,0xfe,
+/* 16395 0x400b "䀋" */
+0x21,0x21,0x22,0x24,0xf8,0x23,0x22,0x22,0x23,0x3a,0xe2,0x43,0x00,0x3f,0x24,0xff,
+0x00,0xfe,0x20,0x3e,0x20,0xfe,0xaa,0x52,0x26,0x52,0xaa,0xfe,0x00,0xf8,0x48,0xfe,
+/* 16396 0x400c "䀌" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7d,0x11,0x7d,0x44,0x7c,0x44,0x7f,0x24,0xff,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x7c,0x10,0x7c,0x44,0x7c,0x44,0xfc,0x48,0xfe,
+/* 16397 0x400d "䀍" */
+0x10,0xfe,0x29,0xfe,0x01,0x7c,0x44,0x7d,0x44,0x7c,0x10,0xfe,0x10,0x3f,0x24,0xff,
+0x40,0xf8,0x48,0x30,0xce,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x50,0xf8,0x48,0xfe,
+/* 16398 0x400e "䀎" */
+0x00,0x03,0x7c,0x44,0x44,0x7c,0x45,0x45,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfe,0x40,0x40,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 16399 0x400f "䀏" */
+0x10,0x10,0x1f,0x20,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 16400 0x4010 "䀐" */
+0x00,0x7e,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x7e,0x42,0x00,
+0x08,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x04,0x08,0x10,0x20,0xc0,
+/* 16401 0x4011 "䀑" */
+0x00,0x01,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 16402 0x4012 "䀒" */
+0x00,0x00,0x7d,0x44,0x44,0x7c,0x44,0x47,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 16403 0x4013 "䀓" */
+0x00,0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7d,0x44,0x44,0x44,0x7c,0x45,0x02,0x04,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 16404 0x4014 "䀔" */
+0x00,0x00,0x7d,0x44,0x44,0x7d,0x45,0x45,0x7d,0x46,0x44,0x44,0x7c,0x45,0x02,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 16405 0x4015 "䀕" */
+0x00,0x03,0x78,0x48,0x48,0x79,0x49,0x49,0x7a,0x4b,0x48,0x48,0x78,0x48,0x01,0x00,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 16406 0x4016 "䀖" */
+0x00,0x00,0x7d,0x44,0x44,0x7c,0x44,0x47,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 16407 0x4017 "䀗" */
+0x00,0x00,0x78,0x4b,0x48,0x78,0x48,0x48,0x7b,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 16408 0x4018 "䀘" */
+0x00,0x03,0x78,0x48,0x48,0x78,0x48,0x4f,0x78,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x90,0x10,0x10,0x10,0x10,
+/* 16409 0x4019 "䀙" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x4f,0x79,0x49,0x49,0x49,0x79,0x48,0x00,0x00,
+0x00,0x00,0x7e,0x12,0x12,0x12,0xd2,0x12,0x12,0x12,0x52,0x92,0x22,0x22,0x4a,0x84,
+/* 16410 0x401a "䀚" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x0c,0x70,0x40,0x40,0x4c,0x70,0x40,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xfc,0x84,0x84,0x84,0x94,0x88,0x80,
+/* 16411 0x401b "䀛" */
+0x01,0x01,0x79,0x49,0x4a,0x7c,0x48,0x49,0x79,0x4a,0x4c,0x48,0x79,0x4a,0x04,0x00,
+0x00,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 16412 0x401c "䀜" */
+0x08,0x08,0x1f,0x22,0x44,0x08,0x11,0x22,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0x00,0xf8,0x48,0x48,0x88,0x28,0x10,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16413 0x401d "䀝" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 16414 0x401e "䀞" */
+0x00,0x01,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7c,0x44,0x47,0x44,0x7c,0x44,0x00,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 16415 0x401f "䀟" */
+0x00,0x00,0x78,0x4b,0x48,0x78,0x4b,0x4a,0x7a,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 16416 0x4020 "䀠" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 16417 0x4021 "䀡" */
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16418 0x4022 "䀢" */
+0x00,0x00,0x78,0x48,0x49,0x7a,0x48,0x48,0x7b,0x48,0x48,0x48,0x78,0x48,0x01,0x02,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 16419 0x4023 "䀣" */
+0x00,0x00,0x78,0x48,0x48,0x78,0x48,0x4a,0x7a,0x4a,0x4c,0x48,0x79,0x4a,0x04,0x00,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 16420 0x4024 "䀤" */
+0x10,0x10,0x3f,0x41,0xa2,0x14,0x08,0x30,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0x30,0x28,0x24,0x22,0x20,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16421 0x4025 "䀥" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7c,0x44,0x44,0x44,0x7d,0x46,0x00,0x00,
+0x08,0x1c,0xe0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 16422 0x4026 "䀦" */
+0x00,0x00,0x78,0x48,0x4b,0x78,0x48,0x48,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16423 0x4027 "䀧" */
+0x01,0x01,0x79,0x49,0x4b,0x79,0x49,0x49,0x79,0x4f,0x48,0x49,0x79,0x4a,0x04,0x08,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 16424 0x4028 "䀨" */
+0x00,0x00,0x79,0x48,0x48,0x7b,0x48,0x48,0x78,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16425 0x4029 "䀩" */
+0x00,0x00,0x78,0x49,0x4b,0x7c,0x48,0x48,0x79,0x4a,0x4d,0x49,0x79,0x49,0x01,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 16426 0x402a "䀪" */
+0x00,0x00,0x79,0x4a,0x4c,0x78,0x49,0x4b,0x7d,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 16427 0x402b "䀫" */
+0x00,0x00,0x78,0x49,0x4a,0x7c,0x4b,0x48,0x78,0x4b,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 16428 0x402c "䀬" */
+0x00,0x00,0x78,0x49,0x4a,0x7c,0x4b,0x48,0x78,0x48,0x4b,0x48,0x78,0x48,0x07,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 16429 0x402d "䀭" */
+0x00,0x00,0x7c,0x45,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x45,0x7c,0x44,0x00,0x01,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 16430 0x402e "䀮" */
+0x00,0x00,0x7b,0x49,0x49,0x79,0x49,0x48,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x80,0x40,0xfc,0x00,0x00,0x00,0xf8,0x00,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 16431 0x402f "䀯" */
+0x00,0x00,0x7b,0x48,0x48,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x02,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 16432 0x4030 "䀰" */
+0x00,0x78,0x49,0x4a,0x48,0x78,0x48,0x49,0x7a,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x88,0x84,0x02,0x22,0x20,0x50,0x88,0x04,0x02,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16433 0x4031 "䀱" */
+0x00,0x00,0x79,0x49,0x4a,0x78,0x49,0x4e,0x79,0x48,0x49,0x48,0x7f,0x48,0x00,0x00,
+0x80,0x80,0xf8,0x10,0xa0,0x40,0xb0,0x4e,0xf0,0x40,0xf0,0x40,0xfc,0x40,0x40,0x40,
+/* 16434 0x4032 "䀲" */
+0x01,0x01,0x79,0x4a,0x4d,0x79,0x49,0x49,0x7b,0x49,0x4a,0x4a,0x7b,0x48,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 16435 0x4033 "䀳" */
+0x00,0x00,0x7b,0x48,0x48,0x79,0x49,0x49,0x79,0x48,0x48,0x48,0x79,0x4a,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 16436 0x4034 "䀴" */
+0x00,0x03,0x78,0x49,0x4a,0x7c,0x4a,0x49,0x78,0x4b,0x48,0x48,0x78,0x48,0x07,0x00,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 16437 0x4035 "䀵" */
+0x00,0x00,0x78,0x49,0x4b,0x78,0x48,0x49,0x7a,0x48,0x4b,0x48,0x78,0x48,0x01,0x06,
+0x20,0x40,0x88,0x04,0xfe,0x82,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 16438 0x4036 "䀶" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x80,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 16439 0x4037 "䀷" */
+0x00,0x00,0x78,0x49,0x48,0x78,0x48,0x4b,0x78,0x48,0x49,0x49,0x7b,0x49,0x00,0x00,
+0x88,0x88,0x88,0xc8,0x9e,0x8a,0x8a,0xea,0x8a,0x8a,0x0a,0x4a,0xea,0x12,0x2a,0x44,
+/* 16440 0x4038 "䀸" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16441 0x4039 "䀹" */
+0x00,0x00,0x78,0x4b,0x48,0x78,0x49,0x49,0x79,0x4a,0x48,0x48,0x78,0x48,0x01,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 16442 0x403a "䀺" */
+0x10,0x20,0x69,0xaa,0x28,0x28,0x23,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x80,0xfc,0x10,0x90,0x60,0x90,0x0c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16443 0x403b "䀻" */
+0x00,0x00,0x79,0x49,0x49,0x79,0x49,0x48,0x7b,0x48,0x49,0x49,0x78,0x48,0x00,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 16444 0x403c "䀼" */
+0x00,0x03,0x7a,0x4a,0x4a,0x7a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x7a,0x4c,0x04,0x08,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 16445 0x403d "䀽" */
+0x00,0x00,0x7b,0x48,0x48,0x79,0x49,0x4b,0x78,0x4a,0x4a,0x49,0x79,0x4a,0x04,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 16446 0x403e "䀾" */
+0x00,0xfe,0x10,0x20,0x7e,0xa2,0x3e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16447 0x403f "䀿" */
+0x01,0x01,0xf1,0x91,0x97,0xf1,0x91,0x91,0xf1,0x97,0x91,0x91,0xf1,0x91,0x05,0x02,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 16448 0x4040 "䁀" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,
+/* 16449 0x4041 "䁁" */
+0x00,0x00,0x7b,0x48,0x48,0x79,0x49,0x49,0x79,0x49,0x48,0x48,0x79,0x4a,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 16450 0x4042 "䁂" */
+0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16451 0x4043 "䁃" */
+0x00,0x00,0x7b,0x48,0x48,0x79,0x48,0x48,0x7b,0x48,0x48,0x49,0x7a,0x4c,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 16452 0x4044 "䁄" */
+0x00,0x00,0x79,0x48,0x48,0x7b,0x48,0x48,0x79,0x48,0x48,0x4b,0x78,0x48,0x00,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x50,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16453 0x4045 "䁅" */
+0x00,0x01,0x78,0x48,0x48,0x7b,0x48,0x48,0x78,0x49,0x49,0x49,0x79,0x49,0x07,0x00,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 16454 0x4046 "䁆" */
+0x00,0x00,0x7b,0x49,0x4a,0x7c,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x7b,0x48,0x00,0x00,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 16455 0x4047 "䁇" */
+0x02,0x01,0x7f,0x42,0xa9,0x49,0x0e,0x77,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0x00,0xfe,0x02,0x6c,0x94,0x10,0xf0,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16456 0x4048 "䁈" */
+0x10,0x08,0x3e,0x22,0x23,0x3e,0x20,0x41,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x88,0x50,0x20,0x58,0x86,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16457 0x4049 "䁉" */
+0x10,0x08,0x3e,0x23,0x22,0x3e,0x22,0x20,0x41,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x48,0x44,0x7e,0xc0,0x24,0x28,0x12,0x6a,0x86,0xf2,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16458 0x404a "䁊" */
+0x00,0x03,0x79,0x49,0x48,0x78,0x49,0x4e,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xf8,0x48,0x10,0xa0,0x40,0xb0,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 16459 0x404b "䁋" */
+0x00,0x01,0x79,0x4b,0x49,0x79,0x49,0x49,0x79,0x48,0x4b,0x48,0x78,0x49,0x06,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16460 0x404c "䁌" */
+0x00,0x03,0x7a,0x4b,0x4a,0x7b,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 16461 0x404d "䁍" */
+0x00,0x00,0xf0,0x97,0x94,0xf4,0x95,0x94,0xf4,0x95,0x95,0x95,0xf5,0x94,0x08,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 16462 0x404e "䁎" */
+0x00,0x00,0x7b,0x48,0x49,0x79,0x49,0x48,0x7b,0x4a,0x49,0x48,0x78,0x48,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 16463 0x404f "䁏" */
+0x00,0x03,0x78,0x48,0x4b,0x7a,0x4a,0x4b,0x78,0x48,0x4f,0x48,0x79,0x48,0x00,0x03,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 16464 0x4050 "䁐" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x49,0x49,0x79,0x49,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 16465 0x4051 "䁑" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x48,0x4b,0x79,0x49,0x4a,0x4c,0x79,0x4a,0x00,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 16466 0x4052 "䁒" */
+0x00,0x01,0x79,0x49,0x49,0x78,0x4f,0x49,0x79,0x49,0x49,0x49,0x79,0x4f,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 16467 0x4053 "䁓" */
+0x00,0x00,0x7a,0x4a,0x4a,0x7a,0x4a,0x4b,0x78,0x49,0x4a,0x48,0x79,0x48,0x00,0x07,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 16468 0x4054 "䁔" */
+0x00,0x03,0x78,0x49,0x48,0x79,0x48,0x48,0x7b,0x48,0x48,0x49,0x79,0x4a,0x00,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 16469 0x4055 "䁕" */
+0x00,0x03,0x7a,0x4b,0x4a,0x7b,0x4a,0x4a,0x7b,0x48,0x4b,0x4a,0x7b,0x4a,0x03,0x02,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16470 0x4056 "䁖" */
+0x00,0x01,0x78,0x48,0x4b,0x78,0x49,0x4a,0x78,0x4b,0x48,0x49,0x79,0x48,0x01,0x06,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 16471 0x4057 "䁗" */
+0x00,0x01,0x79,0x49,0x49,0x78,0x4b,0x48,0x79,0x49,0x49,0x49,0x78,0x48,0x03,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 16472 0x4058 "䁘" */
+0x00,0x00,0x7b,0x48,0x4a,0x79,0x49,0x4a,0x78,0x4b,0x48,0x49,0x79,0x49,0x01,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 16473 0x4059 "䁙" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x48,0x4b,0x7a,0x48,0x4b,0x48,0x79,0x48,0x00,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x02,0x40,0xfe,0x88,0x90,0x60,0x98,0x04,
+/* 16474 0x405a "䁚" */
+0x00,0x01,0x79,0x49,0x49,0x78,0x4b,0x4a,0x7b,0x4a,0x4b,0x4a,0x7b,0x48,0x01,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 16475 0x405b "䁛" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 16476 0x405c "䁜" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x44,0x45,0x7c,0x44,0x47,0x44,0x7c,0x45,0x02,0x04,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 16477 0x405d "䁝" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16478 0x405e "䁞" */
+0x08,0x14,0x22,0x08,0x14,0x22,0xff,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x0f,0x08,
+0x20,0x50,0x88,0x20,0x50,0x88,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16479 0x405f "䁟" */
+0x01,0x00,0x78,0x4b,0x48,0x79,0x48,0x4b,0x78,0x49,0x49,0x4a,0x7c,0x48,0x03,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 16480 0x4060 "䁠" */
+0x01,0x00,0x78,0x4f,0x48,0x7b,0x48,0x4f,0x78,0x4b,0x48,0x49,0x7a,0x4c,0x00,0x00,
+0x10,0xa0,0x00,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 16481 0x4061 "䁡" */
+0x00,0x03,0x7a,0x4b,0x4a,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x0a,0x04,
+/* 16482 0x4062 "䁢" */
+0x02,0x01,0xf1,0x97,0x92,0xf2,0x93,0x92,0xf2,0x92,0x92,0x92,0xf4,0x95,0x08,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 16483 0x4063 "䁣" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x49,0x78,0x4b,0x48,0x4b,0x79,0x48,0x00,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 16484 0x4064 "䁤" */
+0x00,0x00,0x7b,0x48,0x48,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 16485 0x4065 "䁥" */
+0x00,0x03,0x7a,0x4a,0x4b,0x7a,0x4a,0x4b,0x7a,0x4a,0x4b,0x4a,0x7a,0x4a,0x03,0x00,
+0x00,0xfe,0x48,0x48,0xfe,0x48,0x20,0xfe,0x40,0xfc,0x44,0x44,0x7c,0x00,0xfe,0x00,
+/* 16486 0x4066 "䁦" */
+0x00,0x00,0x78,0x4b,0x4a,0x7a,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4c,0x04,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfe,
+/* 16487 0x4067 "䁧" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x49,0x49,0x79,0x48,0x49,0x48,0x7b,0x48,0x00,0x03,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,
+/* 16488 0x4068 "䁨" */
+0x02,0x01,0xf7,0x90,0x97,0xf4,0x97,0x90,0xf7,0x90,0x91,0x91,0xf7,0x91,0x05,0x02,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 16489 0x4069 "䁩" */
+0x00,0x00,0x78,0x49,0x4a,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x78,0x49,0x01,0x02,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x54,0x2a,0x2a,
+/* 16490 0x406a "䁪" */
+0x02,0x02,0xe2,0xaf,0xa2,0xef,0xaa,0xaf,0xea,0xaf,0xa2,0xaf,0xe2,0xa2,0x02,0x02,
+0x00,0x02,0x3c,0xa0,0x20,0xa0,0xbe,0xa4,0xa4,0xa4,0x24,0xa4,0x24,0x44,0x44,0x84,
+/* 16491 0x406b "䁫" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x48,0x79,0x48,0x4b,0x48,0x7a,0x4a,0x04,0x00,
+0x00,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 16492 0x406c "䁬" */
+0x01,0x00,0x78,0x4b,0x4a,0x7a,0x4a,0x4a,0x7b,0x48,0x49,0x49,0x79,0x49,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16493 0x406d "䁭" */
+0x00,0x00,0x7b,0x48,0x48,0x79,0x4a,0x49,0x79,0x49,0x4b,0x49,0x7a,0x4a,0x04,0x08,
+0x28,0x24,0xfe,0x50,0x88,0x04,0x02,0x98,0x54,0x10,0xbe,0x10,0xa8,0xa8,0x44,0x82,
+/* 16494 0x406e "䁮" */
+0x00,0x07,0xf1,0x95,0x97,0xf3,0x95,0x99,0xf0,0x93,0x92,0x92,0xf3,0x92,0x02,0x03,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 16495 0x406f "䁯" */
+0x00,0x00,0xf1,0x96,0x90,0xf3,0x92,0x93,0xf0,0x97,0x90,0x94,0xf2,0x94,0x02,0x01,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 16496 0x4070 "䁰" */
+0x00,0x00,0xf0,0x97,0x92,0xf2,0x92,0x92,0xf2,0x92,0x93,0x9e,0xf0,0x90,0x00,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0xc4,0x44,0x7c,0x28,0x44,0x82,
+/* 16497 0x4071 "䁱" */
+0x00,0x00,0x79,0x48,0x4b,0x79,0x4b,0x49,0x79,0x4e,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 16498 0x4072 "䁲" */
+0x00,0x03,0x7a,0x4a,0x4b,0x78,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x48,0x01,0x02,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 16499 0x4073 "䁳" */
+0x00,0x00,0x7b,0x48,0x48,0x7b,0x48,0x48,0x79,0x4a,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x24,0xfe,0x50,0x88,0x04,0x8a,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 16500 0x4074 "䁴" */
+0x00,0x0f,0xf0,0x97,0x94,0xf5,0x95,0x97,0xf0,0x93,0x92,0x93,0xf2,0x93,0x00,0x0f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 16501 0x4075 "䁵" */
+0x00,0x01,0x79,0x49,0x49,0x78,0x4b,0x48,0x79,0x49,0x49,0x48,0x78,0x49,0x02,0x00,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 16502 0x4076 "䁶" */
+0x01,0x02,0xf7,0x94,0x97,0xf4,0x97,0x92,0xf1,0x97,0x92,0x93,0xf2,0x94,0x05,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 16503 0x4077 "䁷" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16504 0x4078 "䁸" */
+0x00,0x03,0xf2,0x93,0x92,0xf3,0x90,0x93,0xf2,0x92,0x92,0x93,0xf5,0x95,0x05,0x09,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 16505 0x4079 "䁹" */
+0x00,0x03,0x7a,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x4a,0x4e,0x4a,0x7a,0x4b,0x02,0x00,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 16506 0x407a "䁺" */
+0x00,0x01,0x79,0x49,0x48,0x79,0x48,0x4b,0x78,0x48,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 16507 0x407b "䁻" */
+0x04,0x04,0xe8,0xaa,0xae,0xe4,0xaa,0xae,0xe2,0xa0,0xaf,0xa0,0xe1,0xa2,0x0c,0x00,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 16508 0x407c "䁼" */
+0x01,0x79,0x49,0x49,0x49,0x78,0x49,0x48,0x7b,0x49,0x4a,0x48,0x79,0x48,0x03,0x00,
+0xfc,0x24,0xac,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,0x20,0xfc,0x20,0xfe,0x00,
+/* 16509 0x407d "䁽" */
+0x01,0x02,0x79,0x48,0x4b,0x7a,0x4a,0x4a,0x7b,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 16510 0x407e "䁾" */
+0x01,0x07,0x79,0x48,0x4b,0x7a,0x4a,0x4b,0x78,0x4b,0x4a,0x4b,0x7a,0x4a,0x04,0x08,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 16511 0x407f "䁿" */
+0x7f,0x6b,0x5d,0x7f,0x08,0x7f,0x08,0xff,0x55,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x14,0x12,0x10,0x7e,0x10,0x10,0x28,0xa8,0x44,0xf2,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16512 0x4080 "䂀" */
+0x01,0x07,0xf0,0x93,0x90,0xf7,0x90,0x93,0xf1,0x97,0x93,0x95,0xf3,0x90,0x02,0x01,
+0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xd4,0x12,0xfe,0x50,0x34,0x8c,0x8a,0x96,0x02,
+/* 16513 0x4081 "䂁" */
+0x01,0x02,0xf7,0x92,0x93,0xf2,0x93,0x92,0xf1,0x92,0x97,0x92,0xf3,0x90,0x01,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 16514 0x4082 "䂂" */
+0x07,0x04,0xf7,0x94,0x97,0xf4,0x97,0x91,0xf3,0x92,0x97,0x9a,0xf3,0x92,0x03,0x02,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 16515 0x4083 "䂃" */
+0x00,0x07,0xf2,0x91,0x97,0xf4,0x97,0x90,0xf7,0x94,0x97,0x94,0xf7,0x95,0x05,0x06,
+0x3c,0xc0,0x44,0x28,0xfc,0xa4,0xfc,0x08,0x88,0xfe,0x88,0xa8,0x98,0x08,0xa8,0x90,
+/* 16516 0x4084 "䂄" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x78,0x49,0x4b,0x7d,0x49,0x49,0x48,0x79,0x48,0x00,0x07,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 16517 0x4085 "䂅" */
+0x04,0x04,0xea,0xae,0xa4,0xea,0xae,0xa0,0xea,0xaa,0xa0,0xa7,0xe4,0xa7,0x00,0x0f,
+0x44,0xe4,0x0a,0xee,0x04,0xea,0x0e,0xe0,0xaa,0xea,0x40,0xfc,0x44,0xfc,0x44,0xfe,
+/* 16518 0x4086 "䂆" */
+0x00,0x7c,0x04,0x28,0x10,0x08,0xff,0x1a,0x28,0x28,0x48,0x48,0x88,0x08,0x28,0x10,
+0x40,0x40,0x40,0x7c,0x84,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 16519 0x4087 "䂇" */
+0x00,0x7c,0x04,0x28,0x10,0x08,0xfe,0x1a,0x28,0x28,0x48,0x48,0x88,0x08,0x29,0x10,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0xfe,0x00,
+/* 16520 0x4088 "䂈" */
+0x00,0x7c,0x04,0x28,0x10,0x08,0xfe,0x1a,0x28,0x28,0x48,0x48,0x88,0x09,0x28,0x10,
+0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x10,0x14,0x12,0xfe,0x82,0x00,
+/* 16521 0x4089 "䂉" */
+0x00,0xf8,0x08,0x51,0x21,0x13,0xfd,0x35,0x31,0x51,0x51,0x51,0x91,0x11,0x51,0x21,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 16522 0x408a "䂊" */
+0x00,0xf8,0x09,0x53,0x25,0x11,0xfd,0x34,0x30,0x53,0x50,0x53,0x90,0x10,0x53,0x20,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 16523 0x408b "䂋" */
+0x10,0x10,0xfe,0x10,0x7d,0x44,0x7c,0x11,0x12,0x7c,0x11,0x50,0x7c,0x11,0x12,0x10,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16524 0x408c "䂌" */
+0x00,0xf9,0x08,0x50,0x23,0x10,0xfd,0x35,0x31,0x51,0x51,0x50,0x91,0x10,0x53,0x20,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 16525 0x408d "䂍" */
+0x01,0xf9,0x09,0x51,0x21,0x10,0xfd,0x34,0x33,0x50,0x51,0x52,0x90,0x10,0x51,0x20,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 16526 0x408e "䂎" */
+0x05,0xff,0x09,0x57,0x23,0x15,0xfd,0x37,0x32,0x53,0x52,0x53,0x92,0x13,0x51,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 16527 0x408f "䂏" */
+0x20,0x21,0x3c,0x50,0x90,0x10,0x10,0xfe,0x11,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 16528 0x4090 "䂐" */
+0x20,0x20,0x21,0x7d,0x51,0x91,0x11,0xfc,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 16529 0x4091 "䂑" */
+0x20,0x20,0x20,0x7d,0x51,0x91,0x11,0xfd,0x11,0x11,0x11,0x29,0x25,0x47,0x41,0x80,
+0x48,0x48,0x48,0x48,0x4a,0x6c,0x48,0x48,0x48,0x48,0x48,0x4a,0x6a,0x8a,0x06,0x00,
+/* 16530 0x4092 "䂒" */
+0x20,0x20,0x3c,0x53,0x90,0x10,0x11,0xfe,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16531 0x4093 "䂓" */
+0x20,0x21,0x21,0x7d,0x51,0x91,0x11,0xfd,0x11,0x11,0x11,0x28,0x24,0x44,0x41,0x82,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 16532 0x4094 "䂔" */
+0x20,0x20,0x21,0x7c,0x50,0x93,0x10,0xfc,0x11,0x10,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x50,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16533 0x4095 "䂕" */
+0x20,0x20,0x21,0x7d,0x50,0x93,0x10,0xfc,0x13,0x10,0x10,0x2b,0x24,0x44,0x43,0x80,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 16534 0x4096 "䂖" */
+0x00,0xff,0x02,0x02,0x04,0x04,0x08,0x0f,0x18,0x28,0x48,0x88,0x08,0x08,0x0f,0x08,
+0x00,0xfe,0x00,0x10,0x08,0x04,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 16535 0x4097 "䂗" */
+0x00,0x00,0xfe,0x10,0x10,0x20,0x3e,0x62,0x62,0xa2,0x23,0x22,0x3e,0x22,0x00,0x00,
+0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x60,0x40,0xc0,0x40,0x44,0x44,0x44,0x3c,0x00,
+/* 16536 0x4098 "䂘" */
+0x00,0x03,0xfd,0x11,0x11,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x21,0x06,
+0x00,0xfc,0x04,0x44,0x24,0xa8,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 16537 0x4099 "䂙" */
+0x00,0x00,0xfe,0x10,0x10,0x20,0x3e,0x62,0x62,0xa2,0x22,0x22,0x3e,0x22,0x00,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 16538 0x409a "䂚" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3d,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x03,
+0x08,0x88,0x50,0x20,0x50,0x88,0x00,0x08,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 16539 0x409b "䂛" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3d,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 16540 0x409c "䂜" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3c,0x65,0x64,0xa4,0x24,0x27,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16541 0x409d "䂝" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x50,0x48,0x48,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 16542 0x409e "䂞" */
+0x00,0xff,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 16543 0x409f "䂟" */
+0x08,0x08,0x7f,0x09,0x11,0x11,0x25,0x42,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 16544 0x40a0 "䂠" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x67,0xa4,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 16545 0x40a1 "䂡" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x21,0x00,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 16546 0x40a2 "䂢" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x64,0xa7,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 16547 0x40a3 "䂣" */
+0x00,0x00,0xf8,0x22,0x22,0x42,0x7a,0xca,0x4a,0x4a,0x4a,0x4a,0x7a,0x47,0x02,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 16548 0x40a4 "䂤" */
+0x00,0x00,0xfc,0x11,0x11,0x23,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 16549 0x40a5 "䂥" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 16550 0x40a6 "䂦" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3d,0x24,0x20,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 16551 0x40a7 "䂧" */
+0x00,0x00,0xfc,0x11,0x11,0x22,0x3c,0x64,0x65,0xa5,0x26,0x26,0x3c,0x24,0x20,0x00,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 16552 0x40a8 "䂨" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 16553 0x40a9 "䂩" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 16554 0x40aa "䂪" */
+0x00,0x00,0xfc,0x12,0x11,0x20,0x3c,0x65,0x66,0xa4,0x24,0x24,0x3d,0x25,0x22,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 16555 0x40ab "䂫" */
+0x00,0x00,0xf8,0x21,0x22,0x40,0x79,0x4e,0xc8,0x49,0x48,0x4a,0x7b,0x48,0x00,0x00,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 16556 0x40ac "䂬" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 16557 0x40ad "䂭" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3d,0x66,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 16558 0x40ae "䂮" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x08,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 16559 0x40af "䂯" */
+0x00,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 16560 0x40b0 "䂰" */
+0x00,0x00,0xfb,0x20,0x20,0x40,0x7b,0x48,0xc9,0x49,0x4a,0x4a,0x7c,0x48,0x00,0x00,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 16561 0x40b1 "䂱" */
+0x01,0x00,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa4,0x24,0x24,0x3c,0x25,0x22,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 16562 0x40b2 "䂲" */
+0x08,0x7e,0x08,0xff,0x10,0x24,0x7e,0x22,0x01,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x20,0x20,0xfc,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 16563 0x40b3 "䂳" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x64,0x64,0xa5,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x20,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 16564 0x40b4 "䂴" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 16565 0x40b5 "䂵" */
+0x00,0x01,0xfc,0x10,0x13,0x20,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3d,0x24,0x21,0x06,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x24,0x24,0x24,0x54,0x88,0x04,0x02,
+/* 16566 0x40b6 "䂶" */
+0x00,0x00,0xf8,0x21,0x20,0x40,0x78,0x4b,0xc8,0x48,0x49,0x49,0x7b,0x49,0x00,0x00,
+0x88,0x88,0x88,0xc8,0x9e,0x8a,0x8a,0xea,0x8a,0x8a,0x0a,0x4a,0xea,0x12,0x2a,0x44,
+/* 16567 0x40b7 "䂷" */
+0x00,0x01,0xfc,0x10,0x13,0x20,0x3c,0x64,0x67,0xa4,0x24,0x25,0x3e,0x24,0x20,0x00,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0xa8,0xaa,0xac,0xa8,0xaa,0xaa,0xa6,0x20,0x20,0x20,
+/* 16568 0x40b8 "䂸" */
+0x00,0x00,0xf8,0x27,0x20,0x40,0x7b,0xca,0x4a,0x4a,0x4b,0x48,0x78,0x47,0x02,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 16569 0x40b9 "䂹" */
+0x00,0x00,0xfc,0x11,0x12,0x20,0x3c,0x67,0x64,0xa4,0x24,0x24,0x3d,0x24,0x20,0x03,
+0x20,0x40,0xfe,0x24,0x98,0x50,0x60,0x80,0x20,0x24,0xa4,0xa8,0x30,0x50,0x88,0x06,
+/* 16570 0x40ba "䂺" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x64,0xa7,0x24,0x24,0x3d,0x22,0x00,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 16571 0x40bb "䂻" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x67,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 16572 0x40bc "䂼" */
+0x00,0x00,0xf8,0x20,0x21,0x42,0x79,0x48,0xc8,0x48,0x48,0x4a,0x7a,0x4a,0x04,0x00,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 16573 0x40bd "䂽" */
+0x00,0x00,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x24,0x27,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16574 0x40be "䂾" */
+0x00,0x00,0xf8,0x23,0x20,0x41,0x79,0x49,0xca,0x48,0x48,0x48,0x79,0x4a,0x04,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 16575 0x40bf "䂿" */
+0x00,0x00,0xfb,0x20,0x20,0x41,0x7a,0x48,0xc9,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16576 0x40c0 "䃀" */
+0x00,0x00,0xfb,0x20,0x21,0x40,0x7b,0x48,0xc9,0x48,0x4b,0x48,0x79,0x48,0x00,0x03,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x40,0xfe,0x84,0xc8,0x30,0xcc,0x02,
+/* 16577 0x40c1 "䃁" */
+0x00,0x01,0xfc,0x10,0x10,0x21,0x3d,0x65,0x65,0xa5,0x24,0x24,0x3c,0x24,0x21,0x00,
+0x00,0xfe,0x48,0x48,0x48,0xce,0x02,0x02,0x02,0xce,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 16578 0x40c2 "䃂" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x64,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 16579 0x40c3 "䃃" */
+0x00,0x03,0xfa,0x22,0x22,0x43,0x7a,0x4a,0xcb,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 16580 0x40c4 "䃄" */
+0x00,0x00,0xfb,0x20,0x20,0x41,0x79,0x49,0xc9,0x49,0x48,0x48,0x79,0x4a,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 16581 0x40c5 "䃅" */
+0x01,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x24,0x24,0x3d,0x24,0x20,0x00,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 16582 0x40c6 "䃆" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x25,0x3c,0x24,0x20,0x01,
+0x84,0x84,0xfe,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfe,0x00,0x48,0x84,0x02,
+/* 16583 0x40c7 "䃇" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa5,0x25,0x25,0x3d,0x25,0x20,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 16584 0x40c8 "䃈" */
+0x01,0x01,0xfd,0x11,0x11,0x21,0x3d,0x64,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16585 0x40c9 "䃉" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa4,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16586 0x40ca "䃊" */
+0x00,0x00,0xfb,0x20,0x20,0x41,0x79,0x49,0xc9,0x49,0x49,0x49,0x79,0x49,0x07,0x00,
+0x90,0x90,0xfc,0x90,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 16587 0x40cb "䃋" */
+0x00,0x00,0xf9,0x22,0x25,0x40,0x7b,0x4a,0xca,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 16588 0x40cc "䃌" */
+0x00,0x03,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa4,0x24,0x25,0x3c,0x24,0x23,0x00,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16589 0x40cd "䃍" */
+0x01,0x00,0xf8,0x23,0x20,0x40,0x79,0xca,0x48,0x49,0x4a,0x48,0x79,0x46,0x00,0x00,
+0x04,0x88,0x00,0xfe,0x40,0xc2,0x22,0x54,0x98,0x38,0x54,0x94,0x12,0x10,0x50,0x20,
+/* 16590 0x40ce "䃎" */
+0x00,0x00,0xfb,0x20,0x21,0x46,0x78,0x4b,0xc8,0x48,0x4f,0x48,0x7b,0x48,0x00,0x07,
+0x00,0x40,0xfe,0x88,0x04,0x42,0xfc,0x08,0xb0,0xd0,0x3e,0xc2,0x24,0x18,0x60,0x80,
+/* 16591 0x40cf "䃏" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3c,0x65,0x65,0xa6,0x24,0x25,0x3c,0x24,0x23,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16592 0x40d0 "䃐" */
+0x00,0x00,0xfb,0x22,0x20,0x41,0x7a,0x48,0xc8,0x4b,0x48,0x48,0x78,0x48,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 16593 0x40d1 "䃑" */
+0x01,0x02,0xf7,0x24,0x26,0x45,0x74,0xdf,0x54,0x54,0x56,0x55,0x74,0x54,0x04,0x09,
+0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xc2,0x80,0xbc,0xa4,0xa4,0xa4,0x94,0x88,0x94,0xa2,
+/* 16594 0x40d2 "䃒" */
+0x00,0x03,0xf8,0x21,0x21,0x41,0x79,0x48,0xcb,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 16595 0x40d3 "䃓" */
+0x00,0x00,0xfb,0x20,0x21,0x40,0x7b,0x48,0xc9,0x49,0x49,0x49,0x7b,0x49,0x01,0x01,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 16596 0x40d4 "䃔" */
+0x00,0x00,0xfd,0x11,0x10,0x20,0x3c,0x64,0x64,0xa4,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x10,0xfe,0x02,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0x02,0xfe,0x02,
+/* 16597 0x40d5 "䃕" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x80,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 16598 0x40d6 "䃖" */
+0x00,0x00,0xf9,0x21,0x21,0x41,0x79,0xc9,0x49,0x49,0x48,0x4a,0x7a,0x44,0x00,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 16599 0x40d7 "䃗" */
+0x00,0x03,0xf8,0x21,0x20,0x47,0x78,0x4a,0xc9,0x48,0x49,0x4a,0x7c,0x48,0x02,0x01,
+0x02,0xe2,0x22,0xea,0x2a,0xfa,0x8a,0xaa,0xca,0x8a,0xca,0xa2,0x92,0x82,0x8a,0x04,
+/* 16600 0x40d8 "䃘" */
+0x00,0x03,0xfa,0x23,0x22,0x43,0x7a,0x4a,0xcb,0x48,0x48,0x49,0x78,0x48,0x03,0x00,
+0x00,0xdc,0x94,0xd4,0x54,0xc8,0x88,0x94,0xe2,0x00,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16601 0x40d9 "䃙" */
+0x00,0x00,0xfb,0x22,0x22,0x43,0x7a,0xca,0x4b,0x4a,0x4a,0x4a,0x7a,0x44,0x04,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 16602 0x40da "䃚" */
+0x04,0x02,0xf2,0x2f,0x24,0x44,0x77,0xd5,0x55,0x55,0x55,0x55,0x75,0x59,0x0b,0x10,
+0x20,0x20,0x3e,0x40,0xa0,0x20,0x3c,0x50,0x10,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 16603 0x40db "䃛" */
+0x00,0x00,0xfa,0x21,0x21,0x40,0x78,0x4b,0xc9,0x49,0x49,0x49,0x79,0x4a,0x04,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 16604 0x40dc "䃜" */
+0x00,0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x00,0x7f,0x08,0x1f,0x68,0x0f,
+0x00,0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0xfc,0x00,0xf8,0x08,0xf8,
+/* 16605 0x40dd "䃝" */
+0x02,0x02,0xf7,0x22,0x22,0x4f,0x71,0xd2,0x5f,0x54,0x59,0x51,0x7f,0x51,0x05,0x02,
+0x08,0x48,0x48,0x90,0x9e,0xe4,0x14,0x14,0xd4,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 16606 0x40de "䃞" */
+0x08,0x7f,0x22,0x3e,0x00,0x3e,0x04,0x7e,0x08,0x29,0x12,0x7f,0x08,0x1f,0x68,0x0f,
+0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0xfc,0x00,0xf8,0x08,0xf8,
+/* 16607 0x40df "䃟" */
+0x02,0x02,0xf7,0x22,0x22,0x4f,0x70,0xd7,0x54,0x57,0x54,0x57,0x74,0x54,0x04,0x04,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 16608 0x40e0 "䃠" */
+0x02,0x01,0xf1,0x27,0x22,0x42,0x73,0xd2,0x52,0x52,0x52,0x52,0x74,0x55,0x08,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 16609 0x40e1 "䃡" */
+0x00,0x03,0xf8,0x22,0x23,0x41,0x7a,0x4c,0xc9,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16610 0x40e2 "䃢" */
+0x02,0x02,0xf5,0x24,0x28,0x47,0x72,0xd2,0x5f,0x52,0x5a,0x57,0x72,0x53,0x0c,0x00,
+0x10,0x10,0x10,0xbe,0x22,0x44,0x10,0x10,0x10,0x10,0xa8,0x28,0x28,0x44,0x44,0x82,
+/* 16611 0x40e3 "䃣" */
+0x00,0x03,0xf8,0x22,0x21,0x43,0x7a,0xcb,0x4a,0x4b,0x4a,0x4a,0x7a,0x45,0x04,0x08,
+0x0e,0xf0,0x44,0x24,0x08,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 16612 0x40e4 "䃤" */
+0x00,0x03,0xf0,0x27,0x20,0x43,0x70,0xd5,0x57,0x54,0x57,0x54,0x77,0x55,0x05,0x08,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 16613 0x40e5 "䃥" */
+0x00,0x01,0xfc,0x10,0x13,0x20,0x3d,0x65,0x65,0xa5,0x25,0x24,0x3d,0x24,0x23,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 16614 0x40e6 "䃦" */
+0x08,0x7f,0x22,0x3e,0x01,0x3e,0x04,0x7e,0x08,0x28,0x10,0x7f,0x08,0x1f,0x68,0x0f,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0x00,0xfc,0x00,0xf8,0x08,0xf8,
+/* 16615 0x40e7 "䃧" */
+0x00,0x79,0x4a,0x48,0x53,0x49,0x49,0x6a,0x50,0x40,0xff,0x04,0x0f,0x38,0xcf,0x08,
+0x80,0xf8,0x88,0x70,0x8e,0x20,0xfc,0x20,0xf8,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,
+/* 16616 0x40e8 "䃨" */
+0x00,0x03,0xf8,0x20,0x20,0x43,0x7a,0xca,0x4a,0x4b,0x48,0x48,0x78,0x40,0x05,0x02,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 16617 0x40e9 "䃩" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x02,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfe,0x00,0x7c,0x00,0xfe,0x50,0x54,0x48,0x66,
+/* 16618 0x40ea "䃪" */
+0x00,0x03,0xf8,0x23,0x22,0x42,0x7a,0x4b,0xc8,0x49,0x49,0x49,0x79,0x49,0x00,0x03,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 16619 0x40eb "䃫" */
+0x01,0x01,0xfa,0x27,0x22,0x43,0x7b,0xca,0x4a,0x4a,0x4a,0x4a,0x7a,0x44,0x04,0x08,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 16620 0x40ec "䃬" */
+0x00,0x02,0xfa,0x23,0x20,0x43,0x7a,0x4b,0xca,0x4b,0x48,0x48,0x78,0x49,0x02,0x04,
+0x40,0x48,0x48,0xf8,0x80,0xf8,0x48,0xf8,0x48,0xf8,0x48,0xb4,0xbc,0x22,0x22,0x1e,
+/* 16621 0x40ed "䃭" */
+0x00,0x00,0xf7,0x24,0x25,0x44,0x75,0xd5,0x55,0x54,0x54,0x58,0x72,0x52,0x04,0x00,
+0x14,0x12,0xfe,0x10,0xd0,0x14,0xd4,0x58,0xca,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 16622 0x40ee "䃮" */
+0x00,0x04,0xf2,0x20,0x20,0x40,0x76,0xd2,0x52,0x52,0x52,0x52,0x72,0x52,0x05,0x08,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 16623 0x40ef "䃯" */
+0x00,0x00,0xf8,0x22,0x21,0x40,0x79,0x4a,0xc8,0x48,0x4b,0x48,0x78,0x49,0x06,0x00,
+0x20,0x40,0xf8,0x8a,0x8c,0xf8,0x8c,0x8a,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16624 0x40f0 "䃰" */
+0x00,0x00,0xf7,0x24,0x2a,0x43,0x74,0xda,0x55,0x52,0x54,0x5b,0x70,0x52,0x04,0x00,
+0x80,0x40,0xfe,0x02,0x24,0xbc,0xa4,0xa8,0x10,0xe8,0x04,0xfa,0x40,0x48,0x44,0xc0,
+/* 16625 0x40f1 "䃱" */
+0x01,0x01,0xf7,0x21,0x21,0x4f,0x72,0xd6,0x52,0x56,0x52,0x56,0x72,0x52,0x0f,0x00,
+0x14,0x12,0xd2,0x10,0x10,0xfe,0x90,0xd2,0x92,0xd2,0x94,0xd4,0x8a,0xca,0x16,0x22,
+/* 16626 0x40f2 "䃲" */
+0x01,0x03,0xfa,0x23,0x22,0x47,0x7a,0x4b,0xca,0x4c,0x48,0x4b,0x7a,0x4a,0x07,0x00,
+0x00,0xdc,0x54,0x66,0x40,0xdc,0x54,0x48,0x54,0xa2,0x00,0xfc,0x94,0x94,0xfe,0x00,
+/* 16627 0x40f3 "䃳" */
+0x01,0x02,0xf9,0x20,0x23,0x42,0x7a,0x4a,0xcb,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 16628 0x40f4 "䃴" */
+0x04,0x02,0xf0,0x27,0x20,0x47,0x70,0xd7,0x50,0x57,0x55,0x55,0x75,0x57,0x05,0x00,
+0x10,0x10,0x7a,0x12,0x14,0x7e,0x08,0x10,0x3c,0x64,0xa4,0x3c,0x24,0x24,0x3c,0x24,
+/* 16629 0x40f5 "䃵" */
+0x00,0x07,0xf0,0x23,0x22,0x43,0x72,0xd3,0x52,0x53,0x50,0x55,0x70,0x53,0x0d,0x01,
+0x40,0xfe,0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0xa8,0x10,0x48,0x86,
+/* 16630 0x40f6 "䃶" */
+0x00,0x00,0xfd,0x10,0x11,0x21,0x3d,0x64,0x65,0xa4,0x25,0x24,0x3c,0x25,0x22,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x54,0xfc,0x20,0x22,0x8c,0x22,0x54,0xc8,0x44,0x52,0x60,
+/* 16631 0x40f7 "䃷" */
+0x00,0x0f,0xf4,0x27,0x20,0x47,0x74,0xd7,0x50,0x5c,0x57,0x5d,0x75,0x5c,0x15,0x2e,
+0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x80,0x9c,0xd4,0x54,0x5c,0x96,0x56,0x22,
+/* 16632 0x40f8 "䃸" */
+0x01,0x01,0xfa,0x20,0x27,0x41,0x7b,0x49,0xcb,0x49,0x4b,0x49,0x79,0x4b,0x00,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 16633 0x40f9 "䃹" */
+0x03,0x02,0xfb,0x22,0x23,0x42,0x7a,0x4a,0xca,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 16634 0x40fa "䃺" */
+0x00,0x07,0xf4,0x27,0x24,0x45,0x76,0xd4,0x54,0x57,0x54,0x55,0x74,0x5b,0x08,0x10,
+0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 16635 0x40fb "䃻" */
+0x03,0x00,0xf7,0x24,0x21,0x42,0x77,0xd2,0x53,0x51,0x57,0x55,0x77,0x51,0x0f,0x01,
+0xfe,0x20,0xfe,0x22,0xac,0x80,0xde,0x92,0x92,0x1e,0xd2,0x52,0xde,0x12,0xd2,0x26,
+/* 16636 0x40fc "䃼" */
+0x10,0x08,0x08,0x7e,0x04,0x08,0x08,0x1c,0x2a,0x4a,0x88,0x08,0x08,0x08,0x08,0x08,
+0x20,0x20,0x20,0x20,0x20,0x28,0x24,0x22,0x22,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 16637 0x40fd "䃽" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x10,0x39,0x54,0x94,0x10,0x10,0x10,0x10,0x11,0x16,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 16638 0x40fe "䃾" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x10,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 16639 0x40ff "䃿" */
+0x20,0x10,0x10,0xf8,0x09,0x10,0x10,0x38,0x55,0x94,0x10,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 16640 0x4100 "䄀" */
+0x20,0x10,0x10,0xf8,0x08,0x13,0x10,0x38,0x54,0x94,0x10,0x10,0x10,0x11,0x12,0x10,
+0x90,0x88,0x88,0x80,0xbc,0xc0,0x80,0x88,0x88,0x90,0x60,0x44,0xa4,0x14,0x0c,0x04,
+/* 16641 0x4101 "䄁" */
+0x20,0x11,0x11,0xf9,0x09,0x13,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x10,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 16642 0x4102 "䄂" */
+0x20,0x10,0x10,0xf8,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 16643 0x4103 "䄃" */
+0x20,0x10,0x10,0xf9,0x09,0x11,0x19,0x35,0x51,0x93,0x10,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 16644 0x4104 "䄄" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 16645 0x4105 "䄅" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x2f,0xc0,0x3f,0x01,0x11,0x21,0x45,0x02,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0xe8,0x06,0xf8,0x00,0x10,0x08,0x04,0x00,
+/* 16646 0x4106 "䄆" */
+0x20,0x10,0x11,0xf8,0x08,0x13,0x10,0x38,0x54,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16647 0x4107 "䄇" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x10,0x38,0x57,0x94,0x10,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16648 0x4108 "䄈" */
+0x20,0x13,0x10,0xf8,0x09,0x11,0x11,0x39,0x55,0x94,0x11,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x88,0x90,0x00,0xfe,0x00,
+/* 16649 0x4109 "䄉" */
+0x20,0x10,0x13,0xf8,0x08,0x13,0x10,0x38,0x54,0x90,0x13,0x10,0x10,0x10,0x12,0x11,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 16650 0x410a "䄊" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x10,0x39,0x54,0x94,0x10,0x12,0x12,0x12,0x14,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 16651 0x410b "䄋" */
+0x20,0x10,0x13,0xf8,0x08,0x11,0x12,0x39,0x55,0x95,0x11,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 16652 0x410c "䄌" */
+0x40,0x23,0x20,0xf9,0x10,0x11,0x22,0x34,0x68,0xab,0x20,0x21,0x20,0x21,0x22,0x24,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 16653 0x410d "䄍" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x17,0x38,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16654 0x410e "䄎" */
+0x20,0x10,0x11,0xf8,0x08,0x11,0x13,0x38,0x55,0x95,0x11,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 16655 0x410f "䄏" */
+0x20,0x10,0x13,0xf8,0x08,0x10,0x19,0x34,0x50,0x93,0x10,0x10,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x00,0x1c,0xe0,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 16656 0x4110 "䄐" */
+0x10,0x54,0x54,0x7c,0x92,0x92,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x20,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 16657 0x4111 "䄑" */
+0x20,0x13,0x12,0xfb,0x0a,0x12,0x13,0x3a,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16658 0x4112 "䄒" */
+0x20,0x10,0x10,0xf8,0x09,0x12,0x11,0x38,0x54,0x94,0x10,0x12,0x12,0x12,0x14,0x10,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 16659 0x4113 "䄓" */
+0x20,0x10,0x11,0xf9,0x09,0x11,0x11,0x38,0x57,0x94,0x10,0x11,0x10,0x10,0x13,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16660 0x4114 "䄔" */
+0x20,0x10,0x13,0xf8,0x09,0x11,0x19,0x35,0x50,0x93,0x12,0x12,0x12,0x12,0x12,0x12,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 16661 0x4115 "䄕" */
+0x20,0x10,0x13,0xf8,0x08,0x11,0x12,0x38,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 16662 0x4116 "䄖" */
+0x40,0x20,0x21,0xfa,0x15,0x10,0x23,0x32,0x6a,0xab,0x22,0x22,0x23,0x22,0x22,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 16663 0x4117 "䄗" */
+0x40,0x22,0x22,0xfa,0x13,0x12,0x22,0x33,0x6a,0xaa,0x23,0x22,0x22,0x22,0x24,0x28,
+0x50,0x52,0x52,0x52,0xde,0x02,0x02,0xfe,0x02,0x02,0xde,0x52,0x52,0x52,0x52,0x02,
+/* 16664 0x4118 "䄘" */
+0x20,0x10,0x11,0xf8,0x08,0x11,0x11,0x3a,0x54,0x95,0x10,0x10,0x10,0x10,0x10,0x11,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 16665 0x4119 "䄙" */
+0x20,0x13,0x12,0xf8,0x09,0x11,0x11,0x39,0x55,0x94,0x10,0x13,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 16666 0x411a "䄚" */
+0x40,0x20,0x27,0xf8,0x13,0x12,0x23,0x32,0x6b,0xa8,0x21,0x21,0x21,0x21,0x21,0x21,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 16667 0x411b "䄛" */
+0x20,0x11,0x11,0xfb,0x09,0x11,0x10,0x39,0x55,0x95,0x10,0x13,0x10,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 16668 0x411c "䄜" */
+0x20,0x10,0x13,0xf8,0x09,0x11,0x19,0x35,0x50,0x93,0x12,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 16669 0x411d "䄝" */
+0x20,0x10,0x13,0xf8,0x09,0x10,0x1b,0x34,0x51,0x92,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0x42,0x9c,0x04,0xdc,0x04,0xfc,0x04,
+/* 16670 0x411e "䄞" */
+0x41,0x21,0x23,0xfa,0x15,0x12,0x21,0x32,0x6c,0xa8,0x23,0x20,0x21,0x22,0x25,0x20,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 16671 0x411f "䄟" */
+0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,0x0c,0x70,0x1d,0xf0,0x1c,0x00,0xff,0x11,0x23,
+0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,0x20,0x3c,0xe2,0x22,0x1e,0x00,0xfe,0x10,0x08,
+/* 16672 0x4120 "䄠" */
+0x20,0x13,0x10,0xfb,0x0a,0x12,0x12,0x3b,0x54,0x95,0x11,0x11,0x11,0x11,0x10,0x13,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 16673 0x4121 "䄡" */
+0x20,0x10,0x11,0xfb,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x12,0x12,0x14,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 16674 0x4122 "䄢" */
+0x40,0x20,0x27,0xf9,0x10,0x1f,0x25,0x35,0x6b,0xa8,0x22,0x23,0x22,0x23,0x22,0x24,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 16675 0x4123 "䄣" */
+0x20,0x13,0x10,0xf9,0x08,0x13,0x12,0x3b,0x55,0x95,0x11,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 16676 0x4124 "䄤" */
+0x41,0x21,0x27,0xf9,0x11,0x17,0x25,0x35,0x6f,0xa9,0x23,0x25,0x29,0x21,0x21,0x21,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 16677 0x4125 "䄥" */
+0x47,0x20,0x2f,0xf8,0x13,0x10,0x23,0x30,0x6e,0xaa,0x2e,0x20,0x2f,0x22,0x25,0x2f,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xee,0xaa,0xee,0x00,0xfe,0x48,0x54,0xfe,
+/* 16678 0x4126 "䄦" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 16679 0x4127 "䄧" */
+0x04,0x0e,0x79,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x09,0x09,0x0a,
+0x00,0x00,0xfc,0x44,0x48,0x48,0x50,0x5e,0x42,0x42,0x82,0x82,0x82,0x02,0x14,0x08,
+/* 16680 0x4128 "䄨" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 16681 0x4129 "䄩" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x20,0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x20,0x20,0x20,0x10,0x12,0x0a,0x06,0x02,
+/* 16682 0x412a "䄪" */
+0x08,0x1c,0xf0,0x10,0x11,0xfe,0x10,0x31,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 16683 0x412b "䄫" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x84,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 16684 0x412c "䄬" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 16685 0x412d "䄭" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 16686 0x412e "䄮" */
+0x08,0x1c,0xf0,0x10,0x11,0xfc,0x10,0x38,0x35,0x54,0x50,0x90,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 16687 0x412f "䄯" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,
+0x00,0xfc,0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 16688 0x4130 "䄰" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x11,0x31,0x38,0x54,0x54,0x90,0x11,0x12,0x10,0x10,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 16689 0x4131 "䄱" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 16690 0x4132 "䄲" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 16691 0x4133 "䄳" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x17,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 16692 0x4134 "䄴" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 16693 0x4135 "䄵" */
+0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xc0,0x01,0x1f,0x11,0x11,0xff,0x01,0x01,
+0x70,0x80,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,0xf0,0x00,0x00,0xfe,0x00,0x00,
+/* 16694 0x4136 "䄶" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x13,0x3a,0x36,0x53,0x50,0x90,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 16695 0x4137 "䄷" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x10,0x38,0x35,0x52,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 16696 0x4138 "䄸" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 16697 0x4139 "䄹" */
+0x00,0x3f,0x01,0x7f,0x09,0x11,0x22,0xcc,0x30,0xc1,0x1f,0x01,0xff,0x01,0x01,0x01,
+0xf8,0x00,0x00,0xfc,0x20,0x10,0x88,0x64,0x18,0xe6,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 16698 0x413a "䄺" */
+0x08,0x1c,0xf3,0x10,0x11,0xfc,0x11,0x31,0x39,0x54,0x54,0x90,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 16699 0x413b "䄻" */
+0x08,0x1c,0xf0,0x12,0x11,0xfc,0x10,0x31,0x3a,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 16700 0x413c "䄼" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0x04,0xfc,0x04,
+/* 16701 0x413d "䄽" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x5c,0x84,0x04,0x04,0xfc,0x04,
+/* 16702 0x413e "䄾" */
+0x08,0x1c,0xf0,0x10,0x13,0xfc,0x11,0x31,0x39,0x57,0x55,0x91,0x12,0x12,0x14,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 16703 0x413f "䄿" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x54,0x90,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 16704 0x4140 "䅀" */
+0x08,0x1c,0xf3,0x11,0x11,0xfd,0x11,0x3a,0x37,0x52,0x54,0x90,0x10,0x11,0x12,0x14,
+0x02,0x02,0xe2,0x0a,0x0a,0xea,0x2a,0x2a,0x2a,0xaa,0x4a,0x4a,0x82,0x02,0x0a,0x04,
+/* 16705 0x4141 "䅁" */
+0x01,0x7f,0x40,0x04,0xff,0x08,0x1e,0x03,0x3c,0x01,0x1f,0x01,0x7f,0x05,0x19,0x61,
+0x00,0xfc,0x04,0x00,0xfe,0x20,0x40,0xc0,0x38,0xe0,0x00,0x00,0xfc,0x40,0x30,0x0c,
+/* 16706 0x4142 "䅂" */
+0x08,0x1c,0xf0,0x11,0x13,0xfc,0x10,0x38,0x35,0x52,0x55,0x91,0x11,0x11,0x11,0x11,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 16707 0x4143 "䅃" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x00,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0xe0,0x00,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 16708 0x4144 "䅄" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x11,0x32,0x39,0x57,0x55,0x91,0x11,0x12,0x13,0x14,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 16709 0x4145 "䅅" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x55,0x90,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 16710 0x4146 "䅆" */
+0x08,0x1c,0xf2,0x11,0x11,0xfc,0x10,0x38,0x34,0x53,0x51,0x91,0x11,0x11,0x10,0x10,
+0x10,0x10,0x10,0x3e,0x22,0x44,0x10,0x90,0x90,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 16711 0x4147 "䅇" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x00,0x00,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0xe0,0x00,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 16712 0x4148 "䅈" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x2f,0xc1,0x1f,0x05,0x09,0x11,0x61,0x01,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0xd0,0x08,0x06,0xf0,0x40,0x20,0x10,0x08,0x00,
+/* 16713 0x4149 "䅉" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x12,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0x4a,0x4a,0x4c,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 16714 0x414a "䅊" */
+0x08,0x1c,0xf3,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x53,0x92,0x14,0x14,0x18,0x10,
+0x40,0x20,0xfe,0x00,0x00,0x0c,0xf0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x1e,0x00,
+/* 16715 0x414b "䅋" */
+0x08,0x1c,0xf0,0x11,0x12,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x11,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 16716 0x414c "䅌" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 16717 0x414d "䅍" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x11,0x3b,0x34,0x52,0x52,0x91,0x11,0x12,0x14,0x18,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 16718 0x414e "䅎" */
+0x08,0x1d,0xf0,0x10,0x13,0xfc,0x11,0x32,0x39,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 16719 0x414f "䅏" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x18,0xe0,0x38,0xe0,0x3c,0xe0,0x22,0x22,0x1e,0x00,
+/* 16720 0x4150 "䅐" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 16721 0x4151 "䅑" */
+0x08,0x1c,0xf3,0x10,0x12,0xfd,0x11,0x30,0x3b,0x54,0x51,0x93,0x10,0x10,0x11,0x16,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 16722 0x4152 "䅒" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x10,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,
+0x90,0x90,0xfe,0x90,0x90,0x40,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,
+/* 16723 0x4153 "䅓" */
+0x12,0x3a,0xe2,0x27,0x24,0xf8,0x27,0x35,0x6d,0x65,0xa7,0x25,0x20,0x20,0x22,0x21,
+0x00,0x00,0x3c,0xd4,0x54,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x48,0x54,0x94,0x22,
+/* 16724 0x4154 "䅔" */
+0x08,0x1c,0xf1,0x12,0x11,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 16725 0x4155 "䅕" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x10,0xfe,0x10,0x10,0x7e,0x42,0x42,0x42,0x7e,0x42,
+/* 16726 0x4156 "䅖" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x12,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 16727 0x4157 "䅗" */
+0x08,0x1d,0xf0,0x10,0x13,0xfc,0x11,0x3a,0x34,0x53,0x50,0x91,0x10,0x10,0x10,0x11,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 16728 0x4158 "䅘" */
+0x08,0x1c,0xf0,0x13,0x10,0xfd,0x11,0x31,0x3a,0x54,0x54,0x90,0x11,0x12,0x14,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 16729 0x4159 "䅙" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 16730 0x415a "䅚" */
+0x08,0x1d,0xf0,0x10,0x11,0xfc,0x13,0x38,0x35,0x52,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 16731 0x415b "䅛" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 16732 0x415c "䅜" */
+0x08,0x1c,0xf1,0x10,0x13,0xfc,0x10,0x30,0x3b,0x54,0x50,0x93,0x10,0x10,0x11,0x10,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 16733 0x415d "䅝" */
+0x08,0x1c,0xf0,0x13,0x12,0xfc,0x11,0x32,0x38,0x55,0x54,0x90,0x10,0x10,0x17,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 16734 0x415e "䅞" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x31,0x38,0x57,0x54,0x91,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x10,0xfe,0x10,0x10,0x90,0x10,0x50,0x20,
+/* 16735 0x415f "䅟" */
+0x00,0x18,0x70,0x11,0x10,0xfb,0x10,0x31,0x3a,0x55,0x50,0x90,0x11,0x10,0x10,0x13,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x62,0x84,0x18,0x60,0x80,
+/* 16736 0x4160 "䅠" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x39,0x34,0x53,0x50,0x91,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 16737 0x4161 "䅡" */
+0x08,0x1d,0xf0,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x11,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 16738 0x4162 "䅢" */
+0x08,0x1c,0xf3,0x12,0x13,0xfe,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 16739 0x4163 "䅣" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x30,0x3b,0x54,0x54,0x91,0x10,0x10,0x13,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16740 0x4164 "䅤" */
+0x08,0x1c,0xf1,0x10,0x10,0xfd,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 16741 0x4165 "䅥" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x31,0x3a,0x55,0x55,0x91,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 16742 0x4166 "䅦" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 16743 0x4167 "䅧" */
+0x08,0x1c,0xf3,0x10,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16744 0x4168 "䅨" */
+0x08,0x1d,0xf0,0x10,0x13,0xfc,0x11,0x32,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 16745 0x4169 "䅩" */
+0x08,0x1c,0xf3,0x10,0x11,0xfc,0x10,0x30,0x38,0x55,0x54,0x91,0x11,0x11,0x10,0x11,
+0x20,0x20,0xfe,0x20,0xfc,0x88,0x50,0x20,0x58,0x86,0x00,0xfe,0x02,0xfe,0x84,0x02,
+/* 16746 0x416a "䅪" */
+0x08,0x1c,0xf1,0x11,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x13,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 16747 0x416b "䅫" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x11,0x12,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 16748 0x416c "䅬" */
+0x09,0x1c,0xf0,0x10,0x13,0xfc,0x10,0x31,0x3a,0x55,0x55,0x91,0x11,0x11,0x17,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 16749 0x416d "䅭" */
+0x08,0x1c,0xf1,0x10,0x10,0xfd,0x11,0x32,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x11,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 16750 0x416e "䅮" */
+0x08,0x1c,0xf0,0x10,0x10,0xfd,0x12,0x30,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x10,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 16751 0x416f "䅯" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 16752 0x4170 "䅰" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x12,0x12,0x14,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x54,0x8c,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,
+/* 16753 0x4171 "䅱" */
+0x08,0x1d,0xf1,0x11,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x10,0x10,0x13,0x10,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 16754 0x4172 "䅲" */
+0x08,0x1c,0xf1,0x10,0x13,0xfc,0x10,0x31,0x3a,0x54,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 16755 0x4173 "䅳" */
+0x08,0x1c,0xf1,0x12,0x11,0xfd,0x10,0x31,0x3a,0x55,0x52,0x95,0x11,0x10,0x11,0x12,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 16756 0x4174 "䅴" */
+0x00,0x18,0x73,0x10,0x13,0xfa,0x14,0x31,0x38,0x54,0x53,0x90,0x11,0x12,0x14,0x10,
+0x20,0x20,0xfe,0x20,0xfe,0x42,0x8c,0xf0,0x20,0x44,0xfe,0x22,0x28,0x24,0xa4,0x40,
+/* 16757 0x4175 "䅵" */
+0x09,0x1c,0xf0,0x10,0x13,0xfc,0x10,0x39,0x34,0x54,0x53,0x90,0x12,0x12,0x14,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 16758 0x4176 "䅶" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x00,0x7e,0x00,0xfe,0x54,0x48,0x64,0x42,0x04,0xfe,0x44,0x24,0x04,0x0c,
+/* 16759 0x4177 "䅷" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x10,0x31,0x3a,0x54,0x55,0x90,0x10,0x11,0x12,0x10,
+0x88,0x88,0xfe,0x88,0xa8,0x50,0x88,0x74,0x22,0x20,0xfc,0x20,0xa8,0x24,0xa2,0x40,
+/* 16760 0x4178 "䅸" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x11,0x38,0x34,0x53,0x50,0x90,0x11,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,
+/* 16761 0x4179 "䅹" */
+0x08,0x1d,0xf1,0x13,0x11,0xfd,0x10,0x31,0x39,0x55,0x50,0x93,0x10,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 16762 0x417a "䅺" */
+0x08,0x1d,0xf0,0x11,0x11,0xfd,0x11,0x30,0x39,0x54,0x57,0x90,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 16763 0x417b "䅻" */
+0x08,0x1c,0xf3,0x10,0x11,0xfd,0x11,0x39,0x34,0x53,0x52,0x92,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 16764 0x417c "䅼" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x3b,0x36,0x53,0x50,0x91,0x10,0x10,0x11,0x16,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 16765 0x417d "䅽" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x81,0x1f,0x01,0x7f,0x05,0x19,0x61,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xe4,0x00,0x00,0xfc,0x40,0x30,0x0c,
+/* 16766 0x417e "䅾" */
+0x00,0x1b,0x70,0x12,0x13,0xf9,0x12,0x34,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x11,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16767 0x417f "䅿" */
+0x08,0x1f,0xf0,0x10,0x11,0xfc,0x10,0x33,0x38,0x54,0x55,0x90,0x13,0x10,0x10,0x10,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 16768 0x4180 "䆀" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x38,0x35,0x50,0x53,0x90,0x12,0x12,0x14,0x10,
+0x00,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 16769 0x4181 "䆁" */
+0x08,0x1d,0xf1,0x11,0x10,0xfd,0x10,0x33,0x38,0x54,0x55,0x90,0x13,0x10,0x10,0x10,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 16770 0x4182 "䆂" */
+0x10,0x3b,0xe2,0x22,0x23,0xfa,0x22,0x32,0x6b,0x62,0xa2,0x22,0x22,0x25,0x26,0x28,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 16771 0x4183 "䆃" */
+0x21,0x17,0x00,0x73,0x12,0x13,0x12,0x2f,0x40,0x01,0x1f,0x01,0x7f,0x05,0x19,0x61,
+0x10,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x00,0xe0,0x00,0x00,0xfc,0x40,0x30,0x0c,
+/* 16772 0x4184 "䆄" */
+0x08,0x1d,0xf0,0x11,0x11,0xfd,0x11,0x39,0x34,0x54,0x50,0x90,0x10,0x10,0x10,0x11,
+0x10,0xfe,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 16773 0x4185 "䆅" */
+0x0a,0x1d,0xf0,0x10,0x13,0xfd,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x11,
+0x20,0x3e,0x42,0x94,0x10,0x28,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 16774 0x4186 "䆆" */
+0x08,0x1c,0xf0,0x10,0x10,0xfd,0x11,0x31,0x39,0x54,0x57,0x90,0x10,0x11,0x12,0x10,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 16775 0x4187 "䆇" */
+0x10,0xe7,0x24,0x25,0x25,0xfd,0x25,0x35,0x6d,0x65,0xa5,0x25,0x24,0x25,0x25,0x28,
+0x00,0xfc,0x84,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x04,0xf4,0x14,0x56,0x56,0x32,
+/* 16776 0x4188 "䆈" */
+0x10,0xe4,0x22,0x22,0x20,0xf8,0x2e,0x32,0x6a,0x62,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x00,0xfe,0x82,0xfe,0x80,0xaa,0x9c,0xaa,0x80,0xa8,0xbe,0xc8,0xbe,0x88,0x08,0xfe,
+/* 16777 0x4189 "䆉" */
+0x10,0x3b,0xe2,0x22,0x23,0xf9,0x22,0x33,0x68,0x63,0xa2,0x23,0x22,0x23,0x22,0x22,
+0x00,0xfc,0x94,0x94,0xfc,0x10,0x52,0xdc,0x12,0xce,0x40,0xd2,0x5c,0xd0,0x52,0xce,
+/* 16778 0x418a "䆊" */
+0x00,0x1b,0x70,0x11,0x12,0xf9,0x11,0x31,0x39,0x55,0x50,0x91,0x10,0x13,0x10,0x11,
+0x94,0x98,0x92,0x8e,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x04,
+/* 16779 0x418b "䆋" */
+0x10,0x39,0xe2,0x27,0x22,0xfb,0x20,0x33,0x69,0x67,0xa1,0x23,0x21,0x27,0x21,0x23,
+0x80,0xf8,0x08,0xfe,0x52,0xde,0x50,0x5e,0x52,0xde,0x52,0x5e,0x50,0xd2,0x52,0x3e,
+/* 16780 0x418c "䆌" */
+0x03,0x19,0x77,0x11,0x13,0xfd,0x10,0x33,0x38,0x57,0x50,0x93,0x10,0x13,0x12,0x13,
+0x94,0x10,0xbe,0x18,0xaa,0x46,0x20,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,
+/* 16781 0x418d "䆍" */
+0x12,0x39,0xe7,0x20,0x24,0xfa,0x27,0x30,0x6f,0x64,0xa7,0x24,0x27,0x24,0x24,0x24,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 16782 0x418e "䆎" */
+0x11,0x39,0xe2,0x20,0x27,0xf9,0x23,0x31,0x6b,0x61,0xa3,0x21,0x21,0x23,0x20,0x20,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 16783 0x418f "䆏" */
+0x09,0x1c,0xf3,0x10,0x13,0xfd,0x11,0x31,0x39,0x55,0x54,0x93,0x10,0x17,0x11,0x12,
+0x24,0xa8,0xfe,0xa8,0x26,0xfc,0x24,0xfc,0x24,0xfc,0x88,0xfe,0x88,0xfe,0x04,0x02,
+/* 16784 0x4190 "䆐" */
+0x01,0x1f,0x02,0x7f,0x08,0x37,0xc1,0x3f,0x11,0x7d,0x20,0xfe,0x54,0xba,0x10,0x54,
+0x00,0xf0,0x00,0xfc,0x20,0xd8,0x06,0xf8,0x10,0x7c,0x20,0xfe,0x54,0xba,0x10,0x54,
+/* 16785 0x4191 "䆑" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x20,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 16786 0x4192 "䆒" */
+0x02,0x01,0x7f,0x40,0x88,0x12,0x22,0x1f,0x02,0x0a,0x04,0x06,0x09,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 16787 0x4193 "䆓" */
+0x02,0x01,0x7f,0x40,0x88,0x11,0x22,0x04,0x08,0x1f,0x04,0x04,0x04,0x08,0x10,0x60,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x40,0x20,0xf0,0x50,0x40,0x40,0x44,0x44,0x3c,
+/* 16788 0x4194 "䆔" */
+0x02,0x01,0x7f,0x48,0x91,0x21,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 16789 0x4195 "䆕" */
+0x02,0x01,0x7f,0x48,0x91,0x01,0x3f,0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf0,0x10,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 16790 0x4196 "䆖" */
+0x02,0x01,0x7f,0x48,0x90,0x22,0x02,0x7f,0x04,0x04,0x08,0x11,0x22,0x44,0x8f,0x04,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0xfc,0x00,0x80,0x80,0x00,0x20,0x10,0xf8,0x08,
+/* 16791 0x4197 "䆗" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0x88,0x88,0x88,0x88,0x98,0xe8,0x88,0x08,0x08,
+/* 16792 0x4198 "䆘" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x11,0x01,0x01,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x00,0x00,
+/* 16793 0x4199 "䆙" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x7f,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 16794 0x419a "䆚" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x24,0x27,0x20,0x20,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0x48,0xc8,0x08,0x18,
+/* 16795 0x419b "䆛" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x00,0x18,0xe0,0x40,0x40,0x7e,0xc0,0x40,0x44,0x44,0x3c,
+/* 16796 0x419c "䆜" */
+0x02,0x01,0x7f,0x48,0x94,0x04,0x7f,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 16797 0x419d "䆝" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x21,0x02,0x3f,0x24,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 16798 0x419e "䆞" */
+0x02,0x01,0x7f,0x48,0x90,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x10,0x1f,0x10,0x10,0x0f,
+0x00,0x00,0xfe,0x22,0x14,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x00,0x04,0x04,0xfc,
+/* 16799 0x419f "䆟" */
+0x02,0x01,0x7f,0x48,0x91,0x22,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x22,0x14,0x88,0x60,0x18,0xe6,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 16800 0x41a0 "䆠" */
+0x01,0x7f,0x48,0x90,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x3f,0x21,0x21,0x3f,0x00,
+0x00,0xfe,0x22,0x14,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,
+/* 16801 0x41a1 "䆡" */
+0x02,0x01,0x7f,0x48,0x92,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x10,0x12,0x14,0x18,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x18,0x06,
+/* 16802 0x41a2 "䆢" */
+0x02,0x01,0x7f,0x48,0x90,0x10,0xfd,0x10,0x14,0x18,0x33,0xd0,0x10,0x11,0x52,0x24,
+0x00,0x00,0xfe,0x22,0x14,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 16803 0x41a3 "䆣" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x29,0x28,0x48,0x4a,0x8c,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x08,0x90,0x60,0x18,0x06,
+/* 16804 0x41a4 "䆤" */
+0x01,0x7f,0x48,0x90,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x7f,0x01,0x0e,0xf0,0x00,
+0x00,0xfe,0x22,0x14,0x00,0xf0,0x10,0xf0,0x12,0xf4,0x18,0xf0,0x90,0x10,0x50,0x20,
+/* 16805 0x41a5 "䆥" */
+0x02,0x01,0x7f,0x48,0x90,0x7f,0x02,0x0d,0x71,0x02,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0x00,0xfe,0x22,0x14,0xfc,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 16806 0x41a6 "䆦" */
+0x02,0x01,0x7f,0x48,0x91,0x09,0x09,0x12,0x04,0x19,0x69,0x09,0x12,0x04,0x18,0x60,
+0x00,0x00,0xfe,0x22,0x14,0x10,0x20,0xc0,0x30,0x08,0x14,0x10,0xa0,0x40,0x30,0x0c,
+/* 16807 0x41a7 "䆧" */
+0x01,0x7f,0x48,0x90,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x04,0x7f,0x08,0x1c,0x03,0x7c,
+0x00,0xfe,0x22,0x74,0x80,0x00,0xfc,0x40,0x30,0x0e,0x00,0xfc,0x20,0x40,0x80,0x78,
+/* 16808 0x41a8 "䆨" */
+0x01,0x7f,0x48,0x90,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x01,0x7f,0x04,0x18,0xe0,
+0x00,0xfe,0x22,0x14,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfc,0x40,0x30,0x0e,
+/* 16809 0x41a9 "䆩" */
+0x01,0x7f,0x48,0x90,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x04,0x18,0xe0,
+0x00,0xfe,0x22,0x14,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x30,0x0e,
+/* 16810 0x41aa "䆪" */
+0x10,0x10,0x95,0x55,0x58,0x10,0xfd,0x28,0x28,0x28,0x28,0x28,0x29,0x48,0x48,0x87,
+0x40,0x20,0xfc,0x04,0x50,0x88,0x04,0x00,0xf8,0x20,0x20,0x20,0xfc,0x00,0x02,0xfe,
+/* 16811 0x41ab "䆫" */
+0x01,0x7f,0x48,0x90,0x08,0x1f,0x2a,0x44,0x0a,0x11,0x22,0x04,0x01,0x48,0x48,0x87,
+0x00,0xfe,0x22,0x14,0x00,0xf8,0x48,0x48,0x88,0x08,0xa8,0x10,0x00,0x84,0x12,0xf2,
+/* 16812 0x41ac "䆬" */
+0x01,0x7f,0x48,0x90,0x0f,0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x00,0xfe,0x22,0x14,0xe0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 16813 0x41ad "䆭" */
+0x01,0x7f,0x48,0x90,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x00,0xfe,0x22,0x14,0x00,0x7c,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x90,0x10,0x10,
+/* 16814 0x41ae "䆮" */
+0x01,0x7f,0x48,0x90,0x23,0x10,0x11,0x80,0x43,0x50,0x17,0x24,0xe3,0x21,0x20,0x27,
+0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 16815 0x41af "䆯" */
+0x01,0x7f,0x48,0xbe,0x12,0x0c,0x32,0x00,0x3e,0x12,0x0c,0x32,0xff,0x08,0x07,0x78,
+0x00,0xfe,0x22,0xfc,0x48,0x30,0xc8,0x00,0xf8,0x48,0x30,0xc8,0xfe,0x20,0xc0,0x38,
+/* 16816 0x41b0 "䆰" */
+0x02,0x01,0x7f,0x48,0x90,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x29,0x2f,0x20,0x3f,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x00,0xf0,0x10,0xf0,0x00,0x78,0x48,0x78,0x00,0xfc,
+/* 16817 0x41b1 "䆱" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x12,0x90,0x41,0x46,0x10,0x22,0xe4,0x20,0x23,0x2c,
+0x00,0x00,0xfe,0x22,0x14,0x40,0x48,0xb0,0x08,0x04,0x40,0x44,0x48,0xa0,0x18,0x06,
+/* 16818 0x41b2 "䆲" */
+0x01,0x7f,0x48,0x91,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x24,0x22,0x44,0x58,0x81,
+0x00,0xfe,0x22,0x14,0xf8,0x80,0xf8,0x88,0xfe,0x88,0xf8,0xc4,0xa8,0x98,0x86,0x80,
+/* 16819 0x41b3 "䆳" */
+0x01,0x7f,0x48,0x90,0x23,0x10,0x11,0x06,0x70,0x11,0x16,0x10,0x11,0x16,0x28,0x47,
+0x00,0xfe,0x22,0x14,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x24,0xa0,0x40,0xfe,
+/* 16820 0x41b4 "䆴" */
+0x01,0x7f,0x48,0x9f,0x10,0x3f,0x51,0x1f,0x11,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x00,0xfe,0x22,0xd4,0x40,0xf0,0x10,0xf0,0x10,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 16821 0x41b5 "䆵" */
+0x02,0x01,0x7f,0x48,0x90,0x08,0x7f,0x51,0x49,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0x00,0xfe,0x22,0x14,0x20,0xfc,0x14,0x24,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16822 0x41b6 "䆶" */
+0x01,0x7f,0x48,0x91,0x08,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x10,0x24,0x22,0x42,
+0x00,0xfe,0x22,0x14,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x88,0x44,0x44,
+/* 16823 0x41b7 "䆷" */
+0x01,0x7f,0x48,0x90,0x1f,0x02,0x7f,0x04,0x7a,0x01,0x3f,0x28,0x37,0x24,0x27,0x20,
+0x00,0xfe,0x22,0x14,0xf0,0x20,0xfc,0x88,0x80,0x00,0xf8,0x28,0xd8,0x48,0xc8,0x18,
+/* 16824 0x41b8 "䆸" */
+0x02,0x01,0x7f,0x48,0x90,0x7e,0x04,0x28,0x17,0x20,0xdf,0x10,0x1f,0x08,0x04,0x7f,
+0x00,0x00,0xfe,0x22,0x94,0xa0,0x44,0x28,0xd0,0x08,0xf6,0x10,0xf0,0x20,0x40,0xfc,
+/* 16825 0x41b9 "䆹" */
+0x01,0x7f,0x49,0x9f,0x04,0x7f,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,
+0x00,0xfe,0x22,0xf4,0x40,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 16826 0x41ba "䆺" */
+0x01,0x7f,0x48,0x90,0x00,0x3f,0x11,0x09,0xff,0x09,0x30,0xdf,0x11,0x1f,0x11,0x1f,
+0x00,0xfe,0x22,0x14,0xf8,0x00,0x10,0x20,0xfe,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,
+/* 16827 0x41bb "䆻" */
+0x02,0x01,0x7f,0x48,0x90,0x7c,0x04,0xff,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x42,0x02,
+0x00,0x00,0xfe,0x22,0x14,0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x90,0x28,0x44,0x82,
+/* 16828 0x41bc "䆼" */
+0x01,0x7f,0x48,0x90,0x21,0x11,0x11,0x01,0x73,0x12,0x12,0x12,0x12,0x12,0x2a,0x47,
+0x00,0xfe,0x22,0x14,0xf8,0x08,0xe8,0x28,0xfc,0x04,0xf4,0x94,0xf4,0x14,0x08,0xfe,
+/* 16829 0x41bd "䆽" */
+0x01,0x7f,0x48,0x91,0x01,0x3f,0x21,0x2f,0x21,0x2f,0x23,0x2c,0x23,0x5c,0x43,0x9c,
+0x00,0xfe,0x22,0xfc,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x00,0x90,0x60,0xd8,0x46,0xc0,
+/* 16830 0x41be "䆾" */
+0x01,0x7f,0x48,0x90,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x3f,0x24,0x24,0xff,
+0x00,0xfe,0x22,0x14,0x20,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xf8,0x48,0x48,0xfe,
+/* 16831 0x41bf "䆿" */
+0x01,0x7f,0x48,0x90,0x09,0x49,0x49,0x49,0x79,0x09,0x09,0xf8,0x4b,0x48,0x49,0x8a,
+0x00,0xfe,0x22,0x54,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0xa8,0x24,0x22,
+/* 16832 0x41c0 "䇀" */
+0x01,0x7f,0x48,0x90,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x00,0xfe,0x22,0x14,0x00,0x7e,0x24,0x3c,0x24,0x24,0x3c,0x24,0x26,0x7c,0x04,0x04,
+/* 16833 0x41c1 "䇁" */
+0x01,0x7f,0x48,0x90,0x20,0x3e,0x44,0xff,0x49,0x7f,0x49,0x7f,0x00,0x55,0x4a,0x8a,
+0x00,0xfe,0x22,0x14,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x10,0x90,0x90,
+/* 16834 0x41c2 "䇂" */
+0x02,0x01,0x01,0x7f,0x00,0x10,0x08,0x04,0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x20,0x40,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 16835 0x41c3 "䇃" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x28,0x28,0x0e,0xf0,0x40,0x00,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 16836 0x41c4 "䇄" */
+0x10,0x08,0x08,0x7e,0x00,0x05,0x44,0x44,0x24,0x28,0x28,0x0e,0xf1,0x41,0x00,0x00,
+0x40,0x40,0x40,0xfe,0x80,0x00,0x7c,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 16837 0x41c5 "䇅" */
+0x10,0x08,0x08,0x7e,0x00,0x05,0x44,0x44,0x24,0x28,0x28,0x0e,0xf0,0x40,0x03,0x00,
+0x50,0x48,0x48,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 16838 0x41c6 "䇆" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x28,0x29,0x0e,0xf0,0x40,0x00,0x00,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 16839 0x41c7 "䇇" */
+0x20,0x11,0x11,0xfd,0x01,0x09,0x89,0x89,0x49,0x49,0x51,0x51,0x1d,0xe1,0x41,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 16840 0x41c8 "䇈" */
+0x20,0x11,0x10,0xfc,0x00,0x08,0x88,0x8b,0x48,0x48,0x51,0x50,0x1c,0xe0,0x43,0x00,
+0x00,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 16841 0x41c9 "䇉" */
+0x20,0x10,0x13,0xfc,0x00,0x08,0x88,0x88,0x49,0x4a,0x54,0x50,0x1c,0xe0,0x40,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 16842 0x41ca "䇊" */
+0x20,0x10,0x10,0xfd,0x01,0x09,0x89,0x89,0x49,0x49,0x51,0x51,0x1e,0xe2,0x44,0x08,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 16843 0x41cb "䇋" */
+0x10,0x08,0x08,0x7e,0x01,0x04,0x44,0x44,0x25,0x28,0x28,0x0e,0xf0,0x40,0x00,0x01,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x28,0x48,0x9e,0x22,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 16844 0x41cc "䇌" */
+0x20,0x11,0x10,0xfc,0x00,0x09,0x89,0x89,0x49,0x49,0x51,0x51,0x1d,0xe1,0x41,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 16845 0x41cd "䇍" */
+0x20,0x11,0x11,0xfd,0x01,0x09,0x88,0x88,0x49,0x49,0x51,0x51,0x1e,0xe2,0x44,0x08,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 16846 0x41ce "䇎" */
+0x20,0x10,0x10,0xfd,0x00,0x08,0x89,0x88,0x48,0x48,0x50,0x50,0x1c,0xe0,0x40,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 16847 0x41cf "䇏" */
+0x20,0x10,0x13,0xfc,0x01,0x09,0x89,0x88,0x49,0x48,0x50,0x53,0x1c,0xe0,0x40,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 16848 0x41d0 "䇐" */
+0x20,0x10,0x11,0xfc,0x00,0x0b,0x88,0x88,0x49,0x4a,0x51,0x50,0x1d,0xe2,0x40,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 16849 0x41d1 "䇑" */
+0x20,0x10,0x11,0xfd,0x01,0x09,0x89,0x89,0x49,0x48,0x51,0x53,0x1c,0xe0,0x40,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 16850 0x41d2 "䇒" */
+0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,
+0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,
+/* 16851 0x41d3 "䇓" */
+0x0b,0x10,0x61,0x09,0x11,0x61,0x05,0x09,0x31,0xc0,0x03,0x01,0x3f,0x08,0x04,0xff,
+0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x00,0xf8,0x20,0x40,0xfe,
+/* 16852 0x41d4 "䇔" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x02,0x71,0x57,0x70,0x54,0x72,0x51,0xb6,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x1c,0xd4,0x14,0x5c,0x96,0xd6,0x22,
+/* 16853 0x41d5 "䇕" */
+0x00,0x21,0x10,0x13,0xfa,0x01,0x08,0x89,0x88,0x4b,0x50,0x51,0x1d,0xe1,0x41,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 16854 0x41d6 "䇖" */
+0x10,0x10,0x3f,0x48,0x85,0x08,0x08,0x1f,0x21,0x41,0x02,0x02,0x04,0x18,0x60,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 16855 0x41d7 "䇗" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x04,0x08,0x10,0x21,0xc2,0x04,0x08,0x10,0x3f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x40,0x20,0x10,0x08,0x06,0x00,0x20,0x10,0xf8,0x08,
+/* 16856 0x41d8 "䇘" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x7f,0x04,0x0f,0x08,0x08,0x10,0x1f,0x00,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf0,0x10,0x20,0x20,0xc0,0x40,0xfe,0x00,
+/* 16857 0x41d9 "䇙" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x01,0x01,0x3f,0x20,0x40,0x7f,0x01,0x01,0x0a,0x04,
+0x40,0x7e,0x90,0x08,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 16858 0x41da "䇚" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x08,0x08,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,
+/* 16859 0x41db "䇛" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x81,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 16860 0x41dc "䇜" */
+0x20,0x20,0x7e,0x51,0x88,0x08,0x0f,0x10,0x21,0x41,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfc,0x04,0x08,0x00,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 16861 0x41dd "䇝" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x04,0x04,0x04,0xff,0x02,0x01,0x01,0x0e,0x70,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x40,0x20,0x00,0xfe,0x00,0x10,0x60,0x84,0x44,0x34,0x0c,
+/* 16862 0x41de "䇞" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x10,0xff,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x10,0xfe,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 16863 0x41df "䇟" */
+0x10,0x10,0x3f,0x28,0x45,0x90,0x10,0x3e,0x22,0x42,0xa4,0x14,0x08,0x10,0x21,0x42,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x20,0x20,0xfc,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 16864 0x41e0 "䇠" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 16865 0x41e1 "䇡" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x7f,0x40,0x80,0x3f,0x01,0x01,0x01,0x01,0x05,0x02,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 16866 0x41e2 "䇢" */
+0x10,0x10,0x3f,0x28,0x45,0x81,0x01,0xff,0x01,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 16867 0x41e3 "䇣" */
+0x10,0x10,0x3f,0x48,0x85,0x02,0x04,0x09,0x31,0xc1,0x01,0x09,0x11,0x21,0x05,0x02,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x40,0x20,0x18,0x06,0x00,0x20,0x10,0x08,0x00,0x00,
+/* 16868 0x41e4 "䇤" */
+0x20,0x3f,0x48,0x85,0x00,0xff,0x01,0x01,0x7f,0x41,0x42,0x44,0x48,0x40,0x40,0x40,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0x00,0xfc,0x04,0x84,0x44,0x24,0x04,0x14,0x08,
+/* 16869 0x41e5 "䇥" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 16870 0x41e6 "䇦" */
+0x10,0x10,0x3f,0x28,0x45,0x81,0x1f,0x11,0x11,0x11,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 16871 0x41e7 "䇧" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0xff,0x01,0x3f,0x21,0x22,0x24,0x28,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0xf8,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 16872 0x41e8 "䇨" */
+0x20,0x3f,0x48,0x85,0x08,0x1f,0x28,0x07,0x18,0xe1,0x1f,0x01,0x11,0x1f,0x01,0x01,
+0x40,0x7e,0x90,0x08,0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x00,0x00,0xf8,0x00,0x00,
+/* 16873 0x41e9 "䇩" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,0x01,0x0e,0x70,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xb0,0xc2,0x32,0x0e,
+/* 16874 0x41ea "䇪" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x04,0x08,0x1f,0x01,0x01,0x3f,0x01,0x01,0xff,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0x20,0xf0,0x10,0x00,0xf8,0x00,0x00,0xfe,
+/* 16875 0x41eb "䇫" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x80,0x80,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfe,0x00,
+/* 16876 0x41ec "䇬" */
+0x10,0x10,0x3f,0x48,0x85,0x11,0x11,0x3f,0x41,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 16877 0x41ed "䇭" */
+0x20,0x3f,0x48,0x85,0x02,0x02,0x3f,0x02,0xff,0x01,0x06,0x08,0x3f,0xc8,0x08,0x07,
+0x40,0x7e,0x90,0x08,0x00,0x08,0xd0,0x20,0xfe,0x00,0x10,0xe0,0x00,0x08,0x08,0xf8,
+/* 16878 0x41ee "䇮" */
+0x10,0x10,0x3f,0x48,0x85,0x08,0x08,0x13,0x30,0x50,0x9f,0x10,0x10,0x10,0x17,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x00,
+/* 16879 0x41ef "䇯" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x3e,0xd0,0x10,0x10,
+/* 16880 0x41f0 "䇰" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x1f,0x00,0x7d,0x05,0x09,0x31,0xc5,0x02,0x3f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x00,
+/* 16881 0x41f1 "䇱" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x3f,0x22,0x23,0x24,0x2a,0x21,0x22,0x24,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xc8,0x48,0x88,0x08,0x88,0x08,0xf8,0x08,
+/* 16882 0x41f2 "䇲" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x3f,0x01,0x11,0x09,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0x10,0x20,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 16883 0x41f3 "䇳" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x03,0x7e,0x03,0x3e,0x03,0xfe,0x01,0x00,0x07,0x78,
+0x40,0x40,0x7e,0x90,0x48,0x20,0xf8,0x00,0xf0,0x00,0xfc,0x20,0x40,0x84,0x64,0x1c,
+/* 16884 0x41f4 "䇴" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0xff,0x04,0x3f,0x24,0x24,0x28,0x30,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfe,0x40,0xf8,0x48,0x48,0x48,0x38,0x08,0xf8,0x08,
+/* 16885 0x41f5 "䇵" */
+0x10,0x10,0x3f,0x48,0x85,0x20,0x11,0x11,0x81,0x49,0x49,0x11,0xe1,0x22,0x22,0x24,
+0x40,0x40,0x7e,0x90,0x08,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 16886 0x41f6 "䇶" */
+0x20,0x3f,0x48,0x85,0x08,0x1f,0x20,0x5f,0x11,0x1f,0x11,0x1f,0x11,0x21,0x21,0x40,
+0x40,0x7e,0x90,0x08,0x00,0xf0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 16887 0x41f7 "䇷" */
+0x20,0x3f,0x48,0x85,0x3f,0x21,0x21,0x3f,0x08,0x08,0x7f,0x08,0x10,0x10,0x22,0x41,
+0x40,0x7e,0x90,0x08,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0x84,0x94,0x08,
+/* 16888 0x41f8 "䇸" */
+0x10,0x10,0x3f,0x28,0x45,0x9f,0x10,0x10,0x1f,0x00,0x3f,0x01,0x1f,0x01,0x7f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,
+/* 16889 0x41f9 "䇹" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x04,0xff,0x04,0x3f,0x08,0x1f,0x28,0x48,0x8f,0x08,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 16890 0x41fa "䇺" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x00,0x08,0x04,0xff,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x00,0x20,0x40,0xfe,0x00,
+/* 16891 0x41fb "䇻" */
+0x20,0x3f,0x48,0x85,0x3f,0x20,0x3f,0x20,0x20,0x2f,0x20,0x2f,0x20,0x5f,0x40,0x80,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x00,0x70,0x80,0xf0,0x80,0xf8,0x82,0x82,0x7e,
+/* 16892 0x41fc "䇼" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x1f,0x00,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x02,0x02,0xfe,0x00,
+/* 16893 0x41fd "䇽" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x11,0xfd,0x11,0x11,0x1d,0xf1,0x11,0x12,0x52,0x24,
+0x40,0x40,0x7e,0x90,0x08,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 16894 0x41fe "䇾" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x08,
+/* 16895 0x41ff "䇿" */
+0x20,0x3f,0x48,0x85,0x01,0xff,0x01,0x3f,0x21,0x21,0x3f,0x23,0x05,0x19,0xe1,0x01,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x88,0x60,0x18,0x06,0x00,
+/* 16896 0x4200 "䈀" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x2a,0x2a,0x2a,0xff,0x2a,0x2a,0x2a,0x2a,0x20,0x21,
+0x40,0x40,0x7e,0x90,0x08,0x84,0x84,0x94,0x94,0xd4,0x94,0x94,0x94,0x84,0x94,0x88,
+/* 16897 0x4201 "䈁" */
+0x20,0x3f,0x48,0x85,0x02,0x0c,0x37,0xc0,0x3f,0x24,0x24,0x3f,0x24,0x24,0x24,0x20,
+0x40,0x7e,0x90,0x08,0x80,0x60,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,0x88,0xa8,0x10,
+/* 16898 0x4202 "䈂" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x08,0x7f,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 16899 0x4203 "䈃" */
+0x20,0x3f,0x48,0x85,0x23,0x10,0x10,0x80,0x49,0x4a,0x15,0xe1,0x21,0x21,0x21,0x21,
+0x40,0x7e,0x90,0x08,0xfc,0x84,0x84,0x84,0x14,0x08,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 16900 0x4204 "䈄" */
+0x10,0x10,0x3f,0x28,0x45,0x9f,0x40,0x51,0x49,0x43,0x45,0x49,0x55,0x42,0x7f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0xe0,0x44,0x94,0x24,0xc4,0x44,0x24,0x14,0x04,0xfc,0x04,
+/* 16901 0x4205 "䈅" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x00,0x3e,0x22,0x22,0x3e,0x00,0x07,0x78,0x21,
+0x40,0x40,0x7e,0x90,0x28,0x90,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 16902 0x4206 "䈆" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x21,0x42,0x44,0x98,
+0x40,0x7e,0x90,0x08,0x80,0xfc,0x04,0x04,0xfc,0xa0,0x90,0xfc,0x20,0x10,0x08,0x06,
+/* 16903 0x4207 "䈇" */
+0x20,0x3f,0x48,0x85,0x01,0x01,0x01,0x3f,0x20,0x3f,0x20,0x3f,0x01,0xff,0x01,0x01,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,
+/* 16904 0x4208 "䈈" */
+0x10,0x10,0x3f,0x48,0x85,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x4a,0x84,
+0x40,0x40,0x7e,0x90,0x08,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 16905 0x4209 "䈉" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x3f,0x08,0xff,0x04,0x7f,0x08,0x1c,0x03,0x0c,0x70,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xf8,0x20,0xfe,0x00,0xfc,0x20,0x40,0x80,0x70,0x08,
+/* 16906 0x420a "䈊" */
+0x20,0x3f,0x48,0x85,0x01,0x3f,0x01,0xff,0x10,0x22,0x47,0x08,0x14,0x03,0x1c,0xe0,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0xfe,0x10,0x08,0xe4,0x20,0x40,0x80,0x70,0x0e,
+/* 16907 0x420b "䈋" */
+0x20,0x3f,0x48,0x85,0x01,0x7d,0x09,0x31,0xc5,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x04,0x98,0x60,0x18,0x06,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 16908 0x420c "䈌" */
+0x20,0x3f,0x48,0x85,0x10,0x09,0x09,0x41,0x21,0x29,0x09,0x11,0x71,0x11,0x17,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 16909 0x420d "䈍" */
+0x20,0x3f,0x48,0x85,0x00,0xff,0x10,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x40,0x7e,0x90,0x08,0x80,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16910 0x420e "䈎" */
+0x20,0x3f,0x48,0x85,0x12,0x7f,0x12,0x13,0x10,0x1f,0x01,0xff,0x05,0x19,0xe1,0x01,
+0x40,0x7e,0x90,0x08,0x20,0xfc,0x20,0xe0,0x00,0xf8,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 16911 0x420f "䈏" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 16912 0x4210 "䈐" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x13,0x58,0x54,0x51,0x91,0x12,0x14,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x90,0x48,0x40,0xfe,0x80,0x90,0x10,0x52,0x54,0xa8,0x28,0x44,0x82,
+/* 16913 0x4211 "䈑" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0x90,0x90,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 16914 0x4212 "䈒" */
+0x20,0x3f,0x48,0x85,0x01,0xff,0x01,0x3f,0x24,0x22,0x2f,0x21,0x3f,0x21,0x21,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0xf8,0x48,0x88,0xe8,0x08,0xf8,0x08,0x28,0x10,
+/* 16915 0x4213 "䈓" */
+0x10,0x10,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x21,0x52,0x14,0x1f,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x84,0x54,0xe8,
+/* 16916 0x4214 "䈔" */
+0x20,0x3f,0x48,0x85,0x7c,0x44,0x44,0x7c,0x40,0x41,0x7c,0x40,0x40,0x7c,0x40,0x43,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 16917 0x4215 "䈕" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x11,0x11,0x29,0x47,0x80,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,
+/* 16918 0x4216 "䈖" */
+0x20,0x3f,0x48,0x85,0x0c,0x70,0x10,0x10,0xfc,0x30,0x38,0x55,0x50,0x90,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x10,0x90,0x50,0x10,0x90,0x50,0x1e,0xf0,0x10,0x10,0x10,0x10,
+/* 16919 0x4217 "䈗" */
+0x20,0x3f,0x48,0x85,0x09,0x0a,0x17,0x31,0x52,0x94,0x11,0x13,0x14,0x10,0x11,0x16,
+0x40,0x7e,0x90,0x08,0x10,0x08,0xfc,0x10,0x08,0x84,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 16920 0x4218 "䈘" */
+0x20,0x3f,0x48,0x85,0x08,0x04,0xff,0x10,0x10,0x24,0x7c,0x08,0x10,0x24,0x7e,0x02,
+0x40,0x7e,0x90,0x08,0x20,0x40,0xfe,0x20,0x20,0x48,0xf8,0x10,0x20,0x48,0xfc,0x04,
+/* 16921 0x4219 "䈙" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x10,0x24,0x79,0x10,0x24,0x7e,0x00,0x54,0x4a,0x8a,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x08,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 16922 0x421a "䈚" */
+0x20,0x3f,0x48,0x85,0x08,0x10,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x01,0x48,0x48,0x87,
+0x40,0x7e,0x90,0x08,0x00,0x10,0xf8,0x08,0xf0,0x10,0x10,0xf0,0x00,0x84,0x12,0xf2,
+/* 16923 0x421b "䈛" */
+0x20,0x3f,0x48,0x85,0x08,0x0f,0x08,0x08,0x7f,0x55,0x55,0x7f,0x55,0x55,0x55,0x43,
+0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 16924 0x421c "䈜" */
+0x20,0x3f,0x48,0x85,0x0b,0x08,0x11,0x30,0x53,0x90,0x17,0x14,0x13,0x11,0x10,0x17,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 16925 0x421d "䈝" */
+0x20,0x3e,0x48,0xbf,0x01,0x11,0x11,0x2f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x40,0x7e,0x90,0xfc,0x04,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 16926 0x421e "䈞" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,
+0x40,0x7e,0x90,0x08,0x80,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 16927 0x421f "䈟" */
+0x20,0x20,0x7e,0x51,0x88,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,0x3f,0x12,0x21,0x40,
+0x40,0x40,0xfe,0x10,0x08,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x88,
+/* 16928 0x4220 "䈠" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x22,0x11,0x3f,0x02,0xff,0x04,0x0f,0x12,0x21,0xce,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0x08,0x10,0xf8,0x00,0xfe,0x00,0xf0,0x20,0xc0,0x3c,
+/* 16929 0x4221 "䈡" */
+0x20,0x3f,0x48,0x85,0x08,0x1f,0x2a,0x44,0x0a,0x11,0x22,0x04,0x01,0x48,0x48,0x87,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x48,0x48,0x88,0x08,0xa8,0x10,0x00,0x84,0x12,0xf2,
+/* 16930 0x4222 "䈢" */
+0x20,0x3e,0x48,0x90,0x20,0x7f,0x00,0x3f,0x20,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x40,0x7e,0x90,0x00,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 16931 0x4223 "䈣" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x04,0x04,0x27,0x24,0x24,0x24,0x2f,0xf0,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 16932 0x4224 "䈤" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x88,0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,
+/* 16933 0x4225 "䈥" */
+0x20,0x3f,0x48,0x85,0x10,0x1f,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x24,0x42,0x81,
+0x40,0x7e,0x90,0x08,0x10,0x10,0x10,0xbe,0x92,0x92,0x92,0x92,0x92,0xa2,0xaa,0x44,
+/* 16934 0x4226 "䈦" */
+0x20,0x3f,0x48,0x85,0x24,0x23,0x24,0x3f,0x10,0x22,0x47,0x08,0x14,0x03,0x1c,0xe0,
+0x40,0x7e,0x90,0x08,0x48,0x88,0x48,0xf8,0x10,0x08,0xe4,0x20,0x40,0x80,0x70,0x0e,
+/* 16935 0x4227 "䈧" */
+0x20,0x3e,0x48,0x80,0x7f,0x22,0x11,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x2a,0x4a,0x80,
+0x40,0x7e,0x90,0xf8,0x00,0x10,0x20,0xe0,0x20,0xf0,0x10,0xfc,0x04,0xa4,0xa4,0x0c,
+/* 16936 0x4228 "䈨" */
+0x20,0x3f,0x48,0x85,0x00,0x7d,0x45,0x49,0x51,0x49,0x45,0x45,0x55,0x49,0x41,0x41,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x24,0x28,0x10,0x48,0x86,0x00,
+/* 16937 0x4229 "䈩" */
+0x20,0x3f,0x48,0x85,0x08,0x14,0x22,0x5d,0x80,0x11,0x09,0x4a,0x27,0xf8,0x40,0x00,
+0x40,0x7e,0x90,0x08,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x04,0x14,0x08,
+/* 16938 0x422a "䈪" */
+0x20,0x3f,0x48,0x85,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x48,0x44,0x5f,0x41,0x41,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x24,0x44,0xf4,0x04,0x0c,
+/* 16939 0x422b "䈫" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0x25,0x7d,0x09,0x11,0x25,0x7d,0x01,0x55,0x55,0x81,
+0x40,0x7e,0x90,0x08,0x20,0x20,0xfc,0x24,0x24,0x54,0x4c,0x84,0x04,0x04,0x14,0x08,
+/* 16940 0x422c "䈬" */
+0x20,0x3f,0x48,0x85,0x40,0x27,0x20,0x87,0x44,0x57,0x14,0xe7,0x24,0x24,0x24,0x04,
+0x40,0x7e,0x90,0x08,0x44,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 16941 0x422d "䈭" */
+0x20,0x20,0x7e,0x51,0x8a,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x90,0xa8,0xfa,0x8a,0x7e,
+/* 16942 0x422e "䈮" */
+0x20,0x3f,0x48,0x85,0x20,0x10,0x10,0xfd,0x02,0x48,0x48,0x48,0x10,0x1e,0xf0,0x40,
+0x40,0x7e,0x90,0x08,0x80,0x80,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x94,0x04,0x28,0x10,
+/* 16943 0x422f "䈯" */
+0x20,0x3e,0x49,0xbf,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x10,
+0x80,0xfe,0x10,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x10,
+/* 16944 0x4230 "䈰" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0x10,0xfc,0x11,0x11,0x1d,0xf1,0x51,0x11,0x51,0x21,
+0x40,0x7e,0x90,0x08,0x20,0x24,0xa8,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 16945 0x4231 "䈱" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x22,0x11,0x0c,0x30,0x20,0x3c,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0xfc,0x00,0x08,0x10,0x20,0x78,0x08,0x78,0x08,0xf8,0x08,
+/* 16946 0x4232 "䈲" */
+0x20,0x3f,0x48,0x85,0x10,0x3e,0x22,0x2a,0x23,0xfe,0x22,0x2a,0x22,0x42,0x4a,0x84,
+0x40,0x7e,0x90,0x08,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 16947 0x4233 "䈳" */
+0x20,0x3f,0x48,0x9f,0x10,0x1f,0x10,0x1f,0x00,0x7e,0x22,0x12,0x0a,0x12,0x6a,0x04,
+0x40,0x7e,0x90,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x24,0x14,0x24,0xd4,0x08,
+/* 16948 0x4234 "䈴" */
+0x20,0x3f,0x48,0x85,0x10,0x08,0x7f,0x04,0x3f,0x04,0xff,0x04,0x3f,0x0c,0x34,0xc4,
+0x40,0x7e,0x90,0x08,0x20,0x40,0xfc,0x80,0xf0,0x90,0xfe,0x90,0xf0,0xa0,0x98,0x86,
+/* 16949 0x4235 "䈵" */
+0x20,0x3f,0x48,0x85,0x08,0x32,0xc4,0x0f,0x00,0x7e,0x22,0x12,0x0a,0x12,0x2a,0x44,
+0x40,0x7e,0x90,0x48,0x20,0x18,0x46,0xe0,0x20,0xfc,0x44,0x24,0x14,0x24,0x54,0x88,
+/* 16950 0x4236 "䈶" */
+0x10,0x10,0x3f,0x4a,0x85,0x7f,0x40,0x89,0x12,0x24,0x08,0x3f,0xc8,0x08,0x0f,0x08,
+0x40,0x40,0x7e,0x90,0x08,0xfe,0x02,0x24,0x90,0x48,0x20,0xf8,0x26,0x20,0xe0,0x20,
+/* 16951 0x4237 "䈷" */
+0x20,0x3f,0x48,0x95,0x10,0x10,0xfd,0x12,0x30,0x39,0x56,0x51,0x91,0x11,0x11,0x11,
+0x40,0x7e,0x90,0x08,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 16952 0x4238 "䈸" */
+0x20,0x3f,0x48,0x85,0x10,0x1f,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x24,0x42,0x81,
+0x40,0x7e,0x90,0x08,0x04,0x24,0x14,0x84,0xa4,0x94,0x86,0xbc,0x84,0x84,0x84,0x04,
+/* 16953 0x4239 "䈹" */
+0x20,0x3f,0x48,0x85,0x7f,0x48,0x8b,0x10,0x33,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x40,0x7e,0x90,0x08,0xfe,0x02,0xf4,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 16954 0x423a "䈺" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0x24,0x7d,0x08,0x10,0x27,0x7c,0x00,0x54,0x54,0x80,
+0x40,0x7e,0x90,0x08,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0x60,0x10,0xc0,0x30,0x08,
+/* 16955 0x423b "䈻" */
+0x20,0x3f,0x48,0x85,0x00,0x78,0x4b,0x48,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x99,
+0x40,0x7e,0x90,0x08,0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x0c,
+/* 16956 0x423c "䈼" */
+0x20,0x3f,0x50,0x8a,0x01,0x7f,0x42,0x89,0x28,0x49,0x0e,0x77,0x01,0x21,0x21,0x3f,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x02,0x24,0x48,0x94,0x10,0xf0,0x00,0x08,0x08,0xf8,
+/* 16957 0x423d "䈽" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x0f,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x01,0xff,
+0x40,0x7e,0x90,0x08,0x20,0xfc,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xfe,
+/* 16958 0x423e "䈾" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0xfc,0x10,0x31,0x39,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x7e,0x90,0x08,0x20,0x24,0xa8,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 16959 0x423f "䈿" */
+0x20,0x3f,0x48,0x85,0x7f,0x40,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x08,0xfc,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x10,0x08,
+/* 16960 0x4240 "䉀" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x23,0x20,0x4a,0x49,0x91,
+0x40,0x7e,0x90,0x08,0x80,0xfc,0x20,0x20,0xfc,0x20,0x20,0xe0,0x00,0x48,0x24,0x24,
+/* 16961 0x4241 "䉁" */
+0x20,0x3f,0x48,0x85,0x00,0xff,0x22,0x3e,0x22,0x3e,0x22,0x23,0xfe,0x02,0x02,0x02,
+0x40,0x7e,0x90,0x08,0x10,0x90,0x28,0x44,0x92,0x08,0x7c,0x84,0x08,0x30,0x08,0x04,
+/* 16962 0x4242 "䉂" */
+0x20,0x3e,0x48,0x9f,0x11,0x1f,0x11,0x1f,0x04,0x08,0x1f,0x03,0x3f,0x11,0x25,0x42,
+0x40,0x7e,0x90,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x20,0xc0,0x10,0xf8,0x20,0x10,0x08,
+/* 16963 0x4243 "䉃" */
+0x20,0x3f,0x48,0x85,0x04,0x24,0x24,0x3d,0x04,0x04,0x7d,0x24,0x24,0x24,0x44,0x84,
+0x40,0x7e,0x90,0x08,0x40,0x7c,0xa8,0x50,0x28,0x48,0xfe,0x88,0x48,0x48,0x08,0x18,
+/* 16964 0x4244 "䉄" */
+0x20,0x3f,0x48,0x85,0x78,0x4b,0x50,0x67,0x51,0x4a,0x4c,0x69,0x52,0x40,0x41,0x4e,
+0x40,0x7e,0x90,0x08,0x40,0xf8,0x40,0xfc,0x10,0x88,0xf4,0x10,0xa0,0x40,0xb0,0x0e,
+/* 16965 0x4245 "䉅" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x7c,0x11,0xfe,0x44,0x28,0x7c,0x10,0xfe,0x11,0x12,
+0x40,0x40,0x7e,0x90,0x48,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,
+/* 16966 0x4246 "䉆" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x84,0x00,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x94,0x08,
+/* 16967 0x4247 "䉇" */
+0x20,0x3f,0x48,0x95,0x11,0x7f,0x11,0x1f,0x11,0x1f,0x11,0x7f,0x29,0x30,0x20,0x3f,
+0x40,0x7e,0x90,0x08,0x04,0xc4,0x24,0x24,0x24,0x24,0x24,0xe4,0x24,0x84,0x14,0xc8,
+/* 16968 0x4248 "䉈" */
+0x20,0x3f,0x48,0x85,0x24,0x7e,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 16969 0x4249 "䉉" */
+0x20,0x3f,0x48,0x85,0x20,0x3e,0x44,0x7e,0xaa,0x3e,0x2a,0x3e,0x2a,0x2b,0x2b,0x46,
+0x40,0x7e,0x90,0x08,0x00,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0x54,0x74,0x12,
+/* 16970 0x424a "䉊" */
+0x20,0x3e,0x55,0x88,0x1f,0x02,0xff,0x09,0x3f,0xd1,0x1f,0x11,0x1f,0x01,0x7f,0x01,
+0x80,0xfe,0x10,0x20,0xf0,0x10,0xfe,0x20,0xf8,0x16,0xf0,0x10,0xf0,0x00,0xfc,0x00,
+/* 16971 0x424b "䉋" */
+0x20,0x3f,0x48,0x85,0x11,0x11,0xfd,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x40,0x7e,0x90,0x08,0xfc,0x24,0xfc,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+/* 16972 0x424c "䉌" */
+0x20,0x3f,0x48,0x85,0x78,0x4b,0x48,0x51,0x56,0x48,0x49,0x4e,0x68,0x51,0x46,0x40,
+0x40,0x7e,0x90,0x08,0x90,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 16973 0x424d "䉍" */
+0x20,0x3f,0x48,0x85,0x7c,0x44,0x7c,0x44,0x7d,0x40,0x4a,0x4a,0x52,0x41,0x40,0x40,
+0x40,0x7e,0x90,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x84,0x24,0x14,0x54,0xc4,0x14,0x08,
+/* 16974 0x424e "䉎" */
+0x20,0x3f,0x48,0x85,0x11,0x09,0x3f,0x20,0x4f,0x08,0x0f,0x01,0x7f,0x05,0x19,0x61,
+0x40,0x7e,0x90,0x08,0x10,0x20,0xfc,0x04,0xe8,0x20,0xe0,0x00,0xfc,0x40,0x30,0x0c,
+/* 16975 0x424f "䉏" */
+0x20,0x3f,0x48,0x85,0x10,0x1e,0x22,0x7f,0xa9,0x3f,0x29,0x3f,0x29,0x29,0x45,0x82,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x24,0x44,0x9c,0x50,0x7c,0x90,0xfe,0x10,0x10,0x10,
+/* 16976 0x4250 "䉐" */
+0x20,0x3f,0x48,0x85,0x10,0xfe,0x10,0x7d,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x20,0xfc,0x20,0x20,0xf8,0x88,0x88,0x88,0xf8,0x88,
+/* 16977 0x4251 "䉑" */
+0x20,0x3f,0x48,0x85,0x10,0x3f,0x4a,0x0a,0x7f,0x0a,0x0a,0x7f,0x00,0x24,0x22,0x42,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0xa0,0xa0,0xfc,0xa0,0xa0,0xfc,0x00,0x88,0x44,0x44,
+/* 16978 0x4252 "䉒" */
+0x20,0x3e,0x49,0x80,0x3f,0x11,0x09,0xff,0x09,0x30,0xdf,0x11,0x1f,0x11,0x1f,0x10,
+0x80,0xfe,0x10,0xf8,0x00,0x10,0x20,0xfe,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x10,
+/* 16979 0x4253 "䉓" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0x11,0xfd,0x31,0x39,0x54,0x53,0x90,0x11,0x12,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 16980 0x4254 "䉔" */
+0x20,0x3f,0x50,0x88,0x00,0x00,0xfb,0x20,0x3c,0x45,0x48,0xa8,0x13,0x10,0x20,0xc1,
+0x40,0x7e,0x90,0x08,0x90,0x88,0xfe,0x48,0x32,0xce,0x90,0x88,0xfe,0x48,0x32,0xce,
+/* 16981 0x4255 "䉕" */
+0x20,0x3f,0x48,0x85,0x08,0x04,0x3f,0x29,0x25,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x40,0x7e,0x90,0x08,0x20,0x40,0xf8,0x28,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 16982 0x4256 "䉖" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x40,0x7e,0x90,0x08,0x10,0x10,0x28,0x44,0x92,0x08,0x7c,0x04,0x08,0xb0,0x08,0x04,
+/* 16983 0x4257 "䉗" */
+0x20,0x3f,0x48,0x85,0x11,0x11,0xfd,0x10,0x13,0x11,0x1d,0xf1,0x11,0x11,0x57,0x20,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,
+/* 16984 0x4258 "䉘" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0x13,0xfa,0x14,0x30,0x39,0x54,0x50,0x91,0x12,0x10,
+0x40,0x7e,0x90,0x08,0x40,0x20,0xfe,0x02,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 16985 0x4259 "䉙" */
+0x20,0x3e,0x48,0xbf,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x00,0xff,0x10,0x3f,
+0x40,0x7e,0x90,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x00,0xfe,0x10,0xf8,
+/* 16986 0x425a "䉚" */
+0x20,0x3f,0x48,0x85,0x3f,0x24,0x3f,0x00,0x7f,0x40,0xbf,0x08,0x0f,0x11,0x16,0x18,
+0x40,0x7e,0x90,0x08,0xf8,0x48,0xf8,0x00,0xfe,0x02,0xf4,0x00,0xe0,0x24,0xa4,0x1c,
+/* 16987 0x425b "䉛" */
+0x20,0x3e,0x48,0x84,0x3f,0x29,0x25,0x2f,0x25,0x28,0x01,0xff,0x02,0x0c,0x30,0xc0,
+0x40,0x7e,0x90,0x00,0xf8,0x28,0x48,0xe8,0x48,0x28,0x00,0xfe,0x80,0x60,0x18,0x06,
+/* 16988 0x425c "䉜" */
+0x20,0x3f,0x48,0x85,0x20,0x20,0x7d,0x91,0x13,0x11,0xfd,0x11,0x29,0x25,0x41,0x81,
+0x40,0x7e,0x90,0x08,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 16989 0x425d "䉝" */
+0x20,0x3f,0x48,0x95,0x08,0x3f,0x01,0x7f,0x02,0x3c,0x08,0xff,0x08,0x7e,0x08,0x19,
+0x40,0x7e,0x90,0x18,0x20,0xf8,0x00,0xfc,0x40,0x50,0x48,0xfe,0x50,0x24,0x54,0x8c,
+/* 16990 0x425e "䉞" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x20,0x2f,0x20,0x2f,0x48,0x4f,0x82,0x09,0x28,0x47,
+0x40,0x7e,0x90,0x08,0x28,0xfe,0x20,0xa4,0x28,0x90,0xaa,0xc6,0x82,0x00,0x28,0xe4,
+/* 16991 0x425f "䉟" */
+0x20,0x3e,0x48,0x81,0x11,0x13,0xfd,0x11,0x15,0x19,0x31,0xd1,0x13,0x11,0x50,0x27,
+0x40,0x7e,0x90,0x20,0xfc,0x20,0xf8,0x20,0xf8,0x20,0xf8,0x00,0xf8,0x10,0xe0,0x1e,
+/* 16992 0x4260 "䉠" */
+0x20,0x3f,0x48,0x85,0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x29,0x29,0x29,0x30,
+0x40,0x7e,0x90,0x08,0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0x28,0x10,0xa8,0x44,0x82,
+/* 16993 0x4261 "䉡" */
+0x20,0x3e,0x49,0xff,0x00,0x3f,0x20,0x27,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x00,0xff,
+0x80,0xfe,0x10,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 16994 0x4262 "䉢" */
+0x20,0x3e,0x48,0x81,0x7f,0x11,0x29,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,
+0x40,0x7e,0x90,0x00,0xfc,0x10,0x28,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,
+/* 16995 0x4263 "䉣" */
+0x20,0x3e,0x48,0x82,0x1c,0x10,0x1e,0x10,0x1f,0x08,0x1f,0x20,0x49,0x24,0x24,0x40,
+0x40,0x7e,0x90,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x24,0x94,0x94,0x08,
+/* 16996 0x4264 "䉤" */
+0x20,0x3f,0x48,0x85,0x49,0x2a,0xff,0x2a,0x49,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 16997 0x4265 "䉥" */
+0x20,0x3f,0x48,0x85,0x11,0x11,0xfd,0x11,0x15,0x19,0x31,0xd1,0x10,0x12,0x52,0x24,
+0x40,0x7e,0x90,0x48,0xfe,0x22,0x7a,0x8a,0x52,0x22,0x52,0xfe,0x40,0xa4,0x8a,0x7a,
+/* 16998 0x4266 "䉦" */
+0x20,0x3e,0x48,0x8f,0x41,0x2f,0x29,0x0f,0xe1,0x2f,0x24,0x2b,0x32,0x23,0x52,0x8f,
+0x40,0x7e,0x90,0xf8,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x10,0xe8,0x24,0xe0,0x08,0xfe,
+/* 16999 0x4267 "䉧" */
+0x20,0x3e,0x48,0xf7,0x42,0x62,0x54,0x69,0x14,0x22,0xdd,0x08,0x7f,0x4a,0x2f,0xf0,
+0x40,0x7e,0x90,0x84,0x84,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x94,0x08,
+/* 17000 0x4268 "䉨" */
+0x20,0x3e,0x48,0x90,0x08,0x7f,0x22,0x14,0x7f,0x10,0x69,0x16,0x6d,0x14,0x64,0x18,
+0x40,0x7e,0x90,0x00,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x90,0x28,0xc6,
+/* 17001 0x4269 "䉩" */
+0x20,0x3f,0x48,0x85,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x13,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xee,0xaa,0xee,0x00,0xfe,
+/* 17002 0x426a "䉪" */
+0x20,0x3f,0x48,0x85,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x82,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x82,
+/* 17003 0x426b "䉫" */
+0x20,0x3e,0x48,0x86,0x38,0x08,0x7e,0x1c,0x2a,0x49,0x02,0x1d,0xe9,0x05,0x09,0x13,
+0x40,0x7e,0x90,0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0xc0,0x30,0x2e,0x40,0x20,0x10,
+/* 17004 0x426c "䉬" */
+0x20,0x3e,0x49,0x80,0x3f,0x20,0x2f,0x31,0x2a,0x27,0x29,0x37,0x28,0x4f,0x41,0x87,
+0x80,0xfe,0x10,0x80,0xfe,0x20,0x28,0x10,0x0a,0x7c,0x4a,0x84,0x78,0x48,0x30,0x4c,
+/* 17005 0x426d "䉭" */
+0x20,0x3e,0x49,0x90,0x21,0x10,0x3f,0x24,0x23,0x24,0x3f,0x29,0x25,0x29,0x25,0x31,
+0x80,0xfe,0x10,0x84,0x08,0x84,0xf8,0x48,0x88,0x48,0xf8,0x48,0x28,0x4a,0x26,0x82,
+/* 17006 0x426e "䉮" */
+0x20,0x3e,0x48,0xfc,0x44,0x7c,0x44,0x7d,0x44,0x4f,0x59,0x4f,0x49,0x4f,0x49,0x4f,
+0x40,0x7e,0x90,0x7c,0x44,0x7c,0x44,0x7c,0x84,0xe4,0x04,0xc4,0x04,0xc4,0x04,0xec,
+/* 17007 0x426f "䉯" */
+0x20,0x3e,0x48,0xbf,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0x7e,0x90,0x7c,0x44,0x28,0x10,0x28,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 17008 0x4270 "䉰" */
+0x20,0x3e,0x48,0xbe,0x22,0x3a,0x2a,0x7f,0x41,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,
+0x40,0x7e,0x90,0x20,0x10,0xfe,0x00,0x28,0x44,0x82,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17009 0x4271 "䉱" */
+0x20,0x3f,0x48,0xa5,0x10,0x03,0xfa,0x0a,0x12,0x2a,0x72,0xaa,0x2a,0x22,0x22,0x23,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xee,0xaa,0xee,0x00,0xfe,
+/* 17010 0x4272 "䉲" */
+0x20,0x3e,0x48,0x80,0xf7,0x12,0x17,0xfc,0x86,0x85,0xf6,0x15,0x16,0x14,0x54,0x24,
+0x40,0x7e,0x90,0x00,0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 17011 0x4273 "䉳" */
+0x20,0x3f,0x48,0x85,0x20,0x3e,0x44,0xff,0x49,0x7f,0x49,0x7f,0x00,0x55,0x4a,0x8a,
+0x40,0x7e,0x90,0x08,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x10,0x90,0x90,
+/* 17012 0x4274 "䉴" */
+0x20,0x3f,0x48,0x85,0x7f,0x00,0x3e,0x22,0x3e,0x04,0x3f,0x04,0xff,0x04,0x1c,0x67,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x88,0xf8,0x40,0xf8,0x40,0xfe,0x90,0x60,0x1c,
+/* 17013 0x4275 "䉵" */
+0x20,0x3f,0x48,0x9f,0x14,0x12,0x1f,0x02,0xff,0x0a,0x34,0xcf,0x15,0x07,0x04,0x06,
+0x40,0x7e,0x90,0xf8,0x90,0x50,0xf0,0x00,0xfe,0xa0,0x58,0xe6,0x50,0xc0,0xa0,0x70,
+/* 17014 0x4276 "䉶" */
+0x20,0x3e,0x48,0xa4,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,0x1f,0x08,0x07,0xf8,
+0x40,0x7e,0x90,0x48,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,0x40,0xf0,0x20,0xc0,0x3e,
+/* 17015 0x4277 "䉷" */
+0x20,0x3f,0x48,0x85,0x1e,0x12,0x3f,0x20,0x2e,0x22,0x3f,0x29,0x2f,0x49,0x5f,0x81,
+0x40,0x7e,0x90,0x08,0x78,0x48,0xfc,0x20,0x20,0x3c,0xc8,0x28,0x28,0x90,0x28,0x44,
+/* 17016 0x4278 "䉸" */
+0x20,0x20,0x7e,0x51,0x88,0x41,0x27,0xf8,0x53,0x20,0xfb,0x20,0x73,0x22,0x43,0x82,
+0x40,0x40,0xfe,0x10,0x08,0x10,0x88,0x3e,0x94,0x08,0xbe,0x08,0x9c,0x88,0x88,0x88,
+/* 17017 0x4279 "䉹" */
+0x20,0x3e,0x48,0xbf,0x01,0x7f,0x49,0x84,0x3b,0x2a,0x3b,0x00,0x7f,0x11,0x29,0xff,
+0x40,0x7e,0x90,0xf8,0x00,0xfe,0x22,0x14,0xb8,0xa8,0xb8,0x00,0xfc,0x10,0x28,0xfe,
+/* 17018 0x427a "䉺" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x09,0x08,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 17019 0x427b "䉻" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 17020 0x427c "䉼" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x09,0x09,0x0a,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 17021 0x427d "䉽" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfd,0x30,0x38,0x54,0x57,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 17022 0x427e "䉾" */
+0x04,0x04,0x7c,0x04,0x04,0x1c,0xe4,0x00,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x44,0x78,0x40,0x42,0x42,0x3e,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 17023 0x427f "䉿" */
+0x10,0x10,0x95,0x54,0x59,0x10,0xfc,0x30,0x39,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17024 0x4280 "䊀" */
+0x10,0x10,0x94,0x54,0x5b,0x10,0xfc,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 17025 0x4281 "䊁" */
+0x10,0x11,0x95,0x55,0x59,0x12,0xfc,0x33,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 17026 0x4282 "䊂" */
+0x10,0x10,0x97,0x54,0x58,0x11,0xfd,0x31,0x39,0x55,0x54,0x90,0x11,0x16,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x2c,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 17027 0x4283 "䊃" */
+0x20,0x27,0x24,0xac,0x75,0x24,0xfc,0x25,0x75,0x6d,0xad,0x25,0x25,0x24,0x24,0x28,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0x44,0xf4,0x54,0x54,0x54,0x54,0x74,0x46,0x46,0x42,
+/* 17028 0x4284 "䊄" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 17029 0x4285 "䊅" */
+0x10,0x10,0x94,0x55,0x5a,0x10,0xfc,0x30,0x38,0x55,0x56,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 17030 0x4286 "䊆" */
+0x04,0x38,0x20,0x20,0x3c,0x20,0x20,0x3f,0x00,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,
+0x00,0x78,0x08,0x08,0x78,0x08,0x08,0xf8,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,
+/* 17031 0x4287 "䊇" */
+0x10,0x10,0x95,0x54,0x58,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 17032 0x4288 "䊈" */
+0x10,0x10,0x94,0x55,0x5a,0x10,0xfc,0x30,0x3b,0x54,0x55,0x91,0x11,0x10,0x10,0x10,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 17033 0x4289 "䊉" */
+0x10,0x10,0x95,0x55,0x5a,0x10,0xfc,0x31,0x38,0x54,0x54,0x90,0x11,0x12,0x10,0x10,
+0x40,0x20,0xfc,0x04,0x28,0x20,0x20,0xfc,0x70,0x68,0xa8,0xa4,0x24,0x22,0x20,0x20,
+/* 17034 0x428a "䊊" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x12,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x1c,0x70,0x1c,0x70,0x1e,0xf0,0x10,0x12,0x12,0x0e,
+/* 17035 0x428b "䊋" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfc,0x30,0x3b,0x55,0x55,0x91,0x11,0x11,0x12,0x14,
+0x48,0x48,0x48,0x48,0x48,0xc8,0x7e,0x48,0xc8,0x48,0x48,0x48,0x48,0x48,0x5c,0x40,
+/* 17036 0x428c "䊌" */
+0x10,0x10,0x94,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0x10,0xfe,0x00,0x48,0x4a,0x4a,0x6c,0x48,0x48,0x4a,0x4a,0x6a,0x46,0x00,
+/* 17037 0x428d "䊍" */
+0x0c,0x70,0x11,0xfd,0x12,0x38,0x54,0x91,0x10,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,
+0x80,0xfc,0x24,0x24,0x24,0x44,0x84,0x28,0x10,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,
+/* 17038 0x428e "䊎" */
+0x10,0x11,0x94,0x54,0x59,0x10,0xfd,0x30,0x39,0x56,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 17039 0x428f "䊏" */
+0x10,0x10,0x94,0x55,0x58,0x10,0xfd,0x30,0x38,0x54,0x54,0x91,0x10,0x10,0x11,0x12,
+0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x24,0x20,0xa8,0xa8,0x30,0x50,0x88,0x04,0x02,
+/* 17040 0x4290 "䊐" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 17041 0x4291 "䊑" */
+0x10,0x11,0x94,0x54,0x58,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 17042 0x4292 "䊒" */
+0x10,0x10,0x94,0x55,0x59,0x13,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 17043 0x4293 "䊓" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x38,0x57,0x54,0x91,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 17044 0x4294 "䊔" */
+0x20,0x20,0x23,0xa8,0x70,0x20,0xf9,0x21,0x71,0x69,0xab,0x20,0x20,0x20,0x21,0x22,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 17045 0x4295 "䊕" */
+0x20,0x20,0x20,0xab,0x71,0x21,0xfa,0x22,0x77,0x69,0xa9,0x25,0x22,0x23,0x24,0x28,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 17046 0x4296 "䊖" */
+0x20,0x20,0x23,0xa8,0x70,0x23,0xfa,0x22,0x72,0x6a,0xaa,0x22,0x22,0x22,0x22,0x22,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 17047 0x4297 "䊗" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x30,0x3b,0x54,0x54,0x91,0x10,0x10,0x13,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17048 0x4298 "䊘" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 17049 0x4299 "䊙" */
+0x00,0xfd,0x20,0x40,0x7d,0xc4,0x44,0x7d,0x00,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,
+0x00,0xfe,0x48,0x48,0xfe,0x48,0x88,0x08,0x08,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,
+/* 17050 0x429a "䊚" */
+0x20,0x22,0x21,0xa9,0x70,0x20,0xfb,0x21,0x71,0x69,0xa9,0x21,0x21,0x22,0x24,0x20,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 17051 0x429b "䊛" */
+0x20,0x24,0x22,0xa9,0x72,0x24,0xf9,0x21,0x77,0x69,0xad,0x25,0x29,0x21,0x25,0x22,
+0x00,0x5c,0x94,0x14,0x94,0x54,0x26,0x00,0xdc,0x14,0x94,0x54,0x48,0x08,0x14,0x22,
+/* 17052 0x429c "䊜" */
+0x10,0x13,0x94,0x55,0x59,0x11,0xfd,0x31,0x38,0x57,0x54,0x93,0x11,0x10,0x10,0x10,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 17053 0x429d "䊝" */
+0x10,0x11,0x94,0x55,0x58,0x13,0xfc,0x30,0x39,0x56,0x54,0x90,0x12,0x12,0x14,0x10,
+0x1c,0xe0,0x20,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 17054 0x429e "䊞" */
+0x20,0x20,0x23,0xa8,0x70,0x23,0xfa,0x22,0x72,0x6a,0xaa,0x22,0x22,0x22,0x22,0x22,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 17055 0x429f "䊟" */
+0x20,0x20,0x23,0xa8,0x70,0x20,0xf8,0x23,0x72,0x6b,0xaa,0x23,0x22,0x22,0x22,0x22,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 17056 0x42a0 "䊠" */
+0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 17057 0x42a1 "䊡" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfc,0x33,0x3a,0x57,0x54,0x91,0x10,0x10,0x11,0x16,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 17058 0x42a2 "䊢" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x84,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,
+/* 17059 0x42a3 "䊣" */
+0x10,0x10,0x95,0x54,0x58,0x13,0xfc,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 17060 0x42a4 "䊤" */
+0x10,0x13,0x94,0x57,0x5a,0x13,0xfc,0x31,0x39,0x55,0x55,0x91,0x10,0x13,0x10,0x10,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 17061 0x42a5 "䊥" */
+0x20,0x21,0x20,0xab,0x70,0x21,0xf8,0x22,0x73,0x6a,0xab,0x22,0x23,0x22,0x22,0x24,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 17062 0x42a6 "䊦" */
+0x10,0x13,0x94,0x55,0x58,0x13,0xfe,0x31,0x38,0x55,0x55,0x91,0x11,0x10,0x13,0x10,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 17063 0x42a7 "䊧" */
+0x20,0x27,0x20,0xab,0x72,0x23,0xf9,0x23,0x75,0x69,0xa9,0x21,0x21,0x21,0x20,0x21,
+0x90,0xfc,0x94,0xfc,0x90,0xfe,0x12,0xfa,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,
+/* 17064 0x42a8 "䊨" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x01,0x75,0x53,0x77,0x51,0x73,0x55,0xb1,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x5c,0x94,0xd4,0x14,0x96,0x56,0x22,
+/* 17065 0x42a9 "䊩" */
+0x10,0x13,0x95,0x54,0x5b,0x10,0xfd,0x32,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 17066 0x42aa "䊪" */
+0x10,0x10,0x97,0x54,0x59,0x11,0xfd,0x31,0x39,0x54,0x57,0x92,0x12,0x12,0x12,0x12,
+0x88,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 17067 0x42ab "䊫" */
+0x20,0x23,0x22,0xaa,0x73,0x20,0xf8,0x27,0x70,0x68,0xab,0x20,0x20,0x27,0x20,0x20,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0x90,0x9e,0x90,0x90,0x9c,0x90,0x90,0x9e,0x90,0x90,
+/* 17068 0x42ac "䊬" */
+0x0d,0x71,0x11,0x11,0xfd,0x30,0x3b,0x54,0x51,0x82,0x11,0x09,0x7f,0x05,0x19,0xe1,
+0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x10,0x20,0xfc,0x40,0x30,0x0e,
+/* 17069 0x42ad "䊭" */
+0x10,0x13,0x94,0x55,0x58,0x13,0xfc,0x31,0x38,0x57,0x54,0x93,0x10,0x13,0x12,0x13,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 17070 0x42ae "䊮" */
+0x20,0x23,0x20,0xaa,0x71,0x22,0xf8,0x21,0x73,0x6d,0xa9,0x21,0x21,0x21,0x21,0x21,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 17071 0x42af "䊯" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x28,0x7c,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x44,0x82,
+/* 17072 0x42b0 "䊰" */
+0x22,0x21,0x20,0xab,0x70,0x23,0xf8,0x23,0x70,0x6b,0xaa,0x22,0x22,0x23,0x22,0x20,
+0x10,0x10,0x3a,0x92,0x14,0xbe,0x08,0x90,0x3c,0xe4,0xa4,0xbc,0xa4,0xa4,0xbc,0x24,
+/* 17073 0x42b1 "䊱" */
+0x21,0x21,0x22,0xa8,0x77,0x21,0xfb,0x21,0x73,0x69,0xab,0x21,0x21,0x23,0x20,0x20,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 17074 0x42b2 "䊲" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x10,0x54,0x38,0xfe,0x10,0x38,0x55,0x91,0x12,
+0x10,0x08,0xfe,0x00,0x44,0x28,0xfe,0x88,0xa8,0xbe,0xc8,0x88,0xbe,0x08,0x08,0x7e,
+/* 17075 0x42b3 "䊳" */
+0x20,0x23,0x22,0xab,0x72,0x22,0xfb,0x22,0x72,0x6b,0xaa,0x23,0x22,0x25,0x24,0x28,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 17076 0x42b4 "䊴" */
+0x10,0x10,0x94,0x55,0x5a,0x10,0xfc,0x31,0x3a,0x55,0x55,0x91,0x10,0x10,0x11,0x12,
+0x88,0x88,0xee,0x54,0x22,0x50,0x88,0x74,0x02,0xdc,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 17077 0x42b5 "䊵" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x8a,0x8a,0x06,0x00,
+/* 17078 0x42b6 "䊶" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x23,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 17079 0x42b7 "䊷" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x18,0x28,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 17080 0x42b8 "䊸" */
+0x10,0x11,0x20,0x24,0x44,0xfb,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 17081 0x42b9 "䊹" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x23,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 17082 0x42ba "䊺" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfd,0x05,0x00,0x54,0x54,0x81,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x7c,0x84,0x84,0x84,0x04,0xfc,0x08,0x08,0x08,0xfe,0x00,
+/* 17083 0x42bb "䊻" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x11,0x22,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x40,0x40,0x40,0x7e,0x82,0x84,0x20,0x20,0x20,0x50,0x50,0x48,0x88,0x84,0x02,0x00,
+/* 17084 0x42bc "䊼" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x83,0x00,
+0x10,0x10,0x10,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 17085 0x42bd "䊽" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x4b,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 17086 0x42be "䊾" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x48,0xfc,0x05,0x01,0x56,0x54,0x80,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 17087 0x42bf "䊿" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x4b,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 17088 0x42c0 "䋀" */
+0x01,0x00,0x3f,0x20,0x3f,0x20,0x21,0x23,0x20,0x20,0x27,0x20,0x42,0x44,0x89,0x00,
+0x00,0x80,0xfc,0x04,0xfc,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x50,0x48,0x44,0x80,
+/* 17089 0x42c1 "䋁" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x81,0x02,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 17090 0x42c2 "䋂" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x04,0x44,0x28,0x10,0x28,0x44,0x80,0x04,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17091 0x42c3 "䋃" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x11,0x20,0x48,0xfc,0x07,0x00,0x54,0x54,0x80,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 17092 0x42c4 "䋄" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0x04,0x94,0x54,0x54,0x24,0x24,0x54,0x54,0x94,0x04,0x04,0x14,0x08,
+/* 17093 0x42c5 "䋅" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x11,0x20,0x48,0xfd,0x04,0x00,0x54,0x54,0x80,0x00,
+0x10,0x10,0x90,0x90,0xfe,0x90,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 17094 0x42c6 "䋆" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x56,0x82,0x04,
+0x40,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 17095 0x42c7 "䋇" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x82,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x02,
+/* 17096 0x42c8 "䋈" */
+0x08,0x7f,0x11,0x32,0x0c,0x12,0x63,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0x7c,0x44,0x28,0x10,0x28,0x46,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 17097 0x42c9 "䋉" */
+0x10,0x10,0x20,0x2b,0x4a,0xf4,0x10,0x20,0x48,0xfc,0x04,0x01,0x55,0x55,0x82,0x04,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 17098 0x42ca "䋊" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x83,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 17099 0x42cb "䋋" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 17100 0x42cc "䋌" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 17101 0x42cd "䋍" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x80,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 17102 0x42ce "䋎" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x83,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 17103 0x42cf "䋏" */
+0x10,0x10,0x20,0x24,0x45,0xf9,0x12,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,
+/* 17104 0x42d0 "䋐" */
+0x10,0x10,0x20,0x28,0x4b,0xf2,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xab,0xaa,0x80,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 17105 0x42d1 "䋑" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 17106 0x42d2 "䋒" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x13,0x20,0x48,0xfc,0x05,0x02,0x54,0x54,0x80,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x62,0xa4,0xa0,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17107 0x42d3 "䋓" */
+0x10,0x10,0x20,0x25,0x46,0xfc,0x11,0x20,0x48,0xfc,0x05,0x00,0x54,0x54,0x81,0x00,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 17108 0x42d4 "䋔" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x20,0x49,0xfe,0x04,0x00,0x54,0x54,0x83,0x00,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 17109 0x42d5 "䋕" */
+0x08,0x13,0x30,0x57,0x90,0x13,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x18,0xe0,0x40,0xfc,0x40,0xf8,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 17110 0x42d6 "䋖" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x55,0x54,0x80,0x00,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 17111 0x42d7 "䋗" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 17112 0x42d8 "䋘" */
+0x10,0x10,0x23,0x28,0x48,0xf1,0x10,0x20,0x4b,0xf8,0x08,0x00,0xa9,0xaa,0x84,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 17113 0x42d9 "䋙" */
+0x10,0x13,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x57,0x54,0x80,0x00,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 17114 0x42da "䋚" */
+0x10,0x13,0x20,0x28,0x4a,0xf1,0x11,0x20,0x48,0xf9,0x0a,0x00,0xa8,0xa8,0x81,0x00,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 17115 0x42db "䋛" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x23,0x48,0xfc,0x04,0x01,0x55,0x56,0x80,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 17116 0x42dc "䋜" */
+0x10,0x08,0x3e,0x22,0x22,0x3e,0x22,0x44,0x9f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0xfc,0x44,0x28,0x10,0x28,0x46,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 17117 0x42dd "䋝" */
+0x10,0x10,0x22,0x25,0x45,0xf8,0x10,0x20,0x4b,0xfc,0x05,0x01,0x54,0x54,0x81,0x06,
+0x40,0x24,0x24,0x08,0x08,0x10,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 17118 0x42de "䋞" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xac,0x54,0x54,0x54,0x54,0xac,0x04,0x04,0x04,0x14,0x08,
+/* 17119 0x42df "䋟" */
+0x10,0x11,0x20,0x24,0x45,0xf9,0x11,0x21,0x48,0xfc,0x04,0x00,0xaa,0xaa,0x84,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x04,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 17120 0x42e0 "䋠" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 17121 0x42e1 "䋡" */
+0x10,0x10,0x20,0x28,0x49,0xf2,0x10,0x20,0x4b,0xf8,0x09,0x01,0xaa,0xac,0x80,0x00,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 17122 0x42e2 "䋢" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x16,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x48,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17123 0x42e3 "䋣" */
+0x20,0x20,0x3f,0x40,0xbe,0x22,0x32,0x2a,0xff,0x22,0x52,0x4a,0x7f,0x02,0x14,0x08,
+0x10,0x10,0x24,0x44,0xf8,0x10,0x20,0x44,0x7e,0x12,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 17124 0x42e4 "䋤" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0xff,0x10,0x22,0x7c,0x09,0xff,0x08,0x49,0xa8,0x10,
+0x40,0x40,0x40,0x7c,0x84,0x84,0x04,0x44,0x24,0x24,0x04,0x84,0x84,0x04,0xa8,0x10,
+/* 17125 0x42e5 "䋥" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x48,0xfc,0x05,0x00,0x54,0x54,0x83,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 17126 0x42e6 "䋦" */
+0x10,0x10,0x20,0x25,0x46,0xf8,0x10,0x20,0x49,0xfc,0x05,0x01,0x55,0x54,0x80,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 17127 0x42e7 "䋧" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 17128 0x42e8 "䋨" */
+0x10,0x10,0x21,0x24,0x45,0xf8,0x10,0x23,0x48,0xfc,0x05,0x01,0x55,0x55,0x81,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 17129 0x42e9 "䋩" */
+0x10,0x10,0x23,0x2a,0x4a,0xf3,0x12,0x22,0x4b,0xfc,0x04,0x00,0x54,0x55,0x82,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 17130 0x42ea "䋪" */
+0x20,0x27,0x45,0x45,0x95,0xe5,0x26,0x45,0x95,0xf5,0x05,0x15,0xae,0xa4,0x84,0x04,
+0x00,0x7e,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x14,0x08,
+/* 17131 0x42eb "䋫" */
+0x10,0x10,0x20,0x25,0x46,0xf9,0x10,0x20,0x49,0xfc,0x04,0x01,0x54,0x54,0x80,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 17132 0x42ec "䋬" */
+0x10,0x13,0x20,0x28,0x4b,0xf0,0x11,0x22,0x4c,0xf8,0x08,0x02,0xaa,0xac,0x81,0x00,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 17133 0x42ed "䋭" */
+0x10,0x10,0x23,0x28,0x49,0xf3,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 17134 0x42ee "䋮" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x20,0x48,0xfd,0x04,0x01,0x54,0x54,0x83,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 17135 0x42ef "䋯" */
+0x10,0x08,0x3e,0x23,0x22,0x3e,0x22,0x20,0x44,0x88,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x48,0x44,0x7e,0xc0,0x24,0x28,0x12,0x6a,0x46,0x82,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17136 0x42f0 "䋰" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x11,0x22,0xcf,0x02,0x1f,0x09,0x13,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x10,0x48,0x86,0x20,0xf0,0x48,0x20,
+/* 17137 0x42f1 "䋱" */
+0x10,0x10,0x20,0x2b,0x48,0xf1,0x11,0x21,0x4a,0xf8,0x08,0x00,0xa9,0xaa,0x84,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 17138 0x42f2 "䋲" */
+0x10,0x11,0x21,0x29,0x49,0xf0,0x13,0x22,0x4a,0xfb,0x0a,0x02,0xab,0xa8,0x80,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfa,0x42,0x42,0x3e,
+/* 17139 0x42f3 "䋳" */
+0x10,0x10,0x23,0x24,0x44,0xfb,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x50,0x52,0xdc,0x50,0xd2,0x4e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 17140 0x42f4 "䋴" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x21,0x4a,0xfc,0x05,0x00,0x54,0x55,0x82,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 17141 0x42f5 "䋵" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x21,0x4a,0xfd,0x05,0x01,0x55,0x54,0x80,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 17142 0x42f6 "䋶" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x54,0x80,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 17143 0x42f7 "䋷" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17144 0x42f8 "䋸" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x82,0x04,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 17145 0x42f9 "䋹" */
+0x10,0x13,0x20,0x29,0x49,0xf1,0x11,0x20,0x4b,0xfa,0x0a,0x03,0xaa,0xaa,0x83,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 17146 0x42fa "䋺" */
+0x10,0x11,0x27,0x29,0x49,0xf1,0x17,0x21,0x4b,0xfb,0x0d,0x05,0xa9,0xa9,0x81,0x01,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 17147 0x42fb "䋻" */
+0x10,0x10,0x23,0x28,0x48,0xf3,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 17148 0x42fc "䋼" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x21,0x4a,0xfc,0x05,0x01,0xa9,0xa9,0x83,0x00,
+0x00,0xf8,0x88,0x90,0xfc,0x54,0x24,0x54,0x88,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 17149 0x42fd "䋽" */
+0x21,0x21,0x41,0x47,0x91,0xe1,0x27,0x40,0x91,0xf1,0x07,0x11,0xa9,0xa1,0x8e,0x04,
+0x04,0x04,0x04,0xc4,0x3e,0x04,0xc4,0x24,0x14,0x14,0xc4,0x04,0x04,0xc4,0x14,0x08,
+/* 17150 0x42fe "䋾" */
+0x10,0x10,0x23,0x28,0x49,0xf6,0x10,0x23,0x48,0xf8,0x0f,0x00,0xab,0xa8,0x80,0x07,
+0x00,0x40,0xfe,0x88,0x04,0x42,0xfc,0x08,0xb0,0xd0,0x3e,0xc2,0x24,0x18,0x60,0x80,
+/* 17151 0x42ff "䋿" */
+0x10,0x11,0x21,0x29,0x49,0xf1,0x11,0x21,0x48,0xfb,0x09,0x01,0xa9,0xa9,0x81,0x01,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 17152 0x4300 "䌀" */
+0x10,0x17,0x21,0x29,0x49,0xf7,0x11,0x21,0x4b,0xfb,0x0d,0x05,0xa9,0xa9,0x81,0x01,
+0xc4,0x04,0x24,0x14,0x14,0x84,0x24,0x14,0x94,0x46,0x3c,0x04,0x04,0x04,0x04,0x04,
+/* 17153 0x4301 "䌁" */
+0x10,0x13,0x20,0x28,0x4b,0xf2,0x12,0x23,0x48,0xfc,0x07,0x00,0x55,0x54,0x80,0x03,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 17154 0x4302 "䌂" */
+0x10,0x13,0x22,0x22,0x4b,0xfa,0x13,0x22,0x4a,0xfb,0x0a,0x12,0xad,0xa4,0x88,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 17155 0x4303 "䌃" */
+0x10,0x10,0x22,0x29,0x48,0xf3,0x12,0x22,0x4b,0xfa,0x0a,0x03,0xaa,0xaa,0x82,0x02,
+0x82,0x82,0xa2,0xca,0x8a,0xea,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x22,0xaa,0x44,
+/* 17156 0x4304 "䌄" */
+0x11,0x10,0x21,0x25,0x45,0xf9,0x11,0x20,0x48,0xfc,0x05,0x00,0x54,0x54,0x80,0x03,
+0xfc,0x20,0xfc,0x24,0x54,0x04,0x2c,0x20,0x3c,0x20,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 17157 0x4305 "䌅" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x82,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 17158 0x4306 "䌆" */
+0x10,0x10,0x23,0x2a,0x4a,0xf3,0x12,0x22,0x4b,0xf8,0x08,0x00,0xa9,0xa9,0x82,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 17159 0x4307 "䌇" */
+0x10,0x10,0x23,0x28,0x4b,0xf2,0x14,0x21,0x48,0xf8,0x0b,0x00,0xa9,0xaa,0x84,0x00,
+0x20,0x20,0xfe,0x20,0xfe,0x42,0x8c,0xf0,0x20,0x44,0xfe,0x22,0x28,0x24,0xa4,0x40,
+/* 17160 0x4308 "䌈" */
+0x10,0x11,0x21,0x29,0x49,0xf1,0x10,0x23,0x48,0xfa,0x09,0x00,0xab,0xa8,0x81,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 17161 0x4309 "䌉" */
+0x10,0x13,0x22,0x2a,0x4b,0xf0,0x10,0x23,0x48,0xf8,0x09,0x01,0xa9,0xa9,0x87,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0x00,0xfe,0x20,0x20,0x3c,0x20,0x20,0x20,0xfe,0x00,
+/* 17162 0x430a "䌊" */
+0x10,0x10,0x23,0x28,0x4a,0xf1,0x11,0x22,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x81,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 17163 0x430b "䌋" */
+0x10,0x10,0x23,0x28,0x48,0xf0,0x10,0x21,0x4a,0xfc,0x04,0x01,0x55,0x55,0x81,0x01,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 17164 0x430c "䌌" */
+0x10,0x13,0x20,0x2a,0x49,0xf2,0x10,0x20,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 17165 0x430d "䌍" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x11,0x21,0x49,0xfc,0x05,0x00,0x55,0x54,0x83,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 17166 0x430e "䌎" */
+0x00,0x7c,0x55,0x54,0x7d,0x54,0x54,0x7c,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x40,0xf8,0x48,0x30,0xce,0xf8,0x88,0xf8,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17167 0x430f "䌏" */
+0x10,0x10,0x23,0x2a,0x48,0xf2,0x12,0x24,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x81,0x00,
+0x40,0x20,0xfe,0x42,0x28,0x94,0xaa,0xca,0xf8,0x00,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 17168 0x4310 "䌐" */
+0x10,0x13,0x20,0x2a,0x49,0xf3,0x12,0x23,0x4a,0xfb,0x0a,0x03,0xa8,0xa9,0x82,0x0c,
+0x0e,0xf0,0x44,0x24,0x08,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x10,0x12,0x0e,
+/* 17169 0x4311 "䌑" */
+0x10,0x13,0x22,0x2b,0x4a,0xf3,0x12,0x22,0x4b,0xf8,0x08,0x01,0xa8,0xa8,0x83,0x00,
+0x00,0xdc,0x94,0xd4,0x54,0xc8,0x88,0x94,0xe2,0x00,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17170 0x4312 "䌒" */
+0x10,0x10,0x23,0x22,0x4a,0xfb,0x12,0x22,0x4b,0xfa,0x0a,0x12,0xaa,0xa4,0x84,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 17171 0x4313 "䌓" */
+0x20,0x3f,0x40,0xbe,0x2a,0xff,0x4a,0x7f,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x78,0x48,0x4c,0x80,0x78,0x28,0x10,0x28,0x44,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17172 0x4314 "䌔" */
+0x10,0x13,0x22,0x2a,0x4a,0xf2,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x83,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 17173 0x4315 "䌕" */
+0x20,0x20,0x47,0x44,0x94,0xe4,0x27,0x44,0x94,0xf5,0x05,0x16,0xa8,0xa8,0x90,0x00,
+0x40,0x20,0xfe,0x90,0x90,0x90,0xfc,0x90,0xd8,0xb8,0xb4,0xd4,0x92,0x90,0x90,0x90,
+/* 17174 0x4316 "䌖" */
+0x10,0x10,0x21,0x2b,0x49,0xf1,0x11,0x21,0x49,0xfd,0x04,0x03,0x54,0x54,0x83,0x00,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 17175 0x4317 "䌗" */
+0x21,0x21,0x43,0x46,0x9a,0xe2,0x27,0x42,0x92,0xf2,0x0f,0x10,0xaa,0xa2,0x84,0x00,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 17176 0x4318 "䌘" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x45,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x20,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17177 0x4319 "䌙" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x81,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 17178 0x431a "䌚" */
+0x10,0x13,0x20,0x28,0x4b,0xf2,0x12,0x23,0x49,0xf8,0x0b,0x00,0xa8,0xa9,0x86,0x00,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 17179 0x431b "䌛" */
+0x10,0x1e,0x22,0x54,0x28,0x10,0x28,0xff,0x00,0x7e,0x00,0x7e,0x00,0x7f,0x42,0x7e,
+0x00,0x0c,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x12,0x50,0x54,0x92,0x12,0x50,0x20,
+/* 17180 0x431c "䌜" */
+0x10,0x12,0x21,0x28,0x4b,0xf0,0x10,0x23,0x48,0xf9,0x08,0x03,0xa8,0xa9,0x86,0x00,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 17181 0x431d "䌝" */
+0x21,0x21,0x47,0x41,0x93,0xe5,0x29,0x40,0x93,0xf0,0x07,0x10,0xaa,0xa4,0x89,0x00,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 17182 0x431e "䌞" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x20,0x49,0xfd,0x05,0x01,0x54,0x54,0x81,0x02,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 17183 0x431f "䌟" */
+0x10,0x13,0x22,0x2a,0x4a,0xf3,0x12,0x22,0x4b,0xfa,0x0e,0x02,0xaa,0xab,0x82,0x00,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 17184 0x4320 "䌠" */
+0x02,0x7f,0x42,0x5e,0x42,0x5d,0x55,0x5e,0x84,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x90,0xd0,0x1e,0xa2,0x88,0x08,0x48,0xd4,0x62,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 17185 0x4321 "䌡" */
+0x10,0x13,0x22,0x2b,0x4a,0xf3,0x10,0x23,0x48,0xfb,0x0a,0x03,0xa9,0xa8,0x87,0x00,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x08,0x90,0xfe,0x00,
+/* 17186 0x4322 "䌢" */
+0x10,0x11,0x20,0x2b,0x4a,0xf1,0x10,0x21,0x48,0xf8,0x0b,0x00,0xa8,0xa8,0x80,0x00,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x50,0xc8,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 17187 0x4323 "䌣" */
+0x11,0x11,0x21,0x2a,0x48,0xf0,0x11,0x21,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x08,0x08,0xee,0x94,0x42,0x10,0xfe,0x02,0xf8,0x88,0xf8,0x80,0xfc,0x84,0xfc,0x84,
+/* 17188 0x4324 "䌤" */
+0x20,0x27,0x42,0x44,0x9f,0xe4,0x26,0x45,0x96,0xf4,0x06,0x15,0xae,0xa4,0x84,0x04,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 17189 0x4325 "䌥" */
+0x10,0x17,0x22,0x21,0x4b,0xf8,0x17,0x20,0x4b,0xf8,0x0b,0x10,0xab,0xa5,0x85,0x08,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 17190 0x4326 "䌦" */
+0x10,0x13,0x20,0x2a,0x49,0xf2,0x10,0x21,0x4b,0xfd,0x09,0x01,0xa9,0xa9,0x81,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 17191 0x4327 "䌧" */
+0x10,0x13,0x20,0x29,0x48,0xf3,0x10,0x21,0x48,0xfb,0x08,0x03,0xa8,0xab,0x82,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 17192 0x4328 "䌨" */
+0x10,0x10,0x23,0x28,0x49,0xf1,0x12,0x25,0x4a,0xf9,0x0a,0x01,0xa8,0xa9,0x82,0x00,
+0x88,0x88,0xfe,0x88,0x10,0xde,0x52,0x54,0x88,0x74,0x02,0xfc,0x20,0x24,0x22,0x60,
+/* 17193 0x4329 "䌩" */
+0x11,0x17,0x21,0x28,0x4b,0xf2,0x12,0x23,0x48,0xfb,0x0a,0x03,0xaa,0xaa,0x84,0x08,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 17194 0x432a "䌪" */
+0x13,0x12,0x23,0x2a,0x4b,0xf2,0x12,0x22,0x4b,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0xde,0x52,0xde,0x52,0xde,0x42,0x7a,0x8a,0x12,0xda,0x8a,0xda,0x8a,0xfa,0x0a,0x04,
+/* 17195 0x432b "䌫" */
+0x13,0x12,0x23,0x2a,0x4b,0xf2,0x13,0x21,0x49,0xfd,0x05,0x01,0x55,0x54,0x81,0x06,
+0xd0,0x90,0xde,0x68,0xc4,0x84,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x12,0x0e,
+/* 17196 0x432c "䌬" */
+0x11,0x10,0x23,0x28,0x4a,0xf1,0x13,0x20,0x4b,0xfa,0x0b,0x02,0xab,0xaa,0x82,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 17197 0x432d "䌭" */
+0x10,0x10,0x23,0x28,0x48,0xf1,0x11,0x23,0x4d,0xf9,0x09,0x01,0xa9,0xaa,0x82,0x04,
+0x88,0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,
+/* 17198 0x432e "䌮" */
+0x11,0x10,0x23,0x2a,0x49,0xf0,0x11,0x20,0x48,0xfb,0x08,0x01,0xaa,0xac,0x80,0x00,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0x9e,0xf2,0x9e,0xd2,0xbe,0x92,0x9e,0x92,
+/* 17199 0x432f "䌯" */
+0x10,0x13,0x20,0x2b,0x4a,0xf3,0x10,0x20,0x49,0xf9,0x0b,0x05,0xa9,0xa9,0x81,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 17200 0x4330 "䌰" */
+0x13,0x11,0x21,0x29,0x49,0xf1,0x17,0x20,0x4f,0xfa,0x0b,0x02,0xab,0xaa,0x87,0x00,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 17201 0x4331 "䌱" */
+0x40,0x7f,0x48,0x8f,0xa0,0xef,0x48,0x4f,0xa1,0xfc,0x15,0x5c,0x55,0x5c,0x95,0x2c,
+0x80,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x9c,0xd4,0x14,0x5c,0x96,0xd6,0x22,
+/* 17202 0x4332 "䌲" */
+0x10,0x13,0x20,0x29,0x48,0xf3,0x10,0x21,0x49,0xfd,0x05,0x00,0x55,0x54,0x83,0x01,
+0x88,0xfe,0x88,0xf0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x54,
+/* 17203 0x4333 "䌳" */
+0x27,0x22,0x47,0x4c,0x96,0xe5,0x26,0x45,0x96,0xf4,0x04,0x17,0xa8,0xa3,0x80,0x07,
+0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x54,0x08,0xfc,0x40,0xf8,0x50,0xfc,
+/* 17204 0x4334 "䌴" */
+0x40,0x7f,0x48,0x8f,0xa0,0xef,0x48,0x4f,0xa2,0xfd,0x17,0x5c,0x55,0x5c,0x97,0x2c,
+0x80,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x20,0x5c,0xf4,0x94,0xdc,0x96,0xf6,0xa2,
+/* 17205 0x4335 "䌵" */
+0x13,0x12,0x23,0x2a,0x4a,0xf2,0x12,0x22,0x4a,0xfb,0x0a,0x02,0xaa,0xaa,0x85,0x00,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 17206 0x4336 "䌶" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x40,0xfc,0x40,0x01,0x1c,0xe0,0x40,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x30,0x30,0x50,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 17207 0x4337 "䌷" */
+0x10,0x10,0x20,0x24,0x45,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 17208 0x4338 "䌸" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x13,0x20,0x40,0xfd,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x40,0xfe,0x40,0x80,0xfc,0x04,0x88,0x50,0x20,0x10,0x10,
+/* 17209 0x4339 "䌹" */
+0x10,0x13,0x22,0x22,0x4a,0xfa,0x12,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 17210 0x433a "䌺" */
+0x10,0x13,0x20,0x24,0x44,0xf8,0x10,0x20,0x40,0xfc,0x40,0x03,0x1c,0xe0,0x40,0x00,
+0x00,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x8e,0xf8,0x08,0x08,0x08,0x08,
+/* 17211 0x433b "䌻" */
+0x10,0x13,0x20,0x20,0x4a,0xf9,0x11,0x20,0x40,0xf9,0x42,0x00,0x18,0xe0,0x41,0x00,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 17212 0x433c "䌼" */
+0x11,0x10,0x20,0x24,0x45,0xf9,0x11,0x21,0x41,0xfc,0x40,0x00,0x1c,0xe1,0x42,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 17213 0x433d "䌽" */
+0x10,0x10,0x23,0x20,0x4a,0xf9,0x11,0x20,0x43,0xf8,0x40,0x00,0x19,0xe2,0x44,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 17214 0x433e "䌾" */
+0x10,0x10,0x23,0x20,0x48,0xfb,0x12,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 17215 0x433f "䌿" */
+0x10,0x13,0x20,0x21,0x49,0xf9,0x11,0x20,0x43,0xfa,0x42,0x03,0x1a,0xe2,0x43,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 17216 0x4340 "䍀" */
+0x10,0x12,0x22,0x22,0x4a,0xfa,0x12,0x20,0x40,0xfb,0x42,0x02,0x1a,0xe2,0x4f,0x00,
+0x90,0x90,0x9c,0xa0,0xd0,0x88,0x88,0x80,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 17217 0x4341 "䍁" */
+0x10,0x14,0x22,0x20,0x48,0xf8,0x16,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x45,0x08,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 17218 0x4342 "䍂" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x11,0x10,0x54,0x54,0x54,0x5c,0x64,0x04,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17219 0x4343 "䍃" */
+0x00,0x01,0x7e,0x22,0x11,0x11,0x08,0x1f,0x21,0x01,0xff,0x01,0x21,0x21,0x3f,0x00,
+0x08,0xfc,0x00,0x08,0x08,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,0x08,0x08,0xf8,0x08,
+/* 17220 0x4344 "䍄" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x11,0x55,0x55,0x55,0x5d,0x65,0x05,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 17221 0x4345 "䍅" */
+0x20,0x20,0x3c,0x50,0x90,0x11,0xfe,0x10,0x11,0x54,0x54,0x54,0x5c,0x64,0x04,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 17222 0x4346 "䍆" */
+0x20,0x20,0x3c,0x51,0x91,0x12,0xfe,0x10,0x11,0x54,0x54,0x54,0x5c,0x64,0x04,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17223 0x4347 "䍇" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x10,0x54,0x54,0x54,0x5c,0x64,0x05,0x00,
+0x04,0x1e,0xe0,0x00,0x10,0x08,0xfe,0x02,0x04,0x08,0x10,0x20,0x40,0xa0,0x1e,0x00,
+/* 17224 0x4348 "䍈" */
+0x20,0x21,0x3c,0x50,0x91,0x10,0xfe,0x10,0x13,0x54,0x54,0x54,0x5c,0x64,0x04,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 17225 0x4349 "䍉" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x10,0x54,0x54,0x54,0x5c,0x64,0x04,0x01,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 17226 0x434a "䍊" */
+0x20,0x20,0x3c,0x51,0x90,0x10,0xff,0x12,0x10,0x54,0x54,0x54,0x5c,0x64,0x04,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 17227 0x434b "䍋" */
+0x20,0x20,0x3d,0x50,0x91,0x10,0xfe,0x10,0x11,0x54,0x54,0x55,0x5c,0x64,0x05,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 17228 0x434c "䍌" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x11,0x10,0x54,0x54,0x54,0x5c,0x64,0x04,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x48,0x50,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 17229 0x434d "䍍" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x20,0x3c,0x50,0xfe,0x10,0x54,0x7c,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17230 0x434e "䍎" */
+0x40,0x43,0x78,0xa0,0x23,0x22,0xfb,0x22,0x23,0xaa,0xaa,0xaa,0xba,0xcc,0x0a,0x00,
+0x88,0xfe,0x88,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x80,0xfe,0x80,0xfe,0x02,0xaa,0x04,
+/* 17231 0x434f "䍏" */
+0x00,0x3f,0x24,0x24,0x24,0x24,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0xf8,0x48,0x48,0x48,0x48,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 17232 0x4350 "䍐" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 17233 0x4351 "䍑" */
+0x00,0x3f,0x22,0x2a,0x24,0x2a,0x31,0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0xf8,0x28,0xa8,0x48,0xa8,0x28,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 17234 0x4352 "䍒" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 17235 0x4353 "䍓" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x3f,0x00,0x10,0x20,0x3f,0x01,0x06,0x18,0x61,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x80,
+/* 17236 0x4354 "䍔" */
+0x00,0x7f,0x44,0x44,0x7f,0x02,0x02,0x7f,0x04,0x04,0x08,0x11,0x22,0x44,0x8f,0x04,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfc,0x00,0x80,0x80,0x00,0x20,0x10,0xf8,0x08,
+/* 17237 0x4355 "䍕" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x2a,0x31,0x21,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf0,0x00,0x00,0x00,0xfc,0x80,0x40,0x24,0x14,0x0c,
+/* 17238 0x4356 "䍖" */
+0x00,0x7f,0x44,0x44,0x7f,0x08,0x1f,0x20,0x5f,0x10,0x10,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x50,0x24,0x04,0xfc,
+/* 17239 0x4357 "䍗" */
+0x00,0x7f,0x44,0x44,0x7f,0x02,0x01,0x7f,0x04,0x08,0x1f,0x00,0x03,0x0c,0x3f,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfc,0x00,0x20,0xc0,0x80,0x20,0x10,0xf8,0x08,
+/* 17240 0x4358 "䍘" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x11,0x09,0x05,0x7f,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x10,0x20,0x40,0xfc,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 17241 0x4359 "䍙" */
+0x00,0x7f,0x44,0x7f,0x10,0x3f,0x40,0x9f,0x12,0x11,0xff,0x22,0x21,0x3f,0x00,0x00,
+0x00,0xfc,0x44,0xfc,0x00,0xfc,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xfc,0x10,0x60,
+/* 17242 0x435a "䍚" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x10,0x12,0x14,0x18,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x18,0x06,
+/* 17243 0x435b "䍛" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 17244 0x435c "䍜" */
+0x7f,0x44,0x7f,0x09,0x08,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0xfc,0x44,0xfc,0x00,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,
+/* 17245 0x435d "䍝" */
+0x7f,0x44,0x7f,0x00,0x01,0x7d,0x09,0x31,0xc5,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0xfc,0x44,0xfc,0x00,0x04,0x98,0x60,0x18,0x06,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 17246 0x435e "䍞" */
+0x7f,0x40,0x4a,0x44,0x4a,0x00,0x00,0xff,0x00,0x3e,0x22,0x3e,0x00,0x0e,0x70,0x03,
+0xfc,0x04,0xa4,0x44,0xa4,0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x02,
+/* 17247 0x435f "䍟" */
+0x7f,0x44,0x7f,0x00,0x24,0x23,0x24,0x3f,0x10,0x22,0x47,0x08,0x14,0x03,0x1c,0xe0,
+0xfc,0x44,0xfc,0x00,0x48,0x88,0x48,0xf8,0x10,0x08,0xe4,0x20,0x40,0x80,0x70,0x0e,
+/* 17248 0x4360 "䍠" */
+0x7f,0x44,0x7f,0x01,0x00,0xff,0x04,0x13,0x14,0x1f,0x01,0x7f,0x44,0x4f,0x44,0x40,
+0xfc,0x44,0xfc,0x00,0x80,0xfe,0x40,0x90,0x50,0xf0,0x00,0xfc,0x44,0xe4,0x24,0x0c,
+/* 17249 0x4361 "䍡" */
+0x00,0x7f,0x44,0x7f,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x28,0x2f,0x48,0x4b,0x8c,
+0x00,0xfc,0x44,0xfc,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x48,0x70,0x44,0x44,0x3c,
+/* 17250 0x4362 "䍢" */
+0x00,0x7f,0x44,0x7f,0x10,0x3f,0x4a,0x0a,0x7f,0x0a,0x0a,0x7f,0x00,0x24,0x22,0x42,
+0x00,0xfc,0x44,0xfc,0x00,0xfc,0xa0,0xa0,0xfc,0xa0,0xa0,0xfc,0x00,0x88,0x44,0x44,
+/* 17251 0x4363 "䍣" */
+0x7f,0x44,0x7f,0x00,0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0xfc,0x44,0xfc,0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 17252 0x4364 "䍤" */
+0x00,0x7f,0x44,0x7f,0x01,0xff,0x02,0x7d,0x25,0x4d,0x90,0x1f,0x10,0x1f,0x10,0x20,
+0x00,0xfc,0x44,0xfc,0x00,0xfe,0x88,0x70,0x48,0x66,0x10,0xf0,0x10,0xf0,0x10,0x10,
+/* 17253 0x4365 "䍥" */
+0x00,0x7f,0x44,0x7f,0x00,0x7f,0x40,0x5f,0x44,0x7f,0x4e,0x55,0x60,0x44,0x44,0xbf,
+0x00,0xfc,0x44,0xfc,0x00,0xfe,0x00,0x3c,0x10,0x7e,0x34,0x52,0x90,0xf8,0x80,0xfe,
+/* 17254 0x4366 "䍦" */
+0x7f,0x44,0x7f,0x10,0x08,0x7f,0x14,0x49,0x55,0x7f,0x08,0x7f,0x51,0x55,0x5d,0x43,
+0xfc,0x44,0xfc,0x00,0x28,0x24,0x7e,0x48,0xc8,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x40,
+/* 17255 0x4367 "䍧" */
+0x10,0x10,0x50,0x50,0x7d,0x50,0x90,0x10,0x1c,0xf0,0x51,0x10,0x10,0x10,0x10,0x10,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 17256 0x4368 "䍨" */
+0x44,0x24,0x28,0xfd,0x10,0x10,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x20,0x40,0x80,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 17257 0x4369 "䍩" */
+0x44,0x24,0x28,0xfe,0x10,0x11,0x7e,0x10,0x10,0xfe,0x10,0x10,0x20,0x20,0x41,0x82,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 17258 0x436a "䍪" */
+0x44,0x24,0x28,0xfd,0x10,0x10,0x7c,0x11,0x10,0xfc,0x10,0x11,0x21,0x22,0x40,0x80,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 17259 0x436b "䍫" */
+0x44,0x24,0x28,0xfd,0x11,0x12,0x7c,0x10,0x10,0xfc,0x10,0x10,0x20,0x20,0x40,0x80,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 17260 0x436c "䍬" */
+0x44,0x25,0x28,0xfc,0x11,0x10,0x7c,0x10,0x13,0xfc,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 17261 0x436d "䍭" */
+0x44,0x24,0x28,0xfe,0x10,0x10,0x7c,0x13,0x11,0xff,0x11,0x11,0x21,0x20,0x40,0x80,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 17262 0x436e "䍮" */
+0x44,0x24,0x28,0xfd,0x10,0x10,0x7c,0x10,0x10,0xfd,0x10,0x10,0x20,0x20,0x41,0x82,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 17263 0x436f "䍯" */
+0x44,0x24,0x28,0xfd,0x12,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x22,0x42,0x84,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 17264 0x4370 "䍰" */
+0x44,0x25,0x29,0xfd,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x21,0x41,0x81,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 17265 0x4371 "䍱" */
+0x44,0x24,0x28,0xfc,0x11,0x12,0x7c,0x10,0x13,0xfc,0x11,0x11,0x22,0x24,0x40,0x80,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 17266 0x4372 "䍲" */
+0x88,0x48,0x53,0xfa,0x22,0x23,0xfa,0x22,0x23,0xf8,0x20,0x20,0x20,0x41,0x42,0x84,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 17267 0x4373 "䍳" */
+0x88,0x4b,0x50,0xf9,0x20,0x21,0xfa,0x24,0x20,0xfb,0x20,0x21,0x20,0x41,0x42,0x84,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 17268 0x4374 "䍴" */
+0x88,0x49,0x50,0xf8,0x23,0x20,0xf9,0x22,0x20,0xfb,0x20,0x21,0x20,0x40,0x40,0x81,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 17269 0x4375 "䍵" */
+0x44,0x24,0x28,0xfd,0x10,0x11,0x7c,0x10,0x13,0xfc,0x10,0x11,0x20,0x20,0x40,0x80,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 17270 0x4376 "䍶" */
+0x44,0x24,0x2b,0xfc,0x11,0x11,0x7d,0x11,0x11,0xfc,0x10,0x10,0x21,0x26,0x40,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 17271 0x4377 "䍷" */
+0x44,0x24,0x29,0xfc,0x13,0x10,0x7d,0x11,0x11,0xfc,0x13,0x10,0x22,0x23,0x40,0x80,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 17272 0x4378 "䍸" */
+0x44,0x24,0x2b,0xfc,0x11,0x11,0x7d,0x11,0x11,0xfd,0x10,0x13,0x20,0x20,0x40,0x80,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 17273 0x4379 "䍹" */
+0x44,0x24,0x29,0xfd,0x11,0x11,0x7d,0x11,0x11,0xfc,0x10,0x13,0x20,0x20,0x41,0x86,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x88,0x04,0x02,
+/* 17274 0x437a "䍺" */
+0x88,0x48,0x51,0xf9,0x21,0x20,0xfb,0x22,0x23,0xf8,0x20,0x20,0x22,0x42,0x44,0x80,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x20,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 17275 0x437b "䍻" */
+0x88,0x4b,0x52,0xfb,0x22,0x22,0xf9,0x20,0x20,0xfb,0x20,0x20,0x23,0x40,0x41,0x82,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 17276 0x437c "䍼" */
+0x88,0x4b,0x50,0xfa,0x23,0x21,0xfa,0x24,0x21,0xf9,0x21,0x21,0x21,0x41,0x41,0x81,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 17277 0x437d "䍽" */
+0x88,0x4b,0x52,0xfa,0x22,0x23,0xfa,0x22,0x23,0xfa,0x22,0x22,0x22,0x44,0x44,0x8b,
+0x00,0xfe,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x44,0x10,0x90,0x9e,0x90,0x90,0xfe,
+/* 17278 0x437e "䍾" */
+0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 17279 0x437f "䍿" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x02,0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 17280 0x4380 "䎀" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x14,0x12,0x12,0x10,0xfe,0x90,0x92,0x92,0x92,0x94,0x94,0xb4,0xca,0x8a,0x16,0x22,
+/* 17281 0x4381 "䎁" */
+0x10,0x11,0x10,0x10,0xff,0x10,0x10,0x10,0x7c,0x44,0x45,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17282 0x4382 "䎂" */
+0x00,0xee,0x22,0x22,0xab,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 17283 0x4383 "䎃" */
+0x10,0x11,0x10,0x7c,0x55,0x54,0x7c,0x54,0x54,0x54,0xff,0x44,0x44,0x44,0x55,0x48,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17284 0x4384 "䎄" */
+0x00,0xfd,0x24,0x24,0x25,0x24,0x54,0x48,0x80,0x7c,0x45,0x44,0x44,0x44,0x7d,0x44,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17285 0x4385 "䎅" */
+0x10,0x11,0x20,0x7c,0x45,0x44,0x44,0x44,0x7c,0x44,0x45,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17286 0x4386 "䎆" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x03,0x02,0x0c,0x32,0xc1,0x1f,0x00,0x06,0x01,0x00,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0x80,0x60,0x18,0x06,0xe0,0x20,0x40,0x80,0x40,
+/* 17287 0x4387 "䎇" */
+0x10,0x21,0x7c,0x44,0x65,0x54,0x54,0xfc,0x44,0x64,0x55,0x54,0x44,0x44,0x55,0x88,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17288 0x4388 "䎈" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xab,0x44,
+0x20,0x20,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfc,0x20,0x24,0x18,0x12,0x6a,0x86,0x02,
+/* 17289 0x4389 "䎉" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x45,
+0x0c,0x0a,0x08,0xfe,0x88,0x88,0x88,0x8a,0xea,0x8a,0x8c,0x8c,0x8a,0x8a,0x96,0x22,
+/* 17290 0x438a "䎊" */
+0x10,0x10,0x1e,0x22,0x62,0x94,0x08,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x3e,0x22,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 17291 0x438b "䎋" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 17292 0x438c "䎌" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x45,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x10,0x10,0x50,0x5e,0x50,0x50,0x70,0x9e,0x00,
+/* 17293 0x438d "䎍" */
+0x00,0xec,0x25,0x24,0xb4,0x6d,0x25,0x25,0x25,0x6d,0xb5,0x25,0x25,0x25,0xb5,0x49,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 17294 0x438e "䎎" */
+0x00,0xed,0x24,0x24,0xb4,0x6c,0x24,0x24,0x24,0x6c,0xb4,0x24,0x24,0x25,0xb4,0x48,
+0x00,0xfe,0xa0,0xa8,0xa8,0xe8,0xa8,0xa8,0xa8,0xe8,0xa8,0xaa,0xba,0xea,0x26,0x20,
+/* 17295 0x438f "䎏" */
+0x08,0x08,0x14,0x22,0x51,0x88,0x7e,0x02,0x04,0x08,0x7e,0x42,0x42,0x7e,0x42,0x00,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 17296 0x4390 "䎐" */
+0x10,0x11,0xfe,0x10,0x7d,0x44,0x7c,0x44,0x7c,0x54,0x11,0xfe,0x10,0x10,0x11,0x10,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17297 0x4391 "䎑" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x00,0xfc,0x04,0x04,0x7c,0x04,0x04,0xfe,0x10,0x92,0x54,0x38,0x54,0x92,0x50,0x20,
+/* 17298 0x4392 "䎒" */
+0x00,0xee,0x22,0x23,0xaa,0x66,0x22,0x23,0x26,0x6a,0xb3,0x22,0x22,0x22,0xaa,0x45,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 17299 0x4393 "䎓" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x23,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x10,0x10,0xda,0x54,0x54,0x92,0x50,0x20,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 17300 0x4394 "䎔" */
+0x00,0xec,0x27,0x24,0xb5,0x6d,0x25,0x25,0x25,0x6d,0xb4,0x27,0x24,0x24,0xb4,0x48,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 17301 0x4395 "䎕" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x80,0x3e,0x02,0x12,0x0a,0x12,0x22,0x0a,0x04,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xf8,0x08,0x48,0x28,0x48,0x88,0x28,0x10,
+/* 17302 0x4396 "䎖" */
+0x44,0x24,0x28,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 17303 0x4397 "䎗" */
+0x06,0x78,0x10,0xff,0x22,0x5d,0x94,0x1c,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x43,
+0x00,0xee,0x22,0xa2,0xaa,0x66,0xa2,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 17304 0x4398 "䎘" */
+0x08,0x7f,0x09,0xff,0x09,0x7f,0x08,0xaa,0xeb,0x88,0xff,0x88,0xeb,0xaa,0xaa,0x08,
+0x00,0x7e,0x12,0x92,0x5a,0x36,0x12,0x92,0x96,0xba,0xd2,0x92,0x92,0x92,0x92,0xb6,
+/* 17305 0x4399 "䎙" */
+0x20,0x11,0xfe,0x82,0x7d,0x54,0x98,0x7c,0xc4,0x7c,0x45,0x7c,0x44,0x7c,0x29,0x44,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 17306 0x439a "䎚" */
+0x00,0xed,0x24,0x25,0xb4,0x6d,0x24,0x25,0x24,0x6c,0xb4,0x25,0x24,0x25,0xb5,0x4a,
+0x88,0xdc,0x88,0xdc,0x88,0xdc,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x54,0x4a,0x3a,
+/* 17307 0x439b "䎛" */
+0x02,0x02,0x3f,0x02,0xff,0x02,0x0c,0x3f,0xc8,0x07,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x08,0xd0,0x20,0xfe,0x00,0x70,0x84,0x04,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 17308 0x439c "䎜" */
+0x10,0x12,0x7e,0x14,0x14,0xfe,0x08,0x10,0x20,0x7e,0xa0,0x22,0x2d,0x30,0x20,0x00,
+0x10,0x10,0x12,0x7e,0x14,0x14,0xfe,0x08,0x30,0x22,0x64,0xb8,0x22,0x22,0x1e,0x00,
+/* 17309 0x439d "䎝" */
+0x02,0x3f,0x02,0xff,0x02,0x0f,0x34,0xc3,0x00,0x7e,0x22,0x12,0x0a,0x12,0x6a,0x04,
+0x20,0xc0,0x80,0xfe,0x20,0xc0,0x08,0xf8,0x00,0xfc,0x44,0x24,0x14,0x24,0xd4,0x08,
+/* 17310 0x439e "䎞" */
+0x01,0x01,0x1f,0x01,0x7f,0x02,0x0f,0x38,0xcf,0x08,0x0f,0x00,0x3f,0x00,0x00,0x00,
+0x00,0x08,0xd0,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0x08,
+/* 17311 0x439f "䎟" */
+0x10,0x13,0x10,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x81,0x01,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 17312 0x43a0 "䎠" */
+0x20,0x23,0x20,0x20,0xfd,0x25,0x25,0xa5,0x65,0x25,0x35,0x2d,0x25,0x44,0x43,0x80,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x44,0x16,0x0a,0x02,0xfe,0x00,
+/* 17313 0x43a1 "䎡" */
+0x00,0xff,0x02,0x04,0x3f,0x24,0x24,0x24,0x20,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0xa8,0x10,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 17314 0x43a2 "䎢" */
+0x10,0x10,0x10,0xfc,0x11,0x7a,0x10,0xfc,0x10,0x38,0x34,0x54,0x91,0x11,0x10,0x10,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 17315 0x43a3 "䎣" */
+0x10,0x10,0x11,0xfd,0x11,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x91,0x10,0x10,0x10,
+0x08,0x48,0x28,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x48,0x94,0x14,0x22,0x42,0x82,
+/* 17316 0x43a4 "䎤" */
+0x10,0x11,0x11,0xfd,0x11,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x92,0x12,0x14,0x10,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 17317 0x43a5 "䎥" */
+0x10,0x10,0x10,0xfc,0x11,0x78,0x10,0xfc,0x11,0x3a,0x34,0x54,0x90,0x10,0x10,0x10,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 17318 0x43a6 "䎦" */
+0x10,0x10,0x10,0xfd,0x10,0x78,0x11,0xfc,0x10,0x38,0x34,0x55,0x90,0x10,0x11,0x12,
+0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x24,0x20,0xa8,0xa8,0x30,0x50,0x88,0x04,0x02,
+/* 17319 0x43a7 "䎧" */
+0x10,0x10,0x10,0xfc,0x10,0x78,0x10,0xfd,0x10,0x38,0x34,0x54,0x90,0x10,0x10,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x48,0x50,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 17320 0x43a8 "䎨" */
+0x10,0x10,0x13,0xfc,0x10,0x79,0x12,0xfd,0x11,0x39,0x35,0x55,0x90,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 17321 0x43a9 "䎩" */
+0x10,0x10,0x11,0xfe,0x11,0x78,0x10,0xfc,0x11,0x39,0x35,0x55,0x91,0x11,0x11,0x11,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 17322 0x43aa "䎪" */
+0x10,0x11,0x11,0xfd,0x11,0x79,0x10,0xfd,0x10,0x3b,0x34,0x55,0x90,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x08,0xfe,0x08,0x08,0x88,0x08,0x28,0x10,
+/* 17323 0x43ab "䎫" */
+0x10,0x11,0x11,0xfd,0x11,0x78,0x10,0xfd,0x10,0x38,0x34,0x55,0x90,0x10,0x10,0x11,
+0x50,0x24,0x54,0x04,0xfc,0x50,0x88,0x44,0x78,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 17324 0x43ac "䎬" */
+0x10,0x13,0x12,0xfe,0x13,0x78,0x10,0xfd,0x10,0x38,0x37,0x54,0x90,0x11,0x13,0x11,
+0x00,0xfe,0x52,0x52,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x02,
+/* 17325 0x43ad "䎭" */
+0x10,0x10,0x12,0xfd,0x10,0x78,0x10,0xff,0x11,0x39,0x35,0x51,0x51,0x91,0x12,0x14,
+0x10,0x50,0x50,0x7c,0x90,0x10,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 17326 0x43ae "䎮" */
+0x10,0x10,0x11,0xfc,0x10,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x91,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x88,0x50,0xfc,0x04,0x24,0xfc,0x24,0x74,0x54,0x54,0x74,0x04,0x0c,
+/* 17327 0x43af "䎯" */
+0x10,0x10,0x13,0xfc,0x10,0x78,0x11,0xfd,0x11,0x38,0x35,0x54,0x93,0x10,0x10,0x13,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,
+/* 17328 0x43b0 "䎰" */
+0x11,0x11,0x13,0xfd,0x11,0x79,0x13,0xfc,0x11,0x39,0x35,0x55,0x91,0x11,0x11,0x10,
+0x42,0x5c,0xf0,0x50,0x50,0x5e,0xf4,0x14,0xd4,0x54,0x54,0xd4,0x54,0x54,0xe4,0x04,
+/* 17329 0x43b1 "䎱" */
+0x20,0x23,0x22,0xfa,0x23,0x71,0x22,0xfb,0x20,0x73,0x6a,0xa3,0x22,0x23,0x22,0x22,
+0x00,0xfc,0x94,0x94,0xfc,0x10,0x52,0xdc,0x12,0xce,0x40,0xd2,0x5c,0xd0,0x52,0xce,
+/* 17330 0x43b2 "䎲" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0x40,0x40,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 17331 0x43b3 "䎳" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x05,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x84,0x94,0x08,
+/* 17332 0x43b4 "䎴" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x25,0x24,0x2e,0xf4,0x44,0x04,0x04,0x05,
+0x48,0x48,0x48,0x48,0xfc,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 17333 0x43b5 "䎵" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3d,0x25,0x25,0x2e,0xf4,0x44,0x05,0x06,0x04,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 17334 0x43b6 "䎶" */
+0x00,0xfc,0x48,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x4d,0x79,0xc9,0x08,0x08,0x08,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 17335 0x43b7 "䎷" */
+0x00,0xfd,0x49,0x49,0x79,0x4a,0x48,0x7b,0x48,0x48,0x4c,0x79,0xc9,0x0a,0x08,0x08,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 17336 0x43b8 "䎸" */
+0x00,0xfd,0x48,0x48,0x78,0x48,0x48,0x79,0x48,0x48,0x4c,0x78,0xc8,0x08,0x08,0x08,
+0x00,0xfe,0x20,0x20,0xfc,0x44,0x44,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 17337 0x43b9 "䎹" */
+0x00,0x3f,0x11,0x09,0xff,0x09,0x31,0xc1,0x3f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,
+0xf8,0x00,0x10,0x20,0xfe,0x20,0x18,0x06,0xf8,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,
+/* 17338 0x43ba "䎺" */
+0x00,0xfc,0x4a,0x4b,0x7c,0x48,0x4f,0x78,0x4b,0x4a,0x4e,0x7a,0xca,0x0a,0x08,0x08,
+0x82,0x82,0x82,0xea,0x8a,0x8a,0xfa,0x8a,0xea,0xaa,0xaa,0xaa,0xa2,0xe2,0x8a,0x84,
+/* 17339 0x43bb "䎻" */
+0x00,0xfd,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x4d,0x79,0xc9,0x0a,0x0a,0x0c,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 17340 0x43bc "䎼" */
+0x00,0xfd,0x48,0x48,0x79,0x48,0x48,0x7b,0x48,0x4a,0x4d,0x78,0xc9,0x0a,0x08,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 17341 0x43bd "䎽" */
+0x00,0xfd,0x49,0x49,0x79,0x49,0x49,0x79,0x48,0x49,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x1c,0xe0,0x20,0x20,0xfe,0x10,0x4a,0x86,0x02,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,
+/* 17342 0x43be "䎾" */
+0x00,0xfc,0x48,0x48,0x79,0x4a,0x48,0x79,0x49,0x49,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 17343 0x43bf "䎿" */
+0x00,0xfc,0x4b,0x49,0x79,0x49,0x4b,0x79,0x49,0x4b,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x08,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 17344 0x43c0 "䏀" */
+0x00,0xfc,0x4b,0x48,0x78,0x4b,0x4a,0x7a,0x4b,0x48,0x4d,0x7a,0xcc,0x08,0x08,0x08,
+0x82,0x82,0xe2,0x82,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xaa,0xa2,0x82,0x8a,0x84,
+/* 17345 0x43c1 "䏁" */
+0x00,0xfc,0x4b,0x4a,0x78,0x49,0x48,0x78,0x4b,0x48,0x4c,0x79,0xc8,0x08,0x08,0x08,
+0x40,0x20,0xfe,0x42,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 17346 0x43c2 "䏂" */
+0x00,0xfd,0x49,0x49,0x79,0x49,0x49,0x79,0x48,0x49,0x4c,0x78,0xc8,0x08,0x08,0x0b,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 17347 0x43c3 "䏃" */
+0x00,0xfd,0x49,0x48,0x78,0x48,0x48,0x78,0x48,0x48,0x4c,0x79,0xc8,0x08,0x08,0x09,
+0x00,0xfe,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0x10,0xfe,0x00,0x48,0x84,0x02,
+/* 17348 0x43c4 "䏄" */
+0x00,0xfc,0x4b,0x4a,0x79,0x4b,0x48,0x78,0x49,0x48,0x4c,0x79,0xc8,0x08,0x0b,0x08,
+0x40,0x20,0xfe,0x8a,0x04,0xfe,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17349 0x43c5 "䏅" */
+0x00,0xfc,0x49,0x49,0x7a,0x49,0x48,0x79,0x4a,0x48,0x4d,0x78,0xc8,0x09,0x0a,0x08,
+0x80,0x88,0xee,0x2a,0xaa,0x44,0x84,0x7a,0x00,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 17350 0x43c6 "䏆" */
+0x00,0xfc,0x4b,0x48,0x7b,0x4a,0x4b,0x7a,0x4b,0x48,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x50,0x50,0xfe,0x50,0xfe,0x52,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 17351 0x43c7 "䏇" */
+0x00,0xfd,0x48,0x49,0x79,0x49,0x49,0x78,0x49,0x48,0x4f,0x78,0xc8,0x09,0x0a,0x08,
+0x00,0xfc,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 17352 0x43c8 "䏈" */
+0x01,0xf9,0x52,0x52,0x74,0x57,0x51,0x72,0x54,0x57,0x58,0x70,0xd5,0x15,0x14,0x10,
+0x08,0x08,0x54,0x54,0xbc,0x08,0x10,0x24,0xbe,0x8a,0x08,0xac,0x6a,0x4a,0x28,0x10,
+/* 17353 0x43c9 "䏉" */
+0x00,0xfd,0x49,0x49,0x79,0x49,0x48,0x79,0x49,0x48,0x4d,0x79,0xc8,0x09,0x09,0x0a,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x54,0xdc,0x88,0x54,0xdc,0x00,0xa8,0x54,0x54,
+/* 17354 0x43ca "䏊" */
+0x01,0xfc,0x4b,0x48,0x7a,0x49,0x4b,0x78,0x4b,0x4a,0x4f,0x7a,0xcb,0x0a,0x0a,0x0a,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 17355 0x43cb "䏋" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x05,0x09,0x31,0xc1,0x25,0x13,0xa1,0xa5,0x1d,0x01,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x40,0x20,0x18,0x06,0x78,0x48,0x78,0x44,0x3c,0x00,
+/* 17356 0x43cc "䏌" */
+0x08,0x08,0x10,0x20,0x40,0x9f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x40,0x20,0x10,0x08,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 17357 0x43cd "䏍" */
+0x02,0x04,0x08,0x10,0x3f,0x10,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0x00,0x20,0x10,0xf8,0x08,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 17358 0x43ce "䏎" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0xd0,0xb0,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 17359 0x43cf "䏏" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x27,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17360 0x43d0 "䏐" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x27,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 17361 0x43d1 "䏑" */
+0x02,0x04,0x0f,0x12,0x69,0x04,0x03,0x0c,0x71,0x3f,0x22,0x24,0x21,0x22,0x24,0x20,
+0x00,0x00,0xf8,0x10,0x20,0xc0,0x00,0x00,0x00,0xf8,0x88,0x48,0x08,0x88,0x48,0x18,
+/* 17362 0x43d2 "䏒" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x08,0x88,0x88,0x88,0x88,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 17363 0x43d3 "䏓" */
+0x00,0x3c,0x24,0x24,0x34,0x2d,0x24,0x24,0x2c,0x34,0x24,0x24,0x24,0x44,0x54,0x89,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 17364 0x43d4 "䏔" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x44,0x57,0x88,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 17365 0x43d5 "䏕" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x24,0x27,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x88,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 17366 0x43d6 "䏖" */
+0x00,0x3d,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x3d,0x24,0x24,0x24,0x44,0x55,0x88,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 17367 0x43d7 "䏗" */
+0x00,0x3c,0x24,0x25,0x26,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfc,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 17368 0x43d8 "䏘" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x88,
+0x00,0xfe,0x28,0x28,0x28,0x28,0x28,0x28,0x2a,0x2a,0x4a,0x46,0x80,0x00,0xfe,0x00,
+/* 17369 0x43d9 "䏙" */
+0x00,0x3c,0x24,0x25,0x25,0x3e,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 17370 0x43da "䏚" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x25,0x26,0x3c,0x24,0x24,0x24,0x44,0x54,0x8b,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 17371 0x43db "䏛" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x24,0x3c,0x24,0x24,0x25,0x44,0x54,0x88,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 17372 0x43dc "䏜" */
+0x00,0x7b,0x48,0x48,0x48,0x78,0x48,0x48,0x49,0x79,0x49,0x49,0x4a,0x4a,0x4c,0x99,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17373 0x43dd "䏝" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x27,0x24,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x20,0xfc,0x20,0x40,0xfe,0x40,0x80,0xfc,0x04,0x88,0x50,0x20,0x10,0x10,
+/* 17374 0x43de "䏞" */
+0x00,0x3c,0x24,0x27,0x24,0x3c,0x24,0x25,0x24,0x3c,0x24,0x25,0x25,0x46,0x54,0x88,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 17375 0x43df "䏟" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x25,0x25,0x3d,0x26,0x24,0x24,0x45,0x56,0x88,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 17376 0x43e0 "䏠" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x49,0x49,0x78,0x48,0x48,0x48,0x48,0x4b,0x98,
+0x40,0x20,0x20,0x00,0xfc,0x00,0x08,0x08,0x08,0x90,0x90,0x90,0xa0,0x20,0xfe,0x00,
+/* 17377 0x43e1 "䏡" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x3c,0x25,0x25,0x26,0x44,0x54,0x88,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 17378 0x43e2 "䏢" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 17379 0x43e3 "䏣" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x57,0x88,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 17380 0x43e4 "䏤" */
+0x00,0x3d,0x24,0x24,0x25,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 17381 0x43e5 "䏥" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x27,0x25,0x25,0x45,0x55,0x89,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 17382 0x43e6 "䏦" */
+0x00,0x3c,0x25,0x24,0x24,0x3f,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 17383 0x43e7 "䏧" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x25,0x3c,0x24,0x25,0x24,0x44,0x54,0x89,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 17384 0x43e8 "䏨" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x40,0x80,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 17385 0x43e9 "䏩" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 17386 0x43ea "䏪" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x27,0x44,0x54,0x88,
+0x00,0xfe,0x88,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x9e,0xe8,0x08,0x08,0x08,
+/* 17387 0x43eb "䏫" */
+0x00,0x78,0x48,0x49,0x49,0x7b,0x4d,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 17388 0x43ec "䏬" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x3d,0x24,0x25,0x24,0x44,0x54,0x88,
+0x20,0x20,0x48,0x84,0xfe,0x12,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 17389 0x43ed "䏭" */
+0x00,0x79,0x49,0x49,0x49,0x7a,0x48,0x4b,0x48,0x78,0x48,0x49,0x49,0x4a,0x48,0x98,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 17390 0x43ee "䏮" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x24,0x25,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x89,
+0x40,0x40,0xfc,0x44,0x44,0x84,0x94,0x08,0x00,0x02,0x84,0x48,0x00,0x48,0x84,0x02,
+/* 17391 0x43ef "䏯" */
+0x00,0x78,0x48,0x4b,0x48,0x78,0x48,0x49,0x48,0x78,0x48,0x4a,0x4a,0x4a,0x4c,0x98,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 17392 0x43f0 "䏰" */
+0x00,0x7b,0x48,0x49,0x49,0x7a,0x48,0x49,0x4a,0x78,0x48,0x4a,0x4a,0x4a,0x4c,0x98,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 17393 0x43f1 "䏱" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x4a,0x4a,0x4c,0x98,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 17394 0x43f2 "䏲" */
+0x01,0x3c,0x24,0x25,0x24,0x3c,0x25,0x25,0x25,0x3d,0x24,0x24,0x25,0x46,0x54,0x88,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 17395 0x43f3 "䏳" */
+0x01,0x79,0x49,0x49,0x4f,0x79,0x49,0x49,0x49,0x7f,0x49,0x49,0x49,0x49,0x49,0x9b,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 17396 0x43f4 "䏴" */
+0x00,0x3d,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 17397 0x43f5 "䏵" */
+0x00,0x78,0x48,0x4b,0x48,0x78,0x48,0x48,0x48,0x78,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 17398 0x43f6 "䏶" */
+0x01,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3c,0x25,0x24,0x24,0x44,0x57,0x88,
+0x10,0x12,0x14,0xd8,0x10,0x12,0x52,0x8e,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 17399 0x43f7 "䏷" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x24,0x24,0x25,0x3c,0x24,0x27,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 17400 0x43f8 "䏸" */
+0x00,0x7b,0x48,0x48,0x49,0x78,0x48,0x4b,0x48,0x78,0x49,0x49,0x49,0x49,0x49,0x99,
+0x00,0xfc,0x40,0x40,0xf8,0x88,0x88,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 17401 0x43f9 "䏹" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x24,0x24,0x44,0x55,0x8a,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 17402 0x43fa "䏺" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x27,0x24,0x3c,0x24,0x24,0x27,0x44,0x54,0x88,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 17403 0x43fb "䏻" */
+0x10,0x10,0x20,0x44,0xfe,0x02,0x7c,0x44,0x45,0x7c,0x44,0x7c,0x44,0x45,0x54,0x48,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x48,0x84,0xfe,0x82,0x00,
+/* 17404 0x43fc "䏼" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x25,0x24,0x3c,0x25,0x24,0x24,0x44,0x54,0x89,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 17405 0x43fd "䏽" */
+0x00,0x3c,0x25,0x24,0x25,0x3c,0x24,0x27,0x24,0x3c,0x25,0x25,0x25,0x45,0x55,0x89,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 17406 0x43fe "䏾" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x25,0x24,0x25,0x3e,0x24,0x24,0x25,0x44,0x54,0x88,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 17407 0x43ff "䏿" */
+0x10,0x08,0x3e,0x22,0x23,0x3e,0x20,0x41,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x88,0x50,0x20,0x58,0x86,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 17408 0x4400 "䐀" */
+0x00,0x3c,0x25,0x24,0x24,0x3d,0x27,0x24,0x25,0x3d,0x25,0x25,0x25,0x44,0x54,0x88,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 17409 0x4401 "䐁" */
+0x00,0x7b,0x48,0x48,0x49,0x7a,0x48,0x4a,0x49,0x7a,0x48,0x48,0x49,0x4a,0x48,0x98,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 17410 0x4402 "䐂" */
+0x00,0x79,0x48,0x48,0x49,0x78,0x48,0x4b,0x48,0x7a,0x49,0x48,0x49,0x4a,0x48,0x98,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 17411 0x4403 "䐃" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4b,0x4a,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x9a,
+0x00,0xfe,0x02,0x1a,0xe2,0x22,0x22,0xfe,0x22,0x72,0xaa,0x26,0x22,0x22,0xfe,0x02,
+/* 17412 0x4404 "䐄" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 17413 0x4405 "䐅" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 17414 0x4406 "䐆" */
+0x00,0x78,0x4b,0x48,0x4a,0x79,0x49,0x48,0x4b,0x78,0x48,0x48,0x49,0x4a,0x4c,0x98,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 17415 0x4407 "䐇" */
+0x00,0x3c,0x24,0x25,0x26,0x3c,0x25,0x24,0x24,0x3c,0x25,0x25,0x25,0x45,0x55,0x89,
+0x80,0x80,0xfc,0x54,0x54,0x94,0x24,0x54,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 17416 0x4408 "䐈" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x4f,0x98,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 17417 0x4409 "䐉" */
+0x00,0x3c,0x25,0x26,0x25,0x3c,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 17418 0x440a "䐊" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 17419 0x440b "䐋" */
+0x00,0x78,0x49,0x49,0x4a,0x7c,0x49,0x4b,0x48,0x78,0x48,0x4a,0x4a,0x4a,0x4c,0x98,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 17420 0x440c "䐌" */
+0x04,0x04,0x3f,0x24,0x3f,0x24,0xff,0x10,0x20,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x40,0x40,0xf8,0x48,0xf8,0x48,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 17421 0x440d "䐍" */
+0x00,0x3c,0x27,0x24,0x24,0x3d,0x24,0x24,0x25,0x3d,0x25,0x25,0x24,0x44,0x54,0x8b,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x88,0x50,0xfe,
+/* 17422 0x440e "䐎" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x48,0x7b,0x48,0x49,0x49,0x49,0x4a,0x9c,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 17423 0x440f "䐏" */
+0x00,0x3c,0x27,0x24,0x25,0x3c,0x27,0x24,0x25,0x3e,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 17424 0x4410 "䐐" */
+0x00,0x71,0x57,0x51,0x51,0x71,0x57,0x51,0x53,0x73,0x55,0x55,0x59,0x51,0x51,0xb1,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 17425 0x4411 "䐑" */
+0x00,0x3d,0x25,0x27,0x25,0x3d,0x25,0x25,0x25,0x3c,0x27,0x24,0x24,0x45,0x56,0x88,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 17426 0x4412 "䐒" */
+0x00,0x3c,0x25,0x24,0x25,0x3e,0x24,0x27,0x24,0x3c,0x27,0x24,0x25,0x44,0x54,0x8b,
+0x00,0x40,0xfe,0x88,0x04,0x42,0xf8,0x08,0x90,0x70,0xbe,0x42,0xa4,0x18,0x60,0x80,
+/* 17427 0x4413 "䐓" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x89,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 17428 0x4414 "䐔" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x26,0x24,0x24,0x44,0x54,0x88,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 17429 0x4415 "䐕" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x47,0x54,0x88,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 17430 0x4416 "䐖" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x4d,0x4a,0x98,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,
+/* 17431 0x4417 "䐗" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 17432 0x4418 "䐘" */
+0x00,0x7b,0x48,0x49,0x48,0x79,0x48,0x48,0x4b,0x78,0x48,0x49,0x49,0x4a,0x48,0x99,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 17433 0x4419 "䐙" */
+0x00,0x78,0x4b,0x48,0x48,0x78,0x49,0x49,0x49,0x79,0x48,0x4b,0x48,0x48,0x48,0x98,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 17434 0x441a "䐚" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x4a,0x4b,0x98,
+0x00,0xde,0x52,0x52,0x52,0xd2,0x52,0x52,0x52,0xd2,0x1a,0x94,0x50,0xb0,0x10,0x10,
+/* 17435 0x441b "䐛" */
+0x00,0x3c,0x25,0x24,0x24,0x3d,0x27,0x24,0x24,0x3c,0x24,0x24,0x24,0x47,0x54,0x88,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 17436 0x441c "䐜" */
+0x00,0x78,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x4b,0x48,0x49,0x9a,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 17437 0x441d "䐝" */
+0x00,0x3d,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x44,0x54,0x89,
+0x20,0x24,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 17438 0x441e "䐞" */
+0x00,0x7b,0x48,0x48,0x4b,0x7a,0x4a,0x4b,0x48,0x7a,0x49,0x49,0x4a,0x48,0x4a,0x99,
+0x00,0xde,0x42,0x42,0xde,0x10,0x10,0xde,0x42,0x52,0x4a,0x4a,0x52,0x42,0x94,0x08,
+/* 17439 0x441f "䐟" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x48,0x49,0x79,0x49,0x49,0x4b,0x49,0x49,0x99,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 17440 0x4420 "䐠" */
+0x00,0x3c,0x27,0x24,0x24,0x3f,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x88,0x88,0xfe,0xa8,0x10,0xfe,0x80,0x80,0xfc,0x00,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 17441 0x4421 "䐡" */
+0x02,0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x01,0x3f,0x22,0x24,0x21,0x22,0x24,0x20,
+0x00,0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x00,0xf8,0x88,0x48,0x08,0x88,0x48,0x18,
+/* 17442 0x4422 "䐢" */
+0x00,0x78,0x49,0x4a,0x49,0x79,0x48,0x49,0x4a,0x79,0x4a,0x4d,0x49,0x48,0x49,0x9a,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 17443 0x4423 "䐣" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x44,0x54,0x89,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x50,0x88,0x04,
+/* 17444 0x4424 "䐤" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x25,0x24,0x3c,0x24,0x25,0x26,0x44,0x55,0x88,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 17445 0x4425 "䐥" */
+0x00,0x78,0x49,0x4a,0x4c,0x79,0x48,0x48,0x4b,0x78,0x4a,0x49,0x4a,0x48,0x49,0x98,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 17446 0x4426 "䐦" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x25,0x3c,0x25,0x25,0x25,0x45,0x57,0x88,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x84,0xfe,0x02,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 17447 0x4427 "䐧" */
+0x00,0x78,0x4b,0x48,0x49,0x79,0x49,0x48,0x4b,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x40,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf4,0x94,0xf4,0x04,0x14,0x08,
+/* 17448 0x4428 "䐨" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x4d,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17449 0x4429 "䐩" */
+0x00,0x3d,0x25,0x25,0x25,0x3c,0x27,0x24,0x25,0x3d,0x25,0x25,0x24,0x44,0x57,0x88,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 17450 0x442a "䐪" */
+0x00,0x78,0x49,0x4b,0x4d,0x79,0x49,0x49,0x49,0x79,0x4b,0x48,0x48,0x49,0x4a,0x9c,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 17451 0x442b "䐫" */
+0x01,0x79,0x4a,0x4c,0x49,0x79,0x4a,0x4e,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9b,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 17452 0x442c "䐬" */
+0x00,0x78,0x4f,0x48,0x4b,0x7a,0x4b,0x4a,0x4b,0x78,0x49,0x49,0x49,0x49,0x49,0x99,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 17453 0x442d "䐭" */
+0x02,0x72,0x57,0x52,0x52,0x74,0x58,0x57,0x54,0x70,0x53,0x52,0x52,0x52,0x52,0xb0,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 17454 0x442e "䐮" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x4a,0x4c,0x99,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 17455 0x442f "䐯" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x24,0x24,0x25,0x3c,0x24,0x27,0x24,0x45,0x56,0x88,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 17456 0x4430 "䐰" */
+0x01,0x79,0x49,0x4a,0x4a,0x7e,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x20,0x3c,0x44,0xa8,0x10,0xa8,0xc6,0xbc,0xa4,0xbc,0xa4,0xbc,0x24,0x24,0x24,0x2c,
+/* 17457 0x4431 "䐱" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 17458 0x4432 "䐲" */
+0x00,0x7b,0x48,0x4a,0x49,0x7a,0x48,0x48,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 17459 0x4433 "䐳" */
+0x00,0x3c,0x24,0x25,0x26,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x45,0x55,0x8a,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x54,0x2a,0x2a,
+/* 17460 0x4434 "䐴" */
+0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 17461 0x4435 "䐵" */
+0x00,0x3c,0x25,0x24,0x24,0x3f,0x24,0x25,0x25,0x3d,0x25,0x25,0x24,0x44,0x55,0x8a,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 17462 0x4436 "䐶" */
+0x00,0x7b,0x48,0x4a,0x4b,0x79,0x4a,0x4c,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 17463 0x4437 "䐷" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x78,0x49,0x49,0x49,0x79,0x49,0x48,0x4b,0x48,0x48,0x98,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 17464 0x4438 "䐸" */
+0x00,0x3d,0x24,0x27,0x24,0x3d,0x24,0x27,0x24,0x3d,0x25,0x25,0x25,0x45,0x54,0x8b,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 17465 0x4439 "䐹" */
+0x00,0x79,0x48,0x4b,0x48,0x79,0x48,0x4a,0x4b,0x7a,0x4b,0x4a,0x4b,0x4a,0x4a,0x9c,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 17466 0x443a "䐺" */
+0x00,0x7b,0x48,0x4b,0x4a,0x7b,0x48,0x49,0x49,0x79,0x49,0x49,0x48,0x4b,0x48,0x98,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 17467 0x443b "䐻" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x48,0x49,0x48,0x78,0x4b,0x48,0x49,0x48,0x48,0x98,
+0x20,0xfe,0x20,0xfc,0x04,0xfc,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x20,
+/* 17468 0x443c "䐼" */
+0x00,0x7b,0x48,0x49,0x48,0x7b,0x48,0x48,0x48,0x79,0x48,0x4b,0x48,0x49,0x4a,0x98,
+0x80,0xde,0x8a,0xca,0x8a,0xd2,0xa6,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 17469 0x443d "䐽" */
+0x00,0x78,0x4b,0x48,0x48,0x78,0x48,0x4b,0x4a,0x7b,0x4a,0x4b,0x4a,0x4a,0x4a,0x9a,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 17470 0x443e "䐾" */
+0x00,0x3d,0x25,0x25,0x24,0x3d,0x24,0x27,0x24,0x3c,0x25,0x24,0x27,0x44,0x54,0x88,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 17471 0x443f "䐿" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x7a,0x48,0x4b,0x48,0x48,0x48,0x9b,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 17472 0x4440 "䑀" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x7a,0x4e,0x4a,0x4a,0x4b,0x4a,0x98,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 17473 0x4441 "䑁" */
+0x3a,0x21,0x3a,0x22,0x39,0x22,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0xb8,0x08,0xb8,0x88,0x38,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 17474 0x4442 "䑂" */
+0x01,0x7a,0x4a,0x4a,0x4b,0x7a,0x4a,0x4b,0x4a,0x7a,0x4f,0x48,0x49,0x49,0x4a,0x9c,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 17475 0x4443 "䑃" */
+0x00,0x3d,0x24,0x25,0x35,0x2c,0x24,0x25,0x2c,0x34,0x25,0x24,0x25,0x44,0x55,0x88,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x20,0x50,0xaa,0x5c,0xaa,0x48,0xa8,0x10,
+/* 17476 0x4444 "䑄" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x24,0x47,0x54,0x89,
+0x40,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x88,0x08,
+/* 17477 0x4445 "䑅" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x48,0x4b,0x7a,0x48,0x48,0x49,0x48,0x48,0x9b,
+0x88,0xfe,0x88,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x42,0xf8,0x88,0x48,0x30,0x60,0x80,
+/* 17478 0x4446 "䑆" */
+0x01,0x78,0x4b,0x48,0x49,0x78,0x4b,0x49,0x49,0x7b,0x4d,0x49,0x49,0x49,0x49,0x99,
+0x08,0x90,0xfc,0x40,0xf8,0x80,0xfc,0x48,0xfc,0x0a,0xf8,0x08,0xfa,0x34,0x8c,0x02,
+/* 17479 0x4447 "䑇" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7a,0x4c,0x4b,0x4a,0x7b,0x4a,0x4b,0x4a,0x4b,0x49,0x9a,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 17480 0x4448 "䑈" */
+0x01,0x79,0x4a,0x4a,0x4b,0x79,0x4a,0x4b,0x48,0x78,0x4b,0x48,0x48,0x49,0x4a,0x98,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 17481 0x4449 "䑉" */
+0xe0,0xbf,0xa4,0xa7,0xa0,0xe7,0xa4,0xa7,0xa0,0xee,0xab,0xae,0xaa,0xae,0x2a,0x77,
+0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x40,0x4e,0xea,0xaa,0xae,0x4a,0xaa,0x10,
+/* 17482 0x444a "䑊" */
+0x00,0x78,0x4a,0x49,0x49,0x78,0x48,0x4b,0x49,0x79,0x49,0x49,0x49,0x49,0x4a,0x9c,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x80,0x7e,
+/* 17483 0x444b "䑋" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x48,0x4b,0x48,0x7b,0x48,0x4b,0x48,0x49,0x4a,0x98,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 17484 0x444c "䑌" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 17485 0x444d "䑍" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x4b,0x49,0x4a,0x78,0x4f,0x48,0x49,0x48,0x48,0x9b,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 17486 0x444e "䑎" */
+0x01,0x79,0x4a,0x48,0x4f,0x79,0x4b,0x49,0x4b,0x79,0x4b,0x49,0x49,0x4b,0x48,0x98,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 17487 0x444f "䑏" */
+0x00,0x7b,0x48,0x4b,0x4a,0x7b,0x48,0x48,0x49,0x79,0x4b,0x4d,0x49,0x49,0x49,0x99,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 17488 0x4450 "䑐" */
+0x00,0x7e,0x48,0x48,0x48,0x7e,0x43,0x42,0x42,0x7e,0x48,0x48,0x49,0x48,0x7e,0x00,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x10,0x10,0x58,0x54,0x94,0x92,0x12,0x10,0x50,0x20,
+/* 17489 0x4451 "䑑" */
+0x00,0x7e,0x48,0x48,0x48,0x7e,0x42,0x42,0x42,0x7e,0x48,0x48,0x48,0x48,0x7e,0x00,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 17490 0x4452 "䑒" */
+0x00,0xfe,0x11,0x20,0x28,0x44,0xfe,0x12,0x11,0x10,0x7c,0x10,0x10,0x1e,0xf1,0x42,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 17491 0x4453 "䑓" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0x7f,0x40,0xbf,0x08,0x1f,0x01,0x1f,0x01,0x7f,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x02,0xfc,0x20,0xf0,0x00,0xf0,0x00,0xfc,
+/* 17492 0x4454 "䑔" */
+0x00,0x40,0x98,0x8b,0x88,0x88,0x89,0xd9,0x89,0x89,0x89,0x89,0xf9,0x88,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 17493 0x4455 "䑕" */
+0x06,0x38,0x20,0x3e,0x20,0x3f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x41,0x41,0x81,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x0a,0x0a,0x06,0x02,
+/* 17494 0x4456 "䑖" */
+0x00,0x40,0x9b,0x88,0x89,0x88,0x8b,0xd8,0x89,0x88,0x89,0x89,0xf9,0x8a,0x02,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 17495 0x4457 "䑗" */
+0x00,0x41,0x99,0x89,0x89,0x89,0x88,0xdb,0x89,0x89,0x8a,0x8c,0xf9,0x8a,0x00,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 17496 0x4458 "䑘" */
+0x01,0x40,0x98,0x8b,0x88,0x89,0x88,0xdb,0x88,0x89,0x89,0x8a,0xfc,0x88,0x03,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 17497 0x4459 "䑙" */
+0x08,0x1c,0x70,0x10,0x10,0xfd,0x10,0x10,0x7c,0x45,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 17498 0x445a "䑚" */
+0x08,0x1c,0x70,0x10,0x10,0xfc,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 17499 0x445b "䑛" */
+0x08,0x1c,0x71,0x11,0x11,0xfd,0x11,0x11,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 17500 0x445c "䑜" */
+0x08,0x1d,0x71,0x13,0x11,0xfd,0x11,0x11,0x7d,0x44,0x47,0x44,0x44,0x7d,0x46,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 17501 0x445d "䑝" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0xff,0x90,0x10,0x3d,0x44,0xa5,0x19,0x11,0x20,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfe,0x22,0x20,0xf8,0x20,0x20,0x20,0xfc,0x20,0x20,
+/* 17502 0x445e "䑞" */
+0x3f,0x24,0x29,0x26,0x38,0x22,0x25,0x22,0x2c,0x3f,0x10,0x3e,0x42,0x14,0x18,0xe0,
+0xfc,0x90,0x60,0x10,0x88,0x90,0x60,0x10,0x08,0xfc,0x10,0xfc,0x10,0x90,0xfe,0x10,
+/* 17503 0x445f "䑟" */
+0x0f,0xf0,0x11,0x89,0x42,0x00,0xff,0x81,0x42,0x77,0x92,0x5a,0x2f,0x22,0x42,0x82,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 17504 0x4460 "䑠" */
+0x08,0x11,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17505 0x4461 "䑡" */
+0x10,0x21,0x7c,0x44,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 17506 0x4462 "䑢" */
+0x10,0x20,0x7d,0x44,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x92,0x0e,0x00,
+/* 17507 0x4463 "䑣" */
+0x08,0x10,0x3f,0x21,0x29,0x25,0x25,0xff,0x21,0x29,0x25,0x25,0x21,0x41,0x45,0x82,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x20,0xc0,
+/* 17508 0x4464 "䑤" */
+0x08,0x10,0x3e,0x22,0x32,0x2b,0x2a,0xfe,0x22,0x33,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 17509 0x4465 "䑥" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4b,0x84,
+0x00,0xfc,0x44,0x48,0x48,0x50,0x5c,0x44,0x44,0x44,0x68,0xa8,0x90,0x98,0x24,0x42,
+/* 17510 0x4466 "䑦" */
+0x08,0x10,0x3e,0x22,0x33,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x28,0x10,
+/* 17511 0x4467 "䑧" */
+0x10,0x20,0x78,0x49,0x69,0x5b,0x4d,0xf9,0x49,0x49,0x69,0x59,0x49,0x49,0x49,0x99,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 17512 0x4468 "䑨" */
+0x10,0x20,0x7c,0x45,0x66,0x55,0x55,0xfd,0x47,0x65,0x55,0x55,0x45,0x45,0x54,0x88,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 17513 0x4469 "䑩" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 17514 0x446a "䑪" */
+0x08,0x10,0x3e,0x22,0x32,0x2b,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 17515 0x446b "䑫" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x23,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x85,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 17516 0x446c "䑬" */
+0x08,0x10,0x3e,0x23,0x32,0x2a,0x2a,0xfe,0x22,0x33,0x2a,0x2a,0x22,0x42,0x4b,0x86,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 17517 0x446d "䑭" */
+0x10,0x21,0x7c,0x44,0x64,0x56,0x55,0xfd,0x44,0x64,0x57,0x54,0x44,0x44,0x54,0x88,
+0x00,0x00,0xbe,0x88,0x08,0x08,0x08,0x48,0x48,0x88,0x88,0x88,0x88,0xfe,0x80,0x00,
+/* 17518 0x446e "䑮" */
+0x10,0x20,0x7c,0x44,0x64,0x54,0x55,0xfe,0x45,0x64,0x54,0x54,0x45,0x46,0x54,0x88,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x26,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 17519 0x446f "䑯" */
+0x11,0x20,0x7c,0x45,0x64,0x54,0x55,0xfd,0x45,0x65,0x54,0x54,0x45,0x46,0x54,0x88,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 17520 0x4470 "䑰" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2b,0xfe,0x22,0x32,0x2a,0x2b,0x22,0x42,0x4a,0x85,
+0x10,0x10,0x90,0x9e,0x90,0x90,0xfe,0x00,0x10,0x92,0x92,0x14,0x04,0x08,0x30,0xc0,
+/* 17521 0x4471 "䑱" */
+0x10,0x20,0x7b,0x4a,0x6d,0x59,0x49,0xfa,0x4a,0x4b,0x6c,0x58,0x49,0x49,0x4a,0x9c,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 17522 0x4472 "䑲" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2b,0x22,0x42,0x4a,0x84,
+0x20,0x20,0x3e,0x20,0xfc,0x84,0xfc,0x84,0xfc,0xa4,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 17523 0x4473 "䑳" */
+0x10,0x20,0x7c,0x44,0x65,0x56,0x54,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x89,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 17524 0x4474 "䑴" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x44,0x44,0xfe,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0xfe,0x00,0x28,0x44,0x82,
+/* 17525 0x4475 "䑵" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x54,0x88,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 17526 0x4476 "䑶" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x54,0x48,
+/* 17527 0x4477 "䑷" */
+0x10,0x20,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x8a,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x42,0x4a,0x44,
+/* 17528 0x4478 "䑸" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x10,0xfe,0x82,0x00,0x7c,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 17529 0x4479 "䑹" */
+0x10,0x20,0x7b,0x4a,0x68,0x59,0x48,0xf8,0x49,0x48,0x68,0x58,0x48,0x48,0x48,0x9b,
+0x40,0x20,0xfe,0x22,0xa4,0x28,0x50,0x88,0x04,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 17530 0x447a "䑺" */
+0x10,0x23,0x7a,0x4a,0x6b,0x5a,0x4b,0xfb,0x4b,0x4b,0x6a,0x5a,0x4b,0x4a,0x4c,0x98,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 17531 0x447b "䑻" */
+0x11,0x20,0x78,0x4b,0x69,0x59,0x49,0xf9,0x49,0x49,0x69,0x59,0x4a,0x4a,0x4c,0x98,
+0x08,0x88,0x88,0xde,0x10,0x20,0xde,0x42,0x44,0x44,0x5e,0x44,0x44,0x44,0xd4,0x08,
+/* 17532 0x447c "䑼" */
+0x10,0x20,0x7c,0x45,0x64,0x54,0x54,0xfc,0x45,0x64,0x55,0x56,0x44,0x44,0x54,0x89,
+0x40,0x40,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x48,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x08,
+/* 17533 0x447d "䑽" */
+0x10,0x21,0x79,0x49,0x69,0x59,0x48,0xfb,0x48,0x4a,0x69,0x58,0x4b,0x48,0x49,0x98,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 17534 0x447e "䑾" */
+0x10,0x20,0x79,0x4b,0x69,0x59,0x49,0xf9,0x49,0x49,0x6b,0x59,0x48,0x48,0x49,0x9e,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 17535 0x447f "䑿" */
+0x10,0x20,0x7b,0x4a,0x68,0x58,0x49,0xfb,0x4d,0x49,0x69,0x59,0x49,0x49,0x49,0x99,
+0x20,0x10,0xfe,0x02,0x80,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 17536 0x4480 "䒀" */
+0x11,0x21,0x79,0x4a,0x6c,0x58,0x48,0xf9,0x4b,0x4d,0x69,0x59,0x49,0x49,0x49,0x99,
+0x10,0x10,0xde,0xa8,0x44,0x88,0x88,0x08,0x7e,0x08,0x48,0x28,0x08,0x08,0x28,0x10,
+/* 17537 0x4481 "䒁" */
+0x10,0x23,0x78,0x4a,0x69,0x5a,0x48,0xf8,0x49,0x49,0x69,0x59,0x49,0x49,0x49,0x99,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 17538 0x4482 "䒂" */
+0x10,0x22,0x7a,0x4a,0x6a,0x5b,0x48,0xf8,0x4f,0x4a,0x6a,0x5a,0x4a,0x4a,0x4c,0x98,
+0x90,0x90,0x9e,0xa2,0xd4,0xa8,0x94,0xa4,0xfe,0x84,0xa4,0x94,0x94,0x84,0x94,0x88,
+/* 17539 0x4483 "䒃" */
+0x10,0x20,0x7a,0x49,0x68,0x58,0x48,0xfb,0x49,0x49,0x69,0x59,0x49,0x49,0x4a,0x9c,
+0x10,0x50,0x50,0x7c,0x90,0x10,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 17540 0x4484 "䒄" */
+0x10,0x20,0x7b,0x4a,0x69,0x58,0x48,0xf8,0x48,0x48,0x69,0x59,0x49,0x49,0x49,0x99,
+0x00,0x00,0xfe,0x02,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 17541 0x4485 "䒅" */
+0x10,0x21,0x7c,0x45,0x64,0x57,0x54,0xfd,0x47,0x65,0x55,0x55,0x45,0x45,0x55,0x89,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x04,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 17542 0x4486 "䒆" */
+0x11,0x20,0x7b,0x49,0x6a,0x5f,0x48,0xfb,0x4a,0x4b,0x6a,0x5b,0x4a,0x4a,0x4a,0x9a,
+0x08,0x88,0xe8,0x10,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 17543 0x4487 "䒇" */
+0x10,0x20,0x7b,0x4a,0x69,0x58,0x48,0xf8,0x48,0x48,0x69,0x59,0x49,0x49,0x49,0x99,
+0x40,0x20,0xfe,0x02,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 17544 0x4488 "䒈" */
+0x10,0x21,0x7c,0x44,0x67,0x54,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x44,0x55,0x8a,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 17545 0x4489 "䒉" */
+0x10,0x21,0x7b,0x4d,0x69,0x5b,0x49,0xf9,0x4b,0x49,0x69,0x5a,0x49,0x48,0x49,0x9a,
+0x80,0x00,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,
+/* 17546 0x448a "䒊" */
+0x04,0x24,0x22,0x22,0x43,0x40,0xbe,0x10,0x20,0x3e,0x02,0x02,0x02,0x02,0x14,0x08,
+0x40,0x40,0xfc,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 17547 0x448b "䒋" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x54,0xfe,0x10,0x10,0x28,0x24,0x44,0x80,
+0x40,0x40,0xfc,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 17548 0x448c "䒌" */
+0x00,0xff,0x81,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x10,0x08,0xff,0x00,0x24,0x42,0x81,
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x54,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 17549 0x448d "䒍" */
+0x20,0x10,0xfe,0x00,0x45,0x28,0xfe,0xa2,0x10,0xfe,0x20,0x3c,0x24,0x44,0x54,0x88,
+0x40,0x40,0xfc,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 17550 0x448e "䒎" */
+0x24,0x24,0xff,0x24,0x12,0xfe,0x24,0x42,0x81,0x24,0x24,0xff,0x24,0x24,0x44,0x84,
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x54,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 17551 0x448f "䒏" */
+0x44,0x24,0x28,0xfe,0x93,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+0x40,0x40,0xfc,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 17552 0x4490 "䒐" */
+0x22,0xff,0x22,0x7f,0x55,0x7f,0x00,0xff,0x80,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,
+0x20,0xa0,0x7c,0x44,0x88,0x7c,0x54,0xd4,0xd4,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 17553 0x4491 "䒑" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 17554 0x4492 "䒒" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x00,0x00,0x01,0x06,0x18,0x60,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x48,0x88,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 17555 0x4493 "䒓" */
+0x08,0x08,0xff,0x08,0x08,0x00,0xff,0x04,0x04,0x08,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xa0,0x40,
+/* 17556 0x4494 "䒔" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x20,0x40,0x40,0x40,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x02,
+/* 17557 0x4495 "䒕" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x01,0x01,0x11,0x11,0x21,0x21,0x41,0x81,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x10,0x08,0x04,0x04,0x02,0x02,0x00,0x00,
+/* 17558 0x4496 "䒖" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x7f,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x04,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf0,0x10,0x10,0x10,0xd0,0x12,0x0a,0x06,0x02,0x00,
+/* 17559 0x4497 "䒗" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x1f,0x20,0x40,0x9f,0x00,0x00,0x03,0x0c,0x10,0x0f,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xfc,0x00,0x00,0xe0,0x20,0xc0,0x00,0x04,0x04,0xfc,
+/* 17560 0x4498 "䒘" */
+0x08,0x08,0xff,0x08,0x08,0x04,0x04,0x0f,0x10,0x28,0x44,0x02,0x01,0x06,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 17561 0x4499 "䒙" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 17562 0x449a "䒚" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x01,0x11,0x11,0x21,0x21,0x41,0x00,0x01,0x0e,0xf0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x10,0x08,0x04,0x14,0x20,0x40,0x80,0x00,0x00,
+/* 17563 0x449b "䒛" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x22,0x42,0xfc,0x08,0x10,0x22,0x41,0xff,0x41,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 17564 0x449c "䒜" */
+0x08,0x08,0xff,0x08,0x09,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x01,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 17565 0x449d "䒝" */
+0x08,0x08,0xff,0x08,0x00,0x18,0x06,0x01,0x06,0x18,0x6c,0x02,0x01,0x06,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x08,0x10,0x60,0x80,0x60,0x18,0x24,0x40,0x80,0x60,0x18,0x06,
+/* 17566 0x449e "䒞" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x21,0x41,0x02,0x02,0x04,0x08,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x04,0x08,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 17567 0x449f "䒟" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x12,0x11,0x10,0xff,0x10,0x20,0x20,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 17568 0x44a0 "䒠" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 17569 0x44a1 "䒡" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x01,0x3f,0x20,0x40,0x7f,0x01,0x01,0x0a,0x04,
+0x20,0x20,0xfe,0x20,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 17570 0x44a2 "䒢" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x0c,0x70,0x40,0x40,0x40,0x4c,0x70,0x40,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,
+/* 17571 0x44a3 "䒣" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x7f,0x10,0x10,0x7f,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x50,0x20,
+/* 17572 0x44a4 "䒤" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 17573 0x44a5 "䒥" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 17574 0x44a6 "䒦" */
+0x08,0x08,0xff,0x08,0x01,0x3e,0x02,0x01,0x7f,0x00,0x01,0x0e,0x30,0x48,0x87,0x00,
+0x20,0x20,0xfe,0x20,0xf0,0x00,0x00,0x00,0xf8,0x60,0x80,0x00,0x00,0x00,0xfe,0x00,
+/* 17575 0x44a7 "䒧" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x01,0x01,0x01,0xff,0x04,0x08,0x10,0x3f,0x10,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x20,0x10,0xf8,0x08,
+/* 17576 0x44a8 "䒨" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x1f,0x21,0x41,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 17577 0x44a9 "䒩" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x00,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 17578 0x44aa "䒪" */
+0x08,0xff,0x08,0x04,0x08,0x10,0x3f,0x00,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x20,0xfe,0x20,0x00,0x20,0x10,0xf8,0x08,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 17579 0x44ab "䒫" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x50,0x48,0x40,0x7c,0xc0,0x40,0x20,0x20,0x14,0x0c,0x04,
+/* 17580 0x44ac "䒬" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x00,0x00,0xff,0x01,0x11,0x21,0x41,0x85,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x10,0x08,0x04,0x02,0x00,
+/* 17581 0x44ad "䒭" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0xff,0x08,0x04,0x04,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xfc,0x00,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 17582 0x44ae "䒮" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x80,0x0f,0x08,0x0a,0x09,0x09,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xe0,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 17583 0x44af "䒯" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x42,0x82,0x1f,0x02,0x0c,0x04,0x0a,0x11,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 17584 0x44b0 "䒰" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x2f,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,0x3f,
+0x40,0x40,0xfe,0x40,0x00,0xfe,0x00,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,0xfe,
+/* 17585 0x44b1 "䒱" */
+0x04,0x04,0xff,0x04,0x3f,0x00,0x00,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,0xff,0x00,
+0x40,0x40,0xfe,0x40,0xf0,0x20,0xc0,0x04,0x88,0x50,0x20,0x18,0x06,0x00,0xfe,0x00,
+/* 17586 0x44b2 "䒲" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xfe,0x12,0x22,0x22,0x64,0x15,0x08,0x14,0x22,0xc0,
+0x40,0x40,0xfe,0x40,0x08,0x1c,0xe0,0x20,0x20,0x20,0x3e,0xe0,0x22,0x22,0x22,0x1e,
+/* 17587 0x44b3 "䒳" */
+0x08,0x08,0xff,0x08,0x00,0x0f,0x08,0x10,0x61,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xe0,0x20,0x20,0x1c,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 17588 0x44b4 "䒴" */
+0x08,0x08,0xff,0x08,0x04,0x04,0x7f,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x08,0x08,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 17589 0x44b5 "䒵" */
+0x08,0x08,0xff,0x08,0x10,0x11,0xfc,0x24,0x24,0x25,0x44,0x24,0x18,0x18,0x24,0xc2,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x10,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17590 0x44b6 "䒶" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,0x01,0x0e,0x70,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xb0,0xc2,0x32,0x0e,
+/* 17591 0x44b7 "䒷" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x01,0x01,0xff,0x01,0x01,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0xf0,0x00,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 17592 0x44b8 "䒸" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 17593 0x44b9 "䒹" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x7f,0x01,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 17594 0x44ba "䒺" */
+0x08,0x08,0xff,0x0a,0x04,0x08,0x1f,0x00,0x03,0x0c,0x3f,0x01,0x11,0x21,0x45,0x02,
+0x20,0x20,0xfe,0x20,0x00,0x20,0xc0,0x80,0x20,0x10,0xf8,0x08,0x10,0x08,0x04,0x00,
+/* 17595 0x44bb "䒻" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x08,0x49,0x49,0x49,0x49,0x49,0x4f,0x79,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x04,0x04,0x04,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 17596 0x44bc "䒼" */
+0x08,0x08,0xff,0x08,0x04,0x04,0x3f,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xf8,0x48,0x48,0x48,0xf8,0x48,0x48,0x48,0xf8,0x08,
+/* 17597 0x44bd "䒽" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x2a,0x2a,0x24,0x24,0x2a,0x2a,0x20,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x08,0x28,0x10,
+/* 17598 0x44be "䒾" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0xff,0x02,0x05,0x09,0x18,0x28,0xc8,0x0a,0x0c,0x08,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 17599 0x44bf "䒿" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x50,0x20,
+/* 17600 0x44c0 "䓀" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x7f,0x01,0x01,0x1f,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0x00,0xf0,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 17601 0x44c1 "䓁" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x01,0x01,0xff,0x00,0x00,0x7f,0x08,0x04,0x04,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0xfc,0x20,0x20,0xa0,0x40,
+/* 17602 0x44c2 "䓂" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0xff,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x08,
+/* 17603 0x44c3 "䓃" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x1f,0x00,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x02,0x02,0xfe,0x00,
+/* 17604 0x44c4 "䓄" */
+0x08,0x08,0xff,0x08,0x44,0x28,0x11,0x29,0xc9,0x19,0x29,0x49,0x89,0x0a,0x52,0x24,
+0x20,0x20,0xfe,0x20,0x00,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 17605 0x44c5 "䓅" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x11,0x11,0x81,0x49,0x49,0x11,0xe1,0x22,0x22,0x24,
+0x20,0x20,0xfe,0x20,0x20,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 17606 0x44c6 "䓆" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x11,0xfd,0x11,0x11,0x1d,0xf1,0x11,0x12,0x52,0x24,
+0x40,0x40,0xfe,0x40,0x00,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 17607 0x44c7 "䓇" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x01,0x01,0xff,0x04,0x24,0x44,0x88,0x08,0x11,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x40,0x48,0x44,0x42,0x40,0x40,0x80,
+/* 17608 0x44c8 "䓈" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x20,0x41,0x8a,0x10,0x31,0x50,0x90,0x10,0x10,0x17,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x88,0x08,0x06,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 17609 0x44c9 "䓉" */
+0x08,0x08,0xff,0x08,0x00,0x7e,0x24,0x24,0x44,0x7f,0x14,0x24,0x44,0x84,0x14,0x08,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x44,0x48,0x50,0x48,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 17610 0x44ca "䓊" */
+0x08,0xff,0x08,0x00,0x7f,0x02,0x02,0x3f,0x04,0x08,0xff,0x00,0x1f,0x10,0x10,0x1f,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xfe,0x00,0xf0,0x10,0x10,0xf0,
+/* 17611 0x44cb "䓋" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x13,0x82,0x4a,0x4b,0x12,0xe2,0x22,0x22,0x23,0x22,
+0x20,0x20,0xfe,0x20,0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 17612 0x44cc "䓌" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x7f,0x01,0x01,0x3f,0x00,0x01,0x08,0x48,0x48,0x87,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0x84,0x92,0x12,0xf0,
+/* 17613 0x44cd "䓍" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 17614 0x44ce "䓎" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x14,0x55,0x5a,0x50,0x90,0x10,0x28,0x24,0x44,0x80,
+0x40,0x40,0xfe,0x40,0x80,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x28,0x10,
+/* 17615 0x44cf "䓏" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x03,0x0d,0x31,0xc1,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0x60,0x18,0x04,0xf0,0x10,0x10,0xf0,0x10,
+/* 17616 0x44d0 "䓐" */
+0x08,0xff,0x08,0x01,0x7f,0x04,0x08,0x31,0xc1,0x3f,0x01,0x11,0x11,0x1f,0x01,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x40,0x20,0x18,0x06,0xf8,0x00,0x10,0x14,0xf4,0x04,0xfc,
+/* 17617 0x44d1 "䓑" */
+0x08,0x08,0xff,0x08,0x20,0x17,0x91,0x41,0x41,0x17,0x21,0xe1,0x22,0x22,0x24,0x08,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 17618 0x44d2 "䓒" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x20,0x5f,0x92,0x12,0x1f,0x12,0x12,0x1f,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0xc8,0x48,0x48,0xc8,0x48,0x48,0xc8,0x28,0x10,
+/* 17619 0x44d3 "䓓" */
+0x08,0xff,0x0a,0x02,0x7f,0x02,0x3f,0x04,0xff,0x08,0x1f,0x20,0x44,0x82,0x02,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 17620 0x44d4 "䓔" */
+0x08,0x08,0xff,0x08,0x01,0x1f,0x01,0xff,0x01,0x1f,0x08,0x30,0xcf,0x00,0x02,0x01,
+0x20,0x20,0xfe,0x20,0x08,0xd0,0x20,0xfe,0x00,0xf0,0x20,0xc0,0xfc,0x80,0x80,0x00,
+/* 17621 0x44d5 "䓕" */
+0x08,0x08,0xff,0x08,0x23,0x10,0x10,0x07,0x71,0x11,0x12,0x12,0x14,0x28,0x47,0x00,
+0x20,0x20,0xfe,0x20,0xf0,0x00,0x00,0xfc,0x20,0x20,0x24,0x24,0x1c,0x00,0xfe,0x00,
+/* 17622 0x44d6 "䓖" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x88,0x12,0x22,0x1f,0x04,0x04,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x24,0x10,0x08,0xf0,0x10,0x10,0x10,0xa0,0x40,
+/* 17623 0x44d7 "䓗" */
+0x08,0x08,0xff,0x08,0x04,0x08,0x11,0x22,0xc4,0x08,0x1f,0x01,0x08,0x48,0x48,0x87,
+0x20,0x20,0xfe,0x20,0x40,0x20,0x10,0x08,0x46,0x20,0xf0,0x10,0x84,0x92,0x12,0xf0,
+/* 17624 0x44d8 "䓘" */
+0x08,0xff,0x08,0x00,0x08,0x1f,0x22,0x54,0x08,0x37,0xc0,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0xfe,0x20,0x00,0x40,0x60,0x50,0x48,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 17625 0x44d9 "䓙" */
+0x08,0xff,0x08,0x00,0x1f,0x01,0xff,0x01,0x09,0x79,0x09,0x09,0x19,0xe9,0x01,0x01,
+0x20,0xfe,0x20,0x70,0x80,0x00,0xfe,0x00,0x20,0x24,0x28,0x32,0x22,0x1e,0x00,0x00,
+/* 17626 0x44da "䓚" */
+0x04,0x04,0xff,0x04,0x10,0x21,0x41,0x89,0x11,0x31,0x51,0x91,0x11,0x11,0x17,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 17627 0x44db "䓛" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x3f,0x20,0x24,0x24,0x27,0x20,0x48,0x48,0x8f,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x80,0x90,0x90,0xf0,0x80,0x88,0x88,0xf8,
+/* 17628 0x44dc "䓜" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x13,0x82,0x4a,0x4b,0x12,0xe2,0x22,0x22,0x23,0x22,
+0x20,0x20,0xfe,0x20,0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x10,0x12,0x8a,0x26,0x12,
+/* 17629 0x44dd "䓝" */
+0x08,0xff,0x08,0x00,0x1f,0x00,0x01,0x7f,0x01,0x05,0x02,0x3f,0x24,0x24,0xff,0x00,
+0x20,0xfe,0x20,0x00,0xe0,0x40,0x80,0xfc,0x00,0x00,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 17630 0x44de "䓞" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x21,0x42,0x44,0x98,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x04,0x04,0xfc,0xa0,0x90,0xfc,0x20,0x10,0x08,0x06,
+/* 17631 0x44df "䓟" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x27,0x21,0x2f,0x20,0x27,0x24,0x47,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xc8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x28,0x10,
+/* 17632 0x44e0 "䓠" */
+0x08,0x08,0xff,0x08,0x01,0x7d,0x09,0x31,0xc5,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x04,0x98,0x60,0x18,0x06,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 17633 0x44e1 "䓡" */
+0x08,0x08,0xff,0x08,0x28,0x20,0x3e,0x48,0x88,0x08,0xff,0x08,0x14,0x22,0x41,0x80,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 17634 0x44e2 "䓢" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x2f,0x21,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 17635 0x44e3 "䓣" */
+0x08,0x08,0xff,0x08,0xff,0x01,0x01,0x7f,0x41,0x51,0x49,0x55,0x65,0x41,0x41,0x41,
+0x20,0x20,0xfe,0x20,0xfe,0x00,0x00,0xfc,0x04,0x44,0x24,0x54,0x94,0x04,0x14,0x08,
+/* 17636 0x44e4 "䓤" */
+0x04,0x04,0xff,0x04,0x08,0x1f,0x22,0x44,0x08,0x11,0x22,0x04,0x01,0x48,0x48,0x87,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x48,0x48,0x88,0x08,0x28,0x10,0x00,0x84,0x12,0xf2,
+/* 17637 0x44e5 "䓥" */
+0x06,0x01,0x06,0x18,0xe4,0x3f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x7f,0x01,0x01,
+0x00,0x00,0xc0,0x30,0x4e,0xf8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0x00,
+/* 17638 0x44e6 "䓦" */
+0x08,0x08,0xff,0x08,0x04,0x04,0x3f,0x24,0x24,0x3f,0x24,0x24,0xff,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfe,0x20,0x10,0x08,
+/* 17639 0x44e7 "䓧" */
+0x04,0xff,0x04,0x00,0x3f,0x00,0x00,0x79,0x49,0x49,0x49,0x79,0x01,0x05,0x02,0xff,
+0x40,0xfe,0x40,0x00,0xf0,0x20,0xc0,0x3c,0x04,0x68,0x10,0x28,0x44,0x00,0x00,0xfe,
+/* 17640 0x44e8 "䓨" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0x88,0x1f,0x21,0x01,0xff,0x01,0x21,0x21,0x3f,0x00,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x00,0x08,0x08,0xf8,0x08,
+/* 17641 0x44e9 "䓩" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x11,0xfc,0x10,0x31,0x38,0x54,0x50,0x90,0x10,0x13,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 17642 0x44ea "䓪" */
+0x08,0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x22,0x44,0x09,0x12,0x24,
+0x20,0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x48,0x88,0x08,0x28,0x10,
+/* 17643 0x44eb "䓫" */
+0x08,0x08,0xff,0x09,0x01,0x3f,0x04,0x08,0xff,0x00,0x1f,0x10,0x1f,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x40,0x20,0xfe,0x10,0x90,0x90,0x90,0x10,0x50,0x20,
+/* 17644 0x44ec "䓬" */
+0x08,0x08,0xff,0x08,0x01,0x01,0x01,0x3f,0x20,0x3f,0x20,0x3f,0x01,0xff,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,
+/* 17645 0x44ed "䓭" */
+0x08,0x08,0xff,0x08,0x01,0x32,0x0c,0x32,0xc9,0x08,0xff,0x08,0x2a,0x49,0xa8,0x10,
+0x20,0x20,0xfe,0x20,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x94,0x08,
+/* 17646 0x44ee "䓮" */
+0x08,0x08,0xff,0x08,0x3e,0x02,0x14,0x08,0xff,0x0a,0x18,0x28,0x48,0x08,0x28,0x11,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x50,0x20,0x50,0x88,0x04,
+/* 17647 0x44ef "䓯" */
+0x08,0xff,0x09,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x1f,0x12,0xff,0x20,0x3f,0x00,0x00,
+0x20,0xfe,0x20,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x10,0xfe,0x90,0xfc,0x10,0x60,
+/* 17648 0x44f0 "䓰" */
+0x08,0xff,0x08,0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x01,0x01,0x3f,0x01,0x01,0xff,
+0x20,0xfe,0x20,0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 17649 0x44f1 "䓱" */
+0x08,0xff,0x08,0x04,0x27,0x24,0x24,0x2f,0xf0,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x20,0xfe,0x20,0x40,0x4c,0x70,0x42,0x42,0x3e,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 17650 0x44f2 "䓲" */
+0x04,0x04,0xff,0x04,0x09,0x08,0x10,0x13,0x32,0x52,0x93,0x10,0x10,0x11,0x12,0x14,
+0x40,0x40,0xfe,0x40,0x08,0x90,0x00,0xfc,0x04,0x04,0xfc,0x90,0x90,0x12,0x12,0x0e,
+/* 17651 0x44f3 "䓳" */
+0x04,0x04,0xff,0x04,0x00,0x09,0x11,0x21,0x45,0x09,0x19,0x29,0x49,0x09,0x09,0x09,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x24,0x28,0x10,0x48,0x86,0x00,
+/* 17652 0x44f4 "䓴" */
+0x08,0xff,0x08,0x00,0xff,0x02,0x3f,0x24,0x24,0x21,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x20,0xfe,0x20,0x00,0xfe,0x00,0xf8,0x88,0xa8,0x10,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 17653 0x44f5 "䓵" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x1f,0x00,0x7e,0x42,0x42,0x42,0x7e,0x42,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 17654 0x44f6 "䓶" */
+0x04,0x04,0xff,0x04,0x08,0x08,0xff,0x08,0x7f,0x49,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x40,0x40,0xfe,0x40,0x08,0x08,0x88,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 17655 0x44f7 "䓷" */
+0x08,0x08,0xff,0x08,0x21,0x12,0x94,0x41,0x43,0x15,0x21,0xe1,0x21,0x21,0x21,0x21,
+0x20,0x20,0xfe,0xa0,0x00,0x3c,0x80,0x00,0x7e,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 17656 0x44f8 "䓸" */
+0x04,0x04,0xff,0x04,0x08,0x7e,0x12,0x24,0x18,0x65,0x08,0x7e,0x12,0x24,0x18,0x64,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 17657 0x44f9 "䓹" */
+0x08,0x08,0xff,0x09,0x02,0x0e,0x31,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x11,0x14,0x18,
+0x20,0x20,0xfe,0x20,0x80,0x60,0x18,0xe6,0x20,0xe0,0x20,0xe0,0x08,0x90,0x60,0x10,
+/* 17658 0x44fa "䓺" */
+0x08,0xff,0x08,0x10,0x08,0x7f,0x01,0x3f,0x01,0xff,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x20,0xfe,0x20,0x10,0x20,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 17659 0x44fb "䓻" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0xbe,0x00,0x01,0x7e,0x14,0x14,0x14,0x25,0x24,0x43,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0x24,0x20,0xfc,0x48,0xc8,0x30,0x6a,0x86,0x02,0xfe,
+/* 17660 0x44fc "䓼" */
+0x08,0xff,0x08,0x10,0x10,0x13,0xfc,0x24,0x24,0x24,0x48,0x28,0x10,0x29,0x45,0x82,
+0x20,0xfe,0x20,0x88,0x84,0xfe,0xa4,0xa8,0xb4,0xa8,0xb2,0xa4,0xaa,0x32,0x22,0xde,
+/* 17661 0x44fd "䓽" */
+0x04,0x04,0xff,0x04,0x20,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0x80,0x82,0x82,0x7e,
+/* 17662 0x44fe "䓾" */
+0x08,0x08,0xff,0x08,0x20,0x12,0x44,0x20,0x08,0x73,0x20,0x04,0xff,0x08,0x07,0x78,
+0x20,0x20,0xfe,0x20,0x40,0x48,0x44,0x14,0x60,0x80,0x00,0x00,0xfe,0x20,0xc0,0x38,
+/* 17663 0x44ff "䓿" */
+0x08,0xff,0x08,0x00,0x3f,0x04,0x02,0x7f,0x44,0x42,0x5f,0x41,0x7f,0x41,0x41,0x7f,
+0x20,0xfe,0x20,0x00,0xe0,0x40,0x80,0xfc,0x44,0x84,0xf4,0x04,0xfc,0x04,0x04,0xfc,
+/* 17664 0x4500 "䔀" */
+0x04,0xff,0x04,0x10,0x13,0x20,0x27,0x61,0xa2,0x24,0x20,0x2f,0x21,0x23,0x20,0x27,
+0x40,0xfe,0x40,0x38,0xc0,0x40,0xfc,0x50,0x48,0x46,0x80,0xfe,0x10,0x20,0xe0,0x18,
+/* 17665 0x4501 "䔁" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x04,0x3f,0x24,0x3f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 17666 0x4502 "䔂" */
+0x08,0xff,0x0a,0x01,0x7f,0x42,0x81,0x3f,0x08,0x04,0xff,0x01,0x3f,0x01,0x01,0x01,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf8,0x20,0x40,0xfe,0x00,0xf8,0x00,0x00,0x00,
+/* 17667 0x4503 "䔃" */
+0x08,0x08,0xff,0x08,0x20,0x11,0xfd,0x09,0x11,0x39,0x55,0x95,0x11,0x11,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 17668 0x4504 "䔄" */
+0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x20,0x3f,0x41,0x01,0xff,0x01,0x21,0x21,0x3f,
+0x20,0xfe,0x20,0xfc,0x00,0x08,0x10,0x20,0xf8,0x00,0x00,0xfe,0x00,0x08,0x08,0xf8,
+/* 17669 0x4505 "䔅" */
+0x08,0xff,0x08,0x00,0x7f,0x00,0x1f,0x11,0x1f,0x00,0xff,0x00,0x1f,0x11,0x1f,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0x20,0x20,0x20,0x00,0xfc,0x20,0x20,0x20,0x20,0x60,
+/* 17670 0x4506 "䔆" */
+0x08,0x08,0xff,0x08,0x44,0x29,0x11,0x29,0x49,0x99,0x28,0x49,0x88,0x08,0x53,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17671 0x4507 "䔇" */
+0x08,0xff,0x08,0x01,0x21,0x21,0x3f,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x08,0x04,0xff,
+0x20,0xfe,0x20,0x00,0x08,0x08,0xf8,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x20,0x40,0xfe,
+/* 17672 0x4508 "䔈" */
+0x04,0xff,0x04,0x3f,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0xfe,0x40,0xf8,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 17673 0x4509 "䔉" */
+0x08,0x08,0xff,0x08,0x0c,0x71,0x10,0x10,0xfd,0x30,0x38,0x54,0x51,0x92,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x1c,0xe0,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 17674 0x450a "䔊" */
+0x08,0x08,0xff,0x08,0x01,0xfc,0x11,0x10,0x10,0x7c,0x13,0x10,0x1c,0xf1,0x41,0x02,
+0x20,0x20,0xfe,0x20,0x08,0x90,0xfc,0x90,0x90,0x90,0xfe,0x90,0x90,0x10,0x10,0x10,
+/* 17675 0x450b "䔋" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x24,0x7c,0x08,0x11,0x25,0x7e,0x00,0x54,0x54,0x83,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0xa8,0xa4,0x22,0x22,0x28,0x10,0x20,0xc0,0x00,
+/* 17676 0x450c "䔌" */
+0x08,0xff,0x08,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x08,0x31,0xcf,0x01,0x01,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x20,0x18,0xe6,0x00,0x00,
+/* 17677 0x450d "䔍" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x00,0x29,0x44,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 17678 0x450e "䔎" */
+0x08,0x08,0xff,0x08,0x20,0x17,0x10,0x03,0x72,0x12,0x13,0x11,0x12,0x14,0x28,0x47,
+0x20,0x20,0xfe,0x20,0x40,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x50,0x48,0x44,0x40,0xfe,
+/* 17679 0x450f "䔏" */
+0x08,0xff,0x08,0x00,0x22,0x13,0x14,0x00,0x77,0x10,0x13,0x12,0x13,0x28,0x47,0x00,
+0x20,0xfe,0x20,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x00,
+/* 17680 0x4510 "䔐" */
+0x04,0x04,0xff,0x04,0x21,0x11,0x17,0x80,0x40,0x53,0x11,0x21,0xe7,0x20,0x20,0x23,
+0x40,0x40,0xfe,0x40,0x20,0x10,0xfc,0x90,0x64,0x9c,0x20,0x10,0xfc,0x90,0x64,0x9c,
+/* 17681 0x4511 "䔑" */
+0x04,0x04,0xff,0x04,0x08,0x14,0x22,0x5d,0x88,0x08,0x7f,0x08,0x2a,0x49,0xa8,0x10,
+0x40,0x40,0xfe,0x40,0x08,0x48,0x28,0x08,0xc8,0x28,0x0e,0xf8,0x08,0x08,0x88,0x08,
+/* 17682 0x4512 "䔒" */
+0x08,0x08,0xff,0x08,0x00,0x78,0x4b,0x51,0x60,0x57,0x48,0x49,0x69,0x51,0x41,0x41,
+0x20,0x20,0xfe,0x20,0x80,0x40,0xfc,0x08,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 17683 0x4513 "䔓" */
+0x08,0xff,0x08,0x20,0x10,0xfe,0x00,0x7c,0x01,0x7c,0x01,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0xfe,0x20,0x00,0x40,0x40,0xfe,0x90,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 17684 0x4514 "䔔" */
+0x08,0xff,0x08,0x01,0x3f,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x20,0xfe,0x20,0x00,0xf8,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 17685 0x4515 "䔕" */
+0x04,0x04,0xff,0x04,0x00,0x78,0x4b,0x48,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x99,
+0x40,0x40,0xfe,0x40,0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x0c,
+/* 17686 0x4516 "䔖" */
+0x08,0xff,0x08,0x00,0x78,0x4b,0x50,0x67,0x51,0x4a,0x4c,0x69,0x52,0x40,0x41,0x4e,
+0x20,0xfe,0x20,0x00,0x40,0xf8,0x40,0xfc,0x10,0x88,0xf4,0x10,0xa0,0x40,0xb0,0x0e,
+/* 17687 0x4517 "䔗" */
+0x08,0x08,0xff,0x08,0x20,0x10,0xfb,0x08,0x10,0x39,0x54,0x94,0x13,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 17688 0x4518 "䔘" */
+0x04,0x04,0xff,0x04,0x20,0x20,0x3c,0x50,0x10,0xfc,0x10,0x54,0x54,0x5c,0x75,0x04,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,
+/* 17689 0x4519 "䔙" */
+0x08,0x08,0xff,0x08,0x10,0x28,0x44,0xb9,0x12,0x7c,0x10,0x94,0x50,0x1e,0xe0,0x40,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x28,0x10,
+/* 17690 0x451a "䔚" */
+0x08,0xff,0x08,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x26,0x24,0x2f,0x48,0x4f,0x88,0x08,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,0xf8,0x08,0xf8,0x08,0x18,
+/* 17691 0x451b "䔛" */
+0x08,0x08,0xff,0x08,0x23,0x20,0x21,0x21,0x3d,0x21,0x21,0x25,0x29,0x30,0x20,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x90,0x08,
+/* 17692 0x451c "䔜" */
+0x04,0x04,0xff,0x04,0x00,0xfc,0x49,0x79,0x49,0x79,0x49,0x4d,0xfb,0x09,0x09,0x09,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfe,0x04,0x14,0x08,
+/* 17693 0x451d "䔝" */
+0x04,0xff,0x04,0x08,0x2f,0x28,0x2f,0xf4,0x08,0x1f,0x03,0x0c,0x3f,0x01,0x15,0x22,
+0x40,0xfe,0x40,0x44,0x78,0x42,0x3e,0x00,0x20,0xc0,0x10,0x08,0xfc,0x04,0x10,0x08,
+/* 17694 0x451e "䔞" */
+0x08,0xff,0x0a,0x01,0x7f,0x02,0x44,0x2f,0x11,0x22,0x4f,0x00,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0x44,0x88,0x10,0x48,0xe4,0x20,0x00,0xfe,0x00,0x00,
+/* 17695 0x451f "䔟" */
+0x04,0xff,0x04,0x00,0x0c,0x70,0x13,0x10,0xfc,0x30,0x3b,0x54,0x55,0x90,0x10,0x13,
+0x40,0xfe,0x40,0x20,0x40,0xfc,0x08,0x90,0x60,0x90,0x3e,0x42,0xa4,0x18,0x60,0x80,
+/* 17696 0x4520 "䔠" */
+0x04,0x04,0xff,0x04,0x10,0x11,0xfc,0x10,0x31,0x39,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x40,0x20,0x24,0xa8,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 17697 0x4521 "䔡" */
+0x04,0x04,0xff,0x04,0x08,0x1f,0x20,0x7f,0xa1,0x3f,0x21,0x3f,0x00,0x24,0x22,0x42,
+0x40,0x40,0xfe,0x40,0x00,0xe0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x88,0x44,0x44,
+/* 17698 0x4522 "䔢" */
+0x08,0xff,0x08,0x14,0x22,0x08,0x14,0x22,0x1f,0x00,0xff,0x10,0x1f,0x00,0x00,0x00,
+0x20,0xfe,0x20,0x50,0x88,0x20,0x50,0x88,0xf0,0x00,0xfe,0x00,0xf8,0x08,0x50,0x20,
+/* 17699 0x4523 "䔣" */
+0x08,0xff,0x08,0x03,0x3c,0x04,0x7f,0x16,0x25,0x44,0x11,0x1f,0x21,0xff,0x01,0x01,
+0x20,0xfe,0x20,0x04,0x24,0x24,0xa4,0x24,0x04,0x0c,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 17700 0x4524 "䔤" */
+0x08,0x08,0xff,0x08,0x00,0x13,0x20,0x7c,0x45,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 17701 0x4525 "䔥" */
+0x08,0xff,0x08,0x01,0x3f,0x01,0xff,0x01,0x3f,0x09,0x25,0x2f,0x23,0x25,0x29,0x41,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xfc,0x10,0xf0,0x20,0x48,0xe8,0x88,0x48,0x28,0x08,
+/* 17702 0x4526 "䔦" */
+0x04,0x04,0xff,0x04,0x11,0x11,0x12,0xfd,0x31,0x39,0x57,0x51,0x92,0x13,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x00,0xf8,0x48,0x28,0xfe,0x48,0x28,0xfc,0x50,0x20,
+/* 17703 0x4527 "䔧" */
+0x08,0xff,0x08,0x03,0x3c,0x04,0x7f,0x16,0x25,0x44,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x20,0xfe,0x20,0x04,0x24,0x24,0xa4,0x24,0x04,0x0c,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 17704 0x4528 "䔨" */
+0x08,0xff,0x08,0x10,0x10,0x24,0x45,0x7a,0x10,0x24,0x44,0x78,0x08,0x10,0x20,0xc0,
+0x20,0xfe,0x20,0x50,0x48,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0xfe,0x80,
+/* 17705 0x4529 "䔩" */
+0x04,0x04,0xff,0x04,0x08,0x08,0xff,0x08,0x7f,0x49,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17706 0x452a "䔪" */
+0x08,0xff,0x08,0x01,0x7f,0x01,0x29,0x11,0x29,0x01,0x29,0x11,0x2a,0x04,0x18,0xe0,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0x28,0x10,0x28,0x00,0x28,0x10,0xa8,0x40,0x30,0x0e,
+/* 17707 0x452b "䔫" */
+0x04,0x04,0xff,0x04,0x00,0x7c,0x07,0x18,0x51,0x5d,0x51,0x50,0x5c,0x71,0xc2,0x00,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfe,0x20,0xfc,0x24,0x2c,0x70,0xa8,0x24,0x22,0x20,
+/* 17708 0x452c "䔬" */
+0x08,0xff,0x08,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x04,0x3f,0x04,0xff,0x08,0x10,0x20,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xf8,0x40,0xfe,0x20,0x10,0x08,
+/* 17709 0x452d "䔭" */
+0x08,0xff,0x09,0x7f,0x41,0x14,0x14,0x23,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,
+0x20,0xfe,0x20,0xfc,0x04,0x90,0x28,0xe8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 17710 0x452e "䔮" */
+0x08,0x08,0xff,0x08,0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0xff,0x22,0x41,0x80,
+0x20,0x20,0xfe,0x20,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,
+/* 17711 0x452f "䔯" */
+0x08,0xff,0x08,0x00,0x7f,0x14,0x14,0x7f,0x55,0x55,0x57,0x61,0x7f,0x41,0x7f,0x41,
+0x20,0xfe,0x20,0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 17712 0x4530 "䔰" */
+0x08,0xff,0x09,0x7f,0x40,0x3f,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,
+0x20,0xfe,0x20,0xfc,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 17713 0x4531 "䔱" */
+0x08,0x08,0xff,0x08,0x11,0x11,0xfd,0x10,0x13,0x11,0x1d,0xf1,0x11,0x11,0x57,0x20,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,
+/* 17714 0x4532 "䔲" */
+0x08,0x08,0xff,0x08,0x00,0x7e,0x04,0x28,0x17,0x20,0xdf,0x10,0x1f,0x08,0x04,0x7f,
+0x20,0x20,0xfe,0x20,0x90,0xa0,0x44,0x28,0xd0,0x08,0xf6,0x10,0xf0,0x20,0x40,0xfc,
+/* 17715 0x4533 "䔳" */
+0x04,0x04,0xff,0x04,0x10,0x1e,0x32,0x4a,0xa4,0x18,0x10,0x21,0xc0,0x24,0x22,0x42,
+0x40,0x40,0xfe,0x40,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x06,0x00,0x88,0x44,0x44,
+/* 17716 0x4534 "䔴" */
+0x04,0xff,0x04,0x08,0x2a,0x3e,0x49,0x7f,0x00,0x3e,0x00,0x7f,0x08,0x2a,0x49,0x18,
+0x40,0xfe,0x40,0x00,0x00,0x7c,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 17717 0x4535 "䔵" */
+0x08,0xff,0x08,0x00,0x7c,0x44,0x7c,0x44,0x7d,0x41,0x5f,0x43,0x45,0x49,0x51,0x41,
+0x20,0xfe,0x20,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x84,0x44,0x24,0x24,0x0c,
+/* 17718 0x4536 "䔶" */
+0x08,0xff,0x08,0x00,0x11,0x11,0xfd,0x11,0x15,0x18,0x37,0xd0,0x11,0x11,0x52,0x24,
+0x20,0xfe,0x20,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x3c,0x20,0xa0,0x7e,
+/* 17719 0x4537 "䔷" */
+0x08,0xff,0x08,0x00,0xfe,0x10,0x7c,0x10,0xfe,0x01,0x06,0x1a,0xe1,0x1f,0x00,0x00,
+0x20,0xfe,0x20,0x00,0xfe,0x10,0x7c,0x10,0xfe,0x00,0xc0,0x30,0x0e,0xe0,0x40,0x80,
+/* 17720 0x4538 "䔸" */
+0x04,0xff,0x04,0x01,0xff,0x02,0x0c,0x30,0xc0,0x10,0x14,0xfe,0x10,0x28,0x44,0x81,
+0x40,0xfe,0x40,0x20,0xfe,0x80,0x60,0x18,0x06,0x28,0x24,0xfe,0x20,0x50,0x88,0x06,
+/* 17721 0x4539 "䔹" */
+0x08,0xff,0x08,0x01,0x78,0x4b,0x48,0x51,0x56,0x48,0x49,0x4e,0x68,0x51,0x46,0x40,
+0x20,0xfe,0x20,0x08,0x90,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 17722 0x453a "䔺" */
+0x04,0xff,0x04,0x7b,0x48,0x49,0x52,0x55,0x48,0x49,0x49,0x69,0x51,0x41,0x41,0x41,
+0x40,0xfe,0x40,0xfc,0x80,0xf8,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 17723 0x453b "䔻" */
+0x08,0xff,0x08,0x10,0xfe,0x00,0x7c,0x45,0x7e,0x00,0x7c,0x08,0xfe,0x10,0x50,0x23,
+0x20,0xfe,0x20,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 17724 0x453c "䔼" */
+0x08,0xff,0x08,0x00,0x7e,0x12,0x52,0x93,0x26,0x40,0x08,0x2e,0x28,0x2e,0xf1,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x24,0xa4,0x24,0x4c,0x90,0x50,0x5c,0x50,0x50,0xfe,0x00,
+/* 17725 0x453d "䔽" */
+0x08,0xff,0x08,0x23,0x12,0x13,0x82,0x43,0x51,0x13,0x24,0xea,0x22,0x23,0x20,0x20,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0x04,0xf4,0x14,0x08,
+/* 17726 0x453e "䔾" */
+0x08,0xff,0x08,0x23,0x22,0x23,0xfa,0x23,0x29,0x33,0x64,0xaa,0x22,0x23,0xa0,0x40,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0x04,0xf4,0x14,0x08,
+/* 17727 0x453f "䔿" */
+0x08,0xff,0x08,0x04,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,0x00,0xff,0x08,0x04,
+0x20,0xfe,0x20,0x40,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,0x20,0xfe,0x20,0x60,
+/* 17728 0x4540 "䕀" */
+0x04,0x04,0xff,0x04,0x08,0x7f,0x08,0x3e,0x00,0x3e,0x00,0x7f,0x08,0x2a,0x49,0x18,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 17729 0x4541 "䕁" */
+0x08,0xff,0x08,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x05,0x01,0xff,0x05,0x19,0xe1,0x01,
+0x20,0xfe,0x20,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 17730 0x4542 "䕂" */
+0x08,0xff,0x08,0x00,0x21,0x12,0x17,0x00,0x73,0x12,0x13,0x10,0x11,0x12,0x2c,0x47,
+0x20,0xfe,0x20,0x80,0x10,0x08,0xfc,0x04,0xf8,0x08,0xf8,0xc4,0xa8,0x90,0x88,0xfe,
+/* 17731 0x4543 "䕃" */
+0x08,0xff,0x08,0x00,0x78,0x49,0x4b,0x55,0x51,0x49,0x49,0x49,0x6f,0x51,0x42,0x43,
+0x20,0xfe,0x20,0x40,0xa0,0x10,0xf8,0x06,0xf0,0x00,0xf0,0x00,0xfc,0x00,0x10,0xf8,
+/* 17732 0x4544 "䕄" */
+0x08,0xff,0x08,0x00,0x1f,0x00,0x7d,0x05,0x09,0x35,0xc2,0x1f,0x00,0x3f,0x24,0xff,
+0x20,0xfe,0x20,0x00,0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0xf0,0x00,0xf8,0x48,0xfe,
+/* 17733 0x4545 "䕅" */
+0x08,0xff,0x08,0x00,0x11,0x11,0xfd,0x25,0x25,0x48,0x29,0x10,0x28,0x44,0x80,0x03,
+0x20,0xfe,0x20,0x80,0x2c,0x24,0xac,0x24,0xfc,0x20,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 17734 0x4546 "䕆" */
+0x04,0xff,0x04,0x20,0x21,0x22,0xf5,0x20,0x67,0x74,0xaf,0xa4,0x27,0x24,0x24,0x25,
+0x40,0xfe,0x40,0xa0,0x10,0x08,0xf6,0x00,0x84,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x88,
+/* 17735 0x4547 "䕇" */
+0x08,0xff,0x09,0x00,0x3f,0x20,0x21,0x2f,0x28,0x2f,0x29,0x2f,0x42,0x44,0x98,0x60,
+0x20,0xfe,0x20,0x80,0xfc,0x80,0x00,0xf8,0x88,0xf8,0x08,0xf8,0x54,0x5c,0x42,0x3e,
+/* 17736 0x4548 "䕈" */
+0x08,0xff,0x08,0x00,0x09,0x4b,0x49,0x79,0x09,0x09,0xf8,0x4b,0x48,0x48,0x8b,0x08,
+0x20,0xfe,0x20,0x48,0x48,0xfe,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 17737 0x4549 "䕉" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x01,0x3f,0x01,0xff,0x04,0x3f,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x40,0xf8,0x00,0xfe,0x00,0x00,
+/* 17738 0x454a "䕊" */
+0x08,0xff,0x09,0xff,0x00,0x3f,0x20,0x27,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x00,0xff,
+0x20,0xfe,0x20,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 17739 0x454b "䕋" */
+0x08,0xff,0x08,0x10,0x10,0x13,0x12,0x7e,0x12,0x13,0x12,0x1e,0xe2,0x04,0x04,0x08,
+0x20,0xfe,0x20,0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x84,0xfc,
+/* 17740 0x454c "䕌" */
+0x08,0xff,0x08,0x00,0x0c,0x70,0x11,0x11,0xfb,0x31,0x39,0x55,0x51,0x91,0x11,0x11,
+0x20,0xfe,0x20,0x00,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17741 0x454d "䕍" */
+0x08,0xff,0x0a,0x01,0xff,0x04,0x1a,0xec,0x08,0x3f,0x24,0x2f,0x34,0x27,0x20,0x20,
+0x20,0xfe,0x20,0x00,0xfe,0x88,0x70,0x18,0x06,0xf8,0x48,0xe8,0x58,0xc8,0x28,0x10,
+/* 17742 0x454e "䕎" */
+0x08,0x08,0xff,0x08,0x01,0x7c,0x44,0x44,0x44,0x7c,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 17743 0x454f "䕏" */
+0x04,0xff,0x04,0x10,0x08,0x3f,0x01,0x7f,0x02,0x3c,0x08,0xff,0x08,0x7e,0x08,0x19,
+0x40,0xfe,0x40,0x10,0x20,0xf8,0x00,0xfc,0x40,0x50,0x48,0xfe,0x50,0x24,0x54,0x8c,
+/* 17744 0x4550 "䕐" */
+0x08,0x08,0xff,0x08,0x21,0x10,0xfc,0x08,0x10,0x38,0x55,0x95,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 17745 0x4551 "䕑" */
+0x04,0xff,0x04,0x00,0x11,0x10,0x25,0x7c,0x08,0x10,0x25,0x7c,0x00,0x54,0x54,0x81,
+0x40,0xfe,0x40,0x1c,0xe0,0x44,0x24,0x88,0x20,0x20,0xfc,0x48,0xc8,0x30,0x68,0x84,
+/* 17746 0x4552 "䕒" */
+0x08,0xff,0x09,0xff,0x01,0x3f,0x00,0x1f,0x10,0x1f,0x08,0xff,0x10,0x7e,0x22,0x46,
+0x20,0xfe,0x20,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x20,0xfe,0x00,0xf8,0x88,0xf8,
+/* 17747 0x4553 "䕓" */
+0x08,0xff,0x0a,0x01,0x7f,0x50,0x9e,0x22,0x54,0x28,0x17,0x20,0xdf,0x01,0x11,0x23,
+0x20,0xfe,0x20,0x00,0xfe,0x82,0xfc,0x88,0x50,0x20,0xd8,0x06,0xf0,0x00,0x10,0x08,
+/* 17748 0x4554 "䕔" */
+0x08,0xff,0x08,0x21,0x41,0x82,0x14,0x2b,0x71,0xa7,0x21,0x29,0x25,0x21,0x2e,0x24,
+0x20,0xfe,0x20,0x00,0x1c,0x80,0x40,0xbe,0x08,0xc8,0x08,0x48,0x08,0xc8,0x28,0x10,
+/* 17749 0x4555 "䕕" */
+0x08,0xff,0x08,0x11,0x09,0x09,0x41,0x23,0x2a,0x0b,0x10,0x73,0x10,0x10,0x11,0x16,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 17750 0x4556 "䕖" */
+0x08,0xff,0x08,0x40,0x2f,0x21,0x02,0x02,0xe3,0x2e,0x22,0x22,0x2a,0x24,0x50,0x8f,
+0x20,0xfe,0x20,0x0c,0x70,0x10,0x24,0x78,0x12,0x7e,0x10,0x54,0x92,0x30,0x00,0xfe,
+/* 17751 0x4557 "䕗" */
+0x08,0xff,0x0a,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0xff,0x08,0x10,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x20,0x20,
+/* 17752 0x4558 "䕘" */
+0x04,0xff,0x04,0x10,0x13,0x28,0x45,0x93,0x09,0xfd,0x05,0x09,0x51,0x20,0x10,0x01,
+0x40,0xfe,0x40,0x00,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x90,0x08,
+/* 17753 0x4559 "䕙" */
+0x04,0xff,0x04,0x08,0x7f,0x08,0xff,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x40,0xfe,0x40,0x20,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x18,0x92,0x2a,0xc6,0x82,
+/* 17754 0x455a "䕚" */
+0x08,0xff,0x08,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x24,0x27,0x24,0x27,0x22,0x3f,
+0x20,0xfe,0x20,0xfc,0x80,0xf0,0x90,0xf0,0x80,0xfc,0x10,0xf0,0x10,0xf0,0x20,0xfc,
+/* 17755 0x455b "䕛" */
+0x04,0xff,0x04,0x20,0x10,0xfd,0x00,0x78,0x00,0x78,0x01,0x7a,0x48,0x48,0x79,0x4a,
+0x40,0xfe,0x40,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x50,0x88,0x04,0x02,
+/* 17756 0x455c "䕜" */
+0x08,0xff,0x08,0x7c,0x24,0x14,0x24,0x01,0x7f,0x08,0x14,0x22,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0xf8,0x48,0x28,0x48,0x00,0xfc,0x20,0x50,0x88,0x00,0xfe,0x00,0x00,
+/* 17757 0x455d "䕝" */
+0x08,0xff,0x08,0x00,0x0d,0x70,0x11,0x10,0xfd,0x31,0x39,0x55,0x53,0x91,0x11,0x11,
+0x20,0xfe,0x20,0x1e,0xe0,0x44,0x24,0xa8,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 17758 0x455e "䕞" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7d,0x47,0x44,0x47,0x44,0x47,0x44,0x45,0x46,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0xc4,0x44,0xc4,0x44,0xd4,0xa4,0x44,0x2c,
+/* 17759 0x455f "䕟" */
+0x08,0xff,0x08,0x00,0x2f,0x48,0x4b,0x68,0x4b,0x6a,0x4b,0x48,0xff,0x10,0x20,0x40,
+0x20,0xfe,0x20,0x00,0xec,0x24,0xa4,0x2c,0xa4,0xac,0xa4,0x24,0xfe,0x10,0x08,0x04,
+/* 17760 0x4560 "䕠" */
+0x08,0xff,0x08,0x00,0x3f,0x20,0x2f,0x31,0x2a,0x27,0x29,0x37,0x28,0x4f,0x41,0x87,
+0x20,0xfe,0x20,0x80,0xfe,0x20,0x28,0x10,0x0a,0x7c,0x4a,0x84,0x78,0x48,0x30,0x4c,
+/* 17761 0x4561 "䕡" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x47,0x44,0x47,0x40,0x4f,0x48,0x4f,0x40,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0xc4,0x44,0xc4,0x04,0xe4,0x24,0xe4,0x0c,
+/* 17762 0x4562 "䕢" */
+0x08,0x08,0xff,0x08,0x00,0x7c,0x13,0x10,0x21,0x3c,0x67,0xa4,0x25,0x26,0x3c,0x25,
+0x20,0x20,0xfe,0x20,0x88,0x50,0xfe,0x20,0xfc,0x40,0xfe,0x80,0x7c,0x10,0x10,0xfe,
+/* 17763 0x4563 "䕣" */
+0x08,0xff,0x08,0x23,0x12,0x03,0xfa,0x0b,0x11,0x2b,0x74,0xaa,0x2a,0x23,0x20,0x20,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0x04,0xf4,0x14,0x08,
+/* 17764 0x4564 "䕤" */
+0x08,0xff,0x08,0x77,0x55,0x77,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x20,0xfe,0x20,0x00,0x7c,0x44,0x48,0x50,0x48,0x44,0x44,0x54,0x48,0xc0,0x40,0x40,
+/* 17765 0x4565 "䕥" */
+0x04,0xff,0x04,0x11,0x25,0x49,0xbf,0x21,0x35,0x29,0x35,0x21,0x35,0x29,0x35,0x21,
+0x40,0xfe,0x40,0x10,0x48,0x24,0xfa,0x08,0x58,0x28,0x58,0x08,0x58,0x28,0x58,0x18,
+/* 17766 0x4566 "䕦" */
+0x08,0xff,0x08,0x01,0x7f,0x10,0x1f,0x08,0x0f,0x79,0x4f,0x7a,0x4a,0x79,0x4a,0x9c,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x20,0xe0,0x38,0xa8,0xa8,0xb8,0x2a,0xaa,0x46,
+/* 17767 0x4567 "䕧" */
+0x04,0xff,0x04,0x3e,0x22,0x3a,0x2a,0x7f,0x41,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,
+0x40,0xfe,0x40,0x20,0x10,0xfe,0x00,0x28,0x44,0x82,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17768 0x4568 "䕨" */
+0x04,0xff,0x04,0x01,0x3c,0x25,0x24,0x3d,0x24,0x25,0x3e,0x24,0x24,0x45,0x54,0x89,
+0x40,0xfe,0x40,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x44,0x8a,0xf0,0x24,0xfc,0xa8,0x64,
+/* 17769 0x4569 "䕩" */
+0x04,0xff,0x04,0x10,0x10,0x13,0x78,0x12,0x31,0x3a,0x54,0x50,0x90,0x11,0x12,0x10,
+0x40,0xfe,0x40,0x00,0x20,0xfe,0x50,0x8a,0xfc,0x8a,0xf8,0x88,0xf8,0x24,0x22,0x60,
+/* 17770 0x456a "䕪" */
+0x04,0x04,0xff,0x04,0x23,0x12,0x93,0x40,0x43,0x10,0x27,0xe1,0x23,0x20,0x27,0x20,
+0x40,0x40,0xfe,0x40,0xf8,0xa8,0xf8,0x40,0xf8,0x40,0xfc,0x10,0xf8,0x40,0xfc,0x40,
+/* 17771 0x456b "䕫" */
+0x08,0xff,0x08,0x11,0x13,0x5a,0x53,0x5a,0xe3,0x12,0x27,0x48,0x14,0x03,0x1c,0xe0,
+0x20,0xfe,0xa0,0x1e,0xd2,0x5e,0xd0,0x52,0xce,0x08,0xe4,0x22,0x40,0x80,0x70,0x0e,
+/* 17772 0x456c "䕬" */
+0x08,0xff,0x08,0x03,0xf8,0x09,0x09,0xf9,0x81,0x87,0xf8,0x09,0x09,0x09,0x51,0x27,
+0x20,0xfe,0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,
+/* 17773 0x456d "䕭" */
+0x04,0xff,0x04,0x10,0x10,0x7c,0x10,0xfe,0x00,0x54,0x92,0x7c,0x10,0x1c,0xe0,0x41,
+0x40,0xfe,0x40,0x10,0x54,0x58,0x90,0x28,0x44,0x92,0x54,0x58,0x90,0x28,0x44,0x82,
+/* 17774 0x456e "䕮" */
+0x04,0xff,0x04,0x11,0x11,0x7e,0x11,0xfe,0x44,0x29,0x7c,0x10,0xff,0x10,0x10,0x10,
+0x40,0xfe,0x40,0x00,0xfc,0x44,0x54,0xe4,0x44,0xf4,0x44,0xe4,0x54,0x44,0x54,0x08,
+/* 17775 0x456f "䕯" */
+0x08,0xff,0x08,0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x55,0x92,0x30,
+0x20,0xfe,0x20,0x00,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0x4a,0x78,0x08,
+/* 17776 0x4570 "䕰" */
+0x04,0xff,0x04,0x10,0x13,0x15,0x54,0x5b,0x51,0x92,0x11,0x11,0x29,0x25,0x45,0x81,
+0x40,0xfe,0x40,0x1c,0xe0,0x24,0xa8,0xfe,0x24,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 17777 0x4571 "䕱" */
+0x08,0xff,0x08,0x00,0x7d,0x00,0x00,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,0x40,
+0x20,0xfe,0x20,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 17778 0x4572 "䕲" */
+0x08,0xff,0x08,0x3f,0x20,0x2f,0x24,0x25,0x25,0x27,0x20,0x27,0x20,0x4f,0x42,0x84,
+0x20,0xfe,0xa0,0xfe,0x40,0xfe,0x04,0xf4,0x14,0xfc,0x00,0xfc,0x00,0xfe,0x48,0xc4,
+/* 17779 0x4573 "䕳" */
+0x08,0xff,0x08,0x00,0xf7,0x12,0x17,0xfc,0x86,0x85,0xf6,0x15,0x16,0x14,0x54,0x24,
+0x20,0xfe,0x20,0x00,0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 17780 0x4574 "䕴" */
+0x04,0xff,0x04,0x00,0x0c,0x71,0x11,0x13,0xfd,0x31,0x39,0x55,0x50,0x92,0x12,0x14,
+0x40,0xfe,0x40,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,
+/* 17781 0x4575 "䕵" */
+0x04,0xff,0x04,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x7d,0x44,
+0x40,0xfe,0x50,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0x52,0x06,
+/* 17782 0x4576 "䕶" */
+0x04,0xff,0x04,0x20,0x10,0xfd,0x02,0x78,0x00,0x78,0x00,0x78,0x49,0x48,0x78,0x4b,
+0x40,0xfe,0x40,0x90,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfc,0x80,0xfc,0x88,0x70,0x8e,
+/* 17783 0x4577 "䕷" */
+0x08,0xff,0x09,0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x21,0x27,0x21,0x4f,0x44,0x89,
+0x20,0xfe,0x20,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x20,0xc0,0x10,0xf8,0xa4,0x90,
+/* 17784 0x4578 "䕸" */
+0x04,0xff,0x04,0x7f,0x49,0x6b,0x5d,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x00,0x55,0x55,
+0x40,0xfe,0x40,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,
+/* 17785 0x4579 "䕹" */
+0x04,0xff,0x04,0x20,0x10,0xfe,0x44,0x45,0xaa,0x10,0xfe,0x10,0x54,0x52,0x92,0x30,
+0x40,0xfe,0x40,0x10,0x48,0x40,0xfe,0x90,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,
+/* 17786 0x457a "䕺" */
+0x08,0xff,0x08,0x24,0x14,0x7f,0x08,0x04,0x7f,0x01,0xff,0x22,0x3e,0x23,0x7e,0x02,
+0x20,0xfe,0x20,0x48,0x50,0xfc,0x20,0x40,0xfc,0x00,0xfe,0x00,0x7c,0xa4,0x18,0x66,
+/* 17787 0x457b "䕻" */
+0x04,0xff,0x04,0x3f,0x12,0x1b,0x12,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x40,0xfe,0x40,0x7e,0x24,0x34,0xa4,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 17788 0x457c "䕼" */
+0x08,0xff,0x08,0x44,0xfe,0x44,0x7d,0x12,0xfe,0x92,0xfe,0x10,0xfe,0x28,0x44,0x82,
+0x20,0xfe,0x20,0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 17789 0x457d "䕽" */
+0x08,0xff,0x08,0x01,0x7d,0x45,0x44,0x7d,0x12,0x11,0x5d,0x51,0x50,0x5d,0xe0,0x00,
+0x20,0xfe,0x20,0xfc,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 17790 0x457e "䕾" */
+0x08,0xff,0x08,0x00,0x1e,0x12,0x3f,0x20,0x2e,0x22,0x3f,0x29,0x2f,0x49,0x5f,0x81,
+0x20,0xfe,0x20,0x00,0x78,0x48,0xfc,0x20,0x20,0x3c,0xc8,0x28,0x28,0x90,0x28,0x44,
+/* 17791 0x457f "䕿" */
+0x04,0xff,0x04,0x44,0xfe,0x44,0x7c,0x10,0xfe,0x92,0xfe,0x10,0xfe,0x28,0x45,0x82,
+0x40,0xfe,0x50,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0x52,0x06,
+/* 17792 0x4580 "䖀" */
+0x08,0xff,0x08,0x3c,0x24,0xff,0x02,0x1f,0x14,0x12,0x1f,0x08,0x10,0x7c,0x44,0x7c,
+0x20,0xfe,0x20,0x78,0x48,0xfe,0x00,0xf0,0x90,0x50,0xf0,0x20,0x10,0x7c,0x44,0x7c,
+/* 17793 0x4581 "䖁" */
+0x28,0xfe,0x28,0x00,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x92,0x92,0xba,0x8a,0x85,
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x0a,0xaa,0xa4,0x1c,
+/* 17794 0x4582 "䖂" */
+0x08,0xff,0x29,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x00,0x3f,0x01,0xff,0x01,0x03,
+0x20,0xfe,0x28,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0xf0,0x00,0x00,0xfe,0x00,0x00,
+/* 17795 0x4583 "䖃" */
+0x08,0xff,0x0a,0x7f,0x08,0x1f,0x68,0x0f,0x44,0xfe,0x54,0xfe,0x20,0x7c,0xc4,0x7d,
+0x20,0xfe,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x44,0xfe,0x54,0xfe,0x20,0x7c,0xc4,0x7c,
+/* 17796 0x4584 "䖄" */
+0x08,0xff,0x08,0x44,0xfe,0x44,0x7d,0x10,0xfe,0x92,0xfe,0x10,0xfe,0x28,0x44,0x82,
+0x20,0xfe,0x20,0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,0x48,0x24,
+/* 17797 0x4585 "䖅" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x49,0x84,0x3b,0x2a,0x3b,0x00,0x7f,0x11,0x29,0xff,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x22,0x14,0xb8,0xa8,0xb8,0x00,0xfc,0x10,0x28,0xfe,
+/* 17798 0x4586 "䖆" */
+0x04,0xff,0x04,0x00,0xfb,0x21,0xf9,0xa8,0xa9,0xd8,0x89,0x88,0xfb,0x89,0xfe,0x88,
+0x40,0xfe,0x40,0x20,0xfe,0x54,0xdc,0x88,0xfc,0x88,0xfc,0x88,0xfe,0x8a,0xa4,0xc2,
+/* 17799 0x4587 "䖇" */
+0x08,0xff,0x2a,0xf3,0x25,0x73,0xad,0x27,0x00,0xff,0x95,0x6b,0x55,0x7f,0x24,0x3f,
+0x20,0xfe,0x28,0xbc,0x08,0x9c,0x6a,0xc8,0x00,0xfe,0x0a,0x70,0x04,0x38,0x82,0xbc,
+/* 17800 0x4588 "䖈" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x24,0x24,0x27,0x24,0x44,0x43,0x80,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0x18,0xe0,0x04,0x04,0x04,0xfc,0x00,
+/* 17801 0x4589 "䖉" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x23,0x20,0x20,0x2f,0x40,0x41,0x80,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xf8,0x40,0x40,0xfe,0x40,0x40,0x80,
+/* 17802 0x458a "䖊" */
+0x00,0x04,0x04,0x85,0x45,0x29,0x29,0x11,0x11,0x29,0x29,0x45,0x45,0x82,0x02,0x04,
+0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x48,0x4a,0x4a,0x86,
+/* 17803 0x458b "䖋" */
+0x04,0x07,0x04,0x3f,0x24,0x27,0x3c,0x24,0x23,0x20,0x2f,0x29,0x29,0x49,0x91,0x20,
+0x10,0x90,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x28,0x28,0x28,0x64,0xa4,0x24,0x42,
+/* 17804 0x458c "䖌" */
+0x04,0x07,0x04,0x3f,0x24,0x27,0x3c,0x23,0x20,0x2f,0x29,0x29,0x49,0x49,0x91,0x20,
+0x04,0x84,0x04,0xd4,0x54,0x14,0x54,0xd4,0x14,0x14,0x14,0x04,0x44,0x84,0x14,0x08,
+/* 17805 0x458d "䖍" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x21,0x21,0x22,0x25,0x28,0x40,0x41,0x86,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xfc,0x10,0x10,0xa0,0x40,0xb0,0x0c,
+/* 17806 0x458e "䖎" */
+0x00,0x78,0x48,0x50,0x53,0x62,0x52,0x4b,0x4a,0x4a,0x6a,0x52,0x44,0x44,0x49,0x52,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 17807 0x458f "䖏" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x22,0x22,0x27,0x2d,0x33,0x22,0x44,0x49,0x82,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xf8,0x48,0x48,0xe8,0x9e,0x08,0x18,
+/* 17808 0x4590 "䖐" */
+0x04,0x0e,0x30,0x20,0x20,0x20,0x3e,0x24,0x24,0x24,0x24,0x24,0x24,0x45,0x45,0x82,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0x2a,0x2a,0x46,
+/* 17809 0x4591 "䖑" */
+0x08,0x0f,0x08,0x7f,0x49,0x4e,0x78,0x49,0x47,0x40,0x4e,0x4a,0x4a,0x52,0x91,0x20,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x02,0x02,0xfe,0x00,
+/* 17810 0x4592 "䖒" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x2f,0x20,0x27,0x24,0x47,0x42,0x9f,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x20,0xfc,
+/* 17811 0x4593 "䖓" */
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x9e,0xf3,0x01,0x02,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0x2a,0x2a,0x46,
+/* 17812 0x4594 "䖔" */
+0x10,0x10,0x10,0x7d,0x11,0x11,0x11,0xfd,0x11,0x11,0x21,0x49,0xfd,0x46,0x02,0x04,
+0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x48,0x4a,0x4a,0x86,
+/* 17813 0x4595 "䖕" */
+0x08,0x0f,0x08,0x7f,0x49,0x4e,0x78,0x49,0x47,0x40,0x4e,0x4a,0x4a,0x52,0x91,0x20,
+0x00,0x00,0x78,0x48,0x48,0x78,0x48,0x48,0x78,0x48,0x48,0xfc,0x02,0x02,0xfe,0x00,
+/* 17814 0x4596 "䖖" */
+0x08,0x0f,0x08,0x7f,0x49,0x4e,0x78,0x49,0x47,0x40,0x4e,0x4a,0x4a,0x52,0x91,0x20,
+0x00,0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x10,0x10,0x12,0x02,0xfe,0x00,
+/* 17815 0x4597 "䖗" */
+0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x2f,0x28,0x2b,0x28,0x2b,0x2a,0x4b,0x90,
+0xfc,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x28,0xfe,0x20,0xa4,0x28,0xac,0x94,0xac,0x44,
+/* 17816 0x4598 "䖘" */
+0x10,0x1e,0x10,0x7e,0x53,0x5c,0x70,0x52,0x4e,0x40,0x5c,0x54,0x54,0x56,0x94,0x21,
+0x40,0x40,0x78,0x88,0x10,0xfc,0xa4,0xa4,0xfc,0x20,0x50,0x58,0x54,0x92,0x92,0x0e,
+/* 17817 0x4599 "䖙" */
+0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x28,0x49,0x49,0x92,
+0x90,0x18,0x14,0x12,0x10,0x7c,0x80,0x80,0xfc,0x84,0xf0,0x84,0x7c,0xe0,0x24,0x1c,
+/* 17818 0x459a "䖚" */
+0x10,0x1e,0x10,0x7e,0x52,0x5c,0x70,0x52,0x4e,0x40,0x5c,0x54,0x54,0x56,0x94,0x20,
+0x20,0x40,0xfc,0x84,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 17819 0x459b "䖛" */
+0x08,0x0f,0x08,0x7f,0x49,0x4e,0x78,0x49,0x47,0x40,0x4e,0x4a,0x4a,0x52,0x91,0x20,
+0x10,0x10,0x7c,0x10,0xfe,0xa2,0x44,0x78,0x14,0xfe,0x10,0x54,0xb2,0x02,0xfe,0x00,
+/* 17820 0x459c "䖜" */
+0x1e,0x10,0x7e,0x52,0x5c,0x72,0x4e,0x40,0x5c,0x95,0x23,0x5f,0x10,0x1f,0x10,0x1f,
+0x3c,0x20,0xfe,0xa2,0xb8,0xe4,0x9c,0x80,0xb8,0x2a,0x46,0xf0,0x10,0xf0,0x10,0xf0,
+/* 17821 0x459d "䖝" */
+0x00,0x00,0x07,0x79,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x7f,0x20,
+0x08,0x7c,0x80,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x10,0xf8,0x04,0x04,
+/* 17822 0x459e "䖞" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x28,0x10,
+/* 17823 0x459f "䖟" */
+0x02,0x01,0xff,0x10,0x10,0x1f,0x00,0x01,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 17824 0x45a0 "䖠" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 17825 0x45a1 "䖡" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x55,0x7c,0x50,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 17826 0x45a2 "䖢" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x55,0x55,0x7e,0x50,0x10,0x14,0x1e,0xe2,0x40,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 17827 0x45a3 "䖣" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x48,0x44,0x44,0x42,0x00,
+/* 17828 0x45a4 "䖤" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x20,0xc1,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x00,0xf8,0x88,0x88,0xa8,0x94,0x84,0x7c,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 17829 0x45a5 "䖥" */
+0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x01,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 17830 0x45a6 "䖦" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x54,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x41,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 17831 0x45a7 "䖧" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 17832 0x45a8 "䖨" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x7c,0x51,0x12,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 17833 0x45a9 "䖩" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x55,0x7d,0x51,0x12,0x14,0x1c,0xe5,0x42,0x00,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 17834 0x45aa "䖪" */
+0x08,0x08,0x2e,0x28,0x28,0x28,0x2e,0xf0,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x7c,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 17835 0x45ab "䖫" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7c,0x50,0x11,0x14,0x1e,0xe2,0x40,0x00,
+0x10,0x50,0x50,0x88,0x88,0x04,0xfa,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 17836 0x45ac "䖬" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x14,0x1c,0xe4,0x40,0x00,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 17837 0x45ad "䖭" */
+0x11,0x09,0x09,0x7f,0x02,0xff,0x08,0x30,0xc1,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x10,0x10,0x20,0xfc,0x00,0xfe,0x20,0x18,0x06,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 17838 0x45ae "䖮" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 17839 0x45af "䖯" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0xff,0x00,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x00,0xf8,0x00,0xfe,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17840 0x45b0 "䖰" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x11,0x15,0x1d,0xe5,0x42,0x02,0x04,
+0x04,0x1e,0xe0,0x00,0x06,0x78,0x50,0x50,0x52,0x54,0x48,0x48,0x44,0x54,0x62,0x40,
+/* 17841 0x45b1 "䖱" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x00,
+0x00,0xfe,0x00,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 17842 0x45b2 "䖲" */
+0x10,0x10,0x11,0x7d,0x56,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe4,0x40,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 17843 0x45b3 "䖳" */
+0x10,0x10,0x11,0x7d,0x54,0x54,0x54,0x54,0x7c,0x50,0x11,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x10,0xfe,0x02,0x00,0x1c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x1e,0x00,
+/* 17844 0x45b4 "䖴" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7c,0x51,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 17845 0x45b5 "䖵" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x14,0x1c,0xe5,0x40,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x82,0x00,
+/* 17846 0x45b6 "䖶" */
+0x10,0x13,0x10,0x7c,0x55,0x56,0x54,0x54,0x7d,0x52,0x10,0x14,0x1d,0xe6,0x40,0x00,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0x28,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 17847 0x45b7 "䖷" */
+0x21,0x20,0x20,0xf8,0xab,0xa8,0xab,0xa8,0xf9,0xa3,0x25,0x29,0x39,0xe9,0x40,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 17848 0x45b8 "䖸" */
+0x02,0x3c,0x08,0xff,0x08,0x0e,0x78,0x08,0x19,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x40,0x50,0x48,0xfe,0x48,0x50,0x24,0x54,0x8c,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17849 0x45b9 "䖹" */
+0x20,0x20,0x20,0xfb,0xa8,0xa8,0xa8,0xa9,0xf8,0xa0,0x23,0x28,0x38,0xe8,0x40,0x00,
+0x88,0x88,0x88,0x8e,0x88,0x88,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 17850 0x45ba "䖺" */
+0x10,0x10,0x11,0x21,0x2a,0x6c,0xa9,0x2e,0x28,0x2b,0x2a,0x2a,0x2b,0x20,0x27,0x20,
+0x80,0x80,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xf8,0x48,0x48,0xf8,0x44,0xfc,0x04,
+/* 17851 0x45bb "䖻" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x55,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 17852 0x45bc "䖼" */
+0x21,0x21,0x21,0xfb,0xa9,0xa9,0xa9,0xaf,0xf9,0xa1,0x22,0x2a,0x3f,0xea,0x40,0x00,
+0x00,0x00,0x1e,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0x1a,0x94,0xd0,0x50,0x10,0x10,
+/* 17853 0x45bd "䖽" */
+0x03,0x3c,0x04,0x7f,0x0c,0x16,0x25,0x44,0x05,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x08,0x08,0x48,0x48,0x48,0x48,0x08,0x28,0x10,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 17854 0x45be "䖾" */
+0x10,0x10,0x11,0x7d,0x56,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 17855 0x45bf "䖿" */
+0x0c,0x70,0x11,0xfd,0x12,0x38,0x54,0x91,0x10,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x80,0xfc,0x24,0x24,0x24,0x44,0x84,0x28,0x10,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17856 0x45c0 "䗀" */
+0x20,0x20,0x21,0xf8,0xa8,0xab,0xa8,0xa9,0xfa,0xa0,0x21,0x2a,0x38,0xe8,0x41,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 17857 0x45c1 "䗁" */
+0x10,0x10,0x11,0x7c,0x54,0x55,0x57,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe4,0x40,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 17858 0x45c2 "䗂" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x05,
+0x20,0x20,0x3c,0x20,0xfc,0x24,0x30,0xe0,0x24,0x1c,0x00,0x70,0x50,0x52,0x92,0x0e,
+/* 17859 0x45c3 "䗃" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x55,0x7c,0x50,0x11,0x14,0x1e,0xe2,0x40,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 17860 0x45c4 "䗄" */
+0x10,0x10,0x11,0x7c,0x54,0x57,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x42,0x00,
+0x50,0x88,0x54,0x20,0xd8,0x06,0x08,0xf0,0x80,0x80,0xfc,0x90,0x90,0x10,0x10,0x10,
+/* 17861 0x45c5 "䗅" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x57,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 17862 0x45c6 "䗆" */
+0x10,0x10,0x11,0x7d,0x56,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 17863 0x45c7 "䗇" */
+0x10,0x10,0x10,0x7d,0x56,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1d,0xe4,0x40,0x00,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 17864 0x45c8 "䗈" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x40,0x20,0xfe,0x80,0x80,0x80,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 17865 0x45c9 "䗉" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 17866 0x45ca "䗊" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x57,0x54,0x7c,0x50,0x10,0x15,0x1c,0xe4,0x41,0x02,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 17867 0x45cb "䗋" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x13,0x14,0x1c,0xe5,0x42,0x00,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 17868 0x45cc "䗌" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x55,0x7d,0x52,0x10,0x15,0x1c,0xe4,0x43,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17869 0x45cd "䗍" */
+0x0f,0x10,0x1f,0x00,0xff,0x0c,0x73,0x0d,0x72,0x0c,0xf3,0x3f,0x21,0x3f,0x01,0x7f,
+0xe0,0x20,0xc0,0x40,0xfe,0x10,0x20,0xc0,0xb0,0x8e,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 17870 0x45ce "䗎" */
+0x10,0x13,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x50,0x10,0x15,0x1c,0xe4,0x43,0x00,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 17871 0x45cf "䗏" */
+0x10,0x10,0x11,0x7d,0x54,0x55,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x40,0x03,
+0x40,0x20,0xfe,0x22,0xa4,0x28,0x50,0x88,0x04,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 17872 0x45d0 "䗐" */
+0x10,0xfe,0x21,0x3c,0x24,0x27,0x44,0x54,0x88,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x40,0xfe,0x20,0xac,0xf4,0xa4,0xac,0xa2,0x7e,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17873 0x45d1 "䗑" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x51,0x10,0x14,0x1e,0xe2,0x41,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x20,0x10,0xfe,0x00,0x84,0x48,0x00,0xfe,0x00,
+/* 17874 0x45d2 "䗒" */
+0x21,0x20,0x20,0xfb,0xa8,0xa8,0xa8,0xac,0xfa,0xa2,0x20,0x28,0x38,0xe8,0x47,0x00,
+0x08,0x90,0x00,0xfc,0x90,0x90,0x92,0x92,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 17875 0x45d3 "䗓" */
+0x20,0x20,0x20,0xf9,0xaa,0xa8,0xa9,0xaa,0xf8,0xa1,0x20,0x28,0x3a,0xea,0x44,0x00,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 17876 0x45d4 "䗔" */
+0x10,0x10,0x10,0x7d,0x55,0x57,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 17877 0x45d5 "䗕" */
+0x01,0x7f,0x50,0x3e,0x42,0xa2,0x14,0x18,0xe1,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x00,0xfc,0x04,0xf8,0x88,0xaa,0x92,0x7e,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 17878 0x45d6 "䗖" */
+0x20,0x20,0x23,0xf8,0xa8,0xa8,0xab,0xaa,0xf8,0xa1,0x21,0x29,0x39,0xe9,0x40,0x00,
+0xa8,0xa8,0xfe,0xa8,0xa8,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 17879 0x45d7 "䗗" */
+0x22,0x22,0x23,0xfd,0xa8,0xa8,0xab,0xa8,0xf8,0xa0,0x27,0x28,0x38,0xe9,0x42,0x04,
+0x10,0x10,0xde,0x28,0x84,0x00,0xfc,0x90,0x90,0x90,0xfe,0x90,0x90,0x10,0x10,0x10,
+/* 17880 0x45d8 "䗘" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x54,0x54,0x7d,0x50,0x11,0x15,0x1d,0xe5,0x43,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x84,0xfe,0x02,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 17881 0x45d9 "䗙" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x11,0x2f,0xc9,0x0f,0x01,0x3f,0x10,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0xe8,0x26,0xe0,0x10,0xf8,0x08,
+/* 17882 0x45da "䗚" */
+0x10,0x10,0x13,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x17,0x1c,0xe4,0x40,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 17883 0x45db "䗛" */
+0x21,0x21,0x21,0xfa,0xaa,0xae,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x20,0x3c,0x44,0xa8,0x10,0xa8,0xc6,0xbc,0xa4,0xbc,0xa4,0xbc,0x24,0x24,0x24,0x2c,
+/* 17884 0x45dc "䗜" */
+0x20,0x23,0x22,0xfa,0xaa,0xaa,0xab,0xa8,0xfb,0xa2,0x22,0x2b,0x3a,0xea,0x43,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 17885 0x45dd "䗝" */
+0x20,0x10,0xfd,0x09,0x11,0x39,0x55,0x90,0x10,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x20,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17886 0x45de "䗞" */
+0x00,0x3f,0x01,0xff,0x02,0x0c,0x30,0xc0,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0x00,0xf8,0x00,0xfe,0x80,0x60,0x18,0x06,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 17887 0x45df "䗟" */
+0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17888 0x45e0 "䗠" */
+0x20,0x10,0xfe,0x21,0x3d,0x24,0x24,0x44,0x55,0x8a,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x40,0x40,0xfe,0x00,0xfe,0x22,0xa0,0xbc,0x60,0x3e,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 17889 0x45e1 "䗡" */
+0x20,0x23,0x20,0xf9,0xa9,0xaf,0xa8,0xa8,0xf9,0xa1,0x20,0x2a,0x3a,0xec,0x40,0x00,
+0x00,0xfe,0x20,0x3c,0x20,0xfe,0x80,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 17890 0x45e2 "䗢" */
+0x10,0x10,0x12,0x7d,0x54,0x54,0x54,0x57,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x04,
+0x10,0x50,0x50,0x7c,0x90,0x10,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 17891 0x45e3 "䗣" */
+0x08,0x08,0xff,0x08,0x0f,0x08,0x0f,0x00,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0x20,0x20,0xfe,0x20,0xe0,0x20,0xe0,0x00,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 17892 0x45e4 "䗤" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x11,0x15,0x1d,0xe5,0x42,0x02,0x04,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 17893 0x45e5 "䗥" */
+0x21,0x21,0x22,0xfc,0xa9,0xa9,0xaa,0xae,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 17894 0x45e6 "䗦" */
+0x20,0x24,0x22,0xf9,0xa8,0xa8,0xae,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x45,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 17895 0x45e7 "䗧" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x11,0x15,0x1d,0xe5,0x42,0x02,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 17896 0x45e8 "䗨" */
+0x10,0x10,0x10,0x7d,0x56,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe5,0x41,0x02,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x54,0x2a,0x2a,
+/* 17897 0x45e9 "䗩" */
+0x20,0x20,0x20,0xfb,0xaa,0xaa,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3b,0xec,0x44,0x08,
+0x0c,0x0a,0x08,0xfe,0x08,0x48,0x6a,0x4a,0xfa,0x4c,0x4c,0xec,0x5a,0x4a,0xd6,0x22,
+/* 17898 0x45ea "䗪" */
+0x00,0x3f,0x22,0x22,0x3f,0x22,0x23,0x20,0x2a,0x31,0x20,0x2f,0x48,0x4f,0x80,0x1f,
+0x80,0xfe,0x20,0x20,0xfc,0x20,0xe0,0x00,0x48,0x24,0x80,0xf8,0x88,0xf8,0x84,0xfe,
+/* 17899 0x45eb "䗫" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x00,
+0x20,0x10,0xfe,0x48,0x48,0x48,0xfe,0x48,0x48,0xec,0x5a,0x68,0x48,0x48,0x48,0x48,
+/* 17900 0x45ec "䗬" */
+0x21,0x13,0x15,0x00,0x77,0x11,0x10,0x13,0x28,0x47,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x00,0xf0,0x10,0xe0,0x5c,0xf0,0x40,0xfc,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 17901 0x45ed "䗭" */
+0x20,0x20,0x21,0xf9,0xa9,0xa8,0xab,0xaa,0xfb,0xa0,0x20,0x28,0x3a,0xea,0x44,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x20,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 17902 0x45ee "䗮" */
+0x20,0x20,0x23,0xf8,0xaa,0xa9,0xaa,0xa8,0xfa,0xa1,0x22,0x28,0x38,0xe8,0x41,0x06,
+0x20,0x20,0xfe,0x20,0xaa,0x24,0xaa,0x20,0xaa,0x24,0xaa,0x50,0x50,0x88,0x04,0x02,
+/* 17903 0x45ef "䗯" */
+0x20,0x22,0x21,0xf9,0xa9,0xa8,0xab,0xa9,0xf9,0xa1,0x21,0x29,0x39,0xea,0x44,0x00,
+0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0x80,0x7e,0x00,
+/* 17904 0x45f0 "䗰" */
+0x20,0x21,0x21,0xfb,0xa9,0xa9,0xa8,0xa9,0xf9,0xa1,0x21,0x29,0x39,0xe9,0x40,0x01,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 17905 0x45f1 "䗱" */
+0x20,0x22,0x21,0xf8,0xab,0xa8,0xa8,0xab,0xf8,0xa1,0x20,0x2b,0x38,0xe8,0x41,0x06,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 17906 0x45f2 "䗲" */
+0x20,0x21,0x20,0xfb,0xa8,0xa9,0xaa,0xa9,0xf9,0xa1,0x22,0x2d,0x38,0xe9,0x42,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 17907 0x45f3 "䗳" */
+0x20,0x23,0x20,0xf9,0xa8,0xa9,0xaa,0xac,0xf9,0xa1,0x21,0x29,0x39,0xe8,0x47,0x00,
+0x10,0xd2,0x54,0x48,0x8a,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 17908 0x45f4 "䗴" */
+0x21,0x21,0x21,0xfa,0xac,0xa8,0xab,0xa8,0xf9,0xa3,0x20,0x2a,0x39,0xea,0x44,0x00,
+0x10,0x10,0xde,0xa8,0x44,0x06,0xb8,0x88,0x08,0xbe,0x88,0x88,0x3e,0xc0,0x3e,0x00,
+/* 17909 0x45f5 "䗵" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x55,0x57,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x40,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 17910 0x45f6 "䗶" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x55,0x55,0x7c,0x51,0x12,0x15,0x1d,0xe5,0x40,0x00,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 17911 0x45f7 "䗷" */
+0x10,0x10,0x11,0x7c,0x54,0x57,0x54,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe6,0x42,0x04,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 17912 0x45f8 "䗸" */
+0x01,0xff,0x10,0x24,0x79,0x10,0x22,0x7c,0x08,0x30,0xc1,0x3f,0x21,0x3f,0x01,0x7f,
+0x00,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xf8,0x08,0xf8,0x04,0xfe,
+/* 17913 0x45f9 "䗹" */
+0x21,0x20,0x23,0xf9,0xa9,0xaa,0xab,0xa9,0xfa,0xa3,0x20,0x28,0x3a,0xea,0x44,0x00,
+0x08,0x90,0xfe,0x08,0x08,0x52,0x9c,0x08,0x52,0xde,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 17914 0x45fa "䗺" */
+0x00,0x7b,0x10,0x22,0x7a,0x0a,0x2b,0x10,0x2f,0x40,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x18,0xe0,0x40,0x78,0x40,0x40,0xfc,0x00,0xfe,0x00,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17915 0x45fb "䗻" */
+0x21,0x21,0x21,0xfa,0xa8,0xa8,0xab,0xaa,0xfb,0xa2,0x23,0x2a,0x3a,0xeb,0x42,0x00,
+0x08,0x08,0xee,0x94,0x42,0x00,0xde,0x52,0xd2,0x52,0xd2,0x1a,0x94,0x50,0x10,0x10,
+/* 17916 0x45fc "䗼" */
+0x20,0x21,0x20,0xfb,0xa8,0xa9,0xa9,0xa9,0xf9,0xa0,0x21,0x28,0x3b,0xe8,0x41,0x02,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 17917 0x45fd "䗽" */
+0x10,0x20,0x45,0x79,0x13,0x25,0x7d,0x01,0x55,0x81,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 17918 0x45fe "䗾" */
+0x20,0x23,0x22,0xfb,0xaa,0xab,0xa9,0xaa,0xfb,0xa1,0x22,0x2b,0x38,0xea,0x42,0x04,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 17919 0x45ff "䗿" */
+0x20,0x20,0x23,0xfa,0xa9,0xa9,0xaa,0xa8,0xf9,0xa1,0x23,0x28,0x39,0xe8,0x40,0x00,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 17920 0x4600 "䘀" */
+0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x01,0xff,0x11,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17921 0x4601 "䘁" */
+0x08,0x7f,0x08,0xff,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x28,0x24,0x20,0xfe,0x20,0xa4,0x24,0x28,0x12,0xaa,0x46,0xf8,0x08,0xf8,0x04,0xfe,
+/* 17922 0x4602 "䘂" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xa9,0xab,0xf9,0xa3,0x21,0x2b,0x39,0xe9,0x47,0x00,
+0x88,0x8c,0xea,0x88,0x88,0xfe,0x48,0x6a,0x4a,0x6a,0x4c,0x6c,0x4a,0x6a,0x96,0x22,
+/* 17923 0x4603 "䘃" */
+0x21,0x21,0x21,0xf9,0xa9,0xa8,0xa9,0xa8,0xfb,0xa1,0x22,0x28,0x39,0xe8,0x43,0x00,
+0xfc,0x24,0xac,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,0x20,0xfc,0x20,0xfe,0x00,
+/* 17924 0x4604 "䘄" */
+0x01,0x1f,0x01,0x7f,0x02,0x0f,0x38,0xcf,0x08,0x0f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x08,0xd0,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17925 0x4605 "䘅" */
+0x20,0x42,0xff,0x01,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x44,0x58,0x62,0x42,0x3e,0x00,0x4c,0x72,0x42,0x3e,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17926 0x4606 "䘆" */
+0x10,0x13,0x12,0x7d,0x54,0x54,0x54,0x55,0x7c,0x11,0x15,0x1d,0xe4,0x42,0x02,0x04,
+0x20,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfc,0x20,0xfc,0x54,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 17927 0x4607 "䘇" */
+0x01,0x7f,0x08,0x07,0x19,0xef,0x09,0x0f,0x01,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xfc,0x20,0xc0,0x30,0xee,0x20,0xe0,0x10,0xf8,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17928 0x4608 "䘈" */
+0x2f,0x29,0x2b,0xf9,0xa8,0xab,0xaa,0xab,0xfa,0xab,0x28,0x2b,0x3a,0xeb,0x4a,0x12,
+0xe8,0x48,0xe8,0x5e,0x0a,0xea,0xaa,0xea,0xaa,0xea,0x8a,0xea,0xaa,0xea,0x2a,0x76,
+/* 17929 0x4609 "䘉" */
+0x3f,0x01,0x7f,0x04,0x19,0xef,0x09,0x0f,0x01,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0xf8,0x00,0xfc,0x40,0x30,0xee,0x20,0xe0,0x10,0xf8,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17930 0x460a "䘊" */
+0x22,0x23,0x25,0xf8,0xab,0xaa,0xaa,0xab,0xf8,0xa3,0x22,0x2b,0x3a,0xea,0x44,0x08,
+0x10,0xde,0x28,0x84,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 17931 0x460b "䘋" */
+0x21,0x21,0x22,0xf8,0xab,0xa9,0xab,0xa9,0xfb,0xa1,0x23,0x29,0x39,0xeb,0x40,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4a,0x6c,0x4c,0x6a,0x8a,0x16,0x22,
+/* 17932 0x460c "䘌" */
+0x3f,0x24,0x2f,0x25,0x3f,0x22,0x27,0x2a,0x33,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0xfc,0x20,0xf8,0x20,0xfc,0x00,0xf0,0x10,0xf0,0xfc,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17933 0x460d "䘍" */
+0x08,0xff,0x08,0x1f,0x11,0x1f,0x11,0x7f,0x41,0x5f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfc,0x24,0xec,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 17934 0x460e "䘎" */
+0x24,0x28,0x2e,0xfc,0xaa,0xae,0xa8,0xaa,0xf8,0xa3,0x20,0x2b,0x3a,0xeb,0x40,0x00,
+0x44,0xe8,0x0e,0xe4,0x0a,0xee,0xa0,0xea,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x38,
+/* 17935 0x460f "䘏" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 17936 0x4610 "䘐" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x01,
+0x00,0x00,0x78,0x28,0x28,0x28,0x6c,0x6a,0xaa,0x2a,0x28,0x28,0xc8,0x48,0x98,0x00,
+/* 17937 0x4611 "䘑" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x30,0x08,0x00,0x70,0x10,0x1a,0xda,0x5c,0x58,0x58,0x54,0x54,0x94,0x12,0x50,0x20,
+/* 17938 0x4612 "䘒" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x90,0x28,0x44,0x82,
+/* 17939 0x4613 "䘓" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x10,0x10,0x1e,0x22,0x24,0x40,0x10,0x66,0x42,0x42,0x66,0x42,0xc2,0x42,0x7e,0x42,
+/* 17940 0x4614 "䘔" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x20,0x10,0x7e,0x42,0x10,0x1c,0x24,0x54,0x08,0x36,0xc0,0x3c,0xa4,0x24,0x3c,0x24,
+/* 17941 0x4615 "䘕" */
+0x12,0x11,0x21,0x4f,0x80,0x10,0x23,0x62,0xa2,0x22,0x22,0x22,0x24,0x24,0x28,0x20,
+0x00,0x00,0x1c,0xc0,0x00,0x00,0xbe,0x88,0x88,0x88,0x88,0xa8,0xc8,0x88,0x28,0x10,
+/* 17942 0x4616 "䘖" */
+0x10,0x12,0x22,0x43,0x85,0x11,0x21,0x6f,0xa1,0x21,0x25,0x25,0x25,0x26,0x20,0x20,
+0x00,0x00,0x1c,0xc0,0x00,0x00,0x3e,0xc8,0x08,0x08,0x48,0x48,0xc8,0x48,0x28,0x10,
+/* 17943 0x4617 "䘗" */
+0x11,0x15,0x25,0x47,0x80,0x17,0x22,0x64,0xa7,0x21,0x22,0x2f,0x21,0x25,0x29,0x23,
+0x00,0x40,0x4e,0xc0,0x00,0xc0,0x1e,0x44,0x84,0x04,0x44,0xe4,0x04,0x44,0x34,0x08,
+/* 17944 0x4618 "䘘" */
+0x21,0x2f,0x41,0x47,0x81,0x1f,0x22,0x64,0xa7,0x21,0x22,0x2f,0x21,0x25,0x29,0x23,
+0x00,0xe0,0x0e,0xc0,0x00,0xe0,0x1e,0x44,0x84,0x04,0x44,0xe4,0x04,0x44,0x34,0x08,
+/* 17945 0x4619 "䘙" */
+0x11,0x17,0x22,0x4f,0x80,0x17,0x24,0x67,0xa1,0x23,0x25,0x27,0x21,0x27,0x25,0x25,
+0x00,0xc0,0x4e,0xe0,0x00,0xc0,0x5e,0xc4,0x04,0xc4,0x04,0xe4,0x04,0xc4,0x54,0x48,
+/* 17946 0x461a "䘚" */
+0x02,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 17947 0x461b "䘛" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 17948 0x461c "䘜" */
+0x20,0x10,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 17949 0x461d "䘝" */
+0x20,0x10,0x00,0xfc,0x08,0x13,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x50,0x48,0x48,0x40,0x7c,0xc0,0x40,0x40,0x40,0x20,0x20,0x20,0x14,0x14,0x0c,0x04,
+/* 17950 0x461e "䘞" */
+0x20,0x13,0x00,0xfc,0x09,0x11,0x11,0x35,0x58,0x94,0x14,0x13,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xfe,0x02,0x02,0x02,0xfa,0x02,0x02,0x14,0x08,
+/* 17951 0x461f "䘟" */
+0x20,0x11,0x00,0xfc,0x08,0x11,0x11,0x35,0x59,0x95,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x20,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 17952 0x4620 "䘠" */
+0x20,0x10,0x00,0xfc,0x09,0x10,0x10,0x34,0x58,0x94,0x15,0x11,0x12,0x14,0x10,0x11,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x84,0xa4,0xa4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 17953 0x4621 "䘡" */
+0x20,0x20,0x20,0x3e,0x20,0x26,0x38,0x22,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x80,0x88,0xb0,0xc0,0x84,0x84,0x7c,0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 17954 0x4622 "䘢" */
+0x20,0x10,0x00,0xf9,0x09,0x12,0x10,0x34,0x59,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 17955 0x4623 "䘣" */
+0x20,0x10,0x00,0xf2,0x12,0x22,0x22,0x6a,0xb2,0x2a,0x22,0x22,0x23,0x2e,0x24,0x20,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 17956 0x4624 "䘤" */
+0x20,0x10,0x00,0xf8,0x0b,0x10,0x14,0x38,0x55,0x91,0x12,0x14,0x18,0x10,0x10,0x10,
+0x40,0x50,0x48,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 17957 0x4625 "䘥" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 17958 0x4626 "䘦" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 17959 0x4627 "䘧" */
+0x20,0x10,0x00,0xfd,0x09,0x11,0x11,0x35,0x59,0x97,0x14,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 17960 0x4628 "䘨" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x15,0x3a,0x54,0x90,0x10,0x10,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 17961 0x4629 "䘩" */
+0x20,0x10,0x01,0xfd,0x0a,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x10,0x10,0x10,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 17962 0x462a "䘪" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x15,0x3b,0x54,0x90,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 17963 0x462b "䘫" */
+0x08,0x08,0x7f,0x11,0x21,0x1a,0x0c,0x32,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 17964 0x462c "䘬" */
+0x20,0x10,0x00,0xf8,0x0b,0x10,0x11,0x35,0x59,0x97,0x15,0x11,0x12,0x12,0x14,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 17965 0x462d "䘭" */
+0x20,0x11,0x00,0xfc,0x08,0x10,0x11,0x34,0x58,0x94,0x15,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x20,0x20,0x48,0x84,0xfe,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 17966 0x462e "䘮" */
+0x01,0x01,0x7f,0x11,0x11,0x29,0x45,0x01,0xff,0x12,0x11,0x10,0x10,0x14,0x18,0x10,
+0x00,0x00,0xfc,0x10,0x10,0x28,0x44,0x00,0xfe,0x00,0x10,0xa0,0x40,0x30,0x0e,0x00,
+/* 17967 0x462f "䘯" */
+0x20,0x11,0x00,0xfc,0x08,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 17968 0x4630 "䘰" */
+0x20,0x10,0x03,0xf0,0x10,0x21,0x21,0x6b,0xb0,0x2a,0x22,0x21,0x21,0x22,0x24,0x28,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 17969 0x4631 "䘱" */
+0x01,0xff,0x08,0x11,0x22,0x0c,0x30,0xdf,0x10,0x10,0x1f,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x20,0x10,0x88,0x60,0x18,0xf6,0x10,0x10,0xf0,0x88,0x50,0x30,0x0e,0x00,
+/* 17970 0x4632 "䘲" */
+0x20,0x11,0x00,0xf8,0x08,0x11,0x10,0x33,0x56,0x99,0x14,0x10,0x10,0x10,0x10,0x13,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 17971 0x4633 "䘳" */
+0x20,0x10,0x00,0xfc,0x09,0x12,0x10,0x34,0x58,0x95,0x14,0x11,0x10,0x10,0x13,0x10,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 17972 0x4634 "䘴" */
+0x22,0x12,0x02,0xf2,0x1f,0x22,0x22,0x6e,0xb7,0x2a,0x2a,0x32,0x22,0x22,0x22,0x22,
+0x08,0x28,0x28,0x28,0xa4,0x44,0x54,0x92,0x10,0xa0,0x20,0x28,0x44,0xfc,0x44,0x00,
+/* 17973 0x4635 "䘵" */
+0x20,0x11,0x00,0xf8,0x09,0x10,0x14,0x3b,0x54,0x92,0x11,0x10,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 17974 0x4636 "䘶" */
+0x20,0x11,0x00,0xf0,0x12,0x22,0x22,0x6a,0xb2,0x2a,0x23,0x22,0x22,0x22,0x23,0x20,
+0x00,0xfc,0x08,0x10,0x22,0xaa,0x72,0x22,0x72,0xaa,0x26,0xa2,0x42,0x02,0xfe,0x02,
+/* 17975 0x4637 "䘷" */
+0x20,0x11,0x00,0xfc,0x08,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x24,0x24,0x74,0xac,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 17976 0x4638 "䘸" */
+0x20,0x10,0x07,0xf1,0x11,0x22,0x22,0x6e,0xb2,0x2b,0x22,0x22,0x22,0x22,0x22,0x23,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 17977 0x4639 "䘹" */
+0x20,0x10,0x03,0xf8,0x08,0x10,0x15,0x3a,0x54,0x90,0x13,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 17978 0x463a "䘺" */
+0x20,0x10,0x03,0xf2,0x14,0x20,0x23,0x68,0xb0,0x29,0x21,0x21,0x22,0x22,0x24,0x28,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 17979 0x463b "䘻" */
+0x20,0x10,0x03,0xf8,0x09,0x13,0x10,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 17980 0x463c "䘼" */
+0x20,0x10,0x03,0xf2,0x15,0x21,0x21,0x6a,0xb2,0x2b,0x24,0x20,0x21,0x21,0x22,0x24,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 17981 0x463d "䘽" */
+0x20,0x10,0x03,0xfa,0x0a,0x13,0x12,0x36,0x5b,0x94,0x14,0x10,0x10,0x11,0x12,0x14,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 17982 0x463e "䘾" */
+0x20,0x10,0x03,0xfa,0x0c,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 17983 0x463f "䘿" */
+0x20,0x13,0x02,0xf2,0x13,0x22,0x22,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x24,0x24,0x28,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 17984 0x4640 "䙀" */
+0x20,0x13,0x02,0xf2,0x12,0x23,0x22,0x6a,0xb2,0x2b,0x22,0x22,0x22,0x22,0x25,0x28,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 17985 0x4641 "䙁" */
+0x20,0x10,0x00,0xfd,0x08,0x10,0x10,0x35,0x58,0x94,0x15,0x10,0x10,0x10,0x10,0x11,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 17986 0x4642 "䙂" */
+0x20,0x10,0x01,0xf1,0x12,0x24,0x21,0x6b,0xb0,0x28,0x20,0x22,0x22,0x22,0x24,0x20,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 17987 0x4643 "䙃" */
+0x20,0x10,0x03,0xf8,0x09,0x12,0x15,0x30,0x55,0x99,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 17988 0x4644 "䙄" */
+0x20,0x10,0x01,0xf8,0x08,0x13,0x10,0x34,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 17989 0x4645 "䙅" */
+0x20,0x13,0x00,0xf8,0x0b,0x12,0x16,0x3b,0x54,0x90,0x17,0x10,0x11,0x10,0x10,0x13,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 17990 0x4646 "䙆" */
+0x20,0x13,0x00,0xfa,0x09,0x10,0x15,0x3a,0x54,0x90,0x11,0x10,0x10,0x10,0x11,0x12,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 17991 0x4647 "䙇" */
+0x20,0x13,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x95,0x14,0x13,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 17992 0x4648 "䙈" */
+0x21,0x11,0x01,0xf2,0x12,0x26,0x2a,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 17993 0x4649 "䙉" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 17994 0x464a "䙊" */
+0x20,0x10,0x03,0xf8,0x08,0x10,0x13,0x36,0x58,0x95,0x15,0x11,0x11,0x11,0x10,0x10,
+0xa8,0xa8,0xfe,0xa8,0xa8,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 17995 0x464b "䙋" */
+0x20,0x10,0x03,0xfa,0x0c,0x11,0x10,0x35,0x59,0x95,0x15,0x11,0x11,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 17996 0x464c "䙌" */
+0x20,0x10,0x01,0xf9,0x09,0x10,0x13,0x34,0x59,0x95,0x15,0x11,0x11,0x10,0x10,0x13,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 17997 0x464d "䙍" */
+0x20,0x13,0x00,0xf8,0x0b,0x11,0x11,0x35,0x5b,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfa,0x0c,0x4a,0x88,0x2a,0x26,0x22,0xf8,0x2a,0x2c,0x2a,0x28,0x2a,0x26,0x22,
+/* 17998 0x464e "䙎" */
+0x20,0x13,0x01,0xfc,0x08,0x10,0x11,0x34,0x58,0x95,0x14,0x10,0x13,0x10,0x10,0x13,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 17999 0x464f "䙏" */
+0x20,0x10,0x03,0xf8,0x09,0x11,0x11,0x35,0x59,0x95,0x14,0x13,0x10,0x10,0x10,0x10,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 18000 0x4650 "䙐" */
+0x20,0x13,0x00,0xf9,0x09,0x11,0x15,0x38,0x57,0x92,0x12,0x13,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 18001 0x4651 "䙑" */
+0x20,0x10,0x07,0xf0,0x13,0x22,0x2f,0x6a,0xb3,0x28,0x21,0x23,0x25,0x29,0x21,0x21,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xfe,0x08,0xf8,0xa4,0x28,0x10,0x10,0x48,0x86,0x00,
+/* 18002 0x4652 "䙒" */
+0x20,0x10,0x03,0xf8,0x08,0x11,0x10,0x34,0x59,0x94,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x40,0x88,0xf0,0x20,0x44,0xfe,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 18003 0x4653 "䙓" */
+0x20,0x13,0x02,0xfa,0x0b,0x10,0x14,0x39,0x54,0x90,0x17,0x10,0x10,0x11,0x13,0x11,
+0x00,0xfe,0x52,0x52,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x02,
+/* 18004 0x4654 "䙔" */
+0x20,0x13,0x02,0xfa,0x0a,0x12,0x16,0x3a,0x56,0x92,0x12,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 18005 0x4655 "䙕" */
+0x21,0x11,0x02,0xf4,0x11,0x21,0x23,0x6d,0xb1,0x29,0x21,0x21,0x21,0x21,0x21,0x21,
+0x24,0x24,0x24,0xa4,0x54,0x4a,0x92,0x08,0x08,0x28,0x2e,0x28,0x28,0x58,0x4e,0x80,
+/* 18006 0x4656 "䙖" */
+0x20,0x12,0x02,0xf3,0x10,0x23,0x22,0x6a,0xb3,0x2a,0x22,0x23,0x22,0x22,0x25,0x28,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 18007 0x4657 "䙗" */
+0x20,0x10,0x03,0xf8,0x08,0x13,0x16,0x3a,0x56,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 18008 0x4658 "䙘" */
+0x20,0x10,0x00,0xf7,0x14,0x24,0x24,0x6c,0xb7,0x2c,0x24,0x25,0x2a,0x28,0x31,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 18009 0x4659 "䙙" */
+0x20,0x13,0x02,0xf3,0x12,0x22,0x22,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x25,0x24,0x28,
+0x00,0xfe,0x02,0xfe,0x10,0x54,0x38,0x54,0x82,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,
+/* 18010 0x465a "䙚" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,0x02,0xff,0x06,0x1c,0xe5,0x06,
+0x00,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,0x00,0xfe,0x80,0x48,0x30,0x0e,
+/* 18011 0x465b "䙛" */
+0x20,0x10,0x03,0xf8,0x09,0x12,0x10,0x35,0x58,0x94,0x14,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x88,0x24,0x42,0x90,0xf8,0x08,0x44,0xa8,0x90,0x88,0xa4,0xc2,0x80,
+/* 18012 0x465c "䙜" */
+0x20,0x14,0x02,0xf1,0x10,0x20,0x26,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x25,0x28,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 18013 0x465d "䙝" */
+0x01,0xff,0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x0b,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x88,0x50,0x30,0x0e,0x00,
+/* 18014 0x465e "䙞" */
+0x20,0x17,0x00,0xf2,0x11,0x22,0x25,0x68,0xb3,0x2a,0x22,0x23,0x22,0x21,0x2f,0x20,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 18015 0x465f "䙟" */
+0x20,0x17,0x04,0xf5,0x14,0x27,0x24,0x6d,0xb5,0x2d,0x24,0x24,0x25,0x25,0x24,0x27,
+0x00,0xfc,0x44,0xf4,0x94,0xfc,0x04,0xf4,0x14,0xf4,0x44,0xf4,0x44,0xfc,0x44,0xfc,
+/* 18016 0x4660 "䙠" */
+0x20,0x17,0x04,0xf6,0x15,0x27,0x24,0x6c,0xb6,0x2e,0x27,0x24,0x24,0x25,0x29,0x32,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 18017 0x4661 "䙡" */
+0x20,0x11,0x01,0xf9,0x08,0x13,0x10,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 18018 0x4662 "䙢" */
+0x21,0x10,0x00,0xfb,0x0a,0x12,0x12,0x32,0x57,0x98,0x15,0x11,0x11,0x11,0x11,0x11,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 18019 0x4663 "䙣" */
+0x20,0x11,0x00,0xfb,0x08,0x11,0x16,0x30,0x57,0x98,0x15,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfc,0x40,0xfe,0x88,0x04,0x52,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,0x50,
+/* 18020 0x4664 "䙤" */
+0x20,0x12,0x01,0xf1,0x10,0x20,0x26,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x25,0x28,
+0x00,0x7c,0x44,0x74,0x54,0x54,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,0x00,0xfe,
+/* 18021 0x4665 "䙥" */
+0x20,0x11,0x00,0xfb,0x0a,0x11,0x14,0x39,0x54,0x90,0x13,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x50,0xc8,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 18022 0x4666 "䙦" */
+0x20,0x13,0x00,0xf9,0x09,0x11,0x15,0x38,0x57,0x92,0x10,0x10,0x11,0x10,0x10,0x13,
+0x88,0xfe,0x88,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x42,0xf8,0x88,0x48,0x30,0x60,0x80,
+/* 18023 0x4667 "䙧" */
+0x20,0x11,0x00,0xfb,0x08,0x11,0x11,0x35,0x59,0x94,0x15,0x10,0x13,0x10,0x11,0x12,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 18024 0x4668 "䙨" */
+0x21,0x11,0x01,0xf9,0x09,0x10,0x13,0x34,0x59,0x96,0x14,0x13,0x10,0x11,0x16,0x10,
+0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0xa8,0x24,0x42,0x20,0xfe,0x60,0x94,0x88,0xc6,
+/* 18025 0x4669 "䙩" */
+0x20,0x13,0x00,0xfb,0x0a,0x11,0x14,0x3b,0x54,0x90,0x13,0x10,0x13,0x10,0x13,0x10,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 18026 0x466a "䙪" */
+0x22,0x21,0xfa,0x20,0x72,0xa9,0x22,0xff,0x0a,0x31,0xcf,0x02,0x04,0x1c,0x65,0x06,
+0x88,0x08,0xbe,0x08,0x9c,0x2a,0x88,0xfe,0x20,0x18,0xe6,0x88,0x50,0x20,0x18,0x06,
+/* 18027 0x466b "䙫" */
+0x20,0x13,0x00,0xfd,0x0a,0x11,0x11,0x35,0x59,0x95,0x14,0x11,0x10,0x13,0x10,0x11,
+0x94,0x98,0x92,0x8e,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x04,
+/* 18028 0x466c "䙬" */
+0x23,0x12,0x03,0xfa,0x0b,0x12,0x17,0x39,0x56,0x90,0x17,0x10,0x11,0x10,0x10,0x13,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 18029 0x466d "䙭" */
+0x20,0x17,0x04,0xf3,0x10,0x23,0x20,0x6f,0xb1,0x2b,0x25,0x21,0x22,0x22,0x25,0x28,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0xfc,0x0a,0xf8,0x40,0x7c,0x40,0xfe,
+/* 18030 0x466e "䙮" */
+0x20,0x13,0x00,0xfb,0x0a,0x13,0x14,0x38,0x55,0x91,0x13,0x15,0x11,0x11,0x11,0x11,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 18031 0x466f "䙯" */
+0x20,0x17,0x04,0xf4,0x14,0x27,0x25,0x6a,0xb1,0x2b,0x22,0x23,0x20,0x22,0x25,0x28,
+0x14,0xfe,0x90,0xd4,0x94,0xfa,0xaa,0x96,0xa2,0xf8,0x08,0xf8,0x40,0x7c,0x40,0xfe,
+/* 18032 0x4670 "䙰" */
+0x22,0x11,0x07,0xf2,0x15,0x26,0x24,0x6f,0xb1,0x2f,0x25,0x25,0x25,0x24,0x25,0x24,
+0x0c,0x0a,0xc8,0x9e,0x54,0xf4,0x5e,0xd4,0x14,0xde,0x54,0x54,0xd4,0x5e,0x50,0x90,
+/* 18033 0x4671 "䙱" */
+0x23,0x12,0x03,0xfa,0x0a,0x12,0x16,0x3a,0x56,0x93,0x12,0x12,0x12,0x12,0x15,0x10,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 18034 0x4672 "䙲" */
+0x00,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 18035 0x4673 "䙳" */
+0x00,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 18036 0x4674 "䙴" */
+0x7f,0x04,0x3f,0x24,0x24,0x3f,0x02,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,0x08,0x07,
+0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x20,0xf0,0x28,0x26,0xe0,0x08,0x08,0xf8,
+/* 18037 0x4675 "䙵" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x01,0x3f,0x01,0xff,0x00,0x01,0x3f,0x01,0xff,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf8,0x00,0xfe,
+/* 18038 0x4676 "䙶" */
+0x00,0xfe,0x28,0x29,0x29,0xfe,0xaa,0xaa,0xaa,0xaa,0xaf,0xc2,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x10,0xfe,0x22,0x20,0x50,0x50,0xd2,0xcc,0x48,0x44,0x44,0x52,0x60,0x40,
+/* 18039 0x4677 "䙷" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,0x00,0xff,0x08,0x04,0x04,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 18040 0x4678 "䙸" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x24,0x24,0x24,0x43,0x80,
+0x08,0x08,0x08,0xfe,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x12,0x02,0xfe,0x00,
+/* 18041 0x4679 "䙹" */
+0x00,0x7e,0x24,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x85,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18042 0x467a "䙺" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x28,0x24,0x44,0x41,0x82,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 18043 0x467b "䙻" */
+0x08,0x08,0x0b,0x7c,0x48,0x48,0x48,0x7f,0x09,0x19,0x29,0x49,0x8b,0x08,0x08,0x08,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18044 0x467c "䙼" */
+0x00,0x7e,0x12,0x12,0x22,0x2a,0x44,0x80,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18045 0x467d "䙽" */
+0x01,0x01,0xff,0x02,0x24,0x18,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x80,0x48,0x30,0xf8,0x16,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 18046 0x467e "䙾" */
+0x20,0x10,0x10,0xfe,0x82,0x04,0x40,0x40,0x7c,0x40,0x40,0x40,0x4c,0x70,0x40,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18047 0x467f "䙿" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x38,0x34,0x52,0x90,0x10,0x10,0x11,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18048 0x4680 "䚀" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18049 0x4681 "䚁" */
+0x08,0x08,0x10,0x7f,0x41,0x41,0x5d,0x55,0x55,0x55,0x55,0x5d,0x41,0x41,0x45,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18050 0x4682 "䚂" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x28,0x28,0x6c,0xaa,0x28,0x28,0x48,0x48,0x99,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18051 0x4683 "䚃" */
+0x08,0x08,0x0f,0x08,0x08,0x7e,0x42,0x42,0x7a,0x4a,0x4a,0x7a,0x42,0x42,0x7e,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18052 0x4684 "䚄" */
+0x00,0x7e,0x02,0x3e,0x02,0xff,0x08,0x09,0x49,0x2a,0x1c,0x2a,0xc9,0x09,0x28,0x10,
+0x00,0x7c,0x44,0x44,0x7c,0xc4,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18053 0x4685 "䚅" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18054 0x4686 "䚆" */
+0x22,0x22,0x7f,0x22,0x2a,0x08,0x3e,0x2a,0x2a,0x2a,0xff,0x08,0x14,0x12,0x22,0x40,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18055 0x4687 "䚇" */
+0x10,0x10,0x52,0x51,0x95,0x08,0x30,0xc0,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18056 0x4688 "䚈" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x7f,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18057 0x4689 "䚉" */
+0x20,0x2f,0xf5,0x25,0x75,0x25,0xf5,0x29,0x23,0x08,0x08,0xff,0x14,0x22,0x41,0x80,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0xa8,0x28,0x4a,0x4a,0x86,
+/* 18058 0x468a "䚊" */
+0x22,0x14,0x00,0x7f,0x00,0x14,0x22,0x41,0x00,0x7f,0x55,0x55,0x55,0x57,0xfc,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0xca,0x4a,0x86,
+/* 18059 0x468b "䚋" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x14,0x22,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18060 0x468c "䚌" */
+0x08,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x10,0xff,0x22,0x49,0x88,0x7f,0x08,0x08,0x08,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0xc4,0x44,0x7c,0xa8,0x68,0x4a,0x4a,0x86,
+/* 18061 0x468d "䚍" */
+0x08,0xff,0x08,0x7e,0x08,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18062 0x468e "䚎" */
+0x08,0x08,0x7f,0x10,0x3e,0x10,0xff,0x22,0x41,0x90,0x26,0x22,0x36,0x22,0x3e,0x22,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0xc4,0x7c,0x44,0xc4,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18063 0x468f "䚏" */
+0x08,0x4a,0x2c,0x08,0xff,0x2a,0x49,0x88,0x42,0x77,0x92,0x5a,0x2f,0x22,0x42,0x82,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18064 0x4690 "䚐" */
+0x40,0x77,0xa5,0x25,0xfd,0x27,0x55,0x80,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18065 0x4691 "䚑" */
+0x00,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x28,0x45,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18066 0x4692 "䚒" */
+0x10,0x08,0x7f,0x22,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18067 0x4693 "䚓" */
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x11,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18068 0x4694 "䚔" */
+0x20,0x10,0xfe,0x82,0x7c,0x54,0x98,0x7c,0xc4,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x45,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18069 0x4695 "䚕" */
+0x77,0x00,0x77,0x55,0x77,0x55,0x08,0x7f,0x54,0x7f,0x55,0x7f,0x55,0x5e,0x55,0x9b,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 18070 0x4696 "䚖" */
+0x00,0xfe,0x10,0xfe,0x92,0x54,0x00,0xee,0xaa,0xee,0x00,0xfe,0x54,0xba,0x10,0xff,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 18071 0x4697 "䚗" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x54,0x55,0x44,0x8c,
+0x08,0x48,0x48,0x48,0x44,0x84,0xa4,0x22,0x20,0x40,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 18072 0x4698 "䚘" */
+0x12,0x13,0x24,0x49,0x87,0x15,0x25,0x67,0xa5,0x25,0x27,0x25,0x25,0x25,0x24,0x28,
+0x00,0x80,0x9c,0x00,0xc0,0x40,0x7e,0xc8,0x48,0x48,0xc8,0x48,0x48,0x48,0x68,0xd0,
+/* 18073 0x4699 "䚙" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x00,0x00,0xfe,0x00,
+/* 18074 0x469a "䚚" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x87,
+0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x28,0x28,0x28,0x28,0x4a,0x4a,0x86,0x00,
+/* 18075 0x469b "䚛" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x10,0x50,0x50,0x7c,0x50,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 18076 0x469c "䚜" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3f,0x2a,0x4a,0x42,0x86,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 18077 0x469d "䚝" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x56,0x7c,0x54,0x55,0x7c,0x54,0x54,0x44,0x8c,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 18078 0x469e "䚞" */
+0x20,0x20,0x78,0x4b,0x90,0x7d,0x55,0x55,0x7e,0x54,0x54,0x7c,0x55,0x56,0x44,0x8c,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 18079 0x469f "䚟" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2b,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 18080 0x46a0 "䚠" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7c,0x55,0x55,0x7d,0x55,0x55,0x45,0x8d,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 18081 0x46a1 "䚡" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7d,0x55,0x55,0x46,0x8c,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 18082 0x46a2 "䚢" */
+0x20,0x21,0x79,0x4b,0x91,0x7d,0x55,0x55,0x7d,0x54,0x57,0x7c,0x54,0x55,0x46,0x8c,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18083 0x46a3 "䚣" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2b,0x2a,0x3e,0x2a,0x4a,0x43,0x86,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x20,0xa0,0xbc,0xa0,0x60,0x3e,
+/* 18084 0x46a4 "䚤" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x92,0x96,0xbe,0x82,0x8a,0x84,
+/* 18085 0x46a5 "䚥" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x00,0xee,0x22,0x22,0xee,0x88,0x88,0xee,0x22,0xaa,0x66,0x66,0xaa,0x22,0xaa,0x44,
+/* 18086 0x46a6 "䚦" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x56,0x54,0x44,0x8c,
+0x08,0x3c,0xd0,0x1c,0x10,0x7c,0x54,0x58,0x70,0x54,0x4c,0x40,0x78,0xa8,0x2a,0x46,
+/* 18087 0x46a7 "䚧" */
+0x20,0x21,0x78,0x49,0x90,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7c,0x54,0x54,0x44,0x8d,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x18,0x60,0x80,
+/* 18088 0x46a8 "䚨" */
+0x20,0x21,0x78,0x4a,0x91,0x7e,0x55,0x54,0x7c,0x55,0x55,0x7d,0x54,0x54,0x45,0x8c,
+0x12,0xd4,0x48,0x8a,0x04,0x02,0xdc,0x54,0x62,0xc0,0x1e,0xc2,0x54,0x48,0x54,0xa2,
+/* 18089 0x46a9 "䚩" */
+0x20,0x21,0x78,0x4b,0x90,0x7d,0x56,0x54,0x7c,0x55,0x55,0x7d,0x55,0x55,0x45,0x8d,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 18090 0x46aa "䚪" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x57,0x54,0x7d,0x55,0x55,0x7c,0x54,0x55,0x46,0x8c,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 18091 0x46ab "䚫" */
+0x10,0x7e,0x4a,0x7e,0x10,0xff,0x20,0x3e,0x52,0x1f,0x20,0x5f,0x91,0x1f,0x11,0x21,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xe0,0x40,0xf0,0x10,0xf0,0x10,0x30,
+/* 18092 0x46ac "䚬" */
+0x20,0x21,0x78,0x4b,0x90,0x7d,0x56,0x55,0x7d,0x56,0x55,0x7c,0x54,0x55,0x45,0x8e,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x08,0xc8,0x5e,0x48,0xa8,0xbe,0x08,0x08,0x08,
+/* 18093 0x46ad "䚭" */
+0x20,0x23,0x78,0x48,0x91,0x7d,0x55,0x54,0x7d,0x56,0x54,0x7c,0x54,0x54,0x44,0x8c,
+0x88,0xfe,0x88,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,
+/* 18094 0x46ae "䚮" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x00,0x00,0xfc,0x44,0x48,0x48,0x50,0x5e,0x42,0x42,0x82,0x82,0x82,0x02,0x14,0x08,
+/* 18095 0x46af "䚯" */
+0x10,0x08,0x08,0xff,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,0x00,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 18096 0x46b0 "䚰" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 18097 0x46b1 "䚱" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x01,0x7d,0x46,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x20,0x20,0x20,0xa8,0xa4,0xa4,0x22,0x22,0x22,0x20,0x20,0x20,0xa0,0x40,
+/* 18098 0x46b2 "䚲" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x03,
+0x08,0x08,0x10,0x20,0x40,0x88,0x08,0x10,0x20,0x44,0x84,0x08,0x10,0x20,0xc0,0x00,
+/* 18099 0x46b3 "䚳" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x00,0x79,0x00,0x78,0x48,0x48,0x48,0x78,0x49,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 18100 0x46b4 "䚴" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 18101 0x46b5 "䚵" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x45,0x44,0x44,0x7c,0x44,0x00,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 18102 0x46b6 "䚶" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 18103 0x46b7 "䚷" */
+0x20,0x10,0x01,0xfd,0x02,0x7c,0x03,0x78,0x01,0x79,0x48,0x48,0x48,0x78,0x48,0x00,
+0x90,0x90,0x08,0x08,0x04,0x02,0xfc,0x80,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 18104 0x46b8 "䚸" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x02,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 18105 0x46b9 "䚹" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 18106 0x46ba "䚺" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x02,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 18107 0x46bb "䚻" */
+0x02,0x07,0x18,0x62,0x09,0x06,0x19,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x00,0xf0,0x20,0x40,0x80,0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18108 0x46bc "䚼" */
+0x20,0x11,0x10,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x47,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 18109 0x46bd "䚽" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x47,0x44,0x44,0x7c,0x44,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 18110 0x46be "䚾" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 18111 0x46bf "䚿" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 18112 0x46c0 "䛀" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 18113 0x46c1 "䛁" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x00,0x7c,0x00,0x7d,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 18114 0x46c2 "䛂" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x00,0x7b,0x00,0x78,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 18115 0x46c3 "䛃" */
+0x20,0x10,0x11,0xfc,0x00,0x7c,0x03,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,
+/* 18116 0x46c4 "䛄" */
+0x42,0x22,0x02,0xfb,0x02,0x72,0x04,0x74,0x0a,0x71,0x51,0x51,0x52,0x72,0x54,0x08,
+0x00,0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xa4,0xb4,0x28,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 18117 0x46c5 "䛅" */
+0x20,0x11,0x11,0xfd,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 18118 0x46c6 "䛆" */
+0x20,0x10,0x10,0xfe,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 18119 0x46c7 "䛇" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7e,0x00,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x06,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 18120 0x46c8 "䛈" */
+0x20,0x10,0x10,0xfc,0x01,0x7e,0x00,0x7c,0x01,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 18121 0x46c9 "䛉" */
+0x20,0x11,0x11,0xff,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 18122 0x46ca "䛊" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 18123 0x46cb "䛋" */
+0x20,0x10,0x00,0xfc,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x18,0x12,0x1a,0x26,0x42,
+/* 18124 0x46cc "䛌" */
+0x20,0x10,0x10,0xfe,0x01,0x7e,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 18125 0x46cd "䛍" */
+0x20,0x10,0x00,0xfb,0x00,0x78,0x03,0x7a,0x02,0x7b,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 18126 0x46ce "䛎" */
+0x20,0x10,0x00,0xfb,0x02,0x7c,0x00,0x78,0x00,0x78,0x48,0x49,0x49,0x79,0x4a,0x04,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 18127 0x46cf "䛏" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x80,0xa0,0xa2,0xa4,0xb8,0xa0,0xa2,0x22,0x1e,0x00,
+/* 18128 0x46d0 "䛐" */
+0x00,0x3f,0x00,0x7f,0x00,0x3f,0x20,0x3f,0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x00,0xf8,0x08,0xc8,0x08,0x88,0x88,0xa8,0x10,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18129 0x46d1 "䛑" */
+0x20,0x10,0x00,0xfc,0x00,0x78,0x00,0x7a,0x02,0x7a,0x4c,0x48,0x49,0x7a,0x44,0x00,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 18130 0x46d2 "䛒" */
+0x00,0x7d,0x10,0x10,0x1e,0xf0,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18131 0x46d3 "䛓" */
+0x04,0x24,0x24,0x24,0x25,0x04,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x80,0x80,0xfc,0xa0,0x10,0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18132 0x46d4 "䛔" */
+0x20,0x13,0x10,0xfe,0x00,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 18133 0x46d5 "䛕" */
+0x20,0x10,0x03,0xfe,0x02,0x7b,0x02,0x7a,0x03,0x78,0x49,0x48,0x48,0x78,0x49,0x06,
+0x20,0x20,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x20,0x20,0xa0,0x40,0xa0,0x18,0x06,
+/* 18134 0x46d6 "䛖" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x78,0x48,0x48,0x48,0x78,0x4b,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 18135 0x46d7 "䛗" */
+0x00,0x7e,0x49,0x48,0x48,0x7e,0x42,0x42,0x42,0x7e,0x48,0x48,0x48,0x48,0x7e,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 18136 0x46d8 "䛘" */
+0x20,0x10,0x00,0xfd,0x01,0x7b,0x05,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 18137 0x46d9 "䛙" */
+0x20,0x10,0x00,0xfd,0x01,0x7b,0x05,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 18138 0x46da "䛚" */
+0x08,0x7e,0x08,0x3e,0x08,0x7e,0x09,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x00,0xf8,0x48,0x48,0x88,0xa8,0x10,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18139 0x46db "䛛" */
+0x20,0x10,0x11,0xff,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,0x00,
+/* 18140 0x46dc "䛜" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x94,0x54,0x24,0x24,0x54,0x94,0x04,0x04,0xfc,0x04,
+/* 18141 0x46dd "䛝" */
+0x20,0x11,0x00,0xfc,0x01,0x78,0x00,0x7b,0x00,0x78,0x48,0x49,0x49,0x79,0x49,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x44,0x44,0xfe,0x00,0x20,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 18142 0x46de "䛞" */
+0x20,0x11,0x11,0xfd,0x01,0x7d,0x00,0x7c,0x01,0x7c,0x44,0x47,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 18143 0x46df "䛟" */
+0x20,0x10,0x00,0xfb,0x00,0x78,0x01,0x79,0x01,0x7a,0x48,0x48,0x48,0x78,0x49,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 18144 0x46e0 "䛠" */
+0x20,0x11,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 18145 0x46e1 "䛡" */
+0x20,0x13,0x02,0xfe,0x03,0x7a,0x02,0x7b,0x02,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0x90,0x0a,0x06,0xfa,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 18146 0x46e2 "䛢" */
+0x20,0x11,0x00,0xfc,0x03,0x78,0x01,0x7a,0x00,0x78,0x48,0x48,0x48,0x78,0x49,0x02,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0x00,0xf8,0x88,0x88,0x88,0x8a,0x0a,0x06,
+/* 18147 0x46e3 "䛣" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x78,0x03,0x78,0x49,0x49,0x48,0x78,0x48,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 18148 0x46e4 "䛤" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x10,0x10,0x90,0x9e,0x90,0x90,0xd0,0x3e,0x00,
+/* 18149 0x46e5 "䛥" */
+0x21,0x10,0x00,0xfc,0x03,0x78,0x03,0x78,0x01,0x7b,0x4d,0x49,0x49,0x79,0x48,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 18150 0x46e6 "䛦" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x01,0x7e,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 18151 0x46e7 "䛧" */
+0x20,0x11,0x11,0xfd,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x00,
+0x10,0x10,0x10,0x92,0x54,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0xfe,0x00,
+/* 18152 0x46e8 "䛨" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x03,0x7c,0x00,0x7c,0x45,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 18153 0x46e9 "䛩" */
+0x20,0x11,0x10,0xfe,0x00,0x7d,0x01,0x7d,0x01,0x7d,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xfe,0x48,0x48,0x48,0xce,0x02,0x02,0x02,0xce,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 18154 0x46ea "䛪" */
+0x20,0x10,0x03,0xfa,0x00,0x79,0x02,0x79,0x00,0x79,0x49,0x49,0x48,0x78,0x48,0x00,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x02,0xfc,0x04,0xfc,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 18155 0x46eb "䛫" */
+0x20,0x10,0x00,0xfc,0x00,0x78,0x00,0x7b,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 18156 0x46ec "䛬" */
+0x20,0x10,0x01,0xfd,0x02,0x78,0x01,0x78,0x03,0x78,0x49,0x49,0x49,0x78,0x48,0x00,
+0x80,0x80,0xfc,0x04,0x84,0xf4,0x44,0x44,0xfc,0x44,0x54,0x54,0xf4,0x04,0x28,0x10,
+/* 18157 0x46ed "䛭" */
+0x20,0x10,0x01,0xfc,0x00,0x7b,0x00,0x78,0x01,0x78,0x48,0x4b,0x48,0x78,0x48,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x50,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 18158 0x46ee "䛮" */
+0x20,0x10,0x10,0xfd,0x01,0x7e,0x00,0x7c,0x01,0x7e,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x88,0x88,0xe8,0x2c,0x2a,0xa8,0x48,0xa0,0x1e,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 18159 0x46ef "䛯" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x10,0xfe,0x10,0x10,0x7e,0x42,0x42,0x42,0x7e,0x42,
+/* 18160 0x46f0 "䛰" */
+0x20,0x11,0x11,0xff,0x01,0x7d,0x01,0x7d,0x00,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 18161 0x46f1 "䛱" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x78,0x00,0x78,0x48,0x4a,0x4a,0x7a,0x44,0x00,
+0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x20,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 18162 0x46f2 "䛲" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x78,0x00,0x7b,0x4a,0x4a,0x4a,0x7a,0x48,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 18163 0x46f3 "䛳" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x02,0x79,0x01,0x79,0x49,0x49,0x48,0x78,0x48,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 18164 0x46f4 "䛴" */
+0x20,0x10,0x01,0xfc,0x00,0x79,0x03,0x78,0x01,0x79,0x49,0x49,0x49,0x78,0x48,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 18165 0x46f5 "䛵" */
+0x20,0x13,0x00,0xf9,0x00,0x78,0x03,0x7a,0x00,0x79,0x48,0x48,0x48,0x78,0x48,0x03,
+0x1c,0xe0,0x44,0x24,0xa8,0x90,0xfe,0x02,0x00,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 18166 0x46f6 "䛶" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x00,0x78,0x4b,0x48,0x48,0x79,0x4a,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x20,0x00,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18167 0x46f7 "䛷" */
+0x20,0x10,0x03,0xfa,0x05,0x79,0x01,0x7a,0x02,0x7b,0x4c,0x48,0x49,0x79,0x4a,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 18168 0x46f8 "䛸" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x20,0x10,0xfe,0x00,0x10,0x10,0x1e,0x10,0x10,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,
+/* 18169 0x46f9 "䛹" */
+0x20,0x10,0x01,0xfd,0x00,0x7b,0x00,0x78,0x03,0x78,0x48,0x4b,0x48,0x78,0x4b,0x00,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 18170 0x46fa "䛺" */
+0x21,0x11,0x01,0xfd,0x01,0x79,0x01,0x78,0x00,0x79,0x4a,0x48,0x48,0x78,0x49,0x02,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,
+/* 18171 0x46fb "䛻" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x42,0x04,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 18172 0x46fc "䛼" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x00,0x78,0x49,0x48,0x48,0x78,0x4b,0x00,
+0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 18173 0x46fd "䛽" */
+0x20,0x10,0x01,0xfc,0x00,0x7b,0x00,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 18174 0x46fe "䛾" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x00,0x79,0x48,0x4b,0x48,0x79,0x4a,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 18175 0x46ff "䛿" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x01,0x78,0x03,0x7a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 18176 0x4700 "䜀" */
+0x40,0x23,0x01,0xf9,0x03,0x75,0x01,0x72,0x00,0x70,0x51,0x51,0x51,0x71,0x57,0x00,
+0x00,0xde,0x4a,0x4a,0x5a,0x6a,0x4a,0xd6,0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,
+/* 18177 0x4701 "䜁" */
+0x20,0x11,0x02,0xfb,0x02,0x7a,0x03,0x7a,0x03,0x7a,0x4b,0x48,0x4b,0x78,0x48,0x03,
+0x20,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x20,0xfe,0x00,0xe0,0x20,0xfe,0x50,0x88,0x06,
+/* 18178 0x4702 "䜂" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x78,0x03,0x78,0x49,0x4a,0x4d,0x78,0x48,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,
+/* 18179 0x4703 "䜃" */
+0x20,0x10,0xfe,0x00,0x7d,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x01,0x3f,0x01,0xff,0x00,
+0x50,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0x90,0xfe,0x80,0x00,0xf8,0x00,0xfe,0x00,
+/* 18180 0x4704 "䜄" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfe,0x02,0xfe,0x10,0x54,0x38,0x54,0x82,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,
+/* 18181 0x4705 "䜅" */
+0x20,0x12,0x03,0xfc,0x00,0x79,0x03,0x7d,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 18182 0x4706 "䜆" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x3f,0x20,0x2f,0x20,0x2f,0x20,0x4f,0x48,0x8f,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18183 0x4707 "䜇" */
+0x20,0x10,0x03,0xfc,0x01,0x7a,0x00,0x79,0x00,0x78,0x48,0x49,0x4a,0x7c,0x48,0x00,
+0x40,0x20,0xfe,0x88,0x24,0x42,0x90,0xf8,0x08,0x44,0xa8,0x90,0x88,0xa4,0xc2,0x80,
+/* 18184 0x4708 "䜈" */
+0x21,0x12,0x01,0xfc,0x01,0x79,0x01,0x79,0x01,0x78,0x4b,0x48,0x48,0x79,0x46,0x00,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18185 0x4709 "䜉" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x00,0x78,0x01,0x7a,0x49,0x48,0x49,0x7a,0x48,0x00,
+0x20,0x20,0xfe,0x70,0xac,0x22,0x50,0x88,0x24,0x22,0x24,0xa8,0x24,0x22,0xa0,0x40,
+/* 18186 0x470a "䜊" */
+0x20,0x10,0x07,0xf8,0x03,0x7a,0x03,0x7a,0x03,0x78,0x49,0x49,0x49,0x79,0x49,0x01,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 18187 0x470b "䜋" */
+0x20,0x11,0x01,0xfd,0x00,0x7b,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 18188 0x470c "䜌" */
+0x12,0x11,0x20,0x2b,0x48,0xf3,0x10,0x23,0x48,0xfb,0x0a,0x02,0xaa,0xab,0x82,0x00,
+0x04,0x04,0x08,0x8a,0x12,0xbc,0x04,0x88,0x12,0xbe,0x82,0x80,0xaa,0xaa,0xa2,0x00,
+/* 18189 0x470d "䜍" */
+0x20,0x10,0x01,0xfc,0x01,0x78,0x01,0x7a,0x00,0x78,0x48,0x48,0x48,0x78,0x49,0x00,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 18190 0x470e "䜎" */
+0x20,0x12,0x02,0xfc,0x01,0x7a,0x00,0x7b,0x02,0x7c,0x4b,0x48,0x48,0x78,0x49,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 18191 0x470f "䜏" */
+0x40,0x27,0x05,0xfd,0x05,0x76,0x05,0x75,0x05,0x75,0x55,0x56,0x54,0x74,0x54,0x04,
+0x20,0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 18192 0x4710 "䜐" */
+0x00,0x7b,0x48,0x51,0x4a,0x4d,0x68,0x52,0x41,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x40,0xfc,0x80,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 18193 0x4711 "䜑" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x01,0x78,0x00,0x7b,0x48,0x48,0x48,0x7a,0x4a,0x04,
+0x00,0xfe,0x50,0xdc,0x04,0x04,0xdc,0x50,0x50,0xfe,0x40,0x20,0xa4,0x8a,0x8a,0x78,
+/* 18194 0x4712 "䜒" */
+0x20,0x10,0x03,0xfe,0x02,0x7a,0x03,0x7a,0x02,0x7a,0x48,0x4b,0x48,0x78,0x49,0x06,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 18195 0x4713 "䜓" */
+0x20,0x13,0x00,0xfc,0x01,0x7b,0x01,0x79,0x01,0x79,0x48,0x4b,0x48,0x78,0x4b,0x00,
+0x88,0xfe,0x88,0x00,0x48,0xfe,0x48,0x78,0x00,0xfc,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 18196 0x4714 "䜔" */
+0x20,0x10,0x02,0xfd,0x00,0x79,0x00,0x7b,0x01,0x79,0x49,0x49,0x49,0x79,0x4a,0x04,
+0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x4c,0x80,0x7e,
+/* 18197 0x4715 "䜕" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x79,0x01,0x78,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,
+0x88,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 18198 0x4716 "䜖" */
+0x20,0x13,0x00,0xfb,0x02,0x7b,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x01,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 18199 0x4717 "䜗" */
+0x40,0x20,0x07,0xf4,0x05,0x74,0x05,0x75,0x05,0x74,0x54,0x58,0x52,0x72,0x54,0x00,
+0x14,0x12,0xfe,0x10,0xd0,0x14,0xd4,0x58,0xca,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 18200 0x4718 "䜘" */
+0x42,0x22,0x07,0xfa,0x04,0x77,0x04,0x78,0x07,0x75,0x55,0x57,0x55,0x70,0x52,0x01,
+0x88,0x88,0xe8,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x94,0x22,
+/* 18201 0x4719 "䜙" */
+0x20,0x13,0x02,0xfb,0x02,0x7b,0x01,0x7a,0x03,0x79,0x4a,0x4b,0x48,0x7a,0x4a,0x04,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 18202 0x471a "䜚" */
+0x44,0x22,0x02,0xf8,0x00,0x70,0x0e,0x72,0x02,0x72,0x52,0x52,0x52,0x75,0x58,0x00,
+0x00,0xfe,0xaa,0xaa,0xfe,0x10,0x54,0x92,0x10,0x54,0x92,0x10,0x10,0x00,0xfe,0x00,
+/* 18203 0x471b "䜛" */
+0x20,0x11,0x02,0xfd,0x01,0x79,0x00,0x7b,0x00,0x79,0x4a,0x49,0x49,0x79,0x48,0x03,
+0x80,0xf8,0x10,0xfc,0x24,0xfc,0x92,0x0e,0x80,0xf8,0x10,0xfc,0x24,0xfc,0x92,0x0e,
+/* 18204 0x471c "䜜" */
+0x20,0x10,0x00,0xfb,0x02,0x79,0x00,0x79,0x02,0x79,0x4a,0x48,0x48,0x78,0x48,0x00,
+0x40,0x7c,0x40,0xfe,0x02,0xfc,0xa8,0x54,0x88,0xfc,0x8a,0xf8,0x88,0xf8,0x88,0xf8,
+/* 18205 0x471d "䜝" */
+0x20,0x12,0x02,0xfe,0x02,0x7a,0x02,0x7b,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,
+0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,
+/* 18206 0x471e "䜞" */
+0x40,0x20,0x03,0xf8,0x00,0x77,0x02,0x72,0x05,0x70,0x51,0x51,0x51,0x71,0x51,0x02,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 18207 0x471f "䜟" */
+0x20,0x10,0x03,0xf8,0x00,0x7b,0x01,0x7b,0x01,0x7b,0x49,0x4b,0x49,0x79,0x4b,0x00,
+0x88,0x8c,0xea,0x88,0x88,0xfe,0x48,0x6a,0x4a,0x6a,0x4c,0x6c,0x4a,0x6a,0x96,0x22,
+/* 18208 0x4720 "䜠" */
+0x20,0x13,0x02,0xfb,0x02,0x7a,0x04,0x7b,0x02,0x7b,0x4a,0x4b,0x4a,0x7b,0x49,0x02,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 18209 0x4721 "䜡" */
+0x43,0x20,0x01,0xf9,0x01,0x71,0x07,0x74,0x02,0x72,0x54,0x50,0x51,0x72,0x50,0x03,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 18210 0x4722 "䜢" */
+0x20,0x13,0x02,0xfd,0x00,0x78,0x00,0x79,0x00,0x79,0x49,0x49,0x48,0x7a,0x4a,0x04,
+0x20,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfc,0x20,0xfc,0x54,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 18211 0x4723 "䜣" */
+0x00,0x20,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x12,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 18212 0x4724 "䜤" */
+0x01,0x41,0x21,0x21,0x07,0x01,0xe1,0x21,0x21,0x2f,0x20,0x29,0x31,0x22,0x04,0x08,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 18213 0x4725 "䜥" */
+0x00,0x40,0x2f,0x21,0x02,0x02,0xe4,0x27,0x21,0x25,0x25,0x2a,0x32,0x25,0x08,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0xfe,0x00,0x00,0xfe,0x00,
+/* 18214 0x4726 "䜦" */
+0x01,0x21,0x17,0x11,0x02,0x03,0xf4,0x13,0x12,0x13,0x12,0x17,0x1a,0x10,0x00,0x00,
+0x10,0x10,0xfe,0x10,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 18215 0x4727 "䜧" */
+0x00,0x23,0x11,0x11,0x03,0x05,0xf1,0x12,0x10,0x10,0x11,0x15,0x19,0x11,0x07,0x00,
+0x00,0xde,0x4a,0x4a,0x5a,0x6a,0x4a,0xd6,0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,
+/* 18216 0x4728 "䜨" */
+0x00,0x20,0x11,0x11,0x01,0x00,0xf3,0x12,0x13,0x10,0x10,0x14,0x1a,0x12,0x04,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x20,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 18217 0x4729 "䜩" */
+0x01,0x41,0x27,0x21,0x01,0x02,0xe2,0x26,0x22,0x22,0x26,0x2a,0x30,0x22,0x02,0x04,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 18218 0x472a "䜪" */
+0x00,0x24,0x22,0x4a,0x89,0x14,0x22,0x41,0xbc,0x24,0x24,0x24,0x24,0x3c,0x25,0x02,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x8a,0x8a,0x06,0x00,
+/* 18219 0x472b "䜫" */
+0x00,0x24,0x22,0x4a,0x88,0x14,0x22,0x41,0xbc,0x24,0x24,0x24,0x24,0x3d,0x24,0x00,
+0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,0x00,
+/* 18220 0x472c "䜬" */
+0x00,0x24,0x22,0x4a,0x89,0x15,0x23,0x41,0xbd,0x25,0x25,0x25,0x25,0x3d,0x25,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 18221 0x472d "䜭" */
+0x01,0x01,0x01,0x7f,0x40,0x9f,0x08,0x11,0x22,0x0c,0x30,0xdf,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x00,0xfe,0x02,0xf4,0x20,0x10,0x88,0x60,0x18,0xf6,0x10,0x10,0xf0,0x10,
+/* 18222 0x472e "䜮" */
+0x00,0x24,0x22,0x4a,0x89,0x14,0x22,0x41,0xbc,0x24,0x25,0x24,0x24,0x3c,0x24,0x00,
+0x20,0x10,0xfe,0x82,0x14,0x50,0x7e,0x50,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 18223 0x472f "䜯" */
+0x00,0x24,0x22,0x4a,0x89,0x14,0x22,0x41,0xbc,0x24,0x24,0x24,0x25,0x3c,0x24,0x00,
+0x40,0x40,0x7e,0x82,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 18224 0x4730 "䜰" */
+0x00,0x48,0x45,0x95,0x11,0x29,0x45,0x80,0x7b,0x48,0x49,0x4a,0x4d,0x78,0x48,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,
+/* 18225 0x4731 "䜱" */
+0x00,0x49,0x45,0x95,0x11,0x29,0x44,0x83,0x7a,0x4b,0x48,0x49,0x48,0x78,0x49,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 18226 0x4732 "䜲" */
+0x01,0x4a,0x45,0x94,0x13,0x2a,0x46,0x82,0x7b,0x4a,0x4b,0x4a,0x4b,0x7a,0x4a,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 18227 0x4733 "䜳" */
+0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x1f,0x08,0x04,0xff,0x10,0x10,0x10,0x1f,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x20,0x40,0xfe,0x00,0x00,0x00,0xf8,0x00,
+/* 18228 0x4734 "䜴" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x45,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x41,0x06,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 18229 0x4735 "䜵" */
+0x00,0xfe,0x00,0x01,0x7d,0x45,0x45,0x45,0x7d,0x01,0x45,0x29,0x2f,0xf2,0x42,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 18230 0x4736 "䜶" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x40,0x00,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0xd6,0x10,0xfc,0x10,0x90,0xfe,0x10,0x10,0x10,
+/* 18231 0x4737 "䜷" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x45,0x7d,0x00,0x44,0x28,0x2e,0xf0,0x40,0x01,
+0x00,0xfc,0x04,0x7c,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x44,0x44,0x28,0x10,0x68,0x86,
+/* 18232 0x4738 "䜸" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf1,0x41,0x02,
+0x00,0xfe,0x82,0x82,0xfe,0x80,0x8c,0xb0,0x9c,0xb0,0x9e,0xf0,0x92,0x12,0x0e,0x00,
+/* 18233 0x4739 "䜹" */
+0x00,0xfe,0x01,0x00,0x7c,0x45,0x45,0x45,0x7d,0x00,0x44,0x28,0x2f,0xf2,0x40,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 18234 0x473a "䜺" */
+0x00,0xfe,0x00,0x01,0x7c,0x44,0x45,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x40,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 18235 0x473b "䜻" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x01,0x44,0x28,0x2e,0xf0,0x41,0x02,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x20,0xa0,0xbc,0xa0,0x60,0x3e,
+/* 18236 0x473c "䜼" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x04,0x7f,
+0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x40,0xfc,
+/* 18237 0x473d "䜽" */
+0x00,0xfe,0x00,0x01,0x7e,0x44,0x45,0x45,0x7d,0x01,0x45,0x29,0x2f,0xf1,0x41,0x01,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xe2,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x2a,0x64,
+/* 18238 0x473e "䜾" */
+0x00,0xfe,0x01,0x00,0x7c,0x44,0x45,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x40,0x00,
+0x20,0x10,0xfe,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 18239 0x473f "䜿" */
+0x00,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x04,0x7f,
+0x00,0x20,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x40,0xfc,
+/* 18240 0x4740 "䝀" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x40,0x00,
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 18241 0x4741 "䝁" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x9f,0x00,0x1f,0x10,0x1f,0x08,0x04,0xff,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0xf4,0x00,0xf0,0x10,0xf0,0x20,0x40,0xfe,
+/* 18242 0x4742 "䝂" */
+0x7e,0x48,0x7e,0x42,0x42,0x7e,0x48,0x7e,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x04,0x7f,
+0x78,0x48,0x8e,0x00,0xf8,0x48,0x30,0xce,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x40,0xfc,
+/* 18243 0x4743 "䝃" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x40,0x01,
+0x00,0xfe,0x82,0xfe,0x82,0xfe,0x44,0xaa,0xee,0x44,0xaa,0xee,0x00,0xd4,0xaa,0x2a,
+/* 18244 0x4744 "䝄" */
+0x01,0xfa,0x03,0x06,0x7b,0x52,0x53,0x52,0x73,0x02,0x97,0x51,0x60,0x38,0xc1,0x06,
+0x08,0x94,0xde,0xb4,0xde,0x94,0xde,0x94,0xde,0x10,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 18245 0x4745 "䝅" */
+0x00,0xfe,0x08,0x10,0x30,0x4a,0x9d,0x28,0x4c,0x9a,0x2a,0x48,0x88,0x08,0x2b,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 18246 0x4746 "䝆" */
+0x08,0x1f,0x22,0x44,0x09,0x12,0x7f,0x02,0x0d,0x72,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0xf8,0x48,0x88,0x50,0x20,0xfc,0x00,0x10,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 18247 0x4747 "䝇" */
+0x00,0x25,0x22,0x42,0x80,0x25,0x24,0x24,0x25,0x24,0x24,0x25,0x24,0x44,0x43,0x80,
+0x00,0xfc,0x20,0x40,0xa4,0x38,0x50,0x98,0x38,0x54,0x94,0x50,0x22,0x02,0xfe,0x00,
+/* 18248 0x4748 "䝈" */
+0x00,0xfd,0x11,0x21,0x61,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x12,0x52,0x24,
+0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 18249 0x4749 "䝉" */
+0x04,0x24,0x14,0xff,0x80,0x00,0x7f,0x02,0x0d,0x72,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x40,0x48,0x50,0xfe,0x02,0x00,0xfc,0x00,0x10,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 18250 0x474a "䝊" */
+0x00,0xfc,0x13,0x20,0x61,0x94,0x3b,0x50,0x99,0x34,0x55,0x91,0x11,0x12,0x52,0x24,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 18251 0x474b "䝋" */
+0x00,0xfc,0x13,0x22,0x60,0x95,0x38,0x50,0x9b,0x34,0x55,0x91,0x12,0x14,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 18252 0x474c "䝌" */
+0x00,0xfb,0x20,0x41,0xa0,0x15,0x3a,0x54,0x98,0x37,0x50,0x91,0x10,0x11,0x52,0x24,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 18253 0x474d "䝍" */
+0x00,0xfb,0x22,0x40,0xa1,0x14,0x39,0x51,0x99,0x35,0x51,0x90,0x13,0x10,0x50,0x20,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 18254 0x474e "䝎" */
+0x00,0xfd,0x11,0x21,0x61,0x94,0x3b,0x50,0x98,0x35,0x55,0x91,0x11,0x11,0x51,0x21,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 18255 0x474f "䝏" */
+0x00,0xfd,0x11,0x23,0x61,0x95,0x38,0x51,0x99,0x35,0x54,0x93,0x10,0x11,0x50,0x23,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 18256 0x4750 "䝐" */
+0x00,0xfb,0x22,0x42,0xa2,0x17,0x3a,0x52,0x9a,0x36,0x52,0x93,0x12,0x12,0x52,0x22,
+0x10,0x90,0xfe,0xa0,0xbe,0x48,0xbe,0x80,0xbe,0xa2,0xbe,0x22,0x3e,0x22,0x22,0x26,
+/* 18257 0x4751 "䝑" */
+0x00,0xfd,0x10,0x20,0x63,0x94,0x39,0x51,0x99,0x35,0x55,0x90,0x11,0x10,0x53,0x20,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 18258 0x4752 "䝒" */
+0x03,0xfd,0x11,0x21,0x61,0x95,0x3b,0x50,0x98,0x35,0x54,0x91,0x10,0x10,0x53,0x20,
+0xf0,0x2e,0xe2,0x2a,0xe4,0x34,0xea,0x32,0x1e,0xe0,0xa2,0x34,0x68,0xa4,0x22,0x20,
+/* 18259 0x4753 "䝓" */
+0x01,0xfa,0x21,0x40,0xa3,0x16,0x3a,0x52,0x9b,0x36,0x53,0x92,0x13,0x12,0x52,0x23,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 18260 0x4754 "䝔" */
+0x00,0xfb,0x20,0x43,0xa2,0x17,0x38,0x50,0x99,0x35,0x53,0x95,0x11,0x11,0x51,0x21,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 18261 0x4755 "䝕" */
+0x03,0xf9,0x11,0x21,0x65,0x99,0x37,0x50,0x97,0x3a,0x57,0x92,0x13,0x12,0x57,0x20,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 18262 0x4756 "䝖" */
+0x10,0x20,0xd5,0x09,0x51,0x21,0xd1,0x19,0x29,0xc9,0x19,0x29,0xc9,0x0a,0x52,0x24,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x48,0x44,0x44,0x42,0x00,
+/* 18263 0x4757 "䝗" */
+0x0c,0x30,0xc2,0x14,0x4b,0x30,0xc8,0x14,0x24,0xcc,0x15,0x26,0xc4,0x04,0x28,0x10,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 18264 0x4758 "䝘" */
+0x0c,0x30,0xc2,0x14,0x48,0x31,0xca,0x15,0x24,0xcc,0x14,0x24,0xc4,0x04,0x28,0x13,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 18265 0x4759 "䝙" */
+0x0c,0x31,0xc3,0x15,0x49,0x31,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x05,0x29,0x10,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 18266 0x475a "䝚" */
+0x10,0x21,0xd5,0x09,0x51,0x21,0xd1,0x19,0x29,0xc9,0x19,0x29,0xc9,0x0a,0x52,0x24,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 18267 0x475b "䝛" */
+0x10,0x20,0xd4,0x09,0x51,0x21,0xd1,0x19,0x29,0xc9,0x19,0x29,0xc9,0x0a,0x52,0x24,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 18268 0x475c "䝜" */
+0x10,0x20,0xd4,0x09,0x53,0x20,0xd0,0x19,0x2a,0xc8,0x19,0x2a,0xc8,0x08,0x51,0x26,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 18269 0x475d "䝝" */
+0x0c,0x30,0xc3,0x14,0x48,0x31,0xcb,0x14,0x25,0xcd,0x15,0x25,0xc5,0x04,0x28,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 18270 0x475e "䝞" */
+0x10,0x20,0xd4,0x08,0x51,0x21,0xd1,0x19,0x29,0xc9,0x19,0x29,0xca,0x0a,0x54,0x29,
+0x20,0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 18271 0x475f "䝟" */
+0x10,0x20,0xd7,0x08,0x51,0x20,0xd3,0x18,0x28,0xc8,0x1b,0x28,0xc8,0x08,0x51,0x26,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 18272 0x4760 "䝠" */
+0x10,0x21,0xd5,0x09,0x51,0x21,0xd1,0x19,0x29,0xc9,0x19,0x29,0xc9,0x0a,0x52,0x24,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 18273 0x4761 "䝡" */
+0x10,0x20,0xd7,0x08,0x50,0x20,0xd0,0x1b,0x2a,0xcb,0x1a,0x2b,0xca,0x0a,0x52,0x22,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 18274 0x4762 "䝢" */
+0x10,0x21,0xd5,0x09,0x51,0x21,0xd0,0x1b,0x2a,0xcb,0x18,0x29,0xc8,0x08,0x51,0x26,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 18275 0x4763 "䝣" */
+0x12,0x21,0xd4,0x0c,0x52,0x20,0xd1,0x1e,0x2a,0xc8,0x1b,0x28,0xc8,0x09,0x52,0x20,
+0x00,0x7e,0x40,0x7c,0x44,0xfc,0x40,0x7e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18276 0x4764 "䝤" */
+0x0c,0x30,0xc3,0x14,0x49,0x30,0xc9,0x16,0x24,0xcc,0x14,0x24,0xc4,0x04,0x29,0x10,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 18277 0x4765 "䝥" */
+0x10,0x21,0xd5,0x09,0x51,0x21,0xd1,0x19,0x28,0xc9,0x18,0x29,0xc8,0x0b,0x50,0x20,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,
+/* 18278 0x4766 "䝦" */
+0x10,0x20,0xd7,0x0a,0x52,0x27,0xd0,0x18,0x2b,0xc8,0x19,0x2a,0xc8,0x09,0x56,0x20,
+0x40,0x80,0xfe,0x52,0x52,0xfe,0x00,0x1e,0xe0,0xa2,0x22,0x74,0xa8,0x24,0x22,0x20,
+/* 18279 0x4767 "䝧" */
+0x00,0x7c,0x44,0x44,0x7d,0x46,0x44,0x7c,0x44,0x44,0x7c,0x00,0x29,0x24,0x44,0x80,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 18280 0x4768 "䝨" */
+0x04,0x25,0x24,0x24,0x24,0x24,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x88,0x50,0x20,0x50,0x8c,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18281 0x4769 "䝩" */
+0x00,0x7c,0x44,0x44,0x7d,0x46,0x44,0x7c,0x45,0x44,0x7c,0x00,0x29,0x24,0x44,0x83,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 18282 0x476a "䝪" */
+0x00,0x7c,0x45,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x25,0x45,0x82,
+0x00,0x00,0xfe,0x12,0x14,0x10,0x90,0x90,0x9e,0x90,0x90,0x90,0xd0,0x30,0x1e,0x00,
+/* 18283 0x476b "䝫" */
+0x00,0x7c,0x44,0x44,0x7d,0x45,0x46,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,
+/* 18284 0x476c "䝬" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x00,0x28,0x24,0x47,0x80,
+0x40,0x20,0x00,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 18285 0x476d "䝭" */
+0x00,0x7c,0x45,0x45,0x7e,0x44,0x45,0x7d,0x45,0x45,0x7d,0x01,0x28,0x24,0x44,0x80,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 18286 0x476e "䝮" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x00,0x28,0x25,0x44,0x80,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 18287 0x476f "䝯" */
+0x00,0x7c,0x44,0x45,0x7e,0x45,0x45,0x7d,0x47,0x45,0x7d,0x01,0x29,0x25,0x44,0x80,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 18288 0x4770 "䝰" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x47,0x7c,0x44,0x45,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 18289 0x4771 "䝱" */
+0x02,0x1f,0x08,0x10,0x7e,0x22,0x46,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xf0,0x10,0x30,0xfc,0x44,0x8c,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18290 0x4772 "䝲" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x45,0x7d,0x02,0x28,0x24,0x44,0x80,
+0x00,0xfc,0x84,0x84,0xfc,0x90,0x90,0x88,0x84,0x32,0x08,0x00,0x60,0x18,0x04,0x00,
+/* 18291 0x4773 "䝳" */
+0x08,0x0f,0x28,0x7f,0xa1,0x16,0x38,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0x7c,0x44,0x28,0x10,0x28,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18292 0x4774 "䝴" */
+0x01,0x7f,0x01,0x1f,0x11,0x1f,0x01,0x7f,0x50,0x9f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x12,0xf4,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18293 0x4775 "䝵" */
+0x00,0x7c,0x45,0x44,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 18294 0x4776 "䝶" */
+0x00,0x7c,0x47,0x44,0x7c,0x45,0x45,0x7d,0x45,0x44,0x7d,0x01,0x2a,0x24,0x44,0x80,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 18295 0x4777 "䝷" */
+0x20,0x3e,0x48,0x08,0xff,0x24,0x42,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18296 0x4778 "䝸" */
+0x00,0x7c,0x47,0x44,0x7c,0x44,0x47,0x7c,0x44,0x45,0x7c,0x00,0x28,0x24,0x44,0x83,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x20,0x20,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 18297 0x4779 "䝹" */
+0x00,0x78,0x4b,0x4a,0x7d,0x49,0x49,0x7a,0x4a,0x4b,0x7c,0x00,0x51,0x49,0x8a,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 18298 0x477a "䝺" */
+0x10,0x08,0x7e,0x04,0x24,0x18,0x64,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0x10,0xfc,0x48,0x48,0x30,0xcc,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18299 0x477b "䝻" */
+0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x82,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 18300 0x477c "䝼" */
+0x00,0x7c,0x47,0x44,0x7d,0x44,0x47,0x7c,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 18301 0x477d "䝽" */
+0x00,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 18302 0x477e "䝾" */
+0x3f,0x00,0xff,0x08,0x2f,0x28,0x2f,0xf0,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,
+0x50,0x48,0xfe,0x40,0x20,0x12,0x0a,0x06,0xfa,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,
+/* 18303 0x477f "䝿" */
+0x05,0x39,0x21,0x3d,0x22,0x3f,0x08,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0x78,0x08,0x78,0x08,0xf8,0x20,0xf8,0x16,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18304 0x4780 "䞀" */
+0x00,0x7c,0x44,0x45,0x7d,0x47,0x45,0x7d,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 18305 0x4781 "䞁" */
+0x00,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x4a,0x4b,0x7a,0x02,0x52,0x4a,0x8a,0x03,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 18306 0x4782 "䞂" */
+0x00,0x7d,0x44,0x44,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7c,0x03,0x28,0x24,0x45,0x82,
+0x00,0xfc,0x20,0x40,0xfc,0x54,0x54,0x54,0x44,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 18307 0x4783 "䞃" */
+0x00,0x70,0x57,0x52,0x72,0x54,0x57,0x71,0x51,0x57,0x71,0x01,0x51,0x4e,0x84,0x00,
+0x08,0x08,0xc8,0x10,0x1e,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x08,0xc8,0x14,0x14,0x22,
+/* 18308 0x4784 "䞄" */
+0x20,0xfe,0x21,0x3c,0x24,0x47,0x54,0x88,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0xfe,0x20,0xac,0xf4,0xac,0xa2,0x7e,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18309 0x4785 "䞅" */
+0x00,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x00,0xfe,0x00,0x7e,0x00,0xfe,0x54,0x48,0x64,0x42,0x00,0x7e,0x42,0x42,0x7e,0x42,
+/* 18310 0x4786 "䞆" */
+0x00,0x7d,0x44,0x44,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x01,0x29,0x24,0x44,0x81,
+0x20,0x24,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 18311 0x4787 "䞇" */
+0x08,0x3e,0x08,0x7f,0x2a,0x5d,0x08,0x3e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0x20,0xf8,0x28,0x68,0x2a,0x56,0x82,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 18312 0x4788 "䞈" */
+0x00,0x7b,0x49,0x48,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x52,0x4a,0x8d,0x00,
+0x1e,0xe0,0x44,0xa8,0xf8,0x08,0x08,0xfc,0x04,0x04,0xfe,0x02,0xaa,0xaa,0x0a,0x04,
+/* 18313 0x4789 "䞉" */
+0x00,0x7d,0x44,0x45,0x7c,0x47,0x44,0x7d,0x46,0x44,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0xfc,0x8a,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,
+/* 18314 0x478a "䞊" */
+0x00,0x78,0x4b,0x4a,0x7a,0x4b,0x4a,0x7a,0x4b,0x4a,0x7b,0x02,0x52,0x4a,0x8a,0x04,
+0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0xa8,0x54,0xf8,0x8c,0xfa,0x88,0xf8,0x88,0xf8,
+/* 18315 0x478b "䞋" */
+0x02,0x71,0x57,0x50,0x74,0x53,0x57,0x71,0x51,0x57,0x71,0x05,0x55,0x49,0x81,0x03,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xa4,0x3c,0x24,0xa4,0x3c,0x90,0x58,0x68,0x2a,0x46,
+/* 18316 0x478c "䞌" */
+0x00,0x7c,0x45,0x54,0x54,0x57,0x54,0x54,0x54,0x55,0x55,0x11,0x29,0x25,0x45,0x81,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 18317 0x478d "䞍" */
+0x00,0x7c,0x47,0x44,0x55,0x54,0x57,0x54,0x55,0x55,0x55,0x11,0x29,0x25,0x41,0x81,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 18318 0x478e "䞎" */
+0x00,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x11,0x29,0x25,0x45,0x81,
+0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 18319 0x478f "䞏" */
+0x00,0x7d,0x45,0x45,0x55,0x55,0x55,0x55,0x54,0x54,0x54,0x11,0x29,0x25,0x42,0x80,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 18320 0x4790 "䞐" */
+0x00,0x7c,0x47,0x54,0x55,0x54,0x57,0x54,0x55,0x56,0x54,0x10,0x28,0x24,0x44,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 18321 0x4791 "䞑" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x54,0x88,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 18322 0x4792 "䞒" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x94,0x24,0x24,0x54,0x88,
+0x00,0xfe,0x82,0x82,0xba,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x84,
+/* 18323 0x4793 "䞓" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x55,0x88,
+0x00,0xfe,0x00,0x52,0xa4,0x28,0x94,0x4a,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 18324 0x4794 "䞔" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x94,0x24,0x25,0x55,0x8a,
+0x00,0xfe,0x82,0x82,0xfe,0x80,0x8c,0xb0,0x9c,0xb0,0x9e,0xf0,0x92,0x12,0x0e,0x00,
+/* 18325 0x4795 "䞕" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x94,0x24,0x24,0x54,0x88,
+0x00,0x7c,0x10,0xfe,0x92,0x54,0x10,0x54,0x00,0xfe,0x10,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 18326 0x4796 "䞖" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x50,0x48,0x48,0x40,0x5c,0xe0,0x40,0x40,0x20,0x24,0x14,0x0c,0x04,0x00,0xfe,0x00,
+/* 18327 0x4797 "䞗" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x08,0x08,0x08,0x08,0xfe,0x18,0x18,0x28,0x28,0x48,0x48,0x88,0x18,0x00,0xfe,0x00,
+/* 18328 0x4798 "䞘" */
+0x08,0x08,0x08,0x7e,0x09,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x40,0x40,0x7c,0x80,0x00,0x00,0xf8,0x10,0x20,0x40,0x84,0x84,0x7c,0x00,0xfe,0x00,
+/* 18329 0x4799 "䞙" */
+0x10,0x13,0x10,0x7c,0x10,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x51,0x70,0x50,0x8f,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0xfe,
+/* 18330 0x479a "䞚" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0xfe,0x10,0x10,0xfc,0x04,0x04,0x68,0x10,0x28,0x44,0x82,0x00,0xfe,0x00,
+/* 18331 0x479b "䞛" */
+0x08,0x09,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfe,0x20,0xa0,0xbc,0xa4,0xa4,0xfc,0x04,0x04,0x04,0x28,0x10,0x00,0xfe,0x00,
+/* 18332 0x479c "䞜" */
+0x08,0x08,0x09,0x7e,0x08,0x08,0xfe,0x08,0x28,0x29,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x00,0xfe,0x10,0x20,0x20,0x68,0x64,0xa2,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 18333 0x479d "䞝" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0xfc,0x28,0x24,0x24,0x20,0xfe,0x00,0xfe,0x00,
+/* 18334 0x479e "䞞" */
+0x10,0x10,0x10,0x7d,0x10,0x10,0xfd,0x11,0x11,0x51,0x5c,0x50,0x50,0x70,0x51,0x8f,
+0x50,0x50,0x50,0xfc,0x54,0x54,0xfc,0x50,0x50,0xfe,0x52,0x52,0x5a,0x94,0x10,0xfe,
+/* 18335 0x479f "䞟" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0x40,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 18336 0x47a0 "䞠" */
+0x08,0x09,0x08,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfe,0x20,0x20,0x40,0x7c,0xc4,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 18337 0x47a1 "䞡" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,0x00,0xfe,0x00,
+/* 18338 0x47a2 "䞢" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x40,0x40,0x40,0xfe,0xa0,0x20,0x3c,0x20,0x20,0x3e,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 18339 0x47a3 "䞣" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x29,0x5a,0x4f,0x80,
+0x08,0x1c,0xe0,0x80,0x80,0xfe,0x90,0x90,0xb0,0x98,0x94,0x10,0x10,0x00,0xfe,0x00,
+/* 18340 0x47a4 "䞤" */
+0x10,0x10,0x11,0x7d,0x12,0x10,0xfd,0x11,0x11,0x51,0x5d,0x51,0x50,0x70,0x50,0x8f,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,0xfe,
+/* 18341 0x47a5 "䞥" */
+0x08,0x08,0x09,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0xfe,0x20,0x40,0xfc,0x44,0x7c,0x44,0x7c,0x44,0x54,0x48,0x00,0xfe,0x00,
+/* 18342 0x47a6 "䞦" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x00,
+/* 18343 0x47a7 "䞧" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x29,0x5a,0x4f,0x80,
+0x08,0x1c,0xe0,0x80,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xa4,0x3c,0x24,0x00,0xfe,0x00,
+/* 18344 0x47a8 "䞨" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0xfe,0x00,
+/* 18345 0x47a9 "䞩" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 18346 0x47aa "䞪" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfe,0x80,0x84,0xb8,0xa0,0xbe,0xa4,0xa4,0xa4,0xc4,0x80,0xfe,0x00,0xfe,0x00,
+/* 18347 0x47ab "䞫" */
+0x10,0x11,0x10,0x7c,0x13,0x10,0xfc,0x11,0x10,0x50,0x5d,0x52,0x50,0x70,0x50,0x8f,
+0x00,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x80,0xfc,0x84,0x84,0xfc,0x84,0x00,0xfe,
+/* 18348 0x47ac "䞬" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x59,0x4f,0x80,
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x92,0x00,0x7c,0x24,0x2e,0x42,0x8a,0x04,0xfe,0x00,
+/* 18349 0x47ad "䞭" */
+0x10,0x10,0x10,0x7d,0x10,0x10,0xfc,0x11,0x10,0x50,0x5d,0x50,0x50,0x71,0x50,0x8f,
+0x20,0x48,0x84,0xfe,0x02,0x48,0x84,0x42,0x7c,0x84,0x68,0x10,0x68,0x84,0x00,0xfe,
+/* 18350 0x47ae "䞮" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x28,0x44,0xba,0x10,0xfe,0x10,0x58,0x94,0x12,0x50,0x20,0x00,0xfe,0x00,
+/* 18351 0x47af "䞯" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x0e,0xf0,0x22,0x92,0x54,0x00,0x7c,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,0xfe,0x00,
+/* 18352 0x47b0 "䞰" */
+0x10,0x10,0x11,0x7c,0x10,0x13,0xfc,0x10,0x11,0x51,0x5e,0x50,0x50,0x71,0x50,0x8f,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x50,0x50,0x54,0x52,0x52,0x90,0x90,0x30,0x00,0xfe,
+/* 18353 0x47b1 "䞱" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x28,0x44,0x92,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 18354 0x47b2 "䞲" */
+0x10,0x10,0x13,0x7c,0x10,0x13,0xfc,0x10,0x10,0x53,0x5c,0x50,0x52,0x71,0x50,0x8f,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x94,0x94,0xd8,0x92,0xaa,0xca,0x86,0x02,0x00,0xfe,
+/* 18355 0x47b3 "䞳" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x10,0xfc,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 18356 0x47b4 "䞴" */
+0x11,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x52,0x72,0x54,0x8f,
+0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,0xfe,
+/* 18357 0x47b5 "䞵" */
+0x10,0x11,0x10,0x7c,0x10,0x10,0xfd,0x12,0x11,0x50,0x5c,0x50,0x50,0x71,0x52,0x8f,
+0x00,0xee,0x22,0xaa,0x44,0xaa,0x32,0x00,0xee,0x22,0xaa,0x44,0xaa,0x12,0x20,0xfe,
+/* 18358 0x47b6 "䞶" */
+0x11,0x11,0x11,0x7d,0x11,0x11,0xfd,0x10,0x11,0x52,0x5c,0x51,0x52,0x70,0x51,0x8f,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x54,0x94,0x24,0x44,0x94,0x08,0xfe,
+/* 18359 0x47b7 "䞷" */
+0x10,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x52,0x74,0x50,0x8f,
+0x00,0xfc,0x04,0xfc,0x00,0x10,0x54,0x54,0x7c,0x10,0x54,0x54,0x54,0x7c,0x00,0xfe,
+/* 18360 0x47b8 "䞸" */
+0x10,0x10,0x10,0x7c,0x11,0x10,0xfd,0x12,0x10,0x50,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x00,0xf8,0x00,0x00,0xfc,0x20,0x24,0x22,0x60,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,
+/* 18361 0x47b9 "䞹" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x29,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfe,0x00,
+/* 18362 0x47ba "䞺" */
+0x08,0x09,0x09,0x7f,0x09,0x09,0xff,0x09,0x29,0x29,0x2f,0x29,0x29,0x5a,0x4f,0x80,
+0x1e,0xf0,0x10,0x10,0xfe,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x00,0xfe,0x00,
+/* 18363 0x47bb "䞻" */
+0x11,0x10,0x10,0x7d,0x11,0x11,0xfd,0x11,0x11,0x50,0x5d,0x50,0x50,0x71,0x52,0x8f,
+0xf8,0x50,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x40,0xfc,0x44,0x84,0x28,0x10,0xfe,
+/* 18364 0x47bc "䞼" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x3c,0x44,0x78,0x08,0xfe,0x20,0x52,0xac,0x58,0xac,0x4a,0xaa,0x10,0xfe,0x00,
+/* 18365 0x47bd "䞽" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x7c,0x10,0xfe,0xa2,0x44,0x78,0x14,0xfe,0x10,0x54,0xb2,0x00,0xfe,0x00,
+/* 18366 0x47be "䞾" */
+0x10,0x13,0x12,0x7a,0x12,0x12,0xfa,0x12,0x12,0x52,0x5a,0x53,0x55,0x72,0x50,0x8f,
+0x1e,0xe0,0x3c,0x20,0xfe,0xa2,0xb8,0xe4,0x9c,0x80,0xb8,0x28,0x4a,0x86,0x00,0xfe,
+/* 18367 0x47bf "䞿" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x09,0x17,0x21,0xdf,0x01,0x11,0x29,0x47,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xd0,0x08,0xf6,0x00,0xf8,0x00,0xfe,
+/* 18368 0x47c0 "䟀" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x20,0x20,0x7e,0x88,0x08,0x7e,0x00,0xfe,0x00,
+/* 18369 0x47c1 "䟁" */
+0x11,0x12,0x11,0x7c,0x11,0x11,0xfd,0x11,0x11,0x50,0x5d,0x50,0x50,0x71,0x52,0x8f,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x20,0xfe,
+/* 18370 0x47c2 "䟂" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfd,0x11,0x11,0x50,0x5c,0x50,0x50,0x70,0x53,0x8f,
+0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x4a,0xfe,0x00,0xfc,0x48,0x30,0xcc,0x02,0xfe,
+/* 18371 0x47c3 "䟃" */
+0x10,0x10,0x11,0x7d,0x12,0x13,0xfc,0x11,0x16,0x51,0x5c,0x51,0x50,0x71,0x50,0x8f,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x8c,0x22,0xc8,0x32,0xcc,0x30,0xc0,0x00,0xfe,
+/* 18372 0x47c4 "䟄" */
+0x10,0x13,0x10,0x7d,0x10,0x13,0xfc,0x11,0x11,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfe,
+/* 18373 0x47c5 "䟅" */
+0x08,0x7f,0x08,0x3e,0x2a,0x3e,0x2a,0xff,0x09,0x3f,0x01,0xff,0x11,0x11,0x29,0x47,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,
+/* 18374 0x47c6 "䟆" */
+0x11,0x11,0x11,0x7d,0x11,0x10,0xfc,0x13,0x10,0x50,0x5d,0x50,0x53,0x70,0x50,0x8f,
+0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0xfe,
+/* 18375 0x47c7 "䟇" */
+0x08,0x09,0x09,0x7e,0x09,0x09,0xfe,0x09,0x28,0x28,0x2e,0x29,0x2a,0x58,0x4f,0x80,
+0x94,0x18,0xde,0x94,0x5a,0xde,0x94,0xfe,0x90,0xd4,0xaa,0x16,0x22,0x00,0xfe,0x00,
+/* 18376 0x47c8 "䟈" */
+0x10,0x11,0x10,0x7d,0x10,0x11,0xfd,0x11,0x10,0x53,0x5c,0x51,0x50,0x73,0x50,0x8f,
+0x94,0xd2,0x90,0xfe,0x10,0xd4,0x54,0xd4,0x14,0xe8,0x8a,0xca,0x96,0xe2,0x00,0xfe,
+/* 18377 0x47c9 "䟉" */
+0x11,0x11,0x11,0x7d,0x10,0x11,0xfe,0x11,0x11,0x51,0x5d,0x50,0x51,0x70,0x50,0x8f,
+0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,0xfe,
+/* 18378 0x47ca "䟊" */
+0x10,0x10,0x10,0x7d,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x52,0x52,0x74,0x50,0x8f,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x20,0x52,0xac,0x5a,0xaa,0x48,0x90,0xfe,
+/* 18379 0x47cb "䟋" */
+0x10,0x10,0x10,0x7d,0x13,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x52,0x72,0x54,0x8f,
+0x40,0x7c,0x84,0x08,0xfe,0x44,0x92,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x00,0xfe,
+/* 18380 0x47cc "䟌" */
+0x10,0x10,0x11,0x7c,0x13,0x10,0xfd,0x13,0x15,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x48,0x4c,0xfa,0x48,0xfe,0xa8,0xfa,0x4a,0xec,0x4c,0xea,0x4a,0xf6,0x22,0x00,0xfe,
+/* 18381 0x47cd "䟍" */
+0x10,0x11,0x11,0x7d,0x11,0x11,0xfd,0x10,0x13,0x52,0x5d,0x53,0x50,0x70,0x51,0x8f,
+0x40,0xfc,0x24,0x94,0x4c,0x24,0xfc,0x20,0xfe,0x8a,0x24,0xfe,0x80,0xfc,0x04,0xfe,
+/* 18382 0x47ce "䟎" */
+0x10,0x11,0x10,0x7d,0x10,0x11,0xfe,0x11,0x11,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfe,
+/* 18383 0x47cf "䟏" */
+0x11,0x11,0x12,0x7b,0x11,0x12,0xfb,0x10,0x10,0x53,0x58,0x50,0x51,0x72,0x50,0x8f,
+0x24,0x74,0x58,0xfe,0x54,0xda,0xfe,0x82,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0xfe,
+/* 18384 0x47d0 "䟐" */
+0x13,0x12,0x12,0x7e,0x12,0x13,0xfe,0x12,0x13,0x52,0x5e,0x52,0x54,0x73,0x50,0x8f,
+0xfe,0x00,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x10,0x90,0x9e,0x90,0xfe,0x00,0xfe,
+/* 18385 0x47d1 "䟑" */
+0x10,0x10,0x10,0x7d,0x12,0x11,0xfd,0x11,0x10,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x54,0xfc,0x00,0xfc,0x54,0xfc,0x54,0x0c,0x00,0xfe,
+/* 18386 0x47d2 "䟒" */
+0x10,0x13,0x10,0x7b,0x12,0x13,0xf8,0x11,0x11,0x53,0x5d,0x51,0x51,0x71,0x51,0x8f,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfe,
+/* 18387 0x47d3 "䟓" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x10,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 18388 0x47d4 "䟔" */
+0x00,0x7e,0x42,0x42,0x42,0x7e,0x08,0x08,0x4e,0x48,0x48,0x48,0x4e,0xf0,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 18389 0x47d5 "䟕" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x01,0x02,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 18390 0x47d6 "䟖" */
+0x00,0x7c,0x44,0x44,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x00,0x00,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 18391 0x47d7 "䟗" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 18392 0x47d8 "䟘" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 18393 0x47d9 "䟙" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x11,0x17,0x51,0x5d,0x51,0x51,0x59,0xe0,0x00,0x00,
+0x00,0x00,0x7e,0x12,0x12,0x12,0xd2,0x12,0x12,0x12,0x52,0x92,0x22,0x22,0x4a,0x84,
+/* 18394 0x47da "䟚" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x01,0x02,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,0x08,
+/* 18395 0x47db "䟛" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 18396 0x47dc "䟜" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 18397 0x47dd "䟝" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x12,0x11,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x03,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 18398 0x47de "䟞" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x11,0x11,0x12,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 18399 0x47df "䟟" */
+0x02,0x07,0x38,0x20,0x20,0x20,0x3f,0x24,0x24,0x2c,0x24,0x26,0x25,0x44,0x44,0x85,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x90,0x10,0x50,0x5c,0x50,0x50,0x50,0xb0,0x9e,0x00,
+/* 18400 0x47e0 "䟠" */
+0x00,0x7c,0x44,0x44,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x68,0x94,0x14,0x2c,0x44,
+/* 18401 0x47e1 "䟡" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 18402 0x47e2 "䟢" */
+0x00,0x7c,0x44,0x44,0x45,0x7d,0x12,0x10,0x5c,0x50,0x51,0x51,0x5e,0xe0,0x00,0x00,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 18403 0x47e3 "䟣" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x10,0x5c,0x50,0x51,0x51,0x5e,0xe0,0x00,0x00,
+0x20,0x28,0x24,0x20,0xfc,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 18404 0x47e4 "䟤" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x11,0x5d,0x51,0x52,0x50,0x5c,0xe1,0x02,0x00,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 18405 0x47e5 "䟥" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x13,0x10,0x5c,0x50,0x51,0x52,0x5c,0xe0,0x00,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x62,0xa4,0xa0,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 18406 0x47e6 "䟦" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x10,0x10,0x5c,0x50,0x50,0x51,0x5d,0xe2,0x04,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x40,0x40,0x7c,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 18407 0x47e7 "䟧" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 18408 0x47e8 "䟨" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 18409 0x47e9 "䟩" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x13,0x5c,0x50,0x50,0x50,0x5d,0xe3,0x01,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 18410 0x47ea "䟪" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x11,0x10,0x10,0x5c,0x50,0x50,0x50,0x5d,0xe2,0x00,
+0x04,0x1e,0xe0,0x00,0x20,0x10,0xfe,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x3e,0x00,
+/* 18411 0x47eb "䟫" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 18412 0x47ec "䟬" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x07,0x00,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 18413 0x47ed "䟭" */
+0x00,0x7c,0x44,0x44,0x45,0x7d,0x12,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,
+/* 18414 0x47ee "䟮" */
+0x00,0x7c,0x44,0x45,0x45,0x7f,0x15,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x90,0x94,0x92,0x12,0x10,0x7e,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 18415 0x47ef "䟯" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x10,0x10,0x5c,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 18416 0x47f0 "䟰" */
+0x00,0x7c,0x44,0x45,0x46,0x7c,0x10,0x11,0x12,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x40,0x40,0x9c,0x00,0x40,0x40,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0xa8,0x90,
+/* 18417 0x47f1 "䟱" */
+0x00,0x7c,0x47,0x44,0x44,0x7d,0x11,0x11,0x5d,0x51,0x50,0x50,0x5d,0xe6,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x2c,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 18418 0x47f2 "䟲" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x11,0x13,0x10,0x5c,0x50,0x50,0x51,0x5d,0xe2,0x04,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 18419 0x47f3 "䟳" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x08,0x08,0x28,0x2e,0x28,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x22,0xaa,0x44,0x00,0xfe,0x00,
+/* 18420 0x47f4 "䟴" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 18421 0x47f5 "䟵" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x11,0x10,0x5c,0x50,0x50,0x51,0x5e,0xe0,0x00,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 18422 0x47f6 "䟶" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x12,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe3,0x00,
+0x20,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 18423 0x47f7 "䟷" */
+0x01,0x79,0x49,0x49,0x4f,0x79,0x11,0x11,0x1d,0x57,0x51,0x51,0x51,0x5d,0xe1,0x03,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 18424 0x47f8 "䟸" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x11,0x5c,0x50,0x51,0x50,0x5c,0xe0,0x00,0x01,
+0x20,0x20,0x7c,0xc4,0x28,0x90,0x60,0x80,0x48,0x48,0xfe,0x48,0x48,0x88,0x88,0x08,
+/* 18425 0x47f9 "䟹" */
+0x00,0x7c,0x45,0x44,0x45,0x7c,0x10,0x10,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 18426 0x47fa "䟺" */
+0x00,0x7e,0x42,0x42,0x42,0x7e,0x08,0x08,0x4e,0x48,0x48,0x48,0x4e,0xf0,0x00,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x48,0x44,0x82,0x02,
+/* 18427 0x47fb "䟻" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x10,0x10,0x5c,0x53,0x50,0x51,0x5d,0xe2,0x00,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfe,0x20,0x24,0x22,0x22,0xa0,0x40,
+/* 18428 0x47fc "䟼" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x10,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe3,0x01,
+0x08,0x0c,0xea,0x0a,0x08,0xfe,0x48,0x48,0x48,0x68,0x48,0x48,0x4a,0x6a,0x86,0x02,
+/* 18429 0x47fd "䟽" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x13,0x10,0x5d,0x51,0x51,0x51,0x5e,0xe2,0x04,0x08,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 18430 0x47fe "䟾" */
+0x00,0x7b,0x48,0x49,0x48,0x79,0x12,0x14,0x1c,0x53,0x50,0x51,0x50,0x5d,0xe2,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 18431 0x47ff "䟿" */
+0x00,0x7d,0x44,0x44,0x45,0x7c,0x10,0x13,0x5c,0x52,0x51,0x50,0x5d,0xe2,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 18432 0x4800 "䠀" */
+0x00,0x7d,0x44,0x44,0x44,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 18433 0x4801 "䠁" */
+0x00,0x78,0x49,0x4b,0x49,0x7a,0x14,0x17,0x50,0x5c,0x53,0x50,0x58,0xe0,0x07,0x00,
+0x40,0x90,0x08,0xfc,0x08,0x10,0xa4,0xbe,0x82,0x00,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 18434 0x4802 "䠂" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x1f,0x10,0x1f,0x01,0x11,0x11,0x29,0x47,
+0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0xf0,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,
+/* 18435 0x4803 "䠃" */
+0x00,0x7b,0x48,0x48,0x4b,0x7a,0x12,0x13,0x52,0x5e,0x53,0x52,0x5a,0xe2,0x02,0x02,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 18436 0x4804 "䠄" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x53,0x5c,0xe0,0x00,0x01,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x50,0x88,0x04,
+/* 18437 0x4805 "䠅" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x00,0xfe,0x02,0x1a,0x62,0x22,0x22,0xfa,0x22,0x32,0x6a,0xa6,0x22,0x22,0xfe,0x02,
+/* 18438 0x4806 "䠆" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x13,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 18439 0x4807 "䠇" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x52,0x52,0x52,0x7e,0x10,0x52,0x52,0x52,0x7e,0x02,
+/* 18440 0x4808 "䠈" */
+0x00,0x78,0x49,0x48,0x48,0x7b,0x10,0x10,0x51,0x5e,0x51,0x50,0x59,0xe2,0x00,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 18441 0x4809 "䠉" */
+0x00,0x7c,0x45,0x45,0x46,0x7c,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 18442 0x480a "䠊" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x10,0x13,0x10,0x5c,0x50,0x53,0x50,0x5c,0xe0,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 18443 0x480b "䠋" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x50,0x51,0x53,0x5c,0xe0,0x00,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 18444 0x480c "䠌" */
+0x00,0x7c,0x47,0x44,0x44,0x7d,0x12,0x10,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 18445 0x480d "䠍" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7b,0x12,0x12,0x53,0x5e,0x52,0x53,0x5a,0xe2,0x02,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 18446 0x480e "䠎" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5e,0xe2,0x04,0x09,
+0x00,0xfe,0x02,0x02,0xfe,0x00,0xfe,0x20,0x44,0xfe,0x12,0x10,0xfe,0x10,0x10,0xfe,
+/* 18447 0x480f "䠏" */
+0x00,0x7b,0x48,0x4a,0x49,0x78,0x11,0x12,0x10,0x5c,0x53,0x50,0x50,0x5c,0xe1,0x02,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 18448 0x4810 "䠐" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5c,0x50,0x53,0x50,0x5c,0xe0,0x01,0x02,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 18449 0x4811 "䠑" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x11,0x10,0x1c,0x53,0x50,0x50,0x51,0x5c,0xe0,0x03,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 18450 0x4812 "䠒" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x00,0x00,
+0x80,0x9e,0x92,0xd2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 18451 0x4813 "䠓" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 18452 0x4814 "䠔" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x11,0x10,0x5c,0x51,0x50,0x50,0x5d,0xe0,0x00,
+0x00,0x84,0x48,0x00,0xfe,0x20,0x44,0xa8,0x30,0x58,0x98,0x34,0x52,0x90,0x50,0x20,
+/* 18453 0x4815 "䠕" */
+0x00,0x78,0x4a,0x4a,0x4a,0x7a,0x17,0x10,0x1c,0x53,0x50,0x50,0x51,0x5e,0xe0,0x00,
+0x90,0x92,0xd4,0x98,0x92,0xd2,0x0e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 18454 0x4816 "䠖" */
+0x00,0x7d,0x44,0x44,0x44,0x7f,0x11,0x11,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x20,0x20,0xbe,0x42,0x84,0x10,0x10,0x28,0x44,0x82,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 18455 0x4817 "䠗" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x50,0x50,0x53,0x5c,0xe0,0x01,0x02,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x88,0x04,0x02,
+/* 18456 0x4818 "䠘" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5c,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 18457 0x4819 "䠙" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x11,0x12,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x01,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 18458 0x481a "䠚" */
+0x00,0xf0,0x97,0x94,0x91,0xf2,0x20,0x23,0xa2,0xba,0xa2,0xa2,0xa2,0xb4,0xc4,0x08,
+0x80,0x40,0xfc,0x04,0x10,0x08,0x3c,0xd0,0x90,0x90,0x90,0x88,0x88,0xa4,0xd4,0x92,
+/* 18459 0x481b "䠛" */
+0x00,0x78,0x4b,0x48,0x4a,0x79,0x11,0x12,0x1c,0x53,0x50,0x51,0x51,0x5d,0xe1,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 18460 0x481c "䠜" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x10,0x10,0x10,0x5c,0x50,0x50,0x50,0x5d,0xe0,0x00,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x88,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 18461 0x481d "䠝" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x00,0x01,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x50,0x88,0x04,
+/* 18462 0x481e "䠞" */
+0x00,0xf0,0x90,0x97,0x94,0xf4,0x24,0x24,0xa7,0xbc,0xa4,0xa5,0xba,0xe8,0x11,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 18463 0x481f "䠟" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x08,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 18464 0x4820 "䠠" */
+0x14,0x7f,0x24,0x47,0x80,0x7f,0x41,0x3f,0x21,0x3f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x50,0xfc,0x52,0xce,0x00,0xfc,0x04,0xf8,0x08,0xf8,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 18465 0x4821 "䠡" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x02,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,
+/* 18466 0x4822 "䠢" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x00,0x7f,0x40,0x9f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 18467 0x4823 "䠣" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7a,0x11,0x10,0x1c,0x53,0x50,0x50,0x53,0x5c,0xe1,0x02,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 18468 0x4824 "䠤" */
+0x00,0x7d,0x45,0x45,0x45,0x7c,0x11,0x11,0x11,0x5d,0x51,0x50,0x53,0x5c,0xe0,0x00,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 18469 0x4825 "䠥" */
+0x01,0xf1,0x95,0x93,0x91,0xf7,0x25,0x25,0xa5,0xbf,0xa5,0xa5,0xa5,0xb5,0xc4,0x04,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 18470 0x4826 "䠦" */
+0x00,0x7c,0x45,0x44,0x45,0x7c,0x10,0x11,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x80,0xee,0x4a,0x4a,0xfa,0x4e,0xaa,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 18471 0x4827 "䠧" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x12,0x12,0x13,0x5e,0x52,0x53,0x52,0x5c,0xe4,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x22,0xfc,0x28,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 18472 0x4828 "䠨" */
+0x00,0x7c,0x45,0x47,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 18473 0x4829 "䠩" */
+0x00,0xf1,0x91,0x97,0x90,0xf0,0x23,0x22,0xa3,0xba,0xa2,0xa2,0xbb,0xe4,0x08,0x03,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 18474 0x482a "䠪" */
+0x00,0x7a,0x4a,0x4a,0x4a,0x7a,0x12,0x13,0x12,0x5e,0x52,0x52,0x52,0x5e,0xe2,0x03,
+0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,
+/* 18475 0x482b "䠫" */
+0x03,0x79,0x49,0x49,0x49,0x79,0x13,0x10,0x1c,0x53,0x50,0x51,0x50,0x5c,0xe3,0x00,
+0xf0,0x2e,0xe2,0x2a,0xe4,0x34,0xea,0x32,0x1e,0xe0,0xa2,0x34,0x68,0xa4,0x22,0x20,
+/* 18476 0x482c "䠬" */
+0x00,0xf7,0x91,0x95,0x92,0xf2,0x25,0x28,0xa1,0xb9,0xa1,0xa2,0xa1,0xb0,0xc3,0x00,
+0xa0,0x4e,0x5a,0x2a,0x2a,0x1c,0xda,0x0a,0xea,0x2a,0xea,0x2c,0x48,0x68,0x88,0x08,
+/* 18477 0x482d "䠭" */
+0x01,0xf1,0x97,0x91,0x91,0xf7,0x25,0x25,0xa7,0xb9,0xa3,0xa5,0xa9,0xb1,0xc1,0x01,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 18478 0x482e "䠮" */
+0x01,0x78,0x49,0x48,0x4b,0x79,0x13,0x15,0x51,0x5d,0x51,0x51,0x59,0xe0,0x02,0x00,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0xfc,0x22,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xaa,0x04,
+/* 18479 0x482f "䠯" */
+0x00,0xf0,0x91,0x92,0x9d,0xf0,0x2e,0x2a,0xae,0xb8,0xaf,0xa9,0xaf,0xb9,0xc9,0x08,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xee,0xaa,0xee,0x00,0xfe,0x22,0xfe,0x22,0x2a,0x04,
+/* 18480 0x4830 "䠰" */
+0x00,0x7b,0x48,0x4b,0x4a,0x7b,0x10,0x10,0x11,0x5d,0x53,0x55,0x51,0x5d,0xe1,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 18481 0x4831 "䠱" */
+0x03,0x7a,0x4b,0x4a,0x4a,0x7a,0x12,0x12,0x52,0x5f,0x52,0x52,0x5a,0xe2,0x05,0x00,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 18482 0x4832 "䠲" */
+0x10,0x20,0x7c,0x44,0x7c,0x45,0x7e,0x44,0x45,0xfc,0x0c,0x14,0x24,0x44,0x94,0x08,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 18483 0x4833 "䠳" */
+0x10,0x20,0x7d,0x45,0x7d,0x45,0x7d,0x44,0x44,0xfd,0x0d,0x15,0x25,0x45,0x95,0x08,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 18484 0x4834 "䠴" */
+0x10,0x20,0x7c,0x44,0x7d,0x44,0x7c,0x44,0x44,0xfc,0x0c,0x14,0x24,0x44,0x95,0x08,
+0x20,0x10,0x10,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 18485 0x4835 "䠵" */
+0x10,0x20,0x7c,0x44,0x7c,0x45,0x7e,0x44,0x44,0xfc,0x0c,0x14,0x24,0x44,0x94,0x08,
+0x44,0x44,0x44,0x84,0xbe,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 18486 0x4836 "䠶" */
+0x10,0x20,0x7c,0x44,0x7d,0x46,0x7c,0x44,0x47,0xfc,0x0c,0x14,0x24,0x44,0x95,0x0a,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 18487 0x4837 "䠷" */
+0x10,0x20,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0xfd,0x0c,0x14,0x24,0x44,0x95,0x0a,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 18488 0x4838 "䠸" */
+0x10,0x20,0x7d,0x44,0x7c,0x45,0x7e,0x44,0x47,0xfc,0x0c,0x15,0x24,0x44,0x94,0x08,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 18489 0x4839 "䠹" */
+0x10,0x20,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0xfc,0x0c,0x15,0x24,0x44,0x94,0x09,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 18490 0x483a "䠺" */
+0x10,0x20,0x7c,0x45,0x7d,0x45,0x7d,0x45,0x45,0xfd,0x0d,0x15,0x25,0x45,0x95,0x09,
+0x80,0x40,0x5e,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x04,
+/* 18491 0x483b "䠻" */
+0x10,0x20,0x7d,0x45,0x7c,0x44,0x7d,0x44,0x44,0xfc,0x0c,0x14,0x24,0x44,0x94,0x08,
+0x20,0x10,0xfe,0x02,0x48,0x84,0x02,0xfc,0x04,0xfc,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 18492 0x483c "䠼" */
+0x10,0x20,0x7c,0x45,0x7e,0x44,0x7d,0x45,0x45,0xfd,0x0d,0x15,0x25,0x45,0x95,0x09,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xe2,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x2a,0x64,
+/* 18493 0x483d "䠽" */
+0x10,0x21,0x79,0x49,0x79,0x48,0x7b,0x48,0x49,0xf9,0x19,0x29,0x48,0x88,0x2b,0x10,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 18494 0x483e "䠾" */
+0x10,0x23,0x7a,0x4b,0x7a,0x4b,0x7a,0x4a,0x4a,0xfa,0x1a,0x2a,0x4a,0x8a,0x2a,0x12,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x0a,0x04,
+/* 18495 0x483f "䠿" */
+0x10,0x21,0x7d,0x45,0x7c,0x47,0x7c,0x45,0x45,0xfd,0x0d,0x15,0x25,0x45,0x94,0x09,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 18496 0x4840 "䡀" */
+0x10,0x21,0x7c,0x45,0x7d,0x45,0x7d,0x45,0x44,0xfc,0x0c,0x14,0x24,0x44,0x94,0x09,
+0x10,0xfe,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 18497 0x4841 "䡁" */
+0x11,0x20,0x7b,0x48,0x7a,0x49,0x7b,0x48,0x4b,0xfa,0x1b,0x2a,0x4b,0x8a,0x2a,0x12,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 18498 0x4842 "䡂" */
+0x08,0x08,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x74,0x44,0x04,0x04,0x04,0x04,
+/* 18499 0x4843 "䡃" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 18500 0x4844 "䡄" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 18501 0x4845 "䡅" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 18502 0x4846 "䡆" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x55,0x7e,0x54,0x7c,0x10,0xfe,0x10,0x11,0x10,0x10,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x20,0x40,0x48,0x44,0x84,0xfe,0x82,0x00,
+/* 18503 0x4847 "䡇" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x57,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 18504 0x4848 "䡈" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x13,
+0x08,0x88,0x50,0x20,0x50,0x88,0x00,0x08,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 18505 0x4849 "䡉" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 18506 0x484a "䡊" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xff,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 18507 0x484b "䡋" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x16,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 18508 0x484c "䡌" */
+0x10,0x10,0x10,0xfc,0x13,0x7c,0x54,0x7c,0x54,0x7d,0x11,0xfe,0x12,0x14,0x11,0x10,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 18509 0x484d "䡍" */
+0x10,0x10,0x10,0xfc,0x11,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 18510 0x484e "䡎" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x20,0x10,0x10,0xfe,0x82,0x82,0x82,0xfe,0x82,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 18511 0x484f "䡏" */
+0x10,0x11,0x10,0xfe,0x10,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfe,0x10,0x10,0x12,0x11,
+0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x08,0x10,0xd0,0x54,0x54,0x52,0x5e,0x82,0x00,
+/* 18512 0x4850 "䡐" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0xfe,0x82,0x04,0x40,0x48,0x50,0x60,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 18513 0x4851 "䡑" */
+0x10,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 18514 0x4852 "䡒" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 18515 0x4853 "䡓" */
+0x11,0x11,0x21,0x47,0x81,0x17,0x25,0x67,0xa5,0x27,0x21,0x2f,0x21,0x21,0x21,0x21,
+0x00,0x00,0x1c,0xc0,0x00,0xc0,0x7e,0xc8,0x48,0xc8,0x08,0xe8,0x08,0x08,0x28,0x10,
+/* 18516 0x4854 "䡔" */
+0x10,0x10,0x10,0xfc,0x11,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfd,0x10,0x10,0x10,0x11,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 18517 0x4855 "䡕" */
+0x10,0x11,0x10,0xfc,0x10,0x7d,0x54,0x7c,0x55,0x7d,0x12,0xfc,0x10,0x10,0x11,0x10,
+0x00,0xf8,0x10,0x20,0x24,0xa8,0xb0,0xa8,0x28,0x24,0x22,0xa0,0x40,0x00,0xfc,0x00,
+/* 18518 0x4856 "䡖" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7d,0x10,0xfe,0x10,0x10,0x13,0x10,
+0x00,0x00,0xfc,0x00,0x50,0x88,0x24,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 18519 0x4857 "䡗" */
+0x7d,0x11,0x11,0x1d,0xf2,0x05,0x1f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0xf0,0x10,0x90,0x52,0x0e,0x00,0xf0,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 18520 0x4858 "䡘" */
+0x10,0x10,0x10,0xfd,0x11,0x7e,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x02,0xfa,0xaa,0xaa,0xfa,0xaa,0xaa,0xfa,0x8a,0x02,0x14,0x08,
+/* 18521 0x4859 "䡙" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 18522 0x485a "䡚" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 18523 0x485b "䡛" */
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 18524 0x485c "䡜" */
+0x10,0x10,0x11,0xfc,0x10,0x7d,0x54,0x7d,0x56,0x7c,0x11,0xfe,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 18525 0x485d "䡝" */
+0x20,0x20,0x23,0xfa,0x25,0xf9,0xa9,0xfa,0xaa,0xfb,0x24,0xf8,0x21,0x21,0x22,0x24,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 18526 0x485e "䡞" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x11,0x3f,0xc1,0x1f,0x11,0x1f,0x11,0xff,0x01,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xf8,0x06,0xf0,0x10,0xf0,0x10,0xfe,0x00,
+/* 18527 0x485f "䡟" */
+0x10,0x10,0x10,0xfc,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfd,0x10,0x10,0x10,0x10,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 18528 0x4860 "䡠" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x11,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,0x02,
+/* 18529 0x4861 "䡡" */
+0x11,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7c,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 18530 0x4862 "䡢" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfe,0x12,0x12,0x14,0x10,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 18531 0x4863 "䡣" */
+0x10,0x13,0x12,0xfc,0x11,0x7c,0x55,0x7d,0x55,0x7d,0x11,0xfc,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 18532 0x4864 "䡤" */
+0x02,0x3f,0x02,0xff,0x1c,0xef,0x08,0x0f,0x01,0x7f,0x11,0x1f,0x11,0xff,0x01,0x01,
+0x00,0xd0,0x60,0xfe,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x10,0xf0,0x10,0xfe,0x00,0x00,
+/* 18533 0x4865 "䡥" */
+0x10,0x10,0x13,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7d,0x12,0xfc,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 18534 0x4866 "䡦" */
+0x21,0x20,0x20,0xf9,0x20,0xfb,0xaa,0xf9,0xaa,0xf8,0x23,0xf8,0x20,0x21,0x26,0x20,
+0xf8,0x88,0x70,0x8c,0x00,0xde,0x52,0x8c,0x52,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18535 0x4867 "䡧" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfe,0x12,0x14,0x10,0x10,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 18536 0x4868 "䡨" */
+0x08,0x04,0x7f,0x01,0xff,0x04,0x1f,0xe1,0x3f,0x01,0x1f,0x11,0x1f,0x11,0xff,0x01,
+0x20,0x40,0xfc,0x00,0xfe,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,
+/* 18537 0x4869 "䡩" */
+0x10,0x10,0x13,0xfc,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x13,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 18538 0x486a "䡪" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x66,
+/* 18539 0x486b "䡫" */
+0x10,0x12,0x11,0xfc,0x10,0x7c,0x57,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x20,0x20,0x7c,0xa4,0x18,0xe6,0x10,0x7e,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 18540 0x486c "䡬" */
+0x20,0x21,0x21,0xf9,0x21,0xf9,0xa8,0xfb,0xaa,0xfb,0x20,0xf9,0x20,0x20,0x21,0x26,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 18541 0x486d "䡭" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x11,0xfe,0x10,0x10,0x11,0x10,
+0x84,0x48,0xfe,0x10,0xfc,0x20,0xfe,0x40,0x7c,0xa4,0x24,0xfc,0x44,0x44,0xfe,0x00,
+/* 18542 0x486e "䡮" */
+0x11,0x11,0x12,0xfc,0x11,0x7d,0x57,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x24,0x24,0x24,0xa4,0x54,0x4a,0x92,0x08,0x08,0x28,0x2e,0x28,0x28,0x58,0x4e,0x80,
+/* 18543 0x486f "䡯" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfc,0x12,0x12,0x14,0x10,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 18544 0x4870 "䡰" */
+0x08,0xff,0x08,0x3e,0x2a,0x3e,0x40,0x81,0x3f,0x01,0x1f,0x11,0x1f,0x11,0xff,0x01,
+0x78,0x48,0x86,0x78,0x48,0x30,0x48,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,
+/* 18545 0x4871 "䡱" */
+0x20,0x23,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x22,0xfa,0x22,0x22,0x23,0x20,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 18546 0x4872 "䡲" */
+0x10,0x13,0x12,0xfe,0x13,0x7c,0x55,0x7d,0x55,0x7d,0x11,0xfc,0x13,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 18547 0x4873 "䡳" */
+0x21,0x21,0x21,0xfb,0x21,0xf9,0xa9,0xf9,0xa9,0xf9,0x23,0xf8,0x21,0x22,0x24,0x20,
+0x40,0x44,0x58,0xf0,0x50,0xd0,0x5e,0xd4,0x54,0x54,0xf4,0x14,0x54,0x34,0x14,0x24,
+/* 18548 0x4874 "䡴" */
+0x10,0x11,0x10,0xfc,0x13,0x7c,0x55,0x7d,0x55,0x7d,0x11,0xfc,0x11,0x10,0x13,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 18549 0x4875 "䡵" */
+0x10,0x12,0x11,0xfc,0x10,0x7c,0x57,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 18550 0x4876 "䡶" */
+0x20,0x23,0x22,0xfa,0x22,0xfb,0xaa,0xfa,0xab,0xfa,0x26,0xfa,0x22,0x23,0x22,0x20,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 18551 0x4877 "䡷" */
+0x10,0x13,0x10,0xfc,0x11,0x7c,0x57,0x7c,0x54,0x7d,0x10,0xfd,0x11,0x11,0x17,0x10,
+0x88,0xfe,0x88,0x20,0xfc,0x20,0xfe,0x40,0x88,0xfc,0x00,0xfc,0x54,0x54,0xfe,0x00,
+/* 18552 0x4878 "䡸" */
+0x10,0x13,0x10,0xfd,0x11,0x7d,0x55,0x7c,0x54,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x88,0xfe,0x88,0xfc,0x54,0x54,0xfc,0x28,0x24,0xfe,0x20,0x24,0x14,0x4a,0x96,0x22,
+/* 18553 0x4879 "䡹" */
+0x10,0x11,0x10,0xfd,0x11,0x7e,0x54,0x7c,0x54,0x7c,0x10,0xfd,0x10,0x10,0x11,0x12,
+0x20,0xfe,0x20,0xfe,0x02,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xfe,0xa2,0xbc,0x60,0x3e,
+/* 18554 0x487a "䡺" */
+0x20,0x23,0x20,0xf9,0x20,0xfb,0xa8,0xfb,0xa8,0xf9,0x20,0xfb,0x20,0x22,0x22,0x24,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 18555 0x487b "䡻" */
+0x20,0x21,0x21,0xf9,0x21,0xf9,0xa9,0xf8,0xab,0xfa,0x21,0xfb,0x20,0x20,0x21,0x22,
+0x40,0xfc,0x24,0x94,0x4c,0x24,0xfc,0x20,0xfe,0x8a,0x24,0xfe,0x80,0xfc,0x04,0x0c,
+/* 18556 0x487c "䡼" */
+0x20,0x21,0x20,0xfb,0x22,0xf9,0xa8,0xf9,0xa8,0xfb,0x22,0xfa,0x22,0x22,0x23,0x22,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0xaa,
+/* 18557 0x487d "䡽" */
+0x25,0x27,0x29,0xff,0x23,0xfd,0xa9,0xfb,0xaa,0xfb,0x22,0xfb,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 18558 0x487e "䡾" */
+0x21,0x21,0x21,0xff,0x29,0xfb,0xa9,0xff,0xa9,0xfb,0x2a,0xfb,0x2a,0x2b,0x2a,0x32,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 18559 0x487f "䡿" */
+0x21,0x20,0x23,0xfa,0x21,0xf8,0xa9,0xf8,0xab,0xfa,0x23,0xf8,0x23,0x21,0x22,0x27,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xbe,0xaa,0xbe,0x00,0xfe,0x24,0xaa,0xfe,
+/* 18560 0x4880 "䢀" */
+0x10,0x10,0x10,0xfe,0x20,0x29,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x49,0x09,0x08,0x08,
+0x40,0x40,0x40,0xfe,0x80,0x00,0xf8,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 18561 0x4881 "䢁" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x09,0x0a,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 18562 0x4882 "䢂" */
+0x10,0x10,0x10,0xfe,0x21,0x28,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x0b,0x08,
+0x40,0x20,0x20,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 18563 0x4883 "䢃" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x10,0x08,0x06,0x01,0x0e,0xf0,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x08,0x10,0x60,0x80,0x70,0x0e,
+/* 18564 0x4884 "䢄" */
+0x10,0x24,0x42,0x7e,0x00,0x7e,0x42,0x7e,0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,
+/* 18565 0x4885 "䢅" */
+0x02,0x1c,0x10,0x1e,0x10,0x1f,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x28,0x48,0x4a,0x8c,
+0x00,0x78,0x08,0x78,0x08,0xf8,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x88,0x50,0x30,0x0e,
+/* 18566 0x4886 "䢆" */
+0x00,0x01,0x7d,0x45,0x45,0x01,0x39,0x29,0x29,0x29,0x2b,0x2d,0x49,0x41,0x82,0x04,
+0x00,0xfe,0x00,0x7c,0x00,0xfe,0x54,0x48,0x64,0x42,0x08,0xfe,0x48,0x28,0x08,0x18,
+/* 18567 0x4887 "䢇" */
+0x20,0x11,0x7d,0x45,0x45,0x01,0x39,0x29,0x29,0x29,0x2b,0x2d,0x49,0x41,0x82,0x04,
+0x00,0xfe,0x00,0x7c,0x00,0xfe,0x54,0x48,0x64,0x42,0x08,0xfe,0x48,0x28,0x08,0x18,
+/* 18568 0x4888 "䢈" */
+0x3f,0x20,0x2f,0x20,0x3f,0x28,0x49,0x4a,0x8c,0x3f,0xd5,0x13,0x1f,0x0a,0x09,0x0f,
+0xfc,0x00,0xf8,0x00,0xfe,0x68,0x10,0x88,0x64,0xf8,0x56,0x90,0xf0,0x20,0x20,0xe0,
+/* 18569 0x4889 "䢉" */
+0x11,0x27,0x24,0x36,0x25,0x26,0x37,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x44,0x86,
+0x18,0xc8,0x48,0xd8,0x48,0xc8,0xd8,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,
+/* 18570 0x488a "䢊" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf7,0x10,0x10,0x10,0x10,0x11,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x10,0x20,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0xfe,0x00,
+/* 18571 0x488b "䢋" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x10,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 18572 0x488c "䢌" */
+0x00,0x40,0x20,0x2f,0x00,0x00,0xe7,0x24,0x24,0x24,0x24,0x24,0x20,0x20,0x50,0x8f,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x00,0xfe,
+/* 18573 0x488d "䢍" */
+0x00,0x20,0x10,0x17,0x01,0x01,0xf1,0x11,0x11,0x11,0x12,0x12,0x14,0x28,0x47,0x00,
+0x80,0x40,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,0xfe,0x00,
+/* 18574 0x488e "䢎" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf7,0x10,0x10,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x10,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 18575 0x488f "䢏" */
+0x00,0x21,0x10,0x10,0x00,0x02,0xf1,0x11,0x10,0x17,0x10,0x10,0x10,0x28,0x47,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 18576 0x4890 "䢐" */
+0x00,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x17,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x08,0xfe,0x00,0x00,0xfe,0x00,
+/* 18577 0x4891 "䢑" */
+0x00,0x20,0x13,0x12,0x02,0x02,0xf3,0x12,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x10,0x12,0x8a,0x26,0x12,0x00,0xfe,0x00,
+/* 18578 0x4892 "䢒" */
+0x00,0x20,0x17,0x10,0x01,0x02,0xf4,0x11,0x10,0x10,0x10,0x11,0x12,0x28,0x47,0x00,
+0x80,0x40,0xfc,0x00,0x10,0x08,0x14,0x10,0xa0,0x40,0xa0,0x10,0x08,0x00,0xfe,0x00,
+/* 18579 0x4893 "䢓" */
+0x00,0x20,0x13,0x12,0x04,0x01,0xf0,0x10,0x17,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,0xfe,0x00,
+/* 18580 0x4894 "䢔" */
+0x00,0x20,0x11,0x12,0x0d,0x00,0xf0,0x13,0x12,0x12,0x12,0x13,0x10,0x28,0x47,0x00,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 18581 0x4895 "䢕" */
+0x00,0x20,0x10,0x10,0x03,0x02,0xf2,0x12,0x13,0x12,0x12,0x12,0x14,0x14,0x28,0x47,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa8,0x28,0x12,0x1a,0x26,0x42,0x80,0xfe,
+/* 18582 0x4896 "䢖" */
+0x00,0x20,0x13,0x10,0x07,0x00,0xf3,0x10,0x13,0x10,0x10,0x17,0x10,0x28,0x47,0x00,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 18583 0x4897 "䢗" */
+0x01,0x41,0x21,0x2f,0x09,0x09,0xe9,0x2f,0x29,0x29,0x29,0x2f,0x20,0x50,0x8f,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0xfe,0x00,
+/* 18584 0x4898 "䢘" */
+0x00,0x20,0x13,0x12,0x04,0x00,0xf3,0x10,0x11,0x10,0x10,0x10,0x10,0x10,0x28,0x47,
+0x40,0x20,0xfe,0x02,0x14,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,0xfe,
+/* 18585 0x4899 "䢙" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x13,0x12,0x12,0x13,0x10,0x11,0x12,0x28,0x47,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x08,0x04,0x00,0xfe,
+/* 18586 0x489a "䢚" */
+0x00,0x4f,0x20,0x27,0x04,0x07,0xe4,0x27,0x20,0x27,0x20,0x20,0x21,0x22,0x50,0x8f,
+0x00,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0x40,0xc0,0xb0,0x08,0x04,0x00,0xfe,
+/* 18587 0x489b "䢛" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x28,0x47,0x00,
+0x00,0xfc,0x04,0x94,0x0c,0x04,0xf4,0x94,0x94,0xf4,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 18588 0x489c "䢜" */
+0x03,0x20,0x11,0x10,0x03,0x00,0xf7,0x14,0x13,0x12,0x12,0x12,0x12,0x28,0x47,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xf8,0x48,0x48,0x68,0x50,0x40,0xfe,0x00,
+/* 18589 0x489d "䢝" */
+0x00,0x27,0x10,0x10,0x03,0x02,0xf2,0x13,0x10,0x10,0x10,0x17,0x10,0x28,0x47,0x00,
+0x00,0xfe,0x90,0x90,0x9c,0x04,0x04,0x9c,0x90,0x90,0x90,0xfe,0x00,0x00,0xfe,0x00,
+/* 18590 0x489e "䢞" */
+0x02,0x42,0x22,0x2f,0x02,0x06,0xe7,0x2a,0x2a,0x32,0x23,0x22,0x22,0x50,0x8f,0x00,
+0x10,0x10,0x10,0x7c,0x10,0x30,0x38,0xd4,0x52,0x92,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 18591 0x489f "䢟" */
+0x04,0x42,0x20,0x2f,0x04,0x04,0xe7,0x25,0x25,0x29,0x29,0x35,0x22,0x50,0x8f,0x00,
+0x20,0x20,0x20,0xbe,0x48,0x88,0x28,0x28,0x10,0x10,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 18592 0x48a0 "䢠" */
+0x00,0x42,0x22,0x24,0x01,0x02,0xec,0x21,0x21,0x2f,0x21,0x22,0x22,0x54,0x8f,0x00,
+0x40,0x44,0x44,0xa8,0x10,0x08,0x06,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 18593 0x48a1 "䢡" */
+0x02,0x42,0x2f,0x22,0x02,0x02,0xe3,0x20,0x20,0x27,0x21,0x22,0x24,0x50,0x8f,0x00,
+0x90,0x90,0xfc,0x90,0xf0,0x00,0xf8,0x40,0x40,0xfc,0x50,0x48,0x44,0x40,0xfe,0x00,
+/* 18594 0x48a2 "䢢" */
+0x00,0x40,0x21,0x22,0x0c,0x03,0xe2,0x23,0x22,0x23,0x22,0x25,0x25,0x29,0x50,0x8f,
+0x40,0xa0,0x10,0x88,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x00,0xfe,
+/* 18595 0x48a3 "䢣" */
+0x00,0x20,0x13,0x10,0x07,0x01,0xf0,0x11,0x10,0x11,0x10,0x11,0x11,0x11,0x28,0x47,
+0x20,0xfe,0x4c,0x70,0xa0,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x00,0xfe,
+/* 18596 0x48a4 "䢤" */
+0x03,0x4e,0x22,0x22,0x0f,0x06,0xe7,0x2a,0x2a,0x32,0x22,0x22,0x22,0x50,0x8f,0x00,
+0x90,0x18,0x14,0x10,0x7e,0x10,0x38,0xb4,0x54,0x50,0x90,0x10,0x10,0x00,0xfe,0x00,
+/* 18597 0x48a5 "䢥" */
+0x00,0x27,0x10,0x12,0x02,0x0f,0xf0,0x13,0x12,0x13,0x12,0x13,0x12,0x13,0x28,0x47,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 18598 0x48a6 "䢦" */
+0x00,0x20,0x17,0x10,0x00,0x05,0xf2,0x14,0x11,0x10,0x10,0x17,0x10,0x10,0x28,0x47,
+0x80,0x40,0xfc,0x40,0x90,0xe4,0x48,0xa4,0xf0,0x10,0x40,0xfc,0x40,0x40,0x40,0xfe,
+/* 18599 0x48a7 "䢧" */
+0x00,0x27,0x10,0x14,0x02,0x04,0xf0,0x11,0x16,0x10,0x13,0x10,0x13,0x10,0x28,0x47,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0xfe,
+/* 18600 0x48a8 "䢨" */
+0x02,0x42,0x24,0x29,0x01,0x02,0xe6,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,0x53,0x8f,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x50,0x5e,0x50,0x50,0xb0,0x9e,0x00,0xfe,
+/* 18601 0x48a9 "䢩" */
+0x00,0x5f,0x22,0x22,0x0f,0x04,0xe4,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x50,0x8f,0x00,
+0x10,0x90,0x10,0x1e,0xa4,0xc4,0x94,0xd4,0x08,0x88,0x94,0xa2,0xc2,0x00,0xfe,0x00,
+/* 18602 0x48aa "䢪" */
+0x00,0x47,0x20,0x2f,0x01,0x02,0xe5,0x29,0x27,0x24,0x25,0x25,0x25,0x24,0x50,0x8f,
+0x78,0x80,0x80,0xfc,0x20,0x10,0xe8,0x26,0xf8,0x08,0xe8,0x28,0xe8,0x18,0x00,0xfe,
+/* 18603 0x48ab "䢫" */
+0x07,0x25,0x15,0x15,0x06,0x05,0xf5,0x15,0x15,0x15,0x16,0x14,0x14,0x14,0x28,0x47,
+0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x4c,0x00,0xfe,
+/* 18604 0x48ac "䢬" */
+0x00,0x47,0x20,0x22,0x01,0x07,0xe4,0x2a,0x22,0x23,0x24,0x2a,0x21,0x22,0x54,0x8f,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x02,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0xfe,
+/* 18605 0x48ad "䢭" */
+0x02,0x41,0x27,0x20,0x03,0x00,0xe7,0x20,0x24,0x22,0x20,0x22,0x2c,0x24,0x54,0x8f,
+0x08,0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0x40,0x7c,0x84,0x28,0x20,0x50,0x88,0xfe,
+/* 18606 0x48ae "䢮" */
+0x00,0x47,0x20,0x2f,0x08,0x03,0xe0,0x23,0x20,0x27,0x24,0x27,0x24,0x27,0x50,0x8f,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,
+/* 18607 0x48af "䢯" */
+0x02,0x44,0x20,0x23,0x0c,0x02,0xe4,0x23,0x3c,0x24,0x27,0x28,0x35,0x22,0x54,0x8f,
+0x44,0x48,0xb0,0x0c,0x42,0x44,0xa8,0x18,0x06,0x08,0xbe,0x88,0x28,0x3e,0x08,0xfe,
+/* 18608 0x48b0 "䢰" */
+0x07,0x20,0x14,0x12,0x04,0x01,0xf2,0x17,0x1a,0x13,0x12,0x13,0x12,0x13,0x2a,0x47,
+0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfe,
+/* 18609 0x48b1 "䢱" */
+0x00,0x27,0x10,0x13,0x00,0x07,0xf4,0x17,0x12,0x13,0x12,0x13,0x12,0x13,0x29,0x47,
+0x40,0xfc,0x40,0xf8,0x00,0xfc,0xa4,0xfc,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfe,
+/* 18610 0x48b2 "䢲" */
+0x07,0x24,0x17,0x14,0x07,0x01,0xf3,0x12,0x17,0x1a,0x13,0x12,0x10,0x13,0x28,0x47,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x40,0xfc,0x40,0xfc,0x40,0xfe,0x90,0x60,0x98,0x00,0xfe,
+/* 18611 0x48b3 "䢳" */
+0x00,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x80,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18612 0x48b4 "䢴" */
+0x00,0x07,0x78,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0xc8,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18613 0x48b5 "䢵" */
+0x00,0x7e,0x00,0x00,0x00,0xff,0x10,0x10,0x20,0x20,0x44,0x42,0xff,0x41,0x00,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18614 0x48b6 "䢶" */
+0x08,0x08,0x08,0x08,0x7f,0x08,0x18,0x1c,0x2a,0x29,0x48,0x88,0x08,0x08,0x08,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18615 0x48b7 "䢷" */
+0x00,0x3f,0x21,0x21,0x29,0x25,0x25,0x21,0xff,0x21,0x21,0x21,0x21,0x41,0x45,0x82,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0xe2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18616 0x48b8 "䢸" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x21,0x21,0x27,0xf8,0x40,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 18617 0x48b9 "䢹" */
+0x00,0x7f,0x40,0x40,0x40,0x7f,0x41,0x41,0x41,0x41,0x7f,0x40,0x40,0x40,0x7f,0x00,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0xa0,0x20,
+/* 18618 0x48ba "䢺" */
+0x08,0x08,0x49,0x49,0x49,0x49,0x7f,0x08,0x08,0x49,0x49,0x49,0x4f,0x79,0x00,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18619 0x48bb "䢻" */
+0x00,0x7f,0x48,0x48,0x48,0x7f,0x41,0x41,0x41,0x41,0x7f,0x48,0x48,0x48,0x7f,0x00,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0xa0,0x20,
+/* 18620 0x48bc "䢼" */
+0x12,0x12,0x12,0x12,0x7f,0x12,0x12,0x12,0x12,0xff,0x00,0x12,0x11,0x21,0x20,0x40,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0xa2,0x22,0x34,0x28,0x20,0xa0,0xa0,
+/* 18621 0x48bd "䢽" */
+0x04,0x04,0x7f,0x04,0xff,0x10,0x2f,0xc8,0x0f,0x00,0x1f,0x11,0x1f,0x10,0x10,0x0f,
+0x40,0x40,0xfc,0x40,0xfe,0x10,0xe8,0x26,0xe0,0x00,0xf0,0x10,0xf0,0x04,0x04,0xfc,
+/* 18622 0x48be "䢾" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0x08,0x7f,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18623 0x48bf "䢿" */
+0x10,0x08,0x08,0xff,0x80,0x11,0x10,0xff,0x22,0x22,0x42,0x34,0x08,0x14,0x22,0xc1,
+0x00,0x3e,0x22,0xa4,0xa4,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18624 0x48c0 "䣀" */
+0x10,0x10,0x3f,0x21,0x42,0xbf,0x20,0x2f,0x29,0x29,0x2d,0x2a,0x28,0x4a,0x4c,0x88,
+0x00,0x7c,0x44,0x48,0x48,0xd0,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18625 0x48c1 "䣁" */
+0x00,0xf7,0x10,0x10,0x94,0x52,0x52,0x10,0x31,0x52,0x94,0x10,0x10,0x10,0x52,0x21,
+0x00,0xbe,0xa2,0xa4,0xa4,0xa8,0xa4,0xa4,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 18626 0x48c2 "䣂" */
+0x08,0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18627 0x48c3 "䣃" */
+0x20,0x20,0x3f,0x48,0x88,0x08,0x7f,0x08,0x08,0x2e,0x28,0x28,0x2f,0xf0,0x40,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18628 0x48c4 "䣄" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x08,0x2a,0x29,0x49,0x88,0x28,0x10,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18629 0x48c5 "䣅" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x28,0x28,0x2d,0x2a,0x29,0x48,0x4c,0x88,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0xa4,0x22,0xa2,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 18630 0x48c6 "䣆" */
+0x00,0x7f,0x00,0x24,0x49,0x92,0x49,0x24,0x00,0x7f,0x08,0x08,0x08,0x0b,0xfc,0x00,
+0x00,0xbe,0x22,0xa4,0x24,0x28,0x24,0xa4,0x22,0xa2,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 18631 0x48c7 "䣇" */
+0x08,0x0a,0x09,0x08,0x7f,0x08,0x08,0x49,0x2a,0x08,0x1c,0x2a,0xc9,0x08,0x28,0x10,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18632 0x48c8 "䣈" */
+0x00,0x7c,0x44,0x44,0x7c,0x00,0x7d,0x55,0x55,0x55,0x7d,0x41,0x41,0x4d,0x71,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 18633 0x48c9 "䣉" */
+0x20,0x12,0x44,0x20,0x08,0x73,0x20,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x20,0x1f,
+0x40,0x48,0x44,0x14,0x60,0x80,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x02,0xfe,
+/* 18634 0x48ca "䣊" */
+0x08,0x49,0x29,0x2a,0x08,0x7f,0x41,0x41,0x5d,0x55,0x55,0x55,0x5d,0x41,0x45,0x42,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18635 0x48cb "䣋" */
+0x01,0x07,0x78,0x08,0x44,0x25,0x20,0x04,0x7f,0x0c,0x16,0x15,0x24,0x44,0x84,0x04,
+0x00,0xbe,0x22,0xa4,0xa4,0x28,0x24,0x24,0xa2,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 18636 0x48cc "䣌" */
+0x08,0x04,0x7f,0x40,0x43,0x5e,0x52,0x52,0x5f,0x52,0x52,0x52,0x55,0x59,0x94,0x02,
+0x00,0x1e,0xd2,0x12,0x94,0x14,0x18,0x14,0xd2,0x12,0x12,0x1a,0x54,0x50,0xd0,0x50,
+/* 18637 0x48cd "䣍" */
+0x08,0x08,0xff,0x14,0x22,0x49,0x88,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x0a,0x0c,0x08,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18638 0x48ce "䣎" */
+0x24,0x24,0x49,0x92,0x49,0x24,0x24,0x00,0x7f,0x48,0x48,0x7f,0x48,0x48,0x7f,0x40,
+0x80,0xbe,0x22,0x24,0x24,0xa8,0xa4,0x24,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0xa0,
+/* 18639 0x48cf "䣏" */
+0x15,0x15,0x15,0x25,0x2f,0x65,0x65,0xa5,0x25,0x25,0x3f,0x20,0x25,0x24,0x28,0x30,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0xe2,0x34,0x28,0xa0,0xa0,0x20,
+/* 18640 0x48d0 "䣐" */
+0x22,0x22,0x7f,0x22,0x2a,0x08,0x3e,0x2a,0x2a,0x2a,0xff,0x08,0x14,0x12,0x22,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18641 0x48d1 "䣑" */
+0x00,0x3f,0x20,0x2f,0x2a,0x2a,0x2f,0x2a,0x2a,0x2f,0x22,0x2f,0x42,0x43,0x9c,0x08,
+0x00,0xbe,0x22,0xa4,0xa4,0xa8,0xa4,0xa4,0xa2,0xa2,0x22,0xb4,0x28,0xa0,0x20,0x20,
+/* 18642 0x48d2 "䣒" */
+0x08,0x08,0x7f,0x49,0x7f,0x08,0xff,0x00,0x7f,0x41,0x49,0x49,0x49,0x14,0x22,0xc1,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18643 0x48d3 "䣓" */
+0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x00,0xff,0xa2,0x94,0xff,0x88,0x88,0x8a,0x81,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 18644 0x48d4 "䣔" */
+0x08,0x49,0x2a,0x08,0x7f,0x41,0x41,0x7f,0x41,0x7f,0x41,0x41,0x7f,0x00,0x22,0x41,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 18645 0x48d5 "䣕" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0x20,0x20,
+/* 18646 0x48d6 "䣖" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x78,0x48,0x48,0x78,0x00,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,
+/* 18647 0x48d7 "䣗" */
+0x08,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x10,0xff,0x22,0x49,0x88,0x7f,0x08,0x08,0x08,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0x22,0x22,0xb4,0x68,0x20,0x20,0x20,
+/* 18648 0x48d8 "䣘" */
+0x08,0x49,0x2a,0xff,0x80,0x3e,0x22,0x22,0x3e,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x3e,0x22,0xa4,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18649 0x48d9 "䣙" */
+0x04,0x44,0x44,0x7f,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0xab,0x14,
+0x00,0x5e,0x52,0xd2,0x14,0xd4,0x58,0x54,0xd2,0x52,0x52,0xda,0x54,0x50,0x50,0x90,
+/* 18650 0x48da "䣚" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18651 0x48db "䣛" */
+0x08,0x08,0xff,0x1c,0x2b,0xc8,0x14,0x22,0x49,0x88,0x49,0x2a,0x49,0x88,0x28,0x10,
+0x00,0x3e,0xa2,0x24,0x24,0xa8,0x24,0x24,0x22,0xa2,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 18652 0x48dc "䣜" */
+0x08,0x0f,0x08,0x7f,0x48,0x4e,0x79,0x47,0x40,0x5f,0x51,0x5f,0x51,0x5f,0x51,0xbe,
+0x00,0x3e,0x22,0xa4,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0xa0,0x20,
+/* 18653 0x48dd "䣝" */
+0x00,0x3f,0x20,0x20,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x38,0x2f,0x48,0x4f,0x88,
+0x00,0xde,0x52,0x52,0xd4,0x34,0xd8,0x94,0xf2,0x12,0xd2,0x5a,0xd4,0x50,0xd0,0x50,
+/* 18654 0x48de "䣞" */
+0x00,0xf7,0x94,0x94,0xf7,0x22,0x14,0xff,0x08,0x49,0x49,0x7f,0x09,0x10,0x20,0x40,
+0x00,0xbe,0xa2,0xa4,0xa4,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 18655 0x48df "䣟" */
+0x00,0xf7,0x21,0xa5,0xf7,0x63,0xb5,0x21,0x7f,0x40,0x40,0x7f,0x40,0x40,0x7f,0x40,
+0x00,0xbe,0x22,0x24,0xa4,0x28,0xa4,0x24,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0xa0,
+/* 18656 0x48e0 "䣠" */
+0x11,0x11,0x7b,0x11,0xff,0x11,0x2a,0x44,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x1e,0xd2,0x12,0xf4,0x14,0x98,0x54,0xb2,0x92,0x92,0x9a,0x94,0x90,0x90,0x90,
+/* 18657 0x48e1 "䣡" */
+0x41,0x22,0xff,0x08,0x7f,0x08,0xff,0x15,0x64,0x24,0xff,0x24,0x35,0xe2,0x25,0x68,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0xa2,0x22,0xa2,0x34,0x28,0xa0,0xa0,0xa0,
+/* 18658 0x48e2 "䣢" */
+0x22,0x22,0x27,0xfa,0x22,0x72,0x27,0xf8,0x27,0x74,0x6c,0xa7,0x24,0x24,0x27,0x24,
+0x80,0x9e,0xd2,0x92,0x94,0x94,0xf8,0x14,0xd2,0x52,0x52,0xda,0x54,0x50,0xd0,0x50,
+/* 18659 0x48e3 "䣣" */
+0x24,0x15,0x7f,0x40,0x1f,0x11,0x7f,0x55,0x4e,0x7f,0x04,0x7f,0x04,0xff,0x2a,0x45,
+0x80,0x1e,0xd2,0x52,0x14,0x14,0xd8,0x54,0x52,0xd2,0x12,0xda,0x14,0xf0,0x50,0x30,
+/* 18660 0x48e4 "䣤" */
+0x7b,0x4a,0x7b,0x4a,0x7b,0x14,0x3f,0x64,0xbf,0x24,0x3f,0x00,0x3f,0x10,0x0f,0xf0,
+0xc0,0x5e,0xd2,0x52,0xd4,0x14,0xd8,0x14,0x92,0x12,0xd2,0x1a,0x94,0x90,0x10,0x90,
+/* 18661 0x48e5 "䣥" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x20,0xa0,0x20,0x22,0x22,0x24,0x28,0x30,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 18662 0x48e6 "䣦" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x20,0xa0,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 18663 0x48e7 "䣧" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x20,0xa8,0x24,0x24,0x20,0x3e,0xe0,0x20,0x20,0x20,0x20,0x20,0x14,0x14,0x0c,0x04,
+/* 18664 0x48e8 "䣨" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x90,0x10,0x1c,0x70,0x10,0x10,0x10,0x1e,0xf0,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 18665 0x48e9 "䣩" */
+0x00,0xfe,0x28,0x29,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0xa8,0xa8,0xf8,0x22,0x22,0x22,0x1e,0x00,
+/* 18666 0x48ea "䣪" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,0x10,
+/* 18667 0x48eb "䣫" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 18668 0x48ec "䣬" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x48,0x44,0x44,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 18669 0x48ed "䣭" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 18670 0x48ee "䣮" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x3c,0x34,0x54,0x54,0x54,0x88,0x88,0x14,0x22,
+/* 18671 0x48ef "䣯" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x00,0xbc,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x24,0x7e,0x00,
+/* 18672 0x48f0 "䣰" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x00,0xbe,0x20,0x20,0x20,0x3e,0x22,0x22,0x22,0x22,0x3e,0x20,0x20,0x20,0x3e,0x00,
+/* 18673 0x48f1 "䣱" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x20,0xa0,0x20,0x7c,0x44,0x84,0x74,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x28,0x10,
+/* 18674 0x48f2 "䣲" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x20,0x20,0x40,0x48,0x84,0xfc,0x04,0x48,0x48,0xfe,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 18675 0x48f3 "䣳" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 18676 0x48f4 "䣴" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x00,0x44,0x28,0x92,0xaa,0xc6,0x82,0xfe,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 18677 0x48f5 "䣵" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfe,0x48,0x48,0x78,0x48,0x48,0x78,0x48,0x48,0x4e,0xf8,0x08,0x08,0x08,0x08,
+/* 18678 0x48f6 "䣶" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x08,0x1c,0x70,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 18679 0x48f7 "䣷" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,
+/* 18680 0x48f8 "䣸" */
+0x08,0x13,0x30,0x57,0x90,0x10,0x13,0x10,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,
+0x38,0xc0,0x40,0xfc,0x40,0x40,0xf8,0x00,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,
+/* 18681 0x48f9 "䣹" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x50,0x58,0x54,0x94,0x90,0x9c,0xf0,0x94,0x94,0x94,0x98,0x98,0x94,0x94,0xac,0xc4,
+/* 18682 0x48fa "䣺" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x8a,0x84,
+/* 18683 0x48fb "䣻" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x28,0x44,0x92,0x08,0x7c,0x04,0x08,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 18684 0x48fc "䣼" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x10,0x54,0x52,0x92,0x10,0x50,0x20,
+/* 18685 0x48fd "䣽" */
+0x20,0x3e,0x48,0x08,0xff,0x14,0x22,0x40,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x00,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,
+/* 18686 0x48fe "䣾" */
+0x00,0xfe,0x28,0x28,0xff,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x20,0x10,0xfe,0x82,0x04,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0xfe,0x00,
+/* 18687 0x48ff "䣿" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x50,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 18688 0x4900 "䤀" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xff,0x82,0x82,0xfe,0x82,
+0x44,0x44,0xfe,0x44,0x54,0x10,0xfe,0x20,0x40,0x7e,0xc2,0x42,0x42,0x42,0x7e,0x42,
+/* 18689 0x4901 "䤁" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x48,0x48,0xfc,0x48,0x78,0x48,0x78,0x48,0x48,0xfe,0x80,0xa8,0xc4,0x80,0xfe,0x00,
+/* 18690 0x4902 "䤂" */
+0x00,0xfe,0x2b,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x83,0xfe,0x82,0x83,0xfe,0x82,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18691 0x4903 "䤃" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x20,0xfe,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 18692 0x4904 "䤄" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xaa,0xfe,0x82,
+/* 18693 0x4905 "䤅" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xe2,0xaa,0xaa,0xea,0xaa,0xaa,0xe2,0xaa,0xa4,
+/* 18694 0x4906 "䤆" */
+0x00,0xfe,0x28,0x29,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x83,0xfe,0x82,0x82,0xfe,0x83,
+0x10,0xd4,0x48,0x4a,0x84,0x84,0x02,0xf8,0x20,0x20,0xfc,0x20,0x50,0x48,0x84,0x04,
+/* 18695 0x4907 "䤇" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x82,0x28,0x44,0x92,0x28,0x44,0x82,0x7c,0x04,0x28,0x10,0x28,0xc4,
+/* 18696 0x4908 "䤈" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x44,0x82,0x7c,0x20,0x40,0x7c,0x04,0x28,0x10,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 18697 0x4909 "䤉" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x10,0x0c,0x24,0xaa,0xb0,0x24,0x64,0x9c,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 18698 0x490a "䤊" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x44,0x44,0xfe,0x44,0x00,0xfe,0x44,0x44,0x7c,0x44,0x7c,0x44,0x4e,0xf4,0x04,0x04,
+/* 18699 0x490b "䤋" */
+0x44,0x24,0x28,0xfe,0x29,0x28,0xfe,0xaa,0xaa,0xae,0xc2,0xfe,0x82,0x82,0xfe,0x82,
+0x08,0x0c,0x0a,0x08,0xfe,0x08,0x08,0xea,0xaa,0xaa,0xec,0x0c,0x2a,0xca,0x16,0x22,
+/* 18700 0x490c "䤌" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x83,0x83,0xfe,0x82,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 18701 0x490d "䤍" */
+0x00,0xf8,0x23,0x20,0xf8,0xa8,0xa8,0xab,0xda,0x8b,0x8a,0xfb,0x8a,0x8a,0xfa,0x8a,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 18702 0x490e "䤎" */
+0x00,0xfe,0x28,0x29,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0xfc,0x28,0x10,0xfe,0x52,0x94,0x50,0x20,0xfe,0xaa,0xc6,0xba,0xaa,0xba,0x82,0x86,
+/* 18703 0x490f "䤏" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x28,0xee,0x28,0xee,0x28,0xee,0x28,0x06,0xf8,0x10,0xfe,0x10,0xfe,0x10,0x50,0x20,
+/* 18704 0x4910 "䤐" */
+0x00,0xfb,0x20,0x22,0xfb,0xa9,0xaa,0xac,0xd9,0x89,0x89,0xf9,0x89,0x89,0xf9,0x89,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 18705 0x4911 "䤑" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x28,0x28,0x7c,0x28,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x28,0x44,0x82,
+/* 18706 0x4912 "䤒" */
+0x01,0xf9,0x22,0x23,0xf9,0xaa,0xab,0xa9,0xdb,0x89,0x89,0xf9,0x8a,0x8a,0xfa,0x8c,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 18707 0x4913 "䤓" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x48,0x48,0xfe,0x48,0xfe,0x82,0x7c,0x00,0xfe,0x20,0xd2,0x2c,0xd8,0x2c,0xca,0x30,
+/* 18708 0x4914 "䤔" */
+0x42,0x3f,0x8a,0x4f,0x2a,0x5f,0x82,0xff,0x04,0x3f,0x24,0x28,0x30,0x3f,0x20,0x3f,
+0x04,0xd8,0x90,0x9e,0x94,0xd4,0x24,0xfe,0x80,0xf8,0x88,0x78,0x08,0xf8,0x08,0xf8,
+/* 18709 0x4915 "䤕" */
+0x01,0xf9,0x22,0x22,0xfb,0xa9,0xaa,0xab,0xd8,0x88,0x8b,0xf8,0x88,0x89,0xfa,0x88,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18710 0x4916 "䤖" */
+0x01,0xf9,0x21,0x21,0xf9,0xa8,0xa9,0xa8,0xdb,0x88,0x89,0xfa,0x88,0x88,0xf9,0x88,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 18711 0x4917 "䤗" */
+0x08,0x7f,0x14,0x7f,0x22,0x3e,0x22,0x7f,0x08,0xff,0x04,0x3f,0x28,0x37,0x20,0x3f,
+0x20,0x7c,0xc4,0x38,0xd6,0x38,0x50,0x7c,0x10,0xfe,0x40,0xf8,0x48,0xb8,0x08,0xf8,
+/* 18712 0x4918 "䤘" */
+0x01,0xf9,0x22,0x20,0xfb,0xa9,0xab,0xa9,0xdb,0x89,0x8b,0xf9,0x89,0x8b,0xf8,0x88,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4a,0x6c,0x4c,0x6a,0x8a,0x16,0x22,
+/* 18713 0x4919 "䤙" */
+0x00,0xf9,0x21,0x20,0xfb,0xa8,0xab,0xa8,0xdb,0x88,0x8a,0xff,0x8a,0x8f,0xfa,0x8f,
+0xf8,0x08,0xf0,0x10,0xfe,0xc4,0x28,0xd4,0x32,0xd0,0x28,0xbe,0xaa,0xbe,0x8a,0xbe,
+/* 18714 0x491a "䤚" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x3c,0x25,0x24,0x24,0x44,0x57,0x88,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 18715 0x491b "䤛" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0x94,0xe4,0x84,0x04,0x04,0x04,0x04,
+/* 18716 0x491c "䤜" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x13,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0x3c,0xe0,0x20,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 18717 0x491d "䤝" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x00,0x40,0x9e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x5a,0x94,0x10,0x10,0x10,0x10,
+/* 18718 0x491e "䤞" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe1,0x42,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 18719 0x491f "䤟" */
+0x10,0x10,0x29,0x25,0x43,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x41,
+0x00,0x00,0xfe,0x02,0x02,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 18720 0x4920 "䤠" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x10,0x10,0x10,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 18721 0x4921 "䤡" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x97,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 18722 0x4922 "䤢" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1d,0xe2,0x44,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 18723 0x4923 "䤣" */
+0x10,0x10,0x29,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 18724 0x4924 "䤤" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x59,0x50,0x1e,0xf0,0x41,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 18725 0x4925 "䤥" */
+0x10,0x10,0x28,0x25,0x42,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 18726 0x4926 "䤦" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0xa8,0xa4,0xa4,0x20,0x2e,0xf0,0x20,0x24,0x24,0x24,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 18727 0x4927 "䤧" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x40,
+0x00,0x00,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,0x00,
+/* 18728 0x4928 "䤨" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x04,0x1e,0xe0,0x00,0x06,0x78,0x50,0x50,0x52,0x54,0x48,0x48,0x44,0x54,0x62,0x40,
+/* 18729 0x4929 "䤩" */
+0x10,0x10,0x29,0x25,0x40,0xb8,0x10,0x10,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x10,0xfe,0x02,0x00,0x1c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x1e,0x00,
+/* 18730 0x492a "䤪" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x11,0x12,0xfd,0x10,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x26,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 18731 0x492b "䤫" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x10,0x10,0xfd,0x12,0x94,0x59,0x50,0x1c,0xe0,0x40,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x10,0x10,0x20,
+/* 18732 0x492c "䤬" */
+0x20,0x22,0x51,0x49,0x84,0x7a,0x22,0x20,0xf8,0x21,0x2e,0xb2,0x62,0x3a,0xe2,0x00,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 18733 0x492d "䤭" */
+0x21,0x20,0x50,0x48,0x83,0x78,0x23,0x20,0xf9,0x23,0x2d,0xb1,0x61,0x39,0xe0,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 18734 0x492e "䤮" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x94,0x59,0x52,0x1c,0xe0,0x43,
+0x10,0x10,0x90,0x9e,0x90,0x90,0xfe,0x00,0x10,0x92,0x92,0x14,0x08,0x10,0x60,0x80,
+/* 18735 0x492f "䤯" */
+0x10,0x13,0x29,0x25,0x41,0xb9,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x02,0xe2,0x44,0x48,0x40,0x42,0x42,0xe4,0x48,0x40,0x42,0x42,0x44,0x44,0x48,0x50,
+/* 18736 0x4930 "䤰" */
+0x10,0x10,0x7d,0x12,0x10,0x1c,0xe1,0x06,0x18,0xef,0x01,0x3f,0x09,0x05,0xff,0x00,
+0x80,0x80,0xfc,0x44,0x48,0xa0,0x10,0xc8,0x30,0xee,0x00,0xf8,0x20,0x40,0xfe,0x00,
+/* 18737 0x4931 "䤱" */
+0x10,0x11,0x29,0x25,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x24,0x24,0xfc,0x00,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 18738 0x4932 "䤲" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x13,0x10,0xfc,0x11,0x95,0x5a,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x48,0x48,0x4c,0x4a,0x4a,0x88,0x88,0x28,0x10,
+/* 18739 0x4933 "䤳" */
+0x20,0x20,0x57,0x49,0x81,0x7a,0x22,0x26,0xfa,0x23,0x2a,0xb2,0x62,0x3a,0xe2,0x03,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 18740 0x4934 "䤴" */
+0x20,0x21,0x50,0x48,0x82,0x7a,0x22,0x22,0xfa,0x22,0x2b,0xb2,0x62,0x3a,0xe3,0x00,
+0x00,0xfc,0x08,0x10,0x22,0xaa,0x72,0x22,0x72,0xaa,0x26,0xa2,0x42,0x02,0xfe,0x02,
+/* 18741 0x4935 "䤵" */
+0x10,0x10,0x28,0x27,0x40,0xb8,0x10,0x13,0xfc,0x10,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 18742 0x4936 "䤶" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x12,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 18743 0x4937 "䤷" */
+0x20,0x23,0x52,0x4a,0x82,0x7a,0x22,0x22,0xfa,0x23,0x2a,0xb2,0x62,0x3a,0xe2,0x03,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 18744 0x4938 "䤸" */
+0x20,0x20,0x51,0x49,0x80,0x7b,0x20,0x20,0xfb,0x20,0x28,0xb3,0x60,0x38,0xe3,0x00,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 18745 0x4939 "䤹" */
+0x10,0x10,0x2b,0x26,0x40,0xb9,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x43,
+0x40,0x20,0xfe,0x22,0xa4,0x28,0x50,0x88,0x04,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 18746 0x493a "䤺" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x00,0x02,0xdc,0x90,0x90,0x10,0xde,0x54,0x54,0x54,0x54,0xd4,0x54,0x24,0x24,0x44,
+/* 18747 0x493b "䤻" */
+0x10,0x10,0x2b,0x24,0x41,0xba,0x15,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 18748 0x493c "䤼" */
+0x20,0x20,0x51,0x49,0x81,0x79,0x21,0x20,0xf8,0x23,0x28,0xb1,0x61,0x3a,0xe4,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 18749 0x493d "䤽" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x10,0xfc,0x11,0x94,0x58,0x50,0x1d,0xe0,0x40,
+0x00,0xfc,0x54,0x54,0x54,0xfc,0x20,0xa8,0xa4,0x24,0x20,0xa8,0xa4,0x24,0x20,0x20,
+/* 18750 0x493e "䤾" */
+0x10,0x11,0x28,0x25,0x40,0xb8,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 18751 0x493f "䤿" */
+0x10,0x13,0x28,0x25,0x40,0xbb,0x10,0x10,0xfc,0x10,0x95,0x58,0x53,0x1c,0xe0,0x40,
+0x80,0xde,0x8a,0xca,0x8a,0xd2,0xa6,0x08,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 18752 0x4940 "䥀" */
+0x10,0x11,0x29,0x25,0x40,0xbb,0x10,0x10,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe3,0x41,
+0x20,0x24,0x24,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 18753 0x4941 "䥁" */
+0x20,0x23,0x50,0x48,0x80,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb3,0x62,0x3a,0xe3,0x02,
+0x00,0xfc,0x08,0xd0,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 18754 0x4942 "䥂" */
+0x20,0x23,0x52,0x4c,0x80,0x79,0x20,0x20,0xfb,0x20,0x28,0xb3,0x60,0x38,0xe3,0x00,
+0x00,0xfe,0x02,0xfc,0x00,0xfc,0x40,0xa4,0x38,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 18755 0x4943 "䥃" */
+0x10,0x10,0x2b,0x26,0x40,0xb9,0x13,0x15,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x40,0x40,0xfe,0x92,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 18756 0x4944 "䥄" */
+0x20,0x23,0x52,0x4a,0x82,0x7a,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x04,
+0x00,0xfe,0x00,0x48,0x48,0xfc,0x48,0x48,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 18757 0x4945 "䥅" */
+0x01,0x7f,0x01,0x7d,0x11,0x7d,0x11,0x1c,0xe1,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x00,0xfc,0x00,0x7c,0x10,0x7c,0x10,0xfe,0x00,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18758 0x4946 "䥆" */
+0x01,0xff,0x04,0x7c,0x04,0x3c,0x04,0x7d,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x00,0xfe,0x40,0x7c,0x40,0x78,0x40,0x7c,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 18759 0x4947 "䥇" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x66,
+/* 18760 0x4948 "䥈" */
+0x20,0x20,0x53,0x48,0x80,0x7b,0x20,0x20,0xf9,0x22,0x28,0xb3,0x60,0x38,0xe1,0x02,
+0x88,0x88,0xfe,0x88,0x24,0xfe,0x50,0x88,0x04,0x8a,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 18761 0x4949 "䥉" */
+0x10,0x13,0x2a,0x24,0x40,0xb9,0x12,0x11,0xfd,0x11,0x95,0x58,0x50,0x1c,0xe1,0x42,
+0x00,0xfe,0x02,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x50,0x58,0x96,0x12,0x0e,
+/* 18762 0x494a "䥊" */
+0x10,0x13,0x28,0x25,0x40,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 18763 0x494b "䥋" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0x50,0x20,0x00,0x54,0x52,
+/* 18764 0x494c "䥌" */
+0x02,0x01,0x7f,0x40,0x3c,0x24,0x3c,0x24,0x3d,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x00,0x00,0xfc,0x04,0x78,0x48,0x78,0x48,0x78,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18765 0x494d "䥍" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x09,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18766 0x494e "䥎" */
+0x23,0x22,0x52,0x4a,0x83,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3c,0xe4,0x08,
+0xfe,0x00,0xfc,0x00,0xfe,0x94,0xa8,0xc4,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,
+/* 18767 0x494f "䥏" */
+0x22,0x22,0x54,0x49,0x80,0x72,0x25,0x2c,0xf4,0x25,0xa5,0x75,0x25,0x37,0xc4,0x04,
+0x80,0x8e,0xea,0x4a,0x4a,0x4a,0xea,0x4a,0x4a,0x6a,0x4a,0x4e,0x68,0x88,0x08,0x08,
+/* 18768 0x4950 "䥐" */
+0x00,0x7e,0x14,0x08,0xfe,0x2a,0x48,0xa8,0x11,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x20,0x7c,0xc4,0x38,0xc6,0x20,0xfc,0x44,0x8c,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18769 0x4951 "䥑" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x12,0x10,0xfc,0x11,0x94,0x58,0x51,0x1c,0xe0,0x41,
+0x20,0x20,0xfe,0xa8,0xa8,0x74,0x22,0x70,0xa8,0x46,0x78,0x88,0x50,0x20,0x50,0x80,
+/* 18770 0x4952 "䥒" */
+0x7c,0x04,0x04,0x7c,0x41,0x7d,0x05,0x04,0x2b,0x16,0x18,0xef,0x01,0x3f,0x09,0xff,
+0xf8,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x28,0xfc,0xc4,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18771 0x4953 "䥓" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x10,0xfd,0x10,0x95,0x5a,0x50,0x1c,0xe1,0x40,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x24,0xfa,0x20,0x20,0xfe,0x00,
+/* 18772 0x4954 "䥔" */
+0x20,0x23,0x50,0x48,0x83,0x7a,0x22,0x23,0xf9,0x20,0x2b,0xb0,0x60,0x39,0xe6,0x00,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 18773 0x4955 "䥕" */
+0x21,0x21,0x55,0x4b,0x81,0x77,0x25,0x25,0xf5,0x27,0xa5,0x75,0x25,0x35,0xc4,0x04,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 18774 0x4956 "䥖" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe1,0x42,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 18775 0x4957 "䥗" */
+0x21,0x21,0x57,0x49,0x81,0x7b,0x20,0x23,0xf8,0x27,0x29,0xb1,0x65,0x39,0xe1,0x03,
+0x08,0x08,0xc8,0x08,0x1e,0x92,0x24,0x80,0x08,0xc8,0x08,0x08,0x94,0x54,0x24,0x42,
+/* 18776 0x4958 "䥘" */
+0x10,0x10,0x29,0x26,0x40,0xb8,0x11,0x12,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x88,0x88,0x54,0x22,0x88,0x88,0x54,0x22,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 18777 0x4959 "䥙" */
+0x20,0x27,0x55,0x4d,0x85,0x76,0x25,0x25,0xf5,0x25,0xa5,0x76,0x24,0x34,0xc4,0x04,
+0x44,0x24,0x28,0x7e,0x10,0x30,0x4a,0x1a,0x2c,0x4c,0x1a,0x2a,0x48,0x08,0x28,0x10,
+/* 18778 0x495a "䥚" */
+0x3f,0x20,0x2e,0x2a,0x2e,0x2a,0x2e,0x2a,0x2f,0x22,0x24,0x3b,0x21,0x4f,0x45,0x9f,
+0xf8,0x08,0xe8,0xa8,0xe8,0xa8,0xe8,0xa8,0xe8,0x88,0x48,0xb8,0x0a,0xea,0x46,0xf2,
+/* 18779 0x495b "䥛" */
+0x10,0x13,0x28,0x25,0x40,0xbb,0x10,0x10,0xfc,0x11,0x94,0x5b,0x50,0x1d,0xe2,0x40,
+0x80,0xde,0x8a,0xca,0x8a,0xd2,0xa6,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 18780 0x495c "䥜" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x63,0x3a,0xe2,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x22,0x22,0xfa,0x22,0x72,0xaa,0x26,0x22,0x2a,0x04,
+/* 18781 0x495d "䥝" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3c,0xe4,0x08,
+0x20,0xfe,0x50,0xfe,0x52,0xfe,0x94,0xd8,0x92,0xce,0x00,0x84,0x98,0xe2,0x82,0x7e,
+/* 18782 0x495e "䥞" */
+0x21,0x22,0x27,0x54,0x8f,0x74,0x27,0x22,0xf9,0x27,0x2a,0xb3,0x62,0x3c,0xe5,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 18783 0x495f "䥟" */
+0x22,0x22,0x52,0x4a,0x87,0x7a,0x22,0x23,0xfa,0x26,0x2a,0xb2,0x62,0x3a,0xe2,0x06,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x7e,0x92,0x52,0x6a,0x42,0x7a,0x02,0x14,0x08,
+/* 18784 0x4960 "䥠" */
+0x20,0x20,0x53,0x48,0x80,0x78,0x23,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x04,
+0x88,0x88,0xfe,0x88,0x14,0x12,0xfe,0x10,0xf4,0x14,0xf4,0xa8,0xaa,0xfa,0x16,0x22,
+/* 18785 0x4961 "䥡" */
+0x21,0x25,0x55,0x4d,0x85,0x77,0x24,0x24,0xf7,0x25,0xa5,0x75,0x25,0x35,0xc5,0x09,
+0x14,0x54,0x54,0xfe,0x54,0xd4,0x5c,0x40,0x7e,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,
+/* 18786 0x4962 "䥢" */
+0x08,0xff,0x08,0x7f,0x41,0x7f,0x22,0x1f,0xe1,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x10,0x7e,0x10,0x7c,0x04,0x28,0x10,0x28,0x44,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18787 0x4963 "䥣" */
+0x2c,0x44,0x6c,0x44,0x7d,0x00,0x7c,0x10,0xfd,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18788 0x4964 "䥤" */
+0x11,0x10,0x2b,0x26,0x41,0xb8,0x11,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x40,0xfc,0x04,0xf4,0x94,0xf4,0x8a,0x82,0x7e,
+/* 18789 0x4965 "䥥" */
+0x20,0x23,0x50,0x48,0x83,0x7a,0x23,0x22,0xfb,0x22,0x2b,0xb2,0x62,0x3d,0xe6,0x08,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 18790 0x4966 "䥦" */
+0x20,0x21,0x54,0x4a,0x81,0x7a,0x20,0x26,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe5,0x08,
+0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,0x00,0xfe,
+/* 18791 0x4967 "䥧" */
+0x20,0x20,0x50,0x4b,0x82,0x79,0x20,0x21,0xfa,0x21,0x2a,0xb0,0x60,0x38,0xe0,0x00,
+0x40,0x7c,0x40,0xfe,0x02,0xfc,0xa8,0x54,0x88,0xfc,0x8a,0xf8,0x88,0xf8,0x88,0xf8,
+/* 18792 0x4968 "䥨" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x02,0xfa,0x8a,0xfa,0x02,0x06,
+/* 18793 0x4969 "䥩" */
+0x22,0x22,0x56,0x4b,0x80,0x72,0x25,0x2c,0xf4,0x25,0xa5,0x75,0x25,0x35,0xc6,0x04,
+0x88,0xa8,0xa8,0xf0,0x1e,0x24,0xd4,0x14,0x14,0xd4,0x54,0x48,0x68,0x54,0x14,0x22,
+/* 18794 0x496a "䥪" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x21,0x22,0xfb,0x21,0x2a,0xb3,0x60,0x3a,0xe2,0x04,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 18795 0x496b "䥫" */
+0x21,0x21,0x57,0x49,0x8f,0x72,0x24,0x2f,0xf4,0x27,0xa4,0x77,0x24,0x37,0xc4,0x00,
+0x10,0x14,0xd2,0x10,0xfe,0x90,0x50,0xf4,0x94,0xf4,0x94,0xe8,0x8a,0xfa,0x26,0x42,
+/* 18796 0x496c "䥬" */
+0x10,0x13,0x28,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x50,0x1d,0xe0,0x40,
+0x88,0xfe,0x88,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x58,
+/* 18797 0x496d "䥭" */
+0x14,0x10,0xfe,0x10,0x54,0x38,0x54,0x92,0x31,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x14,0x10,0xfe,0x10,0x54,0x38,0x54,0x92,0x30,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18798 0x496e "䥮" */
+0x20,0x23,0x50,0x4b,0x82,0x7b,0x20,0x23,0xfa,0x23,0x2a,0xb3,0x62,0x3a,0xe3,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xde,0x92,0xd2,0x52,0xd2,0x9a,0x94,0xd0,0x10,
+/* 18799 0x496f "䥯" */
+0x20,0x23,0x52,0x4a,0x83,0x79,0x22,0x23,0xf8,0x23,0x2a,0xb3,0x62,0x3b,0xe2,0x02,
+0x00,0xfc,0x94,0x94,0xfc,0x10,0x52,0xdc,0x12,0xce,0x40,0xd2,0x5c,0xd0,0x52,0xce,
+/* 18800 0x4970 "䥰" */
+0x20,0x20,0x57,0x49,0x81,0x79,0x20,0x20,0xfb,0x22,0x2a,0xb3,0x60,0x38,0xe3,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x88,0xfe,0xaa,0xaa,0xfe,0x88,0xaa,0xfe,0x22,
+/* 18801 0x4971 "䥱" */
+0x20,0x23,0x52,0x48,0x81,0x79,0x21,0x21,0xf9,0x21,0x2b,0xb4,0x62,0x3a,0xe4,0x00,
+0x20,0xfe,0x02,0x40,0x9c,0x04,0xdc,0x04,0xfc,0x00,0xfe,0x02,0xaa,0xaa,0x14,0x08,
+/* 18802 0x4972 "䥲" */
+0x20,0x27,0x54,0x4d,0x85,0x75,0x25,0x24,0xf7,0x26,0xa6,0x77,0x24,0x37,0xc0,0x00,
+0x08,0xe8,0x08,0xc8,0x5e,0x52,0xe4,0x00,0xe8,0xa8,0xa8,0xe8,0x14,0xf4,0x24,0x42,
+/* 18803 0x4973 "䥳" */
+0x23,0x20,0x51,0x49,0x81,0x79,0x27,0x24,0xfa,0x22,0x2c,0xb0,0x61,0x3a,0xe0,0x03,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 18804 0x4974 "䥴" */
+0x20,0x22,0x53,0x48,0x81,0x7b,0x25,0x21,0xf9,0x21,0x29,0xb1,0x63,0x3a,0xe2,0x02,
+0x20,0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xde,0x52,0x72,0x06,
+/* 18805 0x4975 "䥵" */
+0x20,0x20,0x57,0x4d,0x85,0x75,0x25,0x27,0xf5,0x25,0xa5,0x75,0x27,0x35,0xc0,0x00,
+0x10,0x10,0x7e,0x10,0xfe,0x44,0xee,0x44,0x64,0xde,0x00,0xfe,0x28,0x2a,0x4a,0x86,
+/* 18806 0x4976 "䥶" */
+0x20,0x23,0x52,0x4a,0x82,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x05,
+0x00,0xfe,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x44,0x10,0x10,0x5e,0x50,0x50,0xfe,
+/* 18807 0x4977 "䥷" */
+0x24,0x27,0x2a,0x51,0x8b,0x72,0x23,0x22,0xfb,0x22,0x2b,0xb1,0x67,0x39,0xe2,0x04,
+0x42,0x72,0xa2,0x1a,0xea,0x2a,0xea,0x2a,0xea,0x2a,0xea,0x4a,0xf2,0x42,0x4a,0x44,
+/* 18808 0x4978 "䥸" */
+0xf7,0x12,0x17,0xfc,0x86,0xf5,0x16,0x15,0x57,0x26,0x18,0xef,0x01,0x3f,0x09,0xff,
+0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0xc4,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 18809 0x4979 "䥹" */
+0x20,0x23,0x50,0x49,0x80,0x7b,0x20,0x20,0xfb,0x20,0x2a,0xb3,0x62,0x3a,0xe3,0x00,
+0x80,0xde,0x8a,0xd2,0xa6,0xd0,0x9c,0x50,0xfe,0x50,0xaa,0xfe,0x52,0xaa,0xfe,0x02,
+/* 18810 0x497a "䥺" */
+0x20,0x23,0x38,0x21,0x41,0x79,0xa2,0x23,0xf8,0x20,0x20,0x21,0x2a,0x34,0x20,0x00,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 18811 0x497b "䥻" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x13,0xfc,0x10,0x10,0x10,0x14,0x19,0x12,0x04,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 18812 0x497c "䥼" */
+0x10,0x10,0x3c,0x20,0x41,0xbe,0x10,0x10,0xfc,0x11,0x12,0x10,0x14,0x18,0x11,0x00,
+0x80,0x80,0x80,0xfc,0x54,0x54,0x54,0x94,0x94,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 18813 0x497d "䥽" */
+0x20,0x20,0x3a,0x22,0x43,0x78,0xa0,0x20,0xf9,0x21,0x21,0x22,0x2a,0x34,0x28,0x03,
+0x40,0x48,0x44,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 18814 0x497e "䥾" */
+0x20,0x23,0x3a,0x24,0x40,0x78,0xa0,0x21,0xf9,0x20,0x20,0x23,0x28,0x30,0x20,0x00,
+0x00,0xfe,0x02,0x84,0x80,0xfc,0x80,0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 18815 0x497f "䥿" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+/* 18816 0x4980 "䦀" */
+0x20,0x27,0x38,0x20,0x44,0x7a,0xa2,0x20,0xf9,0x22,0x24,0x20,0x28,0x30,0x22,0x01,
+0x00,0xbc,0x84,0x84,0xa4,0x94,0x94,0x84,0x8c,0x94,0xa4,0x84,0x84,0x84,0x94,0x08,
+/* 18817 0x4981 "䦁" */
+0x21,0x21,0x39,0x27,0x41,0x79,0xa7,0x21,0xf9,0x27,0x21,0x21,0x29,0x32,0x22,0x04,
+0x00,0x1e,0x12,0xd2,0x14,0x14,0xd8,0x14,0x12,0xd2,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 18818 0x4982 "䦂" */
+0x20,0x20,0x3b,0x22,0x42,0x7b,0xa2,0x23,0xfa,0x23,0x22,0x22,0x2a,0x35,0x24,0x08,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0xdc,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0xcc,
+/* 18819 0x4983 "䦃" */
+0x20,0x20,0x3b,0x20,0x40,0x79,0xa0,0x20,0xfb,0x20,0x20,0x21,0x2a,0x34,0x20,0x00,
+0x88,0x88,0xfe,0xa8,0x22,0xfa,0x24,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 18820 0x4984 "䦄" */
+0x10,0x13,0x3c,0x21,0x41,0xbd,0x11,0x11,0xfc,0x13,0x10,0x10,0x15,0x1a,0x14,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x50,0x94,0x88,0xa8,0xc4,0x82,
+/* 18821 0x4985 "䦅" */
+0x20,0x20,0x3b,0x20,0x41,0x78,0xa3,0x21,0xf8,0x23,0x20,0x21,0x29,0x31,0x21,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 18822 0x4986 "䦆" */
+0x23,0x22,0x3b,0x22,0x43,0x78,0xa1,0x23,0xfd,0x21,0x21,0x20,0x29,0x30,0x20,0x07,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 18823 0x4987 "䦇" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x3d,0x22,0x20,0xfe,0x10,0x20,0x44,0xfe,0x02,0x00,
+0x10,0x50,0x50,0x48,0x88,0xa4,0x24,0x42,0x40,0x80,0xf8,0x08,0x08,0x08,0x50,0x20,
+/* 18824 0x4988 "䦈" */
+0x00,0x3e,0x20,0x20,0x3d,0x20,0x3c,0x20,0x20,0xfe,0x10,0x21,0x45,0xfe,0x02,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x90,0x90,0x10,0x10,0x10,0xfe,0x00,
+/* 18825 0x4989 "䦉" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x3c,0x20,0x20,0xfe,0x10,0x20,0x44,0xfe,0x02,0x00,
+0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0x82,0xfe,0x82,0x00,
+/* 18826 0x498a "䦊" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x3d,0x20,0x20,0xfe,0x10,0x20,0x45,0xfe,0x02,0x00,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 18827 0x498b "䦋" */
+0x00,0x3c,0x20,0x3b,0x20,0x3b,0x20,0x27,0xf9,0x21,0x21,0x49,0xf9,0x4a,0x02,0x04,
+0x88,0x88,0x88,0xd0,0x9e,0xe4,0x94,0xd4,0x14,0xd4,0x54,0x48,0x48,0x54,0xd4,0x22,
+/* 18828 0x498c "䦌" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x4f,0x41,0x41,0x41,0x5f,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 18829 0x498d "䦍" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x44,0x47,0x48,0x57,0x41,0x42,0x44,0x44,0x43,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0xc4,0x84,0x04,0x14,0x14,0xf4,0x0c,
+/* 18830 0x498e "䦎" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x40,0x5f,0x45,0x45,0x45,0x49,0x50,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x04,0xe4,0x04,0x04,0x04,0x24,0xe4,0x14,0x08,
+/* 18831 0x498f "䦏" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x41,0x42,0x44,0x58,0x44,0x44,0x44,0x48,0x50,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x84,0x64,0x1c,0x44,0x44,0x44,0x44,0x54,0x08,
+/* 18832 0x4990 "䦐" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x5f,0x41,0x5f,0x41,0x7f,0x41,0x45,0x42,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0x04,0xe4,0x04,0xfc,0x04,0x14,0x08,
+/* 18833 0x4991 "䦑" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x42,0x4f,0x42,0x42,0x5f,0x42,0x45,0x44,0x48,0x50,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xc4,0x44,0x44,0xf4,0x04,0x04,0x84,0x54,0x08,
+/* 18834 0x4992 "䦒" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x41,0x42,0x47,0x4c,0x54,0x44,0x47,0x44,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0x04,0xc4,0x44,0x44,0x44,0xc4,0x54,0x08,
+/* 18835 0x4993 "䦓" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x41,0x41,0x41,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 18836 0x4994 "䦔" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x5f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x04,0x0c,
+/* 18837 0x4995 "䦕" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x48,0x44,0x5f,0x44,0x44,0x7f,0x44,0x48,0x48,0x50,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x24,0x44,0xf4,0x44,0x44,0xfc,0x44,0x44,0x44,0x4c,
+/* 18838 0x4996 "䦖" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x5f,0x41,0x4f,0x40,0x4f,0x48,0x4f,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0xe4,0x04,0xe4,0x24,0xe4,0x24,0x0c,
+/* 18839 0x4997 "䦗" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x42,0x4f,0x4a,0x4a,0x4a,0x4a,0x5f,0x40,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0xa4,0xa4,0xa4,0xa4,0xf4,0x04,0x14,0x08,
+/* 18840 0x4998 "䦘" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x49,0x48,0x4a,0x4c,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x24,0x1c,
+/* 18841 0x4999 "䦙" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x5f,0x41,0x7f,0x40,0x5f,0x48,0x44,0x41,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0xfc,0x44,0xf4,0x44,0x44,0x54,0x88,
+/* 18842 0x499a "䦚" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x4f,0x41,0x5f,0x41,0x4f,0x48,0x4f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x14,0x08,
+/* 18843 0x499b "䦛" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x47,0x48,0x5f,0x41,0x5f,0x41,0x4f,0x41,0x43,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x84,0xe4,0x24,0xf4,0x24,0xe4,0x04,0x04,0x0c,
+/* 18844 0x499c "䦜" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x4f,0x44,0x7f,0x40,0x4f,0x48,0x4f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x24,0xfc,0x04,0xe4,0x24,0xf4,0x08,
+/* 18845 0x499d "䦝" */
+0x7c,0x44,0x7c,0x44,0x7d,0x41,0x4f,0x41,0x5f,0x42,0x4a,0x4a,0x54,0x44,0x49,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0xf4,0x84,0xa4,0x94,0x94,0x84,0x94,0x08,
+/* 18846 0x499e "䦞" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x49,0x44,0x50,0x49,0x44,0x48,0x58,0x4b,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x44,0x44,0xf4,0x44,0x44,0x44,0xfc,0x04,0x0c,
+/* 18847 0x499f "䦟" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x49,0x49,0x55,0x41,0x4f,0x41,0x41,0x5f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x24,0x24,0x54,0x04,0xe4,0x04,0x04,0xf4,0x04,0x0c,
+/* 18848 0x49a0 "䦠" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x45,0x59,0x4a,0x45,0x5a,0x44,0x5a,0x41,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0x14,0xa4,0xc4,0xa4,0x94,0x94,0x84,0x0c,
+/* 18849 0x49a1 "䦡" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x5f,0x50,0x47,0x44,0x47,0x44,0x47,0x44,0x47,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x14,0xc4,0x44,0xc4,0x04,0xe4,0x24,0xe4,0x0c,
+/* 18850 0x49a2 "䦢" */
+0x7c,0x44,0x7c,0x44,0x7c,0x50,0x48,0x63,0x50,0x48,0x57,0x71,0x52,0x57,0x50,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x84,0x84,0xe4,0x84,0x84,0xf4,0x04,0x24,0xf4,0x14,0x0c,
+/* 18851 0x49a3 "䦣" */
+0x7c,0x44,0x7c,0x44,0x7e,0x41,0x5f,0x48,0x44,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x24,0x44,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x0c,
+/* 18852 0x49a4 "䦤" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4e,0x4a,0x44,0x4a,0x51,0x4e,0x4a,0x44,0x4a,0x51,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0xa4,0x44,0xa4,0x04,0xe4,0xa4,0x44,0xa4,0x0c,
+/* 18853 0x49a5 "䦥" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x44,0x44,0x5e,0x44,0x4e,0x55,0x64,0x44,0x44,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x44,0xf4,0x44,0xe4,0x54,0x4c,0x44,0x54,0x08,
+/* 18854 0x49a6 "䦦" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x42,0x4c,0x77,0x41,0x5f,0x49,0x45,0x7f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x84,0x64,0xdc,0x04,0xf4,0x24,0x44,0xfc,0x04,0x0c,
+/* 18855 0x49a7 "䦧" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x42,0x4c,0x48,0x4e,0x48,0x4f,0x42,0x44,0x58,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x84,0x94,0x74,0x0c,
+/* 18856 0x49a8 "䦨" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x5f,0x41,0x4f,0x49,0x4f,0x49,0x4f,0x45,0x49,0x41,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x44,0x24,0x0c,
+/* 18857 0x49a9 "䦩" */
+0x7c,0x44,0x7c,0x44,0x7f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x44,0x4f,0x54,0x43,0x5c,
+0x7c,0x44,0x7c,0x44,0xfc,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xc4,0x44,0x94,0x68,
+/* 18858 0x49aa "䦪" */
+0x7c,0x44,0x7c,0x44,0x7f,0x48,0x4f,0x48,0x4f,0x44,0x4f,0x59,0x6a,0x4f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0xfc,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x14,0x94,0xd4,0x54,0x2c,
+/* 18859 0x49ab "䦫" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x44,0x5f,0x44,0x41,0x4f,0x49,0x5f,0x42,0x44,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0xf4,0x44,0x04,0xe4,0x24,0xf4,0x84,0x44,0x2c,
+/* 18860 0x49ac "䦬" */
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x5e,0x44,0x4e,0x44,0x5e,0x45,0x5f,0x42,0x44,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x54,0x54,0x54,0xb4,0x04,0xf4,0x84,0x44,0x2c,
+/* 18861 0x49ad "䦭" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x41,0x5f,0x45,0x49,0x57,0x44,0x47,0x44,0x47,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x04,0x04,0xf4,0x44,0x24,0xd4,0x44,0xc4,0x54,0xc8,
+/* 18862 0x49ae "䦮" */
+0x7c,0x44,0x7c,0x44,0x7d,0x4f,0x41,0x4f,0x42,0x5f,0x44,0x4f,0x54,0x67,0x44,0x47,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x04,0xe4,0x04,0xf4,0x44,0xe4,0x5c,0xc4,0x44,0xcc,
+/* 18863 0x49af "䦯" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7f,0x48,0x52,0x5f,0x44,0x5f,0x44,0x47,0x7c,0x51,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x44,0x7c,0x94,0x54,0x54,0x24,0x54,0x94,0x0c,
+/* 18864 0x49b0 "䦰" */
+0x78,0x48,0x7a,0x4b,0x7c,0x4f,0x55,0x47,0x45,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x40,
+0x3c,0x24,0x3c,0xa4,0xbc,0xc4,0x44,0xc4,0x44,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xf4,
+/* 18865 0x49b1 "䦱" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x5e,0x45,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x55,0x65,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x24,0x44,0x84,0x84,0xc4,0x44,0xe4,0x24,0x24,0x6c,
+/* 18866 0x49b2 "䦲" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x47,0x48,0x5f,0x6a,0x4c,0x4f,0x48,0x4b,0x4a,0x53,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x44,0xf4,0x24,0x94,0xf4,0x04,0xe4,0x24,0xec,
+/* 18867 0x49b3 "䦳" */
+0x7c,0x44,0x7c,0x44,0x7c,0x52,0x57,0x6d,0x77,0x55,0x6f,0x7c,0x56,0x55,0x66,0x44,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x74,0x54,0x54,0x64,0x54,0x54,0x54,0x64,0xc4,0x4c,
+/* 18868 0x49b4 "䦴" */
+0x7c,0x44,0x7c,0x44,0x7f,0x4a,0x4f,0x41,0x4f,0x41,0x5f,0x44,0x4f,0x41,0x5f,0x41,
+0x7c,0x44,0x7c,0x44,0xfc,0xa4,0xe4,0x04,0xe4,0x04,0xf4,0x44,0xe4,0x04,0xf4,0x0c,
+/* 18869 0x49b5 "䦵" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x49,0x5f,0x71,0x5b,0x55,0x5b,0x55,0x5b,0x51,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x24,0xf4,0x1c,0xb4,0x54,0xb4,0x54,0xb4,0x1c,
+/* 18870 0x49b6 "䦶" */
+0x20,0x13,0x10,0x42,0x47,0x48,0x50,0x4f,0x41,0x5f,0x41,0x4f,0x41,0x45,0x42,0x40,
+0x00,0xfc,0x04,0x04,0xc4,0x44,0x84,0xe4,0x24,0xf4,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 18871 0x49b7 "䦷" */
+0x20,0x13,0x10,0x40,0x41,0x49,0x49,0x55,0x41,0x4f,0x41,0x41,0x5f,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x24,0x24,0x54,0x04,0xe4,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 18872 0x49b8 "䦸" */
+0x20,0x17,0x00,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x5f,0x51,0x51,0x57,0x50,0x50,0x40,
+0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x14,0x54,0xd4,0x54,0x34,0x0c,
+/* 18873 0x49b9 "䦹" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x4b,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 18874 0x49ba "䦺" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 18875 0x49bb "䦻" */
+0x00,0x7d,0x44,0x48,0x48,0x50,0x48,0x4b,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 18876 0x49bc "䦼" */
+0x00,0x7c,0x44,0x4b,0x48,0x50,0x48,0x48,0x47,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 18877 0x49bd "䦽" */
+0x00,0x7d,0x44,0x48,0x48,0x50,0x4b,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 18878 0x49be "䦾" */
+0x10,0x10,0x20,0x7c,0x45,0x47,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 18879 0x49bf "䦿" */
+0x00,0x7c,0x44,0x48,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x68,0x50,0x40,0x40,0x40,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 18880 0x49c0 "䧀" */
+0x00,0x7c,0x44,0x48,0x4b,0x50,0x48,0x48,0x44,0x45,0x45,0x6a,0x52,0x44,0x41,0x40,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 18881 0x49c1 "䧁" */
+0x00,0x7c,0x45,0x49,0x4a,0x54,0x49,0x49,0x45,0x45,0x45,0x69,0x50,0x40,0x40,0x40,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 18882 0x49c2 "䧂" */
+0x00,0x7d,0x44,0x48,0x48,0x50,0x48,0x48,0x45,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 18883 0x49c3 "䧃" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 18884 0x49c4 "䧄" */
+0x00,0x7c,0x44,0x49,0x4b,0x54,0x48,0x48,0x45,0x46,0x45,0x69,0x51,0x41,0x41,0x41,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 18885 0x49c5 "䧅" */
+0x00,0x78,0x4b,0x48,0x53,0x50,0x63,0x52,0x4b,0x48,0x48,0x68,0x50,0x41,0x42,0x44,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xa8,0xa0,0x10,0x08,0x06,
+/* 18886 0x49c6 "䧆" */
+0x00,0x7c,0x44,0x48,0x4b,0x50,0x48,0x48,0x44,0x47,0x44,0x68,0x50,0x41,0x41,0x42,
+0x90,0x90,0x90,0x90,0xfc,0x90,0x90,0x90,0x90,0xfe,0x00,0x90,0x88,0x08,0x04,0x04,
+/* 18887 0x49c7 "䧇" */
+0x00,0x78,0x48,0x4b,0x50,0x50,0x60,0x50,0x49,0x4a,0x4c,0x68,0x50,0x40,0x40,0x40,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 18888 0x49c8 "䧈" */
+0x00,0x7b,0x48,0x50,0x50,0x63,0x52,0x4a,0x4a,0x4a,0x6a,0x52,0x42,0x43,0x42,0x40,
+0x00,0xfe,0x50,0x50,0x50,0xfe,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0xfe,0x02,0x00,
+/* 18889 0x49c9 "䧉" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x44,0x44,0x45,0x68,0x50,0x40,0x43,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 18890 0x49ca "䧊" */
+0x00,0x7d,0x45,0x49,0x49,0x52,0x48,0x4b,0x44,0x44,0x45,0x69,0x51,0x41,0x41,0x41,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 18891 0x49cb "䧋" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x68,0x50,0x40,0x41,0x42,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 18892 0x49cc "䧌" */
+0x00,0x78,0x4b,0x50,0x52,0x61,0x51,0x48,0x4b,0x48,0x69,0x53,0x40,0x40,0x41,0x46,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 18893 0x49cd "䧍" */
+0x00,0x7c,0x45,0x4a,0x48,0x50,0x48,0x49,0x46,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x88,0x84,0x02,0x22,0x20,0x50,0x88,0x04,0x02,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 18894 0x49ce "䧎" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 18895 0x49cf "䧏" */
+0x00,0x7c,0x44,0x48,0x49,0x50,0x48,0x4b,0x44,0x44,0x44,0x68,0x53,0x40,0x40,0x40,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 18896 0x49d0 "䧐" */
+0x00,0x7c,0x47,0x48,0x49,0x51,0x49,0x48,0x45,0x44,0x44,0x6b,0x50,0x40,0x40,0x40,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 18897 0x49d1 "䧑" */
+0x00,0x78,0x4b,0x52,0x54,0x60,0x53,0x48,0x48,0x49,0x69,0x51,0x42,0x42,0x44,0x48,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 18898 0x49d2 "䧒" */
+0x00,0x7c,0x44,0x4b,0x48,0x51,0x49,0x49,0x46,0x44,0x44,0x68,0x51,0x42,0x44,0x40,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 18899 0x49d3 "䧓" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 18900 0x49d4 "䧔" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x49,0x48,0x44,0x44,0x44,0x6a,0x52,0x42,0x44,0x40,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 18901 0x49d5 "䧕" */
+0x00,0x78,0x48,0x57,0x50,0x60,0x53,0x4a,0x4a,0x4a,0x6b,0x50,0x40,0x47,0x42,0x40,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 18902 0x49d6 "䧖" */
+0x00,0x7c,0x44,0x49,0x48,0x50,0x48,0x49,0x44,0x44,0x45,0x68,0x50,0x40,0x40,0x41,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 18903 0x49d7 "䧗" */
+0x01,0x7d,0x45,0x4a,0x4d,0x51,0x49,0x49,0x45,0x44,0x44,0x69,0x52,0x40,0x41,0x46,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 18904 0x49d8 "䧘" */
+0x01,0x79,0x4a,0x53,0x50,0x67,0x50,0x49,0x4e,0x48,0x69,0x56,0x40,0x41,0x46,0x40,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 18905 0x49d9 "䧙" */
+0x00,0x7a,0x4a,0x52,0x53,0x60,0x50,0x49,0x4a,0x4c,0x68,0x52,0x42,0x44,0x42,0x41,
+0x40,0x48,0x48,0x48,0xf8,0x40,0xa0,0x10,0x88,0x86,0x90,0xa8,0x94,0x94,0x80,0x00,
+/* 18906 0x49da "䧚" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x48,0x48,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 18907 0x49db "䧛" */
+0x00,0x78,0x4b,0x51,0x50,0x63,0x52,0x4c,0x48,0x4b,0x68,0x50,0x40,0x41,0x41,0x42,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 18908 0x49dc "䧜" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 18909 0x49dd "䧝" */
+0x00,0x7d,0x45,0x49,0x48,0x53,0x48,0x48,0x45,0x45,0x45,0x69,0x50,0x40,0x43,0x41,
+0x20,0x24,0x24,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 18910 0x49de "䧞" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x44,0x46,0x6a,0x52,0x42,0x40,0x40,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 18911 0x49df "䧟" */
+0x00,0x7d,0x44,0x49,0x48,0x50,0x48,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 18912 0x49e0 "䧠" */
+0x00,0x7b,0x48,0x51,0x51,0x61,0x51,0x49,0x48,0x4b,0x68,0x53,0x41,0x40,0x40,0x40,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 18913 0x49e1 "䧡" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 18914 0x49e2 "䧢" */
+0x00,0x7b,0x4a,0x52,0x52,0x62,0x52,0x4a,0x4a,0x4a,0x6a,0x52,0x42,0x42,0x43,0x40,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 18915 0x49e3 "䧣" */
+0x00,0x7d,0x44,0x49,0x49,0x51,0x49,0x48,0x45,0x44,0x47,0x68,0x50,0x41,0x42,0x40,
+0x00,0xfc,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 18916 0x49e4 "䧤" */
+0x00,0x7a,0x49,0x50,0x53,0x60,0x50,0x4b,0x48,0x49,0x68,0x53,0x40,0x40,0x41,0x46,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 18917 0x49e5 "䧥" */
+0x00,0x78,0x4b,0x50,0x51,0x61,0x51,0x49,0x49,0x48,0x6b,0x50,0x40,0x42,0x42,0x44,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 18918 0x49e6 "䧦" */
+0x00,0x7b,0x48,0x52,0x51,0x63,0x52,0x4b,0x4a,0x4b,0x6a,0x52,0x42,0x45,0x44,0x48,
+0x0e,0xf0,0x44,0x24,0x08,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 18919 0x49e7 "䧧" */
+0x01,0x78,0x4b,0x48,0x51,0x50,0x63,0x50,0x49,0x48,0x4b,0x68,0x50,0x43,0x40,0x41,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 18920 0x49e8 "䧨" */
+0x00,0x7a,0x49,0x48,0x53,0x50,0x60,0x53,0x48,0x49,0x48,0x6b,0x50,0x41,0x46,0x40,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 18921 0x49e9 "䧩" */
+0x00,0x7b,0x48,0x51,0x57,0x62,0x52,0x4b,0x4a,0x4b,0x6a,0x52,0x43,0x46,0x40,0x40,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 18922 0x49ea "䧪" */
+0x00,0x78,0x4b,0x4a,0x52,0x52,0x62,0x52,0x4a,0x4a,0x4a,0x6a,0x52,0x44,0x44,0x48,
+0x20,0x10,0xfe,0x10,0xfe,0x54,0x54,0xba,0x28,0x44,0x82,0x20,0xfe,0x44,0x38,0xc6,
+/* 18923 0x49eb "䧫" */
+0x00,0x7b,0x48,0x51,0x51,0x61,0x50,0x4b,0x4a,0x49,0x68,0x53,0x40,0x43,0x40,0x43,
+0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x40,0xa4,0xd8,0x34,0xd2,0x30,
+/* 18924 0x49ec "䧬" */
+0x00,0x78,0x4b,0x52,0x51,0x61,0x52,0x49,0x4b,0x49,0x69,0x51,0x41,0x41,0x40,0x41,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 18925 0x49ed "䧭" */
+0x00,0x78,0x4b,0x52,0x52,0x62,0x53,0x4a,0x4a,0x4b,0x68,0x50,0x42,0x42,0x44,0x40,
+0x40,0x80,0xfe,0x22,0x8a,0x52,0x26,0x52,0xaa,0xfe,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 18926 0x49ee "䧮" */
+0x00,0x7b,0x4a,0x51,0x50,0x60,0x50,0x49,0x48,0x49,0x69,0x51,0x40,0x42,0x42,0x44,
+0x20,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfc,0x20,0xfc,0x54,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 18927 0x49ef "䧯" */
+0x01,0x7a,0x4f,0x52,0x53,0x62,0x53,0x4a,0x49,0x4a,0x6f,0x52,0x43,0x40,0x41,0x46,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 18928 0x49f0 "䧰" */
+0x04,0xe4,0xaf,0xa9,0xb2,0xaf,0xca,0xaa,0xaf,0xaa,0xaa,0xaf,0xc0,0x95,0x95,0x80,
+0x06,0x38,0x08,0x10,0x24,0xbc,0x88,0x94,0xbe,0x8a,0x88,0xac,0x2a,0x4a,0x48,0x18,
+/* 18929 0x49f1 "䧱" */
+0x20,0x20,0x20,0x20,0xfd,0x26,0x24,0x24,0x24,0x24,0x25,0x26,0x44,0x40,0x80,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18930 0x49f2 "䧲" */
+0x00,0x7c,0x10,0x10,0x11,0x12,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18931 0x49f3 "䧳" */
+0x08,0x08,0x08,0x08,0x49,0x4e,0x48,0x48,0x48,0x48,0x48,0x4e,0x58,0xe0,0x00,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18932 0x49f4 "䧴" */
+0x10,0x10,0x10,0xfe,0x11,0x12,0xfc,0x04,0x04,0x48,0x28,0x10,0x28,0x44,0x82,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18933 0x49f5 "䧵" */
+0x10,0x10,0x10,0xfe,0x93,0x12,0x10,0x28,0x28,0x28,0x28,0x4a,0x4c,0x88,0x00,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18934 0x49f6 "䧶" */
+0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x12,0x01,0xff,0x00,0x08,0x10,0x20,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x00,0xfe,0x00,0x20,0x10,0x08,
+/* 18935 0x49f7 "䧷" */
+0x20,0x20,0x3c,0x44,0xa9,0x12,0x28,0x44,0x82,0x30,0x08,0x00,0x60,0x10,0x08,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18936 0x49f8 "䧸" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18937 0x49f9 "䧹" */
+0x01,0x00,0x3f,0x22,0x22,0x24,0x24,0x2d,0x36,0x24,0x24,0x24,0x44,0x44,0x84,0x04,
+0x00,0x80,0xfe,0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 18938 0x49fa "䧺" */
+0x08,0x08,0x08,0xff,0x10,0x11,0x20,0x3e,0x62,0xa2,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18939 0x49fb "䧻" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18940 0x49fc "䧼" */
+0x10,0x50,0x50,0x7c,0x51,0x92,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18941 0x49fd "䧽" */
+0x06,0x78,0x08,0x4a,0x2a,0x2d,0x08,0xff,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18942 0x49fe "䧾" */
+0x10,0x10,0x28,0x44,0x82,0x7d,0x12,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x7c,0x44,
+0x50,0x48,0x40,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18943 0x49ff "䧿" */
+0x24,0x24,0x7e,0x24,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x00,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18944 0x4a00 "䨀" */
+0x20,0x10,0x28,0x44,0x91,0x12,0x54,0x38,0x10,0xfe,0x10,0x38,0x54,0x94,0x10,0x10,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18945 0x4a01 "䨁" */
+0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x09,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 18946 0x4a02 "䨂" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x09,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 18947 0x4a03 "䨃" */
+0x00,0x7e,0x42,0x7e,0x42,0x7f,0x08,0xff,0x81,0x10,0xff,0x22,0x64,0x18,0x24,0xc2,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18948 0x4a04 "䨄" */
+0x08,0x14,0x22,0x49,0xbe,0x05,0x08,0xff,0x14,0x7f,0x55,0x63,0x41,0x7f,0x41,0x7f,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18949 0x4a05 "䨅" */
+0x10,0x10,0xfe,0x10,0xaa,0x45,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x10,0x54,0x92,0x30,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18950 0x4a06 "䨆" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x0a,0x1f,0x31,0x5f,0x91,0x1f,0x11,0x1f,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xf8,
+/* 18951 0x4a07 "䨇" */
+0x28,0x24,0x7e,0xc9,0x7e,0x48,0x7e,0x48,0x7e,0x40,0x7d,0x04,0x28,0x10,0x28,0xc5,
+0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xfc,0x88,0x50,0x20,0x58,0x86,
+/* 18952 0x4a08 "䨈" */
+0x20,0x10,0xfe,0x82,0x7d,0x56,0x98,0x7c,0xc4,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 18953 0x4a09 "䨉" */
+0x00,0x77,0x55,0x77,0x55,0x77,0x55,0x77,0x22,0x55,0x10,0xff,0x22,0x64,0x1c,0xe3,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 18954 0x4a0a "䨊" */
+0x08,0x1f,0x30,0xdf,0x10,0x1f,0x14,0x3f,0x64,0xbf,0x24,0x3f,0x10,0x1e,0x12,0x22,
+0x80,0xfc,0x80,0xf8,0x80,0xfc,0x28,0x7e,0xc8,0x7e,0x48,0x7e,0x04,0x7c,0x44,0x44,
+/* 18955 0x4a0b "䨋" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x00,0x3f,0x02,0x03,0x7e,0x02,0x01,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf0,0x00,0x00,0xf8,0x02,0x02,0xfe,
+/* 18956 0x4a0c "䨌" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x1f,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf0,0x00,0xfc,0x40,0x44,0x44,0x3c,
+/* 18957 0x4a0d "䨍" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x08,0x3f,0x08,0x08,0xff,0x10,0x20,0x40,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x20,0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 18958 0x4a0e "䨎" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7f,0x01,0x7f,0x40,0x7f,0x01,0x0a,0x04,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x10,0x10,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 18959 0x4a0f "䨏" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,
+/* 18960 0x4a10 "䨐" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x01,0x06,0x18,0xe7,0x00,0x1f,0x10,0x1f,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xc0,0x30,0xce,0x00,0xf0,0x10,0xf0,0x10,
+/* 18961 0x4a11 "䨑" */
+0x3f,0x01,0x7f,0x49,0x84,0x01,0xff,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x02,0x04,0x18,
+0xf8,0x00,0xfe,0x22,0x14,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x84,0x4c,0x30,
+/* 18962 0x4a12 "䨒" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7e,0x22,0x12,0x0a,0x12,0x22,0x4a,0x04,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x44,0x24,0x14,0x24,0x44,0x94,0x08,
+/* 18963 0x4a13 "䨓" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x20,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 18964 0x4a14 "䨔" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x11,0x09,0xff,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x10,0x20,0xfe,0x40,0x42,0x42,0x3e,
+/* 18965 0x4a15 "䨕" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x11,0x48,0x20,0x0b,0x70,0x10,0x10,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 18966 0x4a16 "䨖" */
+0x3f,0x01,0x7f,0x41,0x9d,0x04,0x7f,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x08,0x08,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 18967 0x4a17 "䨗" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x00,0x7f,0x12,0x09,0x3f,0x00,0xff,0x01,0x05,0x02,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x00,0x10,0x20,0xf0,0x40,0xfe,0x00,0x00,0x00,
+/* 18968 0x4a18 "䨘" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 18969 0x4a19 "䨙" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x20,0x13,0x80,0x48,0x17,0xe0,0x20,0x23,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x38,0xc0,0x40,0x40,0xfe,0x40,0x40,0xfc,
+/* 18970 0x4a1a "䨚" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x08,0x1f,0x64,0x09,0x36,0x01,0x48,0x87,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x88,0x08,0x28,0x10,0x94,0xf2,0x00,
+/* 18971 0x4a1b "䨛" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x10,0xfd,0x11,0x39,0x55,0x92,0x12,0x14,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x0c,0xf0,0x00,0xfe,0x10,0x10,0x10,0x10,
+/* 18972 0x4a1c "䨜" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x4a,0x85,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0x08,
+/* 18973 0x4a1d "䨝" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x01,0x3f,0x01,0xff,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x00,0xf8,0x00,0xfe,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 18974 0x4a1e "䨞" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x01,0x7f,0x01,0x1f,0x11,0x7f,0x41,0x41,0x5e,0x40,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x00,0x00,0xf0,0x10,0xfc,0x24,0xf4,0x14,0x08,
+/* 18975 0x4a1f "䨟" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0x83,0x40,0x17,0x20,0xe3,0x20,0x2f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x40,0xf8,0x40,0xfc,0x40,0xf8,0x40,0xfe,
+/* 18976 0x4a20 "䨠" */
+0x3f,0x01,0x7f,0x49,0x84,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x21,0x52,0x14,0x1f,
+0xf8,0x00,0xfe,0x22,0x14,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x84,0x54,0xe8,
+/* 18977 0x4a21 "䨡" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x1f,0x00,0x51,0x49,0x55,0x42,0x7f,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xe0,0x40,0x94,0x24,0x14,0x04,0xfc,0x04,
+/* 18978 0x4a22 "䨢" */
+0x3f,0x01,0x7f,0x41,0x9d,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x12,0x14,0x1f,
+0xf8,0x00,0xfe,0x02,0x74,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x40,0x20,0xf8,
+/* 18979 0x4a23 "䨣" */
+0x3f,0x01,0x7f,0x41,0x9d,0x08,0x7f,0x08,0x0f,0x01,0x3f,0x21,0x3f,0x01,0xff,0x01,
+0xf8,0x00,0xfe,0x02,0x74,0x20,0xfc,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x00,
+/* 18980 0x4a24 "䨤" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0x07,0xf4,0x17,0x14,0x17,0x28,0x47,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,
+/* 18981 0x4a25 "䨥" */
+0x3f,0x01,0x7f,0x41,0x9d,0x09,0x1f,0x31,0x5f,0x91,0x1f,0x10,0x3f,0x08,0x07,0xf8,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x20,0xc0,0x3e,
+/* 18982 0x4a26 "䨦" */
+0x3f,0x01,0x7f,0x41,0x9d,0x02,0x3f,0x08,0x7f,0x41,0x3f,0x04,0x07,0x08,0x10,0x20,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x20,0xfc,0x04,0xf8,0x00,0xf0,0x10,0x50,0x20,
+/* 18983 0x4a27 "䨧" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0xfe,0x05,0x44,0x28,0x2e,0xf0,0x40,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0x50,0x88,0x26,0x10,0xfc,0x08,0x70,0x08,
+/* 18984 0x4a28 "䨨" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x21,0x13,0x02,0xf3,0x12,0x13,0x12,0x13,0x28,0x47,
+0xf8,0x00,0xfe,0x02,0x74,0x80,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x00,0xfe,
+/* 18985 0x4a29 "䨩" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0xfd,0x09,0x11,0x39,0x55,0x90,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x20,
+/* 18986 0x4a2a "䨪" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x11,0x11,0x11,0xfd,0x11,0x10,0x1d,0xe0,0x43,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 18987 0x4a2b "䨫" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x01,0x7f,0x11,0x2b,0x45,0x19,0xe3,0x0e,0x01,0x0e,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x00,0xfc,0x10,0xa8,0x64,0x18,0xe6,0x40,0x80,0x40,
+/* 18988 0x4a2c "䨬" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x11,0x81,0x4f,0x11,0xe3,0x25,0x29,0x21,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x10,
+/* 18989 0x4a2d "䨭" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0x7e,0x00,0xff,0x10,0x22,0x7f,0x01,
+0x10,0x10,0x54,0xb8,0x90,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x54,0x48,
+/* 18990 0x4a2e "䨮" */
+0x3f,0x01,0x7f,0x49,0x94,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x3f,0x00,0x1f,0x00,0x3f,
+0xf8,0x00,0xfe,0x22,0x14,0xfe,0x10,0x7c,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,
+/* 18991 0x4a2f "䨯" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x7b,0x48,0x51,0x61,0x51,0x49,0x49,0x68,0x50,0x41,
+0xf8,0x00,0xfe,0x02,0x74,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x70,0xa8,0x24,
+/* 18992 0x4a30 "䨰" */
+0x3f,0x01,0x7f,0x49,0x84,0x21,0x17,0x91,0x41,0x48,0x0b,0x12,0xe3,0x20,0x2f,0x20,
+0xf8,0x00,0xfe,0x22,0x14,0x10,0xfc,0x10,0xf0,0x40,0xf8,0x48,0xf8,0x40,0xfe,0x40,
+/* 18993 0x4a31 "䨱" */
+0x3f,0x01,0x7f,0x41,0x9d,0x12,0x27,0x42,0x8b,0x12,0x33,0x51,0x93,0x15,0x10,0x17,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x10,0xe0,0x1e,
+/* 18994 0x4a32 "䨲" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0xff,0x08,0x7f,0x55,0x55,0x55,0x43,
+0x20,0x20,0x3c,0xc4,0x88,0x7e,0x52,0x52,0x7e,0x90,0x2c,0x2a,0x28,0x4a,0x4a,0x86,
+/* 18995 0x4a33 "䨳" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x26,0x45,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x92,0x0e,
+/* 18996 0x4a34 "䨴" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x55,0x36,0x7f,0x14,0x7f,0x08,0x3e,0x08,0x0f,0x78,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x08,0x08,0x7e,0x08,0x48,0x28,0x28,0x08,0x28,0x10,
+/* 18997 0x4a35 "䨵" */
+0x3f,0x01,0x7f,0x49,0xa7,0x10,0x17,0x84,0x47,0x52,0x13,0x22,0xe3,0x20,0x27,0x20,
+0xf8,0x00,0xfe,0x22,0xfc,0xa0,0xfc,0xa4,0xfc,0x08,0xf8,0x08,0xf8,0x40,0xfc,0x40,
+/* 18998 0x4a36 "䨶" */
+0x3f,0x01,0x7f,0x41,0x9d,0x08,0x1f,0x00,0x4f,0x4a,0x49,0x7f,0x04,0xfc,0x24,0x44,
+0xf8,0x00,0xfe,0x02,0x74,0x20,0xf0,0x10,0xe4,0xa4,0x64,0xfc,0x40,0x7c,0x44,0x44,
+/* 18999 0x4a37 "䨷" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x11,0x7b,0x11,0x3b,0x55,0xbf,0x20,0x3f,0x20,0x21,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x08,0xce,0x08,0x88,0x7e,0x92,0x94,0x88,0x94,0xa2,
+/* 19000 0x4a38 "䨸" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x7b,0x49,0x53,0x60,0x53,0x48,0x49,0x68,0x52,0x44,
+0xf8,0x00,0xfe,0x02,0x74,0x18,0xe0,0x50,0xf8,0x40,0xf8,0x08,0xf8,0x40,0x94,0xf4,
+/* 19001 0x4a39 "䨹" */
+0x3f,0x01,0x7f,0x41,0x9d,0x10,0x11,0x22,0x28,0x6b,0xa9,0x29,0x29,0x29,0x28,0x21,
+0xf8,0x00,0xfe,0x02,0x74,0x80,0xfc,0x88,0x70,0x8e,0xfc,0xac,0x74,0xfc,0x20,0x54,
+/* 19002 0x4a3a "䨺" */
+0x3f,0x01,0x7f,0x49,0x9f,0x04,0x0f,0x00,0x7c,0x10,0xfe,0x92,0x54,0xfe,0x28,0x7c,
+0xf8,0x00,0xfe,0x22,0xf4,0x40,0xe0,0x00,0x7c,0x10,0xfe,0x92,0x54,0xfe,0x28,0x7c,
+/* 19003 0x4a3b "䨻" */
+0x7c,0x10,0xfe,0x92,0x7c,0x54,0x7c,0x00,0x7c,0x10,0xfe,0x92,0x7c,0x54,0x7c,0x00,
+0x7c,0x10,0xfe,0x92,0x7c,0x54,0x7c,0x00,0x7c,0x10,0xfe,0x92,0x7c,0x54,0x7c,0x00,
+/* 19004 0x4a3c "䨼" */
+0x10,0x11,0xfe,0x10,0x7c,0x11,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x54,0x49,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 19005 0x4a3d "䨽" */
+0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,0x3f,0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0xf0,0x10,0x10,0xf0,0x00,0x04,0x04,0xfc,
+/* 19006 0x4a3e "䨾" */
+0x01,0x00,0x3f,0x20,0x21,0x21,0x2f,0x21,0x21,0x27,0x21,0x21,0x4f,0x41,0x81,0x01,
+0x00,0x80,0xfe,0x00,0x20,0x20,0x3c,0x20,0x20,0x38,0x20,0x20,0x3c,0x20,0x20,0x20,
+/* 19007 0x4a3f "䨿" */
+0x00,0x3f,0x01,0x02,0xff,0x08,0x30,0xc4,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,
+0x00,0xf8,0x00,0x00,0xfe,0x20,0x18,0x46,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,
+/* 19008 0x4a40 "䩀" */
+0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 19009 0x4a41 "䩁" */
+0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x3f,0x02,0x7f,0x02,0x0d,0x70,0x1c,0xf1,0x1c,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xf0,0x00,0xf8,0x02,0xfe,0x40,0x78,0xc4,0x3c,
+/* 19010 0x4a42 "䩂" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xab,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 19011 0x4a43 "䩃" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x10,0x90,0x90,0x92,0x92,0x94,0xf4,0x98,0x90,0x90,0x90,0x92,0xb2,0xd2,0x8e,0x00,
+/* 19012 0x4a44 "䩄" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x01,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x8a,0x06,
+/* 19013 0x4a45 "䩅" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x83,0x02,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0xa8,0x44,0x82,
+/* 19014 0x4a46 "䩆" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xab,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x40,0x40,0x40,0x7e,0xa0,0xa0,0x20,0x3e,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 19015 0x4a47 "䩇" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 19016 0x4a48 "䩈" */
+0x00,0xfe,0x10,0x20,0xff,0xaa,0xaa,0xba,0xab,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x64,0x54,0xfe,0x44,0xa4,0x94,0xfe,0x04,0x28,0x10,
+/* 19017 0x4a49 "䩉" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 19018 0x4a4a "䩊" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xbb,0xaa,0xaa,0xfe,0x82,0x01,
+0x20,0x10,0xfe,0x82,0x40,0x4e,0x6a,0xaa,0xaa,0xaa,0x6c,0x28,0x4a,0x4a,0x8a,0x06,
+/* 19019 0x4a4b "䩋" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x83,0x00,
+0x10,0x08,0xfe,0xa4,0xa4,0xa4,0xfe,0xa4,0xa4,0xf6,0xac,0xb4,0xa4,0xa4,0x24,0x24,
+/* 19020 0x4a4c "䩌" */
+0x00,0xfe,0x10,0x20,0xfe,0xab,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x01,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0xaa,0x2a,
+/* 19021 0x4a4d "䩍" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xbb,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x10,0x10,0xfe,0x10,0xaa,0x44,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x54,0x92,0x30,
+/* 19022 0x4a4e "䩎" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x01,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x44,0x44,0xaa,0xaa,0x12,
+/* 19023 0x4a4f "䩏" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x01,
+0x24,0xfe,0x24,0x00,0xfe,0xaa,0xaa,0xfe,0x14,0xfe,0x90,0xd2,0xac,0xaa,0x96,0x22,
+/* 19024 0x4a50 "䩐" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x20,0x20,0x20,0x7e,0x40,0x80,0x3c,0x04,0x08,0x10,0x20,0xc0,0x42,0x42,0x3e,0x00,
+/* 19025 0x4a51 "䩑" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x00,0x7e,0x02,0x02,0x02,0x3e,0x20,0x20,0x40,0x7e,0x02,0x82,0x02,0x02,0x14,0x08,
+/* 19026 0x4a52 "䩒" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x00,0x7e,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x90,0x10,0x10,0x50,0x20,
+/* 19027 0x4a53 "䩓" */
+0x28,0x28,0xfc,0x28,0x39,0x12,0x7c,0x54,0x54,0x7d,0x13,0xfd,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x02,0x42,0x42,0x82,0xa2,0x12,0xfa,0x0a,0x02,0x02,0x14,0x08,
+/* 19028 0x4a54 "䩔" */
+0x28,0x28,0xfe,0x28,0x38,0x11,0x7e,0x55,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x13,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 19029 0x4a55 "䩕" */
+0x28,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x10,0x10,0x10,
+0x00,0x40,0x9e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x5a,0x94,0x10,0x10,0x10,0x10,
+/* 19030 0x4a56 "䩖" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7d,0x55,0x56,0x7c,0x10,0xfe,0x10,0x10,0x10,0x13,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 19031 0x4a57 "䩗" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 19032 0x4a58 "䩘" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x00,0x00,0x7e,0x08,0x10,0x10,0x24,0x44,0x78,0x08,0x10,0x94,0x22,0x7e,0x22,0x00,
+/* 19033 0x4a59 "䩙" */
+0x28,0x28,0xfe,0x29,0x38,0x10,0x7c,0x54,0x55,0x7c,0x10,0xfe,0x10,0x11,0x10,0x10,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 19034 0x4a5a "䩚" */
+0x28,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 19035 0x4a5b "䩛" */
+0x28,0x28,0xfc,0x28,0x38,0x10,0x7c,0x55,0x55,0x7d,0x12,0xfc,0x10,0x11,0x12,0x10,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 19036 0x4a5c "䩜" */
+0x28,0x28,0xfe,0x28,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 19037 0x4a5d "䩝" */
+0x28,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 19038 0x4a5e "䩞" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 19039 0x4a5f "䩟" */
+0x28,0x28,0xfd,0x28,0x39,0x10,0x7d,0x55,0x55,0x7c,0x10,0xfc,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 19040 0x4a60 "䩠" */
+0x50,0x50,0xfb,0x50,0x70,0x21,0xf9,0xab,0xa8,0xfa,0x22,0xf9,0x21,0x22,0x24,0x28,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 19041 0x4a61 "䩡" */
+0x28,0x28,0xfc,0x2b,0x38,0x10,0x7d,0x55,0x55,0x7e,0x10,0xfc,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 19042 0x4a62 "䩢" */
+0x51,0x51,0xf9,0x51,0x77,0x21,0xf9,0xa9,0xa9,0xff,0x21,0xf9,0x21,0x21,0x25,0x22,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 19043 0x4a63 "䩣" */
+0x28,0x28,0xfc,0x28,0x39,0x12,0x7c,0x54,0x57,0x7c,0x11,0xfd,0x12,0x14,0x10,0x10,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 19044 0x4a64 "䩤" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 19045 0x4a65 "䩥" */
+0x50,0x50,0xfb,0x50,0x70,0x21,0xf9,0xab,0xa8,0xfa,0x22,0xf9,0x21,0x22,0x24,0x28,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 19046 0x4a66 "䩦" */
+0x10,0x20,0x69,0xaa,0x28,0x28,0x23,0x04,0x7f,0x04,0x07,0x01,0x1f,0x11,0xff,0x01,
+0x80,0xfc,0x10,0x90,0x60,0x90,0x0c,0x40,0xfc,0x40,0xc0,0x00,0xf0,0x10,0xfe,0x00,
+/* 19047 0x4a67 "䩧" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfc,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 19048 0x4a68 "䩨" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x57,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 19049 0x4a69 "䩩" */
+0x50,0x50,0xfb,0x52,0x75,0x21,0xf9,0xaa,0xaa,0xfb,0x24,0xf8,0x21,0x21,0x22,0x24,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 19050 0x4a6a "䩪" */
+0x28,0x28,0xfd,0x29,0x3a,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfc,0x10,0x10,0x10,0x10,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 19051 0x4a6b "䩫" */
+0x50,0x53,0xf8,0x50,0x73,0x22,0xfa,0xab,0xaa,0xfa,0x23,0xfa,0x22,0x22,0x22,0x22,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 19052 0x4a6c "䩬" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7d,0x54,0x55,0x7e,0x10,0xfc,0x11,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 19053 0x4a6d "䩭" */
+0x28,0x28,0xfd,0x28,0x38,0x11,0x7f,0x54,0x55,0x7d,0x11,0xfd,0x11,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 19054 0x4a6e "䩮" */
+0x28,0x29,0xfc,0x28,0x39,0x10,0x7c,0x57,0x54,0x7e,0x11,0xfc,0x11,0x12,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 19055 0x4a6f "䩯" */
+0x50,0x53,0xf8,0x50,0x70,0x23,0xfa,0xaa,0xaa,0xfa,0x23,0xf8,0x20,0x20,0x27,0x20,
+0x00,0xfc,0x08,0x10,0x20,0xae,0xa2,0xaa,0xa4,0xa4,0xaa,0x32,0xa0,0x40,0xfe,0x00,
+/* 19056 0x4a70 "䩰" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7d,0x54,0x54,0x7c,0x10,0xfe,0x10,0x13,0x10,0x10,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 19057 0x4a71 "䩱" */
+0x50,0x50,0xf9,0x52,0x75,0x20,0xfb,0xaa,0xaa,0xfb,0x22,0xfa,0x23,0x22,0x22,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 19058 0x4a72 "䩲" */
+0x28,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x40,0x20,0xfe,0x48,0x48,0xfe,0x48,0x78,0x00,0xfc,0x44,0x48,0x28,0x10,0x28,0xc6,
+/* 19059 0x4a73 "䩳" */
+0x28,0x28,0xfd,0x29,0x38,0x11,0x7c,0x54,0x55,0x7c,0x10,0xfc,0x10,0x10,0x10,0x13,
+0x40,0x20,0xfe,0x22,0xa4,0x28,0x50,0x88,0x04,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 19060 0x4a74 "䩴" */
+0x28,0x28,0xfc,0x29,0x38,0x10,0x7c,0x55,0x55,0x7d,0x11,0xfd,0x11,0x10,0x10,0x10,
+0x80,0x9e,0x92,0xd2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 19061 0x4a75 "䩵" */
+0x28,0x2b,0xfe,0x28,0x3b,0x10,0x7d,0x55,0x55,0x7d,0x11,0xfc,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 19062 0x4a76 "䩶" */
+0x28,0x29,0xfd,0x29,0x38,0x11,0x7c,0x54,0x55,0x7d,0x11,0xfd,0x10,0x10,0x13,0x11,
+0x20,0x24,0x24,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 19063 0x4a77 "䩷" */
+0x28,0x28,0xfd,0x28,0x38,0x11,0x7d,0x56,0x54,0x7d,0x10,0xfc,0x10,0x10,0x10,0x11,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 19064 0x4a78 "䩸" */
+0x28,0x28,0xfd,0x28,0x38,0x11,0x7c,0x54,0x54,0x7c,0x10,0xfc,0x10,0x11,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x88,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 19065 0x4a79 "䩹" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 19066 0x4a7a "䩺" */
+0x50,0x50,0xf9,0x52,0x74,0x21,0xf8,0xa8,0xab,0xf8,0x22,0xf9,0x22,0x20,0x21,0x20,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 19067 0x4a7b "䩻" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7c,0x12,0xfe,0x12,0x12,0x10,0x10,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 19068 0x4a7c "䩼" */
+0x28,0x2a,0xfd,0x28,0x38,0x10,0x7f,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x20,0x20,0x7c,0xa4,0x18,0xe6,0x10,0x7e,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 19069 0x4a7d "䩽" */
+0x50,0x53,0xfa,0x52,0x72,0x22,0xfa,0xaa,0xaa,0xfa,0x22,0xfa,0x22,0x22,0x23,0x20,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 19070 0x4a7e "䩾" */
+0x50,0x50,0xfb,0x52,0x72,0x22,0xfb,0xaa,0xaa,0xfa,0x22,0xfa,0x25,0x25,0x2a,0x30,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 19071 0x4a7f "䩿" */
+0x28,0x29,0xfc,0x28,0x3b,0x10,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x10,0x11,0x12,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 19072 0x4a80 "䪀" */
+0x28,0x29,0xff,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x20,0xfe,0x02,0xf8,0x88,0xf8,0x80,0xfc,0x84,0xfc,0x00,0x20,0x54,0x42,0x4a,0x38,
+/* 19073 0x4a81 "䪁" */
+0x28,0x29,0xfc,0x28,0x39,0x10,0x7c,0x55,0x54,0x7c,0x10,0xfd,0x10,0x10,0x11,0x12,
+0x50,0x52,0xd4,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 19074 0x4a82 "䪂" */
+0x52,0x52,0xff,0x52,0x72,0x2f,0xfa,0xaa,0xaa,0xfb,0x22,0xff,0x2a,0x32,0x22,0x22,
+0x08,0x08,0xbe,0x08,0x08,0xbe,0xaa,0xaa,0xaa,0xae,0x08,0x1c,0xaa,0x48,0x08,0x08,
+/* 19075 0x4a83 "䪃" */
+0x51,0x50,0xfb,0x50,0x73,0x22,0xfb,0xa8,0xab,0xf8,0x20,0xf8,0x23,0x20,0x22,0x21,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 19076 0x4a84 "䪄" */
+0x28,0x28,0xfd,0x28,0x38,0x13,0x7c,0x55,0x55,0x7d,0x11,0xfd,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 19077 0x4a85 "䪅" */
+0x28,0x29,0xfd,0x29,0x39,0x10,0x7d,0x56,0x55,0x7d,0x11,0xfd,0x10,0x13,0x10,0x10,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfe,0x42,0xf2,0x52,0x52,0xf2,0x4a,0xfa,0x0a,0x04,
+/* 19078 0x4a86 "䪆" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7c,0x55,0x54,0x7d,0x11,0xfd,0x10,0x10,0x13,0x10,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 19079 0x4a87 "䪇" */
+0x28,0x2b,0xfc,0x28,0x3b,0x10,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x10,0x11,0x10,0x10,
+0x88,0xfe,0x88,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x58,
+/* 19080 0x4a88 "䪈" */
+0x28,0x28,0xfe,0x29,0x39,0x10,0x7c,0x57,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x40,0x7c,0x44,0x7c,0x80,0x7e,
+/* 19081 0x4a89 "䪉" */
+0x51,0x52,0xf9,0x50,0x73,0x22,0xfa,0xaa,0xab,0xfa,0x23,0xfa,0x23,0x22,0x22,0x23,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 19082 0x4a8a "䪊" */
+0x51,0x50,0xfb,0x50,0x72,0x21,0xfb,0xa8,0xab,0xfa,0x23,0xfa,0x23,0x22,0x22,0x22,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 19083 0x4a8b "䪋" */
+0x28,0x28,0xfe,0x29,0x39,0x10,0x7c,0x57,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x80,0x7e,
+/* 19084 0x4a8c "䪌" */
+0x51,0x52,0xfb,0x56,0x73,0x22,0xfb,0xaa,0xa9,0xfa,0x27,0xfa,0x23,0x20,0x21,0x26,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 19085 0x4a8d "䪍" */
+0x53,0x52,0xfb,0x52,0x73,0x22,0xfa,0xaa,0xaa,0xfa,0x22,0xfa,0x22,0x22,0x22,0x22,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 19086 0x4a8e "䪎" */
+0x52,0x53,0xf8,0x51,0x73,0x25,0xf9,0xa9,0xa9,0xf9,0x21,0xfb,0x22,0x23,0x22,0x22,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 19087 0x4a8f "䪏" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0xaa,0xaa,0xca,0x82,0x82,0x82,0x82,0x8a,0x84,
+/* 19088 0x4a90 "䪐" */
+0x10,0x10,0x7c,0x24,0xfe,0x00,0x7c,0x45,0x7d,0x11,0x7e,0x10,0x50,0x7d,0x12,0x10,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 19089 0x4a91 "䪑" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x20,0x10,0x10,0xfe,0x82,0x84,0x40,0x44,0x48,0x50,0x60,0x42,0x42,0x42,0x3e,0x00,
+/* 19090 0x4a92 "䪒" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x20,0x10,0x00,0xfe,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 19091 0x4a93 "䪓" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 19092 0x4a94 "䪔" */
+0x10,0x10,0x7d,0x24,0xfe,0x01,0x7d,0x45,0x7d,0x11,0x7d,0x11,0x51,0x7d,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 19093 0x4a95 "䪕" */
+0x10,0x10,0x7c,0x25,0xfe,0x00,0x7c,0x44,0x7d,0x10,0x7c,0x10,0x51,0x7c,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 19094 0x4a96 "䪖" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x3c,0x44,0xa8,0x10,0x28,0xc6,
+/* 19095 0x4a97 "䪗" */
+0x10,0x11,0x7d,0x25,0xff,0x01,0x7d,0x45,0x7d,0x11,0x7d,0x11,0x51,0x7d,0x11,0x11,
+0x00,0xdc,0x44,0x44,0x44,0xdc,0x00,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 19096 0x4a98 "䪘" */
+0x10,0x10,0x7c,0x24,0xfe,0x00,0x7c,0x44,0x7c,0x11,0x7c,0x10,0x50,0x7c,0x11,0x12,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x10,0x90,0x9c,0x90,0x50,0x3e,
+/* 19097 0x4a99 "䪙" */
+0x10,0x10,0x7d,0x24,0xfe,0x00,0x7c,0x44,0x7c,0x10,0x7c,0x11,0x50,0x7c,0x10,0x10,
+0x14,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x24,0x24,0x0c,
+/* 19098 0x4a9a "䪚" */
+0x10,0x11,0x7d,0x25,0xff,0x01,0x7c,0x47,0x7c,0x12,0x7d,0x10,0x53,0x7c,0x11,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 19099 0x4a9b "䪛" */
+0x10,0x10,0x7c,0x24,0xfe,0x00,0x7c,0x45,0x7c,0x10,0x7c,0x10,0x50,0x7c,0x10,0x10,
+0x1e,0xf0,0x92,0x54,0xfe,0x54,0x92,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 19100 0x4a9c "䪜" */
+0x10,0x10,0x7c,0x25,0xfe,0x00,0x7c,0x44,0x7c,0x10,0x7c,0x10,0x50,0x7d,0x11,0x12,
+0x40,0x78,0x88,0xfe,0xa4,0xd2,0xfe,0x80,0xbc,0x80,0xbc,0x80,0xbc,0x24,0x3c,0x24,
+/* 19101 0x4a9d "䪝" */
+0x10,0x11,0x7c,0x24,0xfe,0x01,0x7c,0x44,0x7c,0x10,0x7c,0x10,0x51,0x7c,0x10,0x11,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 19102 0x4a9e "䪞" */
+0x00,0x3f,0x01,0xff,0x02,0x04,0x18,0xe4,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0xff,
+0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x4e,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xfe,
+/* 19103 0x4a9f "䪟" */
+0x10,0x11,0xfe,0x10,0x10,0x7c,0x55,0x54,0x55,0x54,0x55,0x5c,0x11,0x10,0x13,0x10,
+0x00,0xf8,0x88,0x50,0x20,0x50,0x8c,0x50,0xdc,0x50,0xdc,0x50,0xdc,0x50,0xfe,0x00,
+/* 19104 0x4aa0 "䪠" */
+0x16,0xf8,0x90,0xfe,0x32,0x52,0x96,0x10,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0xff,
+0x40,0x7c,0x84,0x28,0x20,0x50,0x8c,0x00,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xfe,
+/* 19105 0x4aa1 "䪡" */
+0x11,0x1c,0x70,0x50,0x7d,0x34,0x5c,0x90,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0xff,
+0x20,0xbe,0x42,0x94,0x90,0xa8,0x46,0x00,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xfe,
+/* 19106 0x4aa2 "䪢" */
+0x12,0x1d,0x70,0x50,0x53,0x51,0x7d,0x14,0x35,0x34,0x55,0x98,0x11,0x10,0x13,0x10,
+0x20,0x3e,0x42,0x94,0x10,0x28,0x46,0x50,0xdc,0x50,0xdc,0x50,0xdc,0x50,0xfe,0x00,
+/* 19107 0x4aa3 "䪣" */
+0x12,0x11,0x10,0xfc,0x13,0x11,0x7c,0x54,0x55,0x54,0x5d,0x30,0x51,0x90,0x13,0x10,
+0x20,0x3e,0x42,0x94,0x10,0x28,0x46,0x50,0xdc,0x50,0xdc,0x50,0xdc,0x50,0xfe,0x00,
+/* 19108 0x4aa4 "䪤" */
+0x28,0x29,0x28,0xee,0x29,0x28,0xee,0x29,0x28,0x28,0xee,0x28,0x28,0x2e,0xf0,0x40,
+0x1e,0xf0,0x92,0x54,0xfe,0x54,0x92,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 19109 0x4aa5 "䪥" */
+0x10,0x1e,0x10,0xff,0x81,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,
+0x00,0xfc,0x44,0x28,0x10,0x28,0xc6,0x28,0xee,0x28,0xee,0x28,0xee,0x28,0xfe,0x00,
+/* 19110 0x4aa6 "䪦" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,
+0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 19111 0x4aa7 "䪧" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xfe,0x01,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x20,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xa4,0xb4,0xa8,0xa2,0xa2,0x82,0x7e,0x00,
+/* 19112 0x4aa8 "䪨" */
+0x20,0x10,0x7c,0x00,0x44,0x29,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x40,0x40,0x40,0xfc,0x84,0x04,0x04,0x84,0x44,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 19113 0x4aa9 "䪩" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xff,0x02,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 19114 0x4aaa "䪪" */
+0x10,0x7e,0x12,0x22,0x4a,0x84,0x01,0x3f,0x08,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xf8,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 19115 0x4aab "䪫" */
+0x20,0x10,0x7c,0x00,0x44,0x29,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,
+0x00,0xfe,0x00,0x52,0xa4,0x28,0x94,0x4a,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 19116 0x4aac "䪬" */
+0x20,0x10,0x7d,0x00,0x44,0x29,0xff,0x02,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7c,0x44,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 19117 0x4aad "䪭" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 19118 0x4aae "䪮" */
+0x20,0x10,0x7c,0x01,0x44,0x28,0xfe,0x00,0x7d,0x44,0x45,0x7e,0x44,0x44,0x7c,0x45,
+0x40,0x40,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x48,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x08,
+/* 19119 0x4aaf "䪯" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x41,0x9f,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x40,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 19120 0x4ab0 "䪰" */
+0x20,0x10,0x79,0x00,0x48,0x33,0xfc,0x01,0x79,0x49,0x49,0x79,0x48,0x4a,0x7a,0x4c,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 19121 0x4ab1 "䪱" */
+0x00,0x01,0xfc,0x04,0x05,0x05,0x05,0x7d,0x41,0x41,0x41,0x45,0x59,0x60,0x41,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 19122 0x4ab2 "䪲" */
+0x00,0x00,0xfe,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x2a,0x4c,0x48,0x80,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19123 0x4ab3 "䪳" */
+0x00,0x00,0x7e,0x12,0x12,0xff,0x12,0x12,0x7e,0x12,0x10,0x10,0x20,0x20,0x40,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19124 0x4ab4 "䪴" */
+0x08,0x08,0x08,0x7f,0x49,0x08,0x08,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19125 0x4ab5 "䪵" */
+0x00,0x7e,0x04,0x24,0x24,0x24,0x44,0x7f,0x0c,0x14,0x14,0x24,0x44,0x84,0x14,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19126 0x4ab6 "䪶" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x4e,0xf0,0x00,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19127 0x4ab7 "䪷" */
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x14,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19128 0x4ab8 "䪸" */
+0x00,0x7e,0x42,0x42,0x7e,0x48,0x48,0x48,0x7e,0x48,0x48,0x48,0x4a,0x4a,0x66,0x43,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19129 0x4ab9 "䪹" */
+0x00,0x7e,0x08,0x08,0x10,0x14,0x32,0x51,0x90,0x10,0x10,0x00,0x0e,0xf0,0x40,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19130 0x4aba "䪺" */
+0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0xfe,0x10,0x10,0x20,0x28,0x44,0xfe,0x42,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19131 0x4abb "䪻" */
+0x10,0x10,0x20,0x44,0xfe,0x02,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x44,0x44,0x85,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19132 0x4abc "䪼" */
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x9e,0xf2,0x00,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19133 0x4abd "䪽" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x04,0x28,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19134 0x4abe "䪾" */
+0x00,0xff,0x08,0x10,0x7e,0x42,0x42,0x7e,0x42,0x7e,0x42,0x42,0x7e,0x24,0x42,0x81,
+0x10,0x10,0x28,0x28,0x44,0x82,0x08,0x10,0x64,0x08,0x12,0x64,0x08,0x30,0xc0,0x00,
+/* 19135 0x4abf "䪿" */
+0x08,0x08,0x10,0x7f,0x41,0x41,0x65,0x55,0x49,0x49,0x55,0x65,0x41,0x7f,0x41,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19136 0x4ac0 "䫀" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x48,0x44,0x4a,0x52,0x60,0x40,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19137 0x4ac1 "䫁" */
+0x10,0x11,0x20,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7c,0x45,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 19138 0x4ac2 "䫂" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x24,0xc8,0x1f,0x21,0xd2,0x0c,0x08,0x30,0xc0,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19139 0x4ac3 "䫃" */
+0x00,0x7f,0x40,0x40,0x5e,0x40,0x40,0x7f,0x50,0x51,0x5a,0x54,0x52,0x91,0x98,0x10,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19140 0x4ac4 "䫄" */
+0x44,0x24,0x28,0x00,0x7c,0x44,0x44,0x44,0x7c,0x28,0x28,0x28,0x2a,0x4c,0x88,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19141 0x4ac5 "䫅" */
+0x10,0x08,0x7f,0x41,0x49,0x08,0x08,0x7f,0x08,0x18,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19142 0x4ac6 "䫆" */
+0x04,0x05,0x04,0x04,0x7f,0x44,0x44,0x75,0x55,0x55,0x55,0x52,0x52,0xa6,0x89,0x10,
+0x00,0x3e,0x88,0x10,0xbe,0x22,0x22,0x3e,0x22,0x3e,0x22,0x22,0xbe,0x80,0x94,0xa2,
+/* 19143 0x4ac7 "䫇" */
+0x0c,0x30,0xc6,0x18,0x63,0x0c,0xf0,0x00,0x7e,0x42,0xff,0x42,0xff,0x42,0x4a,0x44,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19144 0x4ac8 "䫈" */
+0x08,0x49,0x49,0x49,0x7f,0x08,0x14,0x22,0x51,0x88,0x08,0x7e,0x02,0x04,0x04,0x08,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0xfc,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19145 0x4ac9 "䫉" */
+0x0c,0x30,0xc2,0x14,0x48,0x30,0xc8,0x14,0x24,0xcc,0x14,0x24,0xc4,0x04,0x28,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19146 0x4aca "䫊" */
+0x00,0xfe,0x08,0x10,0x34,0x52,0x91,0x10,0x00,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19147 0x4acb "䫋" */
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x92,0x00,0x10,0xfc,0x24,0x44,0x28,0x10,0x28,0xc5,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19148 0x4acc "䫌" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x14,0x24,0xff,0x04,0x04,0x04,0x04,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19149 0x4acd "䫍" */
+0x14,0x14,0x14,0xf7,0x14,0x14,0x14,0x77,0x14,0x14,0x14,0xf7,0x14,0x14,0x14,0x14,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19150 0x4ace "䫎" */
+0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19151 0x4acf "䫏" */
+0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0xff,0x00,0x14,0x22,0x41,
+0x00,0x7e,0x90,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19152 0x4ad0 "䫐" */
+0x22,0x22,0x22,0x22,0xf7,0x22,0x22,0x66,0x77,0xaa,0xaa,0x32,0x22,0x22,0x22,0x22,
+0x00,0x7e,0x10,0x20,0xfc,0x44,0x44,0x7c,0x44,0xfc,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19153 0x4ad1 "䫑" */
+0x10,0x10,0xfe,0x10,0x28,0x44,0xfe,0x04,0x74,0x54,0x54,0x74,0x54,0x04,0x14,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19154 0x4ad2 "䫒" */
+0x00,0x06,0x78,0x48,0x7f,0x48,0x45,0x53,0x61,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19155 0x4ad3 "䫓" */
+0x20,0x10,0x7c,0x00,0x44,0x24,0x28,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19156 0x4ad4 "䫔" */
+0x20,0x2f,0xf5,0x25,0x75,0x25,0xf5,0x29,0x23,0x08,0x08,0xff,0x14,0x22,0x41,0x80,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0xc4,0x7c,0x00,0x28,0xc4,
+/* 19157 0x4ad5 "䫕" */
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x82,0x10,0x7c,0x54,0x54,0x54,0x5c,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19158 0x4ad6 "䫖" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19159 0x4ad7 "䫗" */
+0x00,0x77,0x51,0x51,0x51,0x77,0x40,0x40,0x77,0x41,0x49,0x75,0x42,0x42,0x45,0x49,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19160 0x4ad8 "䫘" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x7e,0x92,0x52,0x6a,0x42,0x7a,0x02,0x14,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19161 0x4ad9 "䫙" */
+0x08,0x08,0x7f,0x08,0x2a,0x22,0xff,0x22,0x2a,0x08,0x7f,0x1c,0x2a,0x49,0x89,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0xc4,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19162 0x4ada "䫚" */
+0x00,0x3e,0x22,0x22,0x3a,0x2a,0x2a,0x7f,0x41,0x5d,0x55,0x55,0x5d,0x41,0x45,0x42,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19163 0x4adb "䫛" */
+0x20,0x2f,0x21,0x41,0x5f,0xc8,0x48,0x4f,0x52,0x42,0x5f,0x42,0x45,0x44,0x48,0x50,
+0x00,0x3e,0x08,0x10,0xbe,0x22,0x22,0xbe,0x22,0x3e,0xa2,0x22,0x3e,0x80,0x94,0x22,
+/* 19164 0x4adc "䫜" */
+0x08,0x2a,0x2a,0xaa,0xcc,0xdd,0xff,0xaa,0xaa,0xdd,0xff,0x99,0x88,0x8f,0xf0,0x00,
+0x00,0x3e,0x08,0x90,0xbe,0xa2,0xa2,0xbe,0xa2,0xbe,0xa2,0xa2,0xbe,0x80,0x94,0x22,
+/* 19165 0x4add "䫝" */
+0x06,0x78,0x08,0x08,0xff,0x1c,0x2a,0x49,0xbe,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19166 0x4ade "䫞" */
+0x44,0x24,0x28,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0xaa,0xaa,0xaa,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19167 0x4adf "䫟" */
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x28,0x44,0x85,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19168 0x4ae0 "䫠" */
+0x18,0x60,0x0c,0x70,0x0c,0x70,0x00,0xfe,0x10,0x34,0x52,0x90,0x7c,0x44,0x7c,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19169 0x4ae1 "䫡" */
+0x22,0x14,0xff,0x14,0x14,0x7f,0x15,0xff,0x15,0x7f,0x14,0x36,0x55,0x94,0x14,0x14,
+0x00,0x7e,0x90,0x20,0x7c,0x44,0x44,0xfc,0x44,0x7c,0x44,0x44,0x7c,0x80,0x28,0x44,
+/* 19170 0x4ae2 "䫢" */
+0x03,0x7c,0x47,0x44,0x5f,0x55,0x56,0x5c,0x55,0x53,0x50,0x57,0x55,0x55,0xa9,0x00,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0xa8,0x44,
+/* 19171 0x4ae3 "䫣" */
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x44,0x83,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19172 0x4ae4 "䫤" */
+0x00,0xff,0x81,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x10,0x08,0xff,0x00,0x24,0x42,0x81,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19173 0x4ae5 "䫥" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0xa8,0xc4,0x82,0x02,0xfe,
+/* 19174 0x4ae6 "䫦" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x20,0x41,0xff,0x40,0x00,0x7f,0x55,0x55,0x57,0xfc,
+0x00,0x3e,0x08,0x10,0x3e,0xa2,0x22,0x3e,0xa2,0xbe,0x22,0x22,0x3e,0x00,0x94,0x22,
+/* 19175 0x4ae7 "䫧" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x28,0x54,0x92,0x7c,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19176 0x4ae8 "䫨" */
+0x12,0x12,0x12,0x7a,0x13,0x7c,0x10,0xfc,0x22,0x3a,0x29,0x29,0x29,0x4a,0x5a,0x84,
+0x00,0x3e,0x08,0x10,0xfe,0xa2,0xa2,0xbe,0xa2,0xbe,0x22,0x22,0x3e,0x80,0x94,0xa2,
+/* 19177 0x4ae9 "䫩" */
+0x10,0x22,0x7f,0x42,0x94,0xf7,0x08,0x36,0xc9,0x30,0xc4,0x19,0x62,0x0c,0x30,0xc0,
+0x00,0x3e,0x08,0x10,0xbe,0xa2,0x22,0x3e,0x22,0xbe,0x22,0x22,0x3e,0x00,0x14,0x22,
+/* 19178 0x4aea "䫪" */
+0x10,0x10,0xfe,0x10,0xba,0x54,0xba,0x10,0xba,0x54,0xba,0x10,0x28,0x24,0x42,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19179 0x4aeb "䫫" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x00,0x7e,0x10,0xa0,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19180 0x4aec "䫬" */
+0x00,0xf7,0x21,0xa5,0xf7,0x63,0xb5,0x21,0x7f,0x40,0x40,0x7f,0x40,0x40,0x7f,0x40,
+0x00,0xbe,0x08,0x10,0xbe,0x22,0xa2,0x3e,0xa2,0xbe,0xa2,0xa2,0xbe,0x80,0x94,0xa2,
+/* 19181 0x4aed "䫭" */
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19182 0x4aee "䫮" */
+0x00,0x7f,0x01,0x3f,0x01,0x7f,0x00,0x77,0x25,0xf7,0x02,0xff,0x42,0x22,0x2a,0x04,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0xc4,0x7c,0x00,0x28,0x44,
+/* 19183 0x4aef "䫯" */
+0x41,0x21,0x0f,0xf1,0x42,0x44,0x7f,0x50,0x57,0x55,0x55,0x57,0x55,0x50,0xa1,0x00,
+0x00,0x1e,0xe4,0x08,0x9e,0x52,0xf2,0x5e,0x52,0x5e,0x52,0x52,0x5e,0x40,0x4c,0x92,
+/* 19184 0x4af0 "䫰" */
+0x00,0xf9,0x20,0x43,0xf8,0x89,0x8a,0xf9,0x89,0xf9,0x8a,0x8d,0xf8,0x01,0x52,0x8c,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 19185 0x4af1 "䫱" */
+0x00,0x7f,0x08,0x7f,0x54,0x54,0x54,0x41,0x00,0x7f,0x08,0x7f,0x54,0x54,0x54,0x41,
+0x00,0xbe,0x08,0x90,0xbe,0xa2,0xa2,0xbe,0x22,0xbe,0x22,0xa2,0xbe,0x80,0x94,0xa2,
+/* 19186 0x4af2 "䫲" */
+0x02,0x02,0x7f,0x42,0x5e,0x42,0x5e,0x57,0x5d,0x42,0x88,0x04,0x54,0x51,0x8f,0x00,
+0x80,0x5e,0xc4,0x08,0x1e,0x92,0x92,0x1e,0x52,0xde,0x52,0x92,0x5e,0x40,0x0c,0x12,
+/* 19187 0x4af3 "䫳" */
+0x00,0x7f,0x55,0x55,0x7f,0x20,0x7f,0x91,0x7d,0x55,0x55,0x7d,0x11,0x7d,0x05,0x02,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 19188 0x4af4 "䫴" */
+0x22,0x22,0xf7,0x22,0x77,0xaa,0x22,0x00,0x7f,0x00,0xff,0x08,0x49,0x48,0xa8,0x10,
+0x00,0x3e,0x88,0x10,0x3e,0xa2,0x62,0x3e,0x22,0x3e,0xa2,0x22,0x3e,0x80,0x94,0x22,
+/* 19189 0x4af5 "䫵" */
+0x10,0x7f,0x49,0x65,0x53,0x49,0x7f,0x08,0xff,0xa2,0x49,0xff,0x20,0x3f,0x41,0x83,
+0x00,0x3e,0x08,0x10,0x3e,0x22,0x22,0x3e,0xa2,0xbe,0x22,0xa2,0x3e,0x00,0x14,0x22,
+/* 19190 0x4af6 "䫶" */
+0x20,0x2a,0xf5,0x2a,0x71,0x6a,0xa4,0x2a,0x20,0x04,0x04,0x7f,0x0a,0x11,0x20,0x40,
+0x80,0x9e,0xe4,0x88,0xde,0xb2,0x92,0x9e,0x92,0x1e,0x12,0xd2,0x1e,0x00,0x8c,0x52,
+/* 19191 0x4af7 "䫷" */
+0x00,0xff,0x08,0xeb,0xaa,0xeb,0x08,0xff,0x08,0xeb,0xaa,0xeb,0x08,0x0f,0xf8,0x40,
+0x00,0xbe,0x08,0x90,0xbe,0xa2,0x22,0xbe,0x22,0xbe,0xa2,0xa2,0x3e,0x80,0x14,0x22,
+/* 19192 0x4af8 "䫸" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x00,0xde,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x52,0x52,0x6a,0x44,0x40,0x22,0x1e,0x00,
+/* 19193 0x4af9 "䫹" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x00,0xc0,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x7e,0x40,0x22,0x1e,0x00,
+/* 19194 0x4afa "䫺" */
+0x10,0x11,0x11,0xfd,0x11,0x11,0x21,0x29,0x29,0x29,0x51,0x55,0x5d,0x85,0x02,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 19195 0x4afb "䫻" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x00,0xde,0x52,0x52,0x52,0x5e,0x52,0x52,0x52,0x52,0x5e,0x40,0x40,0x22,0x1e,0x00,
+/* 19196 0x4afc "䫼" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x10,0x10,0x7c,0x14,0x14,0x14,0xfe,0x10,0x28,0x24,0x44,0x80,0x42,0x3e,0x00,
+/* 19197 0x4afd "䫽" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x00,0xc6,0x58,0x48,0x4e,0x58,0x4e,0x78,0x4a,0x4a,0x4a,0x46,0x40,0x22,0x1e,0x00,
+/* 19198 0x4afe "䫾" */
+0x00,0x7c,0x44,0x4c,0x74,0x54,0x55,0x7d,0x56,0x7c,0x54,0x55,0x52,0x7d,0x44,0x80,
+0x40,0x20,0x28,0x08,0x48,0x54,0x52,0x62,0x60,0x44,0xc4,0x3c,0x00,0x00,0x82,0x7e,
+/* 19199 0x4aff "䫿" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x1e,0xca,0x4a,0x4a,0x52,0x66,0x40,0x5e,0x52,0x52,0x5e,0x52,0x40,0x22,0x1e,0x00,
+/* 19200 0x4b00 "䬀" */
+0x00,0x7c,0x44,0x4c,0x75,0x55,0x54,0x7c,0x54,0x7d,0x54,0x54,0x52,0x7d,0x44,0x80,
+0x48,0x48,0x88,0xbe,0x2a,0xca,0x4a,0x8a,0xaa,0xf2,0x12,0x2a,0x44,0x00,0x82,0x7e,
+/* 19201 0x4b01 "䬁" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x08,0x7e,0x42,0x20,0x24,0x38,0x20,0x22,0x22,0x1e,0x00,0x80,0x42,0x3e,0x00,
+/* 19202 0x4b02 "䬂" */
+0x00,0x7c,0x44,0x4d,0x75,0x55,0x55,0x7d,0x55,0x7d,0x55,0x55,0x52,0x7d,0x44,0x80,
+0x28,0x24,0x20,0xfc,0x20,0x24,0x24,0x28,0x28,0x10,0x94,0x2c,0x44,0x00,0x82,0x7e,
+/* 19203 0x4b03 "䬃" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x08,0x00,0x7c,0x00,0x44,0x24,0x28,0x28,0x10,0xfe,0x00,0x80,0x42,0x3e,0x00,
+/* 19204 0x4b04 "䬄" */
+0x00,0x7c,0x44,0x4d,0x75,0x55,0x55,0x7d,0x55,0x7d,0x55,0x55,0x52,0x7d,0x44,0x80,
+0x14,0x12,0x10,0xfe,0x10,0x14,0x14,0xd4,0x08,0x0a,0x1a,0x26,0x42,0x00,0x82,0x7e,
+/* 19205 0x4b05 "䬅" */
+0x00,0x7c,0x45,0x4c,0x74,0x55,0x56,0x7d,0x57,0x7d,0x55,0x56,0x52,0x7d,0x44,0x80,
+0x40,0x40,0xfc,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x52,0x5a,0xe4,0x82,0x7e,
+/* 19206 0x4b06 "䬆" */
+0x00,0x7d,0x44,0x4c,0x77,0x54,0x55,0x7d,0x56,0x7c,0x54,0x54,0x52,0x7d,0x44,0x80,
+0x44,0x84,0x94,0x94,0xf4,0x94,0x94,0xd4,0xb4,0x94,0x84,0x94,0x88,0x00,0x82,0x7e,
+/* 19207 0x4b07 "䬇" */
+0x44,0x25,0x29,0x01,0x7d,0x45,0x45,0x45,0x7d,0x29,0x29,0x29,0x2b,0x4d,0x8a,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 19208 0x4b08 "䬈" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x00,0x44,0x28,0x00,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x86,0x80,0x42,0x3e,0x00,
+/* 19209 0x4b09 "䬉" */
+0x00,0x7c,0x45,0x4c,0x74,0x57,0x54,0x7c,0x55,0x7d,0x56,0x54,0x52,0x7d,0x44,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x50,0x50,0x54,0x52,0x52,0x90,0x90,0x30,0x82,0x7e,
+/* 19210 0x4b0a "䬊" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x10,0xfe,0x10,0x54,0x54,0xba,0x10,0x28,0x24,0x42,0x80,0x80,0x42,0x3e,0x00,
+/* 19211 0x4b0b "䬋" */
+0x00,0x7c,0x44,0x4c,0x75,0x54,0x55,0x7c,0x54,0x7d,0x54,0x54,0x52,0x7d,0x44,0x80,
+0x20,0x20,0xf8,0x20,0xfc,0x88,0x44,0x78,0x88,0x50,0x20,0x50,0x88,0x08,0x82,0x7e,
+/* 19212 0x4b0c "䬌" */
+0x10,0x1d,0x11,0x7d,0x55,0x59,0x71,0x55,0x4d,0x41,0x5d,0x55,0x57,0x95,0x22,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 19213 0x4b0d "䬍" */
+0x00,0x7c,0x44,0x4d,0x76,0x54,0x55,0x7c,0x54,0x7c,0x55,0x55,0x52,0x7d,0x44,0x80,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x54,0x88,0x20,0x14,0x52,0x4a,0x38,0x00,0x82,0x7e,
+/* 19214 0x4b0e "䬎" */
+0x00,0x7c,0x47,0x4c,0x74,0x55,0x55,0x7d,0x55,0x7c,0x54,0x57,0x52,0x7d,0x44,0x80,
+0x14,0x12,0xfe,0x10,0x10,0xd4,0x54,0x54,0xcc,0x0a,0xca,0x16,0x22,0x40,0x82,0x7e,
+/* 19215 0x4b0f "䬏" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x20,0x10,0x7c,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x80,0x42,0x3e,0x00,
+/* 19216 0x4b10 "䬐" */
+0x00,0x7c,0x44,0x4d,0x74,0x54,0x55,0x7c,0x57,0x7c,0x55,0x54,0x53,0x7d,0x44,0x80,
+0x18,0xe0,0x20,0xfc,0x70,0xa8,0x24,0x40,0xfe,0x88,0x90,0x70,0x8c,0x00,0x82,0x7e,
+/* 19217 0x4b11 "䬑" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x7c,0x54,0x7c,0x54,0x7c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xcc,0x42,0x3e,0x00,
+/* 19218 0x4b12 "䬒" */
+0x00,0x7d,0x45,0x4c,0x74,0x55,0x54,0x7c,0x55,0x7c,0x54,0x54,0x52,0x7d,0x44,0x80,
+0x20,0xfc,0x04,0x50,0x88,0x24,0x50,0x88,0x06,0xf8,0x08,0x50,0x20,0x50,0x8a,0x7e,
+/* 19219 0x4b13 "䬓" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x80,0x42,0x3e,0x00,
+/* 19220 0x4b14 "䬔" */
+0x00,0x7c,0x44,0x4d,0x74,0x54,0x55,0x7d,0x55,0x7d,0x55,0x55,0x53,0x7d,0x44,0x80,
+0x20,0x50,0x88,0x04,0xf8,0x00,0xc4,0x54,0xd4,0x54,0xd4,0x44,0x54,0x48,0x82,0x7e,
+/* 19221 0x4b15 "䬕" */
+0x00,0x7d,0x45,0x4d,0x75,0x55,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x49,0x82,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 19222 0x4b16 "䬖" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x7c,0x10,0x7c,0x10,0xfc,0x42,0x3e,0x00,
+/* 19223 0x4b17 "䬗" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x2a,0x4a,0x92,0x2a,0x45,
+0x00,0xf8,0x88,0x98,0xe8,0xa8,0xa8,0xf8,0xa8,0xf8,0xa8,0xaa,0xaa,0xfa,0x86,0x02,
+/* 19224 0x4b18 "䬘" */
+0x00,0x7d,0x44,0x4c,0x74,0x54,0x54,0x7d,0x55,0x7d,0x55,0x55,0x53,0x7d,0x44,0x80,
+0x20,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x04,0x74,0x54,0x74,0x0c,0x00,0x82,0x7e,
+/* 19225 0x4b19 "䬙" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x0e,0x70,0x12,0x44,0x20,0x7c,0x90,0x10,0xfe,0x10,0x54,0x7c,0x80,0x42,0x3e,0x00,
+/* 19226 0x4b1a "䬚" */
+0x00,0x7d,0x45,0x4d,0x75,0x55,0x55,0x7d,0x54,0x7d,0x55,0x54,0x52,0x7d,0x44,0x80,
+0x00,0xfc,0x20,0xf8,0x20,0xf8,0x20,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,0x82,0x7e,
+/* 19227 0x4b1b "䬛" */
+0x01,0x7d,0x45,0x4d,0x75,0x54,0x54,0x7f,0x54,0x7c,0x55,0x54,0x53,0x7d,0x44,0x80,
+0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0xa2,0x7e,
+/* 19228 0x4b1c "䬜" */
+0x00,0x7c,0x45,0x4c,0x75,0x55,0x55,0x7c,0x55,0x7d,0x55,0x55,0x53,0x7d,0x44,0x80,
+0x40,0x20,0xfc,0x50,0x24,0x54,0xfc,0x20,0xfc,0x44,0x54,0x74,0x0c,0x00,0x82,0x7e,
+/* 19229 0x4b1d "䬝" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x28,0x7c,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x44,0x82,0x42,0x3e,0x00,
+/* 19230 0x4b1e "䬞" */
+0x00,0x7d,0x44,0x4c,0x74,0x55,0x54,0x7c,0x54,0x7d,0x54,0x55,0x53,0x7d,0x44,0x80,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xf8,0x20,0xfe,0x04,0xde,0x54,0xcc,0x82,0x7e,
+/* 19231 0x4b1f "䬟" */
+0x00,0x7d,0x45,0x4d,0x75,0x55,0x55,0x7c,0x55,0x7c,0x55,0x55,0x52,0x7d,0x44,0x80,
+0x82,0x7a,0x2a,0xaa,0x4a,0x9a,0x42,0xa2,0xf2,0x4a,0xf2,0x52,0xe6,0xf8,0x82,0x7e,
+/* 19232 0x4b20 "䬠" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7f,0x08,0x72,0x12,0xff,0x12,0x22,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x04,0xe8,0x24,0x12,0x0e,0xd0,0x2a,0x1e,
+/* 19233 0x4b21 "䬡" */
+0x02,0x3f,0x02,0xff,0x1c,0xef,0x08,0x0f,0x00,0x7f,0x08,0x72,0x12,0xff,0x12,0x22,
+0x00,0xd0,0x60,0xfe,0x10,0xf0,0x10,0xf0,0x04,0xe8,0x24,0x12,0x0e,0xd0,0x2a,0x1e,
+/* 19234 0x4b22 "䬢" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x33,0x22,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 19235 0x4b23 "䬣" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x20,0x20,0x20,0x7e,0x40,0x80,0x3c,0x04,0x08,0x10,0x20,0x40,0x42,0x42,0x3e,0x00,
+/* 19236 0x4b24 "䬤" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x23,0x2c,0x37,0x24,0x27,0x24,0x27,0x44,0x45,0x86,
+0x00,0xfc,0x04,0x04,0xfc,0x80,0x60,0x98,0xf6,0x10,0xf0,0x10,0xf4,0x68,0x18,0x04,
+/* 19237 0x4b25 "䬥" */
+0x04,0x02,0x01,0xff,0x00,0x01,0x02,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x20,0x10,0x3e,0xc0,0x22,0x1a,0x86,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19238 0x4b26 "䬦" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa3,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 19239 0x4b27 "䬧" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa3,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x92,0x8e,0x00,
+/* 19240 0x4b28 "䬨" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7d,0x44,0x7c,0x41,0x51,0x4a,0x54,0x64,0x40,
+0x80,0x80,0x80,0xfe,0x02,0x82,0x82,0xe2,0xa2,0xa2,0x2a,0x2a,0x1a,0x02,0x14,0x08,
+/* 19241 0x4b29 "䬩" */
+0x00,0x7f,0x01,0x03,0x0d,0x71,0x02,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x00,0xfc,0x00,0x60,0x18,0x04,0x80,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19242 0x4b2a "䬪" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x21,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0x64,0xa2,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 19243 0x4b2b "䬫" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xd6,0x8a,
+/* 19244 0x4b2c "䬬" */
+0x10,0x10,0x28,0x25,0x53,0xfd,0x45,0x7d,0x45,0x7f,0x40,0x50,0x48,0x54,0x65,0x42,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 19245 0x4b2d "䬭" */
+0x00,0x7d,0x44,0x44,0x7c,0x01,0x02,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x00,0xfc,0x44,0x44,0x94,0x08,0x80,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19246 0x4b2e "䬮" */
+0x10,0x10,0x29,0x25,0x53,0xfd,0x45,0x7d,0x45,0x7d,0x41,0x51,0x49,0x54,0x64,0x40,
+0x08,0x48,0x28,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x48,0x94,0x14,0x22,0x42,0x82,
+/* 19247 0x4b2f "䬯" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 19248 0x4b30 "䬰" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0xfe,0x22,0x22,0x22,0x22,0x4a,0x44,0x80,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,
+/* 19249 0x4b31 "䬱" */
+0x10,0x10,0x28,0x24,0x53,0xfc,0x44,0x7c,0x45,0x7d,0x42,0x50,0x48,0x54,0x64,0x40,
+0x20,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0xf8,0x20,0x20,0x20,0x20,
+/* 19250 0x4b32 "䬲" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x28,0x10,
+/* 19251 0x4b33 "䬳" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x43,0x50,0x48,0x54,0x64,0x40,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 19252 0x4b34 "䬴" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7d,0x44,0x7c,0x40,0x51,0x49,0x56,0x64,0x40,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 19253 0x4b35 "䬵" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x51,0x48,0x54,0x64,0x41,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 19254 0x4b36 "䬶" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xa4,0xc2,0x80,
+/* 19255 0x4b37 "䬷" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x23,0x3e,0x20,0x29,0x24,0x2a,0x32,0x21,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 19256 0x4b38 "䬸" */
+0x7f,0x08,0x1e,0x22,0x54,0x09,0x32,0xcd,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x7c,0x04,0x28,0x10,0x28,0x44,0x80,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19257 0x4b39 "䬹" */
+0x10,0x11,0x28,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x41,0x50,0x48,0x54,0x67,0x40,
+0x00,0xfe,0x20,0x20,0x48,0x84,0xfe,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 19258 0x4b3a "䬺" */
+0x11,0x10,0x28,0x24,0x53,0xfc,0x44,0x7d,0x44,0x7c,0x43,0x50,0x48,0x54,0x64,0x40,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 19259 0x4b3b "䬻" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x45,0x7c,0x44,0x7d,0x40,0x50,0x48,0x54,0x65,0x40,
+0x28,0x24,0x3e,0xe0,0x20,0x3c,0xe0,0x20,0x3e,0xe0,0x22,0x24,0x18,0x6a,0x86,0x02,
+/* 19260 0x4b3c "䬼" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x8a,0x84,
+/* 19261 0x4b3d "䬽" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x84,0x44,0x48,0x00,0xfc,0x84,0x84,0x84,0xfc,0x48,0x48,0x48,0x48,0x8a,0x8a,0x06,
+/* 19262 0x4b3e "䬾" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x45,0x7d,0x45,0x7d,0x40,0x50,0x48,0x54,0x65,0x40,
+0x88,0x48,0x50,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0x6a,0xa4,0x20,0x20,
+/* 19263 0x4b3f "䬿" */
+0x10,0x11,0x29,0x25,0x53,0xfd,0x45,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x42,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x1c,0x70,0x1c,0x70,0x1e,0xf0,0x10,0x12,0x12,0x0e,
+/* 19264 0x4b40 "䭀" */
+0x10,0x10,0x2a,0x25,0x51,0xf8,0x48,0x7b,0x49,0x79,0x41,0x51,0x49,0x5a,0x6c,0x40,
+0x00,0x78,0x28,0x28,0x28,0x28,0x78,0x28,0x28,0x2a,0x2a,0x26,0x22,0x80,0x7e,0x00,
+/* 19265 0x4b41 "䭁" */
+0x10,0xfe,0x10,0x1c,0xf0,0x11,0x32,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x0c,0xf0,0x80,0xfe,0x88,0x08,0x88,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19266 0x4b42 "䭂" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x45,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 19267 0x4b43 "䭃" */
+0x10,0x10,0x28,0x24,0x51,0xfa,0x49,0x78,0x48,0x78,0x40,0x52,0x4a,0x5a,0x6c,0x40,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 19268 0x4b44 "䭄" */
+0x10,0x10,0x2b,0x24,0x53,0xfd,0x45,0x7c,0x45,0x7c,0x43,0x50,0x49,0x54,0x64,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xa0,0x40,
+/* 19269 0x4b45 "䭅" */
+0x10,0x11,0x29,0x25,0x53,0xfd,0x45,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 19270 0x4b46 "䭆" */
+0x7f,0x48,0x7e,0x42,0x7e,0x49,0x7e,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x20,0x30,0x28,0x24,0x20,0x20,0x80,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19271 0x4b47 "䭇" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x47,0x7c,0x45,0x7c,0x41,0x51,0x49,0x54,0x64,0x40,
+0x80,0x80,0xfc,0x04,0x44,0x44,0xfc,0x44,0xf4,0x04,0xf4,0x14,0xf4,0x04,0x28,0x10,
+/* 19272 0x4b48 "䭈" */
+0x10,0x10,0x28,0x27,0x51,0xf9,0x4a,0x7a,0x4f,0x79,0x41,0x55,0x4a,0x53,0x64,0x48,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 19273 0x4b49 "䭉" */
+0x10,0x10,0x28,0x24,0x52,0xfd,0x46,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x40,
+0x20,0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 19274 0x4b4a "䭊" */
+0x10,0x10,0x2b,0x24,0x52,0xfc,0x45,0x7d,0x45,0x7d,0x43,0x50,0x48,0x54,0x65,0x42,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 19275 0x4b4b "䭋" */
+0x11,0x11,0x29,0x26,0x52,0xfe,0x4a,0x7a,0x4a,0x7a,0x42,0x52,0x4a,0x5b,0x6a,0x42,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 19276 0x4b4c "䭌" */
+0x10,0xff,0x10,0x7e,0x42,0x7f,0x02,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x8c,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19277 0x4b4d "䭍" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x44,0x7c,0x45,0x7c,0x41,0x51,0x49,0x55,0x67,0x40,
+0x20,0x20,0xfc,0x20,0x20,0xf8,0x20,0x20,0xfc,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 19278 0x4b4e "䭎" */
+0x10,0x11,0x29,0x27,0x51,0xf9,0x49,0x79,0x49,0x78,0x43,0x50,0x48,0x59,0x6e,0x40,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 19279 0x4b4f "䭏" */
+0x10,0x10,0x29,0x25,0x51,0xf9,0x49,0x79,0x49,0x79,0x41,0x52,0x4a,0x5a,0x6c,0x40,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 19280 0x4b50 "䭐" */
+0x11,0x10,0x28,0x27,0x50,0xf8,0x49,0x78,0x48,0x7b,0x40,0x50,0x4a,0x5a,0x6c,0x40,
+0x04,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 19281 0x4b51 "䭑" */
+0x10,0x10,0x28,0x25,0x52,0xfd,0x44,0x7d,0x44,0x7d,0x40,0x50,0x49,0x56,0x64,0x40,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 19282 0x4b52 "䭒" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x50,0x49,0x55,0x66,0x40,
+0x10,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,0x00,
+/* 19283 0x4b53 "䭓" */
+0x10,0x11,0x29,0x25,0x53,0xfc,0x47,0x7c,0x45,0x7d,0x41,0x51,0x48,0x54,0x67,0x40,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 19284 0x4b54 "䭔" */
+0x10,0x12,0x29,0x25,0x50,0xf8,0x4b,0x79,0x49,0x79,0x41,0x51,0x49,0x5a,0x6c,0x40,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 19285 0x4b55 "䭕" */
+0x10,0xfe,0x54,0x7c,0x54,0xff,0x12,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x0c,0xf0,0x80,0xfe,0x88,0x08,0x88,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 19286 0x4b56 "䭖" */
+0x10,0x10,0x29,0x25,0x51,0xf9,0x49,0x79,0x49,0x79,0x41,0x51,0x4a,0x52,0x65,0x48,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0xd4,0xaa,0x2a,0x00,
+/* 19287 0x4b57 "䭗" */
+0x10,0x10,0x29,0x24,0x50,0xfb,0x48,0x79,0x49,0x79,0x41,0x51,0x48,0x58,0x69,0x46,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x92,0x12,0x0e,
+/* 19288 0x4b58 "䭘" */
+0x10,0x11,0x29,0x25,0x51,0xf9,0x48,0x7b,0x48,0x79,0x41,0x51,0x48,0x59,0x6a,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 19289 0x4b59 "䭙" */
+0x10,0x13,0x28,0x26,0x53,0xf9,0x4a,0x7c,0x49,0x79,0x41,0x51,0x49,0x59,0x69,0x41,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 19290 0x4b5a "䭚" */
+0x10,0x11,0x28,0x24,0x53,0xfc,0x45,0x7d,0x45,0x7d,0x41,0x50,0x49,0x54,0x67,0x40,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 19291 0x4b5b "䭛" */
+0x10,0x13,0x28,0x25,0x57,0xfa,0x4a,0x7b,0x4a,0x7b,0x42,0x52,0x4b,0x5e,0x68,0x40,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 19292 0x4b5c "䭜" */
+0x10,0x10,0x29,0x24,0x53,0xfc,0x45,0x7e,0x44,0x7c,0x40,0x50,0x48,0x54,0x65,0x40,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 19293 0x4b5d "䭝" */
+0x10,0x10,0x28,0x25,0x52,0xfd,0x45,0x7d,0x45,0x7d,0x40,0x50,0x48,0x54,0x64,0x40,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 19294 0x4b5e "䭞" */
+0x10,0x11,0x29,0x25,0x52,0xfd,0x44,0x7f,0x44,0x7c,0x41,0x50,0x4b,0x54,0x64,0x40,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 19295 0x4b5f "䭟" */
+0x10,0x13,0x28,0x24,0x51,0xfb,0x49,0x79,0x49,0x79,0x40,0x53,0x48,0x58,0x6b,0x40,
+0x88,0xfe,0x88,0x00,0x48,0xfe,0x48,0x78,0x00,0xfc,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 19296 0x4b60 "䭠" */
+0x10,0x13,0x2a,0x26,0x53,0xfa,0x4a,0x7a,0x4b,0x7a,0x42,0x52,0x4a,0x55,0x66,0x48,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 19297 0x4b61 "䭡" */
+0x10,0x13,0x29,0x24,0x51,0xf8,0x4b,0x78,0x49,0x78,0x41,0x50,0x49,0x5a,0x6a,0x44,
+0x3c,0xc0,0x44,0xa4,0xf8,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xc4,0xaa,0x7a,
+/* 19298 0x4b62 "䭢" */
+0x10,0x10,0x2b,0x26,0x51,0xf9,0x4a,0x78,0x49,0x79,0x43,0x50,0x49,0x58,0x68,0x40,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 19299 0x4b63 "䭣" */
+0x10,0x10,0x2b,0x24,0x50,0xff,0x4a,0x7a,0x4d,0x78,0x41,0x51,0x49,0x59,0x69,0x42,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 19300 0x4b64 "䭤" */
+0x10,0x10,0x2a,0x25,0x51,0xf8,0x48,0x7b,0x49,0x79,0x41,0x51,0x49,0x59,0x6a,0x44,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x40,0x7c,0x44,0x7c,0x80,0x7e,
+/* 19301 0x4b65 "䭥" */
+0x11,0x10,0x2b,0x24,0x51,0xf8,0x4b,0x79,0x49,0x7b,0x45,0x51,0x49,0x59,0x69,0x41,
+0x08,0x90,0xfc,0x40,0xf8,0x80,0xfc,0x48,0xfc,0x0a,0xf8,0x08,0xfa,0x34,0x8c,0x02,
+/* 19302 0x4b66 "䭦" */
+0x10,0x13,0x28,0x24,0x52,0xf8,0x4c,0x7a,0x4a,0x78,0x41,0x52,0x4e,0x5a,0x6a,0x42,
+0x88,0xfe,0x88,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x2c,
+/* 19303 0x4b67 "䭧" */
+0x10,0x13,0x2a,0x27,0x52,0xfa,0x4b,0x7a,0x4a,0x7a,0x42,0x52,0x4a,0x5a,0x6a,0x44,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x20,0x44,0x78,0x14,0xfe,0x10,0x54,0xb2,
+/* 19304 0x4b68 "䭨" */
+0x12,0x13,0x28,0x25,0x53,0xfd,0x49,0x79,0x49,0x79,0x41,0x53,0x4a,0x5b,0x6a,0x42,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 19305 0x4b69 "䭩" */
+0x10,0x13,0x2a,0x27,0x52,0xfa,0x4b,0x7a,0x4a,0x7b,0x42,0x53,0x4a,0x55,0x64,0x48,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 19306 0x4b6a "䭪" */
+0x20,0x21,0x21,0x3d,0x45,0x4b,0x80,0x21,0x21,0x21,0x21,0x25,0x28,0x31,0x20,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,
+/* 19307 0x4b6b "䭫" */
+0x40,0x44,0x59,0x60,0x42,0x42,0x3e,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x84,0x48,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 19308 0x4b6c "䭬" */
+0x40,0x45,0x59,0x60,0x42,0x42,0x3e,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x92,0x24,0x24,0x92,0x00,0xfe,0x10,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 19309 0x4b6d "䭭" */
+0x44,0x28,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19310 0x4b6e "䭮" */
+0x3f,0x20,0xff,0x22,0x7f,0x10,0x08,0xff,0x02,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,
+0x04,0x18,0x62,0x0c,0x70,0x10,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,
+/* 19311 0x4b6f "䭯" */
+0x04,0x78,0x11,0xff,0x11,0x39,0x55,0x90,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7d,0x44,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 19312 0x4b70 "䭰" */
+0x04,0x78,0x11,0xfe,0x10,0x38,0x57,0x90,0x7d,0x46,0x44,0x7c,0x45,0x44,0x7c,0x44,
+0x20,0x20,0xfc,0x40,0xf8,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfc,0x20,0x20,0x20,
+/* 19313 0x4b71 "䭱" */
+0x04,0x79,0x10,0xfe,0x10,0x39,0x55,0x91,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x24,0x24,0x74,0xac,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 19314 0x4b72 "䭲" */
+0x04,0x78,0x11,0xfe,0x10,0x39,0x57,0x90,0x7d,0x45,0x45,0x7d,0x45,0x44,0x7c,0x44,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 19315 0x4b73 "䭳" */
+0x7c,0x11,0xfd,0x39,0x55,0xfd,0x24,0x1b,0x65,0x7f,0x09,0x3f,0xc8,0x0f,0x08,0x0f,
+0x40,0xfc,0x24,0xfc,0x24,0xfc,0x68,0xa2,0x1e,0xf8,0x20,0xf8,0x26,0xe0,0x20,0xe0,
+/* 19316 0x4b74 "䭴" */
+0x00,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x00,0x29,0x44,0x01,0xff,0x01,0x01,0x01,
+0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x04,0x24,0x94,0x08,0xfe,0x00,0x00,0x00,
+/* 19317 0x4b75 "䭵" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x58,0x58,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 19318 0x4b76 "䭶" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,0x08,
+/* 19319 0x4b77 "䭷" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x1c,0x70,0x10,0x10,0x1c,0x70,0x10,0x90,0x9e,0xf0,0x90,0x92,0x92,0x12,0x0e,
+/* 19320 0x4b78 "䭸" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x10,0x88,0x84,0x84,0x02,0x02,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 19321 0x4b79 "䭹" */
+0x00,0x7c,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x84,0x14,0x08,
+0x00,0x40,0x9e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x5a,0x94,0x10,0x10,0x10,0x10,
+/* 19322 0x4b7a "䭺" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 19323 0x4b7b "䭻" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x49,0x4a,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 19324 0x4b7c "䭼" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3c,0x00,0x00,0x00,0x7e,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x44,0x84,
+/* 19325 0x4b7d "䭽" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x28,0x28,0x28,0x3e,0x28,0x48,0x08,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,
+/* 19326 0x4b7e "䭾" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x20,0x28,0x24,0x24,0x20,0x20,0xfc,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 19327 0x4b7f "䭿" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 19328 0x4b80 "䮀" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 19329 0x4b81 "䮁" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x20,0x20,0x40,0x48,0x84,0xfc,0x04,0x48,0x48,0xfe,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 19330 0x4b82 "䮂" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x3c,0x34,0x54,0x54,0x54,0x88,0x88,0x14,0x22,
+/* 19331 0x4b83 "䮃" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0xfe,0x10,0x10,0x20,0x28,0x44,0xfe,0x42,0x00,
+/* 19332 0x4b84 "䮄" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x08,0x08,0x7e,0x10,0x10,0x24,0x24,0xb8,0x88,0x90,0x90,0xa4,0xbe,0x02,0x00,
+/* 19333 0x4b85 "䮅" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x14,0x12,0x12,0x10,0xfe,0x90,0x92,0x92,0x92,0x94,0x94,0xb4,0xca,0x8a,0x16,0x22,
+/* 19334 0x4b86 "䮆" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x08,0x10,0x34,0x52,0x90,0x10,0x00,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 19335 0x4b87 "䮇" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xab,0x82,0x14,0x08,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 19336 0x4b88 "䮈" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x1e,0x22,0x54,0x08,0x10,0x64,0x88,0x9e,0xa2,0xc2,0x94,0x88,0x10,0x60,
+/* 19337 0x4b89 "䮉" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x40,0x40,0x7e,0x80,0x00,0x1c,0xe0,0xa0,0xa2,0xa4,0xa8,0x90,0x90,0xa8,0xc4,0x82,
+/* 19338 0x4b8a "䮊" */
+0x00,0x7c,0x51,0x7c,0x51,0x7c,0x51,0x51,0x7d,0x04,0x54,0x54,0x54,0x84,0x15,0x0a,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 19339 0x4b8b "䮋" */
+0x00,0x7c,0x53,0x7c,0x50,0x7c,0x50,0x51,0x7d,0x05,0x56,0x54,0x54,0x84,0x15,0x0a,
+0x02,0x02,0xe2,0x8a,0x8a,0xea,0xaa,0x2a,0xaa,0x6a,0x4a,0x4a,0x82,0x82,0x0a,0x04,
+/* 19340 0x4b8c "䮌" */
+0x00,0xf8,0xa0,0xf9,0xa1,0xfb,0xa5,0xa1,0xf9,0x09,0xa9,0xa9,0xa9,0x89,0x09,0x31,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 19341 0x4b8d "䮍" */
+0x3f,0x21,0x3f,0x21,0x3f,0x21,0x3f,0x49,0x86,0x01,0xff,0x04,0x08,0x3a,0xcc,0x08,
+0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x24,0x94,0x08,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 19342 0x4b8e "䮎" */
+0x00,0x7c,0x50,0x7c,0x51,0x7c,0x51,0x50,0x7c,0x05,0x56,0x54,0x54,0x84,0x14,0x08,
+0xc2,0x34,0x18,0x64,0x82,0x20,0xfe,0x50,0x90,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 19343 0x4b8f "䮏" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x10,0x10,0x7c,0x24,0x24,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 19344 0x4b90 "䮐" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x82,0x82,0xaa,0xc6,0x82,0xba,0xaa,0xaa,0xba,0xaa,0x82,0x82,0x8a,0x84,
+/* 19345 0x4b91 "䮑" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x04,0x1e,0xe0,0x12,0x8a,0x4c,0x40,0x08,0xfe,0x08,0x88,0x48,0x28,0x08,0x28,0x10,
+/* 19346 0x4b92 "䮒" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 19347 0x4b93 "䮓" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xab,0xaa,0x82,0x14,0x08,
+0x20,0x20,0x3e,0x20,0xfc,0x84,0xfc,0x84,0xfc,0xa4,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 19348 0x4b94 "䮔" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x04,0x1e,0xf0,0x10,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0x10,0xfe,0x00,
+/* 19349 0x4b95 "䮕" */
+0x00,0xfb,0xa0,0xf9,0xa0,0xf9,0xa2,0xa4,0xf8,0x0b,0xa8,0xa9,0xa8,0x89,0x0a,0x34,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 19350 0x4b96 "䮖" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 19351 0x4b97 "䮗" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x83,0x15,0x0a,
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x80,0xbe,0x88,0x88,0xfe,0x88,0x08,0x08,0x08,
+/* 19352 0x4b98 "䮘" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 19353 0x4b99 "䮙" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x08,0x0c,0x0a,0x08,0xfe,0x08,0x08,0xea,0xaa,0xaa,0xec,0x0c,0x2a,0xca,0x16,0x22,
+/* 19354 0x4b9a "䮚" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0x7e,0x10,0x10,0xfe,0x24,0x42,0x90,0x3c,0x44,0xa4,0x28,0x10,0x28,0xc6,
+/* 19355 0x4b9b "䮛" */
+0x00,0xfb,0xa2,0xfa,0xa2,0xfa,0xa3,0xa2,0xfa,0x0a,0xaa,0xaa,0xab,0x8a,0x0a,0x32,
+0x14,0x94,0x94,0xa4,0xbe,0xa4,0x64,0xb4,0xac,0xac,0xa4,0xa4,0x24,0x24,0x24,0x2c,
+/* 19356 0x4b9c "䮜" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x14,0x54,0x54,0xfe,0x54,0x54,0x5c,0x40,0x7e,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,
+/* 19357 0x4b9d "䮝" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 19358 0x4b9e "䮞" */
+0x00,0x7e,0x49,0x7e,0x48,0x7e,0x49,0x48,0x7f,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 19359 0x4b9f "䮟" */
+0x00,0x7c,0x51,0x7d,0x50,0x7d,0x50,0x50,0x7d,0x04,0x54,0x54,0x54,0x84,0x14,0x0b,
+0x40,0x20,0xfe,0x22,0xa4,0x28,0x50,0x88,0x04,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 19360 0x4ba0 "䮠" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 19361 0x4ba1 "䮡" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x3c,0x44,0xa8,0x10,0x28,0xc6,
+/* 19362 0x4ba2 "䮢" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x04,0x1e,0xf0,0x10,0x10,0xfe,0x10,0x50,0x96,0x92,0x92,0xd6,0x92,0x92,0xfe,0x82,
+/* 19363 0x4ba3 "䮣" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfc,0x44,0x38,0x44,0xee,0xaa,0x44,0xaa,0x10,0xfe,0x38,0x54,0x92,0x10,0x10,
+/* 19364 0x4ba4 "䮤" */
+0x00,0x7e,0x49,0x7f,0x48,0x7e,0x48,0x49,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x20,0xfe,0x52,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 19365 0x4ba5 "䮥" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 19366 0x4ba6 "䮦" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,
+/* 19367 0x4ba7 "䮧" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x12,0x12,0x14,0x10,
+0x10,0x28,0x44,0x82,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x02,0xaa,0xaa,0x14,0x08,
+/* 19368 0x4ba8 "䮨" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0xfe,0xa2,0x10,0xfe,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,
+/* 19369 0x4ba9 "䮩" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+/* 19370 0x4baa "䮪" */
+0x00,0x7c,0x50,0x7d,0x51,0x7e,0x50,0x50,0x7d,0x04,0x55,0x54,0x54,0x85,0x16,0x08,
+0x84,0x84,0xde,0x44,0x54,0xde,0x44,0x84,0x24,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 19371 0x4bab "䮫" */
+0x00,0xf9,0xa1,0xfb,0xa1,0xf9,0xa0,0xa1,0xf9,0x09,0xa8,0xab,0xa8,0x89,0x08,0x33,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 19372 0x4bac "䮬" */
+0x00,0x7e,0x49,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xab,0xaa,0x82,0x14,0x09,
+0x48,0x48,0xfe,0x48,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 19373 0x4bad "䮭" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x0e,0xf0,0x22,0x92,0x44,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x28,0x48,0x8a,0x06,
+/* 19374 0x4bae "䮮" */
+0x00,0x7c,0x53,0x7c,0x50,0x7d,0x52,0x50,0x7c,0x05,0x56,0x54,0x55,0x84,0x14,0x09,
+0x20,0x20,0xfe,0xa8,0xa8,0x74,0x22,0x70,0xa8,0x46,0x78,0x88,0x50,0x20,0x50,0x80,
+/* 19375 0x4baf "䮯" */
+0x00,0xf8,0xa0,0xfb,0xa0,0xfb,0xa0,0xa7,0xf9,0x09,0xa9,0xa9,0xa9,0x8a,0x0a,0x34,
+0x88,0x88,0x88,0xd0,0x9e,0xe4,0x94,0xd4,0x14,0xd4,0x54,0x48,0x48,0x54,0xd4,0x22,
+/* 19376 0x4bb0 "䮰" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x82,0x92,0xfe,0x92,0xba,0xaa,0xaa,0xba,0x82,0x86,
+/* 19377 0x4bb1 "䮱" */
+0x00,0xfa,0xa1,0xf9,0xa0,0xf8,0xa6,0xa2,0xfa,0x0a,0xaa,0xaa,0xaa,0x8d,0x08,0x30,
+0x00,0x7e,0x10,0x30,0x4a,0x9a,0x2c,0x4c,0x9a,0x2a,0x4a,0x88,0x28,0x10,0xfe,0x00,
+/* 19378 0x4bb2 "䮲" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x28,0x28,0x7c,0x28,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x28,0x44,0x82,
+/* 19379 0x4bb3 "䮳" */
+0x00,0xfb,0xa1,0xf8,0xa3,0xf8,0xa1,0xa2,0xf9,0x09,0xa9,0xa9,0xa9,0x89,0x09,0x31,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 19380 0x4bb4 "䮴" */
+0x00,0x7e,0x48,0x7f,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x10,0xd4,0x48,0x4a,0x84,0x84,0x7a,0x00,0xfc,0x84,0xfc,0x00,0x84,0x48,0xfe,0x00,
+/* 19381 0x4bb5 "䮵" */
+0x00,0x7d,0x50,0x7c,0x53,0x7c,0x51,0x51,0x7d,0x05,0x55,0x54,0x55,0x84,0x17,0x08,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 19382 0x4bb6 "䮶" */
+0x00,0x7e,0x48,0x7f,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0x10,0xfe,0x38,0x54,0x92,0x10,
+/* 19383 0x4bb7 "䮷" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x49,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0xaa,0xaa,0xfe,0x40,0xfe,0x22,0xfa,0xaa,0xaa,0xfa,0x22,0xfa,0x0a,0x04,
+/* 19384 0x4bb8 "䮸" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x51,0x9f,0x11,0x1f,0x11,0x1f,0x2a,0x49,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0xf4,0x00,0xf0,0x00,0xfc,0x44,0x2c,
+/* 19385 0x4bb9 "䮹" */
+0x00,0xf9,0xa1,0xfb,0xa0,0xf8,0xa3,0xa2,0xfb,0x0a,0xaa,0xaa,0xab,0x8c,0x08,0x33,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 19386 0x4bba "䮺" */
+0x00,0xf8,0xa3,0xf8,0xa0,0xff,0xa2,0xa2,0xfd,0x08,0xa9,0xa9,0xa9,0x89,0x09,0x32,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 19387 0x4bbb "䮻" */
+0x00,0xfb,0xa0,0xf9,0xa0,0xfb,0xa0,0xa1,0xf8,0x0b,0xa8,0xab,0xa8,0x8b,0x0a,0x33,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 19388 0x4bbc "䮼" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xab,0xaa,0x82,0x14,0x08,
+0x12,0x54,0xa8,0x44,0x92,0x54,0x98,0x24,0xc2,0x84,0xee,0x24,0xb4,0x5e,0x44,0x84,
+/* 19389 0x4bbd "䮽" */
+0x00,0xf8,0xa3,0xfa,0xa3,0xfa,0xa3,0xa2,0xfa,0x0a,0xaa,0xaa,0xaa,0x8c,0x09,0x32,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 19390 0x4bbe "䮾" */
+0x01,0xf8,0xa3,0xf8,0xa2,0xf9,0xa3,0xa0,0xfb,0x0a,0xab,0xaa,0xab,0x8a,0x0a,0x32,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 19391 0x4bbf "䮿" */
+0x00,0xfb,0xa2,0xf9,0xa0,0xf9,0xa0,0xa3,0xf8,0x09,0xaa,0xa8,0xa9,0x89,0x0a,0x34,
+0x20,0xfe,0x4a,0xfe,0x48,0xfe,0x48,0xfe,0x84,0xfe,0x84,0xfc,0x20,0x3c,0xa0,0x7e,
+/* 19392 0x4bc0 "䯀" */
+0x03,0xf9,0xa1,0xf9,0xa1,0xf9,0xa7,0xa0,0xff,0x0a,0xab,0xaa,0xab,0x8a,0x0f,0x30,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 19393 0x4bc1 "䯁" */
+0x00,0x0f,0xf2,0xa3,0xf0,0xa7,0xf4,0xa7,0xf2,0x1d,0x57,0xbc,0x95,0x1c,0x57,0x2c,
+0x40,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x20,0x5c,0xf4,0x94,0xdc,0x96,0xf6,0xa2,
+/* 19394 0x4bc2 "䯂" */
+0x3f,0x21,0x3f,0x21,0x3f,0x92,0x7e,0x48,0x7e,0x48,0x7e,0xaa,0x01,0xff,0x09,0x71,
+0xf8,0x00,0xf0,0x00,0xf8,0x48,0xfc,0x90,0xfc,0x90,0xfe,0xaa,0x00,0xfe,0x20,0x1c,
+/* 19395 0x4bc3 "䯃" */
+0x00,0xf8,0x08,0x4b,0x4a,0x4c,0x48,0x7f,0x04,0x04,0x1d,0xe4,0x44,0x04,0x28,0x13,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 19396 0x4bc4 "䯄" */
+0x00,0xf8,0x08,0x48,0x48,0x48,0x48,0x7c,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x11,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 19397 0x4bc5 "䯅" */
+0x00,0xf1,0x10,0x50,0x50,0x50,0x50,0x7b,0x08,0x0b,0x38,0xc9,0x08,0x09,0x2a,0x14,
+0x00,0xfe,0x84,0xfc,0x84,0xfc,0x86,0xfc,0x04,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 19398 0x4bc6 "䯆" */
+0x00,0x7f,0x41,0x79,0x49,0xff,0x80,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x41,0x45,0x42,
+0x20,0x20,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 19399 0x4bc7 "䯇" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x55,0x4a,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 19400 0x4bc8 "䯈" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 19401 0x4bc9 "䯉" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x55,0x4a,
+0x40,0x40,0x40,0x7c,0x44,0x88,0xa0,0x20,0x20,0x50,0x50,0x48,0x88,0x84,0x04,0x02,
+/* 19402 0x4bca "䯊" */
+0x00,0x7c,0x45,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x00,0x00,0xfe,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 19403 0x4bcb "䯋" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7d,0x45,0x46,0x54,0x48,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 19404 0x4bcc "䯌" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x45,0x45,0x56,0x48,
+0x00,0xfe,0x82,0x82,0xfe,0xa0,0xa0,0xa0,0xf8,0xa8,0xa8,0xa8,0x28,0x2a,0x4a,0x86,
+/* 19405 0x4bcd "䯍" */
+0x00,0x7c,0x44,0x74,0x54,0xff,0x82,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 19406 0x4bce "䯎" */
+0x00,0x7c,0x44,0x74,0x54,0xff,0x82,0x7c,0x44,0x7c,0x45,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 19407 0x4bcf "䯏" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x04,0x1e,0xf0,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 19408 0x4bd0 "䯐" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x10,0x10,0x10,0xfe,0x92,0x92,0xaa,0xc6,0x92,0x92,0xaa,0xc6,0x82,0x82,0x8a,0x84,
+/* 19409 0x4bd1 "䯑" */
+0x00,0x7c,0x45,0x74,0x54,0xfe,0x83,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 19410 0x4bd2 "䯒" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0x4e,0x80,0x20,0x20,0x5e,0xc4,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,
+/* 19411 0x4bd3 "䯓" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x83,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x55,0x48,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 19412 0x4bd4 "䯔" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x45,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x10,0xfe,0x02,0x00,0x1c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x1e,0x00,
+/* 19413 0x4bd5 "䯕" */
+0x00,0x7c,0x45,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7d,0x45,0x7c,0x44,0x45,0x56,0x4c,
+0x00,0x06,0xd8,0x48,0x48,0x88,0x9e,0xc8,0x48,0x48,0x48,0x9e,0x80,0x40,0x3e,0x00,
+/* 19414 0x4bd6 "䯖" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 19415 0x4bd7 "䯗" */
+0x01,0x7d,0x45,0x75,0x55,0xff,0x83,0x7d,0x45,0x7c,0x45,0x7c,0x44,0x44,0x57,0x48,
+0x10,0x12,0x14,0xd8,0x10,0x12,0x52,0x8e,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 19416 0x4bd8 "䯘" */
+0x00,0x7c,0x45,0x75,0x56,0xfe,0x82,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x55,0x4a,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 19417 0x4bd9 "䯙" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 19418 0x4bda "䯚" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x44,0xf8,0x10,0x24,0xfe,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 19419 0x4bdb "䯛" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x82,0x7d,0x45,0x7d,0x46,0x7c,0x44,0x44,0x55,0x4a,
+0x40,0x20,0xfc,0x04,0x80,0x9c,0xd4,0x54,0x54,0x54,0xd8,0x50,0x94,0x94,0x14,0x0c,
+/* 19420 0x4bdc "䯜" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x45,0x7e,0x44,0x45,0x54,0x48,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 19421 0x4bdd "䯝" */
+0x00,0x7c,0x44,0x74,0x54,0xff,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 19422 0x4bde "䯞" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x45,0x55,0x49,
+0x00,0xf8,0x88,0x88,0xe8,0xa8,0xa8,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 19423 0x4bdf "䯟" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7d,0x44,0x7c,0x45,0x7c,0x44,0x45,0x54,0x48,
+0x00,0x84,0x48,0x00,0xfe,0x20,0x44,0xa8,0x30,0x58,0x98,0x34,0x52,0x90,0x50,0x20,
+/* 19424 0x4be0 "䯠" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7d,0x45,0x7d,0x45,0x45,0x57,0x48,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 19425 0x4be1 "䯡" */
+0x00,0x7c,0x44,0x75,0x54,0xff,0x82,0x7d,0x44,0x7d,0x44,0x7c,0x45,0x46,0x54,0x48,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 19426 0x4be2 "䯢" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x37,0x22,0x23,0x22,0x2f,0x2a,0x23,0x42,0x42,0x82,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0xfa,0x08,0xc8,0x48,0xfe,0x0a,0xf8,0x08,0x28,0x10,
+/* 19427 0x4be3 "䯣" */
+0x00,0x7d,0x45,0x75,0x54,0xff,0x82,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x45,0x54,0x49,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 19428 0x4be4 "䯤" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x10,0x28,0x44,0xba,0x00,0xfe,0x92,0xd6,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,
+/* 19429 0x4be5 "䯥" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x00,0xfe,0x82,0xfe,0x82,0xfe,0x44,0xaa,0xee,0x44,0xaa,0xee,0x00,0xd4,0xaa,0x2a,
+/* 19430 0x4be6 "䯦" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x24,0xfe,0x24,0x00,0xfe,0xaa,0xaa,0xfe,0x14,0xfe,0x90,0xd2,0xac,0xaa,0x96,0x22,
+/* 19431 0x4be7 "䯧" */
+0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x9f,0x10,0x17,0x14,0x17,0x10,0x10,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x10,0xd0,0x50,0xd0,0x10,0x30,
+/* 19432 0x4be8 "䯨" */
+0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x02,0xff,0x18,0xe0,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xec,0x00,0xfe,0x30,0x0e,
+/* 19433 0x4be9 "䯩" */
+0x01,0xff,0x00,0x1f,0x10,0x7f,0x40,0x4f,0x48,0x4f,0x00,0x3f,0x21,0x3f,0x20,0x1f,
+0x00,0xfe,0x00,0xf0,0x10,0xfc,0x04,0xe4,0x24,0xec,0x00,0xf8,0x08,0xf8,0x02,0xfe,
+/* 19434 0x4bea "䯪" */
+0x20,0x11,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x87,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 19435 0x4beb "䯫" */
+0x00,0x7c,0x45,0x7c,0x44,0x7c,0x10,0xfe,0x01,0x7d,0x45,0x7d,0x11,0x55,0x93,0x31,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 19436 0x4bec "䯬" */
+0x10,0xfe,0x44,0x7c,0x00,0xfe,0xaa,0xba,0x82,0xfe,0x44,0x7c,0x10,0xfe,0x10,0x10,
+0x00,0xee,0xaa,0xaa,0xee,0x00,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 19437 0x4bed "䯭" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 19438 0x4bee "䯮" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x04,0x04,0x08,0x30,0xc0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xe0,0x20,0x7c,0x04,0x14,0x08,
+/* 19439 0x4bef "䯯" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x11,0x21,0x41,0x03,0x1c,0xe0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0x10,0x08,0x64,0x80,0x00,0x00,
+/* 19440 0x4bf0 "䯰" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x02,0x04,0x1c,0xe4,0x04,0x08,0x10,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x80,0x40,0x70,0x4e,0x40,0x40,0x40,
+/* 19441 0x4bf1 "䯱" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x7f,0x01,0x07,0x19,0xe1,0x01,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x00,0x70,0x0c,0x02,0x00,
+/* 19442 0x4bf2 "䯲" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x21,0x3f,0x20,0x20,0x1f,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xf8,0x08,0xf8,0x02,0x02,0xfe,
+/* 19443 0x4bf3 "䯳" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x04,0x08,0x32,0xc4,0x08,0x1f,0x08,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x40,0x20,0x18,0x46,0x20,0xf0,0x10,
+/* 19444 0x4bf4 "䯴" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x0f,0x10,0x60,0x1f,0x08,0x04,0x07,0xf8,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xe0,0x20,0x1c,0xe0,0x20,0xc0,0x80,0x7e,
+/* 19445 0x4bf5 "䯵" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x3f,0x01,0x08,0xff,0x08,0x10,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xf8,0x00,0x20,0xfe,0x20,0x20,
+/* 19446 0x4bf6 "䯶" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x00,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x00,
+/* 19447 0x4bf7 "䯷" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0xff,0x10,0x7e,0x10,0x20,0xc7,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x90,0xfe,0x88,0x50,0x24,0xd4,0x0c,
+/* 19448 0x4bf8 "䯸" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x41,0x21,0x0a,0x10,0xe0,0x21,0x26,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x44,0x48,0xa0,0x18,0x06,
+/* 19449 0x4bf9 "䯹" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x3f,0x00,0x1f,0x00,0x7f,0x40,0x9f,0x08,0x07,0xf8,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x02,0xf4,0x20,0xc0,0x3e,
+/* 19450 0x4bfa "䯺" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x3f,0x21,0x3f,0x20,0x2c,0x30,0x1f,0x10,0x10,0x1f,
+0x04,0x18,0x62,0x0c,0x70,0x18,0xe0,0x00,0xfc,0x80,0x64,0x1c,0xf0,0x10,0x10,0xf0,
+/* 19451 0x4bfb "䯻" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x11,0x1f,0x21,0xff,0x00,0x1f,0x10,0x1f,0x10,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,
+/* 19452 0x4bfc "䯼" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x14,0x08,0x14,0x6c,0x15,0x64,0x19,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0x20,0xa4,0xa8,0x50,0x88,0x06,
+/* 19453 0x4bfd "䯽" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x3f,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,
+/* 19454 0x4bfe "䯾" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x3f,0x21,0x27,0x21,0x2f,0x20,0x27,0x44,0x47,0x80,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf8,0x08,0xc8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x18,
+/* 19455 0x4bff "䯿" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x3f,0x08,0x14,0x01,0x7f,0x01,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xf8,0x20,0x50,0x00,0xfc,0x00,
+/* 19456 0x4c00 "䰀" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x1f,0x01,0xff,0x09,0x71,0x02,0xff,0x08,0x07,0x78,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x00,0xfe,0x20,0x1c,0x00,0xfe,0x20,0xc0,0x38,
+/* 19457 0x4c01 "䰁" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x3f,0x00,0x1f,0x00,0xff,0x11,0x09,0x05,0x19,0xe3,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xa0,0x40,0x30,0x0e,
+/* 19458 0x4c02 "䰂" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x12,0x09,0x7f,0x05,0x19,0xe1,0x01,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x18,0xe0,0x10,0x20,0xfc,0x40,0x30,0x0e,0x00,
+/* 19459 0x4c03 "䰃" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x08,0x04,0x7f,0x04,0x24,0x14,0xff,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x20,0x40,0xfc,0x40,0x48,0x50,0xfe,
+/* 19460 0x4c04 "䰄" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x49,0x48,0x87,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x04,0x92,0xf2,
+/* 19461 0x4c05 "䰅" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,
+/* 19462 0x4c06 "䰆" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x1f,0x02,0x01,0x7f,0x18,0x62,0x01,0xff,0x09,0x71,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x20,0x40,0xfc,0x84,0x88,0x00,0xfe,0x20,0x1c,
+/* 19463 0x4c07 "䰇" */
+0x3f,0x20,0xff,0x22,0x7f,0x02,0x1f,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 19464 0x4c08 "䰈" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x08,0x37,0xc0,0x1f,
+0x04,0x18,0x62,0x0c,0x70,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x80,0xfc,
+/* 19465 0x4c09 "䰉" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x10,0x3e,0x22,0x2a,0xff,0x22,0x2a,0x42,0x4a,0x84,
+0x04,0x18,0x62,0x0c,0x70,0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x10,0x28,0xc6,
+/* 19466 0x4c0a "䰊" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0xff,0x21,0x3f,0x21,0x3f,0x21,0x00,0xff,0x08,0x04,
+0x04,0x18,0x62,0x0c,0x70,0x10,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x20,0xfe,0x20,0x60,
+/* 19467 0x4c0b "䰋" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x7f,0x44,0x3f,0x08,0x07,0x78,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x04,0xf8,0x20,0xc0,0x38,
+/* 19468 0x4c0c "䰌" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x10,0x21,0x4a,0x11,0x31,0x52,0x14,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x88,0x54,0x22,0x3c,0x20,0xa0,0x7e,
+/* 19469 0x4c0d "䰍" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x7f,0x09,0x31,0xc6,0x19,0xe9,0x05,0x19,0x61,0x03,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x10,0x08,0xc4,0x30,0x2e,0xc0,0x30,0x08,0x00,
+/* 19470 0x4c0e "䰎" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x1f,0x11,0x1f,0x01,0xff,0x10,0x1f,0x10,0x1f,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xf0,0x10,0xf0,0x20,
+/* 19471 0x4c0f "䰏" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x7f,0x08,0xff,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x20,
+0x04,0x18,0x62,0x0c,0x70,0x28,0x24,0x20,0xfe,0x20,0xa4,0x24,0x28,0x12,0xaa,0x46,
+/* 19472 0x4c10 "䰐" */
+0x3f,0x20,0xff,0x22,0x7f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x3f,0x24,0x24,0xff,
+0x04,0x18,0x62,0x0c,0x70,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xf8,0x48,0x48,0xfe,
+/* 19473 0x4c11 "䰑" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x3f,0x01,0x7f,0x49,0x85,0x7f,0x02,0x3f,0x24,0x24,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf8,0x00,0xfe,0x22,0x14,0xfc,0x00,0xf8,0x48,0x58,
+/* 19474 0x4c12 "䰒" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x7f,0x08,0x7f,0x40,0x9f,0x06,0x19,0x06,0x38,0x03,
+0x04,0x18,0x62,0x0c,0x70,0x20,0xfc,0x20,0xfe,0x02,0xf4,0x00,0x20,0xc0,0xa0,0x18,
+/* 19475 0x4c13 "䰓" */
+0x3f,0x20,0xff,0x22,0x7f,0x02,0x1f,0x14,0x12,0xff,0x92,0x2f,0x44,0x07,0x08,0x30,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x90,0x50,0xfe,0x12,0xe8,0x04,0xe0,0x20,0x60,
+/* 19476 0x4c14 "䰔" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x3e,0x22,0x2a,0x7e,0x22,0x2a,0x46,0x3f,0x24,0xff,
+0x04,0x18,0x62,0x0c,0x70,0x00,0x78,0x48,0x86,0x78,0x48,0x30,0x4c,0xf8,0x48,0xfe,
+/* 19477 0x4c15 "䰕" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x4f,0x49,0xbf,
+0x04,0x18,0x62,0x0c,0x70,0xfc,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xfc,0x14,0xfe,
+/* 19478 0x4c16 "䰖" */
+0x3f,0x20,0xff,0x22,0x7f,0x28,0x3e,0x48,0xfe,0x15,0x26,0x5f,0x14,0x12,0x1f,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x50,0x7c,0x90,0xfe,0x28,0x4a,0xf6,0x90,0x50,0xf0,0x20,
+/* 19479 0x4c17 "䰗" */
+0xbe,0x88,0xbe,0x88,0xbe,0x84,0x87,0x88,0x97,0x84,0x8f,0x89,0x8f,0x89,0x8f,0x81,
+0xfa,0x22,0xfa,0x22,0xfa,0x02,0x82,0x82,0xc2,0x42,0xe2,0x22,0xe2,0x22,0x12,0xf6,
+/* 19480 0x4c18 "䰘" */
+0xbe,0x88,0xbe,0x88,0xbe,0x80,0xbe,0x92,0x8a,0x93,0x82,0x8c,0xb1,0x86,0x80,0x9f,
+0xfa,0x22,0xfa,0x22,0xfa,0x02,0xfa,0x4a,0x2a,0x4a,0x82,0x62,0x9a,0x02,0x72,0x86,
+/* 19481 0x4c19 "䰙" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 19482 0x4c1a "䰚" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x20,0x10,0x10,0xfe,0x44,0x44,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 19483 0x4c1b "䰛" */
+0x00,0xfe,0x01,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x00,0x00,0xfe,0x40,0x40,0x78,0x48,0x48,0x68,0x98,0x98,0x88,0x8a,0xaa,0xca,0x86,
+/* 19484 0x4c1c "䰜" */
+0x00,0xef,0x20,0x27,0x24,0xe7,0x80,0x8f,0x88,0xea,0x29,0x2f,0x29,0x29,0xa9,0x48,
+0x00,0xee,0x02,0xc2,0x42,0xce,0x08,0xe8,0x28,0xae,0x22,0xe2,0x22,0x22,0x2a,0x64,
+/* 19485 0x4c1d "䰝" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x44,0x24,0x28,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+/* 19486 0x4c1e "䰞" */
+0x71,0x17,0x71,0x47,0x72,0x17,0x5a,0x23,0xff,0x00,0x1f,0x10,0x7f,0x44,0x5f,0x41,
+0x3c,0xc4,0x9c,0xf0,0x5c,0xc4,0x54,0xc8,0xfe,0x00,0xf0,0x10,0xfc,0x44,0xf4,0x0c,
+/* 19487 0x4c1f "䰟" */
+0x3f,0x00,0xff,0x08,0x10,0x3f,0x02,0x1f,0x11,0x1f,0x12,0x1f,0x04,0x08,0x30,0xc0,
+0xf8,0x00,0xfe,0x20,0x10,0xf8,0x08,0xf0,0x10,0xf0,0x10,0xf0,0xa8,0xba,0x82,0x7e,
+/* 19488 0x4c20 "䰠" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x10,0x10,0x10,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x90,0x90,0x10,0x02,0xfe,
+/* 19489 0x4c21 "䰡" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x08,0x08,0x28,0x28,0x3e,0x48,0x08,0x08,0x7e,0x08,0x08,0x94,0x92,0x20,0x42,0xfe,
+/* 19490 0x4c22 "䰢" */
+0x10,0x20,0x7c,0x55,0x54,0x7c,0x54,0x55,0x7c,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x20,0x40,0x8e,0x00,0x20,0x5e,0xc4,0x44,0x44,0x44,0x44,0x54,0x48,0x02,0xfe,0x00,
+/* 19491 0x4c23 "䰣" */
+0x10,0x21,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x11,0x2b,0x2d,0x4f,0x48,0x87,0x00,
+0x00,0xfc,0x04,0x04,0xac,0x54,0x54,0x54,0x54,0xac,0x04,0x14,0x08,0x02,0xfe,0x00,
+/* 19492 0x4c24 "䰤" */
+0x10,0x10,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x10,0x38,0x54,0x92,0x11,0x11,0x12,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x68,0xb2,0xbe,0x20,0x22,0x1e,
+/* 19493 0x4c25 "䰥" */
+0x00,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x11,0x1f,0x12,0x1f,0x04,0x08,0x30,0xc0,
+0x50,0xfc,0x40,0x48,0x50,0x20,0x54,0xfc,0x14,0xf0,0x10,0xf0,0xa8,0xba,0x82,0x7e,
+/* 19494 0x4c26 "䰦" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x00,0x08,0x10,0x7e,0x4a,0x7e,0x52,0x7e,0x28,0x48,0x7e,0x88,0x88,0x08,0x02,0xfe,
+/* 19495 0x4c27 "䰧" */
+0x10,0x20,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x2a,0x2d,0x4f,0x4a,0x87,0x00,
+0x20,0x3c,0x20,0xfe,0xa2,0xb8,0xe4,0x9c,0x80,0xb8,0xa8,0x2a,0x46,0x02,0xfe,0x00,
+/* 19496 0x4c28 "䰨" */
+0x10,0x21,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x11,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x00,0xfc,0x24,0xfc,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x02,0xfe,0x00,
+/* 19497 0x4c29 "䰩" */
+0x10,0x10,0x7d,0x12,0x14,0xff,0x10,0x20,0x7e,0xa2,0x22,0x3e,0x22,0x22,0x3e,0x23,
+0x20,0x40,0xfc,0x94,0x94,0xfc,0xa4,0xa4,0xfc,0x20,0x44,0x6a,0x6e,0xa0,0xa2,0x1e,
+/* 19498 0x4c2a "䰪" */
+0x10,0x92,0x54,0xaa,0x44,0x82,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x4d,
+0x20,0x40,0xfc,0x94,0x94,0xfc,0xa4,0xa4,0xfc,0x20,0x44,0x6a,0x6e,0xa0,0xa2,0x1e,
+/* 19499 0x4c2b "䰫" */
+0x10,0x20,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x10,0x7c,0x10,0xfe,0x44,0xee,0x44,0xee,0x00,0xfe,0x28,0x2a,0x46,0x82,0xfe,0x00,
+/* 19500 0x4c2c "䰬" */
+0x10,0x20,0x7c,0x55,0x54,0x7c,0x55,0x54,0x7c,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0xfc,0x28,0x10,0xfe,0x52,0x90,0xfe,0xaa,0xc6,0xba,0xaa,0xba,0x84,0x02,0xfe,0x00,
+/* 19501 0x4c2d "䰭" */
+0x00,0xfe,0x10,0xfe,0xaa,0xaa,0xaa,0x86,0x00,0xfe,0x10,0xfe,0xaa,0xaa,0xaa,0x87,
+0x20,0x40,0xfc,0x94,0x94,0xfc,0xa4,0xa4,0xfc,0x20,0x44,0x6a,0x6e,0xa0,0xa2,0x1e,
+/* 19502 0x4c2e "䰮" */
+0x20,0x43,0xf8,0xa9,0xa8,0xfb,0xa8,0xa9,0xf8,0x23,0x20,0x54,0x5b,0x5e,0x51,0x8f,
+0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,0xfe,
+/* 19503 0x4c2f "䰯" */
+0x11,0x21,0x7d,0x55,0x54,0x7d,0x55,0x56,0x7d,0x10,0x2b,0x2d,0x4f,0x48,0x87,0x00,
+0x00,0x5c,0x84,0x58,0xc8,0x3e,0xca,0xa8,0xec,0xa8,0x68,0x5e,0x80,0x02,0xfe,0x00,
+/* 19504 0x4c30 "䰰" */
+0x00,0x7c,0x10,0xfe,0x92,0x54,0x10,0x54,0x00,0xfe,0x10,0xfe,0xaa,0xaa,0xaa,0x87,
+0x20,0x40,0xfc,0x94,0x94,0xfc,0xa4,0xa4,0xfc,0x20,0x44,0x6a,0x6e,0xa0,0xa2,0x1e,
+/* 19505 0x4c31 "䰱" */
+0x00,0xfe,0x10,0xfe,0x92,0x54,0x00,0xee,0xaa,0xee,0x00,0xfe,0x54,0xba,0x10,0xff,
+0x20,0x40,0xfc,0x94,0x94,0xfc,0xa4,0xa4,0xfc,0x20,0x44,0x6a,0x6e,0xa0,0xa2,0x1e,
+/* 19506 0x4c32 "䰲" */
+0x10,0x10,0x3e,0x42,0x84,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x00,0x55,0x4a,0x8a,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x9e,0x80,
+/* 19507 0x4c33 "䰳" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 19508 0x4c34 "䰴" */
+0x20,0x20,0x78,0x48,0x91,0x7e,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x80,0xfc,0x00,0x00,0xf8,0x08,0x10,0x20,0x40,0x80,0x84,0x84,0x7c,0x00,
+/* 19509 0x4c35 "䰵" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x52,0x53,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 19510 0x4c36 "䰶" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0x10,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,
+/* 19511 0x4c37 "䰷" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 19512 0x4c38 "䰸" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x00,0xab,0xaa,0x00,
+0x08,0x48,0x48,0x48,0x44,0x84,0xa4,0x22,0x20,0x40,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 19513 0x4c39 "䰹" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 19514 0x4c3a "䰺" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x04,0x0e,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 19515 0x4c3b "䰻" */
+0x10,0x10,0x3e,0x42,0x84,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x00,0x55,0x4a,0x8a,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0xc4,0x82,
+/* 19516 0x4c3c "䰼" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 19517 0x4c3d "䰽" */
+0x20,0x20,0x78,0x4b,0x90,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 19518 0x4c3e "䰾" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 19519 0x4c3f "䰿" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x7e,0x80,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xb4,0xa8,0xa2,0x82,0x7e,0x00,
+/* 19520 0x4c40 "䱀" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xab,0x02,
+0x20,0x20,0x20,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 19521 0x4c41 "䱁" */
+0x20,0x20,0x78,0x48,0x93,0x7c,0x54,0x54,0x7c,0x54,0x55,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0xfa,0x20,0x20,0x20,0x20,
+/* 19522 0x4c42 "䱂" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x55,0x54,0x7c,0x55,0x55,0x7d,0x00,0xaa,0xaa,0x00,
+0x10,0x50,0x50,0x90,0xfc,0x54,0xd4,0x94,0x94,0x14,0x54,0xd4,0x54,0x24,0x34,0x48,
+/* 19523 0x4c43 "䱃" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 19524 0x4c44 "䱄" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 19525 0x4c45 "䱅" */
+0x20,0x20,0x78,0x4b,0x90,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 19526 0x4c46 "䱆" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x55,0x56,0x7c,0x54,0x57,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x44,0x48,0x8e,0x82,0x7a,0x14,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 19527 0x4c47 "䱇" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 19528 0x4c48 "䱈" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x54,0x54,0x7c,0x54,0x55,0x7d,0x02,0xaa,0xaa,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 19529 0x4c49 "䱉" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 19530 0x4c4a "䱊" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x57,0x7c,0x54,0x54,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 19531 0x4c4b "䱋" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0xfe,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 19532 0x4c4c "䱌" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x90,0x90,0x90,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0x90,0x90,0x90,0xfe,0x00,
+/* 19533 0x4c4d "䱍" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x55,0x55,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x78,0x88,0xa8,0x98,0x08,0x48,0x30,0x10,0x10,0xfe,0x00,
+/* 19534 0x4c4e "䱎" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 19535 0x4c4f "䱏" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 19536 0x4c50 "䱐" */
+0x20,0x20,0x79,0x48,0x91,0x7c,0x54,0x55,0x7c,0x54,0x57,0x7c,0x00,0xaa,0xaa,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 19537 0x4c51 "䱑" */
+0x20,0x20,0x78,0x48,0x93,0x7c,0x54,0x54,0x7c,0x57,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x80,0x8c,0xb0,0xa0,0xe0,0xa0,0xbe,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xc8,0x88,
+/* 19538 0x4c52 "䱒" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0x92,0xfe,0x80,0x80,0x82,0x82,0x7e,
+/* 19539 0x4c53 "䱓" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x55,0x7c,0x55,0x55,0x7c,0x00,0xab,0xaa,0x04,
+0x00,0x06,0xd8,0x48,0x48,0x88,0x9e,0xc8,0x48,0x48,0x48,0x9e,0x80,0x40,0x3e,0x00,
+/* 19540 0x4c54 "䱔" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x57,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x88,0x88,0x88,0x10,0x5e,0x64,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x14,0x22,
+/* 19541 0x4c55 "䱕" */
+0x20,0x20,0x78,0x49,0x92,0x7c,0x54,0x54,0x7d,0x54,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 19542 0x4c56 "䱖" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x28,0x28,0x28,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0x28,0x28,0x28,0x48,0x88,
+/* 19543 0x4c57 "䱗" */
+0x08,0x0f,0x28,0x7f,0xa1,0x16,0x38,0xcf,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x00,0x7c,0x44,0x28,0x10,0x28,0x46,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 19544 0x4c58 "䱘" */
+0x03,0x3c,0x04,0x7f,0x16,0x25,0x44,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x04,0x24,0x24,0xa4,0x24,0x04,0x0c,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 19545 0x4c59 "䱙" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x57,0x54,0x7c,0x54,0x55,0x7e,0x00,0xaa,0xaa,0x01,
+0x80,0x80,0x9c,0xf4,0x94,0x94,0xf4,0x14,0x94,0x94,0xc8,0xa8,0x88,0x94,0x94,0xa2,
+/* 19546 0x4c5a "䱚" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x55,0x7c,0x55,0x54,0x7c,0x00,0xab,0xaa,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfc,0x20,0x24,0xa8,0x70,0xa8,0x24,0xa2,0x40,
+/* 19547 0x4c5b "䱛" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7c,0x00,0xab,0xaa,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xca,0x1a,0x26,0x42,
+/* 19548 0x4c5c "䱜" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 19549 0x4c5d "䱝" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x00,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 19550 0x4c5e "䱞" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x56,0x54,0x7c,0x55,0x54,0x7c,0x00,0xab,0xaa,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0xa4,0xa2,0x22,0x20,0x60,
+/* 19551 0x4c5f "䱟" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x00,0xfe,0x82,0x82,0xfe,0x88,0x88,0xfe,0x88,0x88,0xbe,0xa2,0xa2,0xa2,0xbe,0x22,
+/* 19552 0x4c60 "䱠" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x54,0x55,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xaa,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 19553 0x4c61 "䱡" */
+0x20,0x20,0x78,0x49,0x92,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 19554 0x4c62 "䱢" */
+0x20,0x20,0x78,0x49,0x92,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 19555 0x4c63 "䱣" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x56,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 19556 0x4c64 "䱤" */
+0x20,0x20,0x78,0x48,0x91,0x7e,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0x82,0xfe,0x82,
+/* 19557 0x4c65 "䱥" */
+0x24,0x3f,0x44,0xff,0x04,0x3f,0x24,0x2f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x04,0xa4,0x24,0xa4,0x24,0x84,0x94,0xe8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 19558 0x4c66 "䱦" */
+0x20,0x20,0x78,0x48,0x91,0x7e,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 19559 0x4c67 "䱧" */
+0x20,0x21,0x78,0x48,0x91,0x7c,0x57,0x54,0x7d,0x56,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 19560 0x4c68 "䱨" */
+0x20,0x20,0x73,0x90,0x20,0xfb,0xaa,0xaa,0xfa,0xaa,0xa8,0xf9,0x02,0xac,0xa8,0x00,
+0x82,0x82,0xe2,0x8a,0x8a,0xea,0xaa,0xaa,0xaa,0xea,0x8a,0xca,0xa2,0x82,0x8a,0x84,
+/* 19561 0x4c69 "䱩" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x82,0xc6,0xaa,0xfe,0xa2,0x92,0xfe,0xa2,0xa2,0xba,0x82,0x82,0x8a,0x84,
+/* 19562 0x4c6a "䱪" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x20,0x52,0xd4,0x48,0x44,0x62,0x40,
+/* 19563 0x4c6b "䱫" */
+0x04,0x7f,0x04,0x3f,0x24,0x3f,0x15,0x24,0x4f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,
+0x04,0xc4,0x24,0xa4,0xa4,0xa4,0x04,0x94,0xe8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,
+/* 19564 0x4c6c "䱬" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x12,0x90,0x9c,0x90,0x7e,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 19565 0x4c6d "䱭" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x80,0xfe,0x90,0x90,0xd0,0xbc,0x94,0x94,0xac,0xa4,0xb4,0x88,0x88,0x88,0xfe,0x80,
+/* 19566 0x4c6e "䱮" */
+0x20,0x20,0x73,0x90,0x21,0xf8,0xab,0xa8,0xf8,0xa8,0xab,0xf8,0x00,0xa8,0xa9,0x06,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 19567 0x4c6f "䱯" */
+0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 19568 0x4c70 "䱰" */
+0x20,0x20,0x79,0x48,0x93,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7c,0x01,0xaa,0xab,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 19569 0x4c71 "䱱" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x82,0x10,0x7c,0x54,0x54,0x54,0x5c,0x10,0x10,
+/* 19570 0x4c72 "䱲" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7d,0x00,0xaa,0xab,0x00,
+0x40,0x7c,0x84,0xf8,0x08,0xfe,0x40,0xa4,0x38,0x58,0x94,0x34,0x54,0x92,0x50,0x20,
+/* 19571 0x4c73 "䱳" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x00,0xfe,0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x10,0x7c,0x10,0x10,0xfe,
+/* 19572 0x4c74 "䱴" */
+0x20,0x20,0x78,0x48,0x91,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x5e,0x40,0x60,0x5e,0x52,0x52,0x5e,0x52,0x52,0x52,0x5e,0x52,0x40,0x5e,0x40,
+/* 19573 0x4c75 "䱵" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x54,0x54,0x7d,0x54,0x55,0x7c,0x01,0xaa,0xaa,0x00,
+0x50,0x88,0x24,0x40,0x90,0xf8,0x08,0x00,0xdc,0x44,0x54,0xcc,0x54,0x44,0x54,0xc8,
+/* 19574 0x4c76 "䱶" */
+0x21,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xaa,0x00,
+0x00,0x9e,0xd2,0x54,0x54,0xd8,0x54,0x52,0xd2,0x12,0x9a,0x54,0xd0,0x50,0x10,0x10,
+/* 19575 0x4c77 "䱷" */
+0x0f,0x08,0x7f,0x48,0x4e,0x79,0x4f,0x51,0x5f,0x75,0x5f,0x55,0x5f,0x40,0xaa,0x00,
+0x10,0x10,0x90,0xa0,0x3e,0x44,0x24,0x24,0x24,0x28,0x28,0x10,0x28,0x28,0xc4,0x82,
+/* 19576 0x4c78 "䱸" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x03,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 19577 0x4c79 "䱹" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xab,0xaa,0x00,
+0x44,0x24,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x20,0x20,0x7c,0x50,0x90,0x10,0xfe,0x00,
+/* 19578 0x4c7a "䱺" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x57,0x54,0x7d,0x55,0x55,0x7d,0x00,0xaa,0xab,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 19579 0x4c7b "䱻" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+/* 19580 0x4c7c "䱼" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x00,0xfe,0x02,0x02,0xfe,0x24,0x24,0x7e,0x24,0x24,0xfe,0x52,0x54,0x48,0x64,0x42,
+/* 19581 0x4c7d "䱽" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x01,0xab,0xaa,0x00,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 19582 0x4c7e "䱾" */
+0x20,0x21,0x79,0x4b,0x91,0x7d,0x54,0x55,0x7d,0x55,0x54,0x7d,0x00,0xab,0xaa,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 19583 0x4c7f "䱿" */
+0x21,0x21,0x71,0x97,0x21,0xff,0xad,0xaf,0xfd,0xaf,0xa9,0xff,0x01,0xa9,0xa9,0x01,
+0x00,0x02,0x1c,0xd0,0x10,0xd0,0x5e,0xd4,0x54,0xd4,0x14,0xd4,0x14,0x24,0x24,0x44,
+/* 19584 0x4c80 "䲀" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0xe6,0x42,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 19585 0x4c81 "䲁" */
+0x20,0x23,0x72,0x92,0x23,0xfa,0xaa,0xaa,0xfa,0xab,0xaa,0xfa,0x05,0xad,0xaa,0x00,
+0x04,0xe4,0x24,0x24,0xee,0x04,0xe4,0x04,0x0c,0xf4,0x44,0x64,0x54,0x44,0x54,0xc8,
+/* 19586 0x4c82 "䲂" */
+0x22,0x21,0x71,0x97,0x22,0xfa,0xab,0xaa,0xfa,0xaa,0xaa,0xfa,0x04,0xad,0xa8,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 19587 0x4c83 "䲃" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xab,0x00,
+0x92,0x24,0x92,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x38,0x54,0x92,0x10,0x10,
+/* 19588 0x4c84 "䲄" */
+0x22,0x22,0x73,0x92,0x27,0xfa,0xab,0xaa,0xff,0xaa,0xad,0xfc,0x07,0xa8,0xaa,0x01,
+0x08,0x08,0xc8,0x10,0xde,0x54,0x64,0xd4,0xf4,0x54,0x54,0xc8,0xc8,0x54,0xa4,0x42,
+/* 19589 0x4c85 "䲅" */
+0x21,0x21,0x71,0x93,0x21,0xf9,0xa9,0xab,0xf9,0xa9,0xa9,0xf9,0x02,0xaa,0xac,0x08,
+0x00,0x3c,0x24,0xa4,0x3c,0x24,0x24,0xbc,0x24,0x24,0x3c,0x28,0xa8,0xca,0x4a,0x86,
+/* 19590 0x4c86 "䲆" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+/* 19591 0x4c87 "䲇" */
+0x20,0x22,0x79,0x49,0x90,0x7c,0x57,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x10,0x10,0x7c,0x10,0x7c,0x54,0x54,0x7c,0x10,0x38,0x54,0x92,0x10,0x90,0x7e,0x00,
+/* 19592 0x4c88 "䲈" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xaa,0x00,
+0x20,0x10,0xfe,0x48,0x48,0x48,0xfe,0x48,0x48,0xec,0x5a,0x68,0x48,0x48,0x48,0x48,
+/* 19593 0x4c89 "䲉" */
+0x21,0x21,0x71,0x93,0x21,0xf9,0xa9,0xa9,0xf9,0xa9,0xab,0xf8,0x01,0xaa,0xac,0x00,
+0x40,0x44,0x58,0xf0,0x50,0xd0,0x5e,0xd4,0x54,0x54,0xf4,0x14,0x54,0x34,0x14,0x24,
+/* 19594 0x4c8a "䲊" */
+0x20,0x23,0x72,0x92,0x22,0xfb,0xaa,0xaa,0xfa,0xaa,0xaa,0xfb,0x02,0xaa,0xaa,0x02,
+0x10,0x90,0xfe,0xa0,0xbe,0x48,0xbe,0x80,0xbe,0xa2,0xbe,0x22,0x3e,0x22,0x22,0x26,
+/* 19595 0x4c8b "䲋" */
+0x20,0x20,0x79,0x48,0x93,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x88,0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 19596 0x4c8c "䲌" */
+0x21,0x21,0x77,0x91,0x21,0xfb,0xa8,0xab,0xf8,0xaf,0xa9,0xf9,0x05,0xa9,0xa9,0x03,
+0x08,0x08,0xc8,0x08,0x1e,0x92,0x24,0x80,0x08,0xc8,0x08,0x08,0x94,0x54,0x24,0x42,
+/* 19597 0x4c8d "䲍" */
+0x11,0x20,0x79,0x48,0x6b,0x59,0x4a,0xfc,0x49,0x4b,0x6d,0x59,0x49,0x49,0x48,0x99,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0x84,0xfa,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x54,
+/* 19598 0x4c8e "䲎" */
+0x20,0x23,0x70,0x91,0x27,0xfa,0xaa,0xab,0xfa,0xab,0xaa,0xfa,0x03,0xae,0xa8,0x00,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 19599 0x4c8f "䲏" */
+0x20,0x21,0x78,0x48,0x90,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x48,0x6a,0xdc,0x48,0xb4,0x22,0xfe,0x02,0x20,0x20,0xfc,0x24,0x44,0x44,0x94,0x08,
+/* 19600 0x4c90 "䲐" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x20,0x3e,0x20,0xfe,0x22,0xfc,0x22,0x7e,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x22,0xc6,
+/* 19601 0x4c91 "䲑" */
+0x21,0x20,0x7b,0x48,0x91,0x7c,0x57,0x54,0x7d,0x54,0x57,0x7c,0x00,0xab,0xaa,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 19602 0x4c92 "䲒" */
+0x21,0x21,0x72,0x94,0x23,0xfa,0xaa,0xab,0xfa,0xaa,0xab,0xfa,0x02,0xaa,0xaa,0x04,
+0x00,0xde,0x4a,0x8a,0xea,0xb6,0xa4,0xf4,0xbe,0xa4,0xe4,0xbe,0xa4,0xa4,0x24,0x64,
+/* 19603 0x4c93 "䲓" */
+0x20,0x20,0x78,0x48,0x91,0x7e,0x54,0x54,0x7d,0x55,0x55,0x7d,0x00,0xaa,0xab,0x02,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 19604 0x4c94 "䲔" */
+0x20,0x23,0x70,0x91,0x21,0xf9,0xa9,0xab,0xf8,0xa9,0xa9,0xf9,0x01,0xa9,0xa8,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 19605 0x4c95 "䲕" */
+0x20,0x20,0x79,0x48,0x91,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x84,0x48,0xfe,0x48,0x4a,0xcc,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,
+/* 19606 0x4c96 "䲖" */
+0x20,0x23,0x70,0x91,0x20,0xfb,0xa8,0xa9,0xf8,0xab,0xa8,0xfb,0x00,0xab,0xaa,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 19607 0x4c97 "䲗" */
+0x21,0x21,0x72,0x92,0x25,0xf9,0xaa,0xaa,0xfe,0xaa,0xaa,0xfa,0x02,0xaa,0xaa,0x02,
+0x20,0x20,0x56,0x48,0x80,0x70,0x2e,0x24,0xf4,0x24,0xac,0x74,0x24,0x34,0xc4,0x0c,
+/* 19608 0x4c98 "䲘" */
+0x21,0x21,0x79,0x4a,0x90,0x7c,0x55,0x55,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x08,0x08,0xee,0x94,0x42,0x10,0xfe,0x02,0xf8,0x88,0xf8,0x80,0xfc,0x84,0xfc,0x84,
+/* 19609 0x4c99 "䲙" */
+0x21,0x21,0x71,0x92,0x20,0xf8,0xab,0xaa,0xfb,0xaa,0xab,0xfa,0x02,0xab,0xaa,0x00,
+0x08,0x08,0xee,0x94,0x42,0x00,0xde,0x52,0xd2,0x52,0xd2,0x1a,0x94,0x50,0x10,0x10,
+/* 19610 0x4c9a "䲚" */
+0x20,0x20,0x73,0x90,0x20,0xfb,0xaa,0xaa,0xfb,0xa8,0xa9,0xfa,0x04,0xa8,0xa8,0x00,
+0x88,0x88,0xee,0x92,0x84,0xee,0xaa,0xae,0xea,0x8e,0xca,0xae,0xa0,0x8c,0x8a,0x92,
+/* 19611 0x4c9b "䲛" */
+0x20,0x23,0x78,0x49,0x91,0x7d,0x54,0x57,0x7e,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x88,0xfe,0x88,0xfc,0x54,0xfc,0x00,0xfe,0x02,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,
+/* 19612 0x4c9c "䲜" */
+0x3c,0x48,0xfc,0x54,0x7c,0x54,0x7c,0xaa,0x3c,0x48,0xfc,0x54,0x7c,0x54,0x7c,0xaa,
+0x3c,0x48,0xfc,0x54,0x7c,0x54,0x7c,0xaa,0x3c,0x48,0xfc,0x54,0x7c,0x54,0x7c,0xaa,
+/* 19613 0x4c9d "䲝" */
+0x20,0x20,0x7c,0x44,0x88,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 19614 0x4c9e "䲞" */
+0x20,0x20,0x7c,0x44,0x89,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe3,0x40,
+0x40,0x20,0x20,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 19615 0x4c9f "䲟" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1c,0xe0,0x40,
+0x00,0x40,0x9e,0x12,0x12,0x12,0xd2,0x12,0x12,0x12,0x5a,0x94,0x10,0x10,0x10,0x10,
+/* 19616 0x4ca0 "䲠" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x55,0x54,0x7d,0x56,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 19617 0x4ca1 "䲡" */
+0x20,0x20,0x7c,0x45,0x88,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 19618 0x4ca2 "䲢" */
+0x01,0x3c,0x25,0x24,0x27,0x3d,0x26,0x24,0x25,0x3f,0x25,0x25,0x25,0x45,0x54,0x8b,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0x84,0xfa,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 19619 0x4ca3 "䲣" */
+0x0f,0x08,0x7f,0x48,0x4e,0x79,0x4f,0x51,0x5f,0x75,0x5f,0x55,0x5f,0x40,0xbf,0x00,
+0x10,0x10,0x90,0xa0,0x3e,0x44,0x24,0x24,0x24,0x28,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 19620 0x4ca4 "䲤" */
+0x40,0x44,0x7a,0x88,0x14,0xfa,0xaa,0xa8,0xf9,0xaa,0xae,0xfa,0x02,0x1a,0xe2,0x40,
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 19621 0x4ca5 "䲥" */
+0x02,0x3f,0x04,0x18,0xe2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x00,0xe0,0x22,0x22,0x1e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 19622 0x4ca6 "䲦" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x90,0x28,0xa8,0xa8,0xa8,0xc4,0x44,0x82,
+/* 19623 0x4ca7 "䲧" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x1d,0xe0,0x42,0x02,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19624 0x4ca8 "䲨" */
+0x00,0x00,0x7d,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x1c,0xe2,0x42,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19625 0x4ca9 "䲩" */
+0x3f,0x20,0x3f,0x22,0x27,0x24,0x27,0x24,0x27,0x24,0x27,0x24,0x47,0x40,0x8a,0x0a,
+0xfc,0x04,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x04,0xa4,0xac,
+/* 19626 0x4caa "䲪" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x29,0x25,0x24,0x42,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19627 0x4cab "䲫" */
+0x00,0xfd,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x28,0x29,0x2a,0x48,0x47,0x80,
+0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xfc,0x04,0x54,0x5c,0x02,0xfe,0x00,
+/* 19628 0x4cac "䲬" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xc6,0x82,
+/* 19629 0x4cad "䲭" */
+0x04,0x0e,0xf0,0x90,0x90,0x90,0xfc,0x90,0x90,0x90,0x90,0x88,0x8a,0xc6,0x83,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19630 0x4cae "䲮" */
+0x00,0x7c,0x00,0x00,0x00,0xfe,0x28,0x28,0x28,0x28,0x28,0x2a,0x4e,0x4a,0x82,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19631 0x4caf "䲯" */
+0x00,0x7e,0x22,0x24,0x24,0x28,0x2e,0x22,0x2a,0x24,0x44,0x4a,0x92,0x20,0x41,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19632 0x4cb0 "䲰" */
+0x00,0x00,0x79,0x01,0x01,0x01,0xfd,0x21,0x21,0x21,0x41,0x50,0x8a,0xfa,0x0a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19633 0x4cb1 "䲱" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x20,0x10,0x00,0xfe,0x20,0x20,0x3c,0x24,0xa4,0x24,0xa4,0xa4,0xa4,0xa4,0x54,0x88,
+/* 19634 0x4cb2 "䲲" */
+0x00,0x28,0x24,0x24,0x42,0x52,0x90,0x10,0x20,0x20,0x48,0x44,0xfc,0x44,0x01,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19635 0x4cb3 "䲳" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x81,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19636 0x4cb4 "䲴" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x28,0x26,0x42,0x42,0x80,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19637 0x4cb5 "䲵" */
+0x01,0x11,0x21,0x4f,0xf2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x00,0x10,0xe8,0x04,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 19638 0x4cb6 "䲶" */
+0x1f,0x00,0xff,0x08,0x32,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0xf0,0x00,0xfe,0x44,0x3c,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 19639 0x4cb7 "䲷" */
+0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x84,0x01,0xff,0x09,0x71,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x94,0x08,0xfe,0x20,0x1c,
+/* 19640 0x4cb8 "䲸" */
+0x10,0x10,0x11,0x29,0x25,0x43,0xa9,0x29,0x29,0x29,0x29,0x28,0x4a,0x4a,0x8a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19641 0x4cb9 "䲹" */
+0x00,0x7e,0x09,0x09,0x11,0x15,0x33,0x51,0x91,0x11,0x11,0x00,0x0e,0xf2,0x42,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19642 0x4cba "䲺" */
+0x48,0x48,0x49,0x49,0xfd,0x49,0x49,0x49,0x79,0x49,0x49,0x48,0x4a,0x7a,0x4a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19643 0x4cbb "䲻" */
+0x20,0x10,0x01,0xfd,0x21,0x41,0x49,0x89,0xf1,0x11,0x21,0x20,0x4a,0xfa,0x0a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19644 0x4cbc "䲼" */
+0x10,0x10,0x51,0x51,0x7d,0x51,0x91,0x11,0x11,0x7d,0x11,0x10,0x12,0x1e,0xe2,0x40,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19645 0x4cbd "䲽" */
+0x00,0x00,0xf9,0x21,0x21,0x41,0x79,0x49,0xc9,0x49,0x49,0x48,0x7a,0x4a,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19646 0x4cbe "䲾" */
+0x00,0x7d,0x10,0x10,0x1e,0xf0,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 19647 0x4cbf "䲿" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x20,0x28,0x28,0x2e,0x28,0x28,0x4a,0x4c,0x89,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19648 0x4cc0 "䳀" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7d,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x10,0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 19649 0x4cc1 "䳁" */
+0x10,0x20,0x7c,0x44,0x7d,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x03,0xab,0xaa,0x82,0x0c,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 19650 0x4cc2 "䳂" */
+0x00,0xfc,0x24,0x24,0x44,0x54,0x88,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19651 0x4cc3 "䳃" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,0x08,0x1e,0x22,0x54,0x08,0x30,
+0x00,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,0x00,0xf8,0x88,0x98,0x82,0x7e,
+/* 19652 0x4cc4 "䳄" */
+0x14,0x14,0x14,0x54,0x55,0x5e,0x54,0x54,0x54,0x54,0x54,0x54,0x5d,0x76,0xc5,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19653 0x4cc5 "䳅" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0xa2,0x00,0x94,0x94,0xa2,0xa2,0x42,0x00,
+/* 19654 0x4cc6 "䳆" */
+0x10,0x10,0x21,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x49,0x48,0x4a,0x7a,0x4a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19655 0x4cc7 "䳇" */
+0x00,0x3c,0x24,0x34,0x2c,0x24,0x24,0xfe,0x44,0x64,0x54,0x44,0x7e,0x04,0x29,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19656 0x4cc8 "䳈" */
+0x10,0x20,0x7c,0x44,0x7d,0x46,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 19657 0x4cc9 "䳉" */
+0x20,0x20,0x3d,0x45,0xa9,0x11,0x29,0x45,0x83,0x31,0x09,0x00,0x62,0x12,0x0a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19658 0x4cca "䳊" */
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x3e,0x42,0x44,0x54,0x88,0x16,0x22,0x42,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19659 0x4ccb "䳋" */
+0x20,0x20,0x21,0xf9,0xa9,0xa9,0xa9,0xa9,0xf9,0xa1,0x21,0x28,0x3a,0xea,0x42,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19660 0x4ccc "䳌" */
+0x10,0x10,0x21,0x49,0xfd,0x05,0x79,0x49,0x49,0x79,0x49,0x78,0x4a,0x4a,0x4a,0x58,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19661 0x4ccd "䳍" */
+0x24,0x24,0x24,0x24,0x7f,0x24,0x24,0x24,0x24,0xff,0x00,0x24,0x24,0x42,0x43,0x82,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19662 0x4cce "䳎" */
+0x00,0x40,0x99,0x89,0x89,0x89,0x89,0xd9,0x89,0x89,0x89,0x88,0xfa,0x8a,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19663 0x4ccf "䳏" */
+0x10,0x10,0x11,0x7d,0x11,0x11,0xfd,0x01,0x11,0x11,0x7d,0x10,0x12,0x1e,0xe2,0x40,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19664 0x4cd0 "䳐" */
+0x41,0x21,0x0a,0x10,0xe0,0x21,0x26,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0xfc,0x44,0x48,0xa0,0x18,0x06,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 19665 0x4cd1 "䳑" */
+0x10,0x10,0xfe,0x10,0x20,0x3e,0x22,0x62,0xbe,0x22,0x22,0x3e,0x22,0x22,0x23,0x26,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19666 0x4cd2 "䳒" */
+0x08,0x7f,0x08,0xff,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x01,
+0x20,0x28,0x24,0xfe,0x20,0x20,0x24,0x24,0x24,0xa8,0x28,0x90,0x92,0xaa,0xc6,0x82,
+/* 19667 0x4cd3 "䳓" */
+0x10,0x12,0x7e,0x14,0x14,0xff,0x08,0x10,0x20,0x7e,0xa0,0x22,0x2c,0x30,0x21,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19668 0x4cd4 "䳔" */
+0x06,0x38,0x20,0x3c,0x20,0x3f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 19669 0x4cd5 "䳕" */
+0x0e,0xf0,0x22,0x92,0x54,0x00,0xfc,0x08,0x10,0x16,0x18,0xf0,0x52,0x12,0x52,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19670 0x4cd6 "䳖" */
+0x10,0x21,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xab,0x82,0x0c,
+0x00,0xfe,0xa0,0xa8,0xa8,0xe8,0xa8,0xa8,0xa8,0xe8,0xa8,0xaa,0xba,0xea,0x26,0x20,
+/* 19671 0x4cd7 "䳗" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,0x02,0x3c,0x08,0xff,0x08,0x7e,0x08,0x19,
+0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,0x40,0x50,0x48,0xfe,0x50,0x24,0x54,0x8c,
+/* 19672 0x4cd8 "䳘" */
+0x20,0x40,0xf3,0x90,0xf0,0x93,0xf0,0x80,0xf8,0x80,0xfb,0x08,0xa8,0xa8,0x8a,0x31,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 19673 0x4cd9 "䳙" */
+0x08,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x20,0x40,0x7e,0x02,0x02,0x15,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19674 0x4cda "䳚" */
+0x00,0x7c,0x45,0x7d,0x45,0x7d,0x01,0x01,0x7d,0x11,0x11,0xfe,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19675 0x4cdb "䳛" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x10,0x10,0xfe,0x22,0x64,0x18,0x25,0xc2,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19676 0x4cdc "䳜" */
+0x10,0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0xfe,0x10,0x54,0x52,0x92,0x10,0x51,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19677 0x4cdd "䳝" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7d,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19678 0x4cde "䳞" */
+0x08,0x08,0x7f,0x10,0x3e,0x10,0xff,0x22,0x49,0x88,0x3e,0x08,0x7f,0x08,0x09,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0xfc,0x40,0x7e,0xc0,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19679 0x4cdf "䳟" */
+0x00,0x0e,0xea,0xaa,0xaa,0xae,0xea,0xaa,0xaa,0xae,0xea,0xaa,0x0a,0x12,0x13,0x26,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19680 0x4ce0 "䳠" */
+0x02,0x0f,0x78,0x08,0xff,0x2a,0x2a,0xff,0x2a,0x2a,0xff,0x08,0x08,0x0e,0x71,0x20,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19681 0x4ce1 "䳡" */
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x41,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19682 0x4ce2 "䳢" */
+0x48,0x48,0x49,0xfd,0x49,0x49,0x79,0x49,0x79,0x49,0x49,0xfc,0x02,0x52,0x4a,0x84,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19683 0x4ce3 "䳣" */
+0x08,0x7f,0x08,0xff,0x20,0x3e,0x22,0x46,0x82,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x50,0x48,0x40,0xfe,0x40,0x50,0x22,0x5a,0x86,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19684 0x4ce4 "䳤" */
+0x10,0x92,0x52,0x54,0x10,0xfe,0x92,0x92,0xba,0xd6,0x92,0x92,0x92,0x82,0x8b,0x84,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19685 0x4ce5 "䳥" */
+0x10,0x92,0x92,0xfe,0x10,0x28,0x44,0x92,0x08,0xfc,0x04,0x08,0x52,0x22,0x12,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19686 0x4ce6 "䳦" */
+0x20,0x10,0xfe,0x82,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x02,0x1e,0xe2,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19687 0x4ce7 "䳧" */
+0x21,0x41,0xf1,0x92,0xf2,0x96,0xfa,0x82,0xfa,0x82,0xfa,0x0a,0xaa,0xaa,0x8a,0x32,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 19688 0x4ce8 "䳨" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x7c,0x12,0x1e,0xf2,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19689 0x4ce9 "䳩" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xfe,0x10,0xfc,0x24,0x44,0x2a,0x12,0x2a,0xc4,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19690 0x4cea "䳪" */
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xab,0x86,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19691 0x4ceb "䳫" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x41,0xbe,0x08,0x08,0x7f,0x08,0x14,0x12,0x23,0x40,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19692 0x4cec "䳬" */
+0x28,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfc,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19693 0x4ced "䳭" */
+0x00,0xee,0xaa,0xaa,0xaa,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xae,0xd8,0x88,0x09,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19694 0x4cee "䳮" */
+0x00,0x7c,0x45,0x7c,0x45,0x7c,0x45,0x56,0x8a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x10,0xe0,0x22,0xb4,0xa8,0x24,0xa2,0x40,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19695 0x4cef "䳯" */
+0x1c,0x70,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x7c,0x10,0x1e,0xf1,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19696 0x4cf0 "䳰" */
+0x10,0x17,0x14,0x24,0x24,0x67,0xa2,0x22,0x2f,0x27,0x26,0x2a,0x2a,0x32,0x22,0x22,
+0x08,0x90,0xbc,0xa4,0xbc,0xa4,0x3c,0x20,0xbe,0x20,0xbe,0x82,0xaa,0x2a,0x02,0x0c,
+/* 19697 0x4cf1 "䳱" */
+0x00,0x7e,0x14,0x08,0xfe,0x2a,0x48,0xa8,0x12,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x7c,0xc4,0x38,0xc6,0x20,0xfc,0x44,0x8c,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19698 0x4cf2 "䳲" */
+0x11,0x11,0xfd,0x11,0x1d,0xf1,0x12,0x54,0x22,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0xfe,0x00,0x7c,0x00,0xfe,0x54,0x48,0x64,0x42,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19699 0x4cf3 "䳳" */
+0x10,0x54,0x54,0x7c,0x92,0x92,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x51,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19700 0x4cf4 "䳴" */
+0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0x10,0x54,0x52,0x92,0x10,0x54,0x52,0x92,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19701 0x4cf5 "䳵" */
+0x11,0x11,0x11,0x7d,0x13,0x55,0x55,0x55,0xbb,0x11,0x39,0x55,0x92,0x12,0x15,0x18,
+0x04,0x08,0x1e,0x12,0xde,0x52,0x5e,0x50,0x5e,0x50,0x5e,0x42,0x52,0x52,0x4a,0x84,
+/* 19702 0x4cf6 "䳶" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x44,0x82,
+/* 19703 0x4cf7 "䳷" */
+0x11,0x21,0xca,0x14,0x32,0xd2,0x15,0x14,0x0a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x10,0x10,0xa8,0x44,0x40,0x7c,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19704 0x4cf8 "䳸" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x21,0x27,0x24,0x27,0x24,0x27,0x40,0x4a,0x80,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x04,0xa4,0x0c,
+/* 19705 0x4cf9 "䳹" */
+0x20,0x40,0xf3,0x92,0xf0,0x93,0xf0,0x80,0xfb,0x81,0xf9,0x09,0xa9,0xa9,0x89,0x32,
+0x40,0x20,0xfe,0x02,0x08,0xee,0x08,0x1c,0xe4,0x54,0x48,0x54,0x64,0x42,0x3e,0x00,
+/* 19706 0x4cfa "䳺" */
+0x08,0x14,0x22,0x49,0xbe,0x04,0x08,0xff,0x14,0x7f,0x55,0x63,0x41,0x7f,0x41,0x7f,
+0x10,0x20,0x7c,0x44,0xfc,0x44,0x7c,0xc0,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 19707 0x4cfb "䳻" */
+0x08,0x7f,0x08,0x3e,0x2a,0x3e,0x2a,0xff,0x0a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19708 0x4cfc "䳼" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x00,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xbc,0x80,0xee,0xaa,0xaa,0xee,0x80,0xfe,0x00,
+/* 19709 0x4cfd "䳽" */
+0x10,0x92,0x92,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7f,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19710 0x4cfe "䳾" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x5d,0x80,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19711 0x4cff "䳿" */
+0x24,0x26,0x35,0x54,0x5f,0x74,0x94,0x64,0x2a,0x49,0x91,0x00,0xaa,0xaa,0xab,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19712 0x4d00 "䴀" */
+0x10,0x08,0x7f,0x22,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 19713 0x4d01 "䴁" */
+0x20,0x10,0xfe,0x82,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x92,0x92,0xba,0x8b,0x84,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19714 0x4d02 "䴂" */
+0x20,0x3e,0x42,0xff,0x49,0x49,0x7f,0x10,0x28,0xd5,0x26,0xcd,0x15,0x24,0xd5,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19715 0x4d03 "䴃" */
+0x10,0x10,0x7c,0x10,0xfe,0x44,0xee,0x44,0x64,0xde,0x00,0xfe,0x28,0x2a,0x4d,0x88,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19716 0x4d04 "䴄" */
+0x0f,0xf0,0x11,0x89,0x42,0x00,0xff,0x81,0x42,0x77,0x92,0x5a,0x2f,0x22,0x42,0x82,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 19717 0x4d05 "䴅" */
+0x08,0x7f,0x08,0x22,0xff,0x22,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,0x80,
+0x10,0x20,0x7c,0x44,0xfc,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x8c,
+/* 19718 0x4d06 "䴆" */
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x45,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19719 0x4d07 "䴇" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x14,0x2a,0x45,0xbe,0x02,0x04,0x19,0x04,
+0x10,0x20,0x7c,0xc4,0xfc,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19720 0x4d08 "䴈" */
+0x10,0x20,0xfe,0x92,0xd6,0xba,0xfe,0x92,0xba,0xd6,0x82,0x10,0xfe,0x28,0x45,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19721 0x4d09 "䴉" */
+0x00,0xfe,0xaa,0xaa,0xfe,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x2a,0x64,0xa2,0x31,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 19722 0x4d0a "䴊" */
+0x41,0x22,0xff,0x08,0x7f,0x08,0xff,0x15,0x64,0x24,0xff,0x24,0x35,0xe2,0x25,0x68,
+0x08,0x10,0xbc,0x24,0x3c,0x24,0xbc,0x20,0xbe,0x20,0xbe,0x02,0x2a,0xaa,0x82,0x8c,
+/* 19723 0x4d0b "䴋" */
+0x20,0x43,0xf2,0x92,0xf3,0x90,0xf7,0x80,0xfb,0x82,0xfb,0x08,0xa9,0xab,0x8d,0x31,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 19724 0x4d0c "䴌" */
+0x10,0x20,0x7d,0x44,0x7c,0x44,0x7d,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x48,0x48,0xfe,0x48,0xfe,0x82,0x7c,0x00,0xfe,0x20,0xd2,0x2c,0xd8,0x2c,0xca,0x30,
+/* 19725 0x4d0d "䴍" */
+0x00,0x00,0x77,0x55,0x55,0x77,0x55,0x55,0x77,0x55,0x55,0x77,0x00,0x55,0x88,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0xc2,0x0c,
+/* 19726 0x4d0e "䴎" */
+0x00,0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0x3f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x00,0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xf8,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 19727 0x4d0f "䴏" */
+0x22,0x22,0xff,0x22,0x3e,0x41,0x5d,0xd5,0x55,0x55,0xdd,0x41,0x00,0x55,0x4a,0x8a,
+0x08,0x10,0xbc,0x24,0x3c,0x24,0x3c,0xe0,0x3e,0x20,0x7e,0x82,0x2a,0x2a,0x82,0x8c,
+/* 19728 0x4d10 "䴐" */
+0x08,0xff,0x84,0x77,0x2a,0x77,0x2a,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,
+0x08,0x90,0xbc,0x24,0x3c,0x24,0xbc,0xa0,0x3e,0x20,0x3e,0x02,0x2a,0x2a,0x02,0x0c,
+/* 19729 0x4d11 "䴑" */
+0x7f,0x49,0x7f,0x49,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0xa2,0x3e,0x22,0x27,0xf8,
+0x08,0x10,0x3c,0x24,0xbc,0xa4,0xbc,0xa0,0xbe,0x20,0xbe,0x82,0x2a,0x2a,0x82,0x0c,
+/* 19730 0x4d12 "䴒" */
+0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0xef,0xaa,0xef,0x00,0xff,0x49,0xaa,0xff,
+0x08,0x10,0xbc,0xa4,0x3c,0x24,0x3c,0x20,0xbe,0xa0,0xbe,0x02,0xaa,0x2a,0x82,0x8c,
+/* 19731 0x4d13 "䴓" */
+0x00,0xff,0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x49,0x4d,0x4a,0x08,0x08,0x08,
+0x10,0xa0,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 19732 0x4d14 "䴔" */
+0x20,0x10,0x00,0xfe,0x00,0x28,0x44,0x82,0x04,0x44,0x28,0x10,0x29,0x44,0x84,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 19733 0x4d15 "䴕" */
+0x7f,0x08,0x1e,0x22,0x54,0x08,0x32,0xdf,0x14,0x12,0x10,0x1f,0x00,0x7f,0x00,0x00,
+0x04,0x44,0x44,0x44,0x44,0x44,0x0c,0xe0,0x20,0x60,0x00,0xf8,0x08,0x88,0x28,0x10,
+/* 19734 0x4d16 "䴖" */
+0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x54,0x48,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 19735 0x4d17 "䴗" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x14,0x12,0xff,0x10,0x29,0x24,0x42,0x80,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 19736 0x4d18 "䴘" */
+0x03,0x7c,0x47,0x44,0x5f,0x55,0x56,0x5c,0x55,0x53,0x50,0x57,0x55,0x55,0xa9,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x8a,0x04,
+/* 19737 0x4d19 "䴙" */
+0x02,0x79,0x49,0x4b,0x48,0x7a,0x41,0x47,0x79,0x69,0xab,0xa9,0x29,0x39,0x29,0x01,
+0x08,0x10,0x3e,0xa2,0x32,0xaa,0x22,0xe6,0x20,0x3e,0x82,0x02,0x7a,0x02,0x0a,0x04,
+/* 19738 0x4d1a "䴚" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x01,
+0x40,0x20,0x20,0xfc,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 19739 0x4d1b "䴛" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x00,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 19740 0x4d1c "䴜" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x01,
+0x10,0x20,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x20,0x24,0x5a,0x5e,0x90,0x92,0x0e,
+/* 19741 0x4d1d "䴝" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc7,0xaa,0xd6,0xaa,0xc6,0x92,0xff,0x82,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0xa0,0xee,0xaa,0xea,0xba,0xe4,0x24,0x2a,
+/* 19742 0x4d1e "䴞" */
+0x10,0x11,0x1e,0x11,0x10,0xff,0x92,0xc6,0xaa,0xd7,0xaa,0xc6,0x92,0xfe,0x82,0x00,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x50,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,
+/* 19743 0x4d1f "䴟" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x20,0x23,0x22,0x42,0x44,0x98,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x00,0xf0,0x10,0x90,0x52,0x0e,
+/* 19744 0x4d20 "䴠" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x20,0x27,0x20,0x5f,0x41,0x8e,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x38,0xc0,0x40,0xfe,0x10,0x0e,
+/* 19745 0x4d21 "䴡" */
+0x00,0x7f,0x02,0x12,0x0a,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x28,0x2f,0x48,0x4b,0x8c,
+0x00,0xfe,0x40,0x48,0x50,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x48,0x70,0x44,0x44,0x3c,
+/* 19746 0x4d22 "䴢" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x20,0x20,0x2f,0x41,0x42,0x8c,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x40,0x40,0xfe,0x50,0x48,0x46,
+/* 19747 0x4d23 "䴣" */
+0x08,0x7f,0x54,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5e,0x54,0x54,0x5c,0x56,0x80,
+0x04,0x1e,0xf0,0x10,0x92,0x52,0x54,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 19748 0x4d24 "䴤" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x22,0x23,0x24,0x4b,0x40,0x9f,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0xde,0x40,0xfc,0x40,0xf8,0x40,0xfe,
+/* 19749 0x4d25 "䴥" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x24,0x3f,0x24,0x44,0x4a,0x91,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x00,0xbc,0xa4,0xa4,0xbc,0x24,
+/* 19750 0x4d26 "䴦" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x20,0x3f,0x20,0x27,0x20,0x47,0x44,0x87,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x40,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 19751 0x4d27 "䴧" */
+0x08,0x7f,0x54,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5e,0x54,0x54,0x5c,0x56,0x80,
+0x1c,0x70,0x10,0xfe,0x38,0x54,0x92,0x10,0x20,0xfe,0x24,0x44,0x28,0x10,0x28,0xc4,
+/* 19752 0x4d28 "䴨" */
+0x08,0x7f,0x54,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5e,0x54,0x54,0x5c,0x56,0x81,
+0x00,0x7e,0x48,0x50,0x5c,0x54,0x54,0x5c,0x54,0x54,0x5c,0x48,0x5c,0xaa,0x8a,0x18,
+/* 19753 0x4d29 "䴩" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x3f,0x21,0x2f,0x29,0x2f,0x20,0x5f,0x44,0x89,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x90,0x88,
+/* 19754 0x4d2a "䴪" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x24,0x24,0x3e,0x22,0x24,0x2e,0x55,0x44,0x84,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xf8,0x08,0x78,0x08,0xfe,0x54,0x38,0x54,0xb2,
+/* 19755 0x4d2b "䴫" */
+0x08,0x7f,0x54,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5e,0x54,0x54,0x5c,0x56,0x80,
+0x00,0x7c,0x10,0xfe,0x92,0x54,0x10,0x54,0x28,0x54,0x8a,0x7c,0x04,0x08,0x30,0x08,
+/* 19756 0x4d2c "䴬" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x48,0x44,0x44,0x40,0x5e,0xe0,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 19757 0x4d2d "䴭" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x18,0x28,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 19758 0x4d2e "䴮" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x10,0x10,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,0x00,
+/* 19759 0x4d2f "䴯" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1f,0x22,0x54,0x08,0x14,0x60,
+0x40,0x40,0x40,0x7e,0xaa,0x2a,0x2a,0x4a,0x4a,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 19760 0x4d30 "䴰" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x15,0x60,
+0x48,0x44,0x44,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 19761 0x4d31 "䴱" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x20,0x10,0x10,0xfe,0x82,0x04,0x40,0x48,0x50,0x60,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 19762 0x4d32 "䴲" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,
+/* 19763 0x4d33 "䴳" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x20,0x10,0x10,0xfe,0x82,0x04,0x00,0x28,0x28,0x28,0x28,0x28,0x44,0x44,0x44,0x82,
+/* 19764 0x4d34 "䴴" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 19765 0x4d35 "䴵" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x55,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc1,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 19766 0x4d36 "䴶" */
+0x10,0x10,0xfe,0x54,0x55,0xba,0x10,0x3b,0x54,0xa2,0x3c,0x44,0xab,0x10,0x28,0xc0,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 19767 0x4d37 "䴷" */
+0x10,0x10,0xfe,0x55,0x55,0xba,0x10,0x38,0x54,0xa3,0x3c,0x44,0xa8,0x10,0x29,0xc2,
+0x40,0x20,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 19768 0x4d38 "䴸" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x0e,0xf0,0x22,0x92,0x54,0x00,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 19769 0x4d39 "䴹" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,
+/* 19770 0x4d3a "䴺" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x20,0x10,0x7c,0x00,0x44,0x28,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 19771 0x4d3b "䴻" */
+0x06,0x38,0x08,0x7e,0x2c,0x4a,0x01,0x7f,0x11,0x2b,0x45,0x19,0xe3,0x0e,0x01,0x0e,
+0x40,0x7c,0x94,0x24,0xd4,0x08,0x00,0xfc,0x10,0xa8,0x64,0x18,0xe6,0x40,0x80,0x40,
+/* 19772 0x4d3c "䴼" */
+0x10,0x10,0xfe,0x55,0x54,0xba,0x10,0x39,0x54,0xa2,0x3d,0x44,0xa8,0x10,0x28,0xc1,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 19773 0x4d3d "䴽" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x45,0xa8,0x10,0x28,0xc0,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 19774 0x4d3e "䴾" */
+0x10,0x10,0xfe,0x55,0x54,0xba,0x10,0x39,0x54,0xa2,0x3c,0x45,0xaa,0x14,0x29,0xc0,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 19775 0x4d3f "䴿" */
+0x10,0x11,0xff,0x54,0x54,0xba,0x10,0x38,0x55,0xa2,0x3c,0x45,0xa8,0x10,0x29,0xc0,
+0x00,0xfe,0x02,0x78,0x00,0xfc,0x40,0xa4,0x38,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 19776 0x4d40 "䵀" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x10,0x92,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0xfe,0x82,0x82,0xfe,0x00,0x44,0x82,
+/* 19777 0x4d41 "䵁" */
+0x10,0x11,0xff,0x55,0x55,0xbb,0x10,0x38,0x55,0xa3,0x3d,0x45,0xa9,0x11,0x29,0xc2,
+0x48,0x48,0x5e,0x6a,0x54,0xc8,0x50,0x64,0xc4,0x7e,0x44,0x64,0x54,0x44,0x54,0x48,
+/* 19778 0x4d42 "䵂" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x82,0x92,0xfe,0x92,0xba,0xaa,0xaa,0xba,0x82,0x86,
+/* 19779 0x4d43 "䵃" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x28,0x28,0x7c,0x28,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x28,0x44,0x82,
+/* 19780 0x4d44 "䵄" */
+0x10,0x11,0xff,0x55,0x55,0xbb,0x10,0x39,0x54,0xa3,0x3d,0x45,0xa8,0x10,0x2b,0xc0,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 19781 0x4d45 "䵅" */
+0x08,0x7f,0x08,0x3e,0x08,0x7f,0x10,0x1e,0x22,0xff,0x11,0x2a,0x0d,0x76,0x01,0x1e,
+0x20,0x20,0x3e,0x44,0xa8,0x10,0x28,0x46,0x80,0xfe,0xc8,0xb4,0xd0,0x4e,0x80,0x40,
+/* 19782 0x4d46 "䵆" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x11,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x48,0x48,0xfe,0x48,0xfe,0x82,0x7c,0x00,0xfe,0x20,0xd2,0x2c,0xd8,0x2c,0xca,0x30,
+/* 19783 0x4d47 "䵇" */
+0x08,0x04,0x7f,0x49,0x49,0x49,0x7f,0x49,0x59,0x5d,0x6b,0x4d,0x49,0x49,0x89,0x09,
+0x10,0x10,0xd0,0x10,0x3e,0x24,0xd4,0x14,0x14,0x94,0x54,0x08,0x08,0x14,0x14,0x22,
+/* 19784 0x4d48 "䵈" */
+0x11,0x23,0x40,0x0b,0x11,0x33,0x55,0x10,0x11,0x12,0x3f,0x24,0x3f,0x26,0x4d,0x94,
+0x10,0xe0,0x48,0xfc,0x00,0xf0,0x10,0xe0,0x10,0x88,0xfe,0x10,0x7c,0x38,0x54,0x12,
+/* 19785 0x4d49 "䵉" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x21,0x26,0x3b,0x20,0x2f,0x28,0x4f,0x48,0x89,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x40,0x30,0xee,0x00,0xa4,0xa4,0xa4,0xa4,0x8c,
+/* 19786 0x4d4a "䵊" */
+0x00,0x78,0x49,0x48,0x68,0x5b,0x48,0xfd,0x49,0x49,0x49,0x49,0x48,0x48,0x49,0x9a,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 19787 0x4d4b "䵋" */
+0x28,0x28,0x7d,0x28,0x28,0xfe,0x10,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x28,0x44,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 19788 0x4d4c "䵌" */
+0x28,0x28,0x7c,0x29,0x28,0xfe,0x10,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x29,0x46,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 19789 0x4d4d "䵍" */
+0x28,0x28,0x7d,0x28,0x28,0xfe,0x10,0x7c,0x54,0x54,0x7c,0x55,0x54,0x7c,0x28,0x44,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 19790 0x4d4e "䵎" */
+0x28,0x29,0x7d,0x29,0x29,0xfe,0x13,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7d,0x29,0x45,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 19791 0x4d4f "䵏" */
+0x28,0x29,0x7c,0x29,0x28,0xff,0x10,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x28,0x45,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x18,0x60,0x80,
+/* 19792 0x4d50 "䵐" */
+0x28,0x29,0x7d,0x29,0x29,0xfe,0x11,0x7d,0x55,0x55,0x7d,0x54,0x57,0x7c,0x28,0x44,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 19793 0x4d51 "䵑" */
+0x0c,0x70,0x11,0xfe,0x38,0x54,0x90,0x28,0x55,0x90,0x54,0x38,0x54,0x92,0x51,0x22,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 19794 0x4d52 "䵒" */
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x90,0x28,0x54,0x90,0x54,0x38,0x54,0x92,0x50,0x20,
+0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 19795 0x4d53 "䵓" */
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x91,0x28,0x54,0x91,0x54,0x38,0x54,0x92,0x50,0x20,
+0x10,0x10,0x90,0x90,0xfe,0x90,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 19796 0x4d54 "䵔" */
+0x0c,0x70,0x13,0xfe,0x39,0x55,0x91,0x29,0x55,0x90,0x54,0x38,0x55,0x96,0x50,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 19797 0x4d55 "䵕" */
+0x0c,0x71,0x11,0xff,0x39,0x55,0x91,0x29,0x55,0x91,0x55,0x39,0x55,0x93,0x51,0x22,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 19798 0x4d56 "䵖" */
+0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7f,0x01,0x7f,0x09,0x32,0xcc,0x39,0xc5,0x09,0x33,
+0x7c,0x04,0x28,0x10,0x28,0xfc,0x00,0x00,0xfc,0x10,0x88,0x64,0x38,0x46,0x20,0x10,
+/* 19799 0x4d57 "䵗" */
+0x0c,0x71,0x10,0xfe,0x38,0x54,0x90,0x28,0x55,0x91,0x55,0x39,0x55,0x93,0x51,0x21,
+0x00,0xfc,0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 19800 0x4d58 "䵘" */
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x90,0x29,0x54,0x90,0x55,0x3a,0x54,0x93,0x50,0x20,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 19801 0x4d59 "䵙" */
+0x0c,0x70,0x10,0xfe,0x38,0x55,0x90,0x28,0x54,0x90,0x55,0x38,0x54,0x92,0x50,0x21,
+0x00,0x20,0xfe,0x44,0x82,0x20,0x7c,0x88,0x50,0x68,0x9e,0x22,0xd4,0x08,0x30,0xc0,
+/* 19802 0x4d5a "䵚" */
+0x0c,0x71,0x10,0xff,0x38,0x54,0x90,0x29,0x55,0x91,0x55,0x39,0x55,0x93,0x51,0x21,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 19803 0x4d5b "䵛" */
+0x0c,0x71,0x11,0xff,0x39,0x55,0x91,0x29,0x55,0x90,0x54,0x38,0x54,0x92,0x51,0x20,
+0x00,0xee,0x4a,0xea,0x2a,0xe4,0x44,0x4a,0xf0,0x00,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 19804 0x4d5c "䵜" */
+0x0c,0x71,0x11,0xff,0x39,0x55,0x90,0x29,0x55,0x91,0x55,0x39,0x55,0x93,0x51,0x22,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfe,0x00,0x7c,0x00,0xfe,0x50,0x54,0x48,0x66,
+/* 19805 0x4d5d "䵝" */
+0x00,0x7f,0x49,0x6b,0x5d,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x00,0x55,0x4a,0x80,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x9e,0x00,
+/* 19806 0x4d5e "䵞" */
+0x00,0x7f,0x49,0x6b,0x5d,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x00,0x55,0x4a,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x94,0x08,
+/* 19807 0x4d5f "䵟" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 19808 0x4d60 "䵠" */
+0x00,0xfe,0x92,0xd6,0xba,0x93,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x40,0x40,0x40,0xfc,0x84,0x04,0x04,0x84,0x44,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 19809 0x4d61 "䵡" */
+0x00,0x3f,0x01,0x7f,0x04,0x18,0xe0,0x3f,0x29,0x25,0x3f,0x01,0x7f,0x01,0xff,0x44,
+0x00,0xf8,0x00,0xfc,0x40,0x30,0x0e,0xf8,0x28,0x48,0xf8,0x00,0xfc,0x00,0xfe,0x44,
+/* 19810 0x4d62 "䵢" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,
+/* 19811 0x4d63 "䵣" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa9,0x80,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 19812 0x4d64 "䵤" */
+0x3f,0x08,0x08,0xff,0x08,0x10,0x20,0x7f,0x29,0x25,0x3f,0x01,0x7f,0x01,0xff,0x44,
+0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,0xf8,0x28,0x48,0xf8,0x00,0xfc,0x00,0xfe,0x44,
+/* 19813 0x4d65 "䵥" */
+0x00,0xfe,0x92,0xd6,0xbb,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x40,0x40,0x7c,0x84,0x08,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 19814 0x4d66 "䵦" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x00,0x9c,0x48,0x08,0x88,0x48,0x5e,0x08,0x28,0x48,0xc8,0x48,0x48,0x48,0x48,0x18,
+/* 19815 0x4d67 "䵧" */
+0x08,0x7f,0x08,0xff,0x00,0x7f,0x49,0x6b,0x49,0x7f,0x08,0x7f,0x08,0xff,0x00,0xaa,
+0x20,0x28,0x24,0xfe,0x20,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0xaa,0x46,0x82,
+/* 19816 0x4d68 "䵨" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa9,0x82,
+0x48,0x44,0x40,0xfe,0x50,0x54,0x58,0x52,0x54,0x58,0x52,0x54,0x9a,0x92,0x2e,0x40,
+/* 19817 0x4d69 "䵩" */
+0x03,0x3c,0x04,0x7f,0x16,0x25,0x44,0x3f,0x29,0x25,0x3f,0x01,0x7f,0x01,0xff,0x44,
+0x04,0x24,0x24,0xa4,0x24,0x04,0x0c,0xf8,0x28,0x48,0xf8,0x00,0xfc,0x00,0xfe,0x44,
+/* 19818 0x4d6a "䵪" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x90,0x92,0xf4,0x98,0x92,0xd2,0x8e,
+/* 19819 0x4d6b "䵫" */
+0x01,0x7f,0x50,0x3e,0x42,0xa2,0x14,0x18,0xe0,0x3f,0x29,0x25,0x3f,0x01,0xff,0x24,
+0x00,0xfc,0x04,0xf8,0x88,0xaa,0x92,0x7e,0x00,0xf8,0x28,0x48,0xf8,0x00,0xfe,0x48,
+/* 19820 0x4d6c "䵬" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xff,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0xda,0x54,0x54,0x92,0x50,0x20,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 19821 0x4d6d "䵭" */
+0x00,0xfe,0x92,0xd6,0xba,0x93,0xfe,0x10,0xfe,0x11,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 19822 0x4d6e "䵮" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe1,0x02,0xaa,0xa8,0x80,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x2a,0x4a,0x92,0x2a,0x44,
+/* 19823 0x4d6f "䵯" */
+0x00,0xfe,0x92,0xd6,0xbb,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa9,0x80,
+0x08,0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 19824 0x4d70 "䵰" */
+0x00,0xfe,0x92,0xd7,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x03,0xaa,0xa8,0x80,
+0x40,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0xfe,0x2a,0x4a,0x92,0x26,
+/* 19825 0x4d71 "䵱" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x7c,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,
+/* 19826 0x4d72 "䵲" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa9,0x80,
+0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x10,0xfe,0x38,0x54,0x92,0x10,0x10,
+/* 19827 0x4d73 "䵳" */
+0x00,0xfe,0x92,0xd6,0xbb,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x28,0x44,0xba,0x00,0xfe,0x92,0xd6,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,
+/* 19828 0x4d74 "䵴" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x00,0xfe,0xaa,0xaa,0xee,0x28,0xee,0xaa,0xaa,0xee,0xaa,0xaa,0xee,0xa8,0x2a,0x1e,
+/* 19829 0x4d75 "䵵" */
+0x20,0x3f,0x48,0x9f,0x14,0x12,0x11,0xff,0x08,0x3f,0xd5,0x13,0x1f,0x01,0x7f,0x24,
+0x40,0x7e,0x90,0xf8,0x90,0x50,0x30,0xfe,0x20,0xf8,0x56,0x90,0xf0,0x00,0xfc,0x48,
+/* 19830 0x4d76 "䵶" */
+0x20,0x21,0x21,0x7d,0x45,0x84,0x75,0x55,0x55,0x55,0x75,0x55,0x05,0x05,0x28,0x10,
+0x00,0xfc,0x54,0x54,0xdc,0x50,0xdc,0x54,0x54,0xdc,0x54,0x54,0xdc,0x50,0x52,0x3e,
+/* 19831 0x4d77 "䵷" */
+0x10,0x11,0x11,0x7d,0x11,0x10,0xfd,0x01,0x11,0x11,0x7d,0x11,0x11,0x1d,0xe0,0x40,
+0x00,0xfc,0x54,0x54,0xdc,0x50,0xdc,0x54,0x54,0xdc,0x54,0x54,0xdc,0x50,0x52,0x3e,
+/* 19832 0x4d78 "䵸" */
+0x7c,0x10,0xfe,0x38,0x54,0x9f,0x12,0x1e,0x02,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x10,0x52,0x94,0x28,0x44,0xf2,0x90,0xf0,0x80,0xf8,0x88,0xf8,0x88,0xfa,0x82,0xfe,
+/* 19833 0x4d79 "䵹" */
+0x20,0x7d,0x91,0xfd,0x28,0x5f,0x92,0x1e,0x02,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x1c,0xc8,0x7e,0xc8,0x18,0xf0,0x90,0xf0,0x80,0xf8,0x88,0xf8,0x88,0xfa,0x82,0xfe,
+/* 19834 0x4d7a "䵺" */
+0x21,0x21,0x21,0x25,0xf5,0x25,0x25,0x24,0x27,0x20,0x30,0xef,0x44,0x04,0x04,0x08,
+0xf8,0x08,0xf8,0x0a,0xfa,0x0a,0xfa,0x02,0x9e,0x90,0x90,0x9e,0x92,0x92,0x92,0x92,
+/* 19835 0x4d7b "䵻" */
+0x1c,0x14,0x1c,0x55,0x5d,0x55,0x5d,0x41,0x77,0x14,0x14,0xf7,0x55,0x55,0x55,0x95,
+0x44,0x44,0xee,0x44,0xee,0x44,0xee,0x44,0x44,0x00,0xfe,0x02,0x7e,0x02,0xfe,0x02,
+/* 19836 0x4d7c "䵼" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x8f,0x48,0x4f,0x48,0x7f,0x04,0xfc,0x24,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0xf8,0x24,0xe4,0x24,0xfc,0x40,0x7c,0x44,
+/* 19837 0x4d7d "䵽" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0xfe,0x01,0x3f,0x01,0xff,0x04,0x08,0x1f,0x08,
+0x10,0x7e,0x10,0x7c,0x44,0x28,0x18,0xe6,0x00,0xf8,0x00,0xfe,0x00,0x20,0xf0,0x10,
+/* 19838 0x4d7e "䵾" */
+0x08,0x17,0x32,0xd1,0x10,0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0x1e,0xe0,
+0x10,0xfe,0x10,0x50,0x20,0x10,0x10,0xfe,0x10,0xfc,0x44,0x48,0x28,0x10,0x28,0xc6,
+/* 19839 0x4d7f "䵿" */
+0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0x1e,0xe1,0x01,0x01,0x3f,0x20,0x3f,
+0x10,0x10,0xfc,0x10,0xfc,0x44,0x28,0x10,0x28,0xc6,0x00,0xfc,0x00,0xf8,0x08,0xf8,
+/* 19840 0x4d80 "䶀" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x1e,0xe1,0x06,0x18,0xe7,0x00,0x1f,0x10,0x1f,
+0x10,0x7e,0x10,0x7c,0x04,0x48,0x38,0x44,0x00,0xc0,0x30,0xce,0x00,0xf0,0x10,0xf0,
+/* 19841 0x4d81 "䶁" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x7e,0x01,0x7d,0x09,0x3f,0xd0,0x1f,0x10,0x1f,
+0x10,0x7e,0x10,0x7c,0x44,0x38,0x44,0x82,0x18,0x60,0x18,0xf6,0x10,0xf0,0x10,0xf0,
+/* 19842 0x4d82 "䶂" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x20,0x20,0x7c,0x44,0x84,0x04,0x84,0x44,0x24,0x24,0x04,0x04,0x04,0x28,0x10,
+/* 19843 0x4d83 "䶃" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x10,0x10,0x28,0x28,0x44,0x44,0xa2,0x10,0x10,0x7c,0x04,0x08,0x08,0x10,0x10,
+/* 19844 0x4d84 "䶄" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x93,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0xfc,0x10,0x10,0x94,0x54,0x58,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 19845 0x4d85 "䶅" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 19846 0x4d86 "䶆" */
+0x20,0xce,0x82,0xee,0x82,0x83,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 19847 0x4d87 "䶇" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 19848 0x4d88 "䶈" */
+0x20,0xce,0x83,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x93,0xda,0x92,0x93,0xd9,
+0x14,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x24,0x24,0x0c,
+/* 19849 0x4d89 "䶉" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 19850 0x4d8a "䶊" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x45,0x84,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0xfe,0x00,
+/* 19851 0x4d8b "䶋" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x45,0x84,
+0x00,0xfc,0x44,0x48,0x48,0x50,0x5c,0x44,0x44,0x44,0x68,0xa8,0x90,0x98,0x24,0x42,
+/* 19852 0x4d8c "䶌" */
+0x20,0x7c,0x44,0x7c,0x45,0x7e,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x84,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 19853 0x4d8d "䶍" */
+0x00,0xfe,0x20,0x28,0x44,0xfc,0x14,0x11,0x11,0x7d,0x11,0x11,0x1c,0xe3,0x40,0x01,
+0x40,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x88,0x08,
+/* 19854 0x4d8e "䶎" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x10,0x10,0x28,0x28,0x44,0x82,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0xc4,0x7c,0x44,
+/* 19855 0x4d8f "䶏" */
+0x44,0x28,0x00,0xfc,0x14,0x14,0xfc,0x90,0x90,0xfe,0x32,0x32,0x5a,0x54,0x90,0x10,
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x84,
+/* 19856 0x4d90 "䶐" */
+0x20,0x7c,0x44,0x7c,0x45,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x84,
+0x10,0x28,0x44,0xba,0x00,0xfe,0x92,0xd6,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,
+/* 19857 0x4d91 "䶑" */
+0x20,0x7c,0x44,0x7d,0x45,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x85,
+0x20,0xf8,0x20,0xfc,0x04,0xf8,0xa8,0xf8,0xa8,0xf8,0x44,0xfc,0x20,0xb8,0xa0,0x7c,
+/* 19858 0x4d92 "䶒" */
+0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x20,0x3f,0x20,0x3f,0x22,0x3f,0x24,0x43,0x9c,
+0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x48,0x88,0x68,
+/* 19859 0x4d93 "䶓" */
+0x20,0x20,0x23,0xf8,0xa8,0xaf,0xaa,0xaa,0xad,0xa8,0xa9,0xb9,0x21,0x21,0x21,0x22,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 19860 0x4d94 "䶔" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd7,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x20,0x20,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xa4,0xb4,0xa8,0xa2,0xa2,0x82,0x7e,0x00,
+/* 19861 0x4d95 "䶕" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x00,0x7c,0x54,0x54,0x54,0x54,0x54,0x7c,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 19862 0x4d96 "䶖" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x10,0x10,0x10,0x28,0x28,0x44,0x44,0xa2,0x10,0x10,0x7c,0x04,0x08,0x08,0x10,0x10,
+/* 19863 0x4d97 "䶗" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x7e,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x14,0x08,
+/* 19864 0x4d98 "䶘" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x20,0x10,0x10,0xfe,0x00,0x04,0x44,0x44,0x24,0x24,0x28,0x28,0x08,0x10,0xfe,0x00,
+/* 19865 0x4d99 "䶙" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x7e,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x7c,0x40,0x40,0x40,0x7e,0x00,
+/* 19866 0x4d9a "䶚" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x54,0x10,0x14,0x12,0x7e,0x22,0x00,
+/* 19867 0x4d9b "䶛" */
+0x7f,0x08,0x1e,0x22,0x54,0x08,0x31,0xc9,0x09,0x7f,0x04,0x2a,0x3f,0x24,0x2a,0x3f,
+0x04,0x44,0x44,0x44,0x44,0x44,0x0c,0xe0,0x00,0xfc,0x40,0xa8,0xf8,0x48,0xa8,0xf8,
+/* 19868 0x4d9c "䶜" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x10,0x50,0x50,0x7c,0x50,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 19869 0x4d9d "䶝" */
+0x10,0x50,0x5c,0x51,0xfe,0x28,0xaa,0xd6,0x83,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 19870 0x4d9e "䶞" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x24,0x24,0x7e,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0xfe,0x00,0x24,0x22,0x42,
+/* 19871 0x4d9f "䶟" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x20,0x20,0x3c,0x44,0x48,0x80,0x20,0xcc,0x84,0x84,0xcc,0x84,0x84,0x84,0xfc,0x84,
+/* 19872 0x4da0 "䶠" */
+0x00,0x3f,0x20,0x2f,0x20,0x2f,0x48,0x4f,0x80,0x01,0x11,0x11,0xff,0x04,0x2a,0x3f,
+0x28,0xfe,0x20,0xa4,0x28,0x90,0xaa,0xc6,0x82,0x00,0xf8,0x00,0xfe,0x40,0xa8,0xf8,
+/* 19873 0x4da1 "䶡" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x02,0xe2,0xa2,0xaa,0xaa,0xea,0xaa,0xaa,0xea,0xaa,0xaa,0xa2,0xe2,0x02,0x4a,0xa4,
+/* 19874 0x4da2 "䶢" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x03,
+0x0c,0x0a,0x08,0xfe,0x88,0x88,0xfa,0x8a,0x8a,0xec,0xac,0xac,0xea,0x8a,0x96,0x22,
+/* 19875 0x4da3 "䶣" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x10,0x54,0x54,0x54,0x7c,0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x28,0xfe,0x00,
+/* 19876 0x4da4 "䶤" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+/* 19877 0x4da5 "䶥" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x03,
+0x20,0x3c,0x20,0xfe,0xa2,0xb8,0xe4,0x9c,0x80,0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0x7e,
+/* 19878 0x4da6 "䶦" */
+0x10,0x51,0x5c,0x50,0xfe,0x29,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 19879 0x4da7 "䶧" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x10,0x10,0x7e,0x10,0xfe,0x44,0xee,0x44,0x64,0xde,0x00,0xfe,0x28,0x28,0x4a,0x86,
+/* 19880 0x4da8 "䶨" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x03,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x44,0x44,0xaa,0xaa,0x12,
+/* 19881 0x4da9 "䶩" */
+0x10,0x50,0x5d,0x50,0xff,0x28,0xab,0xd6,0x83,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x03,
+0x20,0x10,0xfe,0x54,0xa8,0xac,0xaa,0xa8,0xac,0x00,0x84,0xfc,0x84,0xfc,0x84,0x04,
+/* 19882 0x4daa "䶪" */
+0x10,0x51,0x5c,0x51,0xfe,0x28,0xaa,0xd6,0x83,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x4c,0xfa,0x48,0xfe,0x08,0x68,0x5a,0xfa,0xaa,0xfc,0xac,0xfc,0xaa,0xfa,0x96,0x22,
+/* 19883 0x4dab "䶫" */
+0x13,0x52,0x5f,0x50,0xff,0x2a,0xaa,0xd6,0x83,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0xde,0x52,0xde,0x00,0xfe,0x00,0xc8,0x4e,0xea,0xb2,0xea,0xaa,0xea,0xb4,0xe4,0x2a,
+/* 19884 0x4dac "䶬" */
+0x00,0x7c,0x10,0xfe,0x10,0x10,0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,
+0x00,0x7c,0x10,0xfe,0x10,0x10,0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,
+/* 19885 0x4dad "䶭" */
+0x14,0x12,0x12,0x10,0xff,0x14,0x14,0x15,0x15,0x16,0x26,0x24,0x2c,0x54,0x43,0x80,
+0x00,0xfe,0x10,0x10,0x90,0x7c,0x10,0x10,0x10,0xfe,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 19886 0x4dae "䶮" */
+0x04,0x04,0xff,0x09,0x11,0x21,0x4f,0x80,0x00,0x1f,0x01,0x7f,0x02,0x04,0x18,0x60,
+0x40,0x20,0xfe,0x10,0x60,0x84,0x04,0xfc,0x00,0xf0,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 19887 0x4daf "䶯" */
+0x20,0x27,0x24,0x27,0xf0,0x56,0x52,0x57,0x52,0x96,0x50,0x26,0x22,0x57,0x52,0x86,
+0x80,0xfc,0x04,0xbc,0xa0,0xbe,0xa2,0xb6,0xaa,0xaa,0xb6,0xa2,0xbe,0xa0,0xa2,0x7e,
+/* 19888 0x4db0 "䶰" */
+0x10,0xff,0x80,0xf7,0x14,0xd7,0x54,0xf6,0x55,0xd5,0x16,0xd4,0x57,0xf4,0x54,0xcf,
+0x00,0x86,0xb8,0x88,0x08,0xce,0x58,0xc8,0x48,0x4e,0xf8,0x48,0xca,0x0a,0x4a,0xc6,
+/* 19889 0x4db1 "䶱" */
+0x40,0x47,0x74,0x97,0x50,0x26,0x52,0x8f,0x0a,0x66,0x10,0x06,0x82,0x47,0x22,0x06,
+0x80,0xfc,0x04,0xbc,0xa0,0xbe,0xa2,0xb6,0xaa,0xaa,0xb6,0xa2,0xbe,0xa0,0xa2,0x7e,
+/* 19890 0x4db2 "䶲" */
+0x10,0x13,0x12,0x7f,0x54,0x57,0x7d,0x57,0x55,0x57,0xfc,0x47,0x45,0x47,0x55,0x4b,
+0x40,0xfe,0x02,0xde,0x50,0x5e,0x52,0xda,0x56,0x56,0x5a,0x52,0x5e,0xd0,0x52,0x3e,
+/* 19891 0x4db3 "䶳" */
+0x08,0x08,0x14,0x22,0x5d,0x80,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,0x55,0x43,
+0x10,0x08,0x00,0x7e,0x00,0x80,0x38,0x28,0x28,0x28,0x28,0x2a,0x2a,0x4a,0x46,0x80,
+/* 19892 0x4db4 "䶴" */
+0x08,0x2a,0x48,0x14,0x21,0x46,0x18,0xef,0x00,0x3b,0x2a,0x7f,0x44,0x7f,0x44,0x44,
+0x40,0x7c,0x94,0x10,0x28,0xc4,0x30,0xee,0x00,0xb8,0xa8,0xfc,0x44,0xfc,0x44,0x4c,
+/* 19893 0x4db5 "䶵" */
+0x10,0x10,0x2b,0x46,0xba,0x02,0xfe,0xaa,0xfe,0x02,0xfe,0xaa,0xfe,0xaa,0xab,0x86,
+0x04,0x3e,0xe0,0x3c,0x20,0xfc,0xa4,0xb8,0xe4,0x9c,0x80,0xb8,0xa8,0xaa,0x2a,0x46,
+/* 19894 0x4db6 "䶶" */
+0x02,0x03,0x02,0x7f,0x00,0x11,0x11,0x7d,0x11,0x1d,0x30,0x57,0x10,0x10,0x51,0x22,
+0x00,0xf8,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x90,0x9c,0x50,0x3e,
+/* 19895 0x4db7 "䶷" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 19896 0x4db8 "䶸" */
+0x00,0x00,0xf0,0x90,0x91,0x91,0x92,0x94,0x90,0x90,0xf0,0x91,0x02,0x07,0x02,0x00,
+0x40,0x40,0x80,0x80,0x00,0x10,0x10,0x20,0x20,0x40,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 19897 0x4db9 "䶹" */
+0x00,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x02,0x02,0x04,0x08,0x30,
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 19898 0x4dba "䶺" */
+0x00,0x78,0x48,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x4a,0x4a,0x9a,
+0xe0,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x52,0x8a,0x06,0x02,0x02,0x02,0x0a,0x04,
+/* 19899 0x4dbb "䶻" */
+0x00,0x3c,0x24,0x25,0x25,0x3e,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 19900 0x4dbc "䶼" */
+0x00,0x78,0x49,0x49,0x4a,0x7c,0x49,0x4b,0x48,0x78,0x48,0x48,0x4a,0x4a,0x4c,0x98,
+0x70,0x10,0x08,0x48,0x44,0x92,0x08,0xfc,0x04,0x40,0x20,0xa4,0x82,0x8a,0x88,0x78,
+/* 19901 0x4dbd "䶽" */
+0x00,0x78,0x4a,0x4a,0x4a,0x7a,0x4b,0x48,0x49,0x7a,0x49,0x48,0x49,0x48,0x48,0x9b,
+0x88,0x50,0x22,0x52,0x8a,0x02,0xfe,0x88,0x08,0x46,0x78,0x88,0x50,0x20,0xd8,0x06,
+/* 19902 0x4dbe "䶾" */
+0x08,0x28,0x4b,0x49,0x49,0x6b,0x49,0x49,0x7f,0x49,0x08,0x14,0x12,0x22,0x40,0x81,
+0x10,0x10,0x10,0x3e,0x22,0x44,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 19903 0x4dbf "䶿" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x50,0x48,0x55,0x65,0x42,
+0x00,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 19904 0x4dc0 "䷀" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19905 0x4dc1 "䷁" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19906 0x4dc2 "䷂" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19907 0x4dc3 "䷃" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19908 0x4dc4 "䷄" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19909 0x4dc5 "䷅" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19910 0x4dc6 "䷆" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19911 0x4dc7 "䷇" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19912 0x4dc8 "䷈" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19913 0x4dc9 "䷉" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19914 0x4dca "䷊" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19915 0x4dcb "䷋" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19916 0x4dcc "䷌" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19917 0x4dcd "䷍" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19918 0x4dce "䷎" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19919 0x4dcf "䷏" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19920 0x4dd0 "䷐" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19921 0x4dd1 "䷑" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19922 0x4dd2 "䷒" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19923 0x4dd3 "䷓" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19924 0x4dd4 "䷔" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19925 0x4dd5 "䷕" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19926 0x4dd6 "䷖" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19927 0x4dd7 "䷗" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19928 0x4dd8 "䷘" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19929 0x4dd9 "䷙" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19930 0x4dda "䷚" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19931 0x4ddb "䷛" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19932 0x4ddc "䷜" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19933 0x4ddd "䷝" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19934 0x4dde "䷞" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19935 0x4ddf "䷟" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19936 0x4de0 "䷠" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19937 0x4de1 "䷡" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19938 0x4de2 "䷢" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19939 0x4de3 "䷣" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19940 0x4de4 "䷤" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19941 0x4de5 "䷥" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19942 0x4de6 "䷦" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19943 0x4de7 "䷧" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19944 0x4de8 "䷨" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19945 0x4de9 "䷩" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19946 0x4dea "䷪" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19947 0x4deb "䷫" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19948 0x4dec "䷬" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19949 0x4ded "䷭" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19950 0x4dee "䷮" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19951 0x4def "䷯" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19952 0x4df0 "䷰" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19953 0x4df1 "䷱" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19954 0x4df2 "䷲" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19955 0x4df3 "䷳" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19956 0x4df4 "䷴" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19957 0x4df5 "䷵" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19958 0x4df6 "䷶" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19959 0x4df7 "䷷" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19960 0x4df8 "䷸" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19961 0x4df9 "䷹" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19962 0x4dfa "䷺" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19963 0x4dfb "䷻" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19964 0x4dfc "䷼" */
+0x00,0x00,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x00,
+/* 19965 0x4dfd "䷽" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x7f,0x00,0x7f,0x00,0x7c,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0xfc,0x00,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x00,
+/* 19966 0x4dfe "䷾" */
+0x00,0x00,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x00,
+/* 19967 0x4dff "䷿" */
+0x00,0x00,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x7f,0x00,0x7c,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0xfc,0x00,0x7c,0x00,0x00,
+/* 19968 0x4e00 "一" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 19969 0x4e01 "丁" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 19970 0x4e02 "丂" */
+0x00,0xff,0x04,0x04,0x08,0x08,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 19971 0x4e03 "七" */
+0x02,0x02,0x02,0x02,0x02,0x02,0x07,0xfa,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x3c,0xc0,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 19972 0x4e04 "丄" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 19973 0x4e05 "丅" */
+0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 19974 0x4e06 "丆" */
+0x00,0xff,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 19975 0x4e07 "万" */
+0x00,0x00,0xff,0x04,0x04,0x04,0x07,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 19976 0x4e08 "丈" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x18,0xe0,
+0x80,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x40,0x30,0x0e,
+/* 19977 0x4e09 "三" */
+0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 19978 0x4e0a "上" */
+0x02,0x02,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 19979 0x4e0b "下" */
+0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 19980 0x4e0c "丌" */
+0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 19981 0x4e0d "不" */
+0x00,0x7f,0x00,0x00,0x01,0x01,0x03,0x05,0x09,0x11,0x21,0x41,0x81,0x01,0x01,0x01,
+0x00,0xfc,0x80,0x80,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,0x00,
+/* 19982 0x4e0e "与" */
+0x10,0x10,0x10,0x1f,0x10,0x20,0x20,0x3f,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xc8,0x08,0x08,0x50,0x20,
+/* 19983 0x4e0f "丏" */
+0x00,0xff,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 19984 0x4e10 "丐" */
+0x00,0xff,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 19985 0x4e11 "丑" */
+0x00,0x3f,0x02,0x02,0x02,0x02,0x02,0x3f,0x04,0x04,0x04,0x04,0x04,0x04,0xff,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 19986 0x4e12 "丒" */
+0x00,0x3f,0x01,0x01,0x09,0x05,0x02,0x03,0x04,0x04,0x08,0x10,0x20,0x00,0xff,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x88,0x08,0x50,0x20,0x00,0xfe,0x00,
+/* 19987 0x4e13 "专" */
+0x01,0x01,0x01,0x3f,0x02,0x02,0xff,0x04,0x08,0x0f,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x40,0x20,
+/* 19988 0x4e14 "且" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0xff,0x00,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 19989 0x4e15 "丕" */
+0x00,0x7f,0x00,0x01,0x01,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,0x01,0x00,0xff,0x00,
+0x00,0xfc,0x80,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 19990 0x4e16 "世" */
+0x02,0x12,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x13,0x10,0x10,0x10,0x1f,0x00,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,0x00,0xfc,0x00,
+/* 19991 0x4e17 "丗" */
+0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x1f,0x10,
+0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 19992 0x4e18 "丘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0xff,0x00,
+0x10,0x78,0x80,0x00,0x00,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 19993 0x4e19 "丙" */
+0x00,0xff,0x01,0x01,0x01,0x7f,0x41,0x41,0x42,0x42,0x44,0x48,0x40,0x40,0x40,0x40,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x84,0x44,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 19994 0x4e1a "业" */
+0x04,0x04,0x04,0x04,0x44,0x24,0x24,0x14,0x14,0x14,0x04,0x04,0x04,0x04,0xff,0x00,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 19995 0x4e1b "丛" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x14,0x12,0x22,0x20,0x41,0x82,0x00,0xff,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x02,0x00,0xfe,0x00,
+/* 19996 0x4e1c "东" */
+0x02,0x02,0x02,0x7f,0x04,0x09,0x11,0x21,0x3f,0x01,0x09,0x11,0x21,0x41,0x05,0x02,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 19997 0x4e1d "丝" */
+0x08,0x08,0x10,0x10,0x22,0x42,0x7c,0x04,0x08,0x10,0x20,0x7e,0x00,0x00,0xff,0x00,
+0x10,0x10,0x20,0x20,0x44,0x84,0xf8,0x08,0x10,0x20,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 19998 0x4e1e "丞" */
+0x00,0x3f,0x00,0x00,0x00,0x7d,0x05,0x09,0x09,0x11,0x21,0x41,0x85,0x02,0xff,0x00,
+0x00,0xf0,0x20,0x40,0x80,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0x00,0xfe,0x00,
+/* 19999 0x4e1f "丟" */
+0x00,0x7f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 20000 0x4e20 "丠" */
+0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x04,0x1c,0xe4,0x44,0x00,0xff,0x00,
+0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x40,0x42,0x42,0x42,0x3e,0x00,0x00,0xfe,0x00,
+/* 20001 0x4e21 "両" */
+0x00,0xff,0x01,0x01,0x01,0x7f,0x41,0x49,0x49,0x49,0x49,0x4f,0x40,0x40,0x40,0x40,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x14,0x08,
+/* 20002 0x4e22 "丢" */
+0x00,0x00,0x3f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x10,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 20003 0x4e23 "丣" */
+0x00,0xff,0x04,0x04,0x04,0x7c,0x44,0x44,0x44,0x7c,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x7c,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 20004 0x4e24 "两" */
+0x00,0xff,0x04,0x04,0x04,0x7f,0x44,0x44,0x44,0x4a,0x4a,0x51,0x42,0x40,0x40,0x40,
+0x00,0xfe,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0x14,0x08,
+/* 20005 0x4e25 "严" */
+0x00,0x7f,0x02,0x12,0x0a,0x02,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0xfc,0x40,0x48,0x50,0x40,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20006 0x4e26 "並" */
+0x10,0x08,0x04,0x7f,0x04,0x04,0x04,0x44,0x24,0x14,0x14,0x04,0x04,0x04,0xff,0x00,
+0x10,0x20,0x40,0xfc,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0x40,0x40,0xfe,0x00,
+/* 20007 0x4e27 "丧" */
+0x01,0x01,0x7f,0x01,0x11,0x09,0x09,0x01,0xff,0x12,0x11,0x10,0x10,0x14,0x18,0x10,
+0x00,0x00,0xfc,0x00,0x10,0x10,0x20,0x00,0xfe,0x00,0x10,0xa0,0x40,0x30,0x0e,0x00,
+/* 20008 0x4e28 "丨" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20009 0x4e29 "丩" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x13,0x1c,0x10,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20010 0x4e2a "个" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x21,0xc1,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20011 0x4e2b "丫" */
+0x00,0x20,0x10,0x08,0x04,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20012 0x4e2c "丬" */
+0x01,0x01,0x01,0x11,0x09,0x09,0x01,0x03,0x05,0x09,0x31,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20013 0x4e2d "中" */
+0x01,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,
+/* 20014 0x4e2e "丮" */
+0x00,0x7f,0x04,0x04,0x04,0x7f,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0xf0,0x10,0x10,0x10,0xd0,0x10,0x10,0x10,0xd0,0x12,0x0a,0x0a,0x06,0x02,0x00,
+/* 20015 0x4e2f "丯" */
+0x01,0x01,0x01,0x07,0x79,0x01,0x01,0x07,0x79,0x01,0x01,0x07,0x79,0x01,0x01,0x01,
+0x00,0x0c,0x70,0x80,0x00,0x0c,0x70,0x80,0x00,0x0c,0x70,0x80,0x00,0x00,0x00,0x00,
+/* 20016 0x4e30 "丰" */
+0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 20017 0x4e31 "丱" */
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x4c,0x54,0x64,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x40,0x40,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20018 0x4e32 "串" */
+0x01,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x7f,0x41,0x41,0x7f,0x41,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,
+/* 20019 0x4e33 "丳" */
+0x04,0x04,0x3f,0x24,0x24,0x3f,0x04,0x04,0x7f,0x44,0x44,0x7f,0x48,0x10,0x20,0x40,
+0x40,0x40,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,
+/* 20020 0x4e34 "临" */
+0x08,0x08,0x08,0x49,0x49,0x4a,0x4c,0x48,0x49,0x49,0x49,0x49,0x49,0x09,0x09,0x08,
+0x80,0x80,0x80,0xfe,0x40,0x20,0x20,0x00,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 20021 0x4e35 "丵" */
+0x04,0x24,0x14,0x04,0xff,0x00,0x08,0x04,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x40,0x48,0x50,0x40,0xfe,0x00,0x20,0x40,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 20022 0x4e36 "丶" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 20023 0x4e37 "丷" */
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20024 0x4e38 "丸" */
+0x02,0x02,0x02,0x02,0x7f,0x02,0x12,0x0a,0x04,0x04,0x0a,0x09,0x11,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20025 0x4e39 "丹" */
+0x00,0x1f,0x10,0x10,0x12,0x11,0x11,0x10,0xff,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 20026 0x4e3a "为" */
+0x01,0x21,0x11,0x11,0x01,0x7f,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x50,0x20,
+/* 20027 0x4e3b "主" */
+0x02,0x01,0x00,0x7f,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 20028 0x4e3c "丼" */
+0x08,0x08,0x08,0x08,0x7f,0x08,0x0a,0x09,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x40,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20029 0x4e3d "丽" */
+0x00,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x32,0x2a,0x2a,0x22,0x22,0x22,0x2a,0x24,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xc8,0xa8,0xa8,0x88,0x88,0x88,0xa8,0x90,
+/* 20030 0x4e3e "举" */
+0x22,0x11,0x11,0x00,0xff,0x08,0x11,0x21,0xcf,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,
+0x08,0x08,0x10,0x20,0xfe,0x20,0x10,0x08,0xe6,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,
+/* 20031 0x4e3f "丿" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20032 0x4e40 "乀" */
+0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x24,0x42,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x0e,0x00,0x00,0x00,
+/* 20033 0x4e41 "乁" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 20034 0x4e42 "乂" */
+0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 20035 0x4e43 "乃" */
+0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0xf0,0x10,0x20,0x20,0x40,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 20036 0x4e44 "乄" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x01,0x22,0x24,0x38,0x20,0x00,
+0x00,0x10,0x10,0x10,0x10,0x20,0x20,0xc0,0x40,0xa0,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 20037 0x4e45 "久" */
+0x04,0x04,0x04,0x07,0x08,0x08,0x10,0x20,0x40,0x00,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xe0,0x20,0x20,0x40,0x40,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 20038 0x4e46 "乆" */
+0x00,0x08,0x08,0x10,0x10,0x20,0x7f,0x20,0x00,0x01,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x10,0x10,0x10,0x20,0x20,0x40,0xc0,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 20039 0x4e47 "乇" */
+0x00,0x03,0x3e,0x02,0x02,0x02,0x02,0x03,0xfe,0x02,0x02,0x02,0x02,0x02,0x01,0x00,
+0x20,0xf0,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 20040 0x4e48 "么" */
+0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0x41,0x02,0x04,0x08,0x10,0x3f,0x10,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,0x00,
+/* 20041 0x4e49 "义" */
+0x02,0x01,0x21,0x20,0x10,0x10,0x08,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 20042 0x4e4a "乊" */
+0x00,0x00,0x01,0x7e,0x00,0x20,0x10,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0xfc,0x00,0x08,0x08,0x10,0x10,0x20,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20043 0x4e4b "之" */
+0x02,0x01,0x01,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x18,0x24,0x43,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 20044 0x4e4c "乌" */
+0x01,0x02,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x10,0x10,0x10,0x50,0x20,0x00,0xfc,0x04,0x04,0xe4,0x04,0x28,0x10,
+/* 20045 0x4e4d "乍" */
+0x08,0x08,0x0f,0x12,0x12,0x22,0x43,0x82,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 20046 0x4e4e "乎" */
+0x00,0x00,0x3f,0x01,0x11,0x09,0x09,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x10,0xf8,0x00,0x00,0x10,0x10,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20047 0x4e4f "乏" */
+0x00,0x01,0x7e,0x00,0x02,0x01,0x01,0x7f,0x00,0x00,0x03,0x0c,0x30,0x48,0x87,0x00,
+0x10,0xf8,0x00,0x00,0x00,0x00,0x00,0xf8,0x30,0xc0,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 20048 0x4e50 "乐" */
+0x00,0x00,0x1f,0x10,0x11,0x21,0x21,0x3f,0x01,0x09,0x09,0x11,0x21,0x41,0x05,0x02,
+0x20,0xf0,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,
+/* 20049 0x4e51 "乑" */
+0x00,0x01,0x7f,0x01,0x09,0x09,0x11,0x21,0x45,0x85,0x09,0x11,0x21,0x41,0x81,0x01,
+0x08,0xfc,0x00,0x00,0x04,0x08,0x90,0xa0,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 20050 0x4e52 "乒" */
+0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0xff,0x00,0x08,0x10,0x20,0x40,
+0x20,0xf0,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 20051 0x4e53 "乓" */
+0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0xff,0x00,0x00,0x00,0x00,0x00,
+0x20,0xf0,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0xfe,0x00,0x40,0x20,0x10,0x08,
+/* 20052 0x4e54 "乔" */
+0x00,0x00,0x3f,0x01,0x02,0x7f,0x04,0x08,0x30,0xc8,0x08,0x08,0x08,0x10,0x10,0x20,
+0x10,0xf8,0x00,0x00,0x00,0xfc,0x40,0x20,0x18,0x26,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20053 0x4e55 "乕" */
+0x00,0x00,0x3f,0x20,0x2f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x28,0x48,0x48,0x88,0x00,
+0x08,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfe,0x80,0x80,0xf8,0x88,0x88,0xa8,0x90,0x80,
+/* 20054 0x4e56 "乖" */
+0x00,0x1f,0x01,0x01,0xff,0x01,0x09,0x09,0x79,0x09,0x09,0x19,0xe9,0x01,0x01,0x01,
+0x70,0x80,0x00,0x00,0xfe,0x00,0x20,0x24,0x28,0x30,0x22,0x22,0x1e,0x00,0x00,0x00,
+/* 20055 0x4e57 "乗" */
+0x00,0x3f,0x01,0x7f,0x09,0x09,0xff,0x09,0x09,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0xf8,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 20056 0x4e58 "乘" */
+0x00,0x3f,0x01,0x7f,0x01,0x09,0xf9,0x09,0x39,0xcb,0x05,0x09,0x31,0xc1,0x01,0x01,
+0xf8,0x00,0x00,0xfc,0x00,0x24,0x38,0x22,0x22,0x9e,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 20057 0x4e59 "乙" */
+0x00,0x7f,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x10,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xf0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 20058 0x4e5a "乚" */
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 20059 0x4e5b "乛" */
+0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20060 0x4e5c "乜" */
+0x00,0x00,0x10,0x10,0x10,0x17,0x38,0xd0,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x00,0x00,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,0x02,0x02,0x02,0xfe,0x00,
+/* 20061 0x4e5d "九" */
+0x04,0x04,0x04,0x04,0x7f,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20062 0x4e5e "乞" */
+0x08,0x08,0x1f,0x10,0x20,0x40,0x9f,0x00,0x00,0x01,0x06,0x08,0x10,0x10,0x0f,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 20063 0x4e5f "也" */
+0x01,0x01,0x11,0x11,0x11,0x17,0x39,0xd1,0x11,0x11,0x11,0x11,0x10,0x10,0x0f,0x00,
+0x00,0x00,0x00,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,0x02,0x02,0x02,0xfe,0x00,
+/* 20064 0x4e60 "习" */
+0x00,0x7f,0x00,0x00,0x08,0x04,0x02,0x02,0x00,0x01,0x0e,0x70,0x20,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x68,0x88,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 20065 0x4e61 "乡" */
+0x02,0x02,0x04,0x08,0x10,0x3f,0x01,0x02,0x04,0x1f,0x00,0x00,0x01,0x06,0x18,0xe0,
+0x00,0x00,0x20,0x20,0x40,0x80,0x08,0x08,0x10,0xe0,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 20066 0x4e62 "乢" */
+0x08,0x08,0x08,0x08,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x4f,0x79,0x00,0x00,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20067 0x4e63 "乣" */
+0x08,0x08,0x10,0x10,0x22,0x42,0xfc,0x04,0x08,0x10,0x24,0x42,0xfe,0x42,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20068 0x4e64 "乤" */
+0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfe,0x00,0x40,0x20,0x10,0x08,0x00,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20069 0x4e65 "乥" */
+0x00,0x01,0x7e,0x00,0x10,0x08,0x04,0x00,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x08,0xfc,0x00,0x10,0x10,0x20,0x40,0x80,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20070 0x4e66 "书" */
+0x02,0x02,0x02,0x3f,0x02,0x02,0x02,0x02,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x20,0x10,0x08,0xe0,0x20,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,0x00,
+/* 20071 0x4e67 "乧" */
+0x00,0x04,0x02,0x12,0x08,0x09,0x7e,0x00,0x00,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 20072 0x4e68 "乨" */
+0x08,0x08,0x10,0x22,0x41,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x20,0x20,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20073 0x4e69 "乩" */
+0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x20,0x20,0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20074 0x4e6a "乪" */
+0x00,0xfd,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x21,0x41,0x41,0x40,0x40,0x3f,0x00,
+0x00,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x02,0x02,0xfe,0x00,
+/* 20075 0x4e6b "乫" */
+0x10,0x10,0x7e,0x12,0x12,0x12,0x22,0x4a,0x84,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20076 0x4e6c "乬" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20077 0x4e6d "乭" */
+0x00,0xff,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x00,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20078 0x4e6e "乮" */
+0x0c,0x70,0x40,0x44,0x5c,0x64,0x44,0x08,0x10,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x00,0xfc,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20079 0x4e6f "乯" */
+0x00,0x7f,0x11,0x09,0xff,0x01,0x01,0x05,0x02,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0xf8,0x00,0x10,0x20,0xfe,0x00,0x00,0x00,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20080 0x4e70 "买" */
+0x00,0x7f,0x00,0x08,0x04,0x24,0x10,0x10,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x04,0x88,0x80,0x80,0x80,0x80,0x00,0xfe,0x00,0xc0,0x20,0x10,0x08,0x04,
+/* 20081 0x4e71 "乱" */
+0x04,0x0e,0x38,0x08,0x08,0xff,0x08,0x08,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20082 0x4e72 "乲" */
+0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 20083 0x4e73 "乳" */
+0x02,0x0f,0xf0,0x01,0x91,0x4a,0x00,0xfe,0x04,0x08,0x0f,0xf8,0x48,0x08,0x28,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20084 0x4e74 "乴" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 20085 0x4e75 "乵" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,
+0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20086 0x4e76 "乶" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x00,0x3f,0x01,0x1e,0x20,0x1f,
+0x20,0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xf0,0xc0,0x04,0x04,0xfc,
+/* 20087 0x4e77 "乷" */
+0x10,0x08,0x40,0x24,0x09,0x12,0x70,0x10,0x17,0x00,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x20,0x20,0xa8,0xa4,0x22,0x28,0x30,0xc0,0x00,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 20088 0x4e78 "乸" */
+0x08,0x08,0x28,0x2e,0x3a,0xea,0x2a,0x2a,0x2a,0x2e,0x28,0x28,0x20,0x20,0x1f,0x00,
+0x00,0x7c,0x44,0x64,0x54,0xfe,0x44,0xa4,0x94,0xfe,0x04,0x2a,0x12,0x02,0xfe,0x00,
+/* 20089 0x4e79 "乹" */
+0x08,0x08,0xff,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x49,0x08,0xff,0x08,0x08,0x08,0x08,
+0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa2,0x22,0x22,0x1e,0x00,
+/* 20090 0x4e7a "乺" */
+0x06,0x38,0x20,0x3e,0x22,0x3e,0x20,0x41,0x80,0x7f,0x00,0x01,0x06,0x18,0x20,0x1f,
+0x18,0xe0,0x80,0xfc,0x90,0x90,0x90,0x10,0x00,0xf0,0x60,0x80,0x00,0x04,0x04,0xfc,
+/* 20091 0x4e7b "乻" */
+0x10,0x08,0xff,0x20,0x3e,0x22,0x22,0x42,0x4a,0x84,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x10,0x10,0x28,0x44,0x82,0x10,0x08,0x20,0x10,0x08,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 20092 0x4e7c "乼" */
+0x20,0x10,0x87,0x40,0x10,0x23,0xe0,0x20,0x27,0x20,0x7f,0x00,0x03,0x1c,0x20,0x1f,
+0x80,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0xf0,0x60,0x80,0x04,0x04,0xfc,
+/* 20093 0x4e7d "乽" */
+0x01,0x1f,0x01,0x7f,0x02,0x0f,0x38,0xcf,0x08,0x0f,0x00,0x3f,0x01,0x1e,0x20,0x1f,
+0x08,0xd0,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0xc0,0x04,0x04,0xfc,
+/* 20094 0x4e7e "乾" */
+0x10,0x10,0x10,0xfe,0x11,0x7e,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x11,0x11,0x10,0x10,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 20095 0x4e7f "乿" */
+0x0f,0xf0,0x11,0x89,0x42,0x10,0x22,0x7c,0x08,0x11,0xff,0x08,0x4a,0x89,0x28,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0xa2,0x22,0x22,0x1e,0x00,
+/* 20096 0x4e80 "亀" */
+0x04,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x00,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 20097 0x4e81 "亁" */
+0x08,0x08,0xff,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x00,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x20,0x20,0xa0,0x7e,0x40,0x80,0x7c,0x04,0x08,0x10,0x20,0x40,0xc2,0x42,0x3e,0x00,
+/* 20098 0x4e82 "亂" */
+0x0f,0xf0,0x49,0x22,0xfe,0x14,0x08,0xff,0x95,0xbd,0x83,0xbd,0x95,0x89,0x95,0xa3,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20099 0x4e83 "亃" */
+0x08,0x49,0x2a,0xff,0x2a,0x49,0x88,0x41,0x41,0x77,0x91,0x55,0x27,0x41,0x81,0x01,
+0x20,0x20,0x20,0xa0,0x20,0x20,0xa0,0x20,0x20,0xa0,0x20,0x22,0xa2,0x22,0x1e,0x00,
+/* 20100 0x4e84 "亄" */
+0x08,0xff,0x08,0x7f,0x00,0xff,0x80,0x7f,0x00,0x7f,0x41,0x7f,0x41,0x22,0x0f,0xf0,
+0x20,0xa0,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x9e,0x00,
+/* 20101 0x4e85 "亅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 20102 0x4e86 "了" */
+0x00,0x7f,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20103 0x4e87 "亇" */
+0x08,0x08,0x08,0x0f,0x10,0x11,0x21,0x41,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0x00,0xfc,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20104 0x4e88 "予" */
+0x00,0x1f,0x00,0x02,0x01,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,
+0x00,0xf0,0x10,0x20,0x40,0x80,0xfe,0x82,0x84,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 20105 0x4e89 "争" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x01,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0x05,0x02,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 20106 0x4e8a "亊" */
+0x01,0x01,0x7f,0x11,0x09,0x3f,0x01,0x01,0xff,0x01,0x01,0x3f,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfc,0x10,0x20,0xf8,0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 20107 0x4e8b "事" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x3f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x00,0x00,
+/* 20108 0x4e8c "二" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 20109 0x4e8d "亍" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20110 0x4e8e "于" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20111 0x4e8f "亏" */
+0x00,0x3f,0x00,0x00,0x00,0xff,0x04,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 20112 0x4e90 "亐" */
+0x00,0x3f,0x02,0x02,0x02,0xff,0x04,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 20113 0x4e91 "云" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0xff,0x02,0x04,0x04,0x08,0x10,0x20,0x7f,0x20,0x00,
+0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x40,0x20,0x10,0xf8,0x08,0x08,
+/* 20114 0x4e92 "互" */
+0x00,0x7f,0x04,0x04,0x04,0x0f,0x08,0x08,0x10,0x10,0x1f,0x00,0x00,0x00,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x20,0xe0,0x20,0x40,0x40,0xfe,0x00,
+/* 20115 0x4e93 "亓" */
+0x00,0x3f,0x00,0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0xf8,0x00,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20116 0x4e94 "五" */
+0x00,0x7f,0x02,0x02,0x02,0x02,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 20117 0x4e95 "井" */
+0x08,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x40,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20118 0x4e96 "亖" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0xff,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 20119 0x4e97 "亗" */
+0x01,0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0xff,0x00,
+0x00,0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 20120 0x4e98 "亘" */
+0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x00,0x00,0xff,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x00,0x00,0xfe,0x00,
+/* 20121 0x4e99 "亙" */
+0x00,0x7f,0x04,0x04,0x04,0x0f,0x08,0x0a,0x11,0x10,0x04,0x02,0x00,0x00,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0xfe,0x00,
+/* 20122 0x4e9a "亚" */
+0x00,0x7f,0x04,0x04,0x04,0x04,0x44,0x24,0x24,0x14,0x14,0x04,0x04,0x04,0xff,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x48,0x50,0x40,0x40,0x40,0xfe,0x00,
+/* 20123 0x4e9b "些" */
+0x04,0x04,0x24,0x27,0x24,0x24,0x24,0x2f,0xf0,0x40,0x00,0x1f,0x00,0x00,0x7f,0x00,
+0x40,0x40,0x44,0x48,0x70,0x42,0x42,0x42,0x3e,0x00,0x00,0xf0,0x00,0x00,0xfc,0x00,
+/* 20124 0x4e9c "亜" */
+0x00,0x7f,0x04,0x04,0x04,0x3f,0x24,0x24,0x24,0x24,0x3f,0x04,0x04,0x04,0xff,0x00,
+0x00,0xfc,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 20125 0x4e9d "亝" */
+0x04,0x08,0x10,0x3f,0x08,0x10,0x24,0x7e,0x02,0x00,0x3f,0x00,0x00,0x00,0xff,0x00,
+0x00,0x20,0x10,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 20126 0x4e9e "亞" */
+0x00,0x7f,0x04,0x04,0x04,0x3c,0x20,0x20,0x20,0x20,0x3c,0x04,0x04,0x04,0xff,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x08,0x08,0x08,0x08,0x78,0x40,0x40,0x40,0xfe,0x00,
+/* 20127 0x4e9f "亟" */
+0x00,0x3f,0x00,0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x79,0x01,0x05,0x02,0xff,0x00,
+0x00,0xf0,0x20,0x40,0x80,0x3c,0x04,0x44,0x28,0x10,0x28,0x44,0x00,0x00,0xfe,0x00,
+/* 20128 0x4ea0 "亠" */
+0x02,0x01,0x01,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20129 0x4ea1 "亡" */
+0x02,0x01,0x01,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 20130 0x4ea2 "亢" */
+0x02,0x01,0x01,0xff,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0x00,0x00,0xfe,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20131 0x4ea3 "亣" */
+0x02,0x01,0x01,0xff,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20132 0x4ea4 "交" */
+0x02,0x01,0x01,0xff,0x00,0x10,0x10,0x20,0x48,0x04,0x02,0x01,0x02,0x0c,0x30,0xc0,
+0x00,0x00,0x00,0xfe,0x00,0x10,0x08,0x24,0x24,0x40,0x80,0x00,0x80,0x40,0x30,0x0e,
+/* 20133 0x4ea5 "亥" */
+0x02,0x01,0x00,0x7f,0x02,0x04,0x08,0x10,0x3f,0x01,0x06,0x18,0x60,0x03,0x0c,0x70,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x20,0x40,0x88,0x10,0x20,0x40,0xa0,0x10,0x08,0x04,
+/* 20134 0x4ea6 "亦" */
+0x02,0x01,0x01,0xff,0x04,0x04,0x24,0x24,0x24,0x44,0x44,0x88,0x08,0x10,0x21,0x40,
+0x00,0x00,0x00,0xfe,0x40,0x40,0x50,0x48,0x48,0x44,0x44,0x44,0x40,0x40,0x40,0x80,
+/* 20135 0x4ea7 "产" */
+0x02,0x01,0x7f,0x00,0x08,0x04,0x04,0x3f,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0x00,0xfc,0x00,0x20,0x20,0x40,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20136 0x4ea8 "亨" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x00,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf0,0x60,0x80,0x00,0x00,0x00,0x00,
+/* 20137 0x4ea9 "亩" */
+0x02,0x01,0x01,0xff,0x00,0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x00,0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 20138 0x4eaa "亪" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x48,0x09,0x10,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x40,0x80,0xe0,0x20,0x20,0x10,0x10,0x08,0x06,
+/* 20139 0x4eab "享" */
+0x02,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x1f,0x00,0x01,0xff,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 20140 0x4eac "京" */
+0x02,0x01,0xff,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 20141 0x4ead "亭" */
+0x02,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x9f,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0x00,0x00,0x00,0x00,
+/* 20142 0x4eae "亮" */
+0x02,0x01,0x7f,0x00,0x0f,0x08,0x0f,0x00,0x7f,0x40,0x87,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x00,0xe0,0x20,0xe0,0x00,0xfe,0x02,0xc4,0x40,0x40,0x42,0x42,0x3e,
+/* 20143 0x4eaf "亯" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 20144 0x4eb0 "亰" */
+0x02,0x01,0xff,0x00,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 20145 0x4eb1 "亱" */
+0x02,0x01,0xff,0x08,0x08,0x13,0x12,0x32,0x53,0x92,0x12,0x13,0x12,0x10,0x17,0x10,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0xfc,0x00,
+/* 20146 0x4eb2 "亲" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x01,0x01,0x7f,0x01,0x09,0x11,0x21,0x45,0x02,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0x00,0xfc,0x00,0x20,0x10,0x08,0x04,0x00,
+/* 20147 0x4eb3 "亳" */
+0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x80,0x3f,0x02,0x03,0x7e,0x02,0x01,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0x00,0xf8,0x02,0x02,0xfe,
+/* 20148 0x4eb4 "亴" */
+0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x41,0x9f,0x01,0x7f,0x02,0x3f,0x08,0x70,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0xfc,0x00,0xe0,0x22,0x1e,
+/* 20149 0x4eb5 "亵" */
+0x01,0xff,0x00,0x08,0x7d,0x08,0x0c,0x78,0x08,0x29,0x13,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0x40,0xf8,0x48,0xc8,0x4a,0xaa,0x06,0x02,0x88,0x50,0x30,0x0e,0x00,
+/* 20150 0x4eb6 "亶" */
+0x01,0xff,0x00,0x3f,0x20,0x27,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,
+0x00,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 20151 0x4eb7 "亷" */
+0x01,0x00,0x3f,0x04,0x02,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x26,0x4a,0x52,0x82,
+0x00,0x80,0xfc,0x10,0x20,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x60,0x50,0x4c,0x40,
+/* 20152 0x4eb8 "亸" */
+0x20,0x10,0xfc,0x01,0x7d,0x45,0x7d,0x01,0x7d,0x09,0x10,0x1c,0xf3,0x10,0x50,0x20,
+0x88,0x48,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 20153 0x4eb9 "亹" */
+0x01,0xff,0x00,0x2f,0x48,0x6b,0x48,0x6b,0x4a,0xff,0x90,0x1f,0x10,0x1f,0x10,0xff,
+0x00,0xfe,0x00,0xec,0x24,0xac,0x24,0xac,0xa4,0xfe,0x12,0xf0,0x10,0xf0,0x10,0xfe,
+/* 20154 0x4eba "人" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x04,0x02,
+/* 20155 0x4ebb "亻" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20156 0x4ebc "亼" */
+0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,0x00,0x00,0xff,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0xfe,0x00,
+/* 20157 0x4ebd "亽" */
+0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0xc0,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0x80,0x80,0x00,0x00,
+/* 20158 0x4ebe "亾" */
+0x00,0x00,0x00,0x20,0x20,0x21,0x21,0x22,0x22,0x24,0x28,0x30,0x20,0x20,0x3f,0x00,
+0x80,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x06,0x00,0x00,0xfe,0x00,
+/* 20159 0x4ebf "亿" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x90,0x11,0x11,0x12,0x12,0x12,0x11,0x10,
+0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x80,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 20160 0x4ec0 "什" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x37,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20161 0x4ec1 "仁" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x17,0x10,0x10,0x10,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 20162 0x4ec2 "仂" */
+0x08,0x08,0x08,0x10,0x13,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 20163 0x4ec3 "仃" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 20164 0x4ec4 "仄" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x21,0x21,0x22,0x42,0x44,0x88,0x10,
+0x00,0xfe,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 20165 0x4ec5 "仅" */
+0x08,0x0b,0x09,0x11,0x11,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x04,0x04,0x04,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 20166 0x4ec6 "仆" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20167 0x4ec7 "仇" */
+0x09,0x09,0x09,0x11,0x17,0x31,0x31,0x51,0x91,0x11,0x11,0x12,0x12,0x14,0x18,0x10,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 20168 0x4ec8 "仈" */
+0x08,0x08,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x12,0x12,0x14,0x18,0x10,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 20169 0x4ec9 "仉" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 20170 0x4eca "今" */
+0x01,0x01,0x02,0x04,0x08,0x12,0x21,0xc1,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x01,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0xf0,0x10,0x20,0x20,0x40,0x80,0x00,
+/* 20171 0x4ecb "介" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x20,0xc8,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x26,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20172 0x4ecc "仌" */
+0x01,0x01,0x02,0x02,0x04,0x08,0x11,0x61,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 20173 0x4ecd "仍" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x90,0x10,0x11,0x11,0x11,0x12,0x12,0x14,
+0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 20174 0x4ece "从" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x14,0x12,0x12,0x20,0x21,0x42,0x84,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x04,0x02,
+/* 20175 0x4ecf "仏" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x50,0x91,0x11,0x11,0x12,0x17,0x12,0x10,0x10,
+0x40,0x40,0x40,0x40,0x40,0x80,0x80,0x80,0x00,0x10,0x08,0x08,0xfc,0x04,0x04,0x00,
+/* 20176 0x4ed0 "仐" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x21,0xc1,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 20177 0x4ed1 "仑" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x20,0xc8,0x08,0x08,0x0f,0x08,0x08,0x08,0x07,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x30,0xc0,0x00,0x08,0x08,0x08,0xf8,0x00,
+/* 20178 0x4ed2 "仒" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x20,0xc6,0x01,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x80,0x40,0x00,0x00,0x00,0xc0,0x20,0x00,
+/* 20179 0x4ed3 "仓" */
+0x01,0x01,0x02,0x04,0x08,0x30,0xc0,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0xe0,0x20,0x20,0xa0,0x44,0x04,0x04,0xfc,0x00,
+/* 20180 0x4ed4 "仔" */
+0x08,0x0b,0x08,0x10,0x10,0x30,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x10,
+0x00,0xf8,0x08,0x10,0x20,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 20181 0x4ed5 "仕" */
+0x08,0x08,0x08,0x10,0x10,0x3f,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x17,0x10,0x10,
+0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfc,0x00,0x00,
+/* 20182 0x4ed6 "他" */
+0x08,0x08,0x0a,0x12,0x12,0x32,0x33,0x5e,0x92,0x12,0x12,0x12,0x12,0x12,0x11,0x10,
+0x40,0x40,0x40,0x58,0x68,0xc8,0x48,0x48,0x48,0x48,0x58,0x42,0x02,0x02,0xfe,0x00,
+/* 20183 0x4ed7 "仗" */
+0x08,0x08,0x08,0x10,0x13,0x30,0x30,0x51,0x91,0x10,0x10,0x10,0x10,0x10,0x11,0x16,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 20184 0x4ed8 "付" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x50,0x91,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 20185 0x4ed9 "仙" */
+0x10,0x10,0x10,0x20,0x24,0x64,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x27,0x20,0x20,
+0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,0x00,
+/* 20186 0x4eda "仚" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x21,0xc1,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20187 0x4edb "仛" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x97,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20188 0x4edc "仜" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x17,0x10,0x10,
+0x00,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 20189 0x4edd "仝" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x20,0xc0,0x1f,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0xf0,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 20190 0x4ede "仞" */
+0x08,0x08,0x0b,0x10,0x10,0x32,0x32,0x52,0x94,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 20191 0x4edf "仟" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20192 0x4ee0 "仠" */
+0x08,0x0b,0x08,0x10,0x10,0x30,0x30,0x5f,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20193 0x4ee1 "仡" */
+0x08,0x08,0x09,0x11,0x12,0x34,0x31,0x50,0x90,0x10,0x10,0x11,0x12,0x12,0x11,0x10,
+0x80,0x80,0x00,0xfe,0x00,0x00,0xf8,0x08,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 20194 0x4ee2 "仢" */
+0x08,0x08,0x09,0x11,0x12,0x32,0x34,0x59,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 20195 0x4ee3 "代" */
+0x08,0x08,0x08,0x10,0x10,0x37,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x90,0x88,0x88,0x80,0xbe,0xc0,0x80,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 20196 0x4ee4 "令" */
+0x01,0x01,0x02,0x04,0x0a,0x11,0x21,0xc0,0x1f,0x00,0x00,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x06,0xf0,0x10,0x20,0x40,0x80,0x00,0x80,0x80,
+/* 20197 0x4ee5 "以" */
+0x00,0x04,0x22,0x21,0x21,0x20,0x20,0x20,0x20,0x20,0x24,0x28,0x30,0x21,0x02,0x04,
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x20,0x40,0x50,0x88,0x04,0x02,0x02,
+/* 20198 0x4ee6 "仦" */
+0x08,0x08,0x08,0x10,0x10,0x31,0x31,0x51,0x92,0x12,0x12,0x14,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x22,0x22,0x20,0x20,0xa0,0x40,
+/* 20199 0x4ee7 "仧" */
+0x02,0x02,0x02,0x03,0x02,0x02,0x02,0xff,0x01,0x01,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 20200 0x4ee8 "仨" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x51,0x90,0x10,0x10,0x10,0x10,0x17,0x10,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 20201 0x4ee9 "仩" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x17,0x10,
+0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 20202 0x4eea "仪" */
+0x08,0x08,0x0a,0x12,0x12,0x31,0x31,0x51,0x90,0x10,0x10,0x10,0x10,0x11,0x12,0x14,
+0x80,0x48,0x48,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 20203 0x4eeb "仫" */
+0x08,0x08,0x08,0x10,0x11,0x31,0x32,0x54,0x90,0x10,0x10,0x11,0x12,0x17,0x12,0x10,
+0x40,0x40,0x80,0x80,0x00,0x10,0x10,0x20,0x20,0x40,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 20204 0x4eec "们" */
+0x09,0x08,0x08,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0x80,0xbc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20205 0x4eed "仭" */
+0x08,0x08,0x0b,0x10,0x10,0x32,0x31,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xc8,0xa8,0x98,0x0e,0x08,0x08,0x50,0x20,
+/* 20206 0x4eee "仮" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x33,0x52,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x19,
+0x08,0x3c,0xc0,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 20207 0x4eef "仯" */
+0x08,0x08,0x08,0x11,0x11,0x32,0x32,0x54,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x16,
+0x40,0x40,0x40,0x48,0x44,0x42,0x42,0x48,0x48,0x48,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 20208 0x4ef0 "仰" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x12,0x13,0x12,0x10,0x10,0x10,
+0x00,0x80,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xb4,0x28,0x20,0x20,0x20,0x20,
+/* 20209 0x4ef1 "仱" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x34,0x50,0x90,0x13,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x88,0x46,0x40,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,
+/* 20210 0x4ef2 "仲" */
+0x08,0x08,0x08,0x10,0x17,0x34,0x34,0x54,0x94,0x14,0x17,0x14,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x40,
+/* 20211 0x4ef3 "仳" */
+0x08,0x0a,0x0a,0x12,0x12,0x32,0x33,0x52,0x92,0x12,0x12,0x12,0x12,0x13,0x12,0x10,
+0x20,0x20,0x20,0x22,0x22,0x24,0xa8,0x30,0x20,0x20,0x20,0x22,0xa2,0x22,0x1e,0x00,
+/* 20212 0x4ef4 "仴" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20213 0x4ef5 "仵" */
+0x11,0x11,0x11,0x23,0x22,0x62,0x64,0xa0,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0xf8,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20214 0x4ef6 "件" */
+0x08,0x08,0x09,0x11,0x11,0x32,0x32,0x54,0x90,0x17,0x10,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 20215 0x4ef7 "价" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x34,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 20216 0x4ef8 "仸" */
+0x08,0x08,0x0f,0x10,0x10,0x30,0x30,0x57,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 20217 0x4ef9 "仹" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x30,0x53,0x90,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 20218 0x4efa "仺" */
+0x01,0x02,0x04,0x08,0x30,0xc0,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x00,
+0x00,0x80,0x40,0x20,0x18,0x06,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf8,0x00,
+/* 20219 0x4efb "任" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x5f,0x90,0x10,0x10,0x10,0x10,0x10,0x17,0x10,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0xfc,0x00,
+/* 20220 0x4efc "仼" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x91,0x10,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 20221 0x4efd "份" */
+0x08,0x08,0x08,0x10,0x11,0x31,0x32,0x55,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 20222 0x4efe "仾" */
+0x08,0x0f,0x08,0x10,0x10,0x30,0x31,0x51,0x91,0x12,0x13,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x80,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x10,0x10,0x10,0xfe,0x00,
+/* 20223 0x4eff "仿" */
+0x08,0x08,0x08,0x17,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x12,0x12,0x14,0x18,
+0x80,0x40,0x40,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 20224 0x4f00 "伀" */
+0x08,0x09,0x09,0x11,0x11,0x32,0x32,0x54,0x98,0x10,0x11,0x11,0x12,0x17,0x12,0x10,
+0x20,0x20,0x20,0x10,0x10,0x48,0x48,0x44,0x82,0x80,0x10,0x08,0x08,0xfc,0x04,0x00,
+/* 20225 0x4f01 "企" */
+0x01,0x01,0x02,0x04,0x08,0x31,0xc1,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 20226 0x4f02 "伂" */
+0x10,0x10,0x10,0x2f,0x20,0x60,0x67,0xa4,0x24,0x24,0x24,0x24,0x24,0x20,0x20,0x20,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 20227 0x4f03 "伃" */
+0x08,0x0b,0x08,0x11,0x10,0x30,0x37,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x10,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xfe,0x42,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 20228 0x4f04 "伄" */
+0x08,0x0b,0x08,0x10,0x10,0x33,0x32,0x52,0x94,0x17,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x40,0x40,0x40,0xfe,0x42,0x42,0x4a,0x44,0x40,0x40,
+/* 20229 0x4f05 "伅" */
+0x08,0x08,0x08,0x17,0x10,0x32,0x32,0x52,0x92,0x13,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 20230 0x4f06 "伆" */
+0x09,0x09,0x09,0x11,0x12,0x34,0x30,0x51,0x91,0x12,0x14,0x10,0x11,0x12,0x14,0x10,
+0x00,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 20231 0x4f07 "伇" */
+0x08,0x09,0x09,0x11,0x11,0x32,0x34,0x53,0x91,0x11,0x10,0x10,0x10,0x10,0x13,0x1c,
+0x00,0xf0,0x10,0x10,0x10,0x0e,0x00,0xf8,0x08,0x10,0x90,0xa0,0x40,0xa0,0x18,0x06,
+/* 20232 0x4f08 "伈" */
+0x08,0x08,0x08,0x10,0x11,0x31,0x31,0x55,0x95,0x15,0x15,0x19,0x11,0x11,0x10,0x10,
+0x00,0x80,0x40,0x20,0x20,0x00,0x00,0x04,0x02,0x02,0x02,0x08,0x08,0x08,0xf8,0x00,
+/* 20233 0x4f09 "伉" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 20234 0x4f0a "伊" */
+0x08,0x0b,0x08,0x10,0x10,0x37,0x30,0x50,0x90,0x13,0x10,0x10,0x11,0x11,0x12,0x14,
+0x00,0xf8,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0xf8,0x88,0x80,0x00,0x00,0x00,0x00,
+/* 20235 0x4f0b "伋" */
+0x10,0x17,0x11,0x21,0x21,0x61,0x61,0xa1,0x21,0x22,0x22,0x22,0x24,0x24,0x28,0x23,
+0x00,0xf8,0x08,0x10,0x10,0x20,0x3c,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 20236 0x4f0c "伌" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x12,0x12,0x14,0x14,0x18,0x10,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xa8,0x90,0x82,0x82,0x82,0x7e,0x00,
+/* 20237 0x4f0d "伍" */
+0x08,0x0b,0x08,0x10,0x10,0x30,0x33,0x50,0x90,0x10,0x10,0x11,0x11,0x11,0x17,0x10,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xf8,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0xfe,0x00,
+/* 20238 0x4f0e "伎" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x30,0x57,0x92,0x12,0x11,0x10,0x10,0x10,0x11,0x16,
+0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 20239 0x4f0f "伏" */
+0x08,0x08,0x08,0x10,0x10,0x37,0x30,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 20240 0x4f10 "伐" */
+0x08,0x08,0x08,0x10,0x10,0x37,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x11,0x16,0x10,
+0x90,0x88,0x88,0x80,0xbe,0xc0,0x80,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 20241 0x4f11 "休" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x50,0x91,0x11,0x12,0x14,0x18,0x10,0x10,0x10,
+0x40,0x40,0x40,0x40,0xfe,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 20242 0x4f12 "伒" */
+0x08,0x08,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 20243 0x4f13 "伓" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x30,0x50,0x91,0x12,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 20244 0x4f14 "伔" */
+0x08,0x08,0x0b,0x12,0x14,0x30,0x31,0x51,0x91,0x11,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 20245 0x4f15 "伕" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x30,0x57,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 20246 0x4f16 "伖" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x31,0x51,0x91,0x12,0x12,0x14,0x14,0x18,0x10,0x13,
+0x80,0x80,0x80,0x80,0xfe,0x80,0x00,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 20247 0x4f17 "众" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x28,0xc8,0x08,0x08,0x08,0x14,0x12,0x22,0x41,0x82,
+0x00,0x00,0x80,0x40,0x20,0x10,0x28,0x26,0x20,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 20248 0x4f18 "优" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x50,0x90,0x10,0x11,0x11,0x11,0x12,0x12,0x14,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20249 0x4f19 "伙" */
+0x08,0x08,0x08,0x10,0x12,0x32,0x32,0x54,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 20250 0x4f1a "会" */
+0x01,0x01,0x02,0x04,0x08,0x30,0xcf,0x00,0x00,0x7f,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x00,0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xfc,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 20251 0x4f1b "伛" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x13,0x10,
+0x00,0xfc,0x00,0x08,0x88,0x50,0x50,0x20,0x20,0x50,0x50,0x88,0x08,0x00,0xfe,0x00,
+/* 20252 0x4f1c "伜" */
+0x08,0x08,0x0b,0x10,0x10,0x31,0x31,0x52,0x94,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0xf0,0x90,0x90,0x12,0x12,0x4e,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 20253 0x4f1d "伝" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x37,0x50,0x90,0x10,0x10,0x11,0x12,0x17,0x12,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 20254 0x4f1e "伞" */
+0x01,0x01,0x02,0x04,0x08,0x30,0xc1,0x11,0x09,0x09,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x10,0x10,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 20255 0x4f1f "伟" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x33,0x50,0x90,0x17,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x42,0x42,0x4a,0x44,0x40,0x40,
+/* 20256 0x4f20 "传" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x37,0x50,0x91,0x13,0x10,0x11,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0xf8,0x40,0x80,0xfe,0x80,0x00,0xf8,0x08,0x10,0xa0,0x40,0x20,0x20,
+/* 20257 0x4f21 "伡" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x31,0x53,0x90,0x10,0x10,0x17,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 20258 0x4f22 "伢" */
+0x08,0x0b,0x08,0x11,0x11,0x31,0x32,0x53,0x90,0x10,0x10,0x11,0x12,0x14,0x10,0x10,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 20259 0x4f23 "伣" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x12,0x11,0x11,0x12,0x14,0x18,
+0x00,0xf8,0x08,0x08,0x48,0x48,0x48,0x48,0x48,0xa8,0xa8,0x20,0x20,0x22,0x22,0x1e,
+/* 20260 0x4f24 "伤" */
+0x08,0x08,0x09,0x11,0x12,0x34,0x30,0x53,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0x00,0xfe,0x00,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 20261 0x4f25 "伥" */
+0x09,0x09,0x09,0x11,0x11,0x31,0x31,0x57,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0x08,0x08,0x10,0x20,0x40,0x00,0xfe,0x40,0x20,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 20262 0x4f26 "伦" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x34,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 20263 0x4f27 "伧" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x3b,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x11,0x10,
+0x40,0x40,0xa0,0x10,0x08,0x04,0xf2,0x10,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 20264 0x4f28 "伨" */
+0x09,0x09,0x09,0x12,0x12,0x35,0x38,0x50,0x90,0x10,0x10,0x13,0x11,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x84,0x84,0x14,0x24,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 20265 0x4f29 "伩" */
+0x08,0x08,0x08,0x17,0x11,0x31,0x31,0x51,0x91,0x10,0x10,0x10,0x10,0x11,0x12,0x1c,
+0x80,0x40,0x40,0xfc,0x10,0x10,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 20266 0x4f2a "伪" */
+0x08,0x0a,0x09,0x11,0x10,0x37,0x30,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x84,0xa4,0x94,0x14,0x04,0x04,0x28,0x10,
+/* 20267 0x4f2b "伫" */
+0x08,0x08,0x08,0x10,0x13,0x32,0x34,0x50,0x90,0x10,0x10,0x10,0x10,0x13,0x10,0x10,
+0x40,0x20,0x20,0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 20268 0x4f2c "伬" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 20269 0x4f2d "伭" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x31,0x52,0x97,0x10,0x10,0x11,0x12,0x17,0x12,0x10,
+0x80,0x40,0x40,0xfe,0x40,0x80,0x08,0x10,0xe0,0x40,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 20270 0x4f2e "伮" */
+0x12,0x12,0x12,0x22,0x2f,0x64,0x64,0xa4,0x24,0x29,0x25,0x22,0x25,0x29,0x30,0x21,
+0x00,0x00,0x7c,0x24,0xa4,0xa4,0xa4,0xa8,0xa8,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 20271 0x4f2f "伯" */
+0x08,0x08,0x08,0x13,0x12,0x32,0x32,0x52,0x93,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20272 0x4f30 "估" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x50,0x93,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20273 0x4f31 "伱" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x34,0x50,0x91,0x11,0x12,0x12,0x14,0x10,0x11,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x46,0x40,0x50,0x48,0x48,0x44,0x44,0x40,0x40,0x80,
+/* 20274 0x4f32 "伲" */
+0x08,0x0b,0x0a,0x12,0x12,0x33,0x32,0x52,0x92,0x12,0x12,0x12,0x14,0x14,0x18,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 20275 0x4f33 "伳" */
+0x08,0x0a,0x0a,0x12,0x12,0x37,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x10,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 20276 0x4f34 "伴" */
+0x08,0x0a,0x09,0x11,0x10,0x37,0x30,0x50,0x90,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x44,0x48,0x50,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20277 0x4f35 "伵" */
+0x10,0x10,0x17,0x24,0x24,0x64,0x64,0xa4,0x24,0x25,0x25,0x26,0x24,0x24,0x27,0x24,
+0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x1c,0x04,0x04,0x04,0xfc,0x04,
+/* 20278 0x4f36 "伶" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x34,0x50,0x93,0x10,0x10,0x11,0x10,0x10,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 20279 0x4f37 "伷" */
+0x10,0x10,0x10,0x20,0x27,0x64,0x64,0xa4,0x24,0x27,0x24,0x24,0x24,0x24,0x27,0x24,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 20280 0x4f38 "伸" */
+0x08,0x08,0x08,0x17,0x14,0x34,0x34,0x57,0x94,0x14,0x14,0x17,0x14,0x10,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,
+/* 20281 0x4f39 "伹" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 20282 0x4f3a "伺" */
+0x08,0x0b,0x08,0x10,0x17,0x30,0x30,0x53,0x92,0x12,0x12,0x13,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 20283 0x4f3b "伻" */
+0x08,0x0b,0x08,0x10,0x12,0x31,0x31,0x50,0x97,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20284 0x4f3c "似" */
+0x10,0x11,0x10,0x24,0x24,0x64,0x64,0xa4,0x24,0x24,0x24,0x25,0x26,0x24,0x20,0x21,
+0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x10,0x10,0x10,0x28,0x24,0x44,0x82,0x02,
+/* 20285 0x4f3d "伽" */
+0x14,0x14,0x14,0x24,0x2f,0x64,0x64,0xa4,0x24,0x24,0x24,0x24,0x28,0x28,0x32,0x21,
+0x00,0x00,0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,0x00,
+/* 20286 0x4f3e "伾" */
+0x08,0x0b,0x08,0x10,0x10,0x30,0x30,0x51,0x92,0x14,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 20287 0x4f3f "伿" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x32,0x52,0x93,0x12,0x10,0x10,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 20288 0x4f40 "佀" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x33,0x52,0x92,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20289 0x4f41 "佁" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x37,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x80,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20290 0x4f42 "佂" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 20291 0x4f43 "佃" */
+0x10,0x10,0x17,0x24,0x24,0x64,0x64,0xa7,0x24,0x24,0x24,0x24,0x24,0x27,0x24,0x20,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,0x00,
+/* 20292 0x4f44 "佄" */
+0x09,0x09,0x09,0x11,0x17,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20293 0x4f45 "佅" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x30,0x57,0x90,0x11,0x11,0x12,0x14,0x18,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 20294 0x4f46 "但" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x33,0x52,0x92,0x12,0x13,0x12,0x10,0x10,0x17,0x10,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 20295 0x4f47 "佇" */
+0x08,0x08,0x08,0x13,0x12,0x34,0x30,0x50,0x93,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 20296 0x4f48 "佈" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x31,0x51,0x93,0x15,0x11,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 20297 0x4f49 "佉" */
+0x08,0x08,0x08,0x10,0x13,0x30,0x30,0x50,0x97,0x10,0x10,0x10,0x11,0x12,0x17,0x12,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x80,0x80,0x10,0x08,0xfc,0x04,
+/* 20298 0x4f4a "佊" */
+0x08,0x08,0x08,0x13,0x12,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x19,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 20299 0x4f4b "佋" */
+0x08,0x0b,0x08,0x10,0x10,0x31,0x31,0x52,0x94,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20300 0x4f4c "佌" */
+0x11,0x11,0x11,0x25,0x25,0x65,0x65,0xa5,0x25,0x25,0x25,0x25,0x25,0x3e,0x28,0x20,
+0x20,0x20,0x20,0x22,0x22,0xe4,0x28,0x30,0x20,0x20,0x20,0x22,0xe2,0x22,0x1e,0x00,
+/* 20301 0x4f4d "位" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x52,0x92,0x11,0x11,0x11,0x11,0x10,0x1f,0x10,
+0x80,0x40,0x40,0x00,0xfc,0x00,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0xfe,0x00,
+/* 20302 0x4f4e "低" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 20303 0x4f4f "住" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x30,0x50,0x97,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x80,0x40,0x00,0xfc,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 20304 0x4f50 "佐" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x31,0x51,0x91,0x12,0x12,0x14,0x14,0x18,0x13,0x10,
+0x80,0x80,0x80,0x80,0xfe,0x80,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 20305 0x4f51 "佑" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x51,0x93,0x15,0x19,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0x40,0x40,0xfe,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20306 0x4f52 "佒" */
+0x08,0x08,0x08,0x13,0x12,0x32,0x32,0x52,0x92,0x17,0x10,0x10,0x10,0x11,0x12,0x14,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 20307 0x4f53 "体" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x50,0x91,0x11,0x12,0x15,0x18,0x10,0x10,0x10,
+0x40,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0xf4,0x42,0x40,0x40,0x40,
+/* 20308 0x4f54 "佔" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x50,0x93,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20309 0x4f55 "何" */
+0x08,0x08,0x17,0x10,0x20,0x33,0x52,0x92,0x12,0x12,0x13,0x12,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0x48,0xc8,0x48,0x08,0x08,0x28,0x10,
+/* 20310 0x4f56 "佖" */
+0x10,0x10,0x10,0x20,0x21,0x61,0x61,0xa5,0x25,0x25,0x25,0x29,0x21,0x23,0x24,0x28,
+0x00,0x80,0x40,0x28,0x28,0x08,0x10,0x14,0x22,0x22,0x42,0x88,0x08,0x08,0xf8,0x00,
+/* 20311 0x4f57 "佗" */
+0x08,0x08,0x08,0x13,0x12,0x34,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x08,0x10,0x20,0xc0,0x02,0x02,0x02,0xfe,0x00,
+/* 20312 0x4f58 "佘" */
+0x01,0x01,0x02,0x04,0x08,0x30,0xcf,0x00,0x00,0x7f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xfc,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 20313 0x4f59 "余" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x2f,0xc1,0x01,0x3f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0xf8,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 20314 0x4f5a "佚" */
+0x10,0x10,0x12,0x22,0x23,0x62,0x64,0xa0,0x2f,0x20,0x20,0x20,0x21,0x22,0x24,0x28,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 20315 0x4f5b "佛" */
+0x11,0x11,0x11,0x2f,0x21,0x61,0x67,0xa5,0x29,0x2f,0x21,0x21,0x22,0x22,0x24,0x28,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 20316 0x4f5c "作" */
+0x09,0x09,0x09,0x11,0x12,0x32,0x34,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 20317 0x4f5d "佝" */
+0x11,0x11,0x12,0x23,0x24,0x68,0x63,0xa2,0x22,0x22,0x22,0x23,0x22,0x20,0x20,0x20,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 20318 0x4f5e "佞" */
+0x10,0x13,0x10,0x20,0x2f,0x60,0x60,0xaf,0x21,0x22,0x26,0x21,0x20,0x20,0x23,0x2c,
+0x00,0xf8,0x00,0x00,0xfe,0x80,0x80,0xfe,0x08,0x10,0x10,0xa0,0x60,0x90,0x08,0x04,
+/* 20319 0x4f5f "佟" */
+0x08,0x08,0x08,0x11,0x13,0x34,0x30,0x50,0x93,0x1c,0x10,0x10,0x10,0x11,0x10,0x10,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xc0,0x20,0x10,0x80,0x60,0x10,
+/* 20320 0x4f60 "你" */
+0x08,0x08,0x08,0x11,0x11,0x32,0x34,0x50,0x91,0x11,0x12,0x12,0x14,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 20321 0x4f61 "佡" */
+0x10,0x10,0x10,0x20,0x21,0x62,0x64,0xa8,0x20,0x24,0x24,0x24,0x24,0x24,0x27,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x44,0x42,0x40,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 20322 0x4f62 "佢" */
+0x08,0x0b,0x0a,0x12,0x12,0x33,0x32,0x52,0x92,0x12,0x13,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 20323 0x4f63 "佣" */
+0x10,0x17,0x14,0x24,0x24,0x67,0x64,0xa4,0x24,0x27,0x24,0x24,0x24,0x28,0x28,0x30,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0x54,0x08,
+/* 20324 0x4f64 "佤" */
+0x08,0x08,0x0f,0x11,0x11,0x31,0x31,0x51,0x91,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x90,0x50,0x50,0x10,0x12,0x92,0x12,0x0e,
+/* 20325 0x4f65 "佥" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x2f,0xc0,0x02,0x11,0x09,0x09,0x08,0x00,0x7f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0xe8,0x06,0x10,0x10,0x10,0x20,0x20,0x40,0xfc,0x00,
+/* 20326 0x4f66 "佦" */
+0x08,0x08,0x0f,0x10,0x10,0x30,0x30,0x51,0x93,0x15,0x19,0x11,0x11,0x11,0x11,0x11,
+0x00,0x00,0xfe,0x40,0x40,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20327 0x4f67 "佧" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x40,0x40,0x50,0x48,0x44,0x40,0x40,0x40,
+/* 20328 0x4f68 "佨" */
+0x08,0x08,0x09,0x11,0x12,0x35,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 20329 0x4f69 "佩" */
+0x10,0x17,0x14,0x24,0x25,0x64,0x64,0xa5,0x25,0x25,0x25,0x25,0x25,0x24,0x24,0x28,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0x44,0xf4,0x54,0x54,0x54,0x54,0x74,0x46,0x46,0x42,
+/* 20330 0x4f6a "佪" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x13,0x12,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0xfc,0x04,0x00,
+/* 20331 0x4f6b "佫" */
+0x08,0x08,0x09,0x12,0x15,0x30,0x30,0x50,0x93,0x1c,0x13,0x12,0x12,0x12,0x13,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 20332 0x4f6c "佬" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x37,0x50,0x90,0x11,0x12,0x14,0x18,0x10,0x10,0x10,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 20333 0x4f6d "佭" */
+0x09,0x09,0x09,0x13,0x14,0x30,0x31,0x56,0x90,0x13,0x10,0x14,0x17,0x10,0x10,0x10,
+0x00,0x00,0xf8,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,
+/* 20334 0x4f6e "佮" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x33,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20335 0x4f6f "佯" */
+0x0a,0x09,0x09,0x10,0x17,0x30,0x30,0x53,0x90,0x10,0x17,0x10,0x10,0x10,0x10,0x10,
+0x08,0x08,0x10,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 20336 0x4f70 "佰" */
+0x08,0x0b,0x08,0x10,0x10,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20337 0x4f71 "佱" */
+0x01,0x01,0x02,0x04,0x08,0x10,0xef,0x00,0x00,0x7f,0x01,0x01,0x11,0x11,0x11,0xff,
+0x00,0x00,0x80,0x40,0x20,0x10,0xee,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 20338 0x4f72 "佲" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x30,0x50,0x91,0x13,0x1d,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xfc,0x04,0x88,0x50,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20339 0x4f73 "佳" */
+0x08,0x08,0x0b,0x10,0x10,0x30,0x3f,0x50,0x90,0x10,0x13,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 20340 0x4f74 "佴" */
+0x08,0x0b,0x09,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x17,0x10,0x10,0x10,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 20341 0x4f75 "併" */
+0x09,0x08,0x08,0x10,0x13,0x30,0x30,0x50,0x90,0x17,0x10,0x10,0x11,0x11,0x12,0x14,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 20342 0x4f76 "佶" */
+0x08,0x08,0x08,0x1f,0x10,0x30,0x37,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20343 0x4f77 "佷" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 20344 0x4f78 "佸" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20345 0x4f79 "佹" */
+0x11,0x11,0x13,0x22,0x24,0x6b,0x62,0xa2,0x22,0x22,0x22,0x22,0x22,0x24,0x24,0x28,
+0x00,0x00,0xf8,0x08,0x10,0xfe,0x00,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 20346 0x4f7a "佺" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x33,0x50,0x90,0x10,0x13,0x10,0x10,0x10,0x17,0x10,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 20347 0x4f7b "佻" */
+0x08,0x08,0x08,0x14,0x12,0x30,0x30,0x51,0x92,0x14,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 20348 0x4f7c "佼" */
+0x10,0x10,0x10,0x27,0x20,0x61,0x62,0xa4,0x21,0x21,0x20,0x20,0x20,0x21,0x22,0x2c,
+0x80,0x40,0x40,0xfc,0x00,0x10,0x08,0x04,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 20349 0x4f7d "佽" */
+0x10,0x10,0x14,0x22,0x22,0x60,0x60,0xa1,0x21,0x2e,0x22,0x22,0x22,0x22,0x20,0x21,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 20350 0x4f7e "佾" */
+0x08,0x09,0x09,0x12,0x14,0x3b,0x32,0x52,0x93,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x10,0x10,0x08,0x08,0x04,0xfa,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 20351 0x4f7f "使" */
+0x10,0x10,0x1f,0x20,0x20,0x67,0x64,0xa4,0x27,0x20,0x22,0x21,0x20,0x21,0x22,0x2c,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x40,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 20352 0x4f80 "侀" */
+0x10,0x1f,0x14,0x24,0x24,0x64,0x64,0xaf,0x24,0x24,0x24,0x24,0x24,0x28,0x28,0x30,
+0x04,0xc4,0x84,0x94,0x94,0x94,0x94,0xd4,0x94,0x94,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 20353 0x4f81 "侁" */
+0x10,0x12,0x12,0x23,0x24,0x68,0x60,0xa7,0x21,0x21,0x21,0x21,0x22,0x22,0x24,0x28,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 20354 0x4f82 "侂" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x32,0x52,0x92,0x12,0x13,0x12,0x14,0x14,0x18,0x10,
+0x40,0x20,0xfe,0x00,0x00,0x0c,0xf0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x1e,0x00,
+/* 20355 0x4f83 "侃" */
+0x10,0x17,0x14,0x24,0x24,0x67,0x60,0xa2,0x22,0x22,0x22,0x22,0x22,0x24,0x24,0x28,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x48,0x48,0x48,0x48,0x48,0x4a,0x4a,0x4a,0x06,
+/* 20356 0x4f84 "侄" */
+0x10,0x17,0x10,0x20,0x21,0x62,0x67,0xa0,0x20,0x20,0x27,0x20,0x20,0x20,0x2f,0x20,
+0x00,0xfe,0x40,0x80,0x10,0x08,0xfc,0x44,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 20357 0x4f85 "侅" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x31,0x53,0x90,0x10,0x11,0x16,0x10,0x10,0x11,0x16,
+0x40,0x20,0x20,0xfe,0x40,0x84,0x08,0xf0,0x22,0x44,0x88,0x10,0x20,0x50,0x88,0x04,
+/* 20358 0x4f86 "來" */
+0x01,0x01,0x01,0x7f,0x01,0x11,0x11,0x29,0x45,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x28,0x44,0x80,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 20359 0x4f87 "侇" */
+0x10,0x10,0x17,0x20,0x27,0x60,0x63,0xa2,0x24,0x27,0x20,0x20,0x20,0x21,0x22,0x2c,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x40,0x40,0xfe,0x42,0xaa,0xa4,0x10,0x08,0x06,
+/* 20360 0x4f88 "侈" */
+0x10,0x10,0x11,0x22,0x25,0x60,0x60,0xa3,0x2c,0x20,0x21,0x26,0x20,0x20,0x21,0x2e,
+0x80,0x80,0xf8,0x10,0x20,0xc0,0x90,0x20,0x7c,0x84,0x08,0x90,0x60,0x40,0x80,0x00,
+/* 20361 0x4f89 "侉" */
+0x10,0x10,0x17,0x20,0x21,0x62,0x6d,0xa0,0x27,0x20,0x21,0x23,0x20,0x20,0x20,0x20,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 20362 0x4f8a "侊" */
+0x08,0x08,0x0a,0x11,0x11,0x30,0x37,0x50,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 20363 0x4f8b "例" */
+0x10,0x10,0x17,0x22,0x22,0x63,0x62,0xa4,0x26,0x25,0x28,0x20,0x21,0x22,0x24,0x28,
+0x04,0x04,0xc4,0x14,0x14,0xd4,0x54,0x54,0x54,0x54,0x94,0x94,0x04,0x04,0x14,0x08,
+/* 20364 0x4f8c "侌" */
+0x01,0x02,0x04,0x09,0x30,0xcf,0x00,0x00,0x3f,0x00,0x00,0xff,0x08,0x10,0x3f,0x00,
+0x00,0x80,0x40,0x20,0x98,0xe6,0x40,0x80,0xf8,0x00,0x00,0xfe,0x20,0x10,0xf8,0x08,
+/* 20365 0x4f8d "侍" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x37,0x50,0x90,0x17,0x10,0x12,0x11,0x11,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 20366 0x4f8e "侎" */
+0x08,0x08,0x0a,0x11,0x11,0x30,0x37,0x50,0x90,0x11,0x11,0x12,0x14,0x18,0x10,0x10,
+0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 20367 0x4f8f "侏" */
+0x08,0x0a,0x0a,0x13,0x14,0x30,0x30,0x57,0x90,0x11,0x11,0x12,0x14,0x18,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 20368 0x4f90 "侐" */
+0x08,0x08,0x08,0x11,0x13,0x32,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x1f,0x10,
+0x40,0x40,0x80,0x00,0xfc,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 20369 0x4f91 "侑" */
+0x08,0x08,0x0f,0x10,0x11,0x31,0x33,0x55,0x99,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 20370 0x4f92 "侒" */
+0x08,0x08,0x08,0x13,0x12,0x34,0x30,0x53,0x90,0x10,0x11,0x10,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 20371 0x4f93 "侓" */
+0x08,0x08,0x0b,0x10,0x17,0x30,0x33,0x50,0x90,0x17,0x10,0x10,0x1f,0x10,0x10,0x10,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,
+/* 20372 0x4f94 "侔" */
+0x08,0x08,0x08,0x11,0x13,0x30,0x31,0x51,0x91,0x12,0x10,0x17,0x10,0x10,0x10,0x10,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 20373 0x4f95 "侕" */
+0x10,0x17,0x10,0x20,0x20,0x67,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x40,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x14,0x08,
+/* 20374 0x4f96 "侖" */
+0x01,0x02,0x04,0x08,0x37,0xc0,0x00,0x3f,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x20,
+0x00,0x80,0x40,0x20,0xd8,0x06,0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0xa8,0x10,
+/* 20375 0x4f97 "侗" */
+0x10,0x17,0x14,0x24,0x25,0x64,0x64,0xa5,0x25,0x25,0x25,0x25,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x04,0x14,0x08,
+/* 20376 0x4f98 "侘" */
+0x08,0x08,0x08,0x13,0x12,0x34,0x30,0x53,0x90,0x10,0x10,0x17,0x10,0x10,0x10,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x38,0xc0,0x40,0x40,0x7e,0xc0,0x40,0x42,0x42,0x3e,
+/* 20377 0x4f99 "侙" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x30,0x57,0x91,0x11,0x11,0x11,0x11,0x17,0x12,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xe0,0x20,0x10,0x10,0x10,0xca,0x0a,0x06,0x02,
+/* 20378 0x4f9a "侚" */
+0x08,0x08,0x09,0x11,0x12,0x34,0x33,0x52,0x92,0x13,0x12,0x12,0x13,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 20379 0x4f9b "供" */
+0x09,0x09,0x09,0x11,0x13,0x31,0x31,0x51,0x91,0x17,0x10,0x11,0x11,0x12,0x14,0x18,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 20380 0x4f9c "侜" */
+0x08,0x09,0x0b,0x12,0x12,0x32,0x32,0x5f,0x92,0x12,0x12,0x12,0x12,0x12,0x14,0x18,
+0x80,0x00,0xf8,0x08,0x88,0x48,0x48,0xfe,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 20381 0x4f9d "依" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x31,0x51,0x93,0x15,0x19,0x11,0x11,0x11,0x11,0x11,
+0x80,0x40,0x40,0xfe,0x80,0x80,0x40,0x44,0x48,0x30,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 20382 0x4f9e "侞" */
+0x09,0x09,0x09,0x11,0x17,0x32,0x32,0x52,0x92,0x14,0x12,0x11,0x12,0x12,0x14,0x18,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x12,0x92,0x5e,0x52,0x00,
+/* 20383 0x4f9f "侟" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x31,0x51,0x93,0x15,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 20384 0x4fa0 "侠" */
+0x08,0x08,0x08,0x17,0x10,0x32,0x31,0x50,0x9f,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x50,0x40,0xfe,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 20385 0x4fa1 "価" */
+0x10,0x17,0x10,0x20,0x20,0x67,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x27,0x24,0x20,
+0x00,0xfe,0xa0,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xfc,0x04,0x00,
+/* 20386 0x4fa2 "侢" */
+0x08,0x0f,0x08,0x10,0x13,0x32,0x32,0x53,0x92,0x12,0x1f,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfe,0x08,0x08,0x08,0x28,0x10,
+/* 20387 0x4fa3 "侣" */
+0x10,0x13,0x12,0x22,0x22,0x62,0x63,0xa0,0x20,0x27,0x24,0x24,0x24,0x24,0x27,0x24,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20388 0x4fa4 "侤" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x51,0x93,0x14,0x19,0x11,0x10,0x10,0x10,0x10,
+0x80,0x88,0xe8,0x90,0xa0,0xfe,0x80,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 20389 0x4fa5 "侥" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x30,0x53,0x90,0x17,0x10,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 20390 0x4fa6 "侦" */
+0x08,0x08,0x08,0x10,0x10,0x33,0x32,0x52,0x92,0x12,0x12,0x12,0x10,0x11,0x12,0x14,
+0x40,0x40,0x7e,0x40,0x40,0xf8,0x08,0x48,0x48,0x48,0x48,0x48,0xa0,0x10,0x08,0x04,
+/* 20391 0x4fa7 "侧" */
+0x10,0x17,0x14,0x24,0x25,0x65,0x65,0xa5,0x25,0x25,0x25,0x21,0x22,0x22,0x24,0x28,
+0x04,0xc4,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x04,0x84,0x44,0x14,0x08,
+/* 20392 0x4fa8 "侨" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x51,0x92,0x15,0x11,0x11,0x11,0x12,0x12,0x14,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 20393 0x4fa9 "侩" */
+0x08,0x08,0x08,0x11,0x12,0x34,0x31,0x50,0x90,0x17,0x10,0x10,0x11,0x12,0x17,0x12,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x00,0x00,0xfc,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 20394 0x4faa "侪" */
+0x08,0x08,0x0f,0x12,0x11,0x30,0x30,0x51,0x96,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x80,0x40,0xfe,0x08,0x10,0xa0,0x40,0xb0,0x0e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 20395 0x4fab "侫" */
+0x08,0x08,0x1f,0x12,0x12,0x32,0x33,0x50,0x90,0x1f,0x11,0x12,0x13,0x10,0x11,0x16,
+0x80,0x40,0xfe,0x00,0x00,0x00,0xfc,0x80,0x80,0xfe,0x08,0x08,0x90,0x60,0x98,0x04,
+/* 20396 0x4fac "侬" */
+0x10,0x10,0x10,0x27,0x24,0x68,0x61,0xa1,0x23,0x25,0x29,0x21,0x21,0x21,0x21,0x21,
+0x40,0x40,0x40,0xfc,0x84,0x88,0x40,0x44,0x48,0x30,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 20397 0x4fad "侭" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x52,0x92,0x14,0x14,0x18,0x11,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x20,0x20,0x10,0x08,0xc6,0x20,0x00,0xc0,0x30,0x08,0x00,
+/* 20398 0x4fae "侮" */
+0x09,0x09,0x09,0x12,0x15,0x31,0x31,0x51,0x97,0x11,0x12,0x12,0x13,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 20399 0x4faf "侯" */
+0x08,0x0b,0x08,0x10,0x17,0x31,0x31,0x53,0x94,0x10,0x1f,0x10,0x10,0x11,0x12,0x1c,
+0x00,0xf8,0x08,0x08,0xfe,0x00,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20400 0x4fb0 "侰" */
+0x08,0x0b,0x08,0x10,0x17,0x30,0x30,0x53,0x91,0x11,0x13,0x15,0x19,0x11,0x11,0x11,
+0x00,0xf8,0x88,0x88,0xfe,0x88,0x88,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 20401 0x4fb1 "侱" */
+0x08,0x0b,0x0a,0x12,0x12,0x33,0x30,0x50,0x97,0x10,0x10,0x13,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 20402 0x4fb2 "侲" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 20403 0x4fb3 "侳" */
+0x08,0x08,0x0a,0x12,0x12,0x35,0x38,0x50,0x90,0x17,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x48,0x48,0x48,0x54,0xe2,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 20404 0x4fb4 "侴" */
+0x01,0x02,0x04,0x08,0x30,0xcf,0x00,0x3f,0x09,0x09,0x3f,0x11,0x11,0x17,0x78,0x20,
+0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0x04,0x0c,
+/* 20405 0x4fb5 "侵" */
+0x08,0x0b,0x08,0x11,0x10,0x33,0x30,0x57,0x94,0x13,0x11,0x11,0x10,0x10,0x11,0x16,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf0,0x10,0x10,0xa0,0x40,0xb0,0x0e,
+/* 20406 0x4fb6 "侶" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20407 0x4fb7 "侷" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x14,0x14,0x18,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x04,0x28,0x10,
+/* 20408 0x4fb8 "侸" */
+0x08,0x0f,0x08,0x10,0x13,0x32,0x32,0x52,0x92,0x13,0x10,0x12,0x11,0x11,0x1f,0x10,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x08,0x08,0x10,0xfe,0x00,
+/* 20409 0x4fb9 "侹" */
+0x10,0x10,0x17,0x21,0x21,0x62,0x62,0xa7,0x21,0x25,0x25,0x22,0x22,0x25,0x28,0x30,
+0x00,0x0c,0x70,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0xfe,0x00,
+/* 20410 0x4fba "侺" */
+0x08,0x0a,0x0a,0x12,0x13,0x30,0x30,0x51,0x92,0x14,0x10,0x13,0x10,0x10,0x10,0x10,
+0x40,0x48,0x48,0x48,0xf8,0x40,0xa0,0x10,0x88,0x46,0x40,0xf0,0x10,0x20,0x20,0x40,
+/* 20411 0x4fbb "侻" */
+0x0a,0x09,0x09,0x10,0x13,0x32,0x32,0x52,0x93,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x08,0x08,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 20412 0x4fbc "侼" */
+0x08,0x08,0x0b,0x10,0x10,0x33,0x32,0x54,0x91,0x10,0x10,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 20413 0x4fbd "侽" */
+0x0b,0x0a,0x0a,0x13,0x12,0x32,0x33,0x50,0x90,0x17,0x10,0x11,0x11,0x12,0x14,0x18,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x80,0x80,0xfc,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 20414 0x4fbe "侾" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x50,0x93,0x11,0x12,0x15,0x18,0x10,0x10,0x10,
+0x40,0x44,0xf4,0x48,0x48,0xfe,0x20,0x40,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 20415 0x4fbf "便" */
+0x10,0x17,0x10,0x27,0x24,0x64,0x67,0xa4,0x24,0x27,0x22,0x21,0x20,0x21,0x22,0x2c,
+0x00,0xfe,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 20416 0x4fc0 "俀" */
+0x08,0x08,0x0b,0x10,0x12,0x31,0x31,0x50,0x93,0x10,0x11,0x13,0x10,0x10,0x11,0x16,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 20417 0x4fc1 "俁" */
+0x08,0x08,0x08,0x10,0x12,0x32,0x32,0x53,0x90,0x10,0x17,0x10,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0x00,0xfc,0x44,0x44,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20418 0x4fc2 "係" */
+0x08,0x08,0x0b,0x10,0x11,0x33,0x30,0x50,0x91,0x17,0x10,0x11,0x11,0x12,0x14,0x10,
+0x04,0x1e,0xe0,0x80,0x08,0xf0,0x20,0x48,0x84,0xfe,0x22,0x28,0x24,0x22,0xa2,0x40,
+/* 20419 0x4fc3 "促" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x33,0x50,0x90,0x12,0x12,0x12,0x12,0x15,0x18,0x10,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x00,
+/* 20420 0x4fc4 "俄" */
+0x10,0x11,0x17,0x21,0x21,0x6f,0x61,0xa1,0x21,0x23,0x2d,0x21,0x21,0x21,0x25,0x22,
+0x28,0xa4,0x24,0x20,0x20,0xfe,0x20,0x24,0xa4,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 20421 0x4fc5 "俅" */
+0x08,0x08,0x08,0x10,0x17,0x30,0x32,0x51,0x91,0x10,0x11,0x12,0x14,0x10,0x11,0x10,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x44,0x64,0x68,0xd0,0x50,0x48,0x44,0x42,0x40,0x80,
+/* 20422 0x4fc6 "俆" */
+0x08,0x08,0x08,0x11,0x12,0x35,0x30,0x50,0x97,0x10,0x12,0x12,0x14,0x18,0x11,0x10,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 20423 0x4fc7 "俇" */
+0x08,0x0c,0x0a,0x11,0x12,0x34,0x30,0x50,0x91,0x12,0x14,0x10,0x10,0x10,0x15,0x12,
+0x00,0x40,0xbe,0x08,0x88,0x88,0x88,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x3e,0x00,
+/* 20424 0x4fc8 "俈" */
+0x08,0x0a,0x0a,0x13,0x14,0x38,0x30,0x57,0x90,0x10,0x13,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 20425 0x4fc9 "俉" */
+0x08,0x0f,0x08,0x10,0x13,0x31,0x31,0x57,0x90,0x10,0x13,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfc,0x80,0x80,0xf8,0x08,0x08,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 20426 0x4fca "俊" */
+0x08,0x08,0x08,0x11,0x13,0x30,0x30,0x51,0x92,0x10,0x11,0x12,0x10,0x10,0x11,0x16,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 20427 0x4fcb "俋" */
+0x08,0x0b,0x0a,0x12,0x13,0x30,0x37,0x54,0x94,0x14,0x17,0x14,0x14,0x14,0x13,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0x44,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 20428 0x4fcc "俌" */
+0x10,0x10,0x17,0x20,0x20,0x67,0x64,0xa4,0x27,0x24,0x24,0x27,0x24,0x24,0x24,0x24,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 20429 0x4fcd "俍" */
+0x08,0x08,0x0b,0x12,0x12,0x33,0x32,0x52,0x93,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x80,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 20430 0x4fce "俎" */
+0x10,0x11,0x11,0x29,0x25,0x45,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x81,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 20431 0x4fcf "俏" */
+0x08,0x0a,0x09,0x11,0x10,0x33,0x32,0x52,0x93,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x40,0x48,0x48,0x50,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 20432 0x4fd0 "俐" */
+0x10,0x11,0x17,0x21,0x21,0x61,0x6f,0xa1,0x23,0x23,0x25,0x25,0x29,0x21,0x21,0x21,
+0x84,0xc4,0x04,0x14,0x14,0x14,0xd4,0x14,0x14,0x94,0x54,0x04,0x04,0x04,0x14,0x08,
+/* 20433 0x4fd1 "俑" */
+0x10,0x17,0x10,0x21,0x20,0x67,0x64,0xa4,0x27,0x24,0x24,0x27,0x24,0x24,0x24,0x24,
+0x00,0xf8,0x10,0xa0,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 20434 0x4fd2 "俒" */
+0x08,0x08,0x0b,0x12,0x14,0x31,0x30,0x50,0x93,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 20435 0x4fd3 "俓" */
+0x08,0x0b,0x08,0x11,0x12,0x34,0x32,0x51,0x90,0x13,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 20436 0x4fd4 "俔" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x92,0x12,0x13,0x11,0x11,0x12,0x14,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 20437 0x4fd5 "俕" */
+0x10,0x10,0x17,0x24,0x28,0x60,0x60,0xa7,0x20,0x21,0x21,0x22,0x24,0x28,0x20,0x20,
+0x80,0x40,0xfe,0x02,0x44,0x40,0x40,0xfc,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 20438 0x4fd6 "俖" */
+0x10,0x17,0x10,0x20,0x20,0x61,0x66,0xa0,0x20,0x23,0x22,0x22,0x22,0x22,0x23,0x22,
+0x00,0xfc,0x20,0x40,0xd0,0x48,0x44,0x40,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20439 0x4fd7 "俗" */
+0x09,0x09,0x0a,0x14,0x10,0x30,0x31,0x52,0x9c,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x10,0x08,0x04,0x44,0x40,0xa0,0x10,0x08,0x06,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20440 0x4fd8 "俘" */
+0x08,0x08,0x0b,0x10,0x12,0x31,0x30,0x53,0x90,0x10,0x17,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 20441 0x4fd9 "俙" */
+0x12,0x11,0x10,0x21,0x22,0x60,0x6f,0xa1,0x22,0x27,0x2a,0x22,0x22,0x22,0x20,0x20,
+0x08,0x10,0xe0,0x10,0x08,0x80,0xfe,0x40,0x40,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 20442 0x4fda "俚" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa7,0x20,0x20,0x27,0x20,0x20,0x20,0x2f,0x20,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 20443 0x4fdb "俛" */
+0x09,0x09,0x09,0x12,0x12,0x37,0x3a,0x52,0x92,0x13,0x12,0x10,0x11,0x12,0x14,0x18,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0x44,0xfc,0xa4,0xa0,0x20,0x22,0x22,0x1e,
+/* 20444 0x4fdc "俜" */
+0x10,0x10,0x17,0x24,0x27,0x64,0x67,0xa0,0x3f,0x21,0x22,0x23,0x20,0x20,0x20,0x20,
+0x40,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 20445 0x4fdd "保" */
+0x08,0x0b,0x0a,0x12,0x12,0x33,0x30,0x50,0x97,0x10,0x11,0x12,0x14,0x18,0x10,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x40,0x40,0xfc,0xe0,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 20446 0x4fde "俞" */
+0x01,0x02,0x04,0x08,0x30,0xcf,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2a,0x24,
+0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x08,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 20447 0x4fdf "俟" */
+0x10,0x10,0x11,0x22,0x27,0x61,0x61,0xa3,0x24,0x20,0x2f,0x20,0x20,0x21,0x22,0x2c,
+0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20448 0x4fe0 "俠" */
+0x08,0x08,0x08,0x17,0x10,0x32,0x32,0x52,0x95,0x18,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0xfe,0x40,0x48,0x48,0x48,0x54,0xa2,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 20449 0x4fe1 "信" */
+0x08,0x08,0x0b,0x10,0x10,0x31,0x30,0x50,0x91,0x10,0x10,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 20450 0x4fe2 "俢" */
+0x08,0x08,0x09,0x13,0x14,0x30,0x31,0x5e,0x90,0x13,0x10,0x11,0x16,0x10,0x10,0x17,
+0x80,0x80,0xf8,0x10,0xa0,0x40,0xb0,0x4e,0x80,0x20,0x44,0x88,0x10,0x20,0xc0,0x00,
+/* 20451 0x4fe3 "俣" */
+0x08,0x0b,0x0a,0x12,0x13,0x30,0x30,0x57,0x90,0x10,0x1f,0x10,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20452 0x4fe4 "俤" */
+0x09,0x08,0x08,0x13,0x10,0x30,0x33,0x52,0x92,0x13,0x10,0x10,0x11,0x12,0x14,0x10,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 20453 0x4fe5 "俥" */
+0x10,0x10,0x1f,0x20,0x27,0x64,0x64,0xa7,0x24,0x24,0x27,0x20,0x3f,0x20,0x20,0x20,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0xfe,0x40,0x40,0x40,
+/* 20454 0x4fe6 "俦" */
+0x10,0x10,0x17,0x20,0x23,0x60,0x67,0xa0,0x21,0x21,0x22,0x22,0x24,0x28,0x20,0x20,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x90,0x10,0xfe,0x10,0x90,0x50,0x10,0x50,0x20,
+/* 20455 0x4fe7 "俧" */
+0x08,0x08,0x08,0x13,0x10,0x30,0x30,0x51,0x90,0x10,0x10,0x12,0x12,0x12,0x14,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 20456 0x4fe8 "俨" */
+0x08,0x0b,0x08,0x12,0x11,0x30,0x33,0x52,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20457 0x4fe9 "俩" */
+0x10,0x1f,0x11,0x21,0x21,0x6f,0x69,0xa9,0x29,0x2a,0x2a,0x2c,0x28,0x28,0x28,0x28,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xa4,0x54,0x4c,0x84,0x04,0x14,0x08,
+/* 20458 0x4fea "俪" */
+0x10,0x1f,0x10,0x20,0x27,0x64,0x64,0xa4,0x26,0x25,0x24,0x24,0x24,0x24,0x24,0x25,
+0x00,0xfe,0x00,0x00,0xbc,0xa4,0xa4,0xa4,0xb4,0xac,0xa4,0xa4,0xa4,0xa4,0xa4,0xac,
+/* 20459 0x4feb "俫" */
+0x08,0x08,0x08,0x17,0x10,0x32,0x31,0x51,0x9f,0x10,0x11,0x11,0x12,0x14,0x18,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x50,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 20460 0x4fec "俬" */
+0x10,0x11,0x1f,0x21,0x21,0x6f,0x61,0xa3,0x23,0x25,0x25,0x29,0x21,0x21,0x21,0x21,
+0x88,0xc8,0x08,0x08,0x08,0xd0,0x10,0x10,0x90,0x54,0x64,0x22,0x7e,0x22,0x02,0x00,
+/* 20461 0x4fed "俭" */
+0x08,0x08,0x08,0x10,0x11,0x32,0x35,0x50,0x90,0x10,0x12,0x11,0x11,0x10,0x17,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 20462 0x4fee "修" */
+0x10,0x10,0x11,0x21,0x2a,0x6c,0xa9,0x2e,0x28,0x2b,0x28,0x28,0x2b,0x20,0x21,0x26,
+0x80,0x80,0xf8,0x08,0x90,0x60,0x98,0x26,0xc0,0x10,0x20,0xc8,0x10,0x60,0x80,0x00,
+/* 20463 0x4fef "俯" */
+0x10,0x10,0x17,0x24,0x24,0x64,0x65,0xa5,0x27,0x25,0x25,0x25,0x29,0x29,0x31,0x21,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x08,0x7e,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 20464 0x4ff0 "俰" */
+0x10,0x11,0x17,0x21,0x21,0x6f,0x61,0xa3,0x23,0x23,0x25,0x25,0x29,0x21,0x21,0x21,
+0x00,0x80,0x00,0x1e,0x12,0xd2,0x12,0x12,0x92,0x52,0x52,0x12,0x1e,0x12,0x00,0x00,
+/* 20465 0x4ff1 "俱" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x33,0x52,0x93,0x12,0x12,0x1f,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,0x10,0x08,0x04,
+/* 20466 0x4ff2 "俲" */
+0x12,0x11,0x11,0x27,0x20,0x62,0x62,0xa4,0x28,0x22,0x21,0x21,0x22,0x24,0x28,0x20,
+0x10,0x10,0x10,0xd0,0x3e,0x92,0x52,0x52,0x92,0x92,0x12,0x12,0xa2,0xa2,0x4a,0x84,
+/* 20467 0x4ff3 "俳" */
+0x08,0x08,0x08,0x17,0x10,0x30,0x30,0x53,0x90,0x10,0x10,0x17,0x10,0x10,0x10,0x10,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 20468 0x4ff4 "俴" */
+0x10,0x10,0x10,0x27,0x20,0x60,0x61,0xae,0x20,0x20,0x20,0x27,0x20,0x20,0x21,0x2e,
+0xa0,0x90,0xbc,0xc8,0x50,0x64,0x94,0x0c,0xa0,0x90,0xbc,0xc8,0x50,0x64,0x94,0x0c,
+/* 20469 0x4ff5 "俵" */
+0x10,0x10,0x17,0x20,0x20,0x63,0x60,0xa0,0x2f,0x20,0x21,0x23,0x25,0x29,0x21,0x21,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x88,0x50,0x20,0x10,0x48,0x86,0x00,
+/* 20470 0x4ff6 "俶" */
+0x09,0x09,0x09,0x11,0x11,0x31,0x37,0x50,0x91,0x11,0x15,0x15,0x19,0x11,0x15,0x12,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 20471 0x4ff7 "俷" */
+0x10,0x17,0x14,0x24,0x24,0x67,0x64,0xa4,0x24,0x27,0x24,0x24,0x24,0x28,0x2a,0x31,
+0x00,0xbe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xbe,0xa0,0xa0,0xa0,0xa2,0xa2,0xa2,0x1e,
+/* 20472 0x4ff8 "俸" */
+0x08,0x08,0x0f,0x10,0x13,0x30,0x37,0x51,0x92,0x14,0x11,0x10,0x17,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x48,0x46,0xf0,0x40,0xfc,0x40,0x40,0x40,
+/* 20473 0x4ff9 "俹" */
+0x08,0x0f,0x08,0x10,0x10,0x33,0x32,0x52,0x92,0x13,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x90,0x90,0x90,0x9c,0x04,0x04,0x04,0x9c,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 20474 0x4ffa "俺" */
+0x08,0x08,0x0b,0x11,0x12,0x34,0x33,0x52,0x92,0x13,0x12,0x12,0x13,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 20475 0x4ffb "俻" */
+0x08,0x08,0x09,0x12,0x15,0x30,0x33,0x5c,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xe0,0x18,0x06,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x08,
+/* 20476 0x4ffc "俼" */
+0x08,0x08,0x0f,0x11,0x12,0x37,0x30,0x53,0x92,0x13,0x12,0x13,0x12,0x12,0x12,0x12,
+0x80,0x40,0xfe,0x00,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 20477 0x4ffd "俽" */
+0x10,0x10,0x17,0x24,0x24,0x64,0x67,0xa5,0x25,0x25,0x25,0x25,0x25,0x29,0x29,0x30,
+0x10,0x90,0x10,0x3e,0x22,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 20478 0x4ffe "俾" */
+0x08,0x08,0x0b,0x12,0x12,0x33,0x32,0x52,0x93,0x10,0x11,0x17,0x10,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 20479 0x4fff "俿" */
+0x08,0x08,0x08,0x10,0x13,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x14,0x14,0x19,0x12,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 20480 0x5000 "倀" */
+0x08,0x09,0x09,0x11,0x11,0x31,0x31,0x5f,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x80,0x48,0x50,0x20,0x10,0x88,0x06,0x00,
+/* 20481 0x5001 "倁" */
+0x09,0x09,0x09,0x13,0x12,0x34,0x30,0x50,0x93,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0x00,0x00,0xde,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x52,0x5e,0x20,0x20,0x00,
+/* 20482 0x5002 "倂" */
+0x08,0x08,0x09,0x13,0x11,0x31,0x31,0x51,0x97,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x84,0x84,0x08,0xde,0x08,0x08,0x08,0x08,0xbe,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 20483 0x5003 "倃" */
+0x11,0x11,0x13,0x22,0x24,0x6a,0x61,0xa2,0x2c,0x20,0x23,0x22,0x22,0x22,0x23,0x22,
+0x10,0x10,0xd8,0x54,0x52,0x90,0x10,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 20484 0x5004 "倄" */
+0x09,0x08,0x08,0x11,0x16,0x30,0x37,0x50,0x91,0x13,0x15,0x11,0x11,0x11,0x11,0x11,
+0x08,0x90,0x60,0x98,0x44,0x40,0xfe,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 20485 0x5005 "倅" */
+0x08,0x08,0x0b,0x10,0x11,0x31,0x32,0x54,0x90,0x10,0x17,0x10,0x10,0x10,0x10,0x10,
+0x80,0x40,0xfc,0x00,0x10,0x10,0xa8,0x44,0x00,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 20486 0x5006 "倆" */
+0x10,0x17,0x10,0x20,0x27,0x64,0x64,0xa6,0x25,0x25,0x26,0x24,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x40,0x40,0xfc,0x44,0x44,0x64,0x54,0x54,0xec,0xcc,0x44,0x44,0x54,0x08,
+/* 20487 0x5007 "倇" */
+0x10,0x10,0x17,0x24,0x2a,0x62,0x63,0xa4,0x24,0x26,0x29,0x21,0x22,0x22,0x24,0x28,
+0x80,0x40,0xfe,0x02,0x04,0x00,0xbc,0xa4,0xa4,0xa4,0x34,0x28,0x22,0x22,0x22,0x1e,
+/* 20488 0x5008 "倈" */
+0x08,0x08,0x08,0x17,0x10,0x32,0x32,0x52,0x95,0x10,0x11,0x11,0x12,0x14,0x18,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 20489 0x5009 "倉" */
+0x01,0x02,0x04,0x0a,0x31,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x2f,0x28,0x48,0x8f,0x08,
+0x00,0x80,0x40,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 20490 0x500a "倊" */
+0x08,0x08,0x09,0x11,0x12,0x34,0x31,0x53,0x90,0x10,0x10,0x12,0x12,0x12,0x14,0x10,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 20491 0x500b "個" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa5,0x25,0x25,0x25,0x25,0x25,0x24,0x27,0x24,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0xfc,0x04,
+/* 20492 0x500c "倌" */
+0x08,0x08,0x0b,0x12,0x14,0x31,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 20493 0x500d "倍" */
+0x08,0x08,0x0b,0x10,0x12,0x31,0x31,0x57,0x90,0x10,0x13,0x12,0x12,0x12,0x13,0x12,
+0x80,0x40,0xfc,0x00,0x08,0x08,0x10,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 20494 0x500e "倎" */
+0x08,0x08,0x08,0x13,0x12,0x32,0x32,0x53,0x92,0x12,0x12,0x17,0x10,0x10,0x11,0x12,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 20495 0x500f "倏" */
+0x10,0x10,0x11,0x21,0x2a,0x6c,0xa9,0x2e,0x28,0x28,0x2b,0x28,0x28,0x21,0x22,0x24,
+0x80,0x80,0xf8,0x08,0x90,0x60,0x98,0x46,0x50,0x48,0xfc,0x40,0xa0,0x10,0x08,0x04,
+/* 20496 0x5010 "倐" */
+0x08,0x08,0x10,0x10,0x35,0x54,0x94,0x17,0x14,0x14,0x14,0x15,0x14,0x10,0x10,0x13,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0x20,0xa4,0xa4,0x28,0x50,0x48,0x84,0x02,
+/* 20497 0x5011 "們" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa7,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,
+0x00,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20498 0x5012 "倒" */
+0x10,0x10,0x1f,0x22,0x22,0x64,0x67,0xa1,0x21,0x27,0x21,0x21,0x21,0x2e,0x24,0x20,
+0x04,0x04,0xc4,0x14,0x14,0x94,0xd4,0x14,0x14,0xd4,0x14,0x14,0xc4,0x04,0x14,0x08,
+/* 20499 0x5013 "倓" */
+0x08,0x0a,0x0a,0x14,0x10,0x31,0x36,0x50,0x90,0x12,0x12,0x14,0x10,0x11,0x12,0x1c,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 20500 0x5014 "倔" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x65,0xa5,0x25,0x25,0x24,0x25,0x25,0x29,0x29,0x30,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x24,0x24,0x24,0xfc,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 20501 0x5015 "倕" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x32,0x52,0x9f,0x12,0x12,0x17,0x10,0x10,0x17,0x10,
+0x10,0x78,0xc0,0x40,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0x40,0xfc,0x00,
+/* 20502 0x5016 "倖" */
+0x08,0x08,0x0f,0x10,0x10,0x37,0x31,0x50,0x97,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0xa0,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 20503 0x5017 "倗" */
+0x10,0x17,0x14,0x24,0x24,0x67,0x64,0xa4,0x24,0x27,0x24,0x24,0x24,0x24,0x2a,0x31,
+0x00,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0x4c,
+/* 20504 0x5018 "倘" */
+0x10,0x12,0x11,0x21,0x20,0x67,0x64,0xa4,0x25,0x25,0x25,0x25,0x25,0x24,0x24,0x24,
+0x40,0x48,0x48,0x50,0x40,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 20505 0x5019 "候" */
+0x10,0x13,0x10,0x28,0x2f,0x69,0x69,0xab,0x2c,0x28,0x2f,0x28,0x28,0x21,0x22,0x2c,
+0x00,0xf8,0x08,0x08,0xfe,0x00,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20506 0x501a "倚" */
+0x08,0x08,0x0b,0x10,0x11,0x32,0x37,0x50,0x93,0x12,0x12,0x12,0x13,0x10,0x10,0x10,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 20507 0x501b "倛" */
+0x09,0x09,0x0f,0x11,0x11,0x31,0x31,0x51,0x91,0x11,0x11,0x17,0x10,0x10,0x11,0x12,
+0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 20508 0x501c "倜" */
+0x10,0x17,0x14,0x24,0x25,0x64,0x64,0xa7,0x24,0x25,0x25,0x25,0x25,0x24,0x24,0x28,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 20509 0x501d "倝" */
+0x08,0x08,0xff,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x49,0x08,0xff,0x08,0x08,0x08,0x09,
+0x10,0x10,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0xa8,0x48,0x44,0x84,0x02,
+/* 20510 0x501e "倞" */
+0x08,0x08,0x0f,0x10,0x10,0x33,0x32,0x52,0x93,0x10,0x12,0x12,0x14,0x18,0x11,0x10,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 20511 0x501f "借" */
+0x09,0x09,0x09,0x17,0x11,0x31,0x3f,0x50,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x10,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 20512 0x5020 "倠" */
+0x09,0x09,0x09,0x13,0x12,0x36,0x3b,0x52,0x92,0x13,0x12,0x12,0x12,0x13,0x12,0x12,
+0x40,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 20513 0x5021 "倡" */
+0x09,0x09,0x09,0x11,0x11,0x31,0x31,0x50,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 20514 0x5022 "倢" */
+0x10,0x10,0x17,0x20,0x23,0x60,0x67,0xa0,0x23,0x20,0x22,0x22,0x22,0x25,0x24,0x28,
+0x40,0x40,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 20515 0x5023 "倣" */
+0x14,0x12,0x12,0x2f,0x24,0x64,0x67,0xa4,0x24,0x24,0x24,0x24,0x2a,0x29,0x30,0x20,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0xa4,0xa4,0xa8,0xa8,0x90,0x90,0xa8,0x28,0x44,0x82,
+/* 20516 0x5024 "値" */
+0x08,0x08,0x0b,0x10,0x11,0x35,0x35,0x55,0x95,0x15,0x15,0x15,0x15,0x14,0x17,0x10,
+0x20,0x20,0xfe,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,
+/* 20517 0x5025 "倥" */
+0x08,0x08,0x08,0x13,0x12,0x34,0x31,0x52,0x90,0x11,0x10,0x10,0x10,0x10,0x17,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 20518 0x5026 "倦" */
+0x10,0x12,0x11,0x27,0x20,0x61,0x6f,0xa2,0x24,0x2b,0x32,0x22,0x22,0x22,0x22,0x21,
+0x40,0x48,0x50,0xfc,0x80,0x00,0xfe,0x10,0x08,0xf4,0x12,0x10,0x50,0x24,0x04,0xfc,
+/* 20519 0x5027 "倧" */
+0x10,0x10,0x17,0x24,0x28,0x63,0x60,0xa0,0x27,0x20,0x22,0x22,0x24,0x28,0x21,0x20,
+0x80,0x40,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 20520 0x5028 "倨" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 20521 0x5029 "倩" */
+0x08,0x08,0x0f,0x10,0x13,0x30,0x37,0x50,0x93,0x12,0x13,0x12,0x13,0x12,0x12,0x12,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 20522 0x502a "倪" */
+0x08,0x08,0x0b,0x12,0x12,0x33,0x32,0x52,0x93,0x10,0x10,0x10,0x10,0x11,0x12,0x14,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 20523 0x502b "倫" */
+0x10,0x10,0x10,0x21,0x22,0x6d,0x60,0xa7,0x24,0x24,0x27,0x24,0x24,0x24,0x24,0x24,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 20524 0x502c "倬" */
+0x08,0x08,0x08,0x10,0x13,0x32,0x33,0x52,0x93,0x12,0x10,0x17,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 20525 0x502d "倭" */
+0x08,0x0b,0x08,0x10,0x17,0x31,0x32,0x54,0x90,0x17,0x11,0x12,0x11,0x10,0x10,0x13,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x86,0x80,0xfc,0x10,0x10,0xa0,0x60,0x90,0x08,
+/* 20526 0x502e "倮" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x90,0x17,0x10,0x11,0x12,0x14,0x10,0x10,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 20527 0x502f "倯" */
+0x12,0x12,0x12,0x22,0x2f,0x62,0x62,0xa6,0x27,0x2a,0x2a,0x32,0x22,0x22,0x22,0x22,
+0x08,0x28,0x28,0x28,0xa4,0x44,0x54,0x92,0x10,0xa0,0x20,0x28,0x44,0xfc,0x44,0x00,
+/* 20528 0x5030 "倰" */
+0x10,0x10,0x17,0x20,0x20,0x6f,0x62,0xa4,0x28,0x21,0x22,0x25,0x20,0x20,0x21,0x2e,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x08,0x84,0x82,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 20529 0x5031 "倱" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa7,0x20,0x24,0x24,0x27,0x24,0x24,0x25,0x26,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x20,0x22,0xac,0x30,0x22,0xa2,0x1e,
+/* 20530 0x5032 "倲" */
+0x10,0x10,0x1f,0x20,0x20,0x67,0x64,0xa7,0x24,0x27,0x24,0x21,0x22,0x24,0x38,0x20,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0xfc,0x44,0xfc,0xe4,0x50,0x48,0x44,0x42,0x40,
+/* 20531 0x5033 "倳" */
+0x10,0x10,0x1f,0x20,0x27,0x64,0x67,0xa0,0x27,0x20,0x3f,0x20,0x27,0x20,0x21,0x20,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x40,0xfc,0x44,0xfe,0x44,0xfc,0x40,0x40,0x80,
+/* 20532 0x5034 "倴" */
+0x08,0x08,0x0f,0x10,0x11,0x32,0x35,0x50,0x91,0x11,0x17,0x11,0x11,0x11,0x12,0x14,
+0x40,0x40,0xfe,0xa0,0x50,0x48,0xf6,0x40,0x50,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 20533 0x5035 "倵" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x50,0x90,0x12,0x12,0x12,0x12,0x12,0x17,0x12,
+0x10,0x18,0xd4,0x14,0x10,0xfe,0x10,0x90,0x90,0xd0,0x90,0x90,0x8a,0xea,0x06,0x02,
+/* 20534 0x5036 "倶" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x33,0x52,0x92,0x13,0x10,0x17,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0x08,0x04,0x02,
+/* 20535 0x5037 "倷" */
+0x08,0x08,0x0f,0x10,0x11,0x32,0x35,0x50,0x90,0x17,0x10,0x12,0x12,0x14,0x11,0x10,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0x00,0xfc,0x40,0x48,0x44,0x44,0x40,0x80,
+/* 20536 0x5038 "倸" */
+0x08,0x08,0x0b,0x10,0x12,0x31,0x31,0x50,0x93,0x10,0x10,0x10,0x11,0x12,0x14,0x10,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 20537 0x5039 "倹" */
+0x08,0x08,0x08,0x11,0x12,0x35,0x30,0x50,0x93,0x12,0x12,0x13,0x10,0x11,0x12,0x14,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xf8,0x48,0x48,0xf8,0xa0,0x10,0x08,0x06,
+/* 20538 0x503a "债" */
+0x08,0x08,0x0f,0x10,0x13,0x30,0x37,0x50,0x93,0x12,0x12,0x12,0x12,0x10,0x11,0x16,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x48,0x48,0x48,0xa0,0x10,0x08,
+/* 20539 0x503b "倻" */
+0x10,0x1f,0x14,0x24,0x24,0x67,0x64,0xa4,0x27,0x24,0x24,0x25,0x2e,0x20,0x20,0x20,
+0x00,0xde,0x92,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0x92,0xda,0x94,0x90,0x90,0x90,
+/* 20540 0x503c "值" */
+0x08,0x08,0x0f,0x10,0x10,0x33,0x32,0x53,0x92,0x13,0x12,0x13,0x12,0x12,0x1f,0x10,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 20541 0x503d "倽" */
+0x08,0x08,0x08,0x11,0x12,0x35,0x30,0x50,0x97,0x10,0x10,0x13,0x12,0x12,0x13,0x12,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 20542 0x503e "倾" */
+0x10,0x10,0x14,0x24,0x24,0x64,0x67,0xa4,0x24,0x24,0x25,0x26,0x24,0x20,0x20,0x20,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 20543 0x503f "倿" */
+0x08,0x08,0x0b,0x10,0x11,0x30,0x37,0x50,0x90,0x17,0x10,0x11,0x10,0x10,0x11,0x16,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 20544 0x5040 "偀" */
+0x11,0x11,0x17,0x21,0x21,0x60,0x63,0xa2,0x22,0x22,0x2f,0x20,0x20,0x21,0x22,0x24,
+0x10,0x10,0xfc,0x10,0x50,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20545 0x5041 "偁" */
+0x10,0x17,0x10,0x24,0x22,0x60,0x67,0xa4,0x24,0x27,0x24,0x24,0x3f,0x24,0x24,0x24,
+0x3e,0xc0,0x84,0x44,0x08,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfe,0x04,0x14,0x08,
+/* 20546 0x5042 "偂" */
+0x09,0x08,0x08,0x17,0x10,0x33,0x32,0x52,0x93,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 20547 0x5043 "偃" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x32,0x52,0x92,0x13,0x12,0x12,0x12,0x12,0x12,0x13,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 20548 0x5044 "偄" */
+0x10,0x17,0x10,0x20,0x27,0x64,0x64,0xa4,0x24,0x24,0x20,0x2f,0x20,0x21,0x22,0x2c,
+0x00,0xfc,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0x84,0x4c,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 20549 0x5045 "偅" */
+0x10,0x10,0x17,0x20,0x2f,0x60,0x67,0xa4,0x27,0x24,0x27,0x20,0x27,0x20,0x2f,0x20,
+0x08,0x3c,0xc0,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfc,0x40,0xfe,0x00,
+/* 20550 0x5046 "偆" */
+0x10,0x10,0x17,0x20,0x23,0x60,0x6f,0xa1,0x22,0x27,0x2a,0x22,0x23,0x22,0x22,0x23,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x10,0x08,0xfc,0x0a,0x08,0xf8,0x08,0x08,0xf8,
+/* 20551 0x5047 "假" */
+0x10,0x17,0x14,0x24,0x24,0x67,0x64,0xa4,0x27,0x24,0x24,0x27,0x24,0x24,0x24,0x24,
+0x00,0xbc,0x84,0x84,0x84,0xbc,0x00,0x00,0xbc,0x24,0x24,0xa8,0x10,0x28,0x44,0x82,
+/* 20552 0x5048 "偈" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x31,0x53,0x94,0x12,0x12,0x12,0x13,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 20553 0x5049 "偉" */
+0x08,0x08,0x0b,0x11,0x17,0x30,0x33,0x52,0x93,0x10,0x17,0x10,0x14,0x17,0x10,0x10,
+0x80,0x80,0xf8,0x08,0xfe,0x00,0xf8,0x08,0xf8,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,
+/* 20554 0x504a "偊" */
+0x08,0x08,0x0b,0x10,0x11,0x31,0x31,0x51,0x90,0x13,0x12,0x12,0x12,0x12,0x12,0x12,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 20555 0x504b "偋" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x52,0x92,0x12,0x12,0x13,0x14,0x14,0x18,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x84,0x48,0xfc,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 20556 0x504c "偌" */
+0x11,0x11,0x17,0x21,0x21,0x60,0x67,0xa0,0x21,0x23,0x25,0x29,0x21,0x21,0x21,0x21,
+0x08,0x08,0xfe,0x08,0x48,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20557 0x504d "偍" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x90,0x17,0x10,0x12,0x12,0x12,0x15,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x40,0x40,0x78,0x40,0x40,0xfe,
+/* 20558 0x504e "偎" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x90,0x17,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 20559 0x504f "偏" */
+0x10,0x10,0x17,0x24,0x24,0x67,0x64,0xa4,0x27,0x26,0x2a,0x2b,0x2a,0x2a,0x32,0x22,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 20560 0x5050 "偐" */
+0x08,0x08,0x0b,0x10,0x11,0x30,0x33,0x52,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x19,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x10,0x20,0xc8,0x10,0x24,0xc8,0x10,0x60,0x80,
+/* 20561 0x5051 "偑" */
+0x20,0x2f,0x28,0x48,0x4b,0x48,0xc8,0x4b,0x4a,0x4a,0x4b,0x48,0x48,0x50,0x57,0x60,
+0x00,0xf8,0x08,0x68,0x88,0x88,0x88,0xe8,0xa8,0xa8,0xe8,0x8a,0xaa,0xea,0x26,0x02,
+/* 20562 0x5052 "偒" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x30,0x5f,0x92,0x13,0x14,0x19,0x12,0x14,0x11,0x12,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 20563 0x5053 "偓" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x33,0x52,0x92,0x13,0x12,0x12,0x15,0x14,0x18,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 20564 0x5054 "偔" */
+0x08,0x0b,0x0a,0x12,0x13,0x30,0x31,0x50,0x97,0x10,0x11,0x11,0x10,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 20565 0x5055 "偕" */
+0x0a,0x0a,0x0b,0x12,0x12,0x33,0x32,0x50,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x20,0x24,0xa8,0x30,0xa2,0x22,0x5e,0x80,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 20566 0x5056 "偖" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x50,0x91,0x13,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 20567 0x5057 "偗" */
+0x08,0x08,0x09,0x11,0x12,0x30,0x30,0x57,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x24,0x22,0x2a,0x30,0xc0,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 20568 0x5058 "偘" */
+0x08,0x0b,0x0a,0x12,0x12,0x32,0x33,0x50,0x90,0x17,0x14,0x14,0x14,0x14,0x17,0x14,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,
+/* 20569 0x5059 "偙" */
+0x08,0x08,0x0b,0x10,0x11,0x30,0x37,0x54,0x98,0x13,0x12,0x12,0x12,0x12,0x10,0x10,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x42,0x44,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 20570 0x505a "做" */
+0x12,0x12,0x12,0x2f,0x22,0x62,0x62,0xaf,0x28,0x28,0x28,0x28,0x2f,0x28,0x20,0x20,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0x24,0xa4,0xa4,0xa8,0xa8,0x90,0xa8,0x28,0x44,0x82,
+/* 20571 0x505b "偛" */
+0x10,0x10,0x17,0x20,0x20,0x6f,0x60,0xa1,0x26,0x24,0x24,0x27,0x24,0x24,0x27,0x24,
+0x08,0x3c,0xc0,0x40,0x40,0xfe,0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x04,
+/* 20572 0x505c "停" */
+0x10,0x10,0x17,0x20,0x23,0x62,0x63,0xa0,0x2f,0x28,0x23,0x20,0x20,0x20,0x21,0x20,
+0x80,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x40,0x40,0x40,0x40,0x80,
+/* 20573 0x505d "偝" */
+0x08,0x08,0x0f,0x10,0x11,0x36,0x30,0x53,0x92,0x13,0x12,0x13,0x12,0x12,0x12,0x12,
+0x90,0x92,0x9c,0x90,0x92,0x8e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 20574 0x505e "偞" */
+0x08,0x0a,0x0a,0x17,0x12,0x32,0x32,0x52,0x93,0x10,0x17,0x10,0x11,0x12,0x1c,0x10,
+0x90,0x90,0x90,0xfe,0x90,0x90,0xf0,0x00,0xfc,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 20575 0x505f "偟" */
+0x08,0x08,0x0b,0x12,0x13,0x32,0x33,0x50,0x97,0x10,0x10,0x13,0x10,0x10,0x17,0x10,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,
+/* 20576 0x5060 "偠" */
+0x08,0x0b,0x08,0x10,0x13,0x32,0x32,0x53,0x90,0x10,0x17,0x10,0x11,0x10,0x10,0x13,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 20577 0x5061 "偡" */
+0x09,0x09,0x0f,0x11,0x11,0x31,0x31,0x51,0x91,0x17,0x12,0x12,0x13,0x12,0x13,0x10,
+0x08,0x08,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x50,0x88,0x04,0x00,0xfc,0x00,
+/* 20578 0x5062 "偢" */
+0x13,0x1e,0x12,0x22,0x22,0x6f,0x62,0xa6,0x27,0x2a,0x2a,0x32,0x22,0x22,0x22,0x23,
+0x90,0x10,0x10,0x12,0x52,0xd4,0x58,0x90,0x10,0xa8,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 20579 0x5063 "偣" */
+0x08,0x08,0x0f,0x10,0x12,0x31,0x3f,0x50,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x80,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 20580 0x5064 "偤" */
+0x09,0x08,0x08,0x17,0x10,0x30,0x33,0x52,0x92,0x13,0x12,0x13,0x12,0x12,0x13,0x12,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 20581 0x5065 "健" */
+0x10,0x10,0x10,0x2e,0x23,0x62,0x64,0xa4,0x2e,0x22,0x22,0x2b,0x24,0x26,0x29,0x30,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfe,0x00,
+/* 20582 0x5066 "偦" */
+0x08,0x0b,0x08,0x11,0x11,0x31,0x32,0x54,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 20583 0x5067 "偧" */
+0x10,0x10,0x17,0x21,0x22,0x6c,0x61,0xa6,0x21,0x21,0x2e,0x21,0x26,0x20,0x20,0x2f,
+0x00,0x80,0xfc,0x10,0x08,0x86,0xf8,0x10,0x60,0xa0,0x7e,0x84,0x48,0x30,0xc0,0x00,
+/* 20584 0x5068 "偨" */
+0x11,0x11,0x15,0x25,0x25,0x65,0x6e,0xa0,0x20,0x27,0x20,0x21,0x22,0x2c,0x20,0x20,
+0x20,0x24,0xa8,0x30,0x24,0xa4,0x1c,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 20585 0x5069 "偩" */
+0x09,0x09,0x0b,0x12,0x14,0x3b,0x32,0x53,0x92,0x13,0x12,0x13,0x10,0x11,0x12,0x14,
+0x00,0x00,0xf8,0x08,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x08,0x04,0x02,
+/* 20586 0x506a "偪" */
+0x10,0x17,0x10,0x23,0x22,0x62,0x63,0xa0,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x24,
+0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 20587 0x506b "偫" */
+0x11,0x11,0x12,0x24,0x29,0x61,0x62,0xa6,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 20588 0x506c "偬" */
+0x11,0x11,0x13,0x24,0x2b,0x61,0x62,0xa4,0x21,0x22,0x20,0x21,0x25,0x25,0x28,0x20,
+0x00,0x00,0xfc,0x94,0x94,0x64,0x54,0x84,0x28,0x10,0x40,0x24,0x2a,0x0a,0xf8,0x00,
+/* 20589 0x506d "偭" */
+0x08,0x0f,0x08,0x10,0x13,0x32,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 20590 0x506e "偮" */
+0x08,0x09,0x09,0x11,0x11,0x30,0x37,0x51,0x91,0x11,0x11,0x11,0x11,0x17,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 20591 0x506f "偯" */
+0x08,0x08,0x0f,0x10,0x13,0x32,0x32,0x52,0x93,0x10,0x11,0x13,0x15,0x19,0x11,0x11,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0x08,0x08,0xf8,0xa4,0x28,0x10,0x10,0x48,0x86,0x00,
+/* 20592 0x5070 "偰" */
+0x09,0x09,0x0f,0x11,0x13,0x31,0x37,0x51,0x91,0x10,0x17,0x10,0x10,0x11,0x12,0x1c,
+0x00,0x3c,0xd4,0x14,0x94,0x14,0xd4,0x24,0x4c,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 20593 0x5071 "偱" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x65,0xa5,0x25,0x25,0x25,0x25,0x29,0x29,0x31,0x21,
+0x3c,0xe0,0x20,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 20594 0x5072 "偲" */
+0x08,0x0b,0x0a,0x12,0x13,0x32,0x32,0x53,0x90,0x10,0x10,0x15,0x15,0x19,0x10,0x10,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x40,0x24,0x22,0x0a,0x08,0xf8,0x00,
+/* 20595 0x5073 "偳" */
+0x10,0x14,0x14,0x24,0x27,0x60,0x6f,0xa0,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x24,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x0c,
+/* 20596 0x5074 "側" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa7,0x24,0x24,0x27,0x20,0x22,0x22,0x24,0x28,
+0x02,0xc2,0x42,0x52,0xd2,0x52,0x52,0xd2,0x52,0x52,0xd2,0x02,0x82,0x42,0x4a,0x04,
+/* 20597 0x5075 "偵" */
+0x10,0x10,0x10,0x20,0x27,0x64,0x64,0xa7,0x24,0x27,0x24,0x24,0x27,0x21,0x22,0x24,
+0x40,0x7e,0x40,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x10,0x08,0x04,
+/* 20598 0x5076 "偶" */
+0x10,0x17,0x14,0x24,0x27,0x64,0x64,0xa7,0x20,0x2f,0x28,0x28,0x2b,0x29,0x28,0x28,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0xfe,0x42,0x52,0xf2,0x12,0x0a,0x04,
+/* 20599 0x5077 "偷" */
+0x08,0x08,0x09,0x12,0x15,0x30,0x33,0x52,0x92,0x13,0x12,0x12,0x13,0x12,0x12,0x12,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 20600 0x5078 "偸" */
+0x09,0x08,0x09,0x12,0x15,0x30,0x33,0x52,0x92,0x13,0x12,0x12,0x13,0x12,0x12,0x12,
+0xc0,0xa0,0x10,0x08,0xf6,0x00,0xca,0x4a,0x54,0xd4,0x68,0x54,0xd4,0x4a,0x4a,0xc0,
+/* 20601 0x5079 "偹" */
+0x08,0x08,0x10,0x10,0x35,0x54,0x94,0x17,0x14,0x14,0x14,0x14,0x14,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0xf8,0xa8,0xa8,0xa8,0xf8,0xa8,0xa8,0xf8,
+/* 20602 0x507a "偺" */
+0x09,0x09,0x0b,0x12,0x14,0x3a,0x31,0x52,0x9c,0x13,0x12,0x12,0x13,0x12,0x12,0x13,
+0x10,0x10,0xd8,0x54,0x52,0x90,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 20603 0x507b "偻" */
+0x08,0x09,0x08,0x10,0x13,0x30,0x31,0x52,0x90,0x17,0x10,0x11,0x11,0x10,0x11,0x16,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 20604 0x507c "偼" */
+0x08,0x08,0x08,0x10,0x13,0x30,0x31,0x50,0x93,0x10,0x12,0x12,0x12,0x15,0x14,0x18,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 20605 0x507d "偽" */
+0x08,0x0a,0x09,0x17,0x10,0x30,0x30,0x51,0x91,0x13,0x12,0x14,0x1a,0x12,0x14,0x10,
+0x40,0x40,0x40,0xf8,0x88,0x90,0xfc,0x04,0x08,0xfe,0x02,0x2a,0xaa,0x82,0x14,0x08,
+/* 20606 0x507e "偾" */
+0x10,0x10,0x17,0x20,0x22,0x6f,0x62,0xa0,0x27,0x24,0x24,0x24,0x24,0x20,0x23,0x2c,
+0x40,0x40,0xfc,0x40,0x48,0xfe,0x08,0x00,0xfc,0x04,0x44,0x44,0x44,0xb0,0x0c,0x02,
+/* 20607 0x507f "偿" */
+0x08,0x0a,0x09,0x10,0x17,0x34,0x38,0x51,0x90,0x10,0x17,0x10,0x11,0x12,0x17,0x12,
+0x40,0x48,0x50,0x40,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x80,0x10,0x08,0xfc,0x04,
+/* 20608 0x5080 "傀" */
+0x10,0x10,0x17,0x24,0x24,0x67,0x64,0xa4,0x27,0x20,0x21,0x21,0x22,0x24,0x28,0x30,
+0x40,0x80,0xfc,0x44,0x44,0xfc,0x44,0x84,0xfc,0x80,0x50,0x64,0x7c,0x42,0x42,0x3e,
+/* 20609 0x5081 "傁" */
+0x11,0x16,0x14,0x24,0x27,0x64,0x64,0xa7,0x20,0x27,0x22,0x21,0x20,0x20,0x21,0x2e,
+0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x40,0xfc,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 20610 0x5082 "傂" */
+0x10,0x10,0x17,0x24,0x24,0x65,0x65,0xa5,0x25,0x25,0x25,0x29,0x2a,0x32,0x24,0x29,
+0x04,0x3e,0xe0,0x3e,0x20,0xfe,0x22,0x38,0xe2,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 20611 0x5083 "傃" */
+0x08,0x08,0x0f,0x10,0x13,0x30,0x37,0x50,0x91,0x13,0x10,0x17,0x10,0x12,0x15,0x10,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x10,0xe0,0x48,0xfc,0x44,0x48,0x44,0x80,
+/* 20612 0x5084 "傄" */
+0x10,0x10,0x1f,0x24,0x22,0x61,0x62,0xac,0x23,0x22,0x23,0x22,0x23,0x22,0x23,0x22,
+0x40,0x40,0xfe,0x44,0xa8,0x10,0x08,0x06,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 20613 0x5085 "傅" */
+0x08,0x08,0x0f,0x10,0x17,0x34,0x37,0x54,0x97,0x14,0x10,0x1f,0x12,0x11,0x11,0x10,
+0x50,0x48,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x08,0xfe,0x08,0x08,0x28,0x10,
+/* 20614 0x5086 "傆" */
+0x10,0x17,0x14,0x24,0x25,0x65,0x65,0xa5,0x25,0x25,0x24,0x24,0x29,0x2a,0x30,0x20,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 20615 0x5087 "傇" */
+0x09,0x09,0x0f,0x11,0x10,0x37,0x31,0x51,0x91,0x11,0x11,0x11,0x17,0x10,0x10,0x10,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,0x08,
+/* 20616 0x5088 "傈" */
+0x10,0x17,0x10,0x20,0x27,0x64,0x64,0xa7,0x20,0x20,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 20617 0x5089 "傉" */
+0x08,0x0b,0x0a,0x12,0x12,0x33,0x32,0x52,0x92,0x12,0x12,0x13,0x12,0x14,0x14,0x18,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 20618 0x508a "傊" */
+0x08,0x09,0x09,0x11,0x11,0x30,0x33,0x52,0x93,0x12,0x13,0x12,0x13,0x10,0x11,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 20619 0x508b "傋" */
+0x09,0x09,0x0f,0x11,0x13,0x31,0x37,0x50,0x93,0x12,0x13,0x12,0x17,0x12,0x12,0x12,
+0x10,0x10,0xfc,0x10,0xf8,0x10,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xfe,0x08,0x28,0x10,
+/* 20620 0x508c "傌" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x32,0x52,0x93,0x10,0x15,0x15,0x15,0x14,0x10,0x10,
+0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x04,0x54,0x54,0x54,0x04,0x28,0x10,
+/* 20621 0x508d "傍" */
+0x10,0x10,0x17,0x22,0x21,0x67,0x64,0xa8,0x20,0x27,0x21,0x21,0x21,0x22,0x22,0x24,
+0x80,0x40,0xfc,0x08,0x10,0xfe,0x02,0x84,0x40,0xfc,0x00,0xf8,0x08,0x08,0x28,0x10,
+/* 20622 0x508e "傎" */
+0x10,0x10,0x17,0x20,0x23,0x62,0x63,0xa2,0x23,0x22,0x23,0x22,0x2f,0x21,0x22,0x24,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 20623 0x508f "傏" */
+0x10,0x10,0x17,0x24,0x25,0x64,0x67,0xa4,0x25,0x24,0x25,0x25,0x25,0x29,0x29,0x31,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 20624 0x5090 "傐" */
+0x10,0x10,0x17,0x20,0x23,0x62,0x63,0xa0,0x27,0x24,0x25,0x25,0x25,0x24,0x24,0x24,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0x14,0x08,
+/* 20625 0x5091 "傑" */
+0x12,0x12,0x13,0x24,0x2a,0x61,0x62,0xa4,0x28,0x27,0x20,0x21,0x22,0x2c,0x20,0x20,
+0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x48,0x48,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 20626 0x5092 "傒" */
+0x08,0x0f,0x0a,0x11,0x10,0x31,0x33,0x50,0x91,0x13,0x10,0x10,0x17,0x10,0x11,0x16,
+0x3c,0xc0,0x44,0x28,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x40,0xfc,0xa0,0x10,0x0e,
+/* 20627 0x5093 "傓" */
+0x10,0x10,0x17,0x24,0x24,0x67,0x64,0xa7,0x24,0x26,0x25,0x24,0x2b,0x28,0x31,0x20,
+0x80,0x40,0xfe,0x02,0x02,0xfe,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 20628 0x5094 "傔" */
+0x0a,0x09,0x08,0x17,0x10,0x37,0x30,0x5f,0x90,0x17,0x10,0x11,0x12,0x1c,0x10,0x10,
+0x08,0x10,0x00,0xfe,0xa0,0xfc,0xa4,0xfe,0xa4,0xfc,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 20629 0x5095 "傕" */
+0x10,0x10,0x17,0x25,0x21,0x63,0x66,0xaa,0x23,0x22,0x22,0x23,0x22,0x22,0x23,0x22,
+0x80,0x80,0xfe,0x22,0x10,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 20630 0x5096 "傖" */
+0x08,0x08,0x08,0x11,0x12,0x37,0x3a,0x53,0x92,0x13,0x12,0x13,0x15,0x15,0x19,0x11,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 20631 0x5097 "傗" */
+0x08,0x08,0x0f,0x10,0x11,0x33,0x30,0x51,0x97,0x10,0x17,0x14,0x17,0x14,0x17,0x14,
+0x80,0x40,0xfc,0x80,0x08,0xf0,0x60,0x84,0xfe,0x02,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 20632 0x5098 "傘" */
+0x01,0x02,0x04,0x08,0x31,0xd1,0x11,0x29,0x45,0x11,0x29,0x45,0xff,0x01,0x01,0x01,
+0x00,0x80,0x40,0x20,0x18,0x16,0x10,0x28,0x44,0x10,0x28,0x44,0xfe,0x00,0x00,0x00,
+/* 20633 0x5099 "備" */
+0x08,0x08,0x0b,0x10,0x10,0x37,0x30,0x51,0x93,0x15,0x11,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x88,0xfe,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 20634 0x509a "傚" */
+0x14,0x12,0x12,0x2f,0x20,0x65,0x64,0xa8,0x31,0x25,0x22,0x22,0x25,0x29,0x30,0x20,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0xa4,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 20635 0x509b "傛" */
+0x08,0x08,0x0b,0x12,0x14,0x31,0x32,0x50,0x91,0x12,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x94,0x08,0x64,0x90,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x08,
+/* 20636 0x509c "傜" */
+0x10,0x10,0x17,0x22,0x21,0x61,0x62,0xa3,0x24,0x20,0x2f,0x20,0x24,0x24,0x27,0x20,
+0x04,0x3e,0xc0,0x44,0x24,0x28,0x00,0xfc,0x40,0x40,0xfe,0x40,0x44,0x44,0xfc,0x04,
+/* 20637 0x509d "傝" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x30,0x50,0x97,0x10,0x14,0x12,0x14,0x10,0x12,0x11,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 20638 0x509e "傞" */
+0x09,0x08,0x08,0x13,0x10,0x31,0x30,0x53,0x90,0x11,0x11,0x12,0x14,0x18,0x13,0x10,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 20639 0x509f "傟" */
+0x09,0x09,0x0a,0x14,0x19,0x33,0x30,0x50,0x97,0x10,0x14,0x12,0x14,0x10,0x12,0x11,
+0x20,0x10,0x08,0x86,0x10,0xf8,0x08,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 20640 0x50a0 "傠" */
+0x12,0x11,0x11,0x2f,0x20,0x67,0x60,0xa7,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x20,
+0x04,0x04,0x04,0xc4,0x3e,0x84,0x04,0xa4,0x14,0x94,0x84,0x84,0x84,0x84,0x94,0x08,
+/* 20641 0x50a1 "傡" */
+0x14,0x12,0x12,0x2f,0x20,0x60,0x68,0xa8,0x24,0x25,0x25,0x21,0x22,0x21,0x2e,0x24,
+0x10,0x08,0x08,0xbe,0x00,0x82,0xa2,0xa2,0x92,0x12,0x14,0x14,0x04,0x88,0x3e,0x00,
+/* 20642 0x50a2 "傢" */
+0x10,0x10,0x17,0x24,0x20,0x63,0x60,0xa1,0x26,0x20,0x21,0x26,0x20,0x21,0x26,0x20,
+0x80,0x40,0xfc,0x04,0x00,0xf8,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 20643 0x50a3 "傣" */
+0x08,0x08,0x0f,0x10,0x13,0x30,0x37,0x51,0x92,0x14,0x12,0x11,0x12,0x14,0x11,0x10,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x48,0x46,0x48,0x50,0x48,0x44,0x40,0x80,
+/* 20644 0x50a4 "傤" */
+0x11,0x11,0x17,0x21,0x2f,0x62,0x62,0xaf,0x24,0x29,0x2f,0x21,0x21,0x2f,0x25,0x21,
+0x10,0x14,0xd2,0x10,0xfe,0x10,0x10,0xd4,0x14,0x14,0xd4,0x08,0xca,0x1a,0x26,0x42,
+/* 20645 0x50a5 "傥" */
+0x08,0x0a,0x09,0x10,0x17,0x34,0x38,0x53,0x92,0x12,0x13,0x10,0x11,0x11,0x12,0x14,
+0x40,0x48,0x50,0x40,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0xa0,0x20,0x24,0x24,0x1c,
+/* 20646 0x50a6 "傦" */
+0x08,0x09,0x09,0x11,0x11,0x37,0x34,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xf8,0x08,0xe8,0x28,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 20647 0x50a7 "傧" */
+0x10,0x10,0x17,0x24,0x28,0x63,0x62,0xa2,0x23,0x22,0x22,0x2f,0x20,0x21,0x22,0x24,
+0x80,0x40,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x10,0x08,0x04,
+/* 20648 0x50a8 "储" */
+0x10,0x10,0x18,0x24,0x24,0x61,0x60,0xbc,0x24,0x25,0x26,0x24,0x25,0x26,0x24,0x20,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 20649 0x50a9 "傩" */
+0x10,0x10,0x17,0x21,0x21,0x69,0x65,0xa5,0x22,0x22,0x25,0x25,0x29,0x20,0x20,0x20,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 20650 0x50aa "傪" */
+0x10,0x11,0x13,0x22,0x24,0x6f,0x60,0xa0,0x23,0x2c,0x21,0x26,0x21,0x26,0x21,0x2e,
+0x80,0x10,0xf8,0x10,0xa4,0xbe,0x42,0xa0,0x18,0x46,0x90,0x64,0x88,0x30,0xc0,0x00,
+/* 20651 0x50ab "傫" */
+0x10,0x17,0x14,0x27,0x24,0x67,0x61,0xa2,0x27,0x20,0x23,0x2f,0x20,0x22,0x25,0x28,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x10,0xe0,0xc8,0x04,0xfe,0x42,0x48,0x44,0x82,
+/* 20652 0x50ac "催" */
+0x08,0x0a,0x0b,0x10,0x10,0x31,0x33,0x55,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 20653 0x50ad "傭" */
+0x10,0x17,0x14,0x25,0x24,0x67,0x64,0xa5,0x24,0x25,0x25,0x25,0x25,0x29,0x29,0x31,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 20654 0x50ae "傮" */
+0x08,0x08,0x0f,0x10,0x17,0x34,0x37,0x54,0x97,0x10,0x13,0x12,0x13,0x12,0x13,0x12,
+0xa0,0xa0,0xfe,0xa0,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 20655 0x50af "傯" */
+0x08,0x08,0x0b,0x12,0x12,0x33,0x32,0x52,0x92,0x13,0x10,0x10,0x15,0x15,0x19,0x10,
+0x40,0x80,0xfc,0x44,0xf4,0x14,0xa4,0x44,0xa4,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 20656 0x50b0 "傰" */
+0x10,0x14,0x14,0x27,0x20,0x67,0x64,0xa4,0x27,0x24,0x24,0x27,0x24,0x24,0x2a,0x31,
+0x40,0x44,0x44,0xfc,0x00,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xb4,0x48,
+/* 20657 0x50b1 "傱" */
+0x11,0x11,0x12,0x24,0x29,0x61,0x62,0xa6,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,0x23,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 20658 0x50b2 "傲" */
+0x12,0x12,0x1f,0x22,0x2f,0x62,0xbf,0x24,0x24,0x27,0x24,0x24,0x24,0x29,0x28,0x30,
+0x10,0x10,0xd0,0x20,0xbe,0x44,0xa4,0x24,0x24,0xa8,0xa8,0x90,0xa8,0xa8,0x44,0x82,
+/* 20659 0x50b3 "傳" */
+0x10,0x1f,0x10,0x27,0x24,0x67,0x64,0xa7,0x20,0x2f,0x20,0x2f,0x22,0x21,0x21,0x20,
+0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x42,0xfe,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 20660 0x50b4 "傴" */
+0x10,0x17,0x14,0x24,0x24,0x64,0x64,0xa4,0x25,0x25,0x25,0x25,0x25,0x24,0x27,0x20,
+0x00,0xfc,0x00,0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0x54,0xdc,0x00,0xfe,0x00,
+/* 20661 0x50b5 "債" */
+0x08,0x0b,0x08,0x11,0x10,0x33,0x30,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 20662 0x50b6 "傶" */
+0x10,0x10,0x10,0x27,0x24,0x64,0x64,0xa4,0x27,0x24,0x24,0x25,0x2a,0x28,0x31,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 20663 0x50b7 "傷" */
+0x09,0x09,0x0a,0x15,0x11,0x31,0x31,0x51,0x90,0x17,0x11,0x13,0x14,0x11,0x12,0x10,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 20664 0x50b8 "傸" */
+0x10,0x10,0x17,0x20,0x25,0x62,0x65,0xa0,0x25,0x22,0x25,0x20,0x20,0x21,0x22,0x2c,
+0x40,0x40,0xfc,0x40,0x54,0x48,0x54,0x40,0x54,0x48,0x54,0xa0,0xa0,0x10,0x08,0x06,
+/* 20665 0x50b9 "傹" */
+0x08,0x08,0x0b,0x11,0x10,0x37,0x30,0x53,0x92,0x13,0x12,0x13,0x11,0x11,0x12,0x1c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 20666 0x50ba "傺" */
+0x09,0x09,0x0b,0x12,0x15,0x32,0x31,0x52,0x94,0x10,0x13,0x10,0x11,0x12,0x15,0x10,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 20667 0x50bb "傻" */
+0x08,0x08,0x0b,0x12,0x12,0x32,0x33,0x50,0x91,0x12,0x14,0x11,0x12,0x10,0x11,0x16,
+0x40,0x80,0xfc,0x94,0x64,0x94,0xfc,0x90,0x08,0x84,0xfa,0x08,0x90,0x60,0x98,0x06,
+/* 20668 0x50bc "傼" */
+0x11,0x11,0x17,0x21,0x21,0x60,0x63,0xa2,0x23,0x20,0x27,0x20,0x2f,0x20,0x21,0x26,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0xa0,0x10,0x0c,
+/* 20669 0x50bd "傽" */
+0x10,0x17,0x11,0x20,0x2f,0x60,0x63,0xa2,0x23,0x22,0x23,0x20,0x2f,0x20,0x20,0x20,
+0x40,0xfc,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 20670 0x50be "傾" */
+0x10,0x11,0x10,0x24,0x24,0x64,0x67,0xa4,0x24,0x24,0x25,0x26,0x24,0x20,0x20,0x21,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 20671 0x50bf "傿" */
+0x10,0x17,0x10,0x22,0x22,0x6f,0x61,0xa1,0x22,0x23,0x20,0x25,0x25,0x28,0x20,0x20,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 20672 0x50c0 "僀" */
+0x12,0x12,0x17,0x22,0x22,0x64,0x68,0xa7,0x24,0x20,0x23,0x22,0x22,0x22,0x22,0x20,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 20673 0x50c1 "僁" */
+0x10,0x10,0x17,0x20,0x22,0x61,0x6f,0xa1,0x22,0x2c,0x20,0x20,0x2a,0x2a,0x31,0x20,
+0x08,0x3c,0xc0,0x40,0x48,0x50,0xfe,0x50,0x48,0x46,0x80,0x44,0x42,0x12,0xf0,0x00,
+/* 20674 0x50c2 "僂" */
+0x10,0x13,0x12,0x2f,0x22,0x63,0x60,0xa3,0x22,0x23,0x20,0x2f,0x21,0x20,0x23,0x2c,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x48,0xf8,0x80,0xfe,0x10,0xe0,0x18,0x04,
+/* 20675 0x50c3 "僃" */
+0x11,0x11,0x1f,0x21,0x24,0x67,0x68,0xb7,0x24,0x27,0x24,0x27,0x24,0x24,0x24,0x20,
+0x10,0x10,0xfe,0x10,0x00,0xfc,0x04,0xf4,0x94,0xf4,0x94,0xf4,0x94,0x94,0x34,0x08,
+/* 20676 0x50c4 "僄" */
+0x10,0x1f,0x10,0x27,0x24,0x64,0x67,0xa0,0x27,0x20,0x2f,0x20,0x22,0x24,0x29,0x20,
+0x00,0xfe,0xa0,0xfc,0xa4,0xa4,0xfc,0x00,0xfc,0x00,0xfe,0x40,0x48,0x44,0x42,0x80,
+/* 20677 0x50c5 "僅" */
+0x11,0x11,0x1f,0x21,0x21,0x60,0x67,0xa4,0x27,0x20,0x2f,0x20,0x27,0x20,0x2f,0x20,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x40,0xfc,0x40,0xfe,0x00,
+/* 20678 0x50c6 "僆" */
+0x10,0x18,0x15,0x24,0x21,0x61,0x6d,0xa5,0x25,0x24,0x25,0x24,0x24,0x2a,0x31,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 20679 0x50c7 "僇" */
+0x08,0x0f,0x08,0x14,0x12,0x34,0x30,0x51,0x96,0x10,0x13,0x10,0x13,0x10,0x10,0x17,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 20680 0x50c8 "僈" */
+0x13,0x12,0x13,0x22,0x23,0x60,0x67,0xa4,0x24,0x27,0x20,0x23,0x21,0x20,0x23,0x2c,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 20681 0x50c9 "僉" */
+0x01,0x02,0x04,0x08,0x37,0xc0,0x00,0x3e,0x22,0x22,0x3e,0x08,0x08,0x14,0x22,0x41,
+0x00,0x80,0x40,0x20,0xd8,0x06,0x00,0xf8,0x88,0x88,0xf8,0x20,0x20,0x50,0x88,0x04,
+/* 20682 0x50ca "僊" */
+0x10,0x17,0x10,0x27,0x24,0x67,0x60,0xaf,0x21,0x22,0x27,0x2a,0x23,0x22,0x22,0x21,
+0x00,0xfc,0xa0,0xfc,0xa4,0xfc,0x40,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x04,0x04,0xfc,
+/* 20683 0x50cb "僋" */
+0x08,0x08,0x09,0x12,0x1d,0x30,0x30,0x53,0x92,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x40,0xa0,0x10,0x48,0xf6,0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 20684 0x50cc "僌" */
+0x12,0x12,0x1f,0x22,0x2f,0x6a,0x6a,0xaf,0x2a,0x2a,0x2f,0x22,0x3f,0x22,0x22,0x22,
+0x10,0x10,0x90,0x20,0xbe,0xc4,0xa4,0xa4,0xa4,0xa8,0xa8,0x10,0xa8,0x28,0x44,0x82,
+/* 20685 0x50cd "働" */
+0x11,0x17,0x11,0x2f,0x21,0x67,0x65,0xa7,0x25,0x27,0x21,0x27,0x21,0x21,0x2e,0x24,
+0xc8,0x08,0x08,0xe8,0x1e,0xca,0x4a,0xca,0x4a,0xca,0x0a,0xca,0x12,0xd2,0x2a,0x44,
+/* 20686 0x50ce "僎" */
+0x10,0x17,0x14,0x27,0x24,0x64,0x63,0xa0,0x21,0x27,0x21,0x21,0x2f,0x21,0x22,0x24,
+0x00,0xbc,0xa4,0xbc,0x20,0xa4,0x9c,0x00,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0x04,
+/* 20687 0x50cf "像" */
+0x09,0x09,0x0a,0x17,0x1a,0x32,0x33,0x50,0x91,0x16,0x11,0x16,0x10,0x11,0x16,0x10,
+0x00,0xf0,0x10,0xfc,0x24,0x44,0xfc,0x80,0x44,0xa8,0x30,0x68,0xa8,0x24,0xa2,0x40,
+/* 20688 0x50d0 "僐" */
+0x08,0x08,0x0b,0x10,0x11,0x30,0x33,0x51,0x90,0x17,0x10,0x11,0x11,0x11,0x11,0x11,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 20689 0x50d1 "僑" */
+0x10,0x13,0x10,0x27,0x21,0x62,0x65,0xa9,0x21,0x20,0x27,0x24,0x25,0x25,0x25,0x24,
+0x38,0xc0,0x80,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x0c,
+/* 20690 0x50d2 "僒" */
+0x10,0x10,0x17,0x25,0x22,0x63,0x60,0xa7,0x20,0x23,0x21,0x23,0x25,0x29,0x21,0x21,
+0x80,0x40,0xfc,0x14,0x08,0xf8,0x88,0xfe,0x88,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 20691 0x50d3 "僓" */
+0x08,0x0b,0x0a,0x13,0x10,0x37,0x30,0x53,0x92,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 20692 0x50d4 "僔" */
+0x09,0x08,0x0f,0x10,0x13,0x32,0x33,0x52,0x93,0x12,0x13,0x10,0x17,0x11,0x10,0x10,
+0x08,0x90,0xfe,0x90,0xfc,0x94,0x1c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x08,0xa8,0x10,
+/* 20693 0x50d5 "僕" */
+0x10,0x14,0x12,0x20,0x27,0x61,0x60,0xa7,0x20,0x23,0x20,0x27,0x20,0x21,0x22,0x2c,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 20694 0x50d6 "僖" */
+0x10,0x17,0x10,0x23,0x20,0x63,0x62,0xa3,0x21,0x2f,0x20,0x23,0x22,0x22,0x23,0x22,
+0x40,0xfc,0x40,0xf8,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 20695 0x50d7 "僗" */
+0x08,0x0a,0x0a,0x14,0x11,0x32,0x30,0x53,0x92,0x14,0x13,0x10,0x10,0x10,0x11,0x12,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 20696 0x50d8 "僘" */
+0x22,0x32,0x2a,0x4a,0x42,0x5f,0xd0,0x50,0x57,0x55,0x55,0x55,0x57,0x50,0x51,0x50,
+0x08,0x48,0x48,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x54,0xa2,
+/* 20697 0x50d9 "僙" */
+0x11,0x11,0x17,0x21,0x21,0x6f,0x60,0xa7,0x24,0x27,0x24,0x27,0x20,0x21,0x22,0x24,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x10,0x08,0x04,
+/* 20698 0x50da "僚" */
+0x10,0x10,0x17,0x20,0x25,0x62,0x67,0xaa,0x23,0x22,0x23,0x20,0x22,0x24,0x29,0x20,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 20699 0x50db "僛" */
+0x15,0x15,0x15,0x2f,0x25,0x67,0x65,0xa7,0x25,0x25,0x2f,0x20,0x25,0x28,0x30,0x20,
+0x10,0x10,0x10,0x90,0x3e,0x22,0x44,0x90,0x10,0x10,0x90,0x28,0x28,0xa4,0x44,0x82,
+/* 20700 0x50dc "僜" */
+0x10,0x17,0x10,0x22,0x21,0x62,0x65,0xa8,0x23,0x22,0x22,0x23,0x22,0x21,0x2f,0x20,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 20701 0x50dd "僝" */
+0x17,0x14,0x17,0x24,0x25,0x64,0x67,0xa4,0x24,0x27,0x24,0x25,0x29,0x2f,0x31,0x23,
+0xfc,0x04,0xfc,0x00,0xf8,0x10,0xfe,0x20,0x60,0x9c,0x84,0x08,0xde,0x08,0x08,0x18,
+/* 20702 0x50de "僞" */
+0x10,0x10,0x17,0x22,0x21,0x63,0x62,0xa3,0x22,0x23,0x24,0x26,0x2a,0x2a,0x30,0x20,
+0x04,0x3e,0xc0,0x44,0x28,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 20703 0x50df "僟" */
+0x12,0x12,0x15,0x27,0x22,0x65,0x67,0xa2,0x2f,0x22,0x22,0x22,0x25,0x24,0x24,0x28,
+0x48,0x48,0x54,0x5c,0x48,0x54,0x5c,0x48,0xfe,0x20,0x28,0x28,0x14,0x94,0x2c,0x44,
+/* 20704 0x50e0 "僠" */
+0x08,0x0f,0x0a,0x11,0x17,0x31,0x32,0x54,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x78,0xc0,0x48,0x50,0xfc,0x50,0x48,0x06,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x08,
+/* 20705 0x50e1 "僡" */
+0x10,0x10,0x1f,0x20,0x27,0x64,0x67,0xa4,0x27,0x20,0x2f,0x20,0x20,0x25,0x25,0x28,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0xfe,0x42,0x24,0x22,0x0a,0xf8,
+/* 20706 0x50e2 "僢" */
+0x10,0x17,0x10,0x22,0x21,0x67,0x64,0xaa,0x22,0x23,0x24,0x2a,0x21,0x22,0x24,0x28,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x02,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 20707 0x50e3 "僣" */
+0x11,0x11,0x17,0x21,0x2f,0x61,0x62,0xa4,0x23,0x22,0x22,0x23,0x22,0x22,0x23,0x22,
+0x10,0x10,0xbc,0x10,0xfe,0x10,0xa8,0x44,0xfa,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 20708 0x50e4 "僤" */
+0x08,0x0b,0x0a,0x12,0x13,0x30,0x31,0x51,0x91,0x11,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 20709 0x50e5 "僥" */
+0x10,0x10,0x17,0x20,0x2f,0x61,0x67,0xa1,0x21,0x26,0x20,0x2f,0x21,0x21,0x22,0x2c,
+0x40,0x40,0xfc,0x40,0xfe,0x10,0xbc,0x10,0x90,0x3e,0x00,0xfe,0x20,0x22,0x22,0x1e,
+/* 20710 0x50e6 "僦" */
+0x14,0x12,0x1f,0x20,0x20,0x6f,0x68,0xa8,0x2f,0x22,0x2b,0x2a,0x32,0x22,0x2a,0x24,
+0x14,0x12,0x92,0x10,0x7e,0x90,0x90,0x90,0x90,0x28,0x28,0xa8,0x28,0x4a,0x4a,0x86,
+/* 20711 0x50e7 "僧" */
+0x09,0x08,0x08,0x13,0x12,0x32,0x32,0x52,0x93,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 20712 0x50e8 "僨" */
+0x10,0x17,0x10,0x21,0x2f,0x61,0x63,0xa2,0x23,0x22,0x23,0x22,0x23,0x21,0x22,0x24,
+0x40,0xfc,0x40,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0x04,
+/* 20713 0x50e9 "僩" */
+0x17,0x14,0x17,0x24,0x27,0x64,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x25,0x24,0x24,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 20714 0x50ea "僪" */
+0x08,0x0b,0x08,0x10,0x13,0x30,0x30,0x53,0x90,0x13,0x12,0x12,0x13,0x12,0x12,0x12,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 20715 0x50eb "僫" */
+0x08,0x0f,0x08,0x10,0x13,0x32,0x32,0x53,0x90,0x10,0x17,0x10,0x15,0x15,0x19,0x10,
+0x00,0xfe,0x90,0x90,0x9c,0x04,0x04,0x9c,0x90,0x90,0xfe,0x40,0x24,0x0a,0x0a,0xf8,
+/* 20716 0x50ec "僬" */
+0x11,0x11,0x13,0x22,0x26,0x6b,0x62,0xa2,0x23,0x22,0x22,0x23,0x22,0x25,0x24,0x28,
+0x40,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x24,0x92,0x92,
+/* 20717 0x50ed "僭" */
+0x10,0x17,0x11,0x25,0x27,0x63,0x65,0xa9,0x20,0x23,0x22,0x22,0x23,0x22,0x22,0x23,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 20718 0x50ee "僮" */
+0x08,0x0b,0x09,0x10,0x17,0x30,0x33,0x52,0x93,0x12,0x13,0x10,0x13,0x10,0x17,0x10,
+0x40,0xf8,0x10,0xa0,0xfc,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xf8,0x40,0xfe,0x00,
+/* 20719 0x50ef "僯" */
+0x10,0x12,0x11,0x27,0x21,0x62,0x64,0xa2,0x22,0x23,0x24,0x2a,0x21,0x22,0x24,0x28,
+0x40,0x48,0x50,0xfc,0x50,0x48,0x44,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 20720 0x50f0 "僰" */
+0x10,0x10,0xfe,0x10,0xfe,0x92,0x92,0x38,0x54,0x92,0x10,0x11,0x02,0x0c,0x30,0xc0,
+0x10,0x10,0xfe,0x10,0xfe,0x92,0x92,0x38,0x54,0x92,0x10,0x10,0x80,0x60,0x18,0x06,
+/* 20721 0x50f1 "僱" */
+0x08,0x08,0x0b,0x12,0x12,0x33,0x32,0x52,0x92,0x13,0x12,0x12,0x14,0x14,0x18,0x10,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x50,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,
+/* 20722 0x50f2 "僲" */
+0x10,0x17,0x10,0x27,0x24,0x64,0x67,0xa2,0x22,0x23,0x24,0x2a,0x21,0x22,0x24,0x28,
+0x00,0xfe,0xa0,0xfc,0xa4,0xa4,0xfc,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 20723 0x50f3 "僳" */
+0x10,0x17,0x10,0x20,0x27,0x64,0x64,0xa7,0x22,0x21,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 20724 0x50f4 "僴" */
+0x10,0x17,0x14,0x27,0x24,0x67,0x64,0xa5,0x25,0x25,0x25,0x25,0x25,0x24,0x24,0x24,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x14,0x04,0x14,0x08,
+/* 20725 0x50f5 "僵" */
+0x10,0x1f,0x10,0x27,0x24,0x67,0x64,0xaf,0x20,0x27,0x24,0x27,0x24,0x27,0x20,0x2f,
+0x00,0xfe,0x00,0xfc,0x44,0xfc,0x44,0xfe,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,
+/* 20726 0x50f6 "僶" */
+0x10,0x17,0x14,0x24,0x27,0x60,0x67,0xa4,0x24,0x27,0x24,0x24,0x27,0x24,0x20,0x20,
+0x00,0xfc,0xa4,0xa4,0xbc,0xa0,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa2,0xa2,0x7e,
+/* 20727 0x50f7 "僷" */
+0x11,0x17,0x11,0x20,0x24,0x6f,0x64,0xa4,0x24,0x27,0x20,0x2f,0x21,0x22,0x2c,0x20,
+0x08,0xfe,0x08,0x00,0x88,0xfe,0x88,0xf8,0x00,0xfc,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 20728 0x50f8 "僸" */
+0x11,0x11,0x17,0x21,0x23,0x65,0x69,0xa0,0x23,0x20,0x27,0x20,0x22,0x24,0x29,0x20,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 20729 0x50f9 "價" */
+0x10,0x1f,0x11,0x2f,0x29,0x6f,0x60,0xa7,0x24,0x27,0x24,0x27,0x24,0x27,0x22,0x24,
+0x00,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 20730 0x50fa "僺" */
+0x13,0x12,0x12,0x23,0x20,0x67,0x64,0xa4,0x27,0x20,0x2f,0x21,0x22,0x24,0x38,0x20,
+0xf8,0x08,0x08,0xf8,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0xfe,0x60,0x50,0x48,0x46,0x40,
+/* 20731 0x50fb "僻" */
+0x10,0x10,0x17,0x24,0x24,0x64,0x67,0xa4,0x24,0x27,0x26,0x2a,0x2a,0x2b,0x32,0x20,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0x7e,0x08,0x88,0xbe,0x88,0x88,0x88,0x88,0x08,
+/* 20732 0x50fc "僼" */
+0x10,0x10,0x17,0x24,0x27,0x64,0x67,0xa0,0x27,0x20,0x23,0x22,0x23,0x21,0x20,0x2f,
+0xa0,0xa0,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x10,0xa0,0xfe,
+/* 20733 0x50fd "僽" */
+0x10,0x17,0x11,0x21,0x2f,0x61,0x63,0xa5,0x29,0x21,0x20,0x20,0x25,0x25,0x29,0x20,
+0xc8,0x08,0x2a,0x2c,0xc8,0x08,0x88,0x54,0x14,0x22,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 20734 0x50fe "僾" */
+0x08,0x0b,0x08,0x12,0x11,0x37,0x34,0x52,0x92,0x14,0x10,0x10,0x11,0x12,0x10,0x17,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 20735 0x50ff "僿" */
+0x10,0x10,0x17,0x25,0x2b,0x61,0x67,0xa1,0x27,0x21,0x22,0x25,0x28,0x20,0x27,0x20,
+0x80,0x40,0xfe,0x12,0xfc,0x10,0xfc,0x10,0xfe,0x10,0x48,0xf4,0x42,0x40,0xfc,0x00,
+/* 20736 0x5100 "儀" */
+0x11,0x17,0x10,0x23,0x20,0x67,0xa0,0x27,0x21,0x2f,0x21,0x21,0x2f,0x21,0x27,0x00,
+0x10,0xfe,0x40,0xfc,0x40,0xfe,0x80,0x28,0x24,0xfe,0x20,0xa4,0x1a,0x12,0x6e,0x00,
+/* 20737 0x5101 "儁" */
+0x11,0x11,0x13,0x22,0x27,0x6a,0x63,0xa2,0x23,0x22,0x27,0x24,0x24,0x24,0x24,0x24,
+0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x9e,0x92,0x92,0xf2,0x02,0x06,
+/* 20738 0x5102 "儂" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x30,0x53,0x92,0x12,0x12,0x13,0x15,0x15,0x15,0x19,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 20739 0x5103 "儃" */
+0x10,0x1f,0x10,0x27,0x24,0x65,0x65,0xa7,0x20,0x23,0x22,0x23,0x22,0x23,0x20,0x2f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 20740 0x5104 "億" */
+0x08,0x08,0x0b,0x11,0x10,0x37,0x30,0x53,0x92,0x13,0x12,0x13,0x10,0x15,0x15,0x18,
+0x80,0x40,0xfc,0x08,0x90,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x24,0x0a,0xfa,
+/* 20741 0x5105 "儅" */
+0x10,0x12,0x11,0x27,0x24,0x68,0x63,0xa2,0x23,0x20,0x27,0x24,0x27,0x24,0x27,0x24,
+0x40,0x48,0x50,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 20742 0x5106 "儆" */
+0x12,0x12,0x17,0x22,0x24,0x67,0x64,0xa8,0x27,0x25,0x25,0x27,0x25,0x20,0x22,0x21,
+0x88,0x88,0xe8,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x94,0x22,
+/* 20743 0x5107 "儇" */
+0x08,0x0b,0x0a,0x12,0x13,0x30,0x37,0x50,0x93,0x12,0x13,0x10,0x11,0x13,0x1d,0x11,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 20744 0x5108 "儈" */
+0x10,0x10,0x13,0x2d,0x20,0x67,0x65,0xa4,0x27,0x20,0x23,0x22,0x23,0x22,0x23,0x22,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 20745 0x5109 "儉" */
+0x10,0x10,0x10,0x21,0x22,0x65,0x68,0xa7,0x24,0x24,0x27,0x22,0x22,0x25,0x29,0x30,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xbc,0xa4,0xa4,0xbc,0x10,0x10,0x28,0x44,0x82,
+/* 20746 0x510a "儊" */
+0x11,0x11,0x17,0x21,0x23,0x65,0x69,0xa0,0x27,0x20,0x22,0x22,0x22,0x25,0x28,0x30,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xfc,0x44,0x40,0x78,0x40,0x40,0xfe,0x00,
+/* 20747 0x510b "儋" */
+0x12,0x13,0x14,0x27,0x2d,0x76,0x67,0xa4,0x25,0x24,0x25,0x24,0x25,0x29,0x29,0x31,
+0x00,0xf8,0x10,0xfe,0x48,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x04,
+/* 20748 0x510c "儌" */
+0x12,0x14,0x1f,0x28,0x2f,0x68,0x6f,0xa4,0x22,0x2f,0x24,0x27,0x24,0x28,0x2a,0x31,
+0x10,0x10,0x90,0x90,0xbe,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x88,0x88,0x94,0x94,0x22,
+/* 20749 0x510d "儍" */
+0x08,0x08,0x0a,0x13,0x12,0x32,0x32,0x53,0x90,0x11,0x12,0x10,0x11,0x10,0x10,0x17,
+0x20,0x88,0x52,0x26,0x52,0x8a,0x22,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 20750 0x510e "儎" */
+0x11,0x17,0x11,0x2f,0x21,0x6f,0x61,0xa7,0x25,0x27,0x25,0x27,0x21,0x2f,0x21,0x21,
+0x14,0xd2,0x10,0xfe,0x10,0xd0,0x12,0xd2,0x52,0xd4,0x54,0xc8,0x0a,0xda,0x26,0x42,
+/* 20751 0x510f "儏" */
+0x10,0x10,0x12,0x23,0x24,0x6a,0x63,0xac,0x22,0x21,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x80,0xdc,0x84,0xd4,0x48,0x94,0x24,0x40,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 20752 0x5110 "儐" */
+0x10,0x10,0x17,0x24,0x2b,0x61,0x62,0xa7,0x22,0x27,0x2a,0x23,0x22,0x23,0x21,0x22,
+0x80,0x40,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 20753 0x5111 "儑" */
+0x08,0x0b,0x0a,0x13,0x12,0x33,0x31,0x52,0x93,0x11,0x12,0x13,0x10,0x12,0x12,0x14,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 20754 0x5112 "儒" */
+0x10,0x17,0x10,0x2f,0x28,0x63,0x60,0xa3,0x20,0x2f,0x20,0x27,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfe,0x40,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 20755 0x5113 "儓" */
+0x10,0x1f,0x10,0x27,0x20,0x63,0x62,0xaf,0x28,0x27,0x21,0x23,0x20,0x27,0x20,0x2f,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xfc,0x40,0xfe,
+/* 20756 0x5114 "儔" */
+0x10,0x17,0x10,0x23,0x20,0x6f,0x60,0xa3,0x20,0x27,0x20,0x27,0x20,0x27,0x24,0x27,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 20757 0x5115 "儕" */
+0x10,0x10,0x17,0x21,0x20,0x6f,0x65,0xa5,0x2b,0x20,0x22,0x23,0x22,0x23,0x22,0x24,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 20758 0x5116 "儖" */
+0x10,0x17,0x15,0x27,0x24,0x67,0x65,0xa7,0x20,0x23,0x22,0x22,0x22,0x22,0x2f,0x20,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 20759 0x5117 "儗" */
+0x14,0x15,0x16,0x24,0x23,0x60,0x64,0xa7,0x2a,0x22,0x2f,0x22,0x25,0x24,0x28,0x21,
+0x00,0x7c,0x04,0xa8,0x90,0x7c,0x14,0x94,0x50,0x50,0xdc,0x50,0x50,0xb0,0x9e,0x00,
+/* 20760 0x5118 "儘" */
+0x08,0x0b,0x08,0x17,0x10,0x33,0x30,0x57,0x90,0x12,0x14,0x13,0x12,0x12,0x1f,0x10,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 20761 0x5119 "儙" */
+0x10,0x14,0x12,0x22,0x20,0x61,0x60,0xae,0x22,0x22,0x22,0x22,0x22,0x22,0x25,0x28,
+0x10,0xfe,0x92,0xfe,0x10,0xfe,0x00,0xfe,0x82,0xfe,0x80,0xfe,0x82,0xfe,0x00,0xfe,
+/* 20762 0x511a "儚" */
+0x08,0x08,0x0b,0x10,0x13,0x32,0x33,0x50,0x93,0x12,0x10,0x11,0x12,0x10,0x10,0x17,
+0x88,0x88,0xfe,0x88,0xfe,0x52,0xfe,0x00,0xfe,0x42,0xf8,0x08,0x90,0x60,0xc0,0x00,
+/* 20763 0x511b "儛" */
+0x11,0x12,0x17,0x2a,0x22,0x6f,0x62,0xa2,0x2f,0x22,0x23,0x24,0x2a,0x21,0x22,0x2c,
+0x00,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,
+/* 20764 0x511c "儜" */
+0x10,0x10,0x17,0x24,0x22,0x62,0x64,0xa0,0x23,0x22,0x2f,0x20,0x27,0x20,0x21,0x20,
+0x80,0x40,0xfc,0x44,0xa8,0x94,0x74,0x00,0xf8,0xa8,0xfe,0x00,0xfc,0x40,0x40,0x80,
+/* 20765 0x511d "儝" */
+0x11,0x15,0x15,0x29,0x22,0x64,0x60,0xa7,0x24,0x20,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0x00,0xfc,0x44,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 20766 0x511e "儞" */
+0x10,0x17,0x12,0x24,0x2f,0x64,0x66,0xa5,0x26,0x24,0x26,0x25,0x26,0x24,0x24,0x24,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 20767 0x511f "償" */
+0x0a,0x09,0x0f,0x14,0x11,0x31,0x33,0x52,0x93,0x12,0x13,0x12,0x13,0x11,0x12,0x14,
+0x48,0x50,0xfe,0x02,0xf8,0x08,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,0x02,
+/* 20768 0x5120 "儠" */
+0x09,0x0a,0x09,0x10,0x13,0x32,0x32,0x52,0x93,0x12,0x13,0x12,0x13,0x12,0x12,0x13,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 20769 0x5121 "儡" */
+0x13,0x12,0x12,0x23,0x22,0x62,0x63,0xa0,0x2f,0x2a,0x2a,0x2f,0x2a,0x2a,0x2f,0x28,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 20770 0x5122 "儢" */
+0x10,0x10,0x10,0x27,0x24,0x65,0x64,0xa5,0x25,0x25,0x25,0x25,0x28,0x2a,0x32,0x24,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x24,0xfc,0x24,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 20771 0x5123 "儣" */
+0x10,0x10,0x17,0x24,0x25,0x64,0x67,0xa4,0x25,0x25,0x25,0x25,0x29,0x28,0x31,0x22,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x04,0x02,
+/* 20772 0x5124 "儤" */
+0x0b,0x0a,0x0b,0x12,0x13,0x31,0x37,0x51,0x9f,0x11,0x12,0x15,0x10,0x11,0x12,0x10,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfc,0x10,0xfe,0x10,0x48,0x54,0xe0,0x50,0x48,0xc0,
+/* 20773 0x5125 "儥" */
+0x08,0x0b,0x08,0x11,0x10,0x33,0x32,0x53,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 20774 0x5126 "儦" */
+0x10,0x10,0x17,0x24,0x27,0x64,0x67,0xa4,0x25,0x25,0x25,0x25,0x25,0x28,0x2a,0x34,
+0x80,0x40,0xfc,0xa0,0xfc,0xa4,0xfc,0x00,0x24,0xa8,0x30,0xa4,0x1c,0x00,0xa4,0x52,
+/* 20775 0x5127 "儧" */
+0x12,0x1f,0x12,0x2f,0x22,0x65,0x68,0xa7,0x24,0x27,0x24,0x27,0x24,0x27,0x21,0x22,
+0x08,0xbe,0x08,0xbe,0x08,0x14,0xa2,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x10,0x08,
+/* 20776 0x5128 "儨" */
+0x08,0x0b,0x0a,0x13,0x12,0x32,0x34,0x53,0x92,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 20777 0x5129 "儩" */
+0x10,0x1f,0x19,0x29,0x2f,0x69,0x69,0xaf,0x29,0x29,0x2f,0x20,0x2a,0x29,0x29,0x31,
+0x00,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x20,0x7e,0xaa,0x2a,0x4a,0x92,0x22,0x4a,0x04,
+/* 20778 0x512a "優" */
+0x17,0x10,0x13,0x22,0x23,0x62,0x6f,0xa8,0x25,0x25,0x28,0x21,0x23,0x25,0x20,0x2f,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xfe,0x82,0x48,0x14,0xf4,0x00,0xf8,0x08,0xf0,0x0e,
+/* 20779 0x512b "儫" */
+0x10,0x17,0x10,0x21,0x21,0x61,0x60,0xa7,0x24,0x23,0x21,0x26,0x21,0x26,0x21,0x2e,
+0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x80,0x44,0xb8,0x68,0xa6,0x60,
+/* 20780 0x512c "儬" */
+0x12,0x12,0x1f,0x22,0x2f,0x62,0x7f,0xa0,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x28,0x29,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xe4,0x3c,0xa4,0xa4,0xbc,0x90,0x98,0xa8,0xaa,0xc6,
+/* 20781 0x512d "儭" */
+0x14,0x12,0x1f,0x20,0x28,0x65,0x6f,0xa2,0x22,0x2f,0x22,0x2b,0x2a,0x32,0x2a,0x24,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xa4,0x3c,0x24,0xa4,0x3c,0x10,0x98,0xa8,0x2a,0x46,
+/* 20782 0x512e "儮" */
+0x10,0x17,0x14,0x25,0x24,0x67,0x64,0xa5,0x26,0x24,0x24,0x25,0x25,0x29,0x29,0x37,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 20783 0x512f "儯" */
+0x12,0x11,0x17,0x20,0x2f,0x62,0x67,0xaa,0x23,0x22,0x23,0x22,0x23,0x20,0x25,0x20,
+0x48,0x50,0xfc,0x80,0xfe,0x08,0xfc,0x42,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0x08,
+/* 20784 0x5130 "儰" */
+0x11,0x1f,0x11,0x20,0x2f,0x64,0x62,0xa7,0x24,0x27,0x24,0x27,0x28,0x2a,0x32,0x20,
+0x10,0xfe,0x10,0x3c,0xc0,0x88,0x50,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x04,
+/* 20785 0x5131 "儱" */
+0x14,0x12,0x1f,0x25,0x22,0x7f,0x60,0xaf,0x28,0x2f,0x28,0x2f,0x28,0x28,0x28,0x29,
+0x20,0x20,0xbe,0x20,0x3e,0x82,0x3e,0xa0,0xbe,0xa0,0xbe,0xa0,0xbe,0xa0,0xa2,0x9e,
+/* 20786 0x5132 "儲" */
+0x14,0x12,0x12,0x2f,0x20,0x6f,0x60,0xaf,0x20,0x2f,0x29,0x29,0x29,0x2f,0x29,0x20,
+0x10,0x10,0x7a,0x12,0x14,0x7e,0x08,0x10,0x3c,0x64,0xa4,0x3c,0x24,0x24,0x3c,0x24,
+/* 20787 0x5133 "儳" */
+0x09,0x0a,0x0f,0x12,0x13,0x32,0x33,0x52,0x91,0x12,0x17,0x12,0x13,0x10,0x11,0x16,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 20788 0x5134 "儴" */
+0x10,0x17,0x10,0x23,0x22,0x63,0x61,0xa7,0x21,0x27,0x21,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 20789 0x5135 "儵" */
+0x10,0x11,0x12,0x20,0x23,0x68,0x69,0xa9,0x29,0x29,0x29,0x28,0x29,0x20,0x23,0x21,
+0x80,0xf8,0x88,0x70,0x8e,0x00,0xfc,0x24,0xac,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x54,
+/* 20790 0x5136 "儶" */
+0x0a,0x0b,0x08,0x11,0x13,0x35,0x31,0x51,0x91,0x11,0x11,0x13,0x12,0x13,0x12,0x12,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 20791 0x5137 "儷" */
+0x17,0x10,0x17,0x24,0x26,0x64,0x60,0xa7,0x24,0x27,0x24,0x27,0x25,0x29,0x29,0x31,
+0xbe,0x00,0xbc,0xa4,0xb4,0xa4,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x12,0xdc,0x12,0xce,
+/* 20792 0x5138 "儸" */
+0x10,0x17,0x14,0x24,0x27,0x62,0x62,0xa4,0x2f,0x22,0x24,0x2f,0x20,0x2a,0x2a,0x20,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 20793 0x5139 "儹" */
+0x15,0x17,0x19,0x27,0x23,0x65,0x69,0xa3,0x22,0x23,0x22,0x23,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 20794 0x513a "儺" */
+0x15,0x15,0x1f,0x25,0x27,0x62,0x6f,0xaa,0x2f,0x22,0x2f,0x22,0x3f,0x25,0x28,0x30,
+0x18,0x14,0x90,0x3e,0x28,0x68,0xbe,0xa8,0xa8,0x3e,0xa8,0x28,0xe8,0x3e,0xa0,0x60,
+/* 20795 0x513b "儻" */
+0x12,0x11,0x17,0x24,0x21,0x61,0x67,0xa5,0x24,0x27,0x20,0x27,0x20,0x2f,0x22,0x24,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 20796 0x513c "儼" */
+0x17,0x14,0x17,0x20,0x27,0x64,0x65,0xa4,0x27,0x25,0x25,0x25,0x25,0x25,0x2b,0x30,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 20797 0x513d "儽" */
+0x17,0x14,0x17,0x24,0x2f,0x6a,0x6f,0xaa,0x2f,0x22,0x27,0x20,0x2f,0x20,0x25,0x28,
+0xfc,0x44,0xfc,0x44,0xfe,0xaa,0xbe,0xaa,0xbe,0x20,0xc0,0x84,0xfe,0x42,0x48,0x84,
+/* 20798 0x513e "儾" */
+0x10,0x17,0x12,0x23,0x20,0x6f,0x6a,0xa3,0x21,0x27,0x21,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 20799 0x513f "儿" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20800 0x5140 "兀" */
+0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,0x00,
+/* 20801 0x5141 "允" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0x40,0x20,0x10,0xf8,0x48,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,
+/* 20802 0x5142 "兂" */
+0x01,0x01,0x01,0x7f,0x01,0x11,0x11,0x21,0x3f,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0x84,0x84,0x7c,0x00,
+/* 20803 0x5143 "元" */
+0x00,0x3f,0x00,0x00,0x00,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0xf8,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20804 0x5144 "兄" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 20805 0x5145 "充" */
+0x02,0x01,0xff,0x04,0x04,0x08,0x10,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0xf8,0x48,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 20806 0x5146 "兆" */
+0x04,0x04,0x44,0x24,0x14,0x14,0x04,0x0c,0x14,0x24,0x44,0x08,0x08,0x10,0x20,0x40,
+0x40,0x40,0x44,0x48,0x50,0x40,0x60,0x50,0x48,0x44,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20807 0x5147 "兇" */
+0x08,0x24,0x22,0x21,0x22,0x24,0x28,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x20,0x48,0x88,0x08,0x88,0x48,0x28,0xf8,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 20808 0x5148 "先" */
+0x01,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 20809 0x5149 "光" */
+0x01,0x21,0x11,0x09,0x09,0x01,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x08,0x08,0x10,0x20,0x00,0xfe,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20810 0x514a "兊" */
+0x04,0x04,0x08,0x11,0x21,0xc2,0x04,0x08,0x1f,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x40,0x40,0x20,0x10,0x08,0x06,0x40,0x20,0xf0,0x50,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 20811 0x514b "克" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x20,0x20,0x20,0x3f,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 20812 0x514c "兌" */
+0x04,0x04,0x08,0x10,0x20,0xdf,0x10,0x10,0x10,0x1f,0x04,0x04,0x04,0x08,0x10,0x60,
+0x40,0x40,0x20,0x10,0x08,0xf6,0x10,0x10,0x10,0xf0,0x40,0x40,0x40,0x44,0x44,0x3c,
+/* 20813 0x514d "免" */
+0x08,0x08,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x21,0x3f,0x22,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x88,0x80,0x80,0x82,0x82,0x7e,
+/* 20814 0x514e "兎" */
+0x00,0x01,0x7f,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x22,0x04,0x08,0x10,0x20,0xc0,
+0x08,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x88,0xa0,0x90,0x92,0x82,0x7e,
+/* 20815 0x514f "兏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x1f,0x11,0x11,0x11,0x22,0x22,0x44,0x98,
+0x10,0xf8,0x80,0x80,0xf8,0x80,0x80,0x80,0xfe,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 20816 0x5150 "児" */
+0x00,0x23,0x22,0x22,0x23,0x22,0x22,0x23,0x22,0x00,0x04,0x04,0x04,0x08,0x10,0x60,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x40,0x40,0x40,0x44,0x44,0x3c,
+/* 20817 0x5151 "兑" */
+0x10,0x08,0x04,0x00,0x1f,0x10,0x10,0x10,0x1f,0x14,0x04,0x04,0x08,0x08,0x10,0x60,
+0x10,0x20,0x40,0x00,0xf0,0x10,0x10,0x10,0xf0,0x50,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 20818 0x5152 "兒" */
+0x00,0x06,0x38,0x20,0x20,0x3c,0x20,0x20,0x3f,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 20819 0x5153 "兓" */
+0x00,0x7e,0x08,0x08,0x48,0x48,0x48,0x7e,0x08,0x08,0x14,0x14,0x25,0x26,0x44,0x81,
+0x00,0xfe,0x10,0x10,0x90,0x90,0x90,0xfe,0x10,0x10,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 20820 0x5154 "兔" */
+0x08,0x08,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x21,0x3f,0x22,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x88,0xa0,0x90,0x92,0x82,0x7e,
+/* 20821 0x5155 "兕" */
+0x00,0x3c,0x24,0x24,0x24,0x27,0x20,0x20,0x3f,0x24,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x78,0x48,0x48,0x48,0xc8,0x08,0x08,0xf8,0x48,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 20822 0x5156 "兖" */
+0x02,0x01,0xff,0x08,0x11,0x22,0x44,0x08,0x1f,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xfe,0x20,0x10,0x08,0x44,0x20,0xf0,0x50,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 20823 0x5157 "兗" */
+0x02,0x01,0xff,0x08,0x10,0x20,0x5f,0x10,0x10,0x10,0x1f,0x04,0x04,0x08,0x10,0x60,
+0x00,0x00,0xfe,0x20,0x10,0x08,0xf4,0x10,0x10,0x10,0xf0,0x40,0x40,0x44,0x44,0x3c,
+/* 20824 0x5158 "兘" */
+0x00,0x7c,0x00,0x00,0x01,0xfe,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x20,0x20,0x48,0x84,0xfe,0x02,0x00,0xfc,0x84,0x84,0xfc,0x84,0x02,0x02,0xfe,0x00,
+/* 20825 0x5159 "兙" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x10,0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x02,0xfe,0x00,
+/* 20826 0x515a "党" */
+0x01,0x11,0x09,0x09,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x10,0x10,0x20,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x40,0x40,0x42,0x42,0x3e,
+/* 20827 0x515b "兛" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x08,0x1c,0x70,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x12,0x02,0xfe,0x00,
+/* 20828 0x515c "兜" */
+0x01,0x12,0x67,0x44,0x44,0x47,0x44,0x44,0x57,0x60,0x04,0x04,0x04,0x08,0x10,0x60,
+0x00,0x00,0xdc,0x44,0x44,0xc4,0x44,0x44,0xc4,0x1c,0x40,0x40,0x40,0x44,0x44,0x3c,
+/* 20829 0x515d "兝" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x25,0x24,0x43,0x80,
+0x08,0x28,0x24,0x44,0x42,0x80,0x7c,0x24,0x24,0x44,0x44,0x94,0x0a,0x02,0xfe,0x00,
+/* 20830 0x515e "兞" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x38,0xe0,0x20,0x38,0xe0,0x20,0x3c,0xe0,0x24,0x24,0x24,0x1c,0x02,0x02,0xfe,0x00,
+/* 20831 0x515f "兟" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0x08,0x7e,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x81,
+0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x28,0x28,0x28,0x28,0x4a,0x4a,0x86,0x00,
+/* 20832 0x5160 "兠" */
+0x01,0x12,0x17,0xf4,0x14,0x17,0x14,0x34,0xd7,0x10,0x04,0x04,0x04,0x08,0x10,0x60,
+0x00,0x10,0xd2,0x54,0x58,0xd0,0x52,0x52,0xce,0x00,0x40,0x40,0x40,0x44,0x44,0x3c,
+/* 20833 0x5161 "兡" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x02,0x02,0xfe,0x00,
+/* 20834 0x5162 "兢" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0x7e,0x42,0x42,0x7e,0x14,0x14,0x25,0x26,0x44,0x81,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0xfc,0x50,0x50,0x50,0x92,0x92,0x0e,
+/* 20835 0x5163 "兣" */
+0x10,0x11,0xfd,0x11,0x11,0x7d,0x45,0x45,0x7d,0x29,0x29,0x2a,0x2c,0x48,0x47,0x80,
+0x00,0xfe,0x00,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x7c,0x10,0xfe,0x00,0x02,0xfe,0x00,
+/* 20836 0x5164 "兤" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x29,0x29,0x29,0x29,0x2a,0x2a,0x4c,0x48,0x87,
+0x10,0xfe,0x28,0x7c,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x28,0x44,0x02,0xfe,
+/* 20837 0x5165 "入" */
+0x04,0x02,0x01,0x01,0x01,0x02,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x06,
+/* 20838 0x5166 "兦" */
+0x04,0x42,0x41,0x41,0x40,0x40,0x41,0x41,0x42,0x42,0x44,0x48,0x50,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x04,0x00,0xfe,0x00,
+/* 20839 0x5167 "內" */
+0x04,0x02,0x02,0x7f,0x41,0x41,0x42,0x42,0x44,0x48,0x50,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x84,0x84,0x44,0x24,0x14,0x04,0x04,0x04,0x14,0x08,
+/* 20840 0x5168 "全" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x2f,0xc1,0x01,0x01,0x1f,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0x00,0xf0,0x00,0x00,0x00,0xfc,0x00,
+/* 20841 0x5169 "兩" */
+0x00,0xff,0x01,0x01,0x01,0x7f,0x41,0x51,0x49,0x49,0x55,0x65,0x41,0x41,0x41,0x40,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x44,0x24,0x24,0x54,0x94,0x04,0x04,0x14,0x08,
+/* 20842 0x516a "兪" */
+0x06,0x01,0x02,0x0c,0x30,0xcf,0x00,0x3e,0x22,0x22,0x3e,0x22,0x3e,0x22,0x22,0x26,
+0x00,0x00,0x80,0x60,0x18,0xe6,0x00,0x24,0x24,0x48,0x48,0x90,0x48,0x48,0x24,0x24,
+/* 20843 0x516b "八" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x20,0x40,
+0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 20844 0x516c "公" */
+0x00,0x04,0x04,0x08,0x08,0x10,0x20,0x42,0x82,0x04,0x04,0x08,0x10,0x3f,0x10,0x00,
+0x80,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x40,0x20,0x20,0xf0,0x10,0x00,
+/* 20845 0x516d "六" */
+0x02,0x01,0x00,0x00,0x00,0xff,0x00,0x00,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x80,0x80,0x00,0xfe,0x00,0x00,0x40,0x20,0x10,0x08,0x08,0x04,0x04,0x00,
+/* 20846 0x516e "兮" */
+0x04,0x04,0x08,0x08,0x10,0x20,0xdf,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x01,0x00,
+0x40,0x40,0x20,0x20,0x10,0x08,0xf6,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 20847 0x516f "兯" */
+0x20,0x10,0x08,0x08,0x00,0x7f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x10,0x10,0x20,0x40,0x00,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 20848 0x5170 "兰" */
+0x10,0x08,0x04,0x04,0x00,0x7f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0xff,0x00,
+0x10,0x10,0x20,0x40,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 20849 0x5171 "共" */
+0x04,0x04,0x04,0x04,0x3f,0x04,0x04,0x04,0x04,0x04,0x7f,0x00,0x04,0x08,0x10,0x20,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,0x20,0x10,0x08,0x04,
+/* 20850 0x5172 "兲" */
+0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 20851 0x5173 "关" */
+0x10,0x08,0x08,0x00,0x3f,0x01,0x01,0x01,0xff,0x01,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x10,0x10,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 20852 0x5174 "兴" */
+0x04,0x02,0x21,0x11,0x08,0x08,0x00,0xff,0x00,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x08,0x08,0x08,0x10,0x10,0x20,0x40,0xfe,0x00,0x40,0x20,0x10,0x08,0x08,0x04,0x04,
+/* 20853 0x5175 "兵" */
+0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0xff,0x00,0x08,0x10,0x20,0x40,
+0x20,0xf0,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0xfe,0x00,0x40,0x20,0x10,0x08,
+/* 20854 0x5176 "其" */
+0x08,0x08,0x7f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0xff,0x00,0x08,0x10,0x20,
+0x20,0x20,0xfc,0x20,0x20,0xe0,0x20,0x20,0xe0,0x20,0x20,0xfe,0x00,0x20,0x10,0x08,
+/* 20855 0x5177 "具" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x04,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x40,0x20,0x10,0x08,
+/* 20856 0x5178 "典" */
+0x04,0x04,0x04,0x3f,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0xff,0x04,0x08,0x10,0x20,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0xf8,0x48,0x48,0x48,0xfe,0x40,0x20,0x10,0x08,
+/* 20857 0x5179 "兹" */
+0x08,0x04,0x04,0xff,0x10,0x10,0x20,0x24,0x44,0x78,0x08,0x10,0x14,0x22,0x7e,0x02,
+0x20,0x20,0x40,0xfe,0x20,0x20,0x40,0x48,0x88,0xf0,0x10,0x20,0x28,0x44,0xfc,0x04,
+/* 20858 0x517a "兺" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x00,0x44,0x58,0x60,0x42,0x42,0x3e,
+/* 20859 0x517b "养" */
+0x08,0x04,0x00,0x7f,0x01,0x3f,0x02,0xff,0x04,0x08,0x34,0xc4,0x04,0x04,0x08,0x10,
+0x20,0x40,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x58,0x46,0x40,0x40,0x40,0x40,
+/* 20860 0x517c "兼" */
+0x10,0x08,0x7f,0x04,0x04,0x3f,0x04,0xff,0x04,0x3f,0x0c,0x14,0x24,0xc4,0x04,0x04,
+0x20,0x40,0xfc,0x80,0x80,0xf0,0x90,0xfe,0x90,0xf0,0xc0,0xa0,0x98,0x86,0x80,0x80,
+/* 20861 0x517d "兽" */
+0x08,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 20862 0x517e "兾" */
+0x08,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x08,0x7f,0x08,0x08,0xff,0x08,0x10,0x20,
+0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x20,0xfc,0x20,0x20,0xfe,0x20,0x10,0x08,
+/* 20863 0x517f "兿" */
+0x08,0x04,0xff,0x08,0x3e,0x08,0x3e,0x08,0x38,0x00,0x1f,0x00,0x7f,0x04,0x08,0x1f,
+0x10,0x20,0xfe,0x20,0xf8,0x28,0xaa,0x66,0x92,0x00,0xf0,0x00,0xfc,0x00,0x10,0xf8,
+/* 20864 0x5180 "冀" */
+0x04,0x7c,0x04,0x1c,0xe4,0x3f,0x21,0x3f,0x21,0x3f,0x04,0x3f,0x04,0xff,0x10,0x20,
+0x44,0x78,0x42,0x3e,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xf8,0x40,0xfe,0x10,0x08,
+/* 20865 0x5181 "冁" */
+0x44,0x25,0x29,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x11,0x11,0xfd,0x12,0x12,0x14,
+0x00,0xfe,0x02,0x02,0xfe,0x24,0x24,0x7e,0x24,0x24,0xfe,0x52,0x54,0x48,0x64,0x42,
+/* 20866 0x5182 "冂" */
+0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20867 0x5183 "冃" */
+0x00,0x7f,0x40,0x40,0x40,0x5f,0x40,0x40,0x40,0x5f,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20868 0x5184 "冄" */
+0x00,0x3f,0x20,0x20,0x20,0xff,0x20,0x20,0x20,0xff,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0xf8,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 20869 0x5185 "内" */
+0x01,0x01,0x01,0x7f,0x41,0x41,0x41,0x42,0x42,0x44,0x48,0x50,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x84,0x44,0x24,0x14,0x14,0x04,0x04,0x14,0x08,
+/* 20870 0x5186 "円" */
+0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20871 0x5187 "冇" */
+0x02,0x02,0xff,0x04,0x04,0x0f,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 20872 0x5188 "冈" */
+0x00,0x7f,0x40,0x40,0x40,0x48,0x44,0x42,0x41,0x42,0x44,0x48,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x24,0x44,0x84,0x04,0x84,0x44,0x24,0x04,0x04,0x14,0x08,
+/* 20873 0x5189 "冉" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x21,0xff,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x28,0x10,
+/* 20874 0x518a "冊" */
+0x00,0x3f,0x24,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x20,0x20,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 20875 0x518b "冋" */
+0x00,0x7f,0x40,0x40,0x40,0x47,0x44,0x44,0x44,0x44,0x47,0x44,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xc4,0x44,0x44,0x44,0x44,0xc4,0x44,0x04,0x04,0x14,0x08,
+/* 20876 0x518c "册" */
+0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x12,0x12,0x26,0x41,
+0x00,0x78,0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x48,0x88,0xa8,0x10,
+/* 20877 0x518d "再" */
+0x00,0xff,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0xff,0x20,0x20,0x20,0x20,0x20,
+0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x08,0x08,0x08,0x28,0x10,
+/* 20878 0x518e "冎" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xf0,0x10,0x10,0x90,0x90,0x90,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 20879 0x518f "冏" */
+0x00,0x7f,0x40,0x44,0x48,0x50,0x67,0x44,0x44,0x44,0x44,0x47,0x44,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x44,0x24,0x14,0xcc,0x44,0x44,0x44,0x44,0xc4,0x44,0x04,0x14,0x08,
+/* 20880 0x5190 "冐" */
+0x00,0x3f,0x20,0x2f,0x20,0x2f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xe8,0x08,0xe8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 20881 0x5191 "冑" */
+0x01,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x1f,0x10,0x17,0x10,0x17,0x10,0x10,0x10,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xd0,0x10,0xd0,0x10,0x50,0x20,
+/* 20882 0x5192 "冒" */
+0x00,0x3f,0x20,0x2f,0x20,0x2f,0x20,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xf8,0x08,0xe8,0x08,0xe8,0x08,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 20883 0x5193 "冓" */
+0x08,0x08,0x7f,0x08,0x3f,0x08,0xff,0x01,0x3f,0x21,0x3f,0x21,0xff,0x20,0x20,0x20,
+0x20,0x20,0xfc,0x20,0xf8,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x08,0x28,0x10,
+/* 20884 0x5194 "冔" */
+0x00,0x3f,0x20,0x2f,0x20,0x2f,0x00,0x7d,0x44,0x44,0x47,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xf8,0x08,0xe8,0x08,0xe8,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 20885 0x5195 "冕" */
+0x7f,0x40,0x5f,0x40,0x5f,0x04,0x0f,0x10,0x3f,0x51,0x11,0x1f,0x02,0x04,0x18,0x60,
+0xfc,0x04,0xf4,0x04,0xf4,0x00,0xe0,0x20,0xf8,0x08,0x08,0xf8,0x80,0x82,0x82,0x7e,
+/* 20886 0x5196 "冖" */
+0x00,0x7f,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20887 0x5197 "冗" */
+0x00,0x00,0x7f,0x40,0x80,0x00,0x0f,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xc0,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 20888 0x5198 "冘" */
+0x01,0x01,0x01,0x3f,0x21,0x41,0x01,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x08,0x00,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x7c,0x00,
+/* 20889 0x5199 "写" */
+0x00,0x7f,0x40,0x90,0x10,0x1f,0x10,0x20,0x3f,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0xc8,0x08,0x08,0x50,0x20,
+/* 20890 0x519a "冚" */
+0x00,0x00,0x7f,0x40,0x81,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20891 0x519b "军" */
+0x00,0x7f,0x40,0x82,0x02,0x3f,0x04,0x09,0x11,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 20892 0x519c "农" */
+0x01,0x01,0x01,0x7f,0x42,0x82,0x05,0x05,0x08,0x18,0x28,0x48,0x88,0x0a,0x0c,0x08,
+0x00,0x00,0x00,0xfc,0x04,0x08,0x00,0x08,0x90,0xa0,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 20893 0x519d "冝" */
+0x00,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0xff,0x00,
+0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x10,0xfe,0x00,
+/* 20894 0x519e "冞" */
+0x00,0x7f,0x40,0x81,0x11,0x09,0x05,0x01,0x7f,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0xfe,0x02,0x04,0x10,0x20,0x40,0x00,0xfc,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 20895 0x519f "冟" */
+0x00,0x7f,0x41,0x82,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x10,0x1f,0x10,0x10,0x0f,0x00,
+0x00,0xfe,0x02,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x00,0x04,0x04,0xfc,0x00,
+/* 20896 0x51a0 "冠" */
+0x00,0x7f,0x40,0x80,0x3e,0x00,0x00,0x7e,0x14,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x00,0xfe,0x02,0x04,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x2a,0x12,0x02,0xfe,0x00,
+/* 20897 0x51a1 "冡" */
+0x00,0x7f,0x40,0x9f,0x00,0x7f,0x02,0x0d,0x71,0x02,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0xfe,0x02,0xf4,0x00,0xfc,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 20898 0x51a2 "冢" */
+0x00,0x7f,0x40,0x80,0x7f,0x02,0x06,0x19,0x6a,0x04,0x1b,0x62,0x0c,0x30,0xc2,0x01,
+0x00,0xfe,0x02,0x04,0xfc,0x00,0x08,0x10,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x80,0x00,
+/* 20899 0x51a3 "冣" */
+0x00,0x7f,0x40,0x80,0x7f,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x27,0xfa,0x42,0x02,
+0x00,0xfe,0x02,0x04,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x90,0x28,0x44,0x82,
+/* 20900 0x51a4 "冤" */
+0x00,0x7f,0x40,0x88,0x0f,0x10,0x20,0x5f,0x11,0x11,0x1f,0x02,0x04,0x08,0x10,0x60,
+0x00,0xfe,0x02,0x04,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x80,0xa0,0x92,0x82,0x7e,
+/* 20901 0x51a5 "冥" */
+0x00,0x7f,0x40,0x80,0x1f,0x10,0x1f,0x10,0x1f,0x12,0x01,0xff,0x00,0x08,0x10,0x20,
+0x00,0xfe,0x02,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x00,0xfe,0x00,0x20,0x10,0x08,
+/* 20902 0x51a6 "冦" */
+0x00,0x00,0x7f,0x40,0x80,0x3e,0x00,0x00,0x7e,0x14,0x14,0x14,0x14,0x24,0x24,0x43,
+0x00,0x00,0xfe,0x02,0x24,0x38,0x20,0x20,0xf8,0x08,0x50,0x20,0x54,0x84,0x04,0xfc,
+/* 20903 0x51a7 "冧" */
+0x00,0x7f,0x40,0x80,0x08,0x08,0x08,0x7e,0x08,0x1c,0x1a,0x2a,0x48,0x89,0x08,0x08,
+0x00,0xfe,0x02,0x04,0x20,0x20,0x20,0xfc,0x20,0x30,0x70,0x68,0xa4,0x22,0x20,0x20,
+/* 20904 0x51a8 "冨" */
+0x00,0x7f,0x40,0x80,0x3f,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 20905 0x51a9 "冩" */
+0x00,0x7f,0x40,0x82,0x1c,0x10,0x1e,0x10,0x1f,0x08,0x1f,0x20,0x49,0x24,0x24,0x40,
+0x00,0xfe,0x02,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x24,0x94,0x94,0x08,
+/* 20906 0x51aa "冪" */
+0xff,0x84,0x3f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x09,0x3f,0xd1,0x11,0x01,
+0xfe,0x42,0xf8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x20,0xf8,0x16,0x30,0x00,
+/* 20907 0x51ab "冫" */
+0x00,0x40,0x20,0x20,0x00,0x08,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 20908 0x51ac "冬" */
+0x04,0x04,0x0f,0x10,0x28,0x44,0x03,0x0c,0x30,0xc0,0x07,0x00,0x00,0x0e,0x01,0x00,
+0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x60,0x18,0x06,0x00,0xc0,0x20,0x00,0x80,0x40,
+/* 20909 0x51ad "冭" */
+0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x10,0x26,0xc1,0x00,0x00,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0x86,0x40,0x00,0x00,0x00,0xc0,0x20,
+/* 20910 0x51ae "冮" */
+0x00,0x40,0x27,0x20,0x00,0x08,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x2f,0x20,0x00,
+0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,0x00,
+/* 20911 0x51af "冯" */
+0x00,0x47,0x20,0x20,0x02,0x0a,0x0a,0x13,0x10,0xe0,0x20,0x27,0x20,0x20,0x20,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 20912 0x51b0 "冰" */
+0x00,0x40,0x20,0x20,0x00,0x07,0x11,0x11,0x21,0xe2,0x22,0x24,0x28,0x20,0x21,0x00,
+0x40,0x40,0x40,0x44,0x68,0x70,0x60,0x50,0x50,0x48,0x48,0x44,0x42,0x40,0x40,0x80,
+/* 20913 0x51b1 "冱" */
+0x00,0x47,0x20,0x20,0x00,0x08,0x09,0x11,0x11,0x22,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x10,0x10,0x10,0xfe,0x00,
+/* 20914 0x51b2 "冲" */
+0x00,0x40,0x20,0x20,0x07,0x04,0x14,0x14,0x24,0xe4,0x27,0x24,0x20,0x20,0x20,0x00,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x40,
+/* 20915 0x51b3 "决" */
+0x00,0x40,0x20,0x27,0x00,0x00,0x10,0x10,0x2f,0xe0,0x21,0x21,0x22,0x24,0x28,0x10,
+0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x88,0xfe,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 20916 0x51b4 "冴" */
+0x00,0x43,0x20,0x21,0x01,0x09,0x0a,0x13,0x10,0xe0,0x20,0x21,0x22,0x24,0x20,0x00,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 20917 0x51b5 "况" */
+0x00,0x47,0x24,0x24,0x04,0x04,0x17,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x28,0x10,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 20918 0x51b6 "冶" */
+0x00,0x40,0x20,0x21,0x02,0x07,0x10,0x10,0x23,0xe2,0x22,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20919 0x51b7 "冷" */
+0x00,0x40,0x20,0x20,0x01,0x02,0x14,0x10,0x23,0xe0,0x20,0x21,0x20,0x20,0x20,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 20920 0x51b8 "冸" */
+0x00,0x42,0x21,0x21,0x00,0x07,0x10,0x10,0x20,0xef,0x20,0x20,0x20,0x20,0x20,0x00,
+0x40,0x44,0x48,0x50,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 20921 0x51b9 "冹" */
+0x00,0x40,0x20,0x20,0x07,0x00,0x11,0x11,0x21,0xe2,0x22,0x24,0x24,0x28,0x20,0x03,
+0x90,0x88,0x88,0x80,0xfe,0x80,0x00,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 20922 0x51ba "冺" */
+0x00,0x43,0x22,0x22,0x02,0x0b,0x0a,0x12,0x13,0xe2,0x22,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 20923 0x51bb "冻" */
+0x00,0x40,0x20,0x27,0x00,0x09,0x09,0x12,0x13,0xe0,0x21,0x21,0x22,0x24,0x20,0x00,
+0x40,0x40,0x40,0xfe,0x80,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 20924 0x51bc "冼" */
+0x00,0x42,0x22,0x23,0x04,0x00,0x10,0x17,0x21,0xe1,0x21,0x21,0x22,0x22,0x24,0x08,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 20925 0x51bd "冽" */
+0x00,0x40,0x2f,0x22,0x02,0x03,0x12,0x14,0x26,0xe5,0x29,0x21,0x22,0x22,0x24,0x08,
+0x04,0x04,0xc4,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 20926 0x51be "冾" */
+0x00,0x40,0x20,0x21,0x02,0x14,0x13,0x10,0x20,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20927 0x51bf "冿" */
+0x00,0x40,0x23,0x20,0x07,0x00,0x13,0x10,0x20,0xe7,0x20,0x20,0x2f,0x20,0x20,0x00,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,
+/* 20928 0x51c0 "净" */
+0x01,0x41,0x23,0x24,0x00,0x17,0x10,0x10,0x2f,0x20,0xe0,0x27,0x20,0x20,0x21,0x00,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x80,
+/* 20929 0x51c1 "凁" */
+0x00,0x40,0x2f,0x20,0x00,0x07,0x14,0x14,0x27,0xe0,0x20,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 20930 0x51c2 "凂" */
+0x01,0x41,0x21,0x22,0x02,0x07,0x1a,0x12,0x22,0xe3,0x22,0x20,0x21,0x22,0x24,0x08,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0x44,0xfc,0xa4,0xa0,0x20,0x22,0x22,0x1e,
+/* 20931 0x51c3 "凃" */
+0x00,0x40,0x20,0x21,0x02,0x05,0x10,0x10,0x27,0xe0,0x22,0x22,0x24,0x28,0x21,0x00,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 20932 0x51c4 "凄" */
+0x00,0x40,0x27,0x20,0x03,0x00,0x17,0x10,0x23,0xe0,0x27,0x21,0x23,0x20,0x21,0x06,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x80,0xfe,0x08,0x90,0x60,0x98,0x04,
+/* 20933 0x51c5 "凅" */
+0x00,0x47,0x24,0x24,0x07,0x04,0x14,0x15,0x25,0xe5,0x25,0x25,0x25,0x24,0x27,0x04,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0xfc,0x04,
+/* 20934 0x51c6 "准" */
+0x01,0x41,0x21,0x23,0x02,0x16,0x1b,0x12,0x22,0x23,0xe2,0x22,0x22,0x23,0x22,0x02,
+0x40,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 20935 0x51c7 "凇" */
+0x02,0x42,0x22,0x22,0x0f,0x02,0x12,0x16,0x27,0xea,0x2a,0x32,0x22,0x22,0x22,0x02,
+0x08,0x28,0x28,0x28,0xa4,0x44,0x54,0x92,0x10,0xa0,0x20,0x28,0x44,0xfc,0x44,0x00,
+/* 20936 0x51c8 "凈" */
+0x00,0x47,0x22,0x21,0x00,0x0b,0x08,0x10,0x17,0xe0,0x20,0x23,0x20,0x20,0x21,0x00,
+0x3c,0xc0,0x44,0x28,0x00,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x48,0x40,0x40,0x80,
+/* 20937 0x51c9 "凉" */
+0x00,0x40,0x2f,0x20,0x00,0x03,0x12,0x12,0x23,0xe0,0x22,0x22,0x24,0x28,0x21,0x00,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 20938 0x51ca "凊" */
+0x00,0x40,0x27,0x20,0x03,0x10,0x17,0x10,0x23,0x22,0xe3,0x22,0x23,0x22,0x22,0x02,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 20939 0x51cb "凋" */
+0x00,0x47,0x24,0x24,0x05,0x04,0x14,0x17,0x24,0xe5,0x25,0x25,0x25,0x24,0x24,0x08,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 20940 0x51cc "凌" */
+0x00,0x40,0x23,0x20,0x00,0x07,0x11,0x12,0x24,0xe1,0x23,0x24,0x20,0x20,0x23,0x0c,
+0x40,0x40,0xf8,0x40,0x40,0xfe,0x10,0x88,0x84,0xf0,0x10,0xa0,0x40,0xa0,0x10,0x0c,
+/* 20941 0x51cd "凍" */
+0x00,0x40,0x27,0x20,0x03,0x0a,0x0b,0x12,0x13,0xe0,0x20,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 20942 0x51ce "凎" */
+0x00,0x40,0x20,0x21,0x02,0x04,0x11,0x10,0x20,0xe3,0x20,0x22,0x21,0x21,0x2f,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x40,0x40,0xf8,0x40,0x48,0x48,0x50,0xfe,0x00,
+/* 20943 0x51cf "减" */
+0x00,0x40,0x20,0x27,0x04,0x04,0x15,0x14,0x24,0xe5,0x25,0x25,0x25,0x24,0x28,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 20944 0x51d0 "凐" */
+0x00,0x47,0x20,0x20,0x07,0x04,0x14,0x14,0x27,0xe0,0x20,0x27,0x20,0x20,0x2f,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 20945 0x51d1 "凑" */
+0x00,0x40,0x27,0x20,0x03,0x00,0x17,0x11,0x22,0xe5,0x20,0x23,0x20,0x20,0x21,0x06,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x40,0xf8,0x40,0xa0,0x10,0x08,
+/* 20946 0x51d2 "凒" */
+0x00,0x42,0x22,0x22,0x03,0x00,0x17,0x10,0x23,0xe2,0x22,0x23,0x21,0x20,0x27,0x00,
+0x40,0x48,0x48,0x48,0xf8,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x10,0xa0,0xfe,0x00,
+/* 20947 0x51d3 "凓" */
+0x00,0x47,0x20,0x20,0x07,0x04,0x14,0x17,0x20,0xe0,0x27,0x20,0x21,0x22,0x2c,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 20948 0x51d4 "凔" */
+0x00,0x40,0x20,0x21,0x02,0x17,0x1a,0x13,0x22,0x23,0xe2,0x23,0x25,0x25,0x29,0x01,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 20949 0x51d5 "凕" */
+0x00,0x47,0x24,0x20,0x03,0x0a,0x0b,0x12,0x13,0xe0,0x20,0x27,0x20,0x21,0x22,0x04,
+0x00,0xfc,0x04,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x40,0xfc,0x00,0x10,0x08,0x04,
+/* 20950 0x51d6 "凖" */
+0x41,0x21,0x03,0x0a,0x17,0xea,0x23,0x22,0x23,0x02,0x01,0xff,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 20951 0x51d7 "凗" */
+0x00,0x44,0x27,0x21,0x01,0x03,0x12,0x16,0x2b,0xe2,0x22,0x23,0x22,0x22,0x23,0x02,
+0x40,0x44,0xfc,0x20,0x10,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 20952 0x51d8 "凘" */
+0x04,0x44,0x24,0x2f,0x04,0x07,0x14,0x17,0x24,0xe4,0x2f,0x20,0x25,0x28,0x30,0x00,
+0x80,0x82,0x9c,0xd0,0x90,0x90,0x9e,0x94,0x94,0x94,0xd4,0x14,0x14,0xa4,0x24,0x44,
+/* 20953 0x51d9 "凙" */
+0x00,0x47,0x24,0x27,0x00,0x03,0x10,0x17,0x21,0xe0,0x23,0x20,0x2f,0x20,0x20,0x00,
+0x00,0xfc,0xa4,0xfc,0x40,0xf8,0x40,0xfc,0x10,0xa0,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 20954 0x51da "凚" */
+0x01,0x41,0x27,0x21,0x03,0x05,0x19,0x10,0x23,0xe0,0x27,0x20,0x22,0x24,0x29,0x00,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 20955 0x51db "凛" */
+0x00,0x4f,0x20,0x27,0x04,0x05,0x15,0x15,0x24,0xe7,0x20,0x23,0x20,0x2f,0x22,0x04,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x00,0xf8,0x00,0xfe,0x48,0xc4,
+/* 20956 0x51dc "凜" */
+0x00,0x4f,0x20,0x27,0x04,0x05,0x15,0x15,0x24,0xe7,0x20,0x23,0x20,0x2f,0x21,0x0e,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 20957 0x51dd "凝" */
+0x04,0x45,0x26,0x24,0x03,0x10,0x14,0x17,0x2a,0x22,0xef,0x22,0x25,0x24,0x28,0x01,
+0x00,0x7c,0x04,0xa8,0x90,0x7c,0x14,0x94,0x50,0x50,0xdc,0x50,0x50,0xb0,0x9e,0x00,
+/* 20958 0x51de "凞" */
+0x08,0x8b,0x4a,0x4a,0x0b,0x2a,0x2a,0x2b,0x4a,0xca,0x4b,0x50,0x40,0x45,0x44,0x08,
+0x00,0xde,0x92,0x92,0xd2,0x5e,0x50,0xd0,0x92,0x92,0xce,0x00,0x00,0x24,0x92,0x92,
+/* 20959 0x51df "凟" */
+0x00,0x4f,0x20,0x27,0x00,0x07,0x14,0x17,0x22,0xe3,0x22,0x23,0x22,0x23,0x21,0x02,
+0x40,0xfe,0x40,0xfc,0x00,0xfc,0xa4,0xfc,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 20960 0x51e0 "几" */
+0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20961 0x51e1 "凡" */
+0x00,0x0f,0x08,0x08,0x08,0x0a,0x09,0x08,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20962 0x51e2 "凢" */
+0x02,0x02,0x04,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20963 0x51e3 "凣" */
+0x02,0x02,0x02,0x02,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 20964 0x51e4 "凤" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x40,0x40,0x80,
+0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0x88,0x88,0x08,0x88,0x4a,0x4a,0x0a,0x06,0x02,
+/* 20965 0x51e5 "凥" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x23,0x22,0x22,0x22,0x22,0x24,0x44,0x48,0x90,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,
+/* 20966 0x51e6 "処" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x94,0x14,0x08,0x09,0x14,0x23,0x40,0x80,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x94,0x94,0x94,0x0c,0x00,0x00,0xfe,0x00,
+/* 20967 0x51e7 "凧" */
+0x00,0x3f,0x20,0x21,0x21,0x21,0x2f,0x29,0x29,0x29,0x29,0x29,0x21,0x41,0x41,0x80,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xe8,0x28,0x28,0x28,0xa8,0x4a,0x0a,0x0a,0x06,0x02,
+/* 20968 0x51e8 "凨" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x22,0x24,0x28,0x3f,0x28,0x40,0x40,0x80,
+0x00,0xf8,0x08,0x08,0xc8,0x08,0x08,0xe8,0x08,0x88,0x48,0xea,0x2a,0x0a,0x06,0x02,
+/* 20969 0x51e9 "凩" */
+0x00,0x3f,0x20,0x21,0x21,0x21,0x2f,0x21,0x23,0x23,0x25,0x25,0x29,0x51,0x41,0x80,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xe8,0x08,0x88,0x48,0x28,0x2a,0x0a,0x0a,0x06,0x02,
+/* 20970 0x51ea "凪" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x5f,0x40,0x80,
+0x00,0xf8,0x08,0x88,0x88,0x88,0x88,0x88,0xe8,0x88,0x88,0x8a,0x8a,0xfa,0x06,0x02,
+/* 20971 0x51eb "凫" */
+0x02,0x04,0x3f,0x20,0x24,0x22,0x20,0x3f,0x00,0x1f,0x10,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0xe0,0x20,0x20,0xa0,0x40,0xf8,0x08,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 20972 0x51ec "凬" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x47,0x44,0x80,
+0x00,0xf8,0x08,0x08,0xe8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x4a,0x4a,0xca,0x46,0x02,
+/* 20973 0x51ed "凭" */
+0x08,0x0b,0x10,0x30,0x57,0x90,0x10,0x10,0x13,0x00,0x0f,0x08,0x08,0x10,0x20,0xc0,
+0x38,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,
+/* 20974 0x51ee "凮" */
+0x00,0x3f,0x20,0x20,0x2f,0x21,0x22,0x27,0x24,0x24,0x27,0x24,0x24,0x47,0x44,0x80,
+0x00,0xf8,0x08,0x08,0xe8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x4a,0x4a,0xca,0x46,0x02,
+/* 20975 0x51ef "凯" */
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x02,0x02,0x7e,0x40,0x40,0x46,0x59,0x61,0x02,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 20976 0x51f0 "凰" */
+0x00,0x3f,0x22,0x27,0x24,0x27,0x24,0x27,0x20,0x2f,0x21,0x27,0x21,0x4f,0x40,0x80,
+0x00,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xc8,0x08,0xe8,0x08,0xca,0x0a,0xea,0x06,0x02,
+/* 20977 0x51f1 "凱" */
+0x08,0x49,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x42,0x24,0x0f,0xf0,0x41,
+0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x06,
+/* 20978 0x51f2 "凲" */
+0x00,0x3f,0x24,0x22,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x22,0x26,0x4a,0x52,0x82,
+0x00,0xf8,0x48,0x88,0xf8,0x88,0xe8,0xa8,0xf8,0xa8,0xe8,0x8a,0xca,0xaa,0x96,0x82,
+/* 20979 0x51f3 "凳" */
+0x00,0x7e,0x04,0x2b,0x10,0x2f,0xc8,0x0f,0x04,0x7f,0x00,0x0f,0x08,0x08,0x10,0x60,
+0x90,0xa0,0x44,0xa8,0x10,0xe8,0x26,0xe0,0x40,0xfc,0x00,0xe0,0x20,0x22,0x22,0x1e,
+/* 20980 0x51f4 "凴" */
+0x00,0x43,0x22,0x0b,0x0a,0x13,0x22,0xe3,0x20,0x25,0x20,0x0f,0x08,0x08,0x10,0x60,
+0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0x08,0xe0,0x20,0x22,0x22,0x1e,
+/* 20981 0x51f5 "凵" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20982 0x51f6 "凶" */
+0x00,0x00,0x10,0x08,0x44,0x42,0x41,0x42,0x44,0x48,0x50,0x60,0x40,0x40,0x7f,0x00,
+0x00,0x10,0x10,0x20,0x44,0x84,0x04,0x84,0x44,0x24,0x14,0x14,0x04,0x04,0xfc,0x04,
+/* 20983 0x51f7 "凷" */
+0x01,0x01,0x01,0x01,0x4f,0x41,0x41,0x41,0x41,0x41,0x5f,0x40,0x40,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0xe4,0x04,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0xfc,0x04,
+/* 20984 0x51f8 "凸" */
+0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x78,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x40,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20985 0x51f9 "凹" */
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x47,0x40,0x40,0x40,0x40,0x7f,0x40,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0xc4,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20986 0x51fa "出" */
+0x01,0x01,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x41,0x41,0x41,0x41,0x7f,0x00,
+0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 20987 0x51fb "击" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 20988 0x51fc "凼" */
+0x01,0x01,0x01,0x01,0x5d,0x45,0x45,0x49,0x49,0x51,0x61,0x45,0x42,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x10,0x24,0x44,0x84,0x44,0x24,0x14,0x14,0x04,0x04,0x04,0xfc,0x04,
+/* 20989 0x51fd "函" */
+0x00,0x3f,0x00,0x00,0x51,0x49,0x45,0x41,0x45,0x49,0x51,0x45,0x42,0x40,0x7f,0x00,
+0x00,0xf0,0x20,0x40,0x94,0x24,0x44,0x04,0x44,0x24,0x14,0x04,0x04,0x04,0xfc,0x04,
+/* 20990 0x51fe "凾" */
+0x00,0x3f,0x00,0x00,0x41,0x5d,0x55,0x55,0x55,0x5d,0x41,0x45,0x42,0x40,0x7f,0x00,
+0x00,0xf0,0x20,0x40,0x84,0x74,0x94,0x54,0x24,0x54,0x94,0x04,0x04,0x04,0xfc,0x04,
+/* 20991 0x51ff "凿" */
+0x04,0x24,0x14,0x04,0xff,0x00,0x04,0x22,0x2f,0x21,0x21,0x2f,0x21,0x21,0x3f,0x00,
+0x40,0x48,0x50,0x40,0xfe,0x00,0x40,0x88,0xe8,0x08,0x08,0xe8,0x08,0x08,0xf8,0x08,
+/* 20992 0x5200 "刀" */
+0x00,0x00,0x3f,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 20993 0x5201 "刁" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x60,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x48,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 20994 0x5202 "刂" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x04,0x14,0x08,
+/* 20995 0x5203 "刃" */
+0x00,0x3f,0x02,0x02,0x02,0x22,0x22,0x22,0x42,0x02,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 20996 0x5204 "刄" */
+0x00,0x7f,0x04,0x04,0x24,0x14,0x0c,0x04,0x06,0x05,0x08,0x08,0x10,0x10,0x20,0xc0,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x70,0x1e,0x10,0x10,0xa0,0x40,
+/* 20997 0x5205 "刅" */
+0x00,0x7f,0x04,0x04,0x04,0x04,0x24,0x24,0x44,0x84,0x08,0x08,0x10,0x10,0x21,0xc0,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x28,0x24,0x22,0x22,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 20998 0x5206 "分" */
+0x00,0x04,0x04,0x08,0x10,0x20,0x40,0x9f,0x04,0x04,0x04,0x08,0x08,0x10,0x21,0x40,
+0x40,0x40,0x20,0x20,0x10,0x08,0x04,0xe2,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 20999 0x5207 "切" */
+0x10,0x10,0x11,0x10,0x10,0x1e,0xf0,0x10,0x10,0x12,0x14,0x18,0x10,0x01,0x02,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 21000 0x5208 "刈" */
+0x00,0x01,0x01,0x21,0x11,0x0a,0x0a,0x04,0x04,0x0a,0x0a,0x11,0x21,0x40,0x80,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21001 0x5209 "刉" */
+0x10,0x10,0x20,0x3f,0x40,0x80,0x3f,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x3f,0x00,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x84,0x84,0x94,0x08,
+/* 21002 0x520a "刊" */
+0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21003 0x520b "刋" */
+0x00,0x07,0x78,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21004 0x520c "刌" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x44,0x24,0x24,0x04,0x04,0x04,0x14,0x08,
+0x04,0x04,0x04,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21005 0x520d "刍" */
+0x04,0x04,0x0f,0x10,0x20,0x40,0xbf,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x3f,0x00,
+0x00,0x00,0xf0,0x10,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21006 0x520e "刎" */
+0x20,0x20,0x20,0x3f,0x54,0x94,0x14,0x24,0x24,0x48,0x88,0x10,0x20,0x40,0x85,0x02,
+0x04,0x04,0x04,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x14,0x08,
+/* 21007 0x520f "刏" */
+0x20,0x20,0x3f,0x40,0x80,0x3f,0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xd4,0x48,
+/* 21008 0x5210 "刐" */
+0x00,0x3f,0x21,0x21,0x29,0x25,0x25,0x21,0xff,0x21,0x21,0x21,0x21,0x41,0x45,0x82,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21009 0x5211 "刑" */
+0x00,0x7f,0x12,0x12,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x82,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21010 0x5212 "划" */
+0x10,0x14,0x12,0x10,0x13,0xfc,0x10,0x11,0x11,0x12,0x0c,0x08,0x14,0x22,0xc1,0x00,
+0x04,0x04,0x04,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x84,0x84,0x94,0x88,
+/* 21011 0x5213 "刓" */
+0x00,0x3f,0x00,0x00,0x00,0xff,0x12,0x12,0x12,0x12,0x12,0x22,0x23,0x42,0x80,0x00,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0xa4,0x04,0x04,0x14,0x08,
+/* 21012 0x5214 "刔" */
+0x08,0x08,0x08,0x7f,0x09,0x09,0x09,0x09,0xff,0x08,0x08,0x14,0x12,0x21,0x41,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21013 0x5215 "刕" */
+0x00,0x3f,0x02,0x02,0x04,0x08,0x30,0x00,0x7e,0x12,0x12,0x12,0x22,0x22,0x4a,0x85,
+0x00,0xf8,0x08,0x08,0x08,0x50,0x20,0x00,0xfc,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21014 0x5216 "刖" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x41,0x45,0x82,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21015 0x5217 "列" */
+0x00,0x7f,0x08,0x08,0x1f,0x11,0x21,0x21,0x52,0x8a,0x04,0x04,0x08,0x10,0x20,0x40,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21016 0x5218 "刘" */
+0x10,0x08,0x08,0xff,0x02,0x42,0x22,0x14,0x14,0x08,0x08,0x14,0x24,0x42,0x82,0x00,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21017 0x5219 "则" */
+0x00,0x7f,0x41,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x14,0x12,0x21,0x40,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x94,0x88,
+/* 21018 0x521a "刚" */
+0x00,0x7f,0x41,0x41,0x65,0x55,0x55,0x49,0x49,0x55,0x55,0x65,0x41,0x41,0x45,0x42,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21019 0x521b "创" */
+0x08,0x08,0x14,0x12,0x21,0x40,0xbe,0x22,0x22,0x22,0x2a,0x24,0x20,0x20,0x1f,0x00,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x84,0x84,0x94,0x08,
+/* 21020 0x521c "刜" */
+0x12,0x12,0x12,0x7f,0x12,0x12,0x7f,0x52,0x52,0x7f,0x12,0x12,0x23,0x22,0x42,0x82,
+0x02,0x02,0x02,0x82,0x92,0x92,0x92,0x12,0x12,0xd2,0x52,0x52,0x42,0x82,0x0a,0x04,
+/* 21021 0x521d "初" */
+0x20,0x10,0x01,0xfc,0x08,0x10,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 21022 0x521e "刞" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x21,0x21,0x27,0xf8,0x40,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x84,0x04,0x14,0x08,
+/* 21023 0x521f "刟" */
+0x00,0x7f,0x11,0x11,0x21,0x25,0x42,0x80,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21024 0x5220 "删" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x4a,0xff,0x4a,0x4a,0x4a,0x4a,0x4a,0x5a,0x85,0x08,
+0x02,0xc2,0x42,0x4a,0x4a,0x4a,0x4a,0xea,0x4a,0x4a,0x4a,0x4a,0x42,0x42,0x4a,0x84,
+/* 21025 0x5221 "刡" */
+0x00,0x7f,0x40,0x40,0x40,0x7f,0x44,0x44,0x7f,0x44,0x44,0x42,0x42,0x51,0x60,0x40,
+0x02,0x82,0x82,0x82,0x92,0x92,0x12,0x12,0xd2,0x12,0x12,0x12,0x42,0x42,0xca,0x44,
+/* 21026 0x5222 "刢" */
+0x08,0x08,0x14,0x12,0x21,0x48,0x84,0x04,0x7f,0x01,0x22,0x14,0x08,0x04,0x04,0x00,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21027 0x5223 "刣" */
+0x08,0x08,0x08,0x10,0x12,0x21,0x7f,0x20,0x00,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21028 0x5224 "判" */
+0x04,0x44,0x24,0x25,0x04,0x7f,0x04,0x04,0x04,0xff,0x04,0x08,0x08,0x10,0x20,0x40,
+0x04,0x84,0x84,0x24,0x24,0xa4,0x24,0x24,0x24,0xe4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21029 0x5225 "別" */
+0x00,0x7f,0x41,0x41,0x41,0x7f,0x00,0x10,0x10,0x1f,0x11,0x11,0x21,0x21,0x4a,0x84,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21030 0x5226 "刦" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x08,0x10,0x10,0x22,0x41,0xff,0x40,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x84,0x94,0x08,
+/* 21031 0x5227 "刧" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x10,0x10,0x24,0x42,0xff,0x41,0x00,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21032 0x5228 "刨" */
+0x10,0x10,0x3f,0x21,0x41,0xbd,0x25,0x25,0x3d,0x21,0x25,0x22,0x20,0x20,0x1f,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x84,0x84,0x94,0x08,
+/* 21033 0x5229 "利" */
+0x01,0x07,0x7c,0x04,0x04,0x04,0xff,0x0c,0x16,0x15,0x24,0x24,0x44,0x84,0x04,0x04,
+0x04,0x84,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0xa4,0x24,0x04,0x04,0x14,0x08,
+/* 21034 0x522a "刪" */
+0x00,0x7f,0x55,0x55,0x55,0x55,0x55,0xff,0x55,0x55,0x55,0x55,0x55,0x51,0x45,0x42,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21035 0x522b "别" */
+0x00,0x7f,0x41,0x41,0x41,0x7f,0x10,0x10,0xff,0x11,0x11,0x11,0x21,0x21,0x4a,0x84,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21036 0x522c "刬" */
+0x14,0x12,0x10,0x17,0x78,0x10,0x17,0xf8,0x11,0x12,0x0c,0x08,0x14,0x22,0xc1,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0xa4,0x84,0x84,0x94,0x88,
+/* 21037 0x522d "刭" */
+0x00,0x7f,0x02,0x04,0x0c,0x12,0x21,0xc0,0x00,0x7f,0x08,0x08,0x08,0x0f,0xf0,0x40,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21038 0x522e "刮" */
+0x02,0x0f,0x78,0x08,0x08,0xff,0x08,0x08,0x08,0x7f,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21039 0x522f "刯" */
+0x00,0x7f,0x00,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x00,0x07,0xf8,0x40,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21040 0x5230 "到" */
+0x00,0xff,0x08,0x10,0x22,0x41,0xff,0x08,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf8,0x40,
+0x04,0x84,0x04,0x24,0x24,0x24,0xa4,0xa4,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21041 0x5231 "刱" */
+0x24,0x24,0x25,0x24,0x7e,0x24,0x25,0x25,0xfe,0x24,0x24,0x24,0x24,0x44,0x44,0x85,
+0x00,0x00,0xf8,0x48,0x48,0x48,0x4c,0x4a,0x4a,0x48,0x48,0x48,0x48,0x88,0xa8,0x10,
+/* 21042 0x5232 "刲" */
+0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21043 0x5233 "刳" */
+0x08,0x08,0xff,0x14,0x22,0x41,0xbe,0x00,0xff,0x10,0x20,0x7f,0x01,0x01,0x0a,0x04,
+0x04,0x04,0x84,0x24,0x24,0x24,0xa4,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21044 0x5234 "刴" */
+0x00,0x7f,0x11,0x12,0x23,0x20,0x4a,0x89,0x08,0xff,0x18,0x2c,0x2a,0x49,0x88,0x08,
+0x04,0x04,0x04,0x24,0xa4,0xa4,0xa4,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x94,0x08,
+/* 21045 0x5235 "刵" */
+0x00,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x27,0xfa,0x42,0x02,0x02,0x02,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x04,0x04,0x14,0x08,
+/* 21046 0x5236 "制" */
+0x04,0x24,0x24,0x3f,0x44,0x04,0xff,0x04,0x04,0x3f,0x24,0x24,0x26,0x25,0x04,0x04,
+0x04,0x04,0x04,0xa4,0x24,0x24,0xe4,0x24,0x24,0xa4,0xa4,0xa4,0x84,0x04,0x14,0x08,
+/* 21047 0x5237 "刷" */
+0x00,0x3f,0x20,0x20,0x3f,0x22,0x22,0x22,0x3f,0x52,0x52,0x52,0x93,0x12,0x02,0x02,
+0x02,0xc2,0x42,0x42,0xd2,0x12,0x12,0x12,0xd2,0x52,0x52,0x52,0x42,0x82,0x0a,0x04,
+/* 21048 0x5238 "券" */
+0x01,0x11,0x09,0x3f,0x02,0x02,0x7f,0x08,0x10,0x2f,0xc4,0x04,0x08,0x08,0x11,0x20,
+0x00,0x10,0x20,0xf8,0x00,0x00,0xfc,0x20,0x10,0xe8,0x26,0x20,0x20,0x20,0x40,0x80,
+/* 21049 0x5239 "刹" */
+0x01,0x62,0x14,0x08,0x14,0x22,0x49,0x08,0xff,0x08,0x2a,0x29,0x48,0x88,0x28,0x10,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x84,0x84,0x14,0x08,
+/* 21050 0x523a "刺" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x49,0x4d,0x4a,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21051 0x523b "刻" */
+0x10,0x08,0x00,0xff,0x08,0x11,0x21,0x7e,0x04,0x09,0x12,0x24,0xcc,0x12,0x21,0xc0,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x88,
+/* 21052 0x523c "刼" */
+0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0xfe,0x10,0x11,0x20,0x28,0x44,0xfe,0x42,0x01,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21053 0x523d "刽" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0xff,0x10,0x10,0x22,0x41,0xff,0x41,0x00,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21054 0x523e "刾" */
+0x08,0x08,0x08,0xff,0x08,0x49,0x29,0x2a,0xff,0x08,0x08,0x14,0x12,0x21,0x41,0x80,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21055 0x523f "刿" */
+0x08,0x49,0x49,0x49,0x7f,0x10,0x10,0x3f,0x41,0xa1,0x12,0x14,0x08,0x10,0x20,0xc0,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21056 0x5240 "剀" */
+0x08,0x49,0x49,0x49,0x7f,0x00,0x7f,0x01,0x01,0x3f,0x20,0x20,0x23,0x2c,0x30,0x00,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21057 0x5241 "剁" */
+0x00,0x3e,0x22,0x22,0x22,0x49,0x88,0x08,0xff,0x08,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21058 0x5242 "剂" */
+0x10,0x08,0xff,0x02,0x64,0x18,0x26,0xc1,0x22,0x22,0x22,0x22,0x22,0x42,0x42,0x82,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21059 0x5243 "剃" */
+0x42,0x22,0x24,0xff,0x09,0x09,0xff,0x88,0x88,0xff,0x18,0x28,0x4a,0x89,0x08,0x08,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0x84,0x04,0x14,0x08,
+/* 21060 0x5244 "剄" */
+0x00,0x7f,0x00,0x24,0x49,0x92,0x49,0x24,0x00,0x7f,0x08,0x08,0x08,0x0b,0xfc,0x00,
+0x04,0x84,0x04,0xa4,0x24,0x24,0x24,0xa4,0x24,0xa4,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21061 0x5245 "剅" */
+0x00,0x7f,0x00,0x00,0x3f,0x21,0x21,0x21,0x3f,0x00,0x21,0x11,0x12,0x07,0x78,0x20,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21062 0x5246 "剆" */
+0x08,0x04,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,0x24,0x22,0x25,0x29,0x30,0x20,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21063 0x5247 "則" */
+0x00,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x00,0x22,0x21,0x40,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x94,0x88,
+/* 21064 0x5248 "剈" */
+0x00,0x3f,0x21,0x21,0x3f,0x00,0x7f,0x40,0x40,0x7f,0x40,0x40,0x7f,0x40,0x42,0x41,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 21065 0x5249 "剉" */
+0x08,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x08,0x7f,0x08,0x08,0x08,0x0f,0xf8,0x40,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21066 0x524a "削" */
+0x08,0x49,0x29,0x2a,0x08,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x41,0x45,0x42,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21067 0x524b "剋" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x08,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x12,0x02,0xfe,0x00,
+/* 21068 0x524c "剌" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21069 0x524d "前" */
+0x10,0x08,0x08,0xff,0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x2a,0x24,
+0x10,0x10,0x20,0xfe,0x00,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 21070 0x524e "剎" */
+0x02,0x64,0x18,0x16,0x21,0xca,0x09,0x08,0xff,0x18,0x1c,0x2a,0x29,0x48,0x88,0x08,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x84,0x94,0x08,
+/* 21071 0x524f "剏" */
+0x42,0x24,0x00,0x7e,0x24,0x24,0x24,0x24,0xfe,0x25,0x24,0x24,0x24,0x44,0x44,0x85,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21072 0x5250 "剐" */
+0x00,0x7f,0x41,0x41,0x41,0x7f,0x08,0x08,0xff,0x88,0x94,0xa2,0xc2,0x80,0x82,0x81,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 21073 0x5251 "剑" */
+0x08,0x08,0x14,0x12,0x21,0x40,0xbe,0x00,0x11,0x09,0x49,0x22,0x22,0x07,0x78,0x20,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21074 0x5252 "剒" */
+0x12,0x12,0x12,0x7f,0x12,0x12,0xff,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21075 0x5253 "剓" */
+0x0c,0x70,0x11,0xfd,0x32,0x38,0x54,0x91,0x12,0x10,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x80,0x80,0xfc,0x24,0x24,0x44,0x84,0x04,0x28,0x10,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21076 0x5254 "剔" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x10,0x3f,0x4a,0x92,0x24,0x48,0x12,0x21,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 21077 0x5255 "剕" */
+0x12,0x12,0x12,0xf3,0x12,0x12,0x12,0x73,0x12,0x12,0x12,0xf3,0x12,0x12,0x12,0x12,
+0x02,0x02,0x02,0xc2,0x12,0x12,0x12,0x92,0x12,0x12,0x12,0xd2,0x02,0x02,0x0a,0x04,
+/* 21078 0x5256 "剖" */
+0x10,0x08,0x7f,0x00,0x21,0x12,0xff,0x00,0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x00,
+0x04,0x04,0x84,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21079 0x5257 "剗" */
+0x24,0x22,0x2f,0xf0,0x14,0x09,0x35,0xcb,0x24,0x2f,0xf0,0x12,0x14,0x09,0x35,0xc3,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21080 0x5258 "剘" */
+0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0xff,0x00,0x22,0x41,0x80,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x04,0x04,0x14,0x88,
+/* 21081 0x5259 "剙" */
+0x42,0x24,0x01,0x7e,0x24,0x24,0x25,0x25,0xfe,0x24,0x24,0x24,0x24,0x44,0x44,0x85,
+0x00,0x00,0xf8,0x48,0x48,0x48,0x4c,0x4a,0x4a,0x48,0x48,0x48,0x48,0x88,0xa8,0x10,
+/* 21082 0x525a "剚" */
+0x04,0x04,0xff,0x04,0x3f,0x24,0x3f,0x04,0x3f,0x04,0xff,0x04,0x3f,0x04,0x14,0x08,
+0x02,0x02,0xc2,0x02,0x92,0x92,0x92,0x12,0x92,0x92,0xd2,0x92,0x82,0x02,0x0a,0x04,
+/* 21083 0x525b "剛" */
+0x00,0x7f,0x40,0x51,0x4a,0x7f,0x44,0x44,0x55,0x55,0x55,0x5f,0x40,0x40,0x41,0x40,
+0x02,0xc2,0x42,0x42,0x52,0xd2,0x52,0x52,0x52,0x52,0x52,0x52,0x42,0x42,0x4a,0x84,
+/* 21084 0x525c "剜" */
+0x08,0x04,0x7f,0x40,0x20,0x3b,0x2a,0x2a,0x2a,0x5a,0x4b,0x8a,0x12,0x12,0x23,0x42,
+0x04,0x04,0x84,0xa4,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x04,0x84,0x14,0x08,
+/* 21085 0x525d "剝" */
+0x20,0x3e,0x42,0x7c,0x04,0xff,0x08,0x09,0x49,0x2a,0x1c,0x2a,0xc9,0x09,0x28,0x10,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21086 0x525e "剞" */
+0x08,0x08,0x7f,0x14,0x22,0x41,0xff,0x01,0x79,0x49,0x49,0x49,0x79,0x01,0x05,0x02,
+0x04,0x04,0x84,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21087 0x525f "剟" */
+0x00,0x7b,0x08,0x2a,0x11,0x2a,0x44,0x88,0x00,0x7b,0x08,0x2a,0x11,0x2a,0x44,0x88,
+0x04,0x84,0x84,0xa4,0x24,0xa4,0xa4,0x24,0x24,0xa4,0xa4,0xa4,0x04,0x84,0x94,0x08,
+/* 21088 0x5260 "剠" */
+0x10,0x08,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x08,0x2a,0x49,0x88,0x28,0x10,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x84,0x14,0x08,
+/* 21089 0x5261 "剡" */
+0x08,0x09,0x49,0x4a,0x88,0x14,0x22,0x49,0x88,0x49,0x49,0x8a,0x14,0x22,0x41,0x80,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x88,
+/* 21090 0x5262 "剢" */
+0x00,0xff,0x08,0x10,0x28,0xc4,0x0d,0x56,0x25,0xd5,0x0c,0x14,0x24,0xc4,0x14,0x08,
+0x04,0x84,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0xa4,0xa4,0x04,0x04,0x14,0x08,
+/* 21091 0x5263 "剣" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x14,0x22,0x41,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21092 0x5264 "剤" */
+0x10,0x08,0xff,0x02,0x64,0x18,0x26,0xc1,0x22,0x3e,0x22,0x22,0x3e,0x42,0x42,0x82,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21093 0x5265 "剥" */
+0x00,0x7e,0x02,0x3e,0x02,0xff,0x08,0x09,0x49,0x2a,0x1c,0x2a,0xc9,0x09,0x28,0x10,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21094 0x5266 "剦" */
+0x08,0x08,0xff,0x14,0x22,0x49,0x88,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x0a,0x0c,0x08,
+0x04,0x04,0x84,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21095 0x5267 "剧" */
+0x00,0x3f,0x20,0x20,0x3f,0x24,0x24,0x3f,0x24,0x24,0x3f,0x50,0x50,0x90,0x1f,0x10,
+0x04,0x84,0x84,0xa4,0xa4,0x24,0x24,0xa4,0x24,0x24,0xa4,0xa4,0x84,0x84,0x94,0x88,
+/* 21096 0x5268 "剨" */
+0x08,0x08,0xff,0x08,0x7f,0x08,0xff,0x08,0xff,0x10,0x20,0x7f,0xa1,0x21,0x3f,0x21,
+0x04,0x04,0x84,0x24,0x24,0x24,0xa4,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21097 0x5269 "剩" */
+0x07,0x78,0x08,0xff,0x2a,0x2a,0xeb,0x2a,0x6a,0xa9,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x02,0x02,0x02,0x82,0x12,0x92,0x12,0x92,0x92,0x92,0x12,0x12,0x02,0x82,0x0a,0x04,
+/* 21098 0x526a "剪" */
+0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x20,0xfe,0x00,0x08,0x48,0x48,0x48,0x48,0x08,0x18,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21099 0x526b "剫" */
+0x04,0x02,0x3f,0x24,0x24,0x3f,0x24,0x27,0x20,0x2f,0x20,0x24,0x22,0x41,0x46,0x98,
+0x02,0x02,0xe2,0x82,0x92,0xf2,0x92,0x92,0x12,0xd2,0x52,0x92,0x82,0x02,0x8a,0x44,
+/* 21100 0x526c "剬" */
+0x08,0x49,0x49,0x49,0x7f,0x00,0xff,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x43,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21101 0x526d "剭" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x3f,0x24,0x29,0x2f,0x22,0x2f,0x22,0x43,0x5e,0x88,
+0x04,0x84,0x84,0xa4,0xa4,0x24,0xa4,0x24,0x24,0xa4,0x24,0xa4,0x04,0x84,0x14,0x08,
+/* 21102 0x526e "剮" */
+0x00,0x7f,0x41,0x41,0x79,0x49,0x49,0xff,0x80,0xbe,0xa2,0xa2,0xbe,0x80,0x82,0x81,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 21103 0x526f "副" */
+0x00,0x7f,0x00,0x3f,0x20,0x20,0x3f,0x00,0x7f,0x44,0x44,0x7f,0x44,0x44,0x7f,0x40,
+0x02,0xc2,0x02,0x82,0x92,0x92,0x92,0x12,0xd2,0x52,0x52,0xd2,0x42,0x42,0xca,0x44,
+/* 21104 0x5270 "剰" */
+0x03,0x3c,0x04,0x7f,0x15,0x15,0xff,0x15,0x15,0x7f,0x0e,0x15,0x24,0x44,0x84,0x04,
+0x82,0x02,0x02,0xc2,0x12,0x12,0xd2,0x12,0x12,0xd2,0x12,0x12,0x82,0x42,0x0a,0x04,
+/* 21105 0x5271 "剱" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x14,0x22,0x41,
+0x00,0x00,0x7e,0x12,0x12,0xd2,0x52,0x52,0x52,0x92,0x12,0x12,0x22,0x22,0x4a,0x84,
+/* 21106 0x5272 "割" */
+0x10,0x08,0xff,0x80,0x09,0x7f,0x08,0x7f,0x08,0xff,0x08,0x7f,0x41,0x41,0x7f,0x41,
+0x04,0x04,0x84,0xa4,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21107 0x5273 "剳" */
+0x22,0x22,0xff,0x22,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x04,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21108 0x5274 "剴" */
+0x08,0x49,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x42,0x24,0x0f,0xf0,0x40,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21109 0x5275 "創" */
+0x08,0x0c,0x12,0x29,0x44,0xbf,0x21,0x3f,0x21,0x3f,0x20,0x3f,0x51,0x51,0x9f,0x11,
+0x04,0x04,0x04,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21110 0x5276 "剶" */
+0x20,0x3f,0x41,0x7e,0x02,0xff,0x10,0x28,0xcd,0x16,0x25,0xcd,0x14,0x24,0xd4,0x08,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0xa4,0x24,0x24,0x24,0x24,0x84,0x84,0x14,0x08,
+/* 21111 0x5277 "剷" */
+0x08,0x04,0x3f,0x11,0x0a,0x3f,0x22,0x2a,0x2f,0x32,0x22,0x2f,0x22,0x42,0x43,0x9c,
+0x04,0x04,0x84,0x24,0x24,0xa4,0x24,0x24,0xa4,0x24,0x24,0xa4,0x04,0x04,0x94,0x08,
+/* 21112 0x5278 "剸" */
+0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x02,0xff,0x42,0x22,0x0a,0x04,
+0x04,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0xa4,0x24,0xa4,0x04,0x04,0x14,0x08,
+/* 21113 0x5279 "剹" */
+0x00,0x77,0x11,0x55,0x33,0x55,0x0c,0x33,0xc4,0x18,0x62,0x0c,0x71,0x06,0x18,0xe0,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0xa4,0x04,0x04,0x14,0x08,
+/* 21114 0x527a "剺" */
+0x08,0x08,0x7e,0x08,0xff,0x1c,0x2a,0x48,0x00,0x3f,0x20,0x2f,0x22,0x42,0x44,0x98,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xfe,0x00,0xf8,0x08,0x08,0x28,0x10,
+/* 21115 0x527b "剻" */
+0x02,0x22,0x22,0x3f,0x00,0x3d,0x25,0x25,0x3d,0x25,0x25,0x3d,0x25,0x25,0x55,0x8a,
+0x02,0x22,0x22,0xea,0x0a,0xea,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x22,0xaa,0x44,
+/* 21116 0x527c "剼" */
+0x10,0x22,0x7f,0x42,0x94,0xf7,0x08,0x36,0xc9,0x30,0xc4,0x19,0x62,0x0c,0x30,0xc0,
+0x04,0x04,0x04,0x24,0xa4,0xa4,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21117 0x527d "剽" */
+0x00,0xff,0x0a,0x7f,0x4a,0x4a,0x7f,0x00,0x7f,0x00,0xff,0x04,0x24,0x44,0x94,0x08,
+0x02,0xe2,0x02,0xc2,0x52,0x52,0xd2,0x12,0xd2,0x12,0xf2,0x12,0x82,0x42,0x2a,0x04,
+/* 21118 0x527e "剾" */
+0x00,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x5d,0x55,0x55,0x55,0x5d,0x40,0x7f,0x00,
+0x02,0xc2,0x02,0x82,0x92,0x92,0x92,0x12,0xd2,0x52,0x52,0x52,0xc2,0x02,0xea,0x04,
+/* 21119 0x527f "剿" */
+0x49,0x92,0x49,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x04,0x04,0x14,0x08,
+/* 21120 0x5280 "劀" */
+0x00,0x7f,0x12,0x0c,0xff,0x14,0x25,0xd4,0x08,0xff,0x94,0xa2,0xdd,0x94,0x9c,0x81,
+0x04,0x04,0x04,0x24,0xa4,0xa4,0x24,0x24,0x24,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x88,
+/* 21121 0x5281 "劁" */
+0x12,0x11,0x3f,0x22,0x62,0xbf,0x22,0x22,0x3f,0x22,0x22,0x3f,0x20,0x54,0x4a,0x8a,
+0x02,0x02,0xc2,0x02,0x12,0xd2,0x12,0x12,0xd2,0x12,0x12,0xd2,0x02,0x82,0x4a,0x44,
+/* 21122 0x5282 "劂" */
+0x00,0x7f,0x40,0x51,0x4a,0x5f,0x44,0x44,0x55,0x55,0x5f,0x44,0x44,0x48,0x49,0x92,
+0x02,0xf2,0x02,0x4a,0x4a,0x7a,0x9a,0x2a,0x0a,0x4a,0x4a,0x4a,0xa2,0xa2,0x2a,0x04,
+/* 21123 0x5283 "劃" */
+0x08,0x7f,0x09,0xff,0x09,0x7f,0x08,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,
+0x04,0x04,0x04,0xa4,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x88,
+/* 21124 0x5284 "劄" */
+0x42,0x42,0x7b,0x45,0xa8,0x14,0x22,0x41,0xbe,0x00,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x04,0x04,0xc4,0x24,0xa4,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21125 0x5285 "劅" */
+0x00,0x7f,0x55,0x55,0x7f,0x20,0x7f,0x90,0x7c,0x54,0x54,0x7c,0x12,0xfe,0x02,0x01,
+0x04,0x04,0x04,0x24,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x94,0x08,
+/* 21126 0x5286 "劆" */
+0x02,0x3f,0x28,0x25,0x3f,0x25,0x2f,0x25,0x3f,0x25,0x2f,0x25,0x2d,0x55,0x65,0x85,
+0x02,0xf2,0x82,0x0a,0xea,0x0a,0xca,0x4a,0xea,0x4a,0xca,0x0a,0x82,0x42,0x2a,0x04,
+/* 21127 0x5287 "劇" */
+0x08,0x0f,0x08,0x7f,0x48,0x7e,0x49,0x47,0x40,0x7f,0x48,0x55,0x4a,0xb7,0x0a,0x36,
+0x04,0x04,0x04,0xa4,0xa4,0x24,0x24,0x24,0x24,0xa4,0x24,0x24,0x04,0x04,0x94,0x08,
+/* 21128 0x5288 "劈" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21129 0x5289 "劉" */
+0x08,0x77,0x52,0x4a,0x55,0x64,0x0a,0x11,0x3f,0xc4,0x3f,0x04,0x25,0x17,0x7c,0x20,
+0x02,0xc2,0x42,0x42,0x52,0x92,0x12,0x12,0x92,0x52,0x12,0x92,0x02,0xc2,0x0a,0x04,
+/* 21130 0x528a "劊" */
+0x04,0x0b,0x30,0xdf,0x00,0x7f,0x55,0x4e,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,
+0x02,0x02,0xc2,0x22,0x12,0xd2,0x52,0x52,0xd2,0x12,0x92,0x92,0x82,0x82,0x8a,0x84,
+/* 21131 0x528b "劋" */
+0x00,0x7f,0x41,0x7f,0x00,0xf7,0x94,0xf7,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x04,0x04,0x04,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0xa4,0x24,0x04,0x04,0x94,0x08,
+/* 21132 0x528c "劌" */
+0x02,0x13,0x12,0x7f,0x01,0x01,0x3f,0x21,0x3f,0x25,0x25,0x2d,0x36,0x44,0x89,0x32,
+0x02,0xc2,0x02,0xea,0x0a,0x4a,0xea,0x0a,0x0a,0x4a,0x4a,0x4a,0x82,0xa2,0x6a,0x24,
+/* 21133 0x528d "劍" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x88,
+0x04,0x04,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x88,
+/* 21134 0x528e "劎" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x89,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21135 0x528f "劏" */
+0x08,0x49,0x2a,0xff,0x80,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x41,
+0x04,0x04,0x04,0xa4,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 21136 0x5290 "劐" */
+0x11,0x7f,0x15,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,0x7f,0x11,0x0e,0x71,
+0x02,0xc2,0x02,0x02,0xd2,0x12,0x92,0x12,0x92,0x12,0xd2,0x12,0x82,0x02,0x0a,0x84,
+/* 21137 0x5291 "劑" */
+0x08,0x04,0x7f,0x11,0x0a,0xf5,0x55,0x55,0xb5,0x00,0x20,0x3f,0x20,0x3f,0x20,0x40,
+0x02,0x02,0xc2,0x02,0x52,0x92,0x52,0x32,0x92,0x12,0x92,0x92,0x82,0x82,0x8a,0x84,
+/* 21138 0x5292 "劒" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x88,
+0x00,0x00,0x7e,0x12,0x12,0x52,0x52,0x52,0x52,0x92,0x12,0x12,0x22,0x22,0x4a,0x84,
+/* 21139 0x5293 "劓" */
+0x08,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x44,0x7f,0x44,0x7f,0x00,0xff,0x11,0x21,
+0x02,0x82,0x82,0x82,0x92,0x92,0x12,0xd2,0x52,0xd2,0x52,0xd2,0x02,0xe2,0x0a,0x04,
+/* 21140 0x5294 "劔" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x88,
+0x00,0x00,0x7c,0x24,0x24,0x24,0xa4,0x64,0x24,0x34,0x2c,0x26,0x24,0x24,0x44,0x8c,
+/* 21141 0x5295 "劕" */
+0x08,0x73,0x42,0x7b,0x52,0x52,0x84,0x7f,0x40,0x7f,0x40,0x7f,0x40,0x7f,0x21,0x40,
+0x44,0x84,0x04,0xe4,0xa4,0xa4,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x84,0x14,0x88,
+/* 21142 0x5296 "劖" */
+0x3e,0x42,0xff,0x40,0x7f,0x44,0x77,0x44,0x3f,0x42,0xff,0x48,0x7f,0x1a,0x29,0xc7,
+0x02,0x02,0x82,0x82,0x92,0x92,0x12,0x52,0xd2,0x12,0x92,0x92,0x82,0x02,0x4a,0xc4,
+/* 21143 0x5297 "劗" */
+0x52,0x7b,0x94,0x7b,0x31,0x5a,0x94,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x10,0x20,
+0x82,0xe2,0x82,0xea,0x8a,0xaa,0x6a,0xca,0x4a,0xca,0x4a,0xca,0x42,0xc2,0x8a,0x44,
+/* 21144 0x5298 "劘" */
+0x02,0x3f,0x24,0x3f,0x24,0x2e,0x35,0x24,0x25,0x3d,0x25,0x3d,0x25,0x5d,0x45,0x85,
+0x02,0xf2,0x82,0xea,0x8a,0xca,0xaa,0x8a,0x0a,0xea,0x0a,0xca,0x02,0xe2,0x0a,0x04,
+/* 21145 0x5299 "劙" */
+0x1f,0x21,0x3e,0x02,0x7f,0x18,0x65,0x1a,0x66,0x1a,0x24,0xfb,0xaa,0xfb,0x28,0xfb,
+0x02,0x02,0x02,0x02,0xd2,0x92,0x12,0x92,0x52,0x12,0x92,0xf2,0xa2,0xe2,0xaa,0xe4,
+/* 21146 0x529a "劚" */
+0x7f,0x40,0x7f,0x52,0x4a,0x52,0x5f,0x55,0x5f,0x64,0x5f,0x55,0x5f,0x44,0xbf,0x00,
+0xc2,0x42,0xc2,0x42,0x92,0x52,0xd2,0x52,0xd2,0x52,0x52,0x52,0x42,0x42,0x4a,0x84,
+/* 21147 0x529b "力" */
+0x02,0x02,0x02,0x02,0x7f,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x50,0x20,
+/* 21148 0x529c "劜" */
+0x10,0x10,0x10,0x10,0xff,0x11,0x11,0x11,0x11,0x11,0x21,0x21,0x21,0x41,0x4a,0x84,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 21149 0x529d "劝" */
+0x00,0x00,0x00,0xfc,0x05,0x04,0x48,0x28,0x10,0x10,0x28,0x24,0x45,0x81,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 21150 0x529e "办" */
+0x02,0x02,0x02,0x02,0x7f,0x02,0x02,0x12,0x12,0x24,0x44,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x18,0x14,0x12,0x12,0x10,0x10,0x10,0xa0,0x40,
+/* 21151 0x529f "功" */
+0x00,0x00,0x00,0xfe,0x11,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0xf1,0x41,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 21152 0x52a0 "加" */
+0x10,0x10,0x10,0x10,0xfe,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 21153 0x52a1 "务" */
+0x04,0x04,0x0f,0x18,0x24,0x03,0x0c,0x32,0xc2,0x1f,0x02,0x04,0x04,0x08,0x10,0x20,
+0x00,0x00,0xf0,0x20,0xc0,0x00,0xc0,0x30,0x0e,0xf0,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 21154 0x52a2 "劢" */
+0x00,0x00,0xff,0x20,0x20,0x20,0x3e,0x22,0x22,0x22,0x22,0x22,0x42,0x42,0x94,0x09,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21155 0x52a3 "劣" */
+0x01,0x11,0x11,0x21,0x41,0x01,0x0e,0xf1,0x01,0x3f,0x02,0x02,0x04,0x08,0x10,0x60,
+0x00,0x10,0x08,0x24,0x44,0x80,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21156 0x52a4 "劤" */
+0x02,0x07,0x38,0x20,0x20,0x20,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x45,0x82,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21157 0x52a5 "劥" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x81,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21158 0x52a6 "劦" */
+0x02,0x02,0x3f,0x04,0x08,0x10,0x60,0x10,0x10,0x7e,0x12,0x12,0x22,0x22,0x4a,0x85,
+0x00,0x00,0xf0,0x10,0x10,0xa0,0x40,0x20,0x20,0xfc,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21159 0x52a7 "劧" */
+0x04,0x0e,0x78,0x08,0x08,0x7e,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x29,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21160 0x52a8 "动" */
+0x00,0x00,0x7c,0x00,0x01,0x00,0xfe,0x20,0x20,0x20,0x48,0x44,0xfd,0x45,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 21161 0x52a9 "助" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x4e,0xf0,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21162 0x52aa "努" */
+0x10,0x10,0xfe,0x22,0x44,0x28,0x10,0x28,0xc5,0x02,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x00,0x00,0xfc,0x84,0x88,0x50,0x20,0x58,0x86,0x00,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21163 0x52ab "劫" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0x08,0xff,0x10,0x10,0x20,0x44,0xfe,0x42,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21164 0x52ac "劬" */
+0x20,0x20,0x20,0x7e,0x42,0x82,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x15,0x0a,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21165 0x52ad "劭" */
+0x00,0x7e,0x12,0x12,0x22,0x2a,0x44,0x80,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21166 0x52ae "劮" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0xff,0x08,0x08,0x14,0x22,0x42,0x81,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21167 0x52af "劯" */
+0x00,0x00,0xff,0x10,0x10,0x10,0x3e,0x22,0x62,0xa2,0x22,0x22,0x3e,0x22,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21168 0x52b0 "劰" */
+0x10,0x10,0x20,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21169 0x52b1 "励" */
+0x00,0x7f,0x40,0x40,0x5f,0x48,0x48,0x4f,0x49,0x49,0x49,0x49,0x49,0x51,0x95,0x22,
+0x10,0xd0,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21170 0x52b2 "劲" */
+0x00,0x7e,0x04,0x08,0x18,0x24,0x42,0x81,0x00,0x7e,0x08,0x08,0x08,0x0e,0xf1,0x42,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21171 0x52b3 "劳" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x42,0x82,0x3f,0x02,0x02,0x04,0x04,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 21172 0x52b4 "労" */
+0x22,0x11,0x11,0x00,0x7f,0x40,0x82,0x02,0x7f,0x02,0x02,0x04,0x04,0x08,0x10,0x60,
+0x08,0x08,0x10,0x20,0xfe,0x02,0x04,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21173 0x52b5 "劵" */
+0x01,0x11,0x09,0x3f,0x02,0x02,0x7f,0x08,0x12,0x22,0xdf,0x04,0x04,0x08,0x10,0x20,
+0x00,0x10,0x20,0xf8,0x00,0x00,0xfc,0x20,0x10,0x08,0xf6,0x10,0x10,0x10,0xa0,0x40,
+/* 21174 0x52b6 "劶" */
+0x04,0x0e,0x70,0x40,0x40,0x7f,0x40,0x40,0x5e,0x52,0x52,0x52,0x52,0x9e,0x92,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21175 0x52b7 "劷" */
+0x22,0x12,0x14,0x7f,0x08,0x08,0x3e,0x08,0x08,0x7f,0x08,0x08,0x10,0x10,0x21,0x42,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21176 0x52b8 "劸" */
+0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x41,
+0x20,0x20,0x20,0x20,0xfc,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21177 0x52b9 "効" */
+0x10,0x08,0x00,0xff,0x00,0x24,0x42,0x81,0x24,0x14,0x08,0x14,0x22,0x42,0x81,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21178 0x52ba "劺" */
+0x10,0x10,0x24,0x42,0xff,0x09,0x48,0x48,0x7f,0x88,0x08,0xff,0x08,0x08,0x08,0x09,
+0x10,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0xa2,0x42,0x42,0x94,0x08,
+/* 21179 0x52bb "劻" */
+0x00,0x7f,0x40,0x40,0x7f,0x44,0x44,0x5f,0x44,0x44,0x7f,0x40,0x40,0x7f,0x00,0x01,
+0x10,0x90,0x10,0x7e,0x92,0x12,0x12,0x12,0x12,0x22,0xa2,0x22,0x42,0xc2,0x94,0x08,
+/* 21180 0x52bc "劼" */
+0x08,0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x00,0x7e,0x42,0x42,0x42,0x7e,0x42,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21181 0x52bd "劽" */
+0x7f,0x08,0x10,0x3f,0x51,0x0a,0x04,0x08,0x30,0xc2,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x84,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21182 0x52be "劾" */
+0x10,0x08,0x08,0xff,0x08,0x10,0x22,0x7c,0x09,0x12,0x24,0xc8,0x14,0x22,0xc0,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21183 0x52bf "势" */
+0x08,0x08,0x7d,0x08,0x0c,0x19,0x68,0x08,0x28,0x13,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x40,0x40,0xf8,0x48,0x48,0xc8,0x4a,0xaa,0x86,0x02,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21184 0x52c0 "勀" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x25,0x26,0x44,0x81,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21185 0x52c1 "勁" */
+0x00,0x7f,0x00,0x25,0x4a,0x92,0x49,0x24,0x00,0x7f,0x08,0x08,0x08,0x0f,0xf8,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21186 0x52c2 "勂" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21187 0x52c3 "勃" */
+0x08,0x08,0x7f,0x08,0x08,0x7f,0x41,0x82,0x3c,0x04,0x08,0x0f,0x78,0x08,0x29,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21188 0x52c4 "勄" */
+0x20,0x20,0x3f,0x40,0xbf,0x21,0x29,0x25,0xff,0x21,0x49,0x45,0x7f,0x01,0x0a,0x04,
+0x10,0x10,0x90,0x10,0x7e,0x12,0x12,0x12,0xd2,0x12,0x12,0x12,0x92,0x22,0x2a,0x44,
+/* 21189 0x52c5 "勅" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x1c,0x2a,0x49,0x88,0x09,0x0a,
+0x20,0x20,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21190 0x52c6 "勆" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x48,0x44,0x4a,0x52,0x61,0x42,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21191 0x52c7 "勇" */
+0x3f,0x06,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x22,0x02,0x7f,0x04,0x08,0x10,0x60,
+0xf0,0x60,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21192 0x52c8 "勈" */
+0x00,0x7e,0x02,0x34,0x08,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x49,0x49,0x49,0x43,
+0x10,0x10,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21193 0x52c9 "勉" */
+0x20,0x20,0x3e,0x44,0x88,0x7f,0x49,0x49,0x49,0x7f,0x14,0x14,0x25,0x24,0x43,0x80,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x0a,0x02,0xfe,0x00,
+/* 21194 0x52ca "勊" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x25,0x24,0x43,0x80,
+0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x88,0x02,0x02,0xfe,0x00,
+/* 21195 0x52cb "勋" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x41,0x49,0x49,0x49,0x49,0x14,0x12,0x21,0xc2,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21196 0x52cc "勌" */
+0x08,0x49,0x2a,0x7f,0x08,0x10,0xff,0x22,0x41,0xbe,0x22,0x2a,0x24,0x20,0x2c,0x31,
+0x20,0x20,0x20,0x20,0xfc,0x24,0xa4,0x24,0x24,0xa4,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21197 0x52cd "勍" */
+0x10,0x08,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x08,0x2a,0x49,0x88,0x28,0x10,
+0x10,0x10,0x90,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0xa2,0x2a,0x44,
+/* 21198 0x52ce "勎" */
+0x08,0x08,0x7e,0x08,0x08,0xff,0x22,0x41,0x88,0x08,0x7e,0x08,0x08,0x0f,0xf8,0x41,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21199 0x52cf "勏" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21200 0x52d0 "勐" */
+0x00,0x3e,0x04,0x08,0x7e,0x08,0x08,0x28,0x10,0x7f,0x55,0x55,0x55,0x57,0xfd,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21201 0x52d1 "勑" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x49,0x88,0x09,0x0a,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21202 0x52d2 "勒" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x09,0x0a,
+0x20,0x20,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0xc4,0x44,0x84,0x28,0x10,
+/* 21203 0x52d3 "勓" */
+0x44,0x44,0x75,0x46,0x54,0x64,0x4b,0x10,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x90,0x10,0x10,0xfe,0x92,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21204 0x52d4 "勔" */
+0x00,0xff,0x08,0x10,0x7f,0x55,0x55,0x5d,0x55,0x55,0x5d,0x55,0x55,0x55,0x7f,0x41,
+0x20,0xa0,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21205 0x52d5 "動" */
+0x0f,0x78,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf8,0x41,
+0x20,0x20,0x20,0xa0,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0xc4,0x94,0x08,
+/* 21206 0x52d6 "勖" */
+0x00,0xff,0x81,0xbd,0x81,0xbd,0x81,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x43,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21207 0x52d7 "勗" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2f,0xf0,0x40,0x01,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21208 0x52d8 "勘" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7f,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21209 0x52d9 "務" */
+0x00,0xfc,0x04,0x68,0x11,0x08,0xfe,0x13,0x34,0x30,0x53,0x50,0x90,0x10,0x51,0x22,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0x40,0x40,0xfc,0x44,0x84,0x84,0x14,0x08,
+/* 21210 0x52da "勚" */
+0x52,0x52,0xff,0x52,0x5e,0x40,0x7f,0x00,0x7f,0x41,0x49,0x49,0x49,0x14,0x22,0xc1,
+0x10,0x10,0x90,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21211 0x52db "勛" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x14,0x22,0x41,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21212 0x52dc "勜" */
+0x28,0x44,0x92,0x20,0x48,0xfc,0x04,0x00,0xee,0x22,0xaa,0x66,0xaa,0x22,0xaa,0x45,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21213 0x52dd "勝" */
+0x00,0x79,0x48,0x48,0x49,0x78,0x4b,0x48,0x49,0x7a,0x4d,0x48,0x48,0x48,0x49,0x9a,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x44,0x42,0xf8,0x48,0x88,0x88,0x28,0x10,
+/* 21214 0x52de "勞" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x41,0x81,0x3f,0x02,0x02,0x04,0x08,0x10,0x60,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21215 0x52df "募" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x10,0x22,0xdf,0x04,0x08,0x30,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0x08,0xf6,0x10,0x50,0x20,
+/* 21216 0x52e0 "勠" */
+0x00,0x77,0x11,0x55,0x33,0x55,0x0c,0x33,0xc4,0x18,0x62,0x0c,0x71,0x06,0x18,0xe1,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0xa4,0x24,0x24,0xa4,0x44,0x44,0x94,0x08,
+/* 21217 0x52e1 "勡" */
+0x00,0xff,0x14,0x7f,0x55,0x55,0x7f,0x00,0x7f,0x00,0xff,0x08,0x2a,0x49,0xa8,0x11,
+0x20,0xa0,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x44,0x44,0xa8,0x10,
+/* 21218 0x52e2 "勢" */
+0x10,0x7c,0x11,0xfe,0x44,0x92,0x7c,0x10,0x1d,0xe2,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x40,0x40,0xf8,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21219 0x52e3 "勣" */
+0x08,0x7f,0x08,0x7f,0x08,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,
+0x10,0x10,0x10,0x10,0x7e,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21220 0x52e4 "勤" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf2,
+0x20,0x20,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21221 0x52e5 "勥" */
+0x7c,0x04,0x04,0x7c,0x41,0x7d,0x05,0x04,0x2b,0x12,0x02,0x7f,0x04,0x08,0x10,0x60,
+0xf8,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x28,0xfc,0x04,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 21222 0x52e6 "勦" */
+0x49,0x92,0x49,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x09,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0xa4,0x24,0x44,0x44,0x94,0x08,
+/* 21223 0x52e7 "勧" */
+0x20,0x20,0x3f,0x48,0x88,0x7f,0x14,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x21,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21224 0x52e8 "勨" */
+0x20,0x3e,0x42,0xff,0x49,0x49,0x7f,0x10,0x28,0xd5,0x26,0xcd,0x15,0x24,0xd4,0x09,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 21225 0x52e9 "勩" */
+0x52,0xff,0x52,0x5e,0x40,0x7f,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x25,0x42,
+0x20,0xa0,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 21226 0x52ea "勪" */
+0x06,0x78,0x10,0xff,0x22,0x5d,0x94,0x1c,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x43,
+0x10,0x10,0x10,0x90,0x7e,0x12,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21227 0x52eb "勫" */
+0x0f,0xf8,0x49,0x2a,0xff,0x2a,0x49,0x80,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x41,
+0x10,0x10,0x10,0x7e,0x92,0x12,0x12,0x92,0x12,0x22,0x22,0x22,0x42,0x42,0x94,0x08,
+/* 21228 0x52ec "勬" */
+0x08,0x49,0x2a,0x7f,0x10,0xff,0x22,0x51,0xa2,0x3c,0x09,0x7f,0x08,0x49,0x88,0x18,
+0x10,0x10,0x10,0x10,0x7e,0x92,0x12,0x12,0x92,0x12,0x12,0x12,0x12,0x22,0xaa,0x44,
+/* 21229 0x52ed "勭" */
+0x10,0x08,0x7f,0x22,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x10,0x10,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x2a,0x44,
+/* 21230 0x52ee "勮" */
+0x08,0x0f,0x08,0x7f,0x48,0x7e,0x49,0x47,0x40,0x7f,0x48,0x55,0x4a,0xb7,0x0a,0x36,
+0x10,0x10,0x10,0x90,0xfe,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,0x22,0xaa,0x44,
+/* 21231 0x52ef "勯" */
+0x08,0xff,0x00,0xff,0x81,0xbd,0xa5,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x00,0xff,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 21232 0x52f0 "勰" */
+0x10,0x10,0x7e,0x12,0x22,0x2a,0x44,0x80,0x44,0xff,0x55,0x55,0x55,0x55,0x59,0xb3,
+0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x10,0x08,0x28,0x20,0x64,0xaa,0x28,0x18,
+/* 21233 0x52f1 "勱" */
+0x22,0x22,0xff,0x22,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x88,0x8a,0xbe,0x82,0x81,
+0x10,0x10,0x90,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x92,0x92,0x92,0xa2,0xaa,0xc4,
+/* 21234 0x52f2 "勲" */
+0x7f,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x00,0x24,0x42,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,0x00,0x48,0x24,
+/* 21235 0x52f3 "勳" */
+0x07,0x78,0x08,0xff,0x08,0x7f,0x6b,0x5d,0x7f,0x08,0x7f,0x08,0xff,0x00,0x55,0x8a,
+0x10,0x10,0x10,0x90,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x92,0x22,0x2a,0xc4,
+/* 21236 0x52f4 "勴" */
+0x08,0x0f,0x08,0x7f,0x48,0x7e,0x48,0x5f,0x55,0x5f,0x55,0x5f,0x48,0x55,0xb2,0x5e,
+0x10,0x90,0x10,0x90,0xfe,0x12,0x92,0x92,0x12,0x12,0x12,0x12,0x12,0x22,0xaa,0x44,
+/* 21237 0x52f5 "勵" */
+0x00,0x7f,0x4a,0x7f,0x4a,0x5f,0x55,0x5f,0x55,0x5f,0x44,0x7f,0x64,0xae,0xa2,0x21,
+0x10,0x90,0x10,0x90,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x92,0x92,0xa2,0xaa,0x44,
+/* 21238 0x52f6 "勶" */
+0x22,0x4f,0x82,0x14,0x2f,0x60,0xaf,0x28,0x2f,0x28,0x29,0x02,0x7f,0x04,0x18,0x60,
+0x10,0x90,0x1e,0xa4,0xd4,0x14,0x94,0x88,0x88,0x94,0xa2,0x00,0xfc,0x04,0x28,0x10,
+/* 21239 0x52f7 "勷" */
+0x08,0xff,0x00,0x77,0x55,0x77,0x22,0x7f,0x22,0x7f,0x22,0xff,0x28,0x65,0xb2,0x21,
+0x10,0x90,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x12,0x12,0x92,0x92,0x22,0x2a,0x44,
+/* 21240 0x52f8 "勸" */
+0x22,0xff,0x22,0xf7,0x94,0xf7,0x28,0x24,0x7f,0x48,0xff,0x48,0x7f,0x48,0x7f,0x40,
+0x10,0x90,0x10,0x90,0xfe,0x92,0x12,0x12,0x92,0x12,0x12,0x12,0x12,0x22,0xaa,0x44,
+/* 21241 0x52f9 "勹" */
+0x10,0x10,0x3f,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 21242 0x52fa "勺" */
+0x08,0x08,0x10,0x1f,0x20,0x40,0x80,0x04,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21243 0x52fb "勻" */
+0x08,0x08,0x10,0x1f,0x20,0x40,0x80,0x1f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x88,0x08,0x08,0x08,0xc8,0x08,0x08,0x50,0x20,
+/* 21244 0x52fc "勼" */
+0x10,0x10,0x3f,0x20,0x44,0x84,0x3f,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x84,0x84,0x84,0x84,0x94,0x94,0x74,0x04,0x28,0x10,
+/* 21245 0x52fd "勽" */
+0x08,0x08,0x10,0x1f,0x20,0x42,0x82,0x02,0x05,0x04,0x04,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x88,0x88,0x48,0x48,0x08,0x50,0x20,
+/* 21246 0x52fe "勾" */
+0x08,0x08,0x10,0x1f,0x20,0x42,0x82,0x04,0x04,0x08,0x10,0x3f,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x88,0x48,0xe8,0x28,0x08,0x50,0x20,
+/* 21247 0x52ff "勿" */
+0x08,0x08,0x08,0x1f,0x12,0x22,0x42,0x84,0x04,0x08,0x10,0x21,0x42,0x04,0x08,0x10,
+0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 21248 0x5300 "匀" */
+0x08,0x08,0x0f,0x10,0x20,0x48,0x84,0x02,0x00,0x00,0x03,0x1c,0x08,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x24,0xc4,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 21249 0x5301 "匁" */
+0x08,0x08,0x08,0x1f,0x11,0x29,0x45,0x82,0x03,0x04,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x88,0x48,0x38,0x0e,0x08,0x50,0x20,
+/* 21250 0x5302 "匂" */
+0x10,0x10,0x3f,0x20,0x48,0x88,0x08,0x09,0x0e,0x08,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x44,0x84,0x04,0x04,0x14,0x14,0x14,0xf4,0x04,0x28,0x10,
+/* 21251 0x5303 "匃" */
+0x08,0x08,0x0f,0x10,0x21,0x41,0x91,0x12,0x12,0x14,0x18,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x24,0x24,0x04,0xe4,0x04,0x28,0x10,
+/* 21252 0x5304 "匄" */
+0x10,0x10,0x3f,0x20,0x42,0x81,0x00,0x3f,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0xe4,0x04,0x28,0x10,
+/* 21253 0x5305 "包" */
+0x08,0x08,0x1f,0x10,0x20,0x5f,0x90,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x00,0xf0,0x10,0x10,0x90,0x90,0x90,0x90,0x90,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 21254 0x5306 "匆" */
+0x08,0x08,0x08,0x1f,0x12,0x22,0x42,0x9c,0x06,0x09,0x10,0x21,0x42,0x04,0x08,0x10,
+0x00,0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x84,0xc4,0x24,0x14,0x04,0x28,0x10,
+/* 21255 0x5307 "匇" */
+0x10,0x10,0x3f,0x22,0x42,0x87,0x08,0x10,0x24,0x02,0x02,0x01,0x06,0x18,0x60,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 21256 0x5308 "匈" */
+0x08,0x08,0x10,0x1f,0x20,0x40,0x88,0x25,0x22,0x25,0x28,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x88,0x88,0x28,0x28,0x28,0xa8,0x28,0xe8,0x08,0x50,0x20,
+/* 21257 0x5309 "匉" */
+0x10,0x10,0x3f,0x20,0x40,0xbf,0x02,0x12,0x0a,0x0a,0x02,0x7f,0x02,0x02,0x02,0x02,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x04,0x44,0x44,0x84,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 21258 0x530a "匊" */
+0x10,0x10,0x3f,0x20,0x42,0x92,0x0a,0x02,0x7f,0x07,0x0a,0x12,0x62,0x02,0x02,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x44,0x84,0x04,0xf4,0x04,0x84,0x44,0x24,0x04,0x28,0x10,
+/* 21259 0x530b "匋" */
+0x10,0x10,0x3f,0x20,0x48,0x8f,0x12,0x02,0x7f,0x02,0x12,0x12,0x1f,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xc4,0x04,0x04,0xf4,0x04,0x44,0x44,0xc4,0x44,0x28,0x10,
+/* 21260 0x530c "匌" */
+0x10,0x10,0x3f,0x22,0x45,0x88,0x10,0x6f,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x84,0x44,0xb4,0x04,0xc4,0x44,0x44,0xc4,0x04,0x28,0x10,
+/* 21261 0x530d "匍" */
+0x10,0x10,0x1f,0x22,0x42,0xbf,0x02,0x3f,0x22,0x3f,0x22,0x3f,0x22,0x22,0x22,0x20,
+0x00,0x00,0xfc,0x44,0x24,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x24,0xb4,0x48,
+/* 21262 0x530e "匎" */
+0x10,0x10,0x1f,0x24,0x7f,0x88,0x12,0x62,0x1f,0x12,0x1f,0x12,0x1f,0x02,0x01,0x00,
+0x00,0x00,0xfc,0x04,0xe4,0x84,0x44,0x34,0xc4,0x44,0xc4,0x44,0xc4,0x24,0xf4,0x08,
+/* 21263 0x530f "匏" */
+0x10,0x10,0xfe,0x28,0x45,0x82,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x28,0x10,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 21264 0x5310 "匐" */
+0x10,0x10,0x1f,0x20,0x7f,0x80,0x1f,0x10,0x1f,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,
+0x00,0x00,0xfc,0x04,0xe4,0x04,0xc4,0x44,0xc4,0x04,0xe4,0x24,0xe4,0x24,0xf4,0x28,
+/* 21265 0x5311 "匑" */
+0x10,0x10,0x3f,0x28,0x5e,0x92,0x1e,0x12,0x1e,0x12,0x7e,0x0a,0x12,0x2a,0x44,0x00,
+0x00,0x00,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x84,0x84,0xf4,0x14,0x14,0x54,0x28,0x10,
+/* 21266 0x5312 "匒" */
+0x10,0x10,0x1f,0x28,0x48,0xbf,0x0a,0x05,0x08,0x17,0x60,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x84,0x84,0xe4,0x84,0x04,0x84,0x44,0x34,0xc4,0x44,0x44,0xd4,0x48,
+/* 21267 0x5313 "匓" */
+0x10,0x10,0x3f,0x40,0xbd,0x25,0x25,0x3d,0x26,0x25,0x3c,0x20,0x28,0x2c,0x33,0x20,
+0x00,0x00,0xfc,0x04,0xe4,0x24,0x24,0x34,0x04,0xe4,0x24,0xa4,0x44,0xa4,0x28,0x10,
+/* 21268 0x5314 "匔" */
+0x10,0x10,0x3f,0x28,0x5e,0x92,0x1e,0x12,0x1e,0x12,0x7e,0x0a,0x12,0x2a,0x44,0x00,
+0x00,0x00,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x04,0xf4,0x94,0x94,0xf4,0x04,0x28,0x10,
+/* 21269 0x5315 "匕" */
+0x10,0x10,0x10,0x10,0x10,0x10,0x13,0x1c,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,
+0x00,0x00,0x00,0x08,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 21270 0x5316 "化" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x30,0x50,0x91,0x12,0x14,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 21271 0x5317 "北" */
+0x04,0x04,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x1c,0xe4,0x44,0x04,
+0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 21272 0x5318 "匘" */
+0x40,0x41,0x42,0x49,0x48,0x50,0x60,0x43,0x42,0x42,0x42,0x4a,0x4a,0x4a,0x3b,0x02,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 21273 0x5319 "匙" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x40,0x40,0x44,0x48,0x50,0x60,0x40,0x44,0x44,0x44,0x3c,0x00,0x00,0xfe,0x00,
+/* 21274 0x531a "匚" */
+0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 21275 0x531b "匛" */
+0x00,0x7f,0x42,0x42,0x47,0x44,0x48,0x50,0x40,0x40,0x41,0x46,0x58,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x20,0x20,0x40,0xa0,0x10,0x08,0x04,0x00,0xfe,0x00,
+/* 21276 0x531c "匜" */
+0x00,0x7f,0x40,0x40,0x44,0x44,0x47,0x5c,0x44,0x44,0x44,0x44,0x43,0x40,0x7f,0x00,
+0x00,0xfc,0x80,0x80,0x80,0xf0,0x90,0x90,0xd0,0xa4,0x84,0x04,0xfc,0x00,0xfe,0x00,
+/* 21277 0x531d "匝" */
+0x00,0x7f,0x40,0x40,0x40,0x4f,0x48,0x48,0x48,0x48,0x48,0x48,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x88,0xa8,0x90,0x80,0x80,0xfe,0x00,
+/* 21278 0x531e "匞" */
+0x00,0x7f,0x40,0x40,0x4f,0x40,0x40,0x40,0x40,0x40,0x40,0x5f,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,0x00,0xfe,0x00,
+/* 21279 0x531f "匟" */
+0x00,0x7f,0x40,0x41,0x40,0x5f,0x40,0x43,0x42,0x42,0x42,0x44,0x48,0x50,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0x80,0xfc,0x00,0xe0,0x20,0x20,0x24,0x24,0x1c,0x00,0xfe,0x00,
+/* 21280 0x5320 "匠" */
+0x00,0x7f,0x40,0x40,0x47,0x44,0x44,0x47,0x44,0x44,0x44,0x48,0x48,0x50,0x7f,0x00,
+0x00,0xfc,0x00,0x38,0xc0,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 21281 0x5321 "匡" */
+0x00,0x7f,0x40,0x40,0x4f,0x40,0x40,0x47,0x40,0x40,0x40,0x4f,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x80,0x80,0xf0,0x80,0x80,0x80,0xf8,0x00,0x00,0xfe,0x00,
+/* 21282 0x5322 "匢" */
+0x00,0x7f,0x44,0x44,0x47,0x49,0x51,0x62,0x44,0x48,0x51,0x42,0x44,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x28,0x28,0x48,0x48,0x88,0x08,0x50,0x20,0x00,0xfe,0x00,
+/* 21283 0x5323 "匣" */
+0x00,0x7f,0x40,0x40,0x4f,0x48,0x48,0x4f,0x48,0x48,0x4f,0x48,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x80,0x80,0xfe,0x00,
+/* 21284 0x5324 "匤" */
+0x00,0x7f,0x40,0x40,0x5f,0x40,0x40,0x4f,0x40,0x40,0x40,0x5f,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xfc,0x80,0x80,0xf8,0x80,0xa0,0x90,0xfc,0x00,0x00,0xfe,0x00,
+/* 21285 0x5325 "匥" */
+0x00,0x7f,0x42,0x44,0x48,0x5f,0x40,0x44,0x44,0x7f,0x44,0x44,0x48,0x50,0x7f,0x00,
+0x00,0xfc,0x00,0x10,0x08,0xfc,0x04,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 21286 0x5326 "匦" */
+0x00,0x7f,0x44,0x44,0x5f,0x48,0x52,0x5f,0x42,0x43,0x5e,0x4a,0x42,0x42,0x7f,0x00,
+0x00,0xfc,0x20,0x20,0xa0,0x78,0x28,0xa8,0x28,0xa8,0x2a,0x2a,0x46,0x80,0xfe,0x00,
+/* 21287 0x5327 "匧" */
+0x00,0x7f,0x40,0x40,0x5f,0x40,0x44,0x44,0x4a,0x51,0x41,0x42,0x44,0x48,0x7f,0x00,
+0x00,0xfc,0x80,0x80,0xfc,0x80,0x90,0x90,0xa8,0x44,0x20,0x20,0x10,0x10,0xfe,0x00,
+/* 21288 0x5328 "匨" */
+0x00,0x7f,0x42,0x52,0x52,0x5e,0x43,0x42,0x7e,0x52,0x52,0x52,0x62,0x42,0x7f,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xf8,0x00,0x00,0xfe,0x00,
+/* 21289 0x5329 "匩" */
+0x00,0x7f,0x40,0x48,0x48,0x4f,0x40,0x5f,0x40,0x40,0x4f,0x40,0x5f,0x40,0x7f,0x00,
+0x00,0xfc,0x80,0x88,0x88,0xf8,0x80,0xfc,0x00,0x80,0xf8,0x80,0xfc,0x00,0xfe,0x00,
+/* 21290 0x532a "匪" */
+0x00,0x7f,0x42,0x42,0x7e,0x42,0x42,0x5e,0x42,0x42,0x7e,0x42,0x42,0x42,0x7f,0x00,
+0x00,0xfc,0x40,0x40,0x7c,0x40,0x40,0x78,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x00,
+/* 21291 0x532b "匫" */
+0x00,0x7f,0x44,0x4f,0x51,0x62,0x44,0x49,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0xfc,0x24,0x44,0xa8,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,
+/* 21292 0x532c "匬" */
+0x7f,0x40,0x41,0x42,0x4c,0x73,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x4a,0x49,0x7f,
+0xfe,0x80,0x40,0x20,0x18,0xf6,0x00,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x08,0xfe,
+/* 21293 0x532d "匭" */
+0x00,0x7f,0x44,0x5f,0x44,0x5f,0x55,0x5f,0x55,0x5f,0x44,0x5f,0x44,0x44,0x7f,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x78,0x28,0x28,0x28,0x28,0x2a,0x2a,0x46,0x80,0xfe,0x00,
+/* 21294 0x532e "匮" */
+0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,0x7f,0x40,0x4f,0x48,0x49,0x42,0x4c,0x7f,0x00,
+0x00,0xfc,0x80,0xf8,0x88,0xf8,0x80,0xfe,0x00,0xf8,0x88,0x68,0x10,0x08,0xfe,0x00,
+/* 21295 0x532f "匯" */
+0x00,0x7f,0x40,0x48,0x45,0x61,0x57,0x45,0x49,0x79,0x49,0x49,0x49,0x40,0x7f,0x00,
+0x00,0xfc,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,0x00,0xfe,0x00,
+/* 21296 0x5330 "匰" */
+0x7f,0x40,0x5f,0x51,0x5f,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x7f,0x40,0x40,0x7f,
+0xfe,0x00,0x7c,0x44,0x7c,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfe,0x80,0x80,0xfe,
+/* 21297 0x5331 "匱" */
+0x7f,0x40,0x4f,0x48,0x4f,0x40,0x7f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x44,0x48,0x7f,
+0xfe,0x80,0xf8,0x88,0xf8,0x80,0xfe,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0xfe,
+/* 21298 0x5332 "匲" */
+0x00,0x7f,0x40,0x5f,0x42,0x4c,0x77,0x44,0x47,0x40,0x4f,0x49,0x4f,0x40,0x7f,0x00,
+0x00,0xfc,0x80,0xfc,0x20,0x18,0xf6,0x10,0xf0,0x00,0x78,0x48,0x78,0x00,0xfe,0x00,
+/* 21299 0x5333 "匳" */
+0x7f,0x40,0x41,0x42,0x4c,0x73,0x40,0x5f,0x51,0x51,0x5f,0x44,0x4a,0x51,0x40,0x7f,
+0xfe,0x80,0x40,0x20,0x18,0xe6,0x00,0x7c,0x44,0x44,0x7c,0x10,0x28,0x44,0x00,0xfe,
+/* 21300 0x5334 "匴" */
+0x7f,0x48,0x4f,0x54,0x6f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x42,0x5f,0x44,0x48,0x7f,
+0xfe,0x40,0x7c,0x90,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfc,0x20,0x20,0xfe,
+/* 21301 0x5335 "匵" */
+0x7f,0x40,0x4f,0x40,0x4f,0x49,0x4f,0x44,0x47,0x44,0x47,0x44,0x47,0x42,0x44,0x7f,
+0xfe,0x80,0xf8,0x80,0xf8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0xfe,
+/* 21302 0x5336 "匶" */
+0x7f,0x44,0x5f,0x44,0x4f,0x58,0x6f,0x48,0x4f,0x48,0x4f,0x44,0x47,0x44,0x7f,0x00,
+0xfe,0x10,0xfc,0x90,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x08,0x38,0x08,0xfe,0x00,
+/* 21303 0x5337 "匷" */
+0x7f,0x49,0x4f,0x49,0x4f,0x49,0x4f,0x44,0x47,0x4c,0x57,0x64,0x47,0x44,0x7f,0x00,
+0xfe,0x48,0x78,0x48,0x78,0x48,0x78,0x80,0xf8,0x80,0xf0,0x80,0xfc,0x00,0xfe,0x00,
+/* 21304 0x5338 "匸" */
+0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 21305 0x5339 "匹" */
+0x00,0x7f,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x48,0x48,0x50,0x40,0x7f,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,0x00,0x00,0xfe,0x00,
+/* 21306 0x533a "区" */
+0x00,0x7f,0x40,0x40,0x44,0x42,0x41,0x40,0x41,0x42,0x44,0x48,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x10,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x10,0x00,0x00,0xfe,0x00,
+/* 21307 0x533b "医" */
+0x00,0x7f,0x44,0x44,0x4f,0x50,0x40,0x5f,0x40,0x41,0x42,0x44,0x58,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x80,0x80,0xfc,0x80,0x40,0x20,0x10,0x08,0x00,0xfe,0x00,
+/* 21308 0x533c "匼" */
+0x00,0x7f,0x40,0x41,0x42,0x44,0x5b,0x40,0x47,0x44,0x44,0x47,0x44,0x40,0x7f,0x00,
+0x00,0xfc,0x80,0x40,0x20,0x10,0xec,0x00,0xf0,0x10,0x10,0xf0,0x10,0x00,0xfe,0x00,
+/* 21309 0x533d "匽" */
+0x7f,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x41,0x5f,0x42,0x47,0x40,0x43,0x4c,0x40,0x7f,
+0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x10,0x20,0xc0,0x30,0x08,0x00,0xfe,
+/* 21310 0x533e "匾" */
+0x00,0x7f,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x59,0x69,0x4f,0x49,0x49,0x40,0x7f,0x00,
+0x00,0xfc,0x80,0xf8,0x08,0xf8,0x00,0xfc,0x24,0x24,0xfc,0x24,0x2c,0x00,0xfe,0x00,
+/* 21311 0x533f "匿" */
+0x00,0x7f,0x42,0x42,0x5f,0x42,0x41,0x5f,0x42,0x47,0x4a,0x52,0x43,0x40,0x7f,0x00,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,
+/* 21312 0x5340 "區" */
+0x00,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x5e,0x52,0x52,0x5e,0x52,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x00,0x78,0x48,0x48,0x78,0x48,0x00,0xfe,0x00,
+/* 21313 0x5341 "十" */
+0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 21314 0x5342 "卂" */
+0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xd0,0x10,0x10,0x12,0x0a,0x0a,0x06,0x02,0x00,
+/* 21315 0x5343 "千" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x10,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 21316 0x5344 "卄" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 21317 0x5345 "卅" */
+0x10,0x11,0x11,0x11,0x11,0x11,0xff,0x11,0x11,0x11,0x11,0x11,0x11,0x21,0x20,0x40,
+0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 21318 0x5346 "卆" */
+0x02,0x02,0x3f,0x04,0x04,0x08,0x10,0x21,0x41,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 21319 0x5347 "升" */
+0x01,0x07,0x3c,0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21320 0x5348 "午" */
+0x08,0x08,0x08,0x1f,0x11,0x21,0x41,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 21321 0x5349 "卉" */
+0x01,0x01,0x01,0x7f,0x01,0x01,0x09,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21322 0x534a "半" */
+0x01,0x21,0x11,0x09,0x09,0x01,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0x08,0x08,0x10,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 21323 0x534b "卋" */
+0x01,0x01,0x01,0x7f,0x01,0x01,0x09,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x0f,0x08,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xe0,0x20,
+/* 21324 0x534c "卌" */
+0x20,0x24,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x20,
+0x10,0x90,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x10,
+/* 21325 0x534d "卍" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+0x04,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x80,0x80,0x80,0x80,0xfe,0x00,0x00,
+/* 21326 0x534e "华" */
+0x08,0x08,0x10,0x30,0x51,0x96,0x10,0x10,0x11,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x80,0x88,0x90,0xe0,0x80,0x84,0x84,0x7c,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 21327 0x534f "协" */
+0x20,0x20,0x20,0x20,0xfb,0x20,0x20,0x22,0x22,0x24,0x28,0x20,0x21,0x21,0x22,0x24,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x98,0x94,0x92,0x92,0x90,0x10,0x10,0x50,0x20,
+/* 21328 0x5350 "卐" */
+0x20,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,
+/* 21329 0x5351 "卑" */
+0x02,0x04,0x3f,0x21,0x21,0x3f,0x22,0x22,0x3f,0x08,0x10,0xff,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,
+/* 21330 0x5352 "卒" */
+0x02,0x01,0x7f,0x08,0x08,0x08,0x14,0x22,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x50,0x88,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 21331 0x5353 "卓" */
+0x01,0x01,0x01,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 21332 0x5354 "協" */
+0x20,0x20,0x23,0x20,0xf8,0x21,0x22,0x20,0x24,0x2f,0x24,0x24,0x24,0x28,0x2a,0x31,
+0x40,0x40,0xfc,0x84,0x84,0x14,0x08,0x10,0x10,0xbe,0x92,0x92,0x92,0xa2,0xaa,0x44,
+/* 21333 0x5355 "单" */
+0x10,0x08,0x04,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x10,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 21334 0x5356 "卖" */
+0x01,0x01,0x3f,0x01,0x01,0x7f,0x04,0x02,0x12,0x08,0x09,0xff,0x02,0x04,0x18,0x60,
+0x00,0x00,0xf8,0x00,0x00,0xfc,0x04,0x88,0x80,0x80,0x00,0xfe,0x40,0x20,0x10,0x08,
+/* 21335 0x5357 "南" */
+0x01,0x01,0xff,0x01,0x01,0x7f,0x48,0x44,0x4f,0x41,0x41,0x5f,0x41,0x41,0x41,0x40,
+0x00,0x00,0xfe,0x00,0x00,0xfc,0x24,0x44,0xe4,0x04,0x04,0xf4,0x04,0x04,0x14,0x08,
+/* 21336 0x5358 "単" */
+0x22,0x11,0x11,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x08,0x08,0x10,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 21337 0x5359 "卙" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x52,0x61,0x40,0x7f,0x00,
+0x10,0x10,0x90,0x10,0x10,0x10,0x7e,0x10,0x10,0xd0,0x10,0x10,0x10,0x10,0x90,0x10,
+/* 21338 0x535a "博" */
+0x20,0x20,0x2f,0x20,0x27,0xfc,0x27,0x24,0x27,0x24,0x20,0x2f,0x22,0x21,0x21,0x20,
+0x50,0x48,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x08,0xfe,0x08,0x08,0x28,0x10,
+/* 21339 0x535b "卛" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x01,0xff,0x01,0x01,0x01,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 21340 0x535c "卜" */
+0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 21341 0x535d "卝" */
+0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 21342 0x535e "卞" */
+0x02,0x01,0x01,0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x40,0x20,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 21343 0x535f "卟" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 21344 0x5360 "占" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21345 0x5361 "卡" */
+0x02,0x02,0x03,0x02,0x02,0x02,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x40,0x20,0x10,0x08,0x00,0x00,0x00,
+/* 21346 0x5362 "卢" */
+0x01,0x01,0x01,0x01,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 21347 0x5363 "卣" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0x88,0x08,0x08,0xf8,0x08,
+/* 21348 0x5364 "卤" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x24,0x22,0x21,0x22,0x24,0x28,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x48,0x88,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 21349 0x5365 "卥" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x29,0x25,0x22,0x25,0x28,0x21,0x22,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x28,0x28,0x48,0x48,0x88,0x48,0x28,0xf8,0x08,
+/* 21350 0x5366 "卦" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x08,0x08,0x7f,0x08,0x08,0x08,0x0f,0xf0,0x00,
+0x40,0x40,0x40,0x40,0x40,0x60,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0xc0,0x40,0x40,
+/* 21351 0x5367 "卧" */
+0x00,0x7f,0x48,0x48,0x48,0x7f,0x41,0x41,0x41,0x7f,0x48,0x48,0x48,0x7f,0x00,0x00,
+0x20,0xa0,0x20,0x20,0x20,0x30,0x28,0x24,0x22,0x22,0x20,0x20,0x20,0xa0,0x20,0x20,
+/* 21352 0x5368 "卨" */
+0x01,0x01,0x01,0x01,0x1f,0x10,0x1f,0x10,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0x90,0x90,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 21353 0x5369 "卩" */
+0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 21354 0x536a "卪" */
+0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0xf8,0x08,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,0x00,0x00,0x00,0x00,
+/* 21355 0x536b "卫" */
+0x00,0x7f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xff,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 21356 0x536c "卬" */
+0x00,0x06,0x78,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x4e,0x70,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xa8,0x90,0x80,0x80,0x80,
+/* 21357 0x536d "卭" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xa8,0x90,0x80,0x80,0x80,
+/* 21358 0x536e "卮" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x7c,0x80,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x50,0x24,0x04,0x04,0xfc,0x00,
+/* 21359 0x536f "卯" */
+0x0c,0x70,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x74,0x04,0x08,0x08,0x10,0x20,
+0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xa8,0x90,0x80,0x80,0x80,0x80,
+/* 21360 0x5370 "印" */
+0x00,0x06,0x78,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,0x4e,0x70,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xa8,0x90,0x80,0x80,0x80,
+/* 21361 0x5371 "危" */
+0x04,0x04,0x0f,0x10,0x20,0x5f,0x10,0x13,0x12,0x12,0x12,0x12,0x22,0x22,0x41,0x80,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x00,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 21362 0x5372 "卲" */
+0x00,0x00,0x7f,0x11,0x11,0x21,0x25,0x42,0x80,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21363 0x5373 "即" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x48,0x44,0x4a,0x52,0x60,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,0x40,
+/* 21364 0x5374 "却" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x10,0x10,0x24,0x42,0xff,0x41,0x00,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21365 0x5375 "卵" */
+0x0c,0x70,0x44,0x44,0x64,0x54,0x54,0x44,0x44,0x4c,0x74,0x04,0x08,0x08,0x10,0x20,
+0x00,0xfc,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0xa8,0x90,0x80,0x80,0x80,0x80,
+/* 21366 0x5376 "卶" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x24,0xc8,0x1f,0x21,0xd2,0x0c,0x08,0x30,0xc0,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21367 0x5377 "卷" */
+0x01,0x11,0x09,0x3f,0x02,0x02,0x7f,0x08,0x10,0x2f,0xc8,0x08,0x08,0x08,0x08,0x07,
+0x00,0x10,0x20,0xf8,0x00,0x00,0xfc,0x20,0x10,0xe8,0x26,0x20,0xa8,0x48,0x08,0xf8,
+/* 21368 0x5378 "卸" */
+0x20,0x20,0x3f,0x48,0x88,0x08,0x7f,0x08,0x08,0x2e,0x28,0x28,0x2f,0xf0,0x40,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21369 0x5379 "卹" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0xc8,0x40,0x40,0x40,
+/* 21370 0x537a "卺" */
+0x1f,0x00,0x7d,0x05,0x09,0x31,0xc5,0x02,0x3f,0x00,0x1f,0x10,0x10,0x10,0x10,0x0f,
+0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x00,0xf0,0x10,0x50,0x24,0x04,0xfc,
+/* 21371 0x537b "卻" */
+0x14,0x12,0x21,0x49,0x08,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21372 0x537c "卼" */
+0x00,0xfc,0x29,0x2a,0x2d,0x29,0x29,0x29,0x29,0x29,0x29,0x2a,0x2c,0x48,0x47,0x80,
+0x80,0x80,0xf8,0x08,0xfe,0x00,0x78,0x48,0x68,0x50,0x44,0x44,0x3c,0x02,0xfe,0x00,
+/* 21373 0x537d "卽" */
+0x08,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x00,0x40,0x40,0x7e,0x40,0x40,0x4c,0x70,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21374 0x537e "卾" */
+0x00,0x77,0x55,0x55,0x77,0x00,0x7f,0x00,0xff,0x20,0x3f,0x01,0x01,0x01,0x0a,0x04,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0xc4,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21375 0x537f "卿" */
+0x08,0x73,0x42,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x5b,0x6a,0x4a,0x12,0x12,0x23,0x42,
+0x00,0xde,0x52,0x52,0x52,0xd2,0x52,0x52,0x52,0xd2,0x12,0x9a,0x54,0xb0,0x10,0x10,
+/* 21376 0x5380 "厀" */
+0x08,0x08,0x7f,0x1c,0x2a,0x49,0x14,0x22,0x49,0x88,0x2a,0x1c,0x2a,0xc9,0x28,0x10,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 21377 0x5381 "厁" */
+0x08,0x14,0x22,0x5c,0x88,0x7f,0x08,0x2a,0x49,0x18,0x7f,0x01,0x01,0x01,0x01,0x01,
+0x08,0x48,0x28,0x88,0x48,0x0e,0xf8,0x08,0x08,0x08,0xfc,0x04,0x14,0x08,0x00,0x00,
+/* 21378 0x5382 "厂" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 21379 0x5383 "厃" */
+0x04,0x04,0x0f,0x10,0x20,0x5f,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 21380 0x5384 "厄" */
+0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x50,0x20,0x04,0x04,0x04,0xfc,0x00,
+/* 21381 0x5385 "厅" */
+0x00,0x3f,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x41,0x80,
+0x00,0xfe,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 21382 0x5386 "历" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x2f,0x20,0x20,0x21,0x21,0x22,0x22,0x44,0x48,0x90,
+0x00,0xfe,0x00,0x80,0x80,0x80,0xfc,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 21383 0x5387 "厇" */
+0x00,0x3f,0x20,0x20,0x20,0x27,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x00,0x10,0xf8,0x80,0x80,0x80,0xfe,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 21384 0x5388 "厈" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 21385 0x5389 "厉" */
+0x00,0x3f,0x20,0x20,0x2f,0x21,0x21,0x21,0x21,0x21,0x21,0x22,0x22,0x44,0x48,0x90,
+0x00,0xfe,0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21386 0x538a "厊" */
+0x00,0x3f,0x20,0x20,0x27,0x20,0x22,0x22,0x24,0x27,0x20,0x20,0x21,0x42,0x4c,0x80,
+0x00,0xfe,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x50,0x90,0x10,0x10,0x50,0x20,
+/* 21387 0x538b "压" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x40,0x5f,0x80,
+0x00,0xfe,0x00,0x80,0x80,0x80,0x80,0xfc,0x80,0x80,0x90,0x88,0x88,0x80,0xfe,0x00,
+/* 21388 0x538c "厌" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x2f,0x20,0x21,0x21,0x22,0x22,0x44,0x48,0x90,
+0x00,0xfe,0x00,0x80,0x90,0x88,0x80,0xfc,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 21389 0x538d "厍" */
+0x00,0x3f,0x20,0x20,0x20,0x2f,0x21,0x22,0x24,0x27,0x20,0x20,0x4f,0x40,0x80,0x00,
+0x00,0xfe,0x00,0x80,0x80,0xfc,0x00,0x40,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,
+/* 21390 0x538e "厎" */
+0x00,0x3f,0x20,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x24,0x24,0x45,0x46,0x84,
+0x00,0xfe,0x00,0x00,0x3c,0xc0,0x40,0x40,0x40,0xfe,0x20,0x20,0x12,0x0a,0x46,0x22,
+/* 21391 0x538f "厏" */
+0x00,0x3f,0x20,0x22,0x22,0x23,0x24,0x24,0x28,0x30,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x00,0x00,0x00,0xfe,0x80,0x80,0xfc,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 21392 0x5390 "厐" */
+0x00,0x3f,0x20,0x22,0x22,0x22,0x2f,0x22,0x22,0x22,0x24,0x24,0x48,0x48,0x93,0x20,
+0x00,0xfe,0x00,0x20,0x10,0x00,0xfc,0x40,0x40,0x48,0x50,0x60,0x42,0xc2,0x3e,0x00,
+/* 21393 0x5391 "厑" */
+0x00,0x3f,0x20,0x20,0x2f,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x2f,0x48,0x40,0x80,
+0x00,0xfe,0x00,0x20,0xa0,0xa2,0xa4,0xa8,0xb0,0xa0,0xa0,0xa2,0xa2,0xa2,0x1e,0x00,
+/* 21394 0x5392 "厒" */
+0x00,0x3f,0x20,0x21,0x21,0x23,0x22,0x24,0x20,0x3f,0x20,0x24,0x24,0x44,0x47,0x80,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 21395 0x5393 "厓" */
+0x00,0x3f,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,0x20,0x20,0x27,0x20,0x40,0x4f,0x80,
+0x00,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 21396 0x5394 "厔" */
+0x00,0x3f,0x20,0x20,0x27,0x20,0x21,0x22,0x27,0x20,0x20,0x27,0x20,0x40,0x4f,0x80,
+0x00,0xfe,0x00,0x00,0xfc,0x80,0x10,0x08,0xfc,0x44,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 21397 0x5395 "厕" */
+0x00,0x3f,0x20,0x2f,0x28,0x28,0x2a,0x2a,0x2a,0x2a,0x2a,0x22,0x25,0x44,0x48,0x90,
+0x00,0xfe,0x00,0x84,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x04,0x84,0x94,0x08,
+/* 21398 0x5396 "厖" */
+0x00,0x3f,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x28,0x49,0x56,0xa0,
+0x00,0xfe,0x10,0x08,0xfe,0x90,0xa0,0xc8,0x90,0xa4,0xc8,0x92,0xe2,0x82,0x7e,0x00,
+/* 21399 0x5397 "厗" */
+0x00,0x3f,0x20,0x20,0x27,0x20,0x21,0x20,0x2f,0x20,0x20,0x27,0x20,0x40,0x40,0x80,
+0x00,0xfe,0x80,0x40,0xfc,0x00,0x10,0xa0,0xfe,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,
+/* 21400 0x5398 "厘" */
+0x00,0x3f,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x20,0x20,0x27,0x40,0x40,0x8f,
+0x00,0xfe,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,
+/* 21401 0x5399 "厙" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x27,0x24,0x27,0x24,0x27,0x20,0x2f,0x40,0x40,0x80,
+0x00,0xfe,0x40,0x40,0xfc,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfe,0x40,0x40,0x40,
+/* 21402 0x539a "厚" */
+0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x20,0x27,0x20,0x20,0x2f,0x40,0x41,0x80,
+0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x10,0x20,0xfe,0x40,0x40,0x80,
+/* 21403 0x539b "厛" */
+0x00,0x3f,0x20,0x20,0x2f,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x2f,0x40,0x40,0x81,
+0x00,0xfe,0x00,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 21404 0x539c "厜" */
+0x00,0x3f,0x20,0x20,0x27,0x20,0x27,0x22,0x22,0x2f,0x22,0x22,0x2f,0x40,0x40,0x87,
+0x00,0xfe,0x00,0x38,0xc0,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfe,0x40,0x40,0xfc,
+/* 21405 0x539d "厝" */
+0x00,0x3f,0x22,0x22,0x2f,0x22,0x22,0x3f,0x20,0x27,0x24,0x24,0x47,0x44,0x84,0x07,
+0x00,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 21406 0x539e "厞" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x2f,0x21,0x21,0x3f,0x21,0x41,0x41,0x81,
+0x00,0xfe,0x20,0x20,0x20,0x3e,0x20,0x20,0x3c,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 21407 0x539f "原" */
+0x00,0x3f,0x20,0x21,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x20,0x24,0x48,0x52,0x81,
+0x00,0xfe,0x80,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x80,0x90,0x88,0x84,0x00,
+/* 21408 0x53a0 "厠" */
+0x00,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x28,0x2f,0x28,0x28,0x2f,0x20,0x49,0x48,0x90,
+0x00,0xfe,0x00,0x84,0x84,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x04,0x94,0x88,
+/* 21409 0x53a1 "厡" */
+0x00,0x3f,0x20,0x21,0x27,0x24,0x27,0x24,0x27,0x20,0x27,0x21,0x22,0x44,0x59,0x80,
+0x00,0xfe,0x80,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x44,0x68,0x50,0x48,0x46,0x80,
+/* 21410 0x53a2 "厢" */
+0x00,0x3f,0x22,0x22,0x22,0x2f,0x22,0x26,0x27,0x2a,0x2a,0x32,0x22,0x42,0x42,0x82,
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0xc4,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 21411 0x53a3 "厣" */
+0x00,0x3f,0x20,0x20,0x3f,0x21,0x26,0x38,0x2f,0x28,0x2f,0x28,0x4f,0x48,0x80,0x00,
+0x00,0xfe,0xa0,0x90,0xfe,0x40,0x30,0x0e,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x80,0x80,
+/* 21412 0x53a4 "厤" */
+0x00,0x3f,0x20,0x23,0x2e,0x22,0x22,0x3f,0x22,0x27,0x26,0x2a,0x2a,0x52,0x42,0x82,
+0x00,0xfe,0x00,0x0c,0x70,0x10,0x10,0xfe,0x10,0x38,0xb4,0x54,0x52,0x90,0x10,0x10,
+/* 21413 0x53a5 "厥" */
+0x00,0x3f,0x20,0x28,0x25,0x2f,0x22,0x22,0x2a,0x2a,0x2f,0x22,0x42,0x44,0x84,0x08,
+0x00,0xfe,0x00,0x90,0x10,0xbe,0x22,0x44,0x90,0x90,0x90,0x10,0x28,0x28,0x44,0x82,
+/* 21414 0x53a6 "厦" */
+0x3f,0x20,0x3f,0x21,0x27,0x24,0x27,0x24,0x27,0x24,0x27,0x22,0x47,0x4a,0x81,0x1e,
+0xfe,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf0,0x0e,
+/* 21415 0x53a7 "厧" */
+0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x27,0x24,0x7f,0x42,0x84,
+0x00,0xfe,0x80,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,
+/* 21416 0x53a8 "厨" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x29,0x29,0x29,0x2f,0x20,0x29,0x26,0x43,0x5c,0x88,
+0x00,0xfe,0x08,0x88,0x08,0x08,0x7e,0x08,0x08,0x48,0x28,0x08,0x08,0x88,0x28,0x10,
+/* 21417 0x53a9 "厩" */
+0x00,0x3f,0x20,0x2f,0x29,0x29,0x2f,0x29,0x29,0x2f,0x28,0x2a,0x29,0x4b,0x4d,0x88,
+0x00,0xfe,0x00,0x7e,0x10,0x10,0x50,0x50,0x7e,0x10,0x28,0x28,0x28,0x4a,0x4a,0x86,
+/* 21418 0x53aa "厪" */
+0x00,0x3f,0x21,0x2f,0x21,0x21,0x20,0x27,0x24,0x27,0x20,0x2f,0x20,0x47,0x40,0x8f,
+0x00,0xfe,0x10,0xfe,0x10,0xf0,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x40,0xfc,0x40,0xfe,
+/* 21419 0x53ab "厫" */
+0x00,0x3f,0x22,0x22,0x2f,0x22,0x2f,0x22,0x3f,0x24,0x27,0x24,0x24,0x48,0x4a,0x91,
+0x00,0xfe,0x10,0x10,0x90,0x1e,0xa4,0x24,0xd4,0x14,0x94,0x88,0x88,0x94,0xa4,0x42,
+/* 21420 0x53ac "厬" */
+0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x22,0x27,0x2d,0x27,0x38,0x47,0x44,0x87,0x04,
+0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xb0,0x28,0xfe,0x00,0xf8,0x08,0xf8,0x08,
+/* 21421 0x53ad "厭" */
+0x00,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x4f,0x48,0x89,
+0x00,0xfe,0x10,0x94,0x92,0x90,0xfe,0x90,0x10,0x90,0x90,0x90,0xa8,0xa8,0xc4,0x82,
+/* 21422 0x53ae "厮" */
+0x00,0x3f,0x29,0x29,0x3f,0x29,0x29,0x2f,0x29,0x2f,0x29,0x29,0x5f,0x40,0x8a,0x11,
+0x00,0xfe,0x00,0x0c,0xb0,0x20,0x20,0x3e,0x28,0x28,0x28,0x28,0xa8,0x48,0x88,0x08,
+/* 21423 0x53af "厯" */
+0x00,0x3f,0x22,0x22,0x3f,0x27,0x2a,0x32,0x22,0x22,0x20,0x24,0x24,0x44,0x43,0x80,
+0x00,0xfe,0x10,0x10,0xfe,0x18,0xb4,0x52,0x10,0x10,0x80,0x44,0x52,0x12,0xf0,0x00,
+/* 21424 0x53b0 "厰" */
+0x00,0x7f,0x42,0x52,0x4a,0x4a,0x5f,0x50,0x57,0x55,0x55,0x57,0x50,0x51,0x50,0x80,
+0x00,0xfe,0x08,0x48,0x50,0x9e,0xe4,0x54,0x54,0x54,0x48,0x48,0x48,0x54,0x94,0x22,
+/* 21425 0x53b1 "厱" */
+0x00,0x3f,0x20,0x20,0x21,0x22,0x2d,0x20,0x27,0x24,0x24,0x27,0x21,0x42,0x44,0x88,
+0x00,0xfe,0x40,0xa0,0x10,0x08,0xf6,0x00,0xbc,0xa4,0xa4,0xbc,0x10,0xa8,0x44,0x82,
+/* 21426 0x53b2 "厲" */
+0x00,0x3f,0x21,0x2f,0x21,0x23,0x22,0x23,0x22,0x23,0x20,0x27,0x24,0x45,0x44,0x84,
+0x00,0xfe,0x10,0xfe,0x10,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x54,0xf4,0x14,0x0c,
+/* 21427 0x53b3 "厳" */
+0x11,0x08,0x08,0x3f,0x20,0x27,0x21,0x2f,0x24,0x27,0x24,0x27,0x24,0x5f,0x40,0x80,
+0x04,0x84,0x88,0xfe,0x00,0x10,0x1e,0xd4,0xa4,0x94,0x94,0x88,0xe8,0x94,0xa4,0xc2,
+/* 21428 0x53b4 "厴" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x20,0x27,0x24,0x27,0x44,0x47,0x80,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0x94,0xa2,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x40,
+/* 21429 0x53b5 "厵" */
+0x3f,0x20,0x2f,0x28,0x2f,0x44,0x4a,0x81,0x7e,0x48,0x5e,0x52,0x5e,0x48,0x6a,0x99,
+0xfe,0x80,0xf8,0x08,0xf8,0x90,0x88,0x00,0xfe,0x90,0xbc,0xa4,0xbc,0x90,0xd4,0x30,
+/* 21430 0x53b6 "厶" */
+0x02,0x02,0x02,0x02,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x7f,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x10,0xf8,0x08,0x08,0x00,
+/* 21431 0x53b7 "厷" */
+0x02,0x02,0x02,0xff,0x04,0x04,0x04,0x08,0x08,0x10,0x11,0x22,0x44,0x8f,0x04,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x10,0x08,0xfc,0x04,0x04,
+/* 21432 0x53b8 "厸" */
+0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x24,0x24,0x42,0xfe,0x42,0x02,0x00,
+0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x24,0x24,0x42,0xfe,0x42,0x02,0x00,
+/* 21433 0x53b9 "厹" */
+0x02,0x02,0x3f,0x02,0x02,0x04,0x04,0x08,0x31,0xc1,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x00,0x00,0xe0,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,
+/* 21434 0x53ba "厺" */
+0x01,0x01,0x01,0xff,0x02,0x04,0x09,0x31,0xc2,0x02,0x04,0x08,0x10,0x3f,0x10,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,0x20,0x10,0x08,0xfc,0x04,0x04,
+/* 21435 0x53bb "去" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0xff,0x02,0x02,0x04,0x08,0x10,0x3f,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 21436 0x53bc "厼" */
+0x02,0x02,0x04,0x08,0x10,0x3f,0x11,0x01,0x09,0x09,0x11,0x21,0x41,0x01,0x05,0x02,
+0x00,0x00,0x00,0x20,0x10,0xf8,0x08,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,
+/* 21437 0x53bd "厽" */
+0x02,0x02,0x04,0x08,0x10,0x3f,0x00,0x10,0x10,0x10,0x20,0x24,0x42,0xfe,0x42,0x00,
+0x00,0x00,0x00,0x20,0x10,0xf8,0x08,0x10,0x10,0x10,0x20,0x24,0x42,0xfe,0x42,0x00,
+/* 21438 0x53be "厾" */
+0x00,0x7f,0x04,0x04,0x04,0x3f,0x04,0x04,0x7f,0x04,0x08,0x11,0x20,0x7f,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x90,0x10,0x10,0xd0,0x10,0x10,0x12,0x8a,0xca,0x46,0x02,
+/* 21439 0x53bf "县" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0xff,0x04,0x08,0x10,0x3f,0x10,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,0x20,0x10,0xf8,0x08,
+/* 21440 0x53c0 "叀" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x04,0x08,0x10,0x3f,0x00,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x20,0x10,0xf8,0x08,
+/* 21441 0x53c1 "叁" */
+0x02,0x04,0x08,0x1f,0x02,0x7f,0x08,0x10,0x27,0xc0,0x00,0x0f,0x00,0x00,0x3f,0x00,
+0x00,0x40,0x20,0xf0,0x00,0xfc,0x20,0x10,0xc8,0x06,0x00,0xe0,0x00,0x00,0xf8,0x00,
+/* 21442 0x53c2 "参" */
+0x02,0x04,0x08,0x1f,0x02,0x7f,0x08,0x10,0x23,0xcc,0x01,0x06,0x18,0x00,0x07,0x78,
+0x00,0x40,0x20,0xf0,0x00,0xfc,0x20,0x90,0x08,0x46,0x80,0x10,0x20,0xc0,0x00,0x00,
+/* 21443 0x53c3 "參" */
+0x04,0x08,0x1f,0x10,0x24,0x7e,0x01,0x06,0x18,0xe3,0x0c,0x31,0x06,0x38,0x07,0x78,
+0x00,0x20,0xf0,0x20,0x48,0xfc,0x00,0xc0,0xb0,0x0e,0x40,0x90,0x20,0xc0,0x00,0x00,
+/* 21444 0x53c4 "叄" */
+0x04,0x08,0x1f,0x10,0x24,0x7e,0x01,0x06,0x18,0xe0,0x0f,0x00,0x1f,0x00,0x7f,0x00,
+0x00,0x20,0xf0,0x20,0x48,0xfc,0x00,0xc0,0x30,0x0e,0xe0,0x00,0xf0,0x00,0xfc,0x00,
+/* 21445 0x53c5 "叅" */
+0x04,0x08,0x1f,0x10,0x24,0x7e,0x01,0x06,0x18,0xe2,0x02,0x12,0x12,0x22,0x0a,0x04,
+0x00,0x20,0xf0,0x20,0x48,0xfc,0x00,0xc0,0x30,0x0e,0x20,0x90,0x48,0x48,0x00,0x00,
+/* 21446 0x53c6 "叆" */
+0x00,0x03,0x78,0x02,0x01,0x03,0xfe,0x10,0x13,0x20,0x28,0x45,0xfd,0x42,0x04,0x01,
+0x0e,0xf0,0x44,0x24,0x08,0xfe,0x42,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 21447 0x53c7 "叇" */
+0x00,0x02,0x79,0x00,0x00,0x00,0xfb,0x21,0x21,0x41,0x51,0x49,0xf9,0x49,0x02,0x04,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x92,0x54,0x38,0x54,0x92,0x30,0x00,0xfe,0x00,
+/* 21448 0x53c8 "又" */
+0x00,0x3f,0x10,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 21449 0x53c9 "叉" */
+0x00,0x3f,0x10,0x12,0x11,0x09,0x08,0x04,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 21450 0x53ca "及" */
+0x00,0x3f,0x08,0x08,0x08,0x08,0x0c,0x0a,0x0a,0x09,0x11,0x10,0x20,0x20,0x43,0x8c,
+0x00,0xe0,0x20,0x20,0x40,0x40,0xf8,0x08,0x08,0x10,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 21451 0x53cb "友" */
+0x02,0x02,0x02,0xff,0x04,0x04,0x0f,0x0a,0x12,0x11,0x21,0x40,0x81,0x06,0x18,0x60,
+0x00,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x20,0x40,0x80,0x40,0x20,0x18,0x06,
+/* 21452 0x53cc "双" */
+0x00,0x00,0xfd,0x04,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x44,0x81,0x02,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 21453 0x53cd "反" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x24,0x24,0x22,0x22,0x21,0x20,0x41,0x42,0x8c,0x30,
+0x10,0xf8,0x00,0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0x40,0x80,0x40,0x20,0x18,0x06,
+/* 21454 0x53ce "収" */
+0x04,0x04,0x45,0x44,0x44,0x44,0x44,0x44,0x4c,0x54,0x64,0x44,0x04,0x04,0x05,0x06,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 21455 0x53cf "叏" */
+0x02,0x02,0x3f,0x02,0x02,0x02,0xff,0x02,0x02,0x3f,0x10,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x70,0x0e,
+/* 21456 0x53d0 "叐" */
+0x00,0x3f,0x01,0x01,0x7f,0x02,0x04,0x07,0x0a,0x0a,0x11,0x20,0x40,0x80,0x03,0x0c,
+0xfc,0x00,0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 21457 0x53d1 "发" */
+0x01,0x11,0x11,0x22,0x3f,0x02,0x04,0x07,0x0a,0x09,0x11,0x10,0x20,0x40,0x03,0x1c,
+0x00,0x10,0x08,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 21458 0x53d2 "叒" */
+0x00,0x3f,0x00,0x1e,0x01,0x06,0x18,0xe0,0x00,0x3e,0x02,0x22,0x14,0x08,0x34,0xc3,
+0x00,0xf0,0x20,0x40,0x80,0x60,0x18,0x04,0x00,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 21459 0x53d3 "叓" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x21,0x3f,0x01,0x3f,0x10,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xf0,0x10,0x20,0x40,0x80,0x70,0x0e,
+/* 21460 0x53d4 "叔" */
+0x08,0x08,0x0e,0x08,0x08,0x08,0xff,0x00,0x08,0x08,0x4a,0x49,0x89,0x08,0x28,0x11,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 21461 0x53d5 "叕" */
+0x00,0x3e,0x02,0x22,0x14,0x08,0x34,0xc3,0x00,0x3e,0x02,0x22,0x14,0x08,0x34,0xc3,
+0x00,0xf8,0x08,0x88,0x50,0x20,0xd0,0x08,0x00,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 21462 0x53d6 "取" */
+0x00,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x27,0xfa,0x42,0x02,0x02,0x02,
+0x00,0x80,0xfc,0x44,0x44,0x44,0x44,0x44,0x28,0x28,0xa8,0x10,0x10,0x28,0x44,0x82,
+/* 21463 0x53d7 "受" */
+0x00,0x00,0x3f,0x11,0x08,0x7f,0x40,0x80,0x3f,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x08,0x7c,0x88,0x08,0x90,0xfe,0x02,0x04,0xf0,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 21464 0x53d8 "变" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x44,0x00,0x3f,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x00,0xf0,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 21465 0x53d9 "叙" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x08,0x2a,0x29,0x49,0x88,0x28,0x11,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 21466 0x53da "叚" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x20,0x20,0x3e,0x20,0x20,0x3e,0x20,0x20,0x20,0x23,
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x00,0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc4,0x02,
+/* 21467 0x53db "叛" */
+0x10,0x10,0x95,0x59,0x11,0x7d,0x11,0x11,0xff,0x11,0x11,0x11,0x21,0x22,0x42,0x84,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 21468 0x53dc "叜" */
+0x02,0x01,0x7f,0x41,0x91,0x22,0x04,0x18,0xe0,0x3f,0x10,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x00,0xfe,0x12,0x24,0xc0,0x30,0x0c,0x02,0xf0,0x10,0x20,0x40,0x80,0x70,0x0e,
+/* 21469 0x53dd "叝" */
+0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x24,0x42,0xfe,0x42,0x00,
+0x00,0xfc,0x84,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0xa8,0xc4,0x82,
+/* 21470 0x53de "叞" */
+0x00,0x7f,0x41,0x41,0x7f,0x40,0x5f,0x40,0x40,0x7f,0x44,0x55,0x94,0xa4,0x14,0x08,
+0x00,0x00,0x7c,0x24,0x24,0x24,0x24,0x28,0x28,0xa8,0x10,0x10,0xa8,0xa8,0x44,0x82,
+/* 21471 0x53df "叟" */
+0x01,0x05,0x39,0x21,0x21,0x3d,0x21,0x21,0x3f,0x01,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x00,0x78,0x08,0x08,0x78,0x08,0x08,0xf8,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 21472 0x53e0 "叠" */
+0x1f,0x04,0x03,0x0c,0x7e,0x22,0x1c,0x62,0x00,0xff,0x90,0x1f,0x10,0x1f,0x10,0xff,
+0xe0,0x40,0x80,0x40,0xfc,0x44,0x38,0x44,0x00,0xfe,0x12,0xf0,0x10,0xf0,0x10,0xfe,
+/* 21473 0x53e1 "叡" */
+0x10,0x1f,0x10,0xff,0x80,0x7f,0x2a,0x55,0xa2,0x7f,0xa2,0x3e,0x22,0x3e,0x22,0x3e,
+0x00,0x00,0x7c,0xa4,0xa4,0x24,0x24,0x28,0x28,0x28,0x90,0x10,0x28,0x28,0x44,0x82,
+/* 21474 0x53e2 "叢" */
+0x24,0x14,0xff,0x08,0x7f,0x01,0x3f,0x01,0xff,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,
+0x48,0x50,0xfe,0x20,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xfc,0x44,0x28,0x90,0x28,0xc6,
+/* 21475 0x53e3 "口" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 21476 0x53e4 "古" */
+0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x1f,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21477 0x53e5 "句" */
+0x08,0x08,0x10,0x1f,0x20,0x40,0x9f,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x50,0x20,
+/* 21478 0x53e6 "另" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x02,0x02,0x7f,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21479 0x53e7 "叧" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 21480 0x53e8 "叨" */
+0x00,0x00,0x7d,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x01,0x02,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 21481 0x53e9 "叩" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,0x80,
+/* 21482 0x53ea "只" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,0x08,0x08,0x10,0x20,0x40,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,0x20,0x10,0x08,0x04,0x04,
+/* 21483 0x53eb "叫" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x00,0x00,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0xb4,0xc4,0x84,0x04,0x04,0x04,0x04,
+/* 21484 0x53ec "召" */
+0x00,0x7f,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x9f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21485 0x53ed "叭" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,0x08,0x10,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 21486 0x53ee "叮" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 21487 0x53ef "可" */
+0x00,0x7f,0x00,0x00,0x1f,0x11,0x11,0x11,0x11,0x11,0x1f,0x11,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 21488 0x53f0 "台" */
+0x02,0x02,0x04,0x08,0x10,0x20,0x7f,0x20,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0x20,0x10,0x08,0xfc,0x04,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21489 0x53f1 "叱" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7d,0x44,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x42,0x44,0x48,0x50,0x60,0x40,0xc0,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 21490 0x53f2 "史" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x11,0x09,0x06,0x05,0x18,0xe0,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x80,0x70,0x0e,
+/* 21491 0x53f3 "右" */
+0x02,0x02,0x02,0xff,0x04,0x04,0x08,0x08,0x1f,0x28,0x48,0x88,0x08,0x08,0x0f,0x08,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21492 0x53f4 "叴" */
+0x02,0x02,0x3f,0x02,0x04,0x04,0x08,0x30,0xc0,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21493 0x53f5 "叵" */
+0x00,0x7f,0x40,0x40,0x40,0x47,0x44,0x44,0x44,0x44,0x47,0x44,0x40,0x40,0x7f,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,0x00,0xfe,0x00,
+/* 21494 0x53f6 "叶" */
+0x00,0x00,0x78,0x48,0x48,0x48,0x4b,0x48,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21495 0x53f7 "号" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x00,0xff,0x08,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xa0,0x40,
+/* 21496 0x53f8 "司" */
+0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xe8,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x28,0x10,
+/* 21497 0x53f9 "叹" */
+0x00,0x07,0x7a,0x4a,0x4a,0x49,0x49,0x49,0x48,0x48,0x78,0x48,0x00,0x01,0x02,0x0c,
+0x00,0xf8,0x08,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 21498 0x53fa "叺" */
+0x02,0x01,0x78,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x79,0x49,0x02,0x02,0x04,0x08,
+0x00,0x00,0x80,0x80,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 21499 0x53fb "叻" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x48,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 21500 0x53fc "叼" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x48,0x48,0x49,0x4a,0x78,0x48,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x04,0x04,0x14,0x24,0x44,0x84,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 21501 0x53fd "叽" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 21502 0x53fe "叾" */
+0x00,0x3f,0x00,0x01,0x01,0x01,0x01,0x05,0x02,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21503 0x53ff "叿" */
+0x00,0x00,0x7d,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x03,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 21504 0x5400 "吀" */
+0x00,0x00,0x7d,0x44,0x44,0x44,0x44,0x47,0x44,0x44,0x7c,0x44,0x00,0x00,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21505 0x5401 "吁" */
+0x00,0x01,0x78,0x48,0x48,0x48,0x48,0x4b,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 21506 0x5402 "吂" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21507 0x5403 "吃" */
+0x00,0x00,0x79,0x49,0x4a,0x4c,0x49,0x48,0x48,0x48,0x78,0x49,0x02,0x02,0x01,0x00,
+0x80,0x80,0x00,0xfe,0x00,0x00,0xf8,0x08,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 21508 0x5404 "各" */
+0x04,0x04,0x0f,0x08,0x14,0x22,0x41,0x06,0x18,0xe0,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xe0,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21509 0x5405 "吅" */
+0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x42,0x00,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,
+/* 21510 0x5406 "吆" */
+0x00,0x00,0x78,0x48,0x48,0x48,0x49,0x4b,0x49,0x48,0x78,0x48,0x00,0x01,0x03,0x01,
+0x20,0x20,0x40,0x40,0x84,0x84,0x08,0xf8,0x10,0x10,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 21511 0x5407 "吇" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x4f,0x48,0x48,0x78,0x48,0x00,0x00,0x01,0x00,
+0x00,0xf8,0x08,0x10,0x20,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 21512 0x5408 "合" */
+0x01,0x01,0x02,0x04,0x08,0x30,0xcf,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21513 0x5409 "吉" */
+0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21514 0x540a "吊" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 21515 0x540b "吋" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x49,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 21516 0x540c "同" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x20,0x20,0x20,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x14,0x08,
+/* 21517 0x540d "名" */
+0x02,0x02,0x07,0x08,0x14,0x62,0x02,0x01,0x06,0x1f,0xe8,0x08,0x08,0x08,0x0f,0x08,
+0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21518 0x540e "后" */
+0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x17,0x14,0x24,0x24,0x44,0x87,0x04,
+0x10,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21519 0x540f "吏" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x11,0x09,0x06,0x05,0x18,0xe0,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x80,0x70,0x0e,
+/* 21520 0x5410 "吐" */
+0x00,0x00,0x78,0x48,0x48,0x48,0x4f,0x48,0x48,0x48,0x78,0x48,0x00,0x00,0x0f,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 21521 0x5411 "向" */
+0x02,0x04,0x08,0x7f,0x40,0x40,0x47,0x44,0x44,0x44,0x44,0x47,0x44,0x40,0x40,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xc4,0x44,0x44,0x44,0x44,0xc4,0x44,0x04,0x14,0x08,
+/* 21522 0x5412 "吒" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x08,0x3c,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 21523 0x5413 "吓" */
+0x00,0x07,0x78,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 21524 0x5414 "吔" */
+0x00,0x00,0x78,0x49,0x49,0x49,0x49,0x4b,0x49,0x49,0x79,0x49,0x01,0x01,0x00,0x00,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 21525 0x5415 "吕" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21526 0x5416 "吖" */
+0x00,0x02,0x79,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x00,0x02,0x04,0x88,0x50,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21527 0x5417 "吗" */
+0x00,0x03,0x78,0x48,0x49,0x49,0x49,0x49,0x48,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 21528 0x5418 "吘" */
+0x00,0x00,0x78,0x49,0x49,0x4a,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21529 0x5419 "吙" */
+0x00,0x00,0x78,0x48,0x4a,0x4a,0x4a,0x4c,0x48,0x48,0x78,0x49,0x01,0x02,0x04,0x08,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 21530 0x541a "吚" */
+0x00,0x03,0x78,0x48,0x48,0x4f,0x48,0x48,0x48,0x4b,0x78,0x48,0x01,0x01,0x02,0x04,
+0x00,0xf8,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0xf8,0x88,0x80,0x00,0x00,0x00,0x00,
+/* 21531 0x541b "君" */
+0x00,0x3f,0x04,0x04,0xff,0x04,0x04,0x3f,0x08,0x08,0x1f,0x18,0x28,0x48,0x8f,0x08,
+0x00,0xf8,0x08,0x08,0xfe,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21532 0x541c "吜" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x4f,0x49,0x49,0x79,0x49,0x01,0x01,0x07,0x00,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 21533 0x541d "吝" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x0c,0x30,0xc0,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x60,0x18,0x06,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21534 0x541e "吞" */
+0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xdf,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0xf6,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21535 0x541f "吟" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x4c,0x48,0x48,0x4b,0x78,0x48,0x00,0x00,0x00,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x88,0x46,0x40,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,
+/* 21536 0x5420 "吠" */
+0x00,0x00,0x78,0x48,0x48,0x4f,0x48,0x48,0x48,0x48,0x48,0x79,0x49,0x02,0x04,0x08,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 21537 0x5421 "吡" */
+0x00,0x02,0x7a,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x03,0x02,0x00,
+0x20,0x20,0x20,0x22,0x22,0x24,0xa8,0x30,0x20,0x20,0x20,0x22,0xa2,0x22,0x1e,0x00,
+/* 21538 0x5422 "吢" */
+0x01,0x00,0x08,0x48,0x48,0x48,0x87,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x80,0x88,0x04,0x12,0x12,0xf0,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21539 0x5423 "吣" */
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x92,0xf2,0x94,0x00,0x00,0x00,0x00,
+0x00,0x40,0x20,0x10,0x90,0x80,0x80,0x84,0x82,0x82,0x82,0x88,0x88,0x88,0x78,0x00,
+/* 21540 0x5424 "吤" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x4c,0x49,0x49,0x49,0x79,0x49,0x01,0x02,0x02,0x04,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 21541 0x5425 "吥" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x79,0x4a,0x04,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0x64,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,
+/* 21542 0x5426 "否" */
+0x00,0x7f,0x00,0x01,0x03,0x05,0x09,0x31,0xc1,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x80,0x00,0x00,0x60,0x18,0x04,0x02,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21543 0x5427 "吧" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x01,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x08,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 21544 0x5428 "吨" */
+0x00,0x00,0x78,0x4b,0x48,0x4a,0x4a,0x4a,0x4a,0x4b,0x78,0x48,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 21545 0x5429 "吩" */
+0x00,0x00,0x78,0x48,0x49,0x49,0x4a,0x4d,0x48,0x48,0x48,0x78,0x49,0x01,0x02,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 21546 0x542a "吪" */
+0x00,0x00,0x78,0x49,0x49,0x4b,0x4d,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0xa0,0xa0,0xa0,0x24,0x24,0x28,0x30,0x20,0x60,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 21547 0x542b "含" */
+0x01,0x01,0x02,0x04,0x0a,0x31,0xc1,0x0f,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0xe0,0x40,0x80,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21548 0x542c "听" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x02,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 21549 0x542d "吭" */
+0x00,0x00,0x78,0x4f,0x48,0x48,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 21550 0x542e "吮" */
+0x00,0x00,0x79,0x49,0x4a,0x4f,0x48,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x80,0x80,0x00,0x10,0x08,0xfc,0x04,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 21551 0x542f "启" */
+0x01,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x17,0x24,0x24,0x44,0x87,0x04,
+0x00,0x80,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 21552 0x5430 "吰" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x48,0x49,0x79,0x4a,0x02,0x04,0x01,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 21553 0x5431 "吱" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x49,0x48,0x48,0x78,0x48,0x00,0x00,0x01,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 21554 0x5432 "吲" */
+0x00,0x03,0x78,0x48,0x48,0x49,0x49,0x49,0x4a,0x4b,0x78,0x48,0x00,0x00,0x01,0x00,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 21555 0x5433 "吳" */
+0x00,0x07,0x04,0x14,0x17,0x10,0x10,0x1f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xe0,0x20,0x20,0xe0,0x00,0x00,0xf0,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 21556 0x5434 "吴" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 21557 0x5435 "吵" */
+0x00,0x00,0x78,0x49,0x49,0x4a,0x4a,0x4c,0x48,0x48,0x78,0x48,0x00,0x00,0x01,0x06,
+0x40,0x40,0x40,0x48,0x44,0x42,0x42,0x48,0x48,0x48,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 21558 0x5436 "吶" */
+0x00,0x00,0x00,0xfb,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0xfb,0x8a,0x02,0x02,0x02,0x02,
+0x40,0x20,0x20,0xfe,0x22,0x22,0x32,0x4a,0x4a,0x86,0x06,0x02,0x02,0x02,0x0a,0x04,
+/* 21559 0x5437 "吷" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x48,0x4f,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 21560 0x5438 "吸" */
+0x00,0x07,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x4a,0x7a,0x4a,0x04,0x04,0x08,0x03,
+0x00,0xf8,0x08,0x10,0x10,0x20,0x3c,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 21561 0x5439 "吹" */
+0x00,0x00,0x78,0x48,0x49,0x49,0x4a,0x4c,0x48,0x48,0x78,0x49,0x01,0x02,0x04,0x08,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 21562 0x543a "吺" */
+0x00,0x01,0x79,0x49,0x49,0x4a,0x4c,0x4b,0x49,0x49,0x78,0x48,0x00,0x00,0x03,0x0c,
+0x00,0xf0,0x10,0x10,0x10,0x0e,0x00,0xf8,0x08,0x10,0x90,0xa0,0x40,0xa0,0x18,0x06,
+/* 21563 0x543b "吻" */
+0x01,0x01,0x79,0x49,0x4a,0x4c,0x48,0x49,0x49,0x4a,0x7c,0x48,0x01,0x02,0x04,0x00,
+0x00,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 21564 0x543c "吼" */
+0x00,0x07,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x4f,0x79,0x49,0x01,0x01,0x05,0x02,
+0x10,0xd0,0x50,0x90,0x10,0x10,0x50,0x90,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 21565 0x543d "吽" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x4a,0x48,0x48,0x4b,0x78,0x48,0x00,0x00,0x00,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21566 0x543e "吾" */
+0x00,0x7f,0x02,0x02,0x3f,0x04,0x04,0x08,0xff,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21567 0x543f "吿" */
+0x01,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x01,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21568 0x5440 "呀" */
+0x00,0x03,0x78,0x49,0x49,0x49,0x4a,0x4b,0x48,0x48,0x78,0x49,0x02,0x04,0x00,0x00,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 21569 0x5441 "呁" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x48,0x48,0x48,0x48,0x48,0x78,0x49,0x00,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 21570 0x5442 "呂" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x02,0x04,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21571 0x5443 "呃" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x08,0x10,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xa8,0x90,0x82,0x82,0x82,0x7e,0x00,
+/* 21572 0x5444 "呄" */
+0x00,0x3f,0x04,0x04,0x08,0x10,0x61,0x01,0xff,0x01,0x01,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0xe0,0x20,0x7c,0x04,0x14,0x08,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21573 0x5445 "呅" */
+0x00,0x00,0x78,0x4f,0x49,0x49,0x49,0x49,0x49,0x48,0x78,0x48,0x00,0x01,0x02,0x0c,
+0x80,0x40,0x40,0xfc,0x10,0x10,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 21574 0x5446 "呆" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 21575 0x5447 "呇" */
+0x01,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21576 0x5448 "呈" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x00,0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 21577 0x5449 "呉" */
+0x00,0x07,0x04,0x14,0x17,0x10,0x10,0x1f,0x00,0x00,0xff,0x00,0x04,0x08,0x10,0x20,
+0x00,0xe0,0x20,0x20,0xe0,0x00,0x00,0xf0,0x10,0x10,0xfe,0x00,0x40,0x20,0x10,0x08,
+/* 21578 0x544a "告" */
+0x01,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21579 0x544b "呋" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x4f,0x48,0x48,0x78,0x49,0x01,0x02,0x04,0x08,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 21580 0x544c "呌" */
+0x00,0x01,0x78,0x48,0x48,0x49,0x48,0x48,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 21581 0x544d "呍" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x48,0x48,0x48,0x78,0x48,0x01,0x03,0x01,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 21582 0x544e "呎" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 21583 0x544f "呏" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x4b,0x48,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 21584 0x5450 "呐" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x02,0x02,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0x04,0x14,0x08,
+/* 21585 0x5451 "呑" */
+0x00,0x00,0x3f,0x01,0x02,0x7f,0x04,0x08,0x30,0xc0,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x10,0xf8,0x00,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21586 0x5452 "呒" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x4f,0x48,0x48,0x48,0x78,0x49,0x01,0x02,0x04,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 21587 0x5453 "呓" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x4b,0x48,0x48,0x48,0x78,0x49,0x02,0x02,0x01,0x00,
+0x90,0x90,0xfe,0x90,0x90,0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 21588 0x5454 "呔" */
+0x00,0x00,0x78,0x48,0x4f,0x48,0x48,0x48,0x48,0x48,0x79,0x49,0x02,0x02,0x04,0x08,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x88,0x48,0x44,0x02,
+/* 21589 0x5455 "呕" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,0x03,0x00,
+0x00,0xfc,0x00,0x08,0x88,0x50,0x50,0x20,0x20,0x50,0x50,0x88,0x08,0x00,0xfe,0x00,
+/* 21590 0x5456 "呖" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x09,0x12,
+0x00,0xfe,0x00,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 21591 0x5457 "呗" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x48,0x00,0x00,0x01,0x06,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x02,0x02,
+/* 21592 0x5458 "员" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x21,0x21,0x21,0x21,0x22,0x04,0x18,0x60,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xc8,0x30,0x08,0x04,
+/* 21593 0x5459 "呙" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x01,0x01,0x7f,0x41,0x42,0x44,0x48,0x40,0x40,0x40,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xfc,0x04,0x84,0x44,0x24,0x04,0x14,0x08,
+/* 21594 0x545a "呚" */
+0x00,0x00,0x7c,0x44,0x44,0x45,0x46,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x01,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 21595 0x545b "呛" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x4c,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x00,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 21596 0x545c "呜" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x48,0x03,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0x04,0x04,0x14,0x08,0x00,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 21597 0x545d "呝" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x02,0x02,0x04,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x08,0x10,0x20,0x42,0x82,0x7e,0x00,
+/* 21598 0x545e "呞" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x48,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x04,0x14,0x08,
+/* 21599 0x545f "呟" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x49,0x4b,0x48,0x78,0x48,0x01,0x03,0x01,0x00,
+0x80,0x40,0x40,0xfe,0x40,0x40,0x88,0x08,0xf0,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 21600 0x5460 "呠" */
+0x00,0x00,0x78,0x48,0x4f,0x48,0x48,0x48,0x49,0x49,0x4a,0x7d,0x48,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0xf4,0x42,0x40,0x40,0x40,
+/* 21601 0x5461 "呡" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 21602 0x5462 "呢" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x08,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 21603 0x5463 "呣" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x4f,0x4a,0x4a,0x7a,0x4a,0x03,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x48,0x28,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0xfe,0x08,0x50,0x20,
+/* 21604 0x5464 "呤" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x4c,0x48,0x4b,0x48,0x78,0x49,0x00,0x00,0x00,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 21605 0x5465 "呥" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4f,0x7a,0x4a,0x02,0x02,0x02,
+0x40,0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0x48,0xfe,0x08,0x08,0x08,0x28,0x10,
+/* 21606 0x5466 "呦" */
+0x00,0x01,0x71,0x52,0x52,0x54,0x57,0x51,0x52,0x52,0x74,0x47,0x00,0x00,0x00,0x01,
+0x20,0x20,0x20,0x20,0xfc,0xa4,0x24,0x24,0x24,0x24,0xa4,0xa4,0xc4,0x44,0x94,0x08,
+/* 21607 0x5467 "呧" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 21608 0x5468 "周" */
+0x00,0x3f,0x21,0x21,0x2f,0x21,0x21,0x3f,0x20,0x27,0x24,0x24,0x27,0x40,0x40,0x80,
+0x00,0xf8,0x08,0x08,0xe8,0x08,0x08,0xf8,0x08,0xc8,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 21609 0x5469 "呩" */
+0x00,0x01,0x78,0x48,0x48,0x4b,0x48,0x48,0x49,0x49,0x7a,0x4a,0x04,0x00,0x00,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 21610 0x546a "呪" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4b,0x48,0x48,0x48,0x78,0x49,0x01,0x02,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,0x00,
+/* 21611 0x546b "呫" */
+0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21612 0x546c "呬" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x03,0x02,
+0x00,0x00,0xfc,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 21613 0x546d "呭" */
+0x00,0x02,0x7a,0x4a,0x4a,0x4f,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 21614 0x546e "呮" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x48,0x00,0x01,0x02,0x04,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 21615 0x546f "呯" */
+0x00,0x01,0x78,0x48,0x49,0x48,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 21616 0x5470 "呰" */
+0x04,0x04,0x24,0x27,0x24,0x24,0x2f,0xf0,0x40,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x44,0x58,0x60,0x42,0x42,0x3e,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21617 0x5471 "呱" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 21618 0x5472 "呲" */
+0x00,0x00,0x78,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x0e,0x04,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 21619 0x5473 "味" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x4f,0x48,0x49,0x79,0x4a,0x04,0x08,0x00,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 21620 0x5474 "呴" */
+0x00,0x00,0x79,0x49,0x4a,0x4c,0x49,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 21621 0x5475 "呵" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 21622 0x5476 "呶" */
+0x02,0x02,0xe2,0xa2,0xaf,0xa4,0xa4,0xa4,0xa4,0xa9,0xe5,0xa2,0x05,0x09,0x10,0x01,
+0x00,0x00,0x7c,0x24,0xa4,0xa4,0xa4,0xa8,0xa8,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 21623 0x5477 "呷" */
+0x00,0x07,0xf4,0x94,0x94,0x97,0x94,0x94,0x94,0x97,0xf4,0x90,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 21624 0x5478 "呸" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x49,0x4a,0x4c,0x78,0x48,0x00,0x00,0x07,0x00,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 21625 0x5479 "呹" */
+0x00,0x00,0x7a,0x4a,0x4b,0x4a,0x4c,0x48,0x4f,0x48,0x78,0x48,0x01,0x02,0x04,0x08,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 21626 0x547a "呺" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x48,0x4b,0x48,0x49,0x79,0x48,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0xfe,0x80,0x00,0xf8,0x08,0x08,0x08,0x50,0x20,
+/* 21627 0x547b "呻" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4b,0x02,0x00,0x00,0x00,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0xf8,0x48,0x48,0x48,0xf8,0x48,0x40,0x40,0x40,
+/* 21628 0x547c "呼" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 21629 0x547d "命" */
+0x01,0x01,0x02,0x04,0x08,0x37,0xc0,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0xd8,0x06,0x00,0xf8,0x88,0x88,0x88,0xa8,0x90,0x80,0x80,
+/* 21630 0x547e "呾" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x03,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 21631 0x547f "呿" */
+0x00,0x00,0x78,0x49,0x48,0x48,0x48,0x4b,0x48,0x48,0x78,0x48,0x01,0x03,0x01,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 21632 0x5480 "咀" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 21633 0x5481 "咁" */
+0x01,0x01,0x79,0x49,0x4f,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21634 0x5482 "咂" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x00,
+0x00,0xfe,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,0xfe,0x00,
+/* 21635 0x5483 "咃" */
+0x01,0x01,0x79,0x4a,0x4a,0x4e,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x20,0x20,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xa4,0xb4,0xa8,0xa2,0xa2,0x82,0x7e,0x00,
+/* 21636 0x5484 "咄" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x48,0x48,0x48,0x7a,0x4a,0x02,0x02,0x03,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x22,0x22,0x22,0x22,0xfe,0x02,
+/* 21637 0x5485 "咅" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 21638 0x5486 "咆" */
+0x00,0x00,0x79,0x49,0x4a,0x4d,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 21639 0x5487 "咇" */
+0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x4a,0x7c,0x48,0x01,0x02,0x04,0x00,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 21640 0x5488 "咈" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x4b,0x4a,0x4a,0x4b,0x78,0x48,0x01,0x01,0x02,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 21641 0x5489 "咉" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x4f,0x78,0x48,0x00,0x01,0x02,0x04,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 21642 0x548a "咊" */
+0x00,0x03,0x78,0x48,0x48,0x4f,0x48,0x48,0x48,0x49,0x79,0x4a,0x04,0x08,0x00,0x00,
+0x38,0xc0,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 21643 0x548b "咋" */
+0x01,0x01,0x79,0x49,0x4a,0x4a,0x4c,0x48,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 21644 0x548c "和" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+/* 21645 0x548d "咍" */
+0x00,0x00,0x78,0x48,0x49,0x4b,0x48,0x48,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21646 0x548e "咎" */
+0x10,0x10,0x1e,0x22,0x22,0x54,0x08,0x14,0x23,0xc0,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0xfe,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21647 0x548f "咏" */
+0x00,0x00,0x78,0x49,0x48,0x48,0x4b,0x48,0x48,0x48,0x79,0x49,0x02,0x04,0x00,0x00,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 21648 0x5490 "咐" */
+0x00,0x00,0x78,0x49,0x49,0x4b,0x4d,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 21649 0x5491 "咑" */
+0x01,0x01,0x79,0x49,0x4f,0x49,0x49,0x49,0x49,0x4f,0x79,0x49,0x01,0x01,0x05,0x02,
+0x00,0x00,0x3e,0x08,0xc8,0x08,0x08,0x48,0x88,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 21650 0x5492 "咒" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x0f,0x08,0x08,0x08,0x10,0x10,0x20,0xc0,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x00,0x00,0xc0,0x40,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 21651 0x5493 "咓" */
+0x00,0x00,0x7b,0x49,0x49,0x49,0x49,0x49,0x49,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x90,0x50,0x50,0x10,0x12,0x92,0x12,0x0e,
+/* 21652 0x5494 "咔" */
+0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4f,0x48,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x40,0x40,0x50,0x48,0x44,0x40,0x40,0x40,
+/* 21653 0x5495 "咕" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21654 0x5496 "咖" */
+0x04,0x04,0xf4,0x94,0x9f,0x94,0x94,0x94,0x94,0x94,0xf4,0x94,0x08,0x08,0x12,0x21,
+0x00,0x00,0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,0x00,
+/* 21655 0x5497 "咗" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x48,0x49,0x79,0x4a,0x02,0x04,0x01,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x80,0xfe,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 21656 0x5498 "咘" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x49,0x49,0x4b,0x4d,0x79,0x49,0x01,0x01,0x00,0x00,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 21657 0x5499 "咙" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x48,0x48,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0x28,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 21658 0x549a "咚" */
+0x00,0x00,0x78,0x49,0x4b,0x4c,0x48,0x48,0x4b,0x4c,0x78,0x48,0x00,0x01,0x00,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xc0,0x20,0x10,0x80,0x60,0x10,
+/* 21659 0x549b "咛" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 21660 0x549c "咜" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x08,0x10,0x20,0xc0,0x02,0x02,0x02,0xfe,0x00,
+/* 21661 0x549d "咝" */
+0x01,0x01,0x71,0x52,0x52,0x54,0x57,0x51,0x51,0x52,0x74,0x57,0x00,0x00,0x0f,0x00,
+0x08,0x08,0x08,0x10,0x94,0xa4,0xbc,0x08,0x08,0x10,0x20,0xbc,0x00,0x00,0xfe,0x00,
+/* 21662 0x549e "咞" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x4f,0x48,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x90,0x10,0x10,0x10,0x10,
+/* 21663 0x549f "咟" */
+0x00,0x03,0x78,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21664 0x54a0 "咠" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x3e,0xd0,0x10,0x10,
+/* 21665 0x54a1 "咡" */
+0x00,0x03,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x07,0x00,0x00,0x00,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 21666 0x54a2 "咢" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x3f,0x00,0xff,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 21667 0x54a3 "咣" */
+0x00,0x00,0x7a,0x49,0x49,0x48,0x4f,0x48,0x48,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 21668 0x54a4 "咤" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x48,0x4b,0x48,0x48,0x78,0x4f,0x00,0x00,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x38,0xc0,0x40,0x40,0x7e,0xc0,0x40,0x42,0x42,0x3e,
+/* 21669 0x54a5 "咥" */
+0x00,0x03,0x78,0x48,0x48,0x49,0x4b,0x48,0x48,0x48,0x7b,0x48,0x00,0x00,0x07,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 21670 0x54a6 "咦" */
+0x00,0x00,0xf7,0x90,0x97,0x90,0x93,0x92,0x94,0x97,0xf0,0x90,0x00,0x01,0x02,0x0c,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x40,0x40,0xfe,0x42,0xaa,0xa4,0x10,0x08,0x06,
+/* 21671 0x54a7 "咧" */
+0x00,0x00,0xef,0xa2,0xa2,0xa3,0xa2,0xa4,0xa6,0xa5,0xe8,0xa0,0x01,0x02,0x04,0x08,
+0x04,0x04,0xc4,0x14,0x14,0xd4,0x54,0x54,0x54,0x54,0x94,0x94,0x04,0x04,0x14,0x08,
+/* 21672 0x54a8 "咨" */
+0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21673 0x54a9 "咩" */
+0x01,0x00,0x78,0x48,0x4b,0x48,0x48,0x49,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 21674 0x54aa "咪" */
+0x00,0x00,0x7a,0x49,0x49,0x48,0x4f,0x48,0x48,0x49,0x79,0x4a,0x04,0x08,0x00,0x00,
+0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 21675 0x54ab "咫" */
+0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x2a,0x28,0x28,0x28,0x24,0x24,0x42,0x41,0x80,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x00,0x28,0x24,0x44,0x42,0x82,0x00,0x80,0x7e,
+/* 21676 0x54ac "咬" */
+0x00,0x00,0xf0,0x97,0x90,0x91,0x92,0x94,0x91,0x91,0xf0,0x90,0x00,0x01,0x02,0x0c,
+0x80,0x40,0x40,0xfc,0x00,0x10,0x08,0x04,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 21677 0x54ad "咭" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x49,0x48,0x48,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21678 0x54ae "咮" */
+0x00,0x01,0x79,0x49,0x49,0x4a,0x48,0x4b,0x48,0x48,0x78,0x49,0x01,0x02,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 21679 0x54af "咯" */
+0x00,0x00,0x78,0x49,0x4b,0x4c,0x48,0x48,0x49,0x4a,0x7d,0x49,0x01,0x01,0x01,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21680 0x54b0 "咰" */
+0x00,0x00,0x79,0x49,0x4a,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 21681 0x54b1 "咱" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,
+0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 21682 0x54b2 "咲" */
+0x02,0x01,0x79,0x48,0x4b,0x48,0x48,0x48,0x4f,0x48,0x78,0x48,0x00,0x01,0x02,0x04,
+0x08,0x08,0x10,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 21683 0x54b3 "咳" */
+0x00,0x00,0xf0,0x97,0x90,0x90,0x91,0x93,0x90,0x90,0xf1,0x96,0x00,0x00,0x01,0x06,
+0x40,0x20,0x20,0xfe,0x40,0x84,0x08,0xf0,0x22,0x44,0x88,0x10,0x20,0x50,0x88,0x04,
+/* 21684 0x54b4 "咴" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x49,0x49,0x49,0x7a,0x4a,0x04,0x00,0x00,0x01,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x90,0x12,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 21685 0x54b5 "咵" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x4a,0x48,0x4b,0x48,0x78,0x49,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 21686 0x54b6 "咶" */
+0x00,0x00,0x79,0x48,0x48,0x4b,0x48,0x48,0x48,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21687 0x54b7 "咷" */
+0x00,0x00,0x78,0x4a,0x49,0x48,0x48,0x49,0x4a,0x4c,0x78,0x48,0x01,0x01,0x02,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 21688 0x54b8 "咸" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x2f,0x29,0x29,0x2f,0x49,0x40,0x81,
+0x50,0x48,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 21689 0x54b9 "咹" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x48,0x4b,0x48,0x48,0x79,0x48,0x00,0x00,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 21690 0x54ba "咺" */
+0x00,0x03,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x03,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 21691 0x54bb "咻" */
+0x00,0x00,0x78,0x49,0x49,0x4b,0x4d,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 21692 0x54bc "咼" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x7f,0x40,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x00,0xf0,0x10,0x10,0x90,0x90,0x90,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x04,0x0c,
+/* 21693 0x54bd "咽" */
+0x00,0x07,0xf4,0x94,0x94,0x94,0x97,0x94,0x94,0x94,0xf4,0x95,0x06,0x04,0x07,0x04,
+0x00,0xfc,0x04,0x44,0x44,0x44,0xfc,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0xfc,0x04,
+/* 21694 0x54be "咾" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x4f,0x48,0x48,0x49,0x4a,0x7c,0x48,0x00,0x00,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 21695 0x54bf "咿" */
+0x01,0x01,0xf1,0x92,0x92,0x96,0x9a,0x92,0x92,0x92,0xf2,0x92,0x02,0x02,0x02,0x02,
+0x00,0x7c,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x7c,0x24,0x20,0x20,0x20,0x40,0x80,
+/* 21696 0x54c0 "哀" */
+0x02,0x01,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x02,0x04,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x80,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 21697 0x54c1 "品" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 21698 0x54c2 "哂" */
+0x00,0x07,0x78,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x02,0x03,0x02,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 21699 0x54c3 "哃" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 21700 0x54c4 "哄" */
+0x01,0x01,0x79,0x49,0x4b,0x49,0x49,0x49,0x49,0x4f,0x78,0x49,0x01,0x02,0x04,0x08,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 21701 0x54c5 "哅" */
+0x01,0x01,0x79,0x49,0x4a,0x4a,0x4d,0x48,0x4a,0x4a,0x7b,0x4a,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x02,0x02,0x12,0xa2,0x4a,0xaa,0x1a,0x0a,0xfa,0x02,0x14,0x08,
+/* 21702 0x54c6 "哆" */
+0x00,0x00,0xf1,0x92,0x95,0x90,0x90,0x93,0x9c,0x90,0xf1,0x96,0x00,0x00,0x01,0x0e,
+0x80,0x80,0xf8,0x10,0x20,0xc0,0x90,0x20,0x7c,0x84,0x08,0x90,0x60,0x40,0x80,0x00,
+/* 21703 0x54c7 "哇" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x48,0x48,0x48,0x79,0x48,0x00,0x00,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 21704 0x54c8 "哈" */
+0x00,0x00,0x00,0x79,0x4a,0x4c,0x4b,0x48,0x48,0x4b,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21705 0x54c9 "哉" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x40,0x48,0x44,0x44,0x40,0x40,0xfe,0x40,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 21706 0x54ca "哊" */
+0x00,0x00,0xf7,0x90,0x91,0x91,0x93,0x95,0x99,0x91,0xf1,0x91,0x01,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 21707 0x54cb "哋" */
+0x02,0x02,0x72,0x52,0x5f,0x52,0x52,0x52,0x52,0x52,0x72,0x53,0x0e,0x04,0x00,0x00,
+0x10,0x50,0x50,0x5c,0x74,0xd4,0x54,0x54,0x54,0x5c,0x50,0x52,0x42,0x42,0x3e,0x00,
+/* 21708 0x54cc "哌" */
+0x00,0x00,0xf7,0x94,0x94,0x95,0x95,0x95,0x95,0x95,0xf5,0x95,0x05,0x09,0x09,0x11,
+0x08,0x3c,0xc0,0x00,0x1c,0xe0,0x20,0x22,0x24,0x28,0x10,0x10,0x08,0x44,0x82,0x00,
+/* 21709 0x54cd "响" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 21710 0x54ce "哎" */
+0x01,0x01,0x7b,0x49,0x49,0x48,0x4a,0x4a,0x49,0x49,0x78,0x48,0x00,0x01,0x02,0x0c,
+0x10,0x10,0xfc,0x10,0x10,0x00,0x08,0x08,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 21711 0x54cf "哏" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 21712 0x54d0 "哐" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x02,0x03,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 21713 0x54d1 "哑" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x4c,0x4a,0x4a,0x4a,0x78,0x48,0x00,0x00,0x07,0x00,
+0x00,0xfc,0x90,0x90,0x90,0x92,0x92,0x94,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 21714 0x54d2 "哒" */
+0x00,0x02,0x79,0x49,0x48,0x48,0x4b,0x49,0x49,0x49,0x79,0x49,0x01,0x02,0x04,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x24,0x44,0x42,0x82,0x00,0x80,0x7e,0x00,
+/* 21715 0x54d3 "哓" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x4b,0x48,0x4b,0x78,0x48,0x01,0x01,0x02,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 21716 0x54d4 "哔" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x10,0x12,0x14,0xd8,0x10,0x12,0x52,0x8e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 21717 0x54d5 "哕" */
+0x00,0x01,0x79,0x49,0x49,0x48,0x48,0x48,0x49,0x4a,0x78,0x48,0x00,0x00,0x00,0x03,
+0x20,0x24,0x24,0x24,0xfc,0x40,0x40,0xfc,0x04,0x84,0x48,0x50,0x20,0x40,0x80,0x00,
+/* 21718 0x54d6 "哖" */
+0x00,0x00,0x78,0x49,0x4a,0x48,0x48,0x48,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x80,0x80,0xfe,0x10,0x10,0x10,0xfc,0x90,0x90,0x90,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 21719 0x54d7 "哗" */
+0x00,0x00,0x79,0x49,0x4b,0x4d,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 21720 0x54d8 "哘" */
+0x00,0x00,0x79,0x4a,0x4c,0x48,0x49,0x4b,0x4d,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 21721 0x54d9 "哙" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x49,0x48,0x48,0x4f,0x78,0x48,0x01,0x02,0x07,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x00,0x00,0xfc,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 21722 0x54da "哚" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x4a,0x4c,0x4b,0x48,0x78,0x49,0x02,0x04,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x4e,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 21723 0x54db "哛" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,
+0x80,0x88,0xb0,0xc4,0x84,0x7c,0x00,0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,
+/* 21724 0x54dc "哜" */
+0x00,0x00,0x7b,0x49,0x48,0x48,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x01,0x01,0x02,
+0x40,0x20,0xfe,0x04,0x88,0x50,0x20,0xd8,0x06,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 21725 0x54dd "哝" */
+0x00,0x00,0xf0,0x97,0x94,0x98,0x91,0x91,0x93,0x95,0xf9,0x91,0x01,0x01,0x01,0x01,
+0x40,0x40,0x40,0xfc,0x84,0x88,0x40,0x44,0x48,0x30,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 21726 0x54de "哞" */
+0x00,0x00,0x78,0x49,0x4b,0x48,0x49,0x49,0x49,0x4a,0x78,0x4f,0x00,0x00,0x00,0x00,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 21727 0x54df "哟" */
+0x02,0x02,0xf2,0x94,0x95,0x9f,0x92,0x92,0x94,0x9f,0xf4,0x90,0x01,0x0e,0x04,0x00,
+0x20,0x20,0x20,0x3c,0x44,0x44,0x84,0x24,0x14,0x94,0x04,0x04,0x84,0x04,0x28,0x10,
+/* 21728 0x54e0 "哠" */
+0x00,0x01,0x79,0x49,0x4a,0x4c,0x48,0x4b,0x48,0x48,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 21729 0x54e1 "員" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 21730 0x54e2 "哢" */
+0x00,0x03,0x78,0x48,0x49,0x48,0x48,0x4b,0x48,0x48,0x7b,0x48,0x00,0x01,0x01,0x02,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,
+/* 21731 0x54e3 "哣" */
+0x00,0x03,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x48,0x79,0x48,0x00,0x00,0x07,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x88,0x90,0x00,0xfe,0x00,
+/* 21732 0x54e4 "哤" */
+0x01,0x01,0x79,0x4f,0x49,0x49,0x49,0x49,0x49,0x4a,0x7a,0x4a,0x04,0x04,0x09,0x10,
+0x10,0x08,0x00,0xfe,0x48,0x50,0x64,0x48,0x50,0x64,0x48,0x52,0x62,0x42,0xbe,0x00,
+/* 21733 0x54e5 "哥" */
+0x00,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x00,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,
+0x00,0xfc,0x10,0x90,0x90,0x90,0x90,0x00,0xfe,0x10,0x90,0x90,0x90,0x90,0x50,0x20,
+/* 21734 0x54e6 "哦" */
+0x00,0x01,0xf7,0x91,0x91,0x9f,0x91,0x91,0x91,0x93,0xfd,0x91,0x01,0x01,0x05,0x02,
+0x28,0xa4,0x24,0x20,0x20,0xfe,0x20,0x24,0xa4,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 21735 0x54e7 "哧" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x48,0x48,0x49,0x79,0x4a,0x00,0x00,0x01,0x02,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x48,0x48,0x4c,0x4a,0x4a,0x88,0x88,0x28,0x10,
+/* 21736 0x54e8 "哨" */
+0x00,0x01,0x78,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 21737 0x54e9 "哩" */
+0x00,0x07,0xf4,0x94,0x97,0x94,0x94,0x97,0x90,0x90,0xf7,0x90,0x00,0x00,0x0f,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 21738 0x54ea "哪" */
+0x00,0x0f,0x72,0x52,0x52,0x57,0x52,0x52,0x52,0x5f,0x72,0x52,0x02,0x04,0x05,0x08,
+0x00,0xde,0x52,0x52,0x54,0xd4,0x58,0x54,0x52,0xd2,0x52,0x5a,0x54,0x50,0x50,0x90,
+/* 21739 0x54eb "哫" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x48,0x48,0x49,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 21740 0x54ec "哬" */
+0x01,0x01,0x79,0x4a,0x4a,0x4e,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x00,0x00,0xfe,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 21741 0x54ed "哭" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x00,0x01,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x78,0x48,0x48,0x48,0x78,0x00,0x10,0x08,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 21742 0x54ee "哮" */
+0x00,0x00,0x7b,0x48,0x48,0x4f,0x48,0x48,0x4b,0x49,0x7a,0x4d,0x08,0x00,0x00,0x00,
+0x40,0x44,0xf4,0x48,0x48,0xfe,0x20,0x40,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 21743 0x54ef "哯" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x48,0x00,0x00,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 21744 0x54f0 "哰" */
+0x00,0x00,0x7b,0x4a,0x4c,0x49,0x49,0x49,0x4a,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x24,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 21745 0x54f1 "哱" */
+0x00,0x00,0x7b,0x48,0x48,0x4b,0x4a,0x4c,0x49,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 21746 0x54f2 "哲" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21747 0x54f3 "哳" */
+0x02,0x02,0x72,0x52,0x5f,0x52,0x52,0x52,0x53,0x5e,0x72,0x52,0x02,0x02,0x0a,0x05,
+0x08,0x1c,0x60,0x40,0xc0,0x40,0x7e,0xc8,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 21748 0x54f4 "哴" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x80,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 21749 0x54f5 "哵" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x49,0x49,0x4b,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x02,0xe2,0x22,0x2a,0x2a,0xea,0x0a,0x0a,0xea,0x2a,0x2a,0x2a,0x22,0x22,0xaa,0x44,
+/* 21750 0x54f6 "哶" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x49,0x48,0x48,0x7b,0x48,0x00,0x00,0x00,0x00,
+0x88,0x88,0x88,0x8e,0x88,0x88,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 21751 0x54f7 "哷" */
+0x00,0x00,0x7b,0x48,0x4a,0x49,0x49,0x48,0x4b,0x48,0x79,0x48,0x00,0x00,0x00,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x50,0x20,
+/* 21752 0x54f8 "哸" */
+0x00,0x00,0x7b,0x48,0x4a,0x49,0x49,0x48,0x4b,0x48,0x79,0x4b,0x00,0x00,0x01,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 21753 0x54f9 "哹" */
+0x00,0x00,0x7b,0x48,0x4a,0x49,0x48,0x4b,0x48,0x48,0x4f,0x78,0x48,0x00,0x00,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 21754 0x54fa "哺" */
+0x00,0x00,0xf7,0x90,0x90,0x93,0x92,0x92,0x93,0x92,0xf2,0x93,0x02,0x02,0x02,0x02,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 21755 0x54fb "哻" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x48,0x48,0x49,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 21756 0x54fc "哼" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x49,0x49,0x48,0x4b,0x78,0x48,0x00,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x08,0x30,0x20,0x20,0xa0,0x40,
+/* 21757 0x54fd "哽" */
+0x00,0x07,0xf0,0x97,0x94,0x94,0x97,0x94,0x94,0x97,0xf2,0x91,0x00,0x01,0x02,0x0c,
+0x00,0xfe,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 21758 0x54fe "哾" */
+0x01,0x00,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x48,0x78,0x48,0x00,0x01,0x02,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 21759 0x54ff "哿" */
+0x08,0x08,0x7f,0x11,0x11,0x25,0x42,0x00,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0xfe,0x10,0x90,0x90,0x90,0x90,0x50,0x20,
+/* 21760 0x5500 "唀" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x4a,0x49,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 21761 0x5501 "唁" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x48,0x48,0x49,0x48,0x78,0x49,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 21762 0x5502 "唂" */
+0x01,0x01,0xf2,0x94,0x90,0x90,0x91,0x92,0x9c,0x93,0xf2,0x92,0x02,0x02,0x03,0x02,
+0x10,0x08,0x04,0x44,0x40,0xa0,0x10,0x08,0x06,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 21763 0x5503 "唃" */
+0x01,0x01,0x7b,0x4a,0x4c,0x4b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4b,0x02,0x04,0x04,0x08,
+0x00,0x00,0xf8,0x08,0x10,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 21764 0x5504 "唄" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x48,0x00,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 21765 0x5505 "唅" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x49,0x48,0x48,0x48,0x7b,0x4a,0x02,0x02,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf0,0x10,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21766 0x5506 "唆" */
+0x00,0x00,0x78,0x49,0x4b,0x48,0x48,0x49,0x4a,0x48,0x79,0x4a,0x00,0x00,0x01,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 21767 0x5507 "唇" */
+0x00,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x24,0x25,0x26,0x20,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x88,0x50,0x30,0x0e,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21768 0x5508 "唈" */
+0x00,0x01,0x79,0x49,0x49,0x48,0x4b,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x01,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0x44,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 21769 0x5509 "唉" */
+0x00,0x00,0xf1,0x92,0x97,0x91,0x91,0x93,0x94,0x90,0x9f,0xf0,0x90,0x01,0x02,0x0c,
+0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 21770 0x550a "唊" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x49,0x49,0x49,0x4a,0x78,0x48,0x00,0x00,0x01,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 21771 0x550b "唋" */
+0x00,0x00,0x78,0x48,0x49,0x4a,0x48,0x48,0x4b,0x48,0x79,0x49,0x02,0x04,0x00,0x00,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 21772 0x550c "唌" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x49,0x4b,0x48,0x4a,0x7a,0x49,0x01,0x02,0x04,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 21773 0x550d "唍" */
+0x00,0x00,0x7b,0x4a,0x4c,0x49,0x48,0x48,0x4b,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 21774 0x550e "唎" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x4f,0x48,0x49,0x49,0x7a,0x4a,0x04,0x00,0x00,0x00,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 21775 0x550f "唏" */
+0x01,0x00,0x78,0x48,0x4b,0x48,0x4b,0x48,0x49,0x4b,0x7d,0x49,0x01,0x01,0x00,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 21776 0x5510 "唐" */
+0x01,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x48,0x48,0x8f,0x08,
+0x00,0x80,0xfe,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x80,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21777 0x5511 "唑" */
+0x00,0x00,0xf2,0x92,0x92,0x95,0x98,0x90,0x90,0x97,0xf0,0x90,0x00,0x00,0x0f,0x00,
+0x40,0x40,0x48,0x48,0x48,0x54,0xe2,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 21778 0x5512 "唒" */
+0x00,0x0f,0xf0,0x90,0x97,0x94,0x94,0x94,0x95,0x96,0xf4,0x97,0x04,0x04,0x07,0x04,
+0x00,0xfe,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0x1c,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 21779 0x5513 "唓" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 21780 0x5514 "唔" */
+0x00,0x07,0xf0,0x90,0x93,0x90,0x90,0x97,0x90,0x90,0xf3,0x92,0x02,0x02,0x03,0x02,
+0x00,0xfc,0x40,0x40,0xf8,0x88,0x88,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21781 0x5515 "唕" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 21782 0x5516 "唖" */
+0x00,0x03,0x78,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x7b,0x48,0x00,0x00,0x07,0x00,
+0x00,0xfc,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0xfc,0x90,0x90,0x90,0xfe,0x00,
+/* 21783 0x5517 "唗" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x48,0x48,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 21784 0x5518 "唘" */
+0x00,0xfe,0x10,0x20,0x3e,0x62,0xa2,0x3e,0x22,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0x44,0x82,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21785 0x5519 "唙" */
+0x00,0x08,0x75,0x52,0x55,0x59,0x51,0x51,0x53,0x55,0x79,0x51,0x01,0x01,0x0a,0x05,
+0x10,0x90,0x10,0x12,0x52,0x54,0x58,0x90,0x10,0x28,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 21786 0x551a "唚" */
+0x00,0x01,0x78,0x48,0x48,0x49,0x48,0x4b,0x4a,0x49,0x78,0x48,0x00,0x00,0x00,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 21787 0x551b "唛" */
+0x00,0x00,0xf7,0x90,0x93,0x90,0x97,0x90,0x90,0x91,0xf3,0x94,0x00,0x00,0x03,0x0c,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 21788 0x551c "唜" */
+0x01,0x01,0x7f,0x01,0x3f,0x05,0x09,0x31,0xc1,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0xfc,0x00,0xf8,0x40,0x20,0x18,0x06,0x00,0x44,0x58,0x60,0x42,0x42,0x3e,
+/* 21789 0x551d "唝" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x01,0x06,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x24,0x24,0x24,0x54,0x88,0x04,0x02,
+/* 21790 0x551e "唞" */
+0x01,0x01,0x79,0x49,0x4f,0x49,0x49,0x49,0x49,0x4f,0x79,0x49,0x01,0x01,0x05,0x02,
+0x04,0x24,0x14,0x14,0xc4,0x24,0x14,0x54,0x86,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 21791 0x551f "唟" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x04,0x08,0x1f,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0xf0,0x10,0x44,0x58,0x60,0x42,0x42,0x3e,
+/* 21792 0x5520 "唠" */
+0x00,0x00,0x7b,0x48,0x48,0x4b,0x4a,0x4c,0x48,0x4b,0x78,0x48,0x00,0x01,0x02,0x04,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x44,0x40,0xfc,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 21793 0x5521 "唡" */
+0x00,0x03,0x78,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x02,0x02,0x02,
+0x00,0xfe,0x50,0x50,0x50,0xfe,0x52,0x52,0x52,0xaa,0xa6,0x02,0x02,0x02,0x0a,0x04,
+/* 21794 0x5522 "唢" */
+0x00,0x01,0x78,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x01,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x88,0x04,0x02,
+/* 21795 0x5523 "唣" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x78,0x48,0x07,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x40,0x40,0x7e,0xc0,0x42,0x42,0x3e,
+/* 21796 0x5524 "唤" */
+0x01,0x01,0xf1,0x92,0x94,0x9b,0x92,0x92,0x92,0x92,0xf7,0x90,0x00,0x01,0x02,0x0c,
+0x00,0x00,0xf0,0x10,0x20,0xf8,0x48,0x48,0x48,0x48,0xfe,0xa0,0xa0,0x10,0x08,0x06,
+/* 21797 0x5525 "唥" */
+0x00,0x04,0x7a,0x4a,0x48,0x49,0x49,0x49,0x4a,0x4e,0x7a,0x4a,0x02,0x02,0x02,0x00,
+0x10,0x10,0x28,0x28,0x44,0x92,0x08,0x08,0xfe,0x02,0x04,0x44,0x28,0x10,0x08,0x08,
+/* 21798 0x5526 "唦" */
+0x00,0x02,0x79,0x49,0x4c,0x4a,0x4a,0x48,0x48,0x49,0x7e,0x4a,0x02,0x02,0x02,0x00,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 21799 0x5527 "唧" */
+0x00,0x07,0x74,0x54,0x54,0x57,0x54,0x54,0x54,0x57,0x74,0x55,0x04,0x05,0x06,0x00,
+0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x34,0x28,0xa0,0x60,0x20,0x20,
+/* 21800 0x5528 "唨" */
+0x00,0x07,0x74,0x55,0x55,0x56,0x55,0x54,0x54,0x54,0x76,0x55,0x04,0x04,0x04,0x04,
+0x00,0xbc,0xa4,0x24,0x24,0x3c,0x24,0xa4,0xa4,0xbc,0xa4,0x24,0x24,0x24,0x7e,0x00,
+/* 21801 0x5529 "唩" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x4a,0x48,0x4b,0x78,0x49,0x00,0x00,0x00,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 21802 0x552a "唪" */
+0x00,0x00,0xf7,0x90,0x93,0x90,0x97,0x91,0x92,0x94,0xf1,0x90,0x07,0x00,0x00,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x48,0x46,0xf0,0x40,0xfc,0x40,0x40,0x40,
+/* 21803 0x552b "唫" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x49,0x48,0x48,0x4b,0x78,0x4a,0x01,0x01,0x0f,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x40,0x40,0xf8,0x40,0x48,0x48,0x50,0xfe,0x00,
+/* 21804 0x552c "唬" */
+0x00,0x00,0x78,0x48,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x09,0x12,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 21805 0x552d "唭" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x78,0x4b,0x00,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 21806 0x552e "售" */
+0x09,0x08,0x0f,0x10,0x3f,0x50,0x9f,0x10,0x1f,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 21807 0x552f "唯" */
+0x00,0x00,0x78,0x49,0x49,0x4b,0x4d,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 21808 0x5530 "唰" */
+0x00,0x07,0x74,0x54,0x57,0x54,0x54,0x54,0x57,0x56,0x76,0x5a,0x0a,0x12,0x00,0x00,
+0x02,0xe2,0x22,0x2a,0xea,0x8a,0x8a,0x8a,0xea,0xaa,0xaa,0xaa,0xa2,0xe2,0x8a,0x84,
+/* 21809 0x5531 "唱" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x49,0x48,0x4b,0x4a,0x7a,0x4b,0x02,0x02,0x03,0x02,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 21810 0x5532 "唲" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x78,0x48,0x00,0x01,0x02,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 21811 0x5533 "唳" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x04,0x05,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 21812 0x5534 "唴" */
+0x02,0x01,0xf1,0x97,0x90,0x90,0x93,0x90,0x90,0x9f,0xf1,0x91,0x02,0x02,0x04,0x08,
+0x08,0x08,0x10,0xfc,0x40,0x40,0xf8,0x40,0x80,0xfe,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 21813 0x5535 "唵" */
+0x00,0x00,0x7b,0x49,0x4a,0x4c,0x4b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4b,0x00,0x00,0x00,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 21814 0x5536 "唶" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x4f,0x48,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 21815 0x5537 "唷" */
+0x00,0x00,0x7b,0x48,0x49,0x4b,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 21816 0x5538 "唸" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x48,0x4b,0x48,0x48,0x78,0x49,0x05,0x05,0x09,0x00,
+0x40,0x40,0xa0,0x10,0x88,0x46,0x00,0xf0,0x10,0x20,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 21817 0x5539 "唹" */
+0x01,0x00,0x78,0x4f,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x05,0x08,
+0x08,0x88,0x08,0xd4,0x14,0x22,0x00,0xc8,0x44,0x44,0x40,0x50,0x48,0x44,0x44,0x80,
+/* 21818 0x553a "唺" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7f,0x48,0x00,0x01,0x02,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 21819 0x553b "唻" */
+0x00,0x00,0x78,0x4f,0x48,0x4a,0x4a,0x4a,0x4d,0x48,0x79,0x49,0x02,0x04,0x08,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 21820 0x553c "唼" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4f,0x48,0x48,0x4f,0x78,0x49,0x00,0x00,0x01,0x06,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 21821 0x553d "唽" */
+0x01,0x01,0xf1,0x91,0x97,0x91,0x91,0x93,0x93,0x95,0xf5,0x99,0x01,0x01,0x01,0x01,
+0x00,0x06,0x38,0x20,0xa0,0x20,0x3e,0x24,0xa4,0x64,0x24,0x24,0x24,0x24,0x24,0x44,
+/* 21822 0x553e "唾" */
+0x00,0x00,0xf3,0x90,0x90,0x97,0x92,0x92,0x97,0x92,0xf2,0x97,0x00,0x00,0x07,0x00,
+0x10,0x78,0xc0,0x40,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0x40,0xfc,0x00,
+/* 21823 0x553f "唿" */
+0x01,0x01,0xf3,0x94,0x98,0x91,0x92,0x94,0x91,0x92,0xf0,0x91,0x05,0x05,0x08,0x00,
+0x00,0x00,0xfc,0x94,0x94,0x24,0x44,0x84,0x28,0x10,0x40,0x24,0x2a,0x0a,0xf8,0x00,
+/* 21824 0x5540 "啀" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x05,0x08,
+0x00,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 21825 0x5541 "啁" */
+0x00,0x07,0xf4,0x94,0x95,0x94,0x94,0x97,0x94,0x95,0xf5,0x95,0x05,0x04,0x04,0x08,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 21826 0x5542 "啂" */
+0x00,0x0f,0xe2,0xa9,0xa5,0xa0,0xa7,0xa0,0xa1,0xa1,0xe1,0xaf,0x01,0x01,0x05,0x02,
+0xe8,0x08,0x28,0x28,0x48,0x08,0xc8,0x88,0x08,0x08,0xe8,0x08,0x0a,0x0a,0x0a,0x06,
+/* 21827 0x5543 "啃" */
+0x00,0x01,0x79,0x49,0x49,0x4f,0x48,0x4b,0x4a,0x4b,0x7a,0x4b,0x02,0x02,0x02,0x02,
+0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 21828 0x5544 "啄" */
+0x00,0x03,0x78,0x48,0x49,0x4a,0x48,0x4a,0x49,0x4a,0x78,0x48,0x01,0x02,0x00,0x00,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 21829 0x5545 "啅" */
+0x00,0x00,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 21830 0x5546 "商" */
+0x02,0x01,0x7f,0x08,0x04,0x3f,0x20,0x24,0x28,0x37,0x24,0x24,0x27,0x20,0x20,0x20,
+0x00,0x00,0xfc,0x20,0x40,0xf8,0x08,0x48,0x28,0xd8,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 21831 0x5547 "啇" */
+0x02,0x01,0x7f,0x08,0x04,0x3f,0x21,0x2f,0x21,0x27,0x24,0x24,0x27,0x20,0x20,0x20,
+0x00,0x00,0xfc,0x20,0x40,0xf8,0x08,0xe8,0x08,0xc8,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 21832 0x5548 "啈" */
+0x00,0x00,0x79,0x48,0x48,0x4b,0x48,0x48,0x49,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x50,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 21833 0x5549 "啉" */
+0x01,0x01,0x71,0x51,0x57,0x51,0x51,0x53,0x53,0x55,0x75,0x59,0x01,0x01,0x01,0x01,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 21834 0x554a "啊" */
+0x00,0x0e,0xea,0xaa,0xaa,0xaa,0xac,0xaa,0xaa,0xaa,0xea,0xaa,0x0c,0x08,0x08,0x08,
+0x00,0xfc,0x08,0x08,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xe8,0xa8,0x08,0x08,0x28,0x10,
+/* 21835 0x554b "啋" */
+0x00,0x00,0x7b,0x48,0x4a,0x49,0x49,0x48,0x4b,0x48,0x78,0x48,0x01,0x02,0x04,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 21836 0x554c "啌" */
+0x00,0x00,0x78,0x4b,0x4a,0x4c,0x49,0x4a,0x48,0x49,0x78,0x48,0x00,0x00,0x07,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 21837 0x554d "啍" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x49,0x48,0x49,0x48,0x78,0x4b,0x00,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 21838 0x554e "啎" */
+0x20,0x21,0x20,0x3e,0x49,0x88,0x08,0x09,0xfe,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0xfe,0x20,0x20,0xfc,0x44,0x44,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 21839 0x554f "問" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x4f,0x48,0x48,0x4f,0x48,0x40,0x40,0x40,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x48,0x08,0x28,0x10,
+/* 21840 0x5550 "啐" */
+0x00,0x00,0xf7,0x90,0x91,0x91,0x92,0x94,0x90,0x90,0xf7,0x90,0x00,0x00,0x00,0x00,
+0x80,0x40,0xfc,0x00,0x10,0x10,0xa8,0x44,0x00,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 21841 0x5551 "啑" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x49,0x48,0x79,0x49,0x01,0x02,0x02,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 21842 0x5552 "啒" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 21843 0x5553 "啓" */
+0x10,0x08,0x3e,0x22,0x23,0x3e,0x20,0x40,0x41,0x80,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x88,0x48,0x50,0x20,0x58,0x86,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21844 0x5554 "啔" */
+0x10,0x08,0x3e,0x23,0x22,0x3e,0x22,0x20,0x41,0x80,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x48,0x44,0x7e,0xc0,0x24,0x28,0x12,0x6a,0x86,0x02,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21845 0x5555 "啕" */
+0x01,0x01,0x79,0x4a,0x4d,0x49,0x4a,0x48,0x4f,0x48,0x7a,0x4a,0x03,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x84,0x84,0xf4,0x84,0xa4,0xa4,0xe4,0x04,0x28,0x10,
+/* 21846 0x5556 "啖" */
+0x00,0x02,0xf2,0x94,0x90,0x91,0x96,0x90,0x90,0x92,0xf2,0x94,0x00,0x01,0x02,0x0c,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 21847 0x5557 "啗" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x48,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x03,0x02,
+0x80,0x80,0xf8,0x08,0x10,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 21848 0x5558 "啘" */
+0x00,0x00,0xf7,0x94,0x9a,0x92,0x93,0x94,0x94,0x96,0xf9,0x91,0x02,0x02,0x04,0x08,
+0x80,0x40,0xfe,0x02,0x04,0x00,0xbc,0xa4,0xa4,0xa4,0x34,0x28,0x22,0x22,0x22,0x1e,
+/* 21849 0x5559 "啙" */
+0x04,0x04,0x24,0x27,0x24,0x24,0x24,0x2f,0xf0,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x40,0x40,0x44,0x58,0x60,0x42,0x42,0x42,0x3e,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 21850 0x555a "啚" */
+0x00,0x1f,0x10,0x10,0x1f,0x01,0xff,0x02,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 21851 0x555b "啛" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x49,0x48,0x7b,0x48,0x01,0x00,0x00,0x03,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x40,0xfe,0x84,0xc8,0x30,0xcc,0x02,
+/* 21852 0x555c "啜" */
+0x00,0x07,0x70,0x52,0x51,0x52,0x54,0x58,0x50,0x57,0x70,0x52,0x01,0x02,0x04,0x08,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 21853 0x555d "啝" */
+0x00,0x01,0x77,0x51,0x51,0x5f,0x51,0x53,0x53,0x53,0x75,0x55,0x09,0x01,0x01,0x01,
+0x00,0x80,0x00,0x1e,0x12,0xd2,0x12,0x12,0x92,0x52,0x52,0x12,0x1e,0x12,0x00,0x00,
+/* 21854 0x555e "啞" */
+0x00,0x07,0x78,0x48,0x48,0x4b,0x4a,0x4a,0x4a,0x4b,0x78,0x48,0x00,0x00,0x07,0x00,
+0x00,0xfe,0x90,0x90,0x90,0x9c,0x04,0x04,0x04,0x9c,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 21855 0x555f "啟" */
+0x08,0x04,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x3f,0x31,0x51,0x51,0x9f,0x11,0x00,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 21856 0x5560 "啠" */
+0x06,0x38,0x20,0x20,0x3f,0x24,0x24,0x24,0x44,0x81,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x0c,0x70,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 21857 0x5561 "啡" */
+0x00,0x00,0xf0,0x97,0x90,0x90,0x90,0x93,0x90,0x90,0xf0,0x97,0x00,0x00,0x00,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 21858 0x5562 "啢" */
+0x00,0x03,0x78,0x48,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x02,0x02,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 21859 0x5563 "啣" */
+0x04,0x04,0x77,0x59,0x51,0x51,0x5f,0x51,0x51,0x55,0x75,0x55,0x05,0x1e,0x08,0x00,
+0x00,0x00,0xde,0x12,0x12,0x12,0xd2,0x12,0x12,0xd2,0x12,0x1a,0xd4,0x10,0x10,0x10,
+/* 21860 0x5564 "啤" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x79,0x4f,0x00,0x00,0x00,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 21861 0x5565 "啥" */
+0x00,0x00,0x78,0x49,0x4a,0x4d,0x48,0x48,0x4f,0x48,0x78,0x4b,0x02,0x02,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 21862 0x5566 "啦" */
+0x01,0x01,0x71,0x51,0x57,0x51,0x51,0x51,0x51,0x53,0x75,0x51,0x01,0x01,0x05,0x02,
+0x20,0x10,0x10,0x7e,0x80,0x04,0x44,0xc4,0x24,0x24,0x28,0x28,0x08,0x10,0x7e,0x00,
+/* 21863 0x5567 "啧" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x49,0x49,0x79,0x49,0x01,0x00,0x00,0x03,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 21864 0x5568 "啨" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 21865 0x5569 "啩" */
+0x01,0x01,0xf7,0x91,0x91,0x91,0x9f,0x90,0x91,0x91,0xf7,0x91,0x01,0x01,0x0e,0x04,
+0x10,0x10,0xd0,0x10,0x10,0x18,0xf4,0x12,0x12,0x10,0xd0,0x10,0x10,0xd0,0x10,0x10,
+/* 21866 0x556a "啪" */
+0x02,0x02,0x72,0x52,0x5f,0x52,0x52,0x52,0x53,0x5e,0x72,0x52,0x02,0x02,0x0a,0x04,
+0x10,0x10,0x20,0x7c,0xc4,0x44,0x44,0xc4,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 21867 0x556b "啫" */
+0x00,0x00,0x7b,0x48,0x48,0x4f,0x48,0x48,0x49,0x4b,0x7d,0x49,0x01,0x01,0x01,0x01,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 21868 0x556c "啬" */
+0x01,0x01,0x7f,0x01,0x11,0x09,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x00,0x00,0xfc,0x00,0x10,0x20,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 21869 0x556d "啭" */
+0x02,0x02,0x72,0x5f,0x52,0x55,0x55,0x57,0x51,0x51,0x71,0x5f,0x05,0x01,0x01,0x01,
+0x10,0x10,0x10,0xbc,0x10,0x10,0x7e,0x90,0x20,0x3c,0xc4,0x08,0x28,0x10,0x08,0x04,
+/* 21870 0x556e "啮" */
+0x00,0x00,0xf2,0x92,0x92,0x92,0x9f,0x90,0x94,0x94,0xf4,0x94,0x05,0x04,0x07,0x00,
+0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x00,0x44,0x44,0xa4,0x94,0x14,0x04,0xfc,0x04,
+/* 21871 0x556f "啯" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x02,0x03,0x02,
+0x00,0xfe,0x02,0x02,0xfe,0x22,0x22,0xfa,0x22,0x32,0x2a,0xfe,0x02,0x02,0xfe,0x02,
+/* 21872 0x5570 "啰" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x48,0x48,0x48,0x49,0x7a,0x48,0x00,0x00,0x01,0x06,
+0x00,0xfe,0x52,0x52,0x52,0xfe,0x20,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0x00,
+/* 21873 0x5571 "啱" */
+0x00,0x01,0x79,0x49,0x49,0x48,0x48,0x4b,0x48,0x48,0x78,0x49,0x02,0x04,0x00,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0x00,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 21874 0x5572 "啲" */
+0x00,0x00,0x79,0x4b,0x4a,0x4a,0x4a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,0x03,0x02,0x00,
+0x88,0x88,0x08,0xde,0x52,0x62,0x42,0x52,0xca,0x4a,0x42,0x42,0x42,0xc2,0x54,0x08,
+/* 21875 0x5573 "啳" */
+0x00,0x02,0xf1,0x97,0x90,0x91,0x9f,0x92,0x94,0x9b,0xf2,0x92,0x02,0x02,0x02,0x01,
+0x40,0x48,0x50,0xfc,0x80,0x00,0xfe,0x10,0x08,0xf4,0x12,0x10,0x50,0x24,0x04,0xfc,
+/* 21876 0x5574 "啴" */
+0x01,0x00,0x78,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x48,0x03,0x00,0x00,0x00,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 21877 0x5575 "啵" */
+0x00,0x04,0x72,0x52,0x58,0x54,0x54,0x52,0x52,0x54,0x7c,0x54,0x04,0x05,0x05,0x02,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 21878 0x5576 "啶" */
+0x00,0x00,0x7b,0x4a,0x4c,0x48,0x4b,0x48,0x48,0x49,0x79,0x49,0x02,0x02,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 21879 0x5577 "啷" */
+0x01,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,0x03,0x02,0x00,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 21880 0x5578 "啸" */
+0x00,0x00,0x7b,0x48,0x4f,0x48,0x4b,0x48,0x4a,0x4a,0x7a,0x4b,0x02,0x02,0x04,0x08,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x48,0x48,0xe8,0x58,0x48,0x48,0x48,0x48,
+/* 21881 0x5579 "啹" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 21882 0x557a "啺" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x48,0x4b,0x49,0x49,0x7a,0x4c,0x01,0x02,0x00,0x01,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x4a,0x92,0x22,0x42,0x94,0x08,
+/* 21883 0x557b "啻" */
+0x01,0x3f,0x08,0x04,0x7f,0x41,0x9f,0x11,0x11,0x11,0x01,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0xf8,0x20,0x40,0xfe,0x02,0xf4,0x10,0x50,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21884 0x557c "啼" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x4b,0x4a,0x4c,0x49,0x49,0x79,0x49,0x01,0x00,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 21885 0x557d "啽" */
+0x00,0x00,0x79,0x4a,0x4d,0x48,0x4b,0x4a,0x4a,0x4b,0x79,0x49,0x07,0x01,0x02,0x04,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xf8,0x08,0x08,0xf8,0x10,0x10,0xfc,0x10,0x10,0x10,
+/* 21886 0x557e "啾" */
+0x00,0x01,0x77,0x51,0x51,0x51,0x57,0x51,0x53,0x53,0x75,0x55,0x09,0x01,0x01,0x01,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 21887 0x557f "啿" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x48,0x48,0x4b,0x79,0x49,0x01,0x01,0x01,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 21888 0x5580 "喀" */
+0x00,0x00,0x7b,0x4a,0x48,0x48,0x49,0x4a,0x48,0x49,0x7e,0x49,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 21889 0x5581 "喁" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x49,0x48,0x48,0x4b,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 21890 0x5582 "喂" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x4f,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 21891 0x5583 "喃" */
+0x00,0x00,0xf7,0x90,0x90,0x97,0x95,0x94,0x95,0x94,0xf4,0x95,0x04,0x04,0x04,0x04,
+0x40,0x40,0xfc,0x40,0x40,0xfc,0x14,0xa4,0xf4,0x44,0x44,0xf4,0x44,0x44,0x54,0x08,
+/* 21892 0x5584 "善" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0x7f,0x11,0x09,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfc,0x10,0x20,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 21893 0x5585 "喅" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x48,0x48,0x4b,0x78,0x49,0x00,0x00,0x07,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x40,0x20,0xfe,0x00,0x04,0x88,0x00,0xfe,0x00,
+/* 21894 0x5586 "喆" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 21895 0x5587 "喇" */
+0x01,0x01,0x77,0x51,0x51,0x57,0x55,0x55,0x57,0x51,0x73,0x55,0x09,0x01,0x01,0x01,
+0x04,0x04,0xc4,0x04,0x14,0xd4,0x54,0x54,0xd4,0x14,0x94,0x54,0x44,0x04,0x14,0x08,
+/* 21896 0x5588 "喈" */
+0x02,0x02,0x7b,0x4a,0x4a,0x4b,0x4a,0x48,0x4b,0x4a,0x7a,0x4b,0x02,0x02,0x03,0x02,
+0x20,0x24,0xa8,0x30,0xa2,0x22,0x5e,0x80,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 21897 0x5589 "喉" */
+0x01,0x01,0x71,0x52,0x52,0x56,0x5a,0x52,0x52,0x52,0x72,0x52,0x02,0x02,0x02,0x02,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 21898 0x558a "喊" */
+0x00,0x00,0x70,0x57,0x54,0x54,0x55,0x54,0x54,0x55,0x75,0x55,0x05,0x04,0x08,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 21899 0x558b "喋" */
+0x00,0x01,0x79,0x4b,0x49,0x49,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x01,0x06,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 21900 0x558c "喌" */
+0x00,0x7e,0x42,0x42,0x7e,0x00,0x10,0x11,0x11,0x55,0x53,0x91,0x21,0x21,0x41,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0x08,0x08,0x08,0x48,0x28,0x08,0x08,0x08,0x08,0x08,
+/* 21901 0x558d "喍" */
+0x00,0x00,0x7a,0x4a,0x4a,0x4a,0x4f,0x48,0x48,0x4b,0x78,0x48,0x01,0x06,0x00,0x00,
+0x90,0x92,0xd4,0x98,0x92,0xd2,0x0e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 21902 0x558e "喎" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 21903 0x558f "喏" */
+0x01,0x01,0xf7,0x91,0x91,0x90,0x97,0x90,0x91,0x93,0xf5,0x99,0x01,0x01,0x01,0x01,
+0x08,0x08,0xfe,0x08,0x48,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 21904 0x5590 "喐" */
+0x01,0x01,0x77,0x51,0x52,0x53,0x52,0x56,0x5b,0x52,0x72,0x53,0x02,0x02,0x02,0x02,
+0x00,0x1e,0xf2,0x12,0x14,0xd4,0x58,0x54,0xd2,0x52,0x52,0xda,0x54,0x50,0x50,0xd0,
+/* 21905 0x5591 "喑" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4f,0x48,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 21906 0x5592 "喒" */
+0x00,0x00,0x79,0x49,0x4a,0x4d,0x48,0x49,0x4e,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x88,0x88,0xec,0x2a,0x28,0x48,0x88,0x7e,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,
+/* 21907 0x5593 "喓" */
+0x00,0x03,0x78,0x48,0x4b,0x4a,0x4a,0x4b,0x48,0x48,0x4f,0x78,0x49,0x00,0x00,0x03,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 21908 0x5594 "喔" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x4b,0x4a,0x4a,0x4b,0x7a,0x4a,0x05,0x04,0x08,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 21909 0x5595 "喕" */
+0x00,0x07,0x78,0x48,0x4b,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x02,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 21910 0x5596 "喖" */
+0x01,0x01,0x71,0x51,0x57,0x51,0x53,0x53,0x55,0x55,0x79,0x51,0x01,0x01,0x01,0x01,
+0x08,0x08,0x08,0x08,0xbe,0x08,0x08,0x88,0x7e,0x22,0x22,0x22,0x22,0x22,0x3e,0x22,
+/* 21911 0x5597 "喗" */
+0x00,0x03,0x7a,0x48,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x48,0x03,0x00,0x00,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 21912 0x5598 "喘" */
+0x00,0x04,0xf4,0x94,0x97,0x90,0x9f,0x90,0x90,0x97,0xf4,0x94,0x04,0x04,0x04,0x04,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x0c,
+/* 21913 0x5599 "喙" */
+0x01,0x01,0xf2,0x93,0x90,0x97,0x90,0x91,0x96,0x90,0xf1,0x96,0x00,0x01,0x06,0x00,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 21914 0x559a "喚" */
+0x01,0x01,0xf3,0x94,0x98,0x97,0x94,0x94,0x95,0x94,0xf0,0x9f,0x00,0x01,0x02,0x0c,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x04,0xa4,0x14,0x44,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 21915 0x559b "喛" */
+0x00,0x07,0x7a,0x49,0x48,0x4b,0x48,0x48,0x4f,0x49,0x79,0x4a,0x02,0x04,0x08,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 21916 0x559c "喜" */
+0x01,0x7f,0x01,0x3f,0x00,0x3f,0x20,0x3f,0x08,0xff,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x20,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21917 0x559d "喝" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4b,0x49,0x4b,0x4c,0x4a,0x7a,0x4a,0x03,0x00,0x00,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 21918 0x559e "喞" */
+0x00,0x01,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x48,0x7a,0x4b,0x02,0x02,0x01,0x00,
+0x80,0x00,0xde,0x52,0x52,0xd2,0x52,0x52,0xd2,0x12,0x5a,0x94,0x10,0x50,0xd0,0x10,
+/* 21919 0x559f "喟" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4b,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 21920 0x55a0 "喠" */
+0x00,0x00,0x79,0x48,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x48,0x01,0x00,0x03,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 21921 0x55a1 "喡" */
+0x00,0x00,0x79,0x48,0x4b,0x48,0x49,0x49,0x49,0x48,0x7b,0x48,0x02,0x03,0x00,0x00,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 21922 0x55a2 "喢" */
+0x00,0x00,0x7b,0x48,0x48,0x4f,0x48,0x48,0x4b,0x4a,0x7a,0x4b,0x02,0x02,0x03,0x02,
+0x04,0x1e,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2e,0x22,0x22,0xae,0x22,0x22,0xfe,0x02,
+/* 21923 0x55a3 "喣" */
+0x01,0x01,0x79,0x4a,0x4c,0x49,0x49,0x49,0x79,0x48,0x00,0x00,0x24,0x22,0x42,0x80,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,0x88,0x44,0x44,0x04,
+/* 21924 0x55a4 "喤" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x48,0x4b,0x48,0x78,0x49,0x00,0x00,0x03,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 21925 0x55a5 "喥" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x09,
+0x40,0x20,0xfe,0x48,0x48,0xfe,0x48,0x78,0x00,0xfc,0x44,0x48,0x28,0x10,0x68,0x86,
+/* 21926 0x55a6 "喦" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x7d,0x45,0x45,0x7d,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x7c,0x44,0x44,0x7c,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 21927 0x55a7 "喧" */
+0x00,0x00,0x7b,0x4a,0x4c,0x49,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 21928 0x55a8 "喨" */
+0x00,0x00,0xf7,0x90,0x93,0x92,0x93,0x90,0x97,0x94,0xf9,0x91,0x01,0x02,0x04,0x08,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf4,0x10,0x10,0x12,0x12,0x0e,
+/* 21929 0x55a9 "喩" */
+0x01,0x00,0x79,0x4a,0x4d,0x48,0x4b,0x4a,0x4a,0x4b,0x7a,0x4a,0x03,0x02,0x02,0x02,
+0xc0,0xa0,0x10,0x08,0xf6,0x00,0xca,0x4a,0x54,0xd4,0x68,0x54,0xd4,0x4a,0x4a,0xc0,
+/* 21930 0x55aa "喪" */
+0x01,0x01,0x7f,0x01,0x3d,0x25,0x3d,0x01,0xff,0x12,0x11,0x10,0x10,0x14,0x18,0x10,
+0x00,0x00,0xfc,0x00,0x78,0x48,0x78,0x00,0xfe,0x00,0x10,0xa0,0x40,0x30,0x0e,0x00,
+/* 21931 0x55ab "喫" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x48,0x48,0x7b,0x48,0x00,0x00,0x01,0x06,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 21932 0x55ac "喬" */
+0x00,0x3f,0x02,0xff,0x04,0x0f,0x34,0xc7,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x20,
+0xf8,0x00,0x00,0xfe,0x40,0xe0,0x58,0xc6,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x28,0x10,
+/* 21933 0x55ad "喭" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x09,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x10,0x20,0xc8,0x10,0x24,0xc8,0x10,0x60,0x80,
+/* 21934 0x55ae "單" */
+0x00,0x7e,0x42,0x42,0x7e,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 21935 0x55af "喯" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x4a,0x48,0x48,0x48,0x7b,0x48,0x00,0x00,0x01,0x02,
+0x20,0x20,0xfe,0x50,0xa8,0x24,0xfa,0x20,0xa8,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 21936 0x55b0 "喰" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x4b,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x02,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x28,0x90,0x08,0x04,
+/* 21937 0x55b1 "喱" */
+0x00,0x07,0xf4,0x95,0x95,0x95,0x95,0x95,0x95,0x95,0xf4,0x94,0x05,0x08,0x08,0x13,
+0x00,0xfe,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 21938 0x55b2 "喲" */
+0x01,0x01,0x72,0x52,0x54,0x5f,0x51,0x52,0x54,0x5f,0x74,0x50,0x0a,0x09,0x11,0x00,
+0x10,0x10,0x10,0x9e,0xa2,0x22,0x42,0x12,0x8a,0xca,0x42,0x02,0x82,0x42,0x54,0x08,
+/* 21939 0x55b3 "喳" */
+0x00,0x00,0xf7,0x90,0x91,0x92,0x94,0x93,0x92,0x93,0xf2,0x93,0x02,0x00,0x0f,0x00,
+0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 21940 0x55b4 "喴" */
+0x00,0x00,0x77,0x54,0x54,0x57,0x54,0x54,0x57,0x55,0x75,0x54,0x05,0x0a,0x08,0x10,
+0x14,0x12,0xfe,0x10,0x10,0xf0,0x92,0x92,0xd2,0x54,0x54,0x88,0x4a,0x1a,0x26,0x42,
+/* 21941 0x55b5 "喵" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 21942 0x55b6 "営" */
+0x22,0x11,0x00,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x08,0x10,0x20,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21943 0x55b7 "喷" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x00,0x03,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 21944 0x55b8 "喸" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x00,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0x88,0xb0,0xc4,0x84,0x7c,
+/* 21945 0x55b9 "喹" */
+0x00,0x00,0xf7,0x90,0x91,0x92,0x9d,0x90,0x90,0x97,0xf0,0x90,0x03,0x00,0x00,0x0f,
+0x40,0x40,0xfc,0xa0,0x10,0x48,0xf6,0x40,0x40,0xfc,0x00,0x40,0xf8,0x40,0x40,0xfe,
+/* 21946 0x55ba "喺" */
+0x01,0x01,0x71,0x52,0x52,0x56,0x5a,0x52,0x52,0x52,0x72,0x52,0x02,0x03,0x02,0x02,
+0x06,0x78,0x10,0x22,0x44,0xf8,0x14,0x22,0xfe,0x12,0x10,0x54,0x92,0x12,0x50,0x20,
+/* 21947 0x55bb "喻" */
+0x00,0x00,0x79,0x4a,0x4d,0x48,0x4b,0x4a,0x4a,0x4b,0x7a,0x4a,0x03,0x02,0x02,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 21948 0x55bc "喼" */
+0x00,0x00,0x79,0x4a,0x4c,0x4b,0x48,0x49,0x48,0x4b,0x78,0x48,0x01,0x05,0x05,0x08,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x40,0x24,0x2a,0x0a,0xf8,
+/* 21949 0x55bd "喽" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x4a,0x48,0x4f,0x78,0x49,0x01,0x00,0x01,0x06,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 21950 0x55be "喾" */
+0x22,0x11,0x00,0x7f,0x41,0x91,0x1f,0x21,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x08,0x10,0x20,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 21951 0x55bf "喿" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x7c,0x44,0x44,0x7c,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 21952 0x55c0 "嗀" */
+0x10,0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x00,0x7c,0x00,0x7c,0x44,0x44,0x7c,0x45,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 21953 0x55c1 "嗁" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x05,0x0a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 21954 0x55c2 "嗂" */
+0x00,0x00,0x7b,0x48,0x4a,0x49,0x49,0x4a,0x48,0x4b,0x78,0x49,0x01,0x01,0x01,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 21955 0x55c3 "嗃" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x49,0x48,0x4b,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 21956 0x55c4 "嗄" */
+0x07,0x00,0xf3,0x92,0x93,0x92,0x93,0x92,0x93,0x90,0xf1,0x93,0x04,0x00,0x01,0x0e,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xf8,0x10,0xa0,0x40,0xb0,0x0e,
+/* 21957 0x55c5 "嗅" */
+0x00,0x00,0x7b,0x4a,0x4b,0x4a,0x4b,0x4a,0x4b,0x48,0x78,0x4f,0x00,0x01,0x02,0x0c,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x50,0x48,0xfe,0xa0,0x10,0x08,0x06,
+/* 21958 0x55c6 "嗆" */
+0x00,0x00,0xf0,0x91,0x92,0x97,0x9a,0x93,0x92,0x93,0xf2,0x93,0x05,0x05,0x09,0x01,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21959 0x55c7 "嗇" */
+0x01,0x01,0x7f,0x11,0x29,0x45,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x00,0x00,0xfc,0x10,0x28,0x44,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 21960 0x55c8 "嗈" */
+0x01,0x02,0x7a,0x49,0x4b,0x4a,0x4b,0x48,0x4b,0x4a,0x7a,0x4b,0x02,0x02,0x01,0x00,
+0x24,0x48,0x48,0x24,0xf8,0x08,0xf8,0x00,0xf8,0x48,0x48,0xf8,0x02,0x02,0xfe,0x00,
+/* 21961 0x55c9 "嗉" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x48,0x48,0x49,0x78,0x4b,0x00,0x01,0x02,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 21962 0x55ca "嗊" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x01,0x02,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 21963 0x55cb "嗋" */
+0x00,0x01,0x78,0x48,0x49,0x4b,0x49,0x49,0x4a,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x40,0xfc,0x44,0x94,0x08,0xde,0x4a,0x4a,0x94,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 21964 0x55cc "嗌" */
+0x02,0x01,0xf1,0x90,0x97,0x90,0x91,0x92,0x94,0x93,0xf2,0x92,0x02,0x02,0x0f,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 21965 0x55cd "嗍" */
+0x04,0x02,0x72,0x50,0x57,0x51,0x55,0x55,0x55,0x57,0x71,0x51,0x02,0x02,0x04,0x08,
+0x40,0x5e,0x92,0x12,0xd2,0x1e,0x52,0x52,0x52,0xde,0x52,0x12,0x12,0x22,0x2a,0x44,
+/* 21966 0x55ce "嗎" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x7a,0x4a,0x02,0x02,0x00,0x00,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 21967 0x55cf "嗏" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x48,0x49,0x4a,0x49,0x78,0x48,0x01,0x02,0x00,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x50,0x88,0x24,0x22,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 21968 0x55d0 "嗐" */
+0x00,0x00,0x7b,0x4a,0x4c,0x49,0x48,0x49,0x48,0x4b,0x78,0x49,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 21969 0x55d1 "嗑" */
+0x00,0x00,0x79,0x48,0x48,0x4b,0x48,0x49,0x4b,0x48,0x7b,0x4a,0x02,0x02,0x07,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 21970 0x55d2 "嗒" */
+0x01,0x01,0xf7,0x91,0x90,0x90,0x91,0x92,0x95,0x90,0xf0,0x93,0x02,0x02,0x03,0x02,
+0x10,0x10,0xfc,0x10,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 21971 0x55d3 "嗓" */
+0x03,0x01,0xf0,0x93,0x90,0x97,0x94,0x93,0x94,0x90,0xf7,0x90,0x01,0x02,0x0c,0x00,
+0xf0,0x10,0xe0,0x18,0x00,0xbc,0xa4,0x18,0xa4,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 21972 0x55d4 "嗔" */
+0x00,0x00,0xf7,0x90,0x93,0x92,0x93,0x92,0x93,0x92,0xf3,0x92,0x0f,0x01,0x02,0x04,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 21973 0x55d5 "嗕" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x04,0x04,0x08,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 21974 0x55d6 "嗖" */
+0x01,0x06,0xf4,0x94,0x97,0x94,0x94,0x97,0x90,0x97,0xf2,0x91,0x00,0x00,0x01,0x0e,
+0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x40,0xfc,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 21975 0x55d7 "嗗" */
+0x00,0x01,0x79,0x49,0x49,0x4b,0x4a,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x00,0xfc,0x04,0xe4,0x24,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 21976 0x55d8 "嗘" */
+0x00,0x03,0x79,0x48,0x48,0x48,0x49,0x48,0x48,0x49,0x78,0x48,0x03,0x00,0x00,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 21977 0x55d9 "嗙" */
+0x00,0x00,0x7b,0x49,0x48,0x4b,0x4a,0x4c,0x48,0x4b,0x78,0x48,0x00,0x01,0x01,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 21978 0x55da "嗚" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x4a,0x02,0x04,0x00,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 21979 0x55db "嗛" */
+0x01,0x00,0x78,0x4b,0x48,0x4b,0x48,0x4f,0x48,0x4b,0x78,0x49,0x02,0x0c,0x00,0x00,
+0x08,0x90,0x00,0xfe,0xa0,0xfc,0xa4,0xfe,0xa4,0xfc,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 21980 0x55dc "嗜" */
+0x00,0x00,0x79,0x48,0x4b,0x48,0x48,0x49,0x4a,0x4c,0x79,0x49,0x01,0x01,0x01,0x01,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 21981 0x55dd "嗝" */
+0x00,0x0f,0xf0,0x93,0x92,0x92,0x93,0x90,0x97,0x95,0xf4,0x97,0x04,0x04,0x04,0x04,
+0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x14,0xa4,0xfc,0x44,0x44,0x54,0x08,
+/* 21982 0x55de "嗞" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x49,0x49,0x4a,0x4b,0x78,0x49,0x01,0x02,0x03,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 21983 0x55df "嗟" */
+0x01,0x00,0x78,0x4b,0x48,0x49,0x48,0x4b,0x48,0x49,0x79,0x4a,0x04,0x08,0x03,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 21984 0x55e0 "嗠" */
+0x0e,0xf0,0x22,0x92,0x55,0x00,0x7c,0x08,0x11,0x10,0x1e,0xf0,0x50,0x10,0x50,0x20,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 21985 0x55e1 "嗡" */
+0x00,0x00,0x79,0x4a,0x4c,0x49,0x48,0x48,0x4b,0x48,0x7a,0x49,0x02,0x00,0x01,0x00,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 21986 0x55e2 "嗢" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x48,0x4b,0x7a,0x4a,0x02,0x02,0x07,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 21987 0x55e3 "嗣" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x55,0x55,0x55,0x7f,0x55,0x55,0x55,0x51,0x43,
+0x00,0x7c,0x04,0x04,0xf4,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 21988 0x55e4 "嗤" */
+0x00,0x01,0x79,0x49,0x48,0x4b,0x48,0x48,0x49,0x49,0x79,0x49,0x00,0x00,0x03,0x01,
+0x20,0x24,0x24,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 21989 0x55e5 "嗥" */
+0x00,0x00,0xf3,0x92,0x93,0x92,0x93,0x90,0x97,0x91,0xf2,0x94,0x0b,0x00,0x00,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xfc,0x10,0x48,0x44,0xfa,0x40,0x40,0x40,
+/* 21990 0x55e6 "嗦" */
+0x00,0x00,0xf7,0x90,0x97,0x94,0x99,0x93,0x90,0x90,0xf7,0x90,0x02,0x04,0x09,0x00,
+0x40,0x40,0xfc,0x40,0xfc,0x84,0x18,0xe0,0x40,0x88,0xfc,0x44,0x50,0x48,0x48,0x80,
+/* 21991 0x55e7 "嗧" */
+0x10,0x7e,0x12,0x2a,0x45,0x82,0x0c,0x37,0xc0,0x3f,0x24,0x24,0x3f,0x24,0x24,0x20,
+0x00,0x78,0x48,0x48,0x78,0x80,0x60,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,0xa8,0x10,
+/* 21992 0x55e8 "嗨" */
+0x00,0x08,0xe4,0xa1,0xaa,0xa4,0xa4,0xa0,0xa3,0xa4,0xed,0xa5,0x05,0x04,0x04,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 21993 0x55e9 "嗩" */
+0x00,0x01,0x78,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x79,0x49,0x00,0x00,0x01,
+0x20,0x24,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 21994 0x55ea "嗪" */
+0x00,0x00,0xf7,0x90,0x93,0x90,0x97,0x91,0x92,0x95,0xf0,0x93,0x00,0x01,0x06,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x68,0xc6,0x40,0xf8,0xe0,0x58,0x44,0x40,
+/* 21995 0x55eb "嗫" */
+0x00,0x03,0x79,0x49,0x49,0x49,0x49,0x4f,0x48,0x4f,0x78,0x4a,0x01,0x02,0x04,0x08,
+0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 21996 0x55ec "嗬" */
+0x01,0x01,0xf7,0x91,0x91,0x92,0x92,0x96,0x9a,0x92,0xf2,0x92,0x02,0x02,0x02,0x02,
+0x10,0x10,0xfe,0x10,0x00,0xfe,0x08,0x08,0xe8,0xa8,0xa8,0xe8,0xa8,0x08,0x28,0x10,
+/* 21997 0x55ed "嗭" */
+0x01,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x00,0x3e,0x22,0x3e,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x90,0xe4,0x84,0x7c,
+/* 21998 0x55ee "嗮" */
+0x00,0x00,0xee,0xaa,0xaa,0xaa,0xaa,0xae,0xaa,0xaa,0xea,0xaa,0x0e,0x0a,0x00,0x00,
+0x00,0xfe,0x28,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0x82,0xfe,0x82,
+/* 21999 0x55ef "嗯" */
+0x00,0x07,0xf4,0x94,0x97,0x94,0x94,0x95,0x94,0x97,0xf0,0x90,0x05,0x05,0x09,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0xa4,0x14,0x04,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 22000 0x55f0 "嗰" */
+0x02,0x03,0x75,0x55,0x5d,0x55,0x55,0x55,0x55,0x55,0x75,0x55,0x05,0x05,0x05,0x05,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x54,0x74,0x04,0xfc,0x04,
+/* 22001 0x55f1 "嗱" */
+0x00,0x00,0x78,0x49,0x4a,0x48,0x48,0x48,0x48,0x49,0x78,0x49,0x00,0x03,0x00,0x00,
+0x20,0x50,0x88,0x74,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0x60,
+/* 22002 0x55f2 "嗲" */
+0x00,0x01,0xf2,0x90,0x91,0x96,0x90,0x93,0x90,0x90,0xf7,0x90,0x03,0x00,0x00,0x07,
+0x90,0x08,0x94,0x60,0x98,0x46,0xfc,0x08,0xb0,0xd0,0x3e,0xc2,0x24,0x18,0x60,0x80,
+/* 22003 0x55f3 "嗳" */
+0x00,0x03,0x78,0x4a,0x49,0x4b,0x4a,0x48,0x4b,0x48,0x78,0x49,0x01,0x02,0x04,0x01,
+0x0e,0xf0,0x44,0x24,0x08,0xfe,0x42,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 22004 0x55f4 "嗴" */
+0x01,0x00,0x7b,0x48,0x48,0x49,0x48,0x48,0x4b,0x48,0x78,0x48,0x01,0x01,0x02,0x04,
+0x08,0x90,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0xa0,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 22005 0x55f5 "嗵" */
+0x01,0x08,0xe4,0xa4,0xa1,0xa1,0xbd,0xa5,0xa5,0xa5,0xe5,0xa5,0x05,0x0a,0x11,0x00,
+0xfc,0x08,0x50,0x20,0xfc,0x24,0x24,0xfc,0x24,0xfc,0x24,0x24,0x2c,0x00,0xfe,0x00,
+/* 22006 0x55f6 "嗶" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x48,0x48,0x4b,0x48,0x78,0x49,0x00,0x03,0x00,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 22007 0x55f7 "嗷" */
+0x01,0x01,0x71,0x57,0x51,0x57,0x51,0x5f,0x52,0x53,0x72,0x52,0x02,0x04,0x04,0x08,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 22008 0x55f8 "嗸" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x80,0x3f,0x20,0x20,0x3f,0x20,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 22009 0x55f9 "嗹" */
+0x00,0x08,0x75,0x54,0x51,0x51,0x5d,0x55,0x55,0x54,0x75,0x54,0x04,0x0a,0x11,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 22010 0x55fa "嗺" */
+0x00,0x02,0x7b,0x48,0x48,0x49,0x4b,0x4d,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 22011 0x55fb "嗻" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x05,0x05,0x0a,0x10,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 22012 0x55fc "嗼" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 22013 0x55fd "嗽" */
+0x01,0x01,0xf7,0x91,0x91,0x97,0x95,0x95,0x97,0x91,0xf3,0x95,0x09,0x01,0x01,0x01,
+0x08,0x08,0xc8,0x08,0x1e,0xd2,0x64,0x40,0xc8,0x08,0x88,0x48,0x54,0x14,0x24,0x42,
+/* 22014 0x55fe "嗾" */
+0x04,0x02,0x72,0x5f,0x54,0x54,0x57,0x55,0x55,0x55,0x75,0x55,0x05,0x09,0x0b,0x10,
+0x20,0x20,0x3e,0x40,0xa0,0x20,0x3c,0x50,0x10,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 22015 0x55ff "嗿" */
+0x00,0x00,0x79,0x4a,0x4d,0x48,0x48,0x4b,0x4a,0x4b,0x7a,0x4b,0x02,0x03,0x01,0x02,
+0x40,0xa0,0x10,0x48,0xf6,0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 22016 0x5600 "嘀" */
+0x00,0x00,0xf7,0x91,0x90,0x97,0x94,0x95,0x94,0x95,0xf5,0x95,0x05,0x04,0x04,0x04,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xf4,0x44,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 22017 0x5601 "嘁" */
+0x00,0x00,0x70,0x57,0x54,0x54,0x54,0x54,0x57,0x54,0x74,0x55,0x0a,0x08,0x11,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 22018 0x5602 "嘂" */
+0x00,0x78,0x48,0x4a,0x4a,0x4a,0x7a,0x02,0x7a,0x4a,0x4b,0x4a,0x48,0x78,0x48,0x00,
+0x40,0x5e,0x52,0x52,0x52,0x52,0x5e,0x40,0x5e,0xd2,0x52,0x52,0x52,0x5e,0x52,0x40,
+/* 22019 0x5603 "嘃" */
+0x00,0x07,0x74,0x55,0x54,0x57,0x54,0x55,0x54,0x55,0x75,0x55,0x05,0x09,0x09,0x11,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 22020 0x5604 "嘄" */
+0x01,0x03,0x7a,0x4b,0x4a,0x4b,0x4a,0x4b,0x4a,0x4b,0x78,0x4f,0x01,0x06,0x18,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfe,0x42,0xfa,0x64,0x58,0x46,0x40,
+/* 22021 0x5605 "嘅" */
+0x00,0x07,0x74,0x54,0x57,0x54,0x54,0x57,0x54,0x55,0x74,0x55,0x06,0x04,0x00,0x00,
+0x00,0xbe,0x88,0x88,0xa8,0xa8,0xa8,0xbe,0x10,0x18,0x98,0xa8,0xaa,0x4a,0x46,0x80,
+/* 22022 0x5606 "嘆" */
+0x01,0x01,0xf7,0x91,0x91,0x90,0x93,0x92,0x93,0x90,0xf7,0x90,0x0f,0x00,0x01,0x06,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0xa0,0x10,0x0c,
+/* 22023 0x5607 "嘇" */
+0x00,0x01,0xf3,0x92,0x94,0x9f,0x90,0x90,0x93,0x9c,0xf1,0x96,0x01,0x06,0x01,0x0e,
+0x80,0x10,0xf8,0x10,0xa4,0xbe,0x42,0xa0,0x18,0x46,0x90,0x64,0x88,0x30,0xc0,0x00,
+/* 22024 0x5608 "嘈" */
+0x00,0x00,0x77,0x50,0x57,0x54,0x57,0x54,0x57,0x50,0x73,0x52,0x03,0x02,0x03,0x02,
+0xa0,0xa0,0xfe,0xa0,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 22025 0x5609 "嘉" */
+0x01,0xff,0x01,0x3f,0x00,0x1f,0x10,0x1f,0x08,0xff,0x10,0x7f,0x11,0x21,0x45,0x82,
+0x00,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x20,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,
+/* 22026 0x560a "嘊" */
+0x00,0x02,0x7a,0x4b,0x48,0x4b,0x4a,0x4b,0x4a,0x4b,0x7a,0x4a,0x05,0x04,0x0b,0x00,
+0x20,0x22,0x22,0xfe,0x00,0xfe,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x20,0xfe,0x00,
+/* 22027 0x560b "嘋" */
+0x02,0x02,0xe7,0xa2,0xa2,0xaf,0xa1,0xa2,0xaf,0xa4,0xe9,0xa1,0x0f,0x01,0x05,0x02,
+0x08,0x48,0x48,0x90,0x9e,0xe4,0x14,0x14,0xd4,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 22028 0x560c "嘌" */
+0x00,0x0f,0xe0,0xa7,0xa4,0xa4,0xa7,0xa0,0xa7,0xa0,0xef,0xa0,0x02,0x04,0x09,0x00,
+0x00,0xfe,0xa0,0xfc,0xa4,0xa4,0xfc,0x00,0xfc,0x00,0xfe,0x40,0x48,0x44,0x42,0x80,
+/* 22029 0x560d "嘍" */
+0x00,0x03,0xf2,0x9f,0x92,0x93,0x90,0x93,0x92,0x93,0xf0,0x9f,0x01,0x00,0x03,0x0c,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x48,0xf8,0x80,0xfe,0x10,0xe0,0x18,0x04,
+/* 22030 0x560e "嘎" */
+0x07,0x00,0x7b,0x4a,0x4b,0x4a,0x4b,0x4a,0x4b,0x49,0x79,0x4f,0x00,0x00,0x01,0x0e,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x7c,0x80,0x90,0x62,0xb2,0x0e,
+/* 22031 0x560f "嘏" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xdc,0x44,0x44,0x44,0xdc,0x00,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 22032 0x5610 "嘐" */
+0x00,0x07,0xf0,0x94,0x92,0x94,0x90,0x91,0x96,0x90,0xf3,0x90,0x03,0x00,0x00,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 22033 0x5611 "嘑" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7b,0x4a,0x05,0x04,0x08,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 22034 0x5612 "嘒" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x48,0x48,0x4b,0x48,0x78,0x49,0x00,0x00,0x03,0x00,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 22035 0x5613 "嘓" */
+0x00,0x0f,0xe8,0xa8,0xaf,0xa8,0xab,0xaa,0xab,0xa8,0xe9,0xae,0x08,0x08,0x0f,0x08,
+0x00,0xfe,0x2a,0x26,0xfe,0x22,0xaa,0xaa,0xaa,0x32,0x96,0x2e,0x46,0x82,0xfe,0x02,
+/* 22036 0x5614 "嘔" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x03,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 22037 0x5615 "嘕" */
+0x00,0x07,0xf0,0x92,0x92,0x9f,0x91,0x91,0x92,0x93,0xf0,0x95,0x05,0x08,0x00,0x00,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 22038 0x5616 "嘖" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x00,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 22039 0x5617 "嘗" */
+0x11,0x09,0x7f,0x50,0x9f,0x00,0x20,0x3f,0x20,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x10,0x20,0xfe,0x12,0xf4,0x00,0xf0,0x04,0x04,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 22040 0x5618 "嘘" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7a,0x4b,0x04,0x04,0x09,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0x50,0x54,0x54,0xd8,0x50,0xfe,0x00,
+/* 22041 0x5619 "嘙" */
+0x04,0x02,0xe8,0xa4,0xa2,0xa4,0xac,0xa5,0xa5,0xa6,0xe0,0xaf,0x01,0x03,0x00,0x07,
+0x10,0x10,0xfe,0x92,0xfc,0xa4,0xa8,0x10,0x28,0xc6,0x80,0xfe,0x10,0x20,0xe0,0x18,
+/* 22042 0x561a "嘚" */
+0x02,0x02,0x74,0x59,0x51,0x52,0x56,0x5a,0x52,0x53,0x72,0x52,0x02,0x02,0x02,0x02,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfc,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 22043 0x561b "嘛" */
+0x00,0x00,0xf7,0x94,0x94,0x94,0x97,0x94,0x94,0x95,0xf5,0x96,0x08,0x08,0x10,0x00,
+0x40,0x20,0xfe,0x90,0x90,0x90,0xfc,0x90,0xd8,0xb8,0xb4,0xd4,0x92,0x90,0x90,0x90,
+/* 22044 0x561c "嘜" */
+0x00,0x07,0x71,0x51,0x52,0x54,0x50,0x53,0x5c,0x50,0x71,0x52,0x04,0x00,0x00,0x07,
+0x40,0xfc,0x50,0x50,0xe8,0x44,0xe0,0x58,0x46,0x80,0xf8,0x08,0xd0,0x20,0xd0,0x08,
+/* 22045 0x561d "嘝" */
+0x02,0x02,0x77,0x54,0x59,0x57,0x55,0x55,0x57,0x55,0x75,0x57,0x05,0x05,0x04,0x08,
+0x04,0x04,0x84,0x94,0x0c,0xc4,0x64,0x54,0xc4,0x46,0x7c,0xc4,0x44,0x44,0x44,0xc4,
+/* 22046 0x561e "嘞" */
+0x02,0x02,0x77,0x52,0x53,0x51,0x57,0x55,0x55,0x57,0x71,0x57,0x01,0x01,0x01,0x01,
+0x90,0x90,0xd0,0x90,0xbc,0x14,0xd4,0x54,0x54,0xd4,0x14,0xd4,0x24,0x24,0x54,0x88,
+/* 22047 0x561f "嘟" */
+0x02,0x02,0xef,0xa2,0xa2,0xaf,0xa1,0xa2,0xa7,0xac,0xf4,0xa7,0x04,0x04,0x07,0x04,
+0x00,0x3e,0x62,0x64,0xa4,0xe8,0x24,0x24,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0xa0,
+/* 22048 0x5620 "嘠" */
+0x07,0x00,0xf3,0x92,0x93,0x92,0x93,0x92,0x97,0x94,0xf8,0x97,0x00,0x00,0x00,0x03,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0xa2,0x9c,0xf0,0x50,0x24,0xd4,0x0c,
+/* 22049 0x5621 "嘡" */
+0x00,0x01,0x78,0x4b,0x4a,0x48,0x48,0x48,0x48,0x48,0x78,0x49,0x00,0x00,0x03,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 22050 0x5622 "嘢" */
+0x00,0x07,0x75,0x55,0x57,0x55,0x55,0x57,0x51,0x51,0x77,0x51,0x01,0x01,0x0e,0x04,
+0x00,0xde,0x42,0x54,0xc8,0x44,0x7e,0xca,0x0a,0x08,0xc8,0x08,0x08,0xc8,0x28,0x10,
+/* 22051 0x5623 "嘣" */
+0x00,0x04,0x74,0x57,0x50,0x57,0x54,0x54,0x57,0x54,0x74,0x57,0x04,0x04,0x0a,0x11,
+0x40,0x44,0x44,0xfc,0x00,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xb4,0x48,
+/* 22052 0x5624 "嘤" */
+0x00,0x0f,0xe8,0xaa,0xaa,0xaa,0xa5,0xa8,0xa0,0xaf,0xe1,0xa2,0x03,0x00,0x01,0x0e,
+0x00,0xbe,0xa2,0xaa,0xaa,0xaa,0x14,0xa2,0x80,0xfe,0x10,0x10,0xa0,0x60,0x98,0x04,
+/* 22053 0x5625 "嘥" */
+0x02,0x02,0x74,0x59,0x51,0x52,0x56,0x5a,0x52,0x52,0x72,0x52,0x02,0x02,0x03,0x02,
+0x10,0x10,0x50,0x5c,0x50,0x50,0xfe,0x00,0x10,0x50,0x5c,0x50,0xb0,0x90,0x0e,0x00,
+/* 22054 0x5626 "嘦" */
+0x3f,0x20,0x3f,0x10,0x20,0x5f,0x04,0x3f,0x24,0x3f,0x04,0xff,0x08,0x1e,0x03,0x3c,
+0xf8,0x08,0xf8,0x10,0x08,0xf4,0x40,0xf8,0x48,0xf8,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 22055 0x5627 "嘧" */
+0x00,0x00,0xf7,0x94,0x98,0x90,0x95,0x95,0x98,0x93,0xf0,0x94,0x04,0x04,0x07,0x00,
+0x80,0x40,0xfe,0x02,0x94,0x50,0x24,0x4a,0xfa,0x00,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 22056 0x5628 "嘨" */
+0x00,0x00,0x77,0x50,0x5f,0x50,0x57,0x50,0x55,0x54,0x74,0x57,0x04,0x09,0x0a,0x10,
+0x40,0x40,0xfc,0x44,0xfe,0x44,0xfc,0x40,0x54,0xe4,0x44,0xfc,0xe4,0x54,0x4c,0x44,
+/* 22057 0x5629 "嘩" */
+0x00,0x03,0x78,0x48,0x49,0x48,0x48,0x4b,0x48,0x48,0x79,0x48,0x03,0x00,0x00,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22058 0x562a "嘪" */
+0x00,0x03,0x7a,0x4a,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x01,0x02,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 22059 0x562b "嘫" */
+0x01,0x01,0x79,0x4a,0x4a,0x4d,0x48,0x4a,0x49,0x49,0x7a,0x4c,0x00,0x02,0x02,0x04,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 22060 0x562c "嘬" */
+0x00,0x03,0xf2,0x93,0x92,0x93,0x90,0x9f,0x94,0x97,0xf4,0x97,0x04,0x0f,0x00,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x80,0xbc,0x94,0x94,0xd4,0x88,0x94,0xa2,
+/* 22061 0x562d "嘭" */
+0x01,0x01,0x77,0x51,0x51,0x57,0x50,0x57,0x54,0x54,0x77,0x54,0x02,0x00,0x0f,0x04,
+0x04,0x04,0xe8,0x10,0x00,0xc4,0x04,0xc8,0x50,0x42,0xc2,0x44,0x84,0xe8,0x10,0x20,
+/* 22062 0x562e "嘮" */
+0x00,0x02,0x7a,0x4c,0x49,0x4a,0x48,0x4b,0x4a,0x4c,0x7b,0x48,0x00,0x00,0x01,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 22063 0x562f "嘯" */
+0x00,0x03,0xf0,0x97,0x90,0x93,0x90,0x95,0x97,0x94,0xf7,0x94,0x07,0x05,0x05,0x08,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 22064 0x5630 "嘰" */
+0x02,0x02,0x75,0x57,0x52,0x55,0x57,0x52,0x5f,0x52,0x72,0x52,0x05,0x04,0x04,0x08,
+0x48,0x48,0x54,0x5c,0x48,0x54,0x5c,0x48,0xfe,0x20,0x28,0x28,0x14,0x94,0x2c,0x44,
+/* 22065 0x5631 "嘱" */
+0x00,0x07,0xf4,0x97,0x94,0x95,0x94,0x95,0x95,0x95,0xf4,0x97,0x06,0x06,0x0a,0x12,
+0x00,0xfc,0x04,0xfc,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x2a,0xfa,0x0a,0x06,
+/* 22066 0x5632 "嘲" */
+0x02,0x02,0x0f,0xe2,0xa2,0xaf,0xa8,0xaf,0xa8,0xaf,0xa2,0xe2,0xaf,0x02,0x02,0x02,
+0x00,0x3c,0xa4,0x24,0x24,0xbc,0xa4,0xa4,0xa4,0xbc,0x24,0x24,0xa4,0x24,0x44,0x8c,
+/* 22067 0x5633 "嘳" */
+0x00,0x01,0x79,0x49,0x48,0x4b,0x48,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x00,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 22068 0x5634 "嘴" */
+0x00,0x02,0xf2,0x92,0x92,0x97,0x91,0x92,0x97,0x9a,0xf3,0x92,0x03,0x04,0x04,0x08,
+0x90,0x94,0xd8,0x92,0xd2,0x0e,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x54,0x08,
+/* 22069 0x5635 "嘵" */
+0x00,0x00,0x79,0x48,0x4b,0x49,0x4b,0x49,0x49,0x4e,0x78,0x4b,0x00,0x00,0x01,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 22070 0x5636 "嘶" */
+0x04,0x04,0xe4,0xaf,0xa4,0xa7,0xa4,0xa7,0xa4,0xa4,0xef,0xa0,0x05,0x08,0x10,0x00,
+0x80,0x82,0x9c,0xd0,0x90,0x90,0x9e,0x94,0x94,0x94,0xd4,0x14,0x14,0xa4,0x24,0x44,
+/* 22071 0x5637 "嘷" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x48,0x49,0x78,0x49,0x00,0x03,0x00,0x00,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,
+/* 22072 0x5638 "嘸" */
+0x00,0x00,0x79,0x4b,0x4d,0x49,0x4b,0x49,0x49,0x49,0x4f,0x78,0x49,0x01,0x02,0x00,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 22073 0x5639 "嘹" */
+0x00,0x00,0xf7,0x90,0x95,0x92,0x97,0x9a,0x93,0x92,0xf3,0x90,0x02,0x04,0x09,0x00,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 22074 0x563a "嘺" */
+0x00,0x03,0xf0,0x97,0x91,0x92,0x95,0x99,0x91,0x90,0xf7,0x94,0x05,0x05,0x05,0x04,
+0x38,0xc0,0x80,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x0c,
+/* 22075 0x563b "嘻" */
+0x00,0x07,0xf0,0x93,0x90,0x93,0x92,0x93,0x91,0x9f,0xf0,0x93,0x02,0x02,0x03,0x02,
+0x40,0xfc,0x40,0xf8,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 22076 0x563c "嘼" */
+0x3e,0x22,0x3e,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x00,0x3f,0x20,0x3f,0x20,
+0x7c,0x44,0x7c,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,
+/* 22077 0x563d "嘽" */
+0x00,0x03,0x7a,0x4a,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x48,0x03,0x00,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22078 0x563e "嘾" */
+0x00,0x03,0x78,0x4b,0x4a,0x4b,0x48,0x49,0x49,0x49,0x79,0x49,0x00,0x03,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 22079 0x563f "嘿" */
+0x00,0x07,0xf4,0x95,0x94,0x94,0x97,0x90,0x97,0x90,0xf0,0x9f,0x00,0x05,0x04,0x08,
+0x00,0xfc,0x44,0x54,0xe4,0x44,0xfc,0x40,0xfc,0x40,0x40,0xfe,0x00,0x24,0x92,0x92,
+/* 22080 0x5640 "噀" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4a,0x49,0x48,0x48,0x4b,0x78,0x48,0x07,0x00,0x01,0x02,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 22081 0x5641 "噁" */
+0x00,0x07,0xf0,0x90,0x93,0x92,0x92,0x93,0x90,0x90,0xf7,0x90,0x05,0x05,0x09,0x00,
+0x00,0xfe,0x90,0x90,0x9c,0x04,0x04,0x9c,0x90,0x90,0xfe,0x40,0x24,0x0a,0x0a,0xf8,
+/* 22082 0x5642 "噂" */
+0x01,0x00,0xf7,0x90,0x93,0x92,0x93,0x92,0x93,0x92,0xf3,0x90,0x07,0x01,0x00,0x00,
+0x08,0x90,0xfe,0x90,0xfc,0x94,0x1c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x08,0xa8,0x10,
+/* 22083 0x5643 "噃" */
+0x00,0x03,0x79,0x48,0x4b,0x48,0x49,0x4a,0x49,0x49,0x79,0x49,0x01,0x01,0x01,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 22084 0x5644 "噄" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x48,0x48,0x48,0x49,0x78,0x4b,0x00,0x01,0x02,0x00,
+0x80,0xde,0x8a,0xca,0x8a,0xd2,0xa6,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 22085 0x5645 "噅" */
+0x00,0x00,0xf7,0x92,0x91,0x93,0x92,0x93,0x92,0x93,0xf4,0x96,0x0a,0x0a,0x10,0x00,
+0x04,0x3e,0xc0,0x44,0x28,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 22086 0x5646 "噆" */
+0x00,0x07,0x71,0x55,0x57,0x53,0x55,0x59,0x50,0x53,0x72,0x52,0x03,0x02,0x02,0x03,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 22087 0x5647 "噇" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x48,0x01,0x00,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 22088 0x5648 "噈" */
+0x04,0x02,0xef,0xa0,0xa0,0xaf,0xa8,0xa8,0xaf,0xa2,0xeb,0xaa,0x12,0x02,0x0a,0x04,
+0x14,0x12,0x92,0x10,0x7e,0x90,0x90,0x90,0x90,0x28,0x28,0xa8,0x28,0x4a,0x4a,0x86,
+/* 22089 0x5649 "噉" */
+0x00,0x07,0x70,0x51,0x5f,0x54,0x54,0x57,0x54,0x57,0x74,0x54,0x07,0x0c,0x00,0x00,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 22090 0x564a "噊" */
+0x00,0x03,0x78,0x48,0x4b,0x48,0x48,0x4b,0x48,0x4b,0x7a,0x4a,0x03,0x02,0x02,0x02,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 22091 0x564b "噋" */
+0x02,0x01,0x77,0x50,0x57,0x54,0x57,0x50,0x57,0x50,0x71,0x51,0x07,0x01,0x05,0x02,
+0x08,0x08,0xc8,0x10,0x9e,0x94,0xa4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 22092 0x564c "噌" */
+0x02,0x01,0xf0,0x97,0x94,0x95,0x94,0x94,0x97,0x90,0xf3,0x92,0x03,0x02,0x03,0x02,
+0x08,0x10,0x00,0xfc,0x44,0x54,0xe4,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 22093 0x564d "噍" */
+0x01,0x01,0xf3,0x92,0x96,0x9b,0x92,0x92,0x93,0x92,0xf2,0x93,0x02,0x05,0x04,0x08,
+0x40,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x24,0x92,0x92,
+/* 22094 0x564e "噎" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x4a,0x49,0x48,0x49,0x79,0x49,0x01,0x00,0x03,0x00,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 22095 0x564f "噏" */
+0x00,0x00,0xf1,0x96,0x90,0x93,0x92,0x93,0x90,0x97,0xf0,0x94,0x02,0x04,0x02,0x01,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 22096 0x5650 "噐" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x3f,0x01,0x01,0x7f,0x00,0x3e,0x22,0x22,0x3e,0x22,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfc,0x00,0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,
+/* 22097 0x5651 "噑" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x48,0x49,0x48,0x79,0x48,0x03,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 22098 0x5652 "噒" */
+0x00,0x01,0x78,0x4b,0x48,0x49,0x4a,0x49,0x49,0x49,0x7a,0x4d,0x00,0x01,0x02,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 22099 0x5653 "噓" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4a,0x7b,0x4b,0x05,0x04,0x0b,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0x50,0x54,0x54,0xdc,0x50,0xfe,0x00,
+/* 22100 0x5654 "噔" */
+0x00,0x07,0xf0,0x92,0x91,0x92,0x95,0x98,0x93,0x92,0xf2,0x93,0x02,0x01,0x0f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 22101 0x5655 "噕" */
+0x00,0x3f,0x09,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x2a,0x40,0xbf,0x20,0x20,0x3f,0x20,
+0xf8,0x20,0x40,0xe0,0x20,0xf0,0x10,0xfc,0x04,0xa4,0x0c,0xf8,0x08,0x08,0xf8,0x08,
+/* 22102 0x5656 "噖" */
+0x00,0x0f,0xf2,0x97,0x92,0x9f,0x90,0x90,0x93,0x9c,0xf0,0x93,0x00,0x00,0x00,0x00,
+0x00,0xbe,0x08,0x1c,0x08,0xbe,0x40,0xa0,0x18,0x46,0x20,0xf8,0x08,0x10,0x20,0x40,
+/* 22103 0x5657 "噗" */
+0x00,0x04,0xf2,0x90,0x97,0x91,0x90,0x97,0x90,0x93,0xf0,0x97,0x00,0x01,0x02,0x0c,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 22104 0x5658 "噘" */
+0x00,0x0f,0xe8,0xaa,0xa9,0xab,0xa8,0xa8,0xaa,0xaa,0xeb,0xa8,0x08,0x09,0x09,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 22105 0x5659 "噙" */
+0x00,0x00,0xf1,0x92,0x9d,0x90,0x92,0x92,0x93,0x90,0xf7,0x94,0x05,0x05,0x04,0x04,
+0x40,0xa0,0x10,0x48,0xf6,0xa0,0x48,0xa8,0xf8,0x40,0xfc,0x84,0x24,0xf4,0x14,0x0c,
+/* 22106 0x565a "噚" */
+0x00,0x03,0x78,0x4b,0x48,0x4b,0x48,0x4b,0x49,0x4f,0x78,0x4b,0x01,0x00,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 22107 0x565b "噛" */
+0x00,0x00,0x79,0x49,0x49,0x4f,0x48,0x48,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x03,0x00,
+0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0xaa,0x22,0xfe,0x72,0xaa,0x22,0xfe,0x02,
+/* 22108 0x565c "噜" */
+0x01,0x03,0xf4,0x9f,0x94,0x97,0x94,0x97,0x90,0x9f,0xf0,0x93,0x02,0x03,0x02,0x03,
+0x00,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 22109 0x565d "噝" */
+0x01,0x01,0xe2,0xa2,0xa4,0xaf,0xa1,0xa2,0xa4,0xaf,0xe0,0xa0,0x0a,0x0a,0x08,0x00,
+0x08,0x08,0x14,0x94,0xbc,0x08,0x10,0x24,0xbe,0x8a,0x88,0x2c,0xaa,0xca,0x28,0x10,
+/* 22110 0x565e "噞" */
+0x00,0x00,0xf0,0x91,0x92,0x95,0x98,0x97,0x94,0x94,0xf7,0x92,0x02,0x05,0x09,0x10,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xbc,0xa4,0xa4,0xbc,0x10,0x10,0x28,0x44,0x82,
+/* 22111 0x565f "噟" */
+0x01,0x00,0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x24,0x24,0x24,0x4f,0x48,0x8f,0x08,
+0x00,0x80,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xfc,0x04,0xfc,0x04,
+/* 22112 0x5660 "噠" */
+0x00,0x04,0x7a,0x48,0x48,0x48,0x4e,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x05,0x08,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 22113 0x5661 "噡" */
+0x01,0x01,0x7a,0x4f,0x4a,0x4b,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,0x04,0x08,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 22114 0x5662 "噢" */
+0x00,0x01,0xf7,0x94,0x95,0x94,0x97,0x94,0x95,0x94,0xf0,0x97,0x00,0x01,0x02,0x0c,
+0x80,0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x04,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 22115 0x5663 "噣" */
+0x00,0x03,0x7a,0x4a,0x4b,0x49,0x4b,0x4c,0x4b,0x4a,0x7a,0x4b,0x00,0x07,0x00,0x00,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xfc,0x84,0xe4,0xa4,0xa4,0xe4,0x94,0xf4,0x14,0x08,
+/* 22116 0x5664 "噤" */
+0x01,0x01,0xf7,0x91,0x93,0x95,0x99,0x90,0x93,0x90,0xf7,0x90,0x02,0x04,0x09,0x00,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 22117 0x5665 "噥" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4b,0x48,0x4b,0x4a,0x4a,0x7a,0x4b,0x05,0x05,0x05,0x09,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 22118 0x5666 "噦" */
+0x00,0x01,0x79,0x4f,0x48,0x48,0x4b,0x4a,0x4b,0x4a,0x7a,0x4a,0x03,0x04,0x08,0x03,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 22119 0x5667 "噧" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x49,0x49,0x49,0x48,0x7b,0x4a,0x02,0x02,0x02,0x02,
+0x88,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 22120 0x5668 "器" */
+0x00,0x3e,0x22,0x22,0x3e,0x01,0x01,0xff,0x02,0x0c,0x30,0xc0,0x3e,0x22,0x22,0x3e,
+0x00,0x7c,0x44,0x44,0x7c,0x20,0x10,0xfe,0x80,0x60,0x18,0x06,0x7c,0x44,0x44,0x7c,
+/* 22121 0x5669 "噩" */
+0x00,0x7f,0x01,0x3d,0x25,0x25,0x3d,0x01,0x7f,0x01,0x3d,0x25,0x25,0x3d,0x01,0xff,
+0x00,0xfc,0x00,0x78,0x48,0x48,0x78,0x00,0xfc,0x00,0x78,0x48,0x48,0x78,0x00,0xfe,
+/* 22122 0x566a "噪" */
+0x03,0x02,0xf2,0x93,0x90,0x97,0x94,0x94,0x97,0x90,0xff,0x91,0x02,0x04,0x18,0x00,
+0xf8,0x08,0x08,0xf8,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0xfe,0x60,0x50,0x48,0x46,0x40,
+/* 22123 0x566b "噫" */
+0x00,0x00,0x7b,0x49,0x48,0x4f,0x48,0x4b,0x4a,0x4b,0x7a,0x4b,0x00,0x05,0x05,0x08,
+0x80,0x40,0xfc,0x08,0x90,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x24,0x0a,0xfa,
+/* 22124 0x566c "噬" */
+0x02,0x02,0xf3,0x95,0x98,0x90,0x97,0x90,0x92,0x92,0xf2,0x95,0x08,0x00,0x0f,0x00,
+0x10,0x10,0xde,0x28,0x84,0x00,0xfc,0x40,0x48,0x48,0x48,0x54,0xe2,0x40,0xfe,0x00,
+/* 22125 0x566d "噭" */
+0x01,0x02,0x77,0x54,0x57,0x54,0x57,0x52,0x51,0x57,0x72,0x53,0x02,0x04,0x05,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 22126 0x566e "噮" */
+0x00,0x03,0x7a,0x4a,0x4b,0x48,0x4f,0x48,0x4b,0x4a,0x7b,0x48,0x01,0x03,0x0d,0x01,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 22127 0x566f "噯" */
+0x00,0x03,0x70,0x52,0x51,0x57,0x54,0x52,0x52,0x54,0x70,0x50,0x01,0x02,0x00,0x07,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 22128 0x5670 "噰" */
+0x00,0x00,0x77,0x50,0x52,0x52,0x54,0x57,0x51,0x52,0x74,0x57,0x01,0x02,0x04,0x08,
+0x40,0x20,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x7e,0x40,
+/* 22129 0x5671 "噱" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4b,0x4a,0x4a,0x4b,0x7a,0x4b,0x02,0x05,0x04,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 22130 0x5672 "噲" */
+0x00,0x00,0xf3,0x9d,0x90,0x97,0x95,0x94,0x97,0x90,0xf3,0x92,0x03,0x02,0x03,0x02,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 22131 0x5673 "噳" */
+0x00,0x00,0x78,0x4b,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x05,0x04,0x09,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x84,0xfc,0x00,0xfc,0x20,0xfe,0x48,0x86,
+/* 22132 0x5674 "噴" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x00,0x01,0x02,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 22133 0x5675 "噵" */
+0x21,0x17,0x10,0x03,0xf2,0x13,0x12,0x13,0x12,0x13,0x28,0x47,0x00,0x3f,0x20,0x3f,
+0x10,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xf8,0x08,0xf8,
+/* 22134 0x5676 "噶" */
+0x00,0x03,0x78,0x49,0x49,0x49,0x49,0x49,0x48,0x49,0x7a,0x4d,0x01,0x01,0x00,0x00,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 22135 0x5677 "噷" */
+0x02,0x01,0x77,0x50,0x54,0x53,0x5f,0x50,0x57,0x54,0x77,0x54,0x04,0x07,0x00,0x00,
+0x10,0x10,0x90,0x3e,0xa2,0x44,0x90,0x10,0x90,0x90,0xa8,0xa8,0xa8,0xc4,0x44,0x82,
+/* 22136 0x5678 "噸" */
+0x02,0x02,0xe2,0xbf,0xa2,0xaa,0xaa,0xaa,0xaa,0xaf,0xe2,0xa2,0x02,0x03,0x02,0x00,
+0x00,0x3e,0x08,0xd0,0x3e,0xa2,0xa2,0xbe,0xa2,0xbe,0x22,0x22,0xbe,0x00,0x14,0x22,
+/* 22137 0x5679 "噹" */
+0x00,0x02,0xf1,0x97,0x94,0x98,0x93,0x92,0x93,0x90,0xf7,0x94,0x07,0x04,0x07,0x04,
+0x40,0x48,0x50,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 22138 0x567a "噺" */
+0x02,0x01,0x77,0x50,0x54,0x52,0x57,0x51,0x51,0x57,0x71,0x55,0x05,0x09,0x05,0x02,
+0x00,0x02,0xdc,0x10,0x50,0x90,0xde,0x14,0x14,0xd4,0x14,0x94,0x54,0x24,0x24,0x44,
+/* 22139 0x567b "噻" */
+0x00,0x00,0xf7,0x95,0x9b,0x91,0x97,0x91,0x97,0x91,0xf2,0x95,0x08,0x00,0x07,0x00,
+0x80,0x40,0xfe,0x12,0xfc,0x10,0xfc,0x10,0xfe,0x10,0x48,0xf4,0x42,0x40,0xfc,0x00,
+/* 22140 0x567c "噼" */
+0x00,0x00,0x77,0x54,0x54,0x54,0x57,0x54,0x54,0x57,0x76,0x5a,0x0a,0x0b,0x12,0x00,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0x7e,0x08,0x88,0xbe,0x88,0x88,0x88,0x88,0x08,
+/* 22141 0x567d "噽" */
+0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,
+0x00,0x00,0xfe,0x10,0x10,0x30,0x38,0x54,0x92,0x10,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 22142 0x567e "噾" */
+0x00,0x00,0x7b,0x4a,0x49,0x4a,0x49,0x48,0x4b,0x48,0x79,0x49,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x8a,0x44,0x22,0xfc,0x88,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 22143 0x567f "噿" */
+0x03,0x00,0x7a,0x49,0x4a,0x48,0x4b,0x48,0x48,0x49,0x7a,0x48,0x03,0x00,0x00,0x00,
+0xde,0x42,0x52,0x4a,0x52,0x20,0xfe,0x88,0x88,0x54,0x22,0x20,0xfe,0x20,0x20,0x20,
+/* 22144 0x5680 "嚀" */
+0x00,0x00,0x7b,0x4a,0x49,0x49,0x4a,0x48,0x49,0x49,0x7b,0x48,0x01,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 22145 0x5681 "嚁" */
+0x00,0x03,0x78,0x4a,0x49,0x4a,0x48,0x49,0x4b,0x4d,0x79,0x49,0x01,0x01,0x01,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 22146 0x5682 "嚂" */
+0x00,0x07,0x75,0x57,0x54,0x57,0x55,0x57,0x50,0x53,0x72,0x52,0x02,0x02,0x0f,0x00,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 22147 0x5683 "嚃" */
+0x04,0x02,0x7a,0x48,0x48,0x48,0x4e,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x05,0x08,0x00,
+0x00,0xfe,0xaa,0xaa,0xfe,0x10,0x54,0x92,0x10,0x54,0x92,0x10,0x10,0x00,0xfe,0x00,
+/* 22148 0x5684 "嚄" */
+0x00,0x03,0x78,0x48,0x49,0x4b,0x49,0x49,0x49,0x49,0x79,0x49,0x03,0x00,0x00,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 22149 0x5685 "嚅" */
+0x00,0x07,0xe0,0xaf,0xa8,0xa3,0xa0,0xa3,0xa0,0xaf,0xe0,0xa7,0x04,0x04,0x04,0x04,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfe,0x40,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 22150 0x5686 "嚆" */
+0x01,0x07,0xf1,0x90,0x97,0x90,0x91,0x91,0x91,0x90,0xf7,0x94,0x05,0x05,0x05,0x04,
+0x08,0xfe,0x08,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xfa,0x0a,0xfa,0x06,
+/* 22151 0x5687 "嚇" */
+0x01,0x01,0x71,0x57,0x51,0x51,0x5f,0x52,0x52,0x56,0x7a,0x52,0x02,0x05,0x04,0x08,
+0x10,0x10,0x10,0xbc,0x10,0x10,0xfe,0xa8,0xa8,0xec,0xaa,0xaa,0xa8,0xa8,0x48,0x98,
+/* 22152 0x5688 "嚈" */
+0x00,0x0f,0xe8,0xab,0xaa,0xab,0xaa,0xab,0xa8,0xab,0xea,0xab,0x0a,0x0b,0x0a,0x12,
+0x00,0xfe,0x08,0xc8,0x4c,0xca,0x48,0xde,0x08,0xc8,0x48,0xd4,0x54,0xd4,0x54,0xe2,
+/* 22153 0x5689 "嚉" */
+0x02,0x02,0xea,0xa6,0xa2,0xaf,0xa0,0xa4,0xa2,0xaf,0xe1,0xa7,0x01,0x01,0x0e,0x00,
+0x84,0x84,0xa4,0xc4,0x9e,0xe4,0x04,0x54,0x8c,0xe4,0x04,0xc4,0x04,0xc4,0x14,0x08,
+/* 22154 0x568a "嚊" */
+0x00,0x03,0xf2,0x93,0x92,0x93,0x90,0x97,0x94,0x97,0xf4,0x97,0x00,0x0f,0x01,0x02,
+0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x10,0x10,
+/* 22155 0x568b "嚋" */
+0x00,0x07,0x70,0x53,0x50,0x57,0x50,0x53,0x50,0x57,0x70,0x57,0x00,0x07,0x04,0x07,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 22156 0x568c "嚌" */
+0x00,0x00,0x77,0x51,0x50,0x5f,0x55,0x55,0x5b,0x50,0x72,0x53,0x02,0x03,0x02,0x04,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 22157 0x568d "嚍" */
+0x00,0x03,0x70,0x57,0x50,0x53,0x50,0x57,0x50,0x52,0x74,0x53,0x02,0x02,0x0f,0x00,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 22158 0x568e "嚎" */
+0x00,0x07,0xf0,0x91,0x91,0x91,0x90,0x97,0x94,0x93,0xf1,0x96,0x01,0x06,0x01,0x0e,
+0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x80,0x44,0xb8,0x68,0xa6,0x60,
+/* 22159 0x568f "嚏" */
+0x00,0x07,0xf0,0x97,0x94,0x9b,0x92,0x93,0x92,0x93,0xf0,0x97,0x02,0x02,0x05,0x08,
+0x40,0xfc,0x40,0xfe,0x02,0xfc,0x48,0xf8,0x48,0xf8,0x00,0xfc,0x44,0x78,0x40,0xfe,
+/* 22160 0x5690 "嚐" */
+0x01,0x00,0x7b,0x4a,0x48,0x49,0x49,0x49,0x48,0x48,0x79,0x49,0x01,0x01,0x01,0x01,
+0x24,0xa8,0xfe,0x8a,0xf8,0x0c,0xf0,0x02,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 22161 0x5691 "嚑" */
+0x00,0x07,0xf0,0x9f,0x90,0x97,0x95,0x94,0x97,0x90,0xf7,0x90,0x0f,0x00,0x05,0x08,
+0x3c,0xc0,0x40,0xfe,0x40,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0x00,0x24,0x92,
+/* 22162 0x5692 "嚒" */
+0x00,0x00,0x77,0x54,0x57,0x54,0x55,0x56,0x54,0x54,0x74,0x55,0x04,0x04,0x09,0x10,
+0x40,0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x40,0x88,0xf0,0x20,0x48,0xfc,0x84,
+/* 22163 0x5693 "嚓" */
+0x00,0x00,0x77,0x54,0x5a,0x53,0x54,0x5a,0x55,0x52,0x74,0x5b,0x00,0x02,0x04,0x00,
+0x80,0x40,0xfe,0x02,0x24,0xbc,0xa4,0xa8,0x10,0xe8,0x04,0xfa,0x40,0x48,0x44,0xc0,
+/* 22164 0x5694 "嚔" */
+0x00,0x07,0x70,0x57,0x54,0x5b,0x52,0x53,0x52,0x53,0x71,0x57,0x02,0x02,0x05,0x08,
+0x40,0xfc,0x40,0xfe,0x02,0xfc,0x48,0xf8,0x48,0xf8,0x08,0xfc,0x44,0x78,0x40,0xfe,
+/* 22165 0x5695 "嚕" */
+0x01,0x03,0x74,0x5f,0x54,0x57,0x54,0x57,0x55,0x58,0x73,0x52,0x03,0x02,0x03,0x02,
+0x00,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x24,0x92,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 22166 0x5696 "嚖" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x48,0x4b,0x48,0x49,0x78,0x4b,0x00,0x02,0x02,0x04,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 22167 0x5697 "嚗" */
+0x03,0x02,0xf3,0x92,0x93,0x91,0x97,0x91,0x9f,0x91,0xf2,0x95,0x00,0x01,0x02,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfc,0x10,0xfe,0x10,0x48,0x54,0xe0,0x50,0x48,0xc0,
+/* 22168 0x5698 "嚘" */
+0x07,0x00,0xe3,0xa2,0xa3,0xa2,0xaf,0xa8,0xa5,0xa5,0xe8,0xa1,0x03,0x05,0x00,0x0f,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xfe,0x82,0x48,0x14,0xf4,0x00,0xf8,0x08,0xf0,0x0e,
+/* 22169 0x5699 "嚙" */
+0x00,0x01,0x79,0x49,0x4f,0x48,0x4a,0x4b,0x4a,0x4b,0x7a,0x4a,0x03,0x02,0x03,0x00,
+0x20,0x20,0x3c,0x20,0xfe,0x90,0x94,0x6c,0x04,0xfc,0x94,0x94,0x6c,0x04,0xfc,0x04,
+/* 22170 0x569a "嚚" */
+0x00,0x3e,0x22,0x3e,0x00,0x3f,0x21,0x3f,0x20,0x3f,0x21,0x3f,0x00,0x3e,0x22,0x3e,
+0x00,0x7c,0x44,0x7c,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0x7c,0x44,0x7c,
+/* 22171 0x569b "嚛" */
+0x04,0x04,0xe8,0xaa,0xae,0xa4,0xaa,0xae,0xa2,0xa0,0xef,0xa0,0x01,0x02,0x0c,0x00,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 22172 0x569c "嚜" */
+0x01,0x01,0x79,0x49,0x49,0x48,0x49,0x48,0x4b,0x49,0x7a,0x48,0x01,0x00,0x03,0x00,
+0xfc,0x24,0xac,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,0x20,0xfc,0x20,0xfe,0x00,
+/* 22173 0x569d "嚝" */
+0x00,0x00,0x77,0x54,0x55,0x54,0x57,0x54,0x55,0x55,0x75,0x55,0x09,0x08,0x11,0x02,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x04,0x02,
+/* 22174 0x569e "嚞" */
+0x01,0xff,0x01,0x7f,0x00,0x3f,0x20,0x3f,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x7c,
+0x00,0xfe,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x7c,
+/* 22175 0x569f "嚟" */
+0x00,0x03,0xf1,0x97,0x91,0x93,0x95,0x99,0x90,0x91,0xf2,0x94,0x00,0x01,0x06,0x00,
+0x90,0x1e,0x2a,0xca,0x0a,0x92,0x22,0x56,0x88,0x24,0x22,0xa8,0x70,0xac,0x22,0x60,
+/* 22176 0x56a0 "嚠" */
+0x02,0x05,0x74,0x56,0x55,0x56,0x51,0x52,0x54,0x5b,0x71,0x57,0x01,0x05,0x01,0x0e,
+0x02,0xe2,0xa2,0xaa,0x2a,0x6a,0x0a,0x8a,0x4a,0xaa,0x0a,0xca,0x22,0x42,0xea,0x04,
+/* 22177 0x56a1 "嚡" */
+0x05,0x05,0xef,0xa5,0xa7,0xa2,0xaf,0xaa,0xaa,0xaf,0xe2,0xaf,0x02,0x02,0x02,0x02,
+0x08,0x08,0xbe,0x08,0x08,0x08,0xbe,0x80,0x88,0x88,0x3e,0x88,0x08,0x08,0x3e,0x00,
+/* 22178 0x56a2 "嚢" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x94,0x2f,0x44,0x1f,0x04,0x7f,0x05,0x18,0xea,0x0c,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x52,0xe8,0x44,0xf0,0x40,0xfc,0x08,0x90,0x60,0x18,
+/* 22179 0x56a3 "嚣" */
+0x3e,0x22,0x3e,0x00,0xff,0x01,0x1f,0x10,0x11,0x02,0x0c,0x70,0x00,0x3e,0x22,0x3e,
+0xf8,0x88,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0xc0,0x30,0x08,0x00,0xf8,0x88,0xf8,
+/* 22180 0x56a4 "嚤" */
+0x00,0x07,0x74,0x57,0x54,0x55,0x56,0x54,0x55,0x54,0x75,0x54,0x07,0x08,0x08,0x10,
+0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x8c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 22181 0x56a5 "嚥" */
+0x01,0x01,0x77,0x51,0x51,0x52,0x52,0x56,0x52,0x52,0x76,0x5a,0x00,0x02,0x02,0x04,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 22182 0x56a6 "嚦" */
+0x00,0x07,0x74,0x55,0x54,0x57,0x54,0x55,0x56,0x54,0x74,0x55,0x05,0x09,0x09,0x17,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 22183 0x56a7 "嚧" */
+0x00,0x00,0x78,0x4b,0x4a,0x4b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x05,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 22184 0x56a8 "嚨" */
+0x02,0x01,0x77,0x50,0x54,0x52,0x57,0x50,0x57,0x54,0x77,0x54,0x07,0x04,0x04,0x04,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 22185 0x56a9 "嚩" */
+0x04,0x04,0xe9,0xaa,0xb2,0xbc,0xa4,0xa8,0xb2,0xbe,0xe2,0x81,0x2a,0x2a,0x20,0x00,
+0x14,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x24,0x24,0x0c,
+/* 22186 0x56aa "嚪" */
+0x03,0x02,0x7b,0x4a,0x4b,0x4a,0x4a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,0x02,0x02,0x02,
+0xde,0x52,0xde,0x52,0xde,0x42,0x7a,0x8a,0x12,0xda,0x8a,0xda,0x8a,0xfa,0x0a,0x04,
+/* 22187 0x56ab "嚫" */
+0x04,0x02,0xef,0xa0,0xa8,0xa5,0xaf,0xa2,0xa2,0xaf,0xe2,0xab,0x0a,0x12,0x0a,0x04,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xa4,0x3c,0x24,0xa4,0x3c,0x10,0x98,0xa8,0x2a,0x46,
+/* 22188 0x56ac "嚬" */
+0x01,0x01,0x75,0x55,0x55,0x55,0x5f,0x50,0x51,0x55,0x75,0x55,0x08,0x01,0x02,0x0c,
+0x00,0x3e,0x08,0xd0,0x3e,0x22,0xe2,0x3e,0x22,0x7e,0x62,0xa2,0xbe,0x00,0x14,0x22,
+/* 22189 0x56ad "嚭" */
+0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,
+0x00,0x7e,0x08,0x08,0x10,0x34,0x52,0x92,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 22190 0x56ae "嚮" */
+0x11,0x2b,0x4a,0x73,0x2a,0x4b,0x7a,0x12,0x23,0xca,0x3f,0x20,0x27,0x24,0x27,0x20,
+0x00,0xde,0x52,0xd4,0x52,0xd2,0x1a,0x94,0x50,0x40,0xfc,0x04,0xe4,0x24,0xe4,0x0c,
+/* 22191 0x56af "嚯" */
+0x07,0x00,0xf7,0x94,0x9b,0x90,0x97,0x91,0x93,0x96,0xfb,0x92,0x03,0x02,0x03,0x02,
+0xfc,0x40,0xfe,0x42,0x5c,0x40,0x5c,0x20,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 22192 0x56b0 "嚰" */
+0x00,0x00,0x7b,0x4a,0x4b,0x4a,0x4a,0x4b,0x4a,0x4b,0x7a,0x4a,0x02,0x03,0x04,0x08,
+0x40,0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0xfe,0x20,0x7c,0xc4,0x44,0x7c,0x44,
+/* 22193 0x56b1 "嚱" */
+0x01,0x01,0x71,0x57,0x55,0x55,0x57,0x54,0x54,0x57,0x74,0x57,0x0a,0x0b,0x11,0x07,
+0x08,0xec,0x0a,0xe8,0x28,0xde,0x28,0xea,0x0a,0xea,0x0c,0xec,0x2a,0xea,0x56,0xe2,
+/* 22194 0x56b2 "嚲" */
+0x20,0x11,0xfd,0x01,0x7d,0x44,0x7d,0x01,0x7d,0x09,0x11,0x1c,0xf3,0x10,0x50,0x20,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22195 0x56b3 "嚳" */
+0x3a,0x21,0x3a,0x22,0x39,0x22,0x7f,0x40,0x91,0x1f,0x21,0xff,0x00,0x1f,0x10,0x1f,
+0xb8,0x08,0xb8,0x88,0x38,0x88,0xfe,0x02,0x04,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,
+/* 22196 0x56b4 "嚴" */
+0x3e,0x22,0x3e,0x00,0x3f,0x20,0x2e,0x22,0x3f,0x29,0x2f,0x29,0x2f,0x49,0x7f,0x81,
+0x7c,0x44,0x7c,0x00,0xfe,0x00,0x20,0x3c,0xa8,0x48,0x28,0x28,0x10,0xd0,0x28,0x44,
+/* 22197 0x56b5 "嚵" */
+0x01,0x02,0x77,0x52,0x53,0x52,0x53,0x52,0x51,0x52,0x77,0x52,0x03,0x00,0x01,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 22198 0x56b6 "嚶" */
+0x03,0x02,0x7b,0x4a,0x4b,0x4a,0x4b,0x49,0x4a,0x48,0x7f,0x48,0x01,0x00,0x00,0x03,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 22199 0x56b7 "嚷" */
+0x00,0x07,0xf0,0x93,0x92,0x93,0x91,0x97,0x91,0x97,0xf1,0x9f,0x01,0x03,0x0d,0x01,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 22200 0x56b8 "嚸" */
+0x00,0x0f,0xe9,0xad,0xab,0xa9,0xaf,0xa1,0xaf,0xa1,0xe1,0xbf,0x00,0x15,0x15,0x20,
+0x08,0xe8,0x28,0x68,0xae,0x28,0xe8,0x08,0xe8,0x1e,0x12,0xf2,0x12,0x52,0x5e,0x12,
+/* 22201 0x56b9 "嚹" */
+0x08,0x08,0xee,0xb4,0xa4,0xa4,0xbf,0xa4,0xb5,0xb5,0xf5,0xb7,0x18,0x01,0x01,0x02,
+0x20,0x3c,0x20,0xfe,0xa2,0xb8,0xe2,0x9e,0x82,0xbc,0xaa,0x9c,0xff,0x08,0x28,0x10,
+/* 22202 0x56ba "嚺" */
+0x01,0x09,0x75,0x54,0x50,0x53,0x5c,0x54,0x55,0x54,0x75,0x54,0x05,0x04,0x0a,0x11,
+0xfc,0x54,0xfc,0x88,0x50,0xfe,0x40,0xa2,0x34,0x58,0xb4,0x52,0x92,0x50,0x20,0xfe,
+/* 22203 0x56bb "嚻" */
+0x00,0x7b,0x48,0x49,0x4b,0x4a,0x7a,0x03,0x7a,0x4b,0x4a,0x4a,0x4b,0x78,0x49,0x02,
+0x00,0xde,0x92,0x12,0xd2,0x52,0x5e,0xc0,0x5e,0xd2,0x52,0x52,0xd2,0x1e,0x92,0x40,
+/* 22204 0x56bc "嚼" */
+0x00,0x07,0x72,0x51,0x57,0x54,0x57,0x50,0x57,0x54,0x77,0x54,0x07,0x05,0x05,0x06,
+0x3c,0xc0,0x44,0x28,0xfc,0xa4,0xfc,0x08,0x88,0xfe,0x88,0xa8,0x98,0x08,0xa8,0x90,
+/* 22205 0x56bd "嚽" */
+0x01,0x07,0x71,0x57,0x51,0x5f,0x52,0x53,0x54,0x5b,0x72,0x53,0x02,0x03,0x01,0x02,
+0x10,0xd0,0x1e,0xa4,0x54,0xd4,0x08,0x94,0xa2,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 22206 0x56be "嚾" */
+0x00,0x03,0x78,0x4b,0x4a,0x4b,0x48,0x48,0x49,0x49,0x7b,0x4d,0x01,0x01,0x01,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 22207 0x56bf "嚿" */
+0x01,0x07,0x71,0x53,0x52,0x57,0x5a,0x53,0x52,0x53,0x70,0x53,0x02,0x03,0x02,0x03,
+0x08,0xfe,0x28,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x80,0x1c,0x04,0x9c,0x04,0xfc,
+/* 22208 0x56c0 "囀" */
+0x02,0x02,0xe2,0xaf,0xa2,0xaf,0xaa,0xaf,0xaa,0xaf,0xe2,0xaf,0x02,0x02,0x02,0x02,
+0x08,0x08,0x7e,0x88,0x3e,0xaa,0xbe,0xaa,0xbe,0x8a,0x7e,0x84,0x7e,0x24,0x14,0x0c,
+/* 22209 0x56c1 "囁" */
+0x03,0x01,0x79,0x49,0x49,0x49,0x4f,0x48,0x4f,0x4a,0x7b,0x4a,0x03,0x02,0x07,0x00,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 22210 0x56c2 "囂" */
+0x3e,0x22,0x3e,0x00,0xff,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,0x3e,0x22,0x3e,
+0xf8,0x88,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0xf8,0x88,0xf8,
+/* 22211 0x56c3 "囃" */
+0x04,0x02,0xef,0xa5,0xa5,0xaa,0xa0,0xa2,0xaf,0xa2,0xeb,0xaa,0x12,0x02,0x0a,0x04,
+0x14,0x12,0xa0,0x3e,0x64,0xa4,0x3e,0x24,0xa4,0x3e,0x24,0xa4,0xa4,0x3e,0x20,0x20,
+/* 22212 0x56c4 "囄" */
+0x04,0x02,0xef,0xa5,0xaa,0xad,0xa8,0xaf,0xa2,0xaf,0xea,0xaa,0x0b,0x08,0x0a,0x09,
+0x18,0x14,0x90,0x3e,0xa8,0xe8,0xbe,0xa8,0x28,0xbe,0xa8,0xa8,0xa8,0xbe,0xa0,0x20,
+/* 22213 0x56c5 "囅" */
+0x00,0xee,0xaa,0xaa,0xee,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x11,0x11,0x12,
+0x00,0xfe,0x82,0x82,0xfe,0xa4,0xa4,0xfe,0xa4,0xa4,0xfe,0xa8,0xaa,0x24,0x32,0x20,
+/* 22214 0x56c6 "囆" */
+0x00,0x03,0x78,0x49,0x49,0x49,0x49,0x4b,0x4a,0x4a,0x7a,0x49,0x01,0x01,0x00,0x03,
+0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfe,0x2a,0xfa,0x26,0xfc,0x24,0xfc,0x22,0xfe,
+/* 22215 0x56c7 "囇" */
+0x0f,0x00,0x77,0x54,0x56,0x54,0x50,0x57,0x54,0x57,0x74,0x57,0x05,0x09,0x09,0x11,
+0xbe,0x00,0xbc,0xa4,0xb4,0xa4,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x12,0xdc,0x12,0xce,
+/* 22216 0x56c8 "囈" */
+0x01,0x07,0x71,0x53,0x51,0x57,0x52,0x55,0x53,0x51,0x73,0x50,0x07,0x00,0x01,0x03,
+0x08,0xfe,0x08,0x90,0x3c,0xd4,0xb4,0x5c,0x96,0x22,0xfc,0x00,0xfe,0x80,0x04,0xfe,
+/* 22217 0x56c9 "囉" */
+0x00,0x07,0x74,0x54,0x57,0x52,0x52,0x54,0x5f,0x52,0x74,0x5f,0x00,0x0a,0x0a,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 22218 0x56ca "囊" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x92,0x1e,0x04,0x3f,0x04,0xff,0x04,0x0c,0x35,0xc6,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x92,0xf0,0x40,0xf8,0x40,0xfe,0x88,0x50,0x30,0x0e,
+/* 22219 0x56cb "囋" */
+0x05,0x07,0x79,0x57,0x53,0x55,0x59,0x53,0x52,0x53,0x72,0x53,0x02,0x03,0x01,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 22220 0x56cc "囌" */
+0x01,0x0f,0xe5,0xa4,0xaf,0xb1,0xaf,0xaa,0xaa,0xaf,0xea,0xaf,0x00,0x15,0x15,0x00,
+0x10,0xfe,0x10,0x00,0x06,0x38,0x88,0x88,0xbe,0x88,0x9c,0x9a,0x28,0x48,0x48,0x08,
+/* 22221 0x56cd "囍" */
+0x10,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x7c,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,
+0x10,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x7c,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,
+/* 22222 0x56ce "囎" */
+0x00,0x0e,0xea,0xaa,0xae,0xaa,0xaa,0xae,0xaa,0xaa,0xee,0xa0,0x0a,0x09,0x11,0x00,
+0x44,0x28,0xfe,0x92,0xd6,0xba,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 22223 0x56cf "囏" */
+0x28,0x29,0xfe,0x28,0x38,0x10,0x7c,0x54,0x7c,0x11,0x7c,0x10,0xfe,0x28,0x44,0x82,
+0x10,0xfe,0x10,0xfc,0x00,0xfc,0x84,0xfc,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 22224 0x56d0 "囐" */
+0x01,0x01,0xe1,0xaf,0xa9,0xab,0xa9,0xaf,0xa9,0xab,0xea,0xab,0x0a,0x0b,0x0a,0x12,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 22225 0x56d1 "囑" */
+0x07,0x04,0x77,0x55,0x54,0x55,0x55,0x55,0x55,0x56,0x75,0x55,0x09,0x08,0x13,0x00,
+0xfc,0x04,0xfc,0x24,0xa8,0x24,0xfc,0x54,0xfc,0x44,0xf4,0x54,0xf4,0x44,0xf4,0x08,
+/* 22226 0x56d2 "囒" */
+0x01,0x07,0x71,0x57,0x54,0x57,0x54,0x57,0x54,0x57,0x75,0x55,0x04,0x04,0x05,0x04,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xfc,0x54,0xf4,0x44,0xe4,0x54,0x48,
+/* 22227 0x56d3 "囓" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x48,0x48,0x4b,0x48,0x7a,0x4b,0x02,0x02,0x03,0x00,
+0x80,0xde,0x8a,0xd2,0xa6,0xd0,0x9c,0x50,0xfe,0x50,0xaa,0xfe,0x52,0xaa,0xfe,0x02,
+/* 22228 0x56d4 "囔" */
+0x00,0x07,0x72,0x53,0x50,0x5f,0x5a,0x53,0x51,0x57,0x71,0x4f,0x01,0x03,0x0d,0x01,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 22229 0x56d5 "囕" */
+0x07,0x05,0x77,0x54,0x57,0x55,0x57,0x50,0x53,0x52,0x73,0x52,0x03,0x00,0x01,0x06,
+0x90,0x1e,0xa8,0x84,0xbe,0x2a,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 22230 0x56d6 "囖" */
+0x02,0x07,0xe9,0xaf,0xa9,0xaf,0xa2,0xa4,0xa9,0xaf,0xe2,0xa5,0x0f,0x00,0x15,0x15,
+0x10,0xde,0x28,0xfe,0x12,0xfe,0x28,0x44,0xfe,0x48,0x7e,0x48,0x7e,0x48,0x7e,0x40,
+/* 22231 0x56d7 "囗" */
+0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 22232 0x56d8 "囘" */
+0x00,0x7f,0x40,0x40,0x4f,0x48,0x48,0x48,0x4f,0x48,0x48,0x48,0x47,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xc4,0x44,0x44,0x44,0xc4,0x04,0x24,0x24,0xe4,0x04,0x14,0x08,
+/* 22233 0x56d9 "囙" */
+0x00,0x7f,0x40,0x40,0x40,0x7f,0x40,0x40,0x40,0x40,0x7f,0x40,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xfc,0x04,
+/* 22234 0x56da "囚" */
+0x00,0x7f,0x40,0x41,0x41,0x41,0x41,0x42,0x42,0x44,0x44,0x48,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x24,0x24,0x24,0x04,0xfc,0x04,
+/* 22235 0x56db "四" */
+0x00,0x00,0x7f,0x44,0x44,0x44,0x44,0x44,0x48,0x48,0x50,0x60,0x40,0x7f,0x40,0x00,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x3c,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 22236 0x56dc "囜" */
+0x00,0x7f,0x40,0x40,0x41,0x41,0x42,0x42,0x44,0x48,0x5f,0x48,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x24,0xf4,0x14,0x04,0x04,0xfc,0x04,
+/* 22237 0x56dd "囝" */
+0x00,0x7f,0x40,0x40,0x4f,0x40,0x40,0x41,0x5f,0x41,0x41,0x41,0x45,0x42,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x44,0x84,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 22238 0x56de "回" */
+0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x27,0x20,0x20,0x3f,0x20,0x00,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x24,0xe4,0x04,0x04,0xfc,0x04,0x00,
+/* 22239 0x56df "囟" */
+0x02,0x02,0x04,0x7f,0x40,0x48,0x44,0x42,0x41,0x42,0x44,0x48,0x40,0x40,0x7f,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x24,0x44,0x84,0x04,0x84,0x44,0x24,0x04,0x04,0xfc,0x04,
+/* 22240 0x56e0 "因" */
+0x00,0x7f,0x40,0x41,0x41,0x41,0x5f,0x41,0x42,0x42,0x44,0x48,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xf4,0x04,0x84,0x44,0x24,0x14,0x14,0x04,0xfc,0x04,
+/* 22241 0x56e1 "囡" */
+0x00,0x7f,0x42,0x42,0x42,0x7f,0x44,0x44,0x48,0x46,0x41,0x42,0x44,0x48,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x44,0x44,0x84,0x84,0x04,0x84,0x44,0x24,0xfc,0x04,
+/* 22242 0x56e2 "团" */
+0x00,0x7f,0x40,0x40,0x40,0x5f,0x40,0x41,0x42,0x44,0x48,0x50,0x42,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x84,0x84,0xf4,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xfc,0x04,
+/* 22243 0x56e3 "団" */
+0x00,0x7f,0x40,0x40,0x40,0x5f,0x40,0x48,0x44,0x44,0x40,0x40,0x42,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x84,0x84,0xf4,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xfc,0x04,
+/* 22244 0x56e4 "囤" */
+0x00,0x7f,0x41,0x41,0x5f,0x41,0x49,0x49,0x4f,0x41,0x41,0x41,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x24,0x24,0xe4,0x14,0x14,0x14,0xf4,0x04,0xfc,0x04,
+/* 22245 0x56e5 "囥" */
+0x00,0x7f,0x40,0x42,0x41,0x5f,0x40,0x40,0x47,0x44,0x44,0x44,0x48,0x50,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0xc4,0x44,0x44,0x54,0x34,0x04,0xfc,0x04,
+/* 22246 0x56e6 "囦" */
+0x00,0x7f,0x40,0x41,0x41,0x5d,0x45,0x45,0x49,0x49,0x51,0x65,0x42,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x14,0xa4,0x44,0x24,0x14,0x14,0x04,0x04,0x04,0xfc,0x04,
+/* 22247 0x56e7 "囧" */
+0x00,0x7f,0x40,0x44,0x44,0x48,0x50,0x60,0x47,0x44,0x44,0x44,0x44,0x44,0x7f,0x40,
+0x00,0xfc,0x04,0x44,0x24,0x14,0x14,0x04,0xc4,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 22248 0x56e8 "囨" */
+0x00,0x7f,0x40,0x5f,0x40,0x41,0x41,0x43,0x45,0x49,0x51,0x61,0x41,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0xf4,0x84,0x04,0x04,0x84,0x44,0x24,0x14,0x14,0x04,0x04,0xfc,0x04,
+/* 22249 0x56e9 "囩" */
+0x00,0x7f,0x40,0x40,0x4f,0x40,0x40,0x5f,0x42,0x44,0x48,0x5f,0x48,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x04,0x04,0xf4,0x04,0x44,0x24,0xf4,0x14,0x04,0xfc,0x04,
+/* 22250 0x56ea "囪" */
+0x04,0x08,0x7f,0x40,0x40,0x48,0x45,0x42,0x45,0x48,0x51,0x42,0x4c,0x40,0x7f,0x40,
+0x00,0x00,0xfc,0x04,0x84,0x94,0x14,0x24,0x44,0x84,0x44,0x24,0x24,0x04,0xfc,0x04,
+/* 22251 0x56eb "囫" */
+0x00,0x7f,0x44,0x44,0x47,0x49,0x49,0x52,0x42,0x44,0x49,0x42,0x44,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x54,0x54,0x54,0x94,0x94,0x14,0xa4,0x44,0x04,0xfc,0x04,
+/* 22252 0x56ec "囬" */
+0x00,0x7f,0x44,0x44,0x44,0x47,0x44,0x44,0x44,0x47,0x44,0x44,0x44,0x44,0x7f,0x40,
+0x00,0xfc,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 22253 0x56ed "园" */
+0x00,0x7f,0x40,0x4f,0x40,0x40,0x5f,0x44,0x44,0x44,0x48,0x48,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0xe4,0x04,0x04,0xf4,0x84,0x84,0x84,0x94,0x94,0x74,0x04,0xfc,0x04,
+/* 22254 0x56ee "囮" */
+0x00,0x7f,0x45,0x45,0x49,0x59,0x69,0x49,0x4f,0x49,0x49,0x48,0x48,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x24,0x44,0x84,0x04,0x14,0x14,0x14,0xf4,0x04,0x04,0xfc,0x04,
+/* 22255 0x56ef "囯" */
+0x00,0x7f,0x40,0x40,0x5f,0x41,0x41,0x4f,0x41,0x41,0x41,0x5f,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x04,0xfc,0x04,
+/* 22256 0x56f0 "困" */
+0x00,0x7f,0x41,0x41,0x41,0x5f,0x41,0x43,0x43,0x45,0x49,0x51,0x41,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x84,0x44,0x24,0x14,0x14,0x04,0x04,0xfc,0x04,
+/* 22257 0x56f1 "囱" */
+0x04,0x08,0x7f,0x42,0x42,0x47,0x48,0x52,0x41,0x40,0x41,0x46,0x58,0x40,0x7f,0x40,
+0x00,0x00,0xfc,0x04,0x04,0xf4,0x14,0x24,0x44,0x84,0x44,0x24,0x04,0x04,0xfc,0x04,
+/* 22258 0x56f2 "囲" */
+0x00,0x7f,0x44,0x44,0x44,0x5f,0x44,0x44,0x44,0x7f,0x44,0x44,0x48,0x50,0x7f,0x40,
+0x00,0xfc,0x44,0x44,0x44,0xf4,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 22259 0x56f3 "図" */
+0x00,0x7f,0x40,0x41,0x44,0x42,0x52,0x48,0x44,0x42,0x41,0x46,0x58,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x84,0xa4,0x24,0x44,0x44,0x84,0x04,0xc4,0x34,0x04,0xfc,0x04,
+/* 22260 0x56f4 "围" */
+0x00,0x7f,0x41,0x41,0x5f,0x41,0x4f,0x41,0x5f,0x41,0x41,0x41,0x41,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0xe4,0x04,0xf4,0x14,0x14,0x54,0x24,0x04,0xfc,0x04,
+/* 22261 0x56f5 "囵" */
+0x00,0x7f,0x41,0x41,0x42,0x44,0x48,0x54,0x65,0x46,0x44,0x44,0x43,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x84,0x44,0x24,0x9c,0x04,0x04,0x24,0x24,0xe4,0x04,0xfc,0x04,
+/* 22262 0x56f6 "囶" */
+0x00,0x7f,0x40,0x44,0x48,0x51,0x41,0x4f,0x41,0x41,0x41,0x5f,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x44,0x24,0x14,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x04,0xfc,0x04,
+/* 22263 0x56f7 "囷" */
+0x00,0x7f,0x40,0x40,0x4f,0x41,0x41,0x5f,0x43,0x45,0x49,0x51,0x41,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x84,0x44,0x24,0x04,0x04,0xfc,0x04,
+/* 22264 0x56f8 "囸" */
+0x00,0x7f,0x40,0x40,0x5f,0x41,0x41,0x49,0x49,0x49,0x49,0x5f,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x04,0xfc,0x04,
+/* 22265 0x56f9 "囹" */
+0x00,0x7f,0x41,0x41,0x42,0x44,0x4a,0x51,0x6f,0x40,0x40,0x42,0x41,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x84,0x44,0x24,0x1c,0xe4,0x24,0x44,0x84,0x04,0x84,0xfc,0x04,
+/* 22266 0x56fa "固" */
+0x00,0x7f,0x41,0x41,0x5f,0x41,0x41,0x4f,0x48,0x48,0x48,0x4f,0x48,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0xfc,0x04,
+/* 22267 0x56fb "囻" */
+0x00,0x7f,0x40,0x5f,0x50,0x50,0x5f,0x51,0x5f,0x51,0x50,0x54,0x58,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x04,0xf4,0x04,0x94,0x54,0x34,0x04,0xfc,0x04,
+/* 22268 0x56fc "囼" */
+0x00,0x7f,0x42,0x42,0x44,0x48,0x5f,0x40,0x4f,0x48,0x48,0x4f,0x48,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0x44,0x24,0xf4,0x14,0xe4,0x24,0x24,0xe4,0x24,0x04,0xfc,0x04,
+/* 22269 0x56fd "国" */
+0x00,0x7f,0x40,0x40,0x5f,0x41,0x41,0x4f,0x41,0x41,0x41,0x5f,0x40,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x04,0x44,0x24,0xf4,0x04,0x04,0xfc,0x04,
+/* 22270 0x56fe "图" */
+0x00,0x7f,0x42,0x42,0x47,0x4c,0x52,0x41,0x46,0x78,0x43,0x40,0x46,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x44,0x84,0x04,0xc4,0x3c,0x04,0x84,0x04,0x84,0xfc,0x04,
+/* 22271 0x56ff "囿" */
+0x00,0x7f,0x42,0x42,0x5f,0x44,0x4f,0x54,0x67,0x44,0x47,0x44,0x44,0x44,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xa4,0x44,0xfc,0x04,
+/* 22272 0x5700 "圀" */
+0x7f,0x40,0x44,0x48,0x52,0x41,0x5f,0x44,0x44,0x47,0x44,0x48,0x48,0x50,0x7f,0x40,
+0xfc,0x04,0x44,0x24,0x14,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0xa4,0x44,0xfc,0x04,
+/* 22273 0x5701 "圁" */
+0x00,0x7f,0x41,0x5f,0x40,0x4f,0x40,0x4f,0x40,0x4f,0x48,0x4f,0x48,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0xf4,0x04,0xe4,0x04,0xe4,0x04,0xe4,0x24,0xe4,0x24,0x04,0xfc,0x04,
+/* 22274 0x5702 "圂" */
+0x00,0x7f,0x40,0x4f,0x42,0x45,0x59,0x42,0x44,0x59,0x42,0x44,0x5a,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0xe4,0x04,0x14,0xa4,0xc4,0xa4,0xa4,0x94,0x94,0x84,0x04,0xfc,0x04,
+/* 22275 0x5703 "圃" */
+0x00,0x7f,0x41,0x41,0x5f,0x41,0x4f,0x49,0x4f,0x49,0x4f,0x49,0x49,0x40,0x7f,0x40,
+0x00,0xfc,0x44,0x24,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x64,0x04,0xfc,0x04,
+/* 22276 0x5704 "圄" */
+0x00,0x7f,0x40,0x5f,0x42,0x4f,0x44,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0xf4,0x04,0xe4,0x24,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x04,0xfc,0x04,
+/* 22277 0x5705 "圅" */
+0x3f,0x00,0x06,0x01,0x7f,0x44,0x42,0x5f,0x41,0x41,0x7f,0x41,0x41,0x41,0x7f,0x40,
+0xf0,0x20,0x40,0x80,0xfc,0x44,0x84,0xf4,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 22278 0x5706 "圆" */
+0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,0x5f,0x50,0x51,0x51,0x52,0x44,0x48,0x7f,0x40,
+0x00,0xfc,0x04,0xe4,0x24,0xe4,0x04,0xf4,0x14,0x14,0x14,0x94,0x44,0x24,0xfc,0x04,
+/* 22279 0x5707 "圇" */
+0x00,0x7f,0x41,0x42,0x44,0x4b,0x50,0x4f,0x4a,0x4a,0x4f,0x4a,0x4a,0x48,0x7f,0x40,
+0x00,0xfc,0x04,0x84,0x44,0xa4,0x14,0xe4,0xa4,0xa4,0xe4,0xa4,0xa4,0x64,0xfc,0x04,
+/* 22280 0x5708 "圈" */
+0x00,0x7f,0x49,0x45,0x5f,0x42,0x7f,0x48,0x57,0x64,0x44,0x44,0x43,0x40,0x7f,0x40,
+0x00,0xfc,0x24,0x44,0xf4,0x04,0xfc,0x24,0xd4,0x4c,0xc4,0x24,0xe4,0x04,0xfc,0x04,
+/* 22281 0x5709 "圉" */
+0x00,0x7f,0x41,0x41,0x4f,0x41,0x5f,0x44,0x42,0x4f,0x41,0x5f,0x41,0x41,0x7f,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x04,0xf4,0x44,0x84,0xe4,0x04,0xf4,0x04,0x04,0xfc,0x04,
+/* 22282 0x570a "圊" */
+0x7f,0x41,0x4f,0x41,0x4f,0x41,0x7f,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x48,0x7f,
+0xfc,0x04,0xe4,0x04,0xe4,0x04,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x64,0xfc,
+/* 22283 0x570b "國" */
+0x00,0x7f,0x40,0x40,0x7f,0x40,0x5e,0x52,0x52,0x5e,0x40,0x46,0x59,0x40,0x7f,0x40,
+0x00,0xfc,0xa4,0x94,0xfc,0x84,0x94,0x94,0xa4,0xa4,0x54,0xb4,0x14,0x04,0xfc,0x04,
+/* 22284 0x570c "圌" */
+0x00,0x7f,0x41,0x51,0x51,0x5f,0x40,0x7f,0x41,0x5f,0x52,0x52,0x50,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x14,0x14,0xf4,0x04,0xfc,0x04,0xf4,0x94,0x94,0x34,0x04,0xfc,0x04,
+/* 22285 0x570d "圍" */
+0x7f,0x42,0x4f,0x44,0x5f,0x40,0x4f,0x48,0x4f,0x41,0x5f,0x41,0x51,0x5f,0x41,0x7f,
+0xfc,0x04,0xe4,0x24,0xfc,0x04,0xe4,0x24,0xe4,0x04,0xf4,0x04,0x04,0xfc,0x04,0xfc,
+/* 22286 0x570e "圎" */
+0x7f,0x44,0x48,0x5f,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x44,0x48,0x7f,0x40,
+0xfc,0x04,0x24,0xf4,0x14,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x44,0x24,0xfc,0x04,
+/* 22287 0x570f "圏" */
+0x00,0x7f,0x49,0x45,0x5f,0x42,0x7f,0x48,0x57,0x60,0x47,0x44,0x43,0x40,0x7f,0x40,
+0x00,0xfc,0x24,0x44,0xf4,0x04,0xfc,0x24,0xd4,0x4c,0xc4,0x24,0xe4,0x04,0xfc,0x04,
+/* 22288 0x5710 "圐" */
+0x00,0x7f,0x40,0x5f,0x52,0x52,0x5f,0x41,0x7f,0x44,0x47,0x48,0x50,0x60,0x7f,0x40,
+0x00,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x04,0xfc,0x04,0xf4,0x14,0x54,0x24,0xfc,0x04,
+/* 22289 0x5711 "圑" */
+0x7f,0x41,0x5f,0x41,0x4f,0x49,0x4f,0x49,0x4f,0x49,0x40,0x5f,0x48,0x45,0x40,0x7f,
+0xfc,0x24,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x44,0xf4,0x44,0x44,0x84,0xfc,
+/* 22290 0x5712 "園" */
+0x00,0x7f,0x41,0x4f,0x41,0x5f,0x40,0x4f,0x48,0x4f,0x41,0x46,0x5a,0x42,0x7f,0x40,
+0x00,0xfc,0x04,0xe4,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x24,0xfc,0x04,
+/* 22291 0x5713 "圓" */
+0x7f,0x40,0x4f,0x48,0x4f,0x40,0x5f,0x50,0x5f,0x50,0x5f,0x50,0x5f,0x44,0x48,0x7f,
+0xfc,0x04,0xe4,0x24,0xe4,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x14,0xf4,0x44,0x24,0xfc,
+/* 22292 0x5714 "圔" */
+0x7f,0x41,0x4f,0x41,0x5f,0x42,0x44,0x4f,0x40,0x4f,0x4a,0x4a,0x5f,0x40,0x7f,0x40,
+0xfc,0x04,0xe4,0x04,0xf4,0x04,0x44,0xe4,0x04,0xe4,0xa4,0xa4,0xf4,0x04,0xfc,0x04,
+/* 22293 0x5715 "圕" */
+0x7f,0x41,0x41,0x4f,0x41,0x5f,0x41,0x4f,0x41,0x5f,0x48,0x4f,0x48,0x4f,0x40,0x7f,
+0xfc,0x04,0x04,0xe4,0x24,0xf4,0x24,0xe4,0x04,0xf4,0x24,0xe4,0x24,0xe4,0x04,0xfc,
+/* 22294 0x5716 "圖" */
+0x7f,0x40,0x4f,0x48,0x4f,0x41,0x7f,0x41,0x5f,0x50,0x57,0x54,0x5f,0x40,0x7f,0x40,
+0xfc,0x04,0xe4,0x24,0xe4,0x04,0xfc,0x04,0xf4,0x14,0xd4,0x54,0xf4,0x04,0xfc,0x04,
+/* 22295 0x5717 "圗" */
+0x7f,0x42,0x44,0x4f,0x41,0x7f,0x42,0x5f,0x54,0x57,0x54,0x57,0x54,0x5f,0x40,0x7f,
+0xfc,0x04,0x44,0xe4,0x04,0xfc,0x04,0xf4,0x54,0xd4,0x54,0xd4,0x54,0xf4,0x04,0xfc,
+/* 22296 0x5718 "團" */
+0x7f,0x41,0x5f,0x41,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x5f,0x40,0x5f,0x48,0x44,0x7f,
+0xfc,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xf4,0x44,0xf4,0x44,0xc4,0xfc,
+/* 22297 0x5719 "圙" */
+0x00,0x7f,0x44,0x48,0x57,0x41,0x4f,0x4a,0x4b,0x4a,0x4b,0x4a,0x4f,0x40,0x7f,0x40,
+0x00,0xfc,0x44,0x24,0xd4,0x04,0xe4,0xa4,0xa4,0xa4,0xa4,0xa4,0xe4,0x04,0xfc,0x04,
+/* 22298 0x571a "圚" */
+0x7f,0x41,0x4f,0x49,0x4f,0x41,0x5f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x44,0x48,0x7f,
+0xfc,0x04,0xe4,0x24,0xe4,0x04,0xf4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x44,0x24,0xfc,
+/* 22299 0x571b "圛" */
+0x7f,0x40,0x5f,0x52,0x5f,0x41,0x4f,0x41,0x5f,0x44,0x42,0x4f,0x41,0x7f,0x41,0x7f,
+0xfc,0x04,0xf4,0x94,0xf4,0x04,0xe4,0x04,0xf4,0x44,0x84,0xe4,0x04,0xfc,0x04,0xfc,
+/* 22300 0x571c "圜" */
+0x7f,0x40,0x5f,0x52,0x5f,0x40,0x7f,0x40,0x4f,0x48,0x4f,0x45,0x4c,0x74,0x46,0x7f,
+0xfc,0x04,0xf4,0x94,0xf4,0x04,0xfc,0x04,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x24,0xfc,
+/* 22301 0x571d "圝" */
+0x00,0xff,0x80,0x91,0x93,0xa8,0xbb,0x90,0xab,0xb8,0x83,0xaa,0xab,0x80,0xff,0x80,
+0x00,0xfe,0x02,0x12,0x92,0x2a,0xba,0x12,0xaa,0x3a,0x82,0xaa,0xaa,0x02,0xfe,0x02,
+/* 22302 0x571e "圞" */
+0xff,0x91,0xa3,0xb8,0x93,0xa8,0xbb,0x82,0xab,0x81,0xbf,0x85,0x89,0x91,0xff,0x80,
+0xfe,0x12,0xa2,0x3a,0x92,0x2a,0xba,0x82,0xaa,0x02,0xfa,0x42,0x22,0x12,0xfe,0x02,
+/* 22303 0x571f "土" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 22304 0x5720 "圠" */
+0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x16,0x18,0xe0,0x40,0x00,0x00,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 22305 0x5721 "圡" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x20,0x10,0x10,0x00,0x00,0xfe,0x00,
+/* 22306 0x5722 "圢" */
+0x10,0x10,0x13,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x16,0x18,0xe0,0x40,0x00,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22307 0x5723 "圣" */
+0x00,0x3f,0x08,0x04,0x02,0x01,0x06,0x18,0xe1,0x01,0x1f,0x01,0x01,0x01,0x7f,0x00,
+0x00,0xf0,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,0x00,0xf0,0x00,0x00,0x00,0xfc,0x00,
+/* 22308 0x5724 "圤" */
+0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x16,0x18,0xe0,0x40,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 22309 0x5725 "圥" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 22310 0x5726 "圦" */
+0x12,0x11,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0x00,0x80,0x80,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 22311 0x5727 "圧" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x40,0x5f,0x80,
+0x00,0xfe,0x00,0x80,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0xfe,0x00,
+/* 22312 0x5728 "在" */
+0x02,0x02,0x04,0xff,0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xfe,0x00,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 22313 0x5729 "圩" */
+0x10,0x11,0x10,0x10,0x10,0xfc,0x10,0x13,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22314 0x572a "圪" */
+0x10,0x10,0x10,0x10,0x11,0xfe,0x10,0x10,0x10,0x10,0x10,0x1c,0xe1,0x41,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 22315 0x572b "圫" */
+0x10,0x10,0x13,0x10,0x10,0xfe,0x10,0x10,0x13,0x10,0x16,0x18,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 22316 0x572c "圬" */
+0x20,0x21,0x20,0x20,0x20,0xfb,0x20,0x20,0x21,0x21,0x20,0x38,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 22317 0x572d "圭" */
+0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22318 0x572e "圮" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x10,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 22319 0x572f "圯" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 22320 0x5730 "地" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x13,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 22321 0x5731 "圱" */
+0x00,0x0c,0x70,0x10,0x10,0x11,0x10,0xfe,0x10,0x10,0x10,0x10,0x20,0x23,0x40,0x80,
+0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 22322 0x5732 "圲" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x10,0x13,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 22323 0x5733 "圳" */
+0x11,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 22324 0x5734 "圴" */
+0x10,0x10,0x10,0x10,0x11,0xfd,0x12,0x14,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x84,0x44,0x24,0x24,0x04,0x04,0x04,0x28,0x10,
+/* 22325 0x5735 "圵" */
+0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x16,0x18,0xe0,0x40,0x07,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 22326 0x5736 "圶" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x31,0xc1,0x01,0x3f,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 22327 0x5737 "圷" */
+0x10,0x13,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x16,0x18,0xe0,0x40,0x00,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 22328 0x5738 "圸" */
+0x10,0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 22329 0x5739 "圹" */
+0x10,0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x12,0x12,0x1e,0xe2,0x42,0x04,0x04,0x08,
+0x40,0x20,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 22330 0x573a "场" */
+0x20,0x23,0x20,0x20,0x20,0xf9,0x23,0x21,0x21,0x21,0x22,0x3a,0xe4,0x48,0x01,0x02,
+0x00,0xf0,0x20,0x40,0x80,0x00,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 22331 0x573b "圻" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 22332 0x573c "圼" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22333 0x573d "圽" */
+0x11,0x11,0x11,0x11,0x12,0xfc,0x10,0x11,0x11,0x12,0x1c,0xe0,0x41,0x02,0x04,0x00,
+0x00,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 22334 0x573e "圾" */
+0x10,0x17,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x12,0x1e,0xe2,0x44,0x04,0x08,0x03,
+0x00,0xf8,0x08,0x10,0x10,0x20,0x3c,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 22335 0x573f "圿" */
+0x10,0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x10,0x10,0x10,0x1c,0xe0,0x41,0x01,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 22336 0x5740 "址" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x07,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22337 0x5741 "坁" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 22338 0x5742 "坂" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 22339 0x5743 "坃" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 22340 0x5744 "坄" */
+0x20,0x21,0x21,0x21,0x21,0xfa,0x24,0x23,0x21,0x21,0x20,0x38,0xe0,0x40,0x03,0x0c,
+0x00,0xf0,0x10,0x10,0x10,0x0e,0x00,0xf8,0x08,0x10,0x90,0xa0,0x40,0xa0,0x18,0x06,
+/* 22341 0x5745 "坅" */
+0x10,0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x10,0x11,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 22342 0x5746 "坆" */
+0x10,0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x01,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 22343 0x5747 "均" */
+0x10,0x10,0x10,0x10,0x11,0xfe,0x10,0x10,0x10,0x10,0x10,0x1c,0xe1,0x40,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 22344 0x5748 "坈" */
+0x10,0x10,0x13,0x12,0x14,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0x00,0xfc,0x04,0x08,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 22345 0x5749 "坉" */
+0x10,0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x11,0x11,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 22346 0x574a "坊" */
+0x10,0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 22347 0x574b "坋" */
+0x10,0x10,0x10,0x10,0x11,0xfd,0x12,0x15,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 22348 0x574c "坌" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x61,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22349 0x574d "坍" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x17,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x00,0xf8,0x08,0x08,0x48,0x28,0x28,0x08,0xfe,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 22350 0x574e "坎" */
+0x10,0x10,0x10,0x10,0x11,0xfd,0x12,0x14,0x10,0x10,0x10,0x1d,0xe1,0x42,0x04,0x08,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 22351 0x574f "坏" */
+0x10,0x10,0x13,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0x1d,0xe2,0x44,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0x64,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,
+/* 22352 0x5750 "坐" */
+0x01,0x11,0x11,0x11,0x11,0x29,0x25,0x45,0x81,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x10,0x10,0x10,0x10,0x28,0x24,0x44,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22353 0x5751 "坑" */
+0x10,0x10,0x10,0x13,0x10,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 22354 0x5752 "坒" */
+0x20,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,0x21,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x80,0x88,0xb0,0xc0,0x80,0x84,0x84,0x7c,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22355 0x5753 "坓" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x10,0x20,0x41,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22356 0x5754 "坔" */
+0x01,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22357 0x5755 "坕" */
+0x00,0x1f,0x11,0x11,0x11,0x11,0x21,0x21,0x40,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x78,0xa0,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22358 0x5756 "坖" */
+0x00,0x3f,0x00,0x00,0xff,0x04,0x04,0x08,0x30,0xc1,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xf8,0x00,0x00,0xfe,0x40,0x42,0x42,0x3e,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22359 0x5757 "块" */
+0x10,0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x13,0x10,0x10,0x1c,0xe1,0x42,0x04,0x08,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 22360 0x5758 "坘" */
+0x10,0x17,0x10,0x10,0x10,0xfc,0x11,0x11,0x11,0x12,0x13,0x1c,0xe0,0x40,0x07,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x10,0x10,0x10,0xfe,0x00,
+/* 22361 0x5759 "坙" */
+0x00,0x7f,0x08,0x08,0x11,0x22,0x11,0x08,0x08,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfe,0x88,0x88,0x10,0x20,0x10,0x88,0x88,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22362 0x575a "坚" */
+0x04,0x25,0x25,0x24,0x24,0x24,0x24,0x25,0x04,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x04,0x88,0x50,0x20,0x58,0x86,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22363 0x575b "坛" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x10,0x1c,0xe1,0x43,0x01,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 22364 0x575c "坜" */
+0x20,0x23,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe4,0x44,0x09,0x12,
+0x00,0xfe,0x00,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 22365 0x575d "坝" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1c,0xe0,0x40,0x01,0x06,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x02,0x02,
+/* 22366 0x575e "坞" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x10,0x1c,0xe3,0x40,0x00,0x00,
+0x20,0x40,0xfc,0x04,0x04,0x04,0x14,0x08,0x00,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 22367 0x575f "坟" */
+0x10,0x10,0x10,0x17,0x11,0xfd,0x11,0x11,0x11,0x10,0x10,0x1c,0xe0,0x41,0x02,0x0c,
+0x80,0x40,0x40,0xfc,0x10,0x10,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 22368 0x5760 "坠" */
+0x00,0x7c,0x44,0x48,0x44,0x44,0x55,0x49,0x42,0x45,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x40,0x40,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22369 0x5761 "坡" */
+0x20,0x20,0x20,0x23,0x22,0xfa,0x22,0x23,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x09,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 22370 0x5762 "坢" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x11,0x10,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 22371 0x5763 "坣" */
+0x01,0x11,0x09,0x01,0x7f,0x40,0x81,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x10,0x20,0x00,0xfe,0x02,0x04,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 22372 0x5764 "坤" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 22373 0x5765 "坥" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 22374 0x5766 "坦" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x03,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 22375 0x5767 "坧" */
+0x10,0x10,0x13,0x10,0x10,0xfc,0x10,0x10,0x11,0x12,0x14,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 22376 0x5768 "坨" */
+0x10,0x10,0x10,0x13,0x12,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x08,0x10,0x20,0xc0,0x02,0x02,0x02,0xfe,0x00,
+/* 22377 0x5769 "坩" */
+0x11,0x11,0x11,0x11,0x17,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 22378 0x576a "坪" */
+0x10,0x11,0x10,0x10,0x11,0xfc,0x10,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 22379 0x576b "坫" */
+0x10,0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 22380 0x576c "坬" */
+0x20,0x20,0x23,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 22381 0x576d "坭" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 22382 0x576e "坮" */
+0x10,0x10,0x10,0x10,0x10,0xfd,0x13,0x10,0x10,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 22383 0x576f "坯" */
+0x10,0x13,0x10,0x10,0x10,0xfe,0x10,0x11,0x12,0x14,0x16,0x18,0xe0,0x40,0x07,0x00,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 22384 0x5770 "坰" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfe,0x02,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x04,
+/* 22385 0x5771 "坱" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x11,0x13,0x10,0x1c,0xe0,0x40,0x01,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 22386 0x5772 "坲" */
+0x10,0x10,0x10,0x13,0x10,0xfc,0x13,0x12,0x12,0x13,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 22387 0x5773 "坳" */
+0x20,0x21,0x21,0x22,0x22,0xf4,0x27,0x21,0x22,0x22,0x24,0x37,0xe0,0x40,0x00,0x01,
+0x20,0x20,0x20,0x20,0xfc,0xa4,0x24,0x24,0x24,0x24,0xa4,0xa4,0xc4,0x44,0x94,0x08,
+/* 22388 0x5774 "坴" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x08,0x10,0x21,0x41,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x20,0x10,0x08,0x04,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22389 0x5775 "坵" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x07,0x00,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 22390 0x5776 "坶" */
+0x20,0x21,0x21,0x21,0x21,0xf9,0x21,0x27,0x22,0x22,0x22,0x3a,0xe3,0x40,0x00,0x00,
+0x00,0xf8,0x08,0x48,0x28,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0xfe,0x08,0x50,0x20,
+/* 22391 0x5777 "坷" */
+0x20,0x20,0x27,0x20,0x20,0xfb,0x22,0x22,0x22,0x22,0x23,0x3a,0xe0,0x40,0x00,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0x48,0xc8,0x48,0x08,0x08,0x28,0x10,
+/* 22392 0x5778 "坸" */
+0x10,0x10,0x11,0x11,0x12,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 22393 0x5779 "坹" */
+0x10,0x10,0x10,0x13,0x12,0xfc,0x10,0x10,0x10,0x10,0x10,0x1d,0xe1,0x41,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 22394 0x577a "坺" */
+0x10,0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 22395 0x577b "坻" */
+0x10,0x10,0x13,0x12,0x12,0xfe,0x12,0x13,0x12,0x12,0x12,0x1e,0xe2,0x42,0x03,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 22396 0x577c "坼" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 22397 0x577d "坽" */
+0x10,0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x11,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 22398 0x577e "坾" */
+0x10,0x10,0x10,0x13,0x12,0xfc,0x10,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22399 0x577f "坿" */
+0x20,0x20,0x20,0x21,0x21,0xfb,0x25,0x21,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 22400 0x5780 "垀" */
+0x10,0x10,0x13,0x10,0x11,0xfc,0x10,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22401 0x5781 "垁" */
+0x10,0x10,0x10,0x10,0x11,0xfe,0x10,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x01,0x02,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 22402 0x5782 "垂" */
+0x00,0x00,0x3f,0x01,0x01,0x7f,0x09,0x09,0xff,0x09,0x09,0x7f,0x01,0x01,0x3f,0x00,
+0x10,0xf8,0x00,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xf8,0x00,
+/* 22403 0x5783 "垃" */
+0x10,0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x11,0x10,0x10,0x1c,0xe0,0x40,0x07,0x00,
+0x80,0x40,0x40,0x00,0xfc,0x00,0x08,0x08,0x08,0x90,0x90,0x90,0xa0,0x20,0xfe,0x00,
+/* 22404 0x5784 "垄" */
+0x04,0x04,0xff,0x09,0x11,0x11,0x23,0x4d,0x80,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x20,0xfe,0x10,0x20,0xc0,0x04,0x04,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22405 0x5785 "垅" */
+0x10,0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x10,0x10,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0xa8,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 22406 0x5786 "垆" */
+0x20,0x20,0x20,0x20,0x20,0xfb,0x22,0x22,0x22,0x23,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x40,0x40,0x7e,0x40,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,
+/* 22407 0x5787 "垇" */
+0x20,0x20,0x23,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x43,0x02,0x00,
+0x00,0x00,0xde,0x52,0x52,0x52,0x52,0x52,0x72,0x02,0x02,0x02,0x02,0xfe,0x02,0x00,
+/* 22408 0x5788 "垈" */
+0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x11,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x90,0x88,0x80,0x9e,0xe0,0x80,0x44,0x34,0x0c,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22409 0x5789 "垉" */
+0x10,0x10,0x11,0x11,0x12,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 22410 0x578a "垊" */
+0x20,0x23,0x22,0x22,0x22,0xfb,0x22,0x22,0x23,0x22,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 22411 0x578b "型" */
+0x00,0x7f,0x12,0x12,0x12,0xff,0x12,0x22,0x22,0x41,0x81,0x3f,0x01,0x01,0xff,0x00,
+0x04,0x84,0x24,0x24,0x24,0xa4,0x24,0x04,0x14,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22412 0x578c "垌" */
+0x20,0x23,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x00,0xfe,0x02,0x02,0xfa,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x02,0x0a,0x04,
+/* 22413 0x578d "垍" */
+0x10,0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 22414 0x578e "垎" */
+0x20,0x20,0x21,0x22,0x25,0xf8,0x20,0x20,0x23,0x2c,0x23,0x3a,0xe2,0x42,0x03,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 22415 0x578f "垏" */
+0x10,0x10,0x11,0x10,0x13,0xfc,0x11,0x10,0x10,0x11,0x10,0x1c,0xe3,0x40,0x00,0x00,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 22416 0x5790 "垐" */
+0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22417 0x5791 "垑" */
+0x20,0x20,0x20,0x21,0x22,0xf8,0x20,0x21,0x26,0x20,0x20,0x3b,0xe0,0x40,0x00,0x07,
+0x40,0x40,0xfc,0x08,0x90,0x60,0x48,0x90,0x3e,0x42,0x84,0x48,0x30,0x20,0xc0,0x00,
+/* 22418 0x5792 "垒" */
+0x04,0x08,0x10,0x3f,0x08,0x10,0x24,0x7e,0x02,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x20,0x10,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22419 0x5793 "垓" */
+0x20,0x20,0x20,0x27,0x20,0xf8,0x21,0x23,0x20,0x20,0x39,0xe6,0x40,0x00,0x01,0x06,
+0x40,0x20,0x20,0xfe,0x40,0x84,0x08,0xf0,0x22,0x44,0x88,0x10,0x20,0x50,0x88,0x04,
+/* 22420 0x5794 "垔" */
+0x00,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22421 0x5795 "垕" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x20,0x20,0x2f,0x40,0x40,0xbf,0x00,
+0x7c,0x80,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfc,0x80,0x80,0xfe,0x00,
+/* 22422 0x5796 "垖" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x40,0x80,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 22423 0x5797 "垗" */
+0x10,0x10,0x10,0x12,0x11,0xfc,0x10,0x11,0x12,0x14,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 22424 0x5798 "垘" */
+0x10,0x10,0x10,0x11,0x11,0xff,0x15,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x90,0x94,0x92,0x12,0x10,0x7e,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 22425 0x5799 "垙" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 22426 0x579a "垚" */
+0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x10,0x10,0x10,0x7c,0x10,0x10,0x1e,0xf0,0x40,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,
+/* 22427 0x579b "垛" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x12,0x14,0x13,0x10,0x1c,0xe1,0x42,0x04,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x4e,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 22428 0x579c "垜" */
+0x10,0x13,0x10,0x10,0x10,0xfd,0x11,0x12,0x10,0x17,0x10,0x1c,0xe1,0x42,0x04,0x00,
+0x00,0xf8,0x88,0x90,0xbc,0x04,0x14,0x48,0x40,0xfe,0x40,0xe0,0x50,0x48,0x46,0x40,
+/* 22429 0x579d "垝" */
+0x10,0x10,0x10,0x11,0x12,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 22430 0x579e "垞" */
+0x20,0x20,0x23,0x22,0x20,0xf8,0x23,0x20,0x20,0x20,0x23,0x38,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x00,0x38,0xc0,0x40,0x40,0x7c,0xc0,0x40,0x42,0x42,0x3e,0x00,
+/* 22431 0x579f "垟" */
+0x11,0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 22432 0x57a0 "垠" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 22433 0x57a1 "垡" */
+0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x11,0x16,0x01,0x3f,0x01,0x01,0xff,
+0xa0,0x90,0x80,0xfc,0x80,0x48,0x50,0x24,0x54,0x8c,0x04,0x00,0xf8,0x00,0x00,0xfe,
+/* 22434 0x57a2 "垢" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 22435 0x57a3 "垣" */
+0x10,0x13,0x10,0x10,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x03,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 22436 0x57a4 "垤" */
+0x20,0x27,0x20,0x20,0x21,0xfa,0x27,0x20,0x20,0x20,0x27,0x38,0xe0,0x40,0x0f,0x00,
+0x00,0xfe,0x40,0x80,0x10,0x08,0xfc,0x44,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 22437 0x57a5 "垥" */
+0x20,0x20,0x20,0x21,0xfa,0x24,0x23,0x20,0x20,0x23,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 22438 0x57a6 "垦" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x22,0x21,0x2c,0x31,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x1c,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22439 0x57a7 "垧" */
+0x20,0x20,0x20,0x23,0x22,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 22440 0x57a8 "垨" */
+0x10,0x10,0x13,0x12,0x14,0xfc,0x10,0x13,0x10,0x11,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x14,0x10,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 22441 0x57a9 "垩" */
+0x00,0x7f,0x04,0x24,0x14,0x14,0x04,0xff,0x00,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x40,0x48,0x48,0x50,0x40,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22442 0x57aa "垪" */
+0x11,0x10,0x10,0x10,0x11,0xfc,0x10,0x10,0x10,0x13,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 22443 0x57ab "垫" */
+0x08,0x08,0x7d,0x08,0x0c,0x19,0x68,0x08,0x28,0x11,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x40,0xf8,0x48,0x48,0xc8,0x4a,0xaa,0x86,0x02,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22444 0x57ac "垬" */
+0x10,0x10,0x10,0x10,0x11,0xfc,0x10,0x10,0x10,0x13,0x10,0x1c,0xe0,0x41,0x02,0x04,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 22445 0x57ad "垭" */
+0x20,0x23,0x20,0x20,0x20,0xf8,0x24,0x22,0x22,0x22,0x20,0x38,0xe0,0x40,0x07,0x00,
+0x00,0xfc,0x90,0x90,0x90,0x92,0x92,0x94,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 22446 0x57ae "垮" */
+0x20,0x20,0x27,0x20,0x21,0xfa,0x2d,0x20,0x27,0x20,0x21,0x3b,0xe0,0x40,0x00,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 22447 0x57af "垯" */
+0x10,0x12,0x11,0x11,0x10,0xfc,0x13,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x04,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x24,0x44,0x42,0x82,0x00,0x80,0x7e,0x00,
+/* 22448 0x57b0 "垰" */
+0x10,0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x11,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x20,0x20,0x20,
+/* 22449 0x57b1 "垱" */
+0x10,0x11,0x10,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x11,0x1c,0xe0,0x40,0x03,0x00,
+0x20,0x24,0xa4,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 22450 0x57b2 "垲" */
+0x10,0x11,0x11,0x11,0x11,0xfc,0x11,0x10,0x10,0x11,0x11,0x1d,0xe1,0x41,0x00,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 22451 0x57b3 "垳" */
+0x20,0x20,0x21,0x22,0x24,0xf8,0x21,0x23,0x25,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 22452 0x57b4 "垴" */
+0x20,0x20,0x20,0x27,0x20,0xf8,0x20,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x03,0x00,
+0x40,0x20,0x20,0xfe,0x00,0x00,0x90,0x54,0x24,0x24,0x54,0x94,0x04,0x04,0xfc,0x04,
+/* 22453 0x57b5 "垵" */
+0x10,0x10,0x10,0x13,0x12,0xfc,0x10,0x13,0x10,0x10,0x11,0x1c,0xe0,0x40,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 22454 0x57b6 "垶" */
+0x10,0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x11,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 22455 0x57b7 "垷" */
+0x10,0x13,0x12,0x12,0x13,0xfe,0x12,0x13,0x12,0x12,0x13,0x1d,0xe1,0x42,0x04,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 22456 0x57b8 "垸" */
+0x10,0x10,0x13,0x12,0x14,0xfd,0x10,0x10,0x13,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 22457 0x57b9 "垹" */
+0x21,0x21,0x21,0x2f,0x21,0xf9,0x27,0x21,0x21,0x2f,0x21,0x39,0xe2,0x42,0x04,0x08,
+0x00,0x1e,0x12,0xd2,0x14,0x14,0xd8,0x14,0x12,0xd2,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 22458 0x57ba "垺" */
+0x10,0x10,0x11,0x10,0x11,0xfc,0x10,0x11,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 22459 0x57bb "垻" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1c,0xe0,0x40,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 22460 0x57bc "垼" */
+0x10,0x20,0x41,0x8a,0x10,0x31,0x50,0x90,0x10,0x10,0x17,0x01,0x3f,0x01,0x01,0xff,
+0xf8,0x88,0x08,0x06,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,0x00,0xf8,0x00,0x00,0xfe,
+/* 22461 0x57bd "垽" */
+0x20,0x11,0x81,0x49,0x09,0x11,0xe1,0x22,0x22,0x25,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22462 0x57be "垾" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x10,0x10,0x11,0x10,0x1c,0xe3,0x40,0x00,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 22463 0x57bf "垿" */
+0x20,0x20,0x23,0x22,0x22,0xfa,0x22,0x22,0x22,0x23,0x3a,0xe2,0x42,0x04,0x04,0x08,
+0x40,0x20,0xfe,0x00,0x00,0xfe,0x04,0x28,0x10,0xfe,0x12,0x14,0x10,0x10,0x50,0x20,
+/* 22464 0x57c0 "埀" */
+0x00,0x3f,0x01,0xff,0x01,0x09,0xf9,0x09,0x39,0xc9,0x01,0x3f,0x01,0x01,0xff,0x00,
+0xf8,0x00,0x00,0xfe,0x00,0x24,0x38,0x22,0x22,0x1e,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22465 0x57c1 "埁" */
+0x10,0x11,0x11,0x11,0x11,0xfc,0x10,0x10,0x11,0x12,0x10,0x1d,0xe0,0x40,0x00,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x10,0x10,0x20,
+/* 22466 0x57c2 "埂" */
+0x10,0x13,0x10,0x10,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x00,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 22467 0x57c3 "埃" */
+0x20,0x20,0x21,0x22,0x27,0xf9,0x21,0x23,0x24,0x20,0x27,0x38,0xe0,0x41,0x02,0x0c,
+0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 22468 0x57c4 "埄" */
+0x21,0x21,0x23,0x24,0x20,0xf9,0x26,0x20,0x23,0x20,0x23,0x38,0xe7,0x40,0x00,0x00,
+0x00,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x40,0x40,0x40,
+/* 22469 0x57c5 "埅" */
+0x00,0x78,0x4b,0x50,0x48,0x44,0x55,0x49,0x42,0x41,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x20,0xfe,0x80,0xf8,0x88,0x08,0x28,0x10,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22470 0x57c6 "埆" */
+0x10,0x10,0x10,0x11,0x12,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x14,0x08,
+/* 22471 0x57c7 "埇" */
+0x10,0x11,0x10,0x10,0x10,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 22472 0x57c8 "埈" */
+0x10,0x10,0x10,0x11,0x13,0xfc,0x10,0x11,0x12,0x10,0x1d,0xe2,0x40,0x00,0x01,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 22473 0x57c9 "埉" */
+0x10,0x10,0x10,0x13,0x10,0xfc,0x11,0x11,0x11,0x12,0x10,0x1c,0xe0,0x40,0x01,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 22474 0x57ca "埊" */
+0x01,0x21,0x21,0x3f,0x00,0x01,0x7d,0x09,0x11,0x25,0xc2,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x08,0x08,0xf8,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x00,0x00,0xfe,
+/* 22475 0x57cb "埋" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x10,0x11,0x1c,0xe0,0x40,0x03,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 22476 0x57cc "埌" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 22477 0x57cd "埍" */
+0x10,0x10,0x10,0x10,0x10,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 22478 0x57ce "城" */
+0x20,0x20,0x20,0x27,0x24,0xfc,0x24,0x27,0x24,0x24,0x24,0x3c,0xe6,0x49,0x08,0x10,
+0x28,0x24,0x20,0xfe,0x20,0x20,0x24,0xa4,0xa4,0xa8,0xa8,0x90,0x92,0x2a,0x46,0x82,
+/* 22479 0x57cf "埏" */
+0x20,0x20,0x27,0x21,0x21,0xfa,0x22,0x27,0x21,0x25,0x25,0x3a,0xe2,0x45,0x08,0x10,
+0x08,0x1c,0x70,0x10,0x10,0x50,0x5c,0x50,0x50,0x50,0x50,0x7c,0x00,0x00,0xfe,0x00,
+/* 22480 0x57d0 "埐" */
+0x10,0x11,0x10,0x10,0x10,0xfd,0x10,0x13,0x12,0x11,0x10,0x1c,0xe0,0x40,0x00,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 22481 0x57d1 "埑" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22482 0x57d2 "埒" */
+0x10,0x10,0x13,0x10,0x12,0xfd,0x11,0x10,0x13,0x10,0x11,0x1c,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x50,0x20,
+/* 22483 0x57d3 "埓" */
+0x10,0x10,0x13,0x11,0x10,0xfc,0x13,0x10,0x13,0x10,0x11,0x1c,0xe0,0x40,0x00,0x00,
+0x08,0x3c,0xc0,0x24,0x98,0x60,0x90,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x50,0x20,
+/* 22484 0x57d4 "埔" */
+0x20,0x20,0x27,0x20,0x20,0xfb,0x22,0x22,0x23,0x22,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 22485 0x57d5 "埕" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x10,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x03,0x00,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 22486 0x57d6 "埖" */
+0x21,0x21,0x27,0x21,0x21,0xf8,0x20,0x20,0x21,0x23,0x25,0x39,0xe1,0x41,0x01,0x01,
+0x08,0x08,0xfe,0x08,0x08,0x00,0x90,0x92,0x14,0x18,0x10,0x32,0x52,0x12,0x0e,0x00,
+/* 22487 0x57d7 "埗" */
+0x10,0x10,0x10,0x10,0x10,0xfc,0x13,0x10,0x10,0x10,0x10,0x1d,0xe2,0x40,0x00,0x03,
+0x10,0x10,0x90,0x9e,0x90,0x90,0xfe,0x00,0x10,0x92,0x92,0x14,0x08,0x10,0x60,0x80,
+/* 22488 0x57d8 "埘" */
+0x20,0x20,0x27,0x24,0x24,0xfc,0x24,0x27,0x24,0x24,0x24,0x3c,0xe7,0x44,0x00,0x00,
+0x08,0x08,0x88,0x88,0xfe,0x88,0x88,0xc8,0xa8,0xa8,0x88,0x88,0x88,0x88,0x28,0x10,
+/* 22489 0x57d9 "埙" */
+0x20,0x23,0x22,0x22,0x23,0xf8,0x20,0x27,0x24,0x24,0x24,0x3c,0xe4,0x41,0x06,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x44,0x44,0x44,0xb4,0x08,0x04,0x02,
+/* 22490 0x57da "埚" */
+0x20,0x23,0x22,0x22,0x22,0xfb,0x20,0x20,0x27,0x24,0x24,0x3d,0xe6,0x44,0x04,0x04,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x40,0x40,0xfc,0x44,0xa4,0x14,0x14,0x04,0x14,0x08,
+/* 22491 0x57db "埛" */
+0x20,0x27,0x24,0x24,0x25,0xfe,0x24,0x25,0x25,0x25,0x25,0x3d,0xe5,0x44,0x04,0x04,
+0x00,0xfc,0x04,0xa4,0x14,0x0c,0x04,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0x14,0x08,
+/* 22492 0x57dc "埜" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x09,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22493 0x57dd "埝" */
+0x20,0x20,0x20,0x20,0x21,0xfa,0x21,0x20,0x20,0x20,0x20,0x3a,0xe2,0x42,0x04,0x00,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 22494 0x57de "埞" */
+0x10,0x10,0x13,0x12,0x14,0xfc,0x13,0x10,0x10,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 22495 0x57df "域" */
+0x20,0x20,0x20,0x27,0x20,0xf8,0x23,0x22,0x22,0x22,0x23,0x38,0xe0,0x47,0x02,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 22496 0x57e0 "埠" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x10,0x1c,0xe3,0x40,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 22497 0x57e1 "埡" */
+0x20,0x27,0x20,0x20,0x20,0xfb,0x22,0x22,0x22,0x23,0x20,0x38,0xe0,0x40,0x07,0x00,
+0x00,0xfe,0x90,0x90,0x90,0x9c,0x04,0x04,0x04,0x9c,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 22498 0x57e2 "埢" */
+0x20,0x22,0x21,0x20,0x23,0xf8,0x27,0x21,0x22,0x25,0x29,0x39,0xe1,0x41,0x01,0x00,
+0x40,0x48,0x50,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf4,0x12,0x10,0x50,0x24,0x04,0xfc,
+/* 22499 0x57e3 "埣" */
+0x10,0x10,0x13,0x10,0x10,0xfc,0x11,0x12,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 22500 0x57e4 "埤" */
+0x20,0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x23,0x20,0x39,0xe7,0x40,0x00,0x00,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 22501 0x57e5 "埥" */
+0x10,0x10,0x13,0x10,0x11,0xfc,0x13,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 22502 0x57e6 "埦" */
+0x20,0x20,0x23,0x22,0x25,0xf9,0x21,0x22,0x22,0x23,0x24,0x38,0xe1,0x41,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 22503 0x57e7 "埧" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x1d,0xe3,0x40,0x00,0x01,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 22504 0x57e8 "埨" */
+0x20,0x20,0x20,0x21,0x22,0xfd,0x20,0x27,0x24,0x24,0x27,0x3c,0xe4,0x44,0x04,0x04,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 22505 0x57e9 "埩" */
+0x10,0x10,0x11,0x11,0x12,0xfd,0x10,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x00,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 22506 0x57ea "埪" */
+0x10,0x10,0x10,0x13,0x12,0xfc,0x11,0x12,0x10,0x11,0x10,0x1c,0xe0,0x40,0x07,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22507 0x57eb "埫" */
+0x20,0x21,0x20,0x20,0x20,0xfb,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 22508 0x57ec "埬" */
+0x20,0x20,0x27,0x20,0x23,0xfa,0x23,0x22,0x23,0x20,0x20,0x39,0xe2,0x4c,0x00,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 22509 0x57ed "埭" */
+0x20,0x20,0x23,0x20,0xf8,0x27,0x20,0x20,0x23,0x24,0x22,0x39,0xe2,0x44,0x01,0x00,
+0x40,0x40,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x44,0xe8,0x50,0x48,0x46,0x40,0x80,
+/* 22510 0x57ee "埮" */
+0x10,0x11,0x11,0x12,0x10,0xfc,0x13,0x10,0x10,0x11,0x1d,0xe2,0x40,0x00,0x01,0x06,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 22511 0x57ef "埯" */
+0x20,0x20,0x27,0x21,0x22,0xfc,0x23,0x22,0x22,0x23,0x22,0x3a,0xe3,0x40,0x00,0x00,
+0x40,0x80,0xfe,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 22512 0x57f0 "埰" */
+0x10,0x10,0x13,0x10,0x12,0xfd,0x11,0x10,0x13,0x10,0x10,0x1c,0xe1,0x42,0x04,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 22513 0x57f1 "埱" */
+0x21,0x21,0x21,0x21,0xf1,0x21,0x27,0x20,0x21,0x21,0x35,0xe5,0x49,0x01,0x05,0x02,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 22514 0x57f2 "埲" */
+0x10,0x10,0x13,0x10,0x11,0xfc,0x13,0x10,0x11,0x12,0x10,0x1c,0xe3,0x40,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 22515 0x57f3 "埳" */
+0x20,0x20,0x20,0x21,0xfa,0x24,0x20,0x23,0x22,0x22,0x23,0x3a,0xe2,0x42,0x03,0x02,
+0x80,0x80,0xf8,0x08,0x10,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 22516 0x57f4 "埴" */
+0x20,0x20,0x27,0x20,0x20,0xfb,0x22,0x23,0x22,0x23,0x22,0x3b,0xe2,0x42,0x0f,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 22517 0x57f5 "埵" */
+0x20,0x20,0x21,0x20,0x20,0xfb,0x21,0x21,0x27,0x21,0x21,0x3b,0xe0,0x40,0x03,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x24,0x24,0xfe,0x24,0x24,0xfe,0x20,0x20,0xfe,0x00,
+/* 22518 0x57f6 "埶" */
+0x10,0x10,0x7c,0x10,0x11,0xfe,0x00,0x45,0x92,0x10,0x7c,0x10,0x10,0x1c,0xe1,0x42,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0xc8,0x48,0x68,0x5a,0x8a,0x8a,0x06,0x02,
+/* 22519 0x57f7 "執" */
+0x10,0x10,0x7c,0x11,0x10,0xfe,0x44,0x29,0x7c,0x10,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xa8,0x8a,0x0a,0x06,0x02,
+/* 22520 0x57f8 "埸" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x10,0x10,0x11,0x12,0x14,0x1c,0xe1,0x42,0x00,0x01,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0x80,0xfe,0x4a,0x4a,0x92,0x22,0x42,0x94,0x08,
+/* 22521 0x57f9 "培" */
+0x10,0x10,0x11,0x10,0x11,0xfc,0x10,0x13,0x10,0x10,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 22522 0x57fa "基" */
+0x08,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x08,0x11,0x21,0xcf,0x01,0x01,0x3f,
+0x20,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x20,0x10,0x08,0xe6,0x00,0x00,0xf8,
+/* 22523 0x57fb "埻" */
+0x10,0x10,0x13,0x10,0x11,0xfd,0x11,0x10,0x11,0x10,0x1c,0xe3,0x40,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 22524 0x57fc "埼" */
+0x20,0x20,0x23,0x20,0x21,0xfa,0x27,0x20,0x23,0x22,0x22,0x3a,0xe3,0x40,0x00,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 22525 0x57fd "埽" */
+0x20,0x23,0x20,0x21,0x20,0xfb,0x20,0x27,0x24,0x28,0x23,0x3a,0xe2,0x42,0x02,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x42,0x44,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 22526 0x57fe "埾" */
+0x00,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x7c,0x44,0x44,0x28,0x10,0xa8,0x44,0x82,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22527 0x57ff "埿" */
+0x23,0x12,0x82,0x4b,0x0a,0x12,0xe2,0x22,0x24,0x25,0x09,0x3f,0x01,0x01,0xff,0x00,
+0xf8,0x08,0x08,0xf8,0x40,0x48,0x70,0x44,0x44,0x3c,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22528 0x5800 "堀" */
+0x10,0x13,0x12,0x12,0x13,0xfe,0x12,0x12,0x12,0x12,0x12,0x1e,0xe2,0x44,0x04,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 22529 0x5801 "堁" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x13,0x10,0x1c,0xe1,0x42,0x00,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 22530 0x5802 "堂" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22531 0x5803 "堃" */
+0x10,0x08,0x7e,0x10,0x1e,0x12,0x12,0x22,0x4a,0x85,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x10,0xfe,0x20,0x3c,0x24,0x24,0x44,0x94,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22532 0x5804 "堄" */
+0x20,0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x23,0x20,0x20,0x38,0xe0,0x41,0x02,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 22533 0x5805 "堅" */
+0x7f,0x48,0x7f,0x41,0x41,0x7f,0x48,0x48,0x7f,0x00,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x7c,0x44,0x44,0x48,0x28,0x30,0x10,0x28,0x44,0x82,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22534 0x5806 "堆" */
+0x21,0x21,0x21,0x23,0x22,0xfe,0x2b,0x22,0x22,0x23,0x22,0x3a,0xe2,0x43,0x02,0x02,
+0x40,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 22535 0x5807 "堇" */
+0x08,0x08,0xff,0x08,0x0f,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x01,0x3f,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,
+/* 22536 0x5808 "堈" */
+0x20,0x23,0x22,0x22,0x22,0xfb,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 22537 0x5809 "堉" */
+0x20,0x20,0x23,0x20,0x21,0xfb,0x20,0x21,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 22538 0x580a "堊" */
+0x00,0x7f,0x04,0x3c,0x20,0x20,0x3c,0x04,0xff,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x40,0x78,0x08,0x08,0x78,0x40,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22539 0x580b "堋" */
+0x20,0x23,0x22,0x22,0x22,0xfb,0x22,0x22,0x22,0x23,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 22540 0x580c "堌" */
+0x20,0x27,0x24,0x24,0x27,0xfc,0x24,0x25,0x25,0x25,0x25,0x3d,0xe5,0x44,0x07,0x04,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0xfc,0x04,
+/* 22541 0x580d "堍" */
+0x21,0x21,0x21,0x22,0xfa,0x27,0x2a,0x22,0x22,0x23,0x22,0x38,0xe1,0x42,0x04,0x08,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0x44,0xfc,0xa4,0xb0,0x28,0x2a,0x22,0x1e,
+/* 22542 0x580e "堎" */
+0x20,0x20,0x21,0x20,0x20,0xfb,0x20,0x21,0x22,0x20,0x21,0x3a,0xe0,0x40,0x01,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 22543 0x580f "堏" */
+0x08,0x08,0x09,0x7e,0x18,0x2c,0x2a,0x48,0x89,0x08,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22544 0x5810 "堐" */
+0x10,0x13,0x12,0x12,0x12,0xfe,0x12,0x13,0x12,0x12,0x12,0x1e,0xe2,0x44,0x05,0x08,
+0x00,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 22545 0x5811 "堑" */
+0x10,0xfe,0x20,0x48,0x7e,0x08,0x0e,0xf9,0x4a,0x09,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22546 0x5812 "堒" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 22547 0x5813 "堓" */
+0x10,0x11,0x11,0x11,0x11,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 22548 0x5814 "堔" */
+0x10,0x13,0x12,0x12,0x10,0xfd,0x10,0x10,0x13,0x10,0x10,0x1c,0xe1,0x42,0x00,0x00,
+0x00,0xfe,0x02,0x52,0x88,0x04,0x20,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 22549 0x5815 "堕" */
+0x00,0x7b,0x48,0x48,0x51,0x4a,0x48,0x68,0x50,0x41,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22550 0x5816 "堖" */
+0x21,0x22,0x24,0x22,0x21,0xf8,0x21,0x27,0x24,0x25,0x24,0x3c,0xe4,0x45,0x07,0x04,
+0x24,0x48,0x90,0x48,0x24,0x80,0x00,0xfc,0x04,0x14,0xa4,0x44,0xa4,0x14,0xfc,0x04,
+/* 22551 0x5817 "堗" */
+0x10,0x10,0x13,0x12,0x10,0xfd,0x12,0x10,0x10,0x13,0x10,0x1c,0xe0,0x40,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 22552 0x5818 "堘" */
+0x20,0x22,0x21,0x20,0x23,0xf8,0x27,0x21,0x22,0x24,0x38,0xe3,0x40,0x00,0x07,0x00,
+0x40,0x48,0x50,0x40,0xf8,0x80,0xfc,0x10,0x48,0x44,0x42,0xf8,0x40,0x40,0xfc,0x00,
+/* 22553 0x5819 "堙" */
+0x20,0x27,0x20,0x20,0x27,0xfc,0x24,0x24,0x27,0x20,0x38,0xe7,0x40,0x00,0x0f,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 22554 0x581a "堚" */
+0x10,0x13,0x12,0x10,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22555 0x581b "堛" */
+0x20,0x23,0x20,0x21,0x21,0xf9,0x21,0x20,0x23,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 22556 0x581c "堜" */
+0x10,0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x11,0x11,0x10,0x1c,0xe0,0x41,0x02,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 22557 0x581d "堝" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x13,0x12,0x12,0x1e,0xe2,0x42,0x02,0x02,0x02,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 22558 0x581e "堞" */
+0x20,0x22,0x22,0x27,0x22,0xfa,0x22,0x22,0x23,0x20,0x27,0x38,0xe1,0x42,0x0c,0x00,
+0x90,0x90,0x90,0xfe,0x90,0x90,0xf0,0x00,0xfc,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 22559 0x581f "堟" */
+0x20,0x20,0x21,0x21,0x20,0xfb,0x20,0x20,0x23,0x20,0x20,0x3b,0xe0,0x40,0x03,0x00,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 22560 0x5820 "堠" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x2a,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 22561 0x5821 "堡" */
+0x08,0x0b,0x12,0x33,0x50,0x97,0x11,0x12,0x14,0x11,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xf8,0x08,0xf8,0x40,0xfc,0x50,0x48,0x46,0x40,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22562 0x5822 "堢" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x2a,0x22,0x22,0x22,0x22,0x3a,0xe2,0x43,0x02,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 22563 0x5823 "堣" */
+0x11,0x11,0x11,0x11,0x11,0xfd,0x11,0x10,0x10,0x13,0x12,0x1e,0xe2,0x42,0x02,0x02,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 22564 0x5824 "堤" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x13,0x10,0x1d,0xe1,0x41,0x02,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 22565 0x5825 "堥" */
+0x00,0x7f,0x12,0x0c,0xff,0x19,0x2a,0x48,0xa8,0x11,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22566 0x5826 "堦" */
+0x11,0x11,0x11,0x11,0x11,0xfd,0x11,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 22567 0x5827 "堧" */
+0x10,0x13,0x10,0x10,0x11,0xfd,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 22568 0x5828 "堨" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x10,0x11,0x12,0x11,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 22569 0x5829 "堩" */
+0x22,0x22,0x22,0x22,0xfb,0x22,0x26,0x2a,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x00,0xfe,0x20,0x20,0x20,0xbc,0x44,0x54,0x4c,0x84,0xa4,0x18,0x08,0x08,0xfe,0x00,
+/* 22570 0x582a "堪" */
+0x10,0x10,0x13,0x10,0x10,0xfc,0x10,0x10,0x10,0x13,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 22571 0x582b "堫" */
+0x20,0x20,0x22,0x22,0x22,0xfa,0x22,0x23,0x20,0x21,0x22,0x38,0xe1,0x40,0x00,0x07,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 22572 0x582c "堬" */
+0x20,0x20,0x21,0x22,0x25,0xf8,0x23,0x22,0x22,0x23,0x22,0x3a,0xe3,0x42,0x02,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 22573 0x582d "堭" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x03,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 22574 0x582e "堮" */
+0x10,0x13,0x12,0x12,0x13,0xfc,0x11,0x10,0x13,0x10,0x11,0x1d,0xe0,0x40,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 22575 0x582f "堯" */
+0x01,0x01,0x3f,0x01,0xff,0x08,0x3e,0x08,0x0e,0x78,0x00,0xff,0x04,0x08,0x10,0x60,
+0x00,0x00,0xf8,0x00,0xfe,0x20,0xf8,0x20,0x20,0xfc,0x00,0xfe,0x40,0x42,0x42,0x3e,
+/* 22576 0x5830 "堰" */
+0x20,0x23,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x23,0x22,0x3a,0xe2,0x42,0x02,0x03,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 22577 0x5831 "報" */
+0x10,0x10,0x7c,0x10,0x10,0xfe,0x44,0x28,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x84,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0xa8,0xc4,0x82,
+/* 22578 0x5832 "堲" */
+0x7e,0x42,0x7e,0x42,0x7e,0x48,0x44,0x5a,0x62,0x40,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x7c,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22579 0x5833 "堳" */
+0x20,0x23,0x22,0x22,0x23,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe4,0x44,0x08,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 22580 0x5834 "場" */
+0x20,0x23,0x22,0x23,0x22,0xfb,0x20,0x2f,0x22,0x23,0x24,0x39,0xe2,0x44,0x01,0x02,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 22581 0x5835 "堵" */
+0x20,0x20,0x23,0x20,0xf8,0x27,0x20,0x20,0x21,0x2b,0x35,0x21,0xc1,0x01,0x01,0x01,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 22582 0x5836 "堶" */
+0x20,0x20,0x23,0x20,0x21,0xfa,0x25,0x20,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 22583 0x5837 "堷" */
+0x20,0x20,0x27,0x20,0x22,0xf9,0x2f,0x20,0x23,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x80,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 22584 0x5838 "堸" */
+0x20,0x2f,0x28,0x28,0xfb,0x28,0x28,0x2b,0x2a,0x2a,0x3b,0xe8,0x48,0x10,0x17,0x20,
+0x00,0xf8,0x08,0x68,0x88,0x88,0x88,0xe8,0xa8,0xa8,0xe8,0x8a,0xaa,0xea,0x26,0x02,
+/* 22585 0x5839 "堹" */
+0x10,0x10,0x11,0x10,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1c,0xe1,0x40,0x03,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 22586 0x583a "堺" */
+0x23,0x22,0x22,0x23,0x22,0xfa,0x23,0x20,0x21,0x22,0x25,0x39,0xe1,0x41,0x02,0x04,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,
+/* 22587 0x583b "堻" */
+0x20,0x13,0x90,0x4f,0x40,0x13,0x20,0xe3,0x20,0x2f,0x20,0x20,0x01,0x3f,0x01,0xff,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,0x00,0xf8,0x00,0xfe,
+/* 22588 0x583c "堼" */
+0x08,0x08,0x7e,0x08,0xfe,0x08,0x7e,0x08,0x0f,0xf0,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22589 0x583d "堽" */
+0x10,0x13,0x12,0x12,0x13,0xfc,0x10,0x13,0x10,0x10,0x11,0x1d,0xe1,0x41,0x07,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0x00,0xfe,0x20,0x20,0x3c,0x20,0x20,0x20,0xfe,0x00,
+/* 22590 0x583e "堾" */
+0x20,0x20,0x27,0x20,0x23,0xf8,0x27,0x21,0x22,0x27,0x3a,0xe2,0x43,0x02,0x02,0x03,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x10,0x08,0xfc,0x0a,0x08,0xf8,0x08,0x08,0xf8,
+/* 22591 0x583f "堿" */
+0x20,0x20,0x20,0x27,0x24,0xfc,0x25,0x24,0x24,0x25,0x25,0x3d,0xe5,0x44,0x08,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 22592 0x5840 "塀" */
+0x20,0x23,0x22,0x22,0x23,0xfa,0x22,0x22,0x22,0x22,0x22,0x3b,0xe4,0x44,0x08,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x84,0x48,0xfc,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 22593 0x5841 "塁" */
+0x3f,0x21,0x3f,0x21,0x3f,0x60,0x18,0x06,0x18,0x61,0x01,0x3f,0x01,0x01,0xff,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x0c,0x30,0xc0,0x30,0x0c,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22594 0x5842 "塂" */
+0x21,0x21,0x27,0x21,0xf1,0x2f,0x21,0x22,0x27,0x2a,0x32,0xe3,0x42,0x02,0x01,0x00,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0xf4,0x12,0x10,0xf0,0x04,0x04,0xfc,0x00,
+/* 22595 0x5843 "塃" */
+0x21,0x21,0x27,0x21,0xf8,0x27,0x22,0x22,0x23,0x20,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x08,0x08,0xfe,0x48,0x20,0xfe,0x00,0x00,0xfc,0x00,0x48,0x48,0x48,0x4a,0x4a,0x46,
+/* 22596 0x5844 "塄" */
+0x20,0x23,0x22,0x22,0x22,0xfb,0x20,0x20,0x27,0x20,0x20,0x38,0xe1,0x41,0x02,0x04,
+0x00,0xfc,0x94,0x94,0x94,0xfc,0x80,0x40,0xfe,0x80,0xf8,0x88,0x08,0x08,0x28,0x10,
+/* 22597 0x5845 "塅" */
+0x20,0x23,0x22,0x22,0x23,0xfa,0x22,0x22,0x23,0x22,0x22,0x3b,0xe6,0x42,0x02,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 22598 0x5846 "塆" */
+0x20,0x20,0x27,0x20,0xfa,0x24,0x20,0x23,0x20,0x23,0x22,0x3b,0xe0,0x40,0x00,0x00,
+0x80,0x40,0xfe,0x90,0x94,0x92,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 22599 0x5847 "塇" */
+0x10,0x10,0x13,0x12,0x14,0xfd,0x10,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 22600 0x5848 "塈" */
+0x00,0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22601 0x5849 "塉" */
+0x20,0x22,0x21,0x22,0x24,0xf9,0x26,0x23,0x22,0x23,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x40,0x48,0x50,0x48,0xa4,0x18,0x06,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 22602 0x584a "塊" */
+0x20,0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x23,0x20,0x20,0x38,0xe1,0x41,0x02,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 22603 0x584b "塋" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x81,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 22604 0x584c "塌" */
+0x20,0x23,0x22,0x23,0x22,0xfb,0x20,0x20,0x27,0x20,0x24,0x3a,0xe4,0x40,0x02,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 22605 0x584d "塍" */
+0x00,0x79,0x48,0x48,0x49,0x78,0x4b,0x48,0x49,0x7a,0x4c,0x49,0x48,0x48,0x4b,0x98,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 22606 0x584e "塎" */
+0x10,0x10,0x13,0x12,0x10,0xfc,0x11,0x10,0x10,0x11,0x12,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 22607 0x584f "塏" */
+0x10,0x11,0x11,0x11,0x11,0xfc,0x13,0x10,0x11,0x11,0x11,0x1d,0xe0,0x40,0x03,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 22608 0x5850 "塐" */
+0x10,0x10,0x13,0x10,0x11,0xfc,0x13,0x10,0x10,0x11,0x1c,0xe3,0x40,0x01,0x02,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 22609 0x5851 "塑" */
+0x22,0x14,0xff,0x08,0x49,0x49,0x7f,0x08,0x10,0x21,0x41,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x94,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22610 0x5852 "塒" */
+0x20,0x20,0x27,0x25,0x25,0xf5,0x25,0x27,0x25,0x25,0x25,0x35,0xe7,0x40,0x00,0x00,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 22611 0x5853 "塓" */
+0x10,0x13,0x12,0x10,0x11,0xfd,0x11,0x11,0x11,0x10,0x1c,0xe3,0x40,0x00,0x01,0x02,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 22612 0x5854 "塔" */
+0x21,0x21,0x27,0x21,0x20,0xf8,0x21,0x22,0x25,0x20,0x20,0x3b,0xe2,0x42,0x03,0x02,
+0x10,0x10,0xfc,0x10,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 22613 0x5855 "塕" */
+0x21,0x21,0x22,0x24,0x29,0xfb,0x20,0x20,0x27,0x20,0x24,0x3a,0xe4,0x40,0x02,0x01,
+0x20,0x10,0x08,0x86,0x10,0xf8,0x08,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 22614 0x5856 "塖" */
+0x20,0x23,0x20,0x27,0x21,0xf9,0x27,0x21,0x23,0x25,0x20,0x39,0xe2,0x44,0x08,0x00,
+0x38,0xc0,0x40,0xfc,0x50,0x54,0x58,0x54,0x54,0x4c,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 22615 0x5857 "塗" */
+0x20,0x10,0x91,0x42,0x4d,0x10,0x27,0xe0,0x22,0x24,0x29,0x20,0x01,0x3f,0x01,0xff,
+0x40,0xa0,0x10,0x08,0xf6,0x40,0xfc,0x40,0x48,0x44,0x42,0x80,0x00,0xf8,0x00,0xfe,
+/* 22616 0x5858 "塘" */
+0x20,0x20,0x27,0x24,0x25,0xfc,0x27,0x24,0x25,0x24,0x25,0x3d,0xe5,0x49,0x09,0x11,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 22617 0x5859 "塙" */
+0x10,0x10,0x13,0x10,0x11,0xfd,0x11,0x10,0x13,0x12,0x1e,0xe2,0x42,0x02,0x02,0x02,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 22618 0x585a "塚" */
+0x20,0x27,0x24,0x28,0x27,0xf8,0x21,0x22,0x26,0x21,0x3a,0xe4,0x41,0x02,0x0c,0x00,
+0x00,0xfe,0x02,0x04,0xfe,0x80,0x84,0x44,0xa8,0x30,0xf0,0xa8,0x28,0x24,0xa2,0x40,
+/* 22619 0x585b "塛" */
+0x20,0x27,0x20,0x20,0x27,0xfc,0x24,0x27,0x20,0x20,0x27,0x38,0xe1,0x42,0x0c,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 22620 0x585c "塜" */
+0x20,0x27,0x24,0x29,0x20,0xfb,0x20,0x21,0x26,0x20,0x39,0xe6,0x40,0x01,0x06,0x00,
+0x00,0xfe,0x02,0xf4,0x00,0xf8,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 22621 0x585d "塝" */
+0x20,0x20,0x23,0x21,0x20,0xfb,0x22,0x24,0x20,0x23,0x20,0x38,0xe0,0x41,0x01,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 22622 0x585e "塞" */
+0x02,0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x11,0x21,0xdf,0x01,0x01,0x7f,
+0x00,0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0x08,0xf6,0x00,0x00,0xfc,
+/* 22623 0x585f "塟" */
+0x08,0xff,0x08,0x00,0x7f,0x08,0x1f,0x62,0x14,0x18,0xe0,0x01,0x3f,0x01,0x01,0xff,
+0x20,0xfe,0x20,0x00,0xfc,0x40,0x48,0x50,0x62,0x42,0x3e,0x00,0xf8,0x00,0x00,0xfe,
+/* 22624 0x5860 "塠" */
+0x20,0x24,0x22,0x22,0xf8,0x20,0x2e,0x22,0x22,0x22,0x22,0x3a,0xe2,0x45,0x08,0x00,
+0x10,0x20,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 22625 0x5861 "塡" */
+0x11,0x11,0x11,0x10,0x10,0xfc,0x12,0x12,0x12,0x12,0x12,0x1e,0xe2,0x43,0x01,0x02,
+0x18,0xe2,0x02,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x08,0x04,
+/* 22626 0x5862 "塢" */
+0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x1c,0xe2,0x42,0x04,0x00,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 22627 0x5863 "塣" */
+0x20,0x13,0x92,0x42,0x4b,0x08,0x17,0xe0,0x23,0x20,0x27,0x01,0x3f,0x01,0x01,0xff,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xf8,0x00,0x00,0xfe,
+/* 22628 0x5864 "塤" */
+0x10,0x11,0x11,0x11,0x11,0xfc,0x13,0x12,0x13,0x12,0x13,0x1e,0xe3,0x40,0x01,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 22629 0x5865 "塥" */
+0x20,0x23,0x20,0x21,0x21,0xf9,0x21,0x20,0x23,0x22,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 22630 0x5866 "塦" */
+0x7c,0x45,0x48,0x51,0x49,0x45,0x45,0x55,0x48,0x43,0x40,0x01,0x3f,0x01,0x01,0xff,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,
+/* 22631 0x5867 "塧" */
+0x22,0x21,0x21,0x20,0x27,0xf8,0x21,0x22,0x24,0x23,0x22,0x3a,0xe2,0x42,0x0f,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 22632 0x5868 "塨" */
+0x20,0x20,0x23,0x20,0x20,0xf8,0x27,0x20,0x21,0x22,0x24,0x39,0xe1,0x42,0x01,0x00,
+0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x90,0x48,0x44,0x4a,0x54,0x4a,0x4a,0x40,0x80,
+/* 22633 0x5869 "塩" */
+0x21,0x21,0x21,0x22,0x25,0xf9,0x21,0x21,0x20,0x23,0x22,0x3a,0xe2,0x42,0x07,0x00,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 22634 0x586a "塪" */
+0x10,0x11,0x10,0x11,0x10,0xfc,0x10,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 22635 0x586b "填" */
+0x20,0x20,0x27,0x20,0x23,0xfa,0x23,0x22,0x23,0x22,0x23,0x3a,0xef,0x41,0x02,0x04,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 22636 0x586c "塬" */
+0x20,0x27,0x24,0x24,0x25,0xfd,0x25,0x25,0x25,0x25,0x3c,0xe4,0x49,0x0a,0x10,0x00,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 22637 0x586d "塭" */
+0x10,0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x13,0x12,0x1e,0xe2,0x42,0x07,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 22638 0x586e "塮" */
+0x20,0x21,0x23,0x22,0x23,0xfa,0x23,0x22,0x22,0x27,0x20,0x39,0xe2,0x44,0x01,0x00,
+0x84,0x04,0xc4,0x44,0xde,0x44,0xc4,0x64,0x54,0xd4,0xc4,0x44,0x44,0x44,0x54,0x88,
+/* 22639 0x586f "塯" */
+0x20,0x23,0x22,0x22,0x22,0xfa,0x23,0x20,0x23,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 22640 0x5870 "塰" */
+0x21,0x11,0x92,0x45,0x41,0x11,0x23,0xe1,0x22,0x23,0x20,0x01,0x3f,0x01,0x01,0xff,
+0x00,0xfc,0x00,0xf8,0x48,0x28,0xfe,0x48,0x28,0xfc,0x50,0x20,0xf8,0x00,0x00,0xfe,
+/* 22641 0x5871 "塱" */
+0x10,0x7e,0x42,0x7e,0x42,0x7e,0x48,0x44,0x5a,0x61,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x94,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22642 0x5872 "塲" */
+0x21,0x21,0x22,0x25,0x21,0xf9,0x21,0x21,0x20,0x27,0x21,0x3b,0xe4,0x41,0x02,0x00,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 22643 0x5873 "塳" */
+0x20,0x24,0x22,0x21,0x20,0xf8,0x26,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 22644 0x5874 "塴" */
+0x20,0x22,0x22,0x23,0x20,0xfb,0x22,0x22,0x23,0x22,0x22,0x3b,0xe2,0x42,0x05,0x08,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 22645 0x5875 "塵" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x28,0x2f,0x20,0x2f,0x40,0x7f,0x80,
+0x00,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x78,0x42,0x3e,0x80,0xf8,0x80,0xfe,0x00,
+/* 22646 0x5876 "塶" */
+0x20,0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x23,0x22,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 22647 0x5877 "塷" */
+0x20,0x20,0x20,0x20,0x20,0xfb,0x22,0x23,0x22,0x22,0x23,0x3a,0xe2,0x43,0x03,0x02,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x02,0x26,0x8a,0x52,0x26,0x52,0x8a,0x26,0xfe,0x02,
+/* 22648 0x5878 "塸" */
+0x20,0x23,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x03,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 22649 0x5879 "塹" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x01,0x3f,0x01,0x01,0xff,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0xf8,0x00,0x00,0xfe,
+/* 22650 0x587a "塺" */
+0x01,0x00,0x3f,0x22,0x22,0x2f,0x23,0x26,0x2a,0x20,0x20,0x2f,0x40,0x40,0x9f,0x00,
+0x00,0x80,0xfe,0x10,0x10,0xbc,0x18,0xb4,0x52,0x80,0x80,0xfc,0x80,0x80,0xfe,0x00,
+/* 22651 0x587b "塻" */
+0x10,0x10,0x13,0x10,0x10,0xfd,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 22652 0x587c "塼" */
+0x10,0x13,0x10,0x11,0x11,0xfd,0x11,0x11,0x10,0x13,0x1c,0xe3,0x41,0x00,0x00,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 22653 0x587d "塽" */
+0x20,0x20,0x27,0x20,0x25,0xfa,0x25,0x20,0x25,0x22,0x25,0x38,0xe0,0x41,0x02,0x0c,
+0x40,0x40,0xfc,0x40,0x54,0x48,0x54,0x40,0x54,0x48,0x54,0xa0,0xa0,0x10,0x08,0x06,
+/* 22654 0x587e "塾" */
+0x10,0xfe,0x00,0x7d,0x44,0x7c,0x00,0x7c,0x08,0xfe,0x11,0x52,0x21,0x3f,0x01,0xff,
+0x40,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0x00,0xf8,0x00,0xfe,
+/* 22655 0x587f "塿" */
+0x10,0x11,0x11,0x13,0x11,0xfd,0x10,0x11,0x11,0x11,0x1c,0xe3,0x40,0x01,0x00,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 22656 0x5880 "墀" */
+0x20,0x27,0x24,0x27,0x24,0xfc,0x24,0x24,0x25,0x24,0x3c,0xe5,0x44,0x0b,0x08,0x10,
+0x00,0xfc,0x04,0xfc,0x20,0xa8,0x70,0xa8,0x04,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,
+/* 22657 0x5881 "墁" */
+0x23,0x22,0x23,0x22,0x23,0xf8,0x27,0x24,0x24,0x27,0x20,0x3b,0xe1,0x40,0x03,0x0c,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 22658 0x5882 "墂" */
+0x10,0x13,0x10,0x11,0x11,0xfd,0x11,0x10,0x11,0x10,0x13,0x1c,0xe0,0x41,0x02,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 22659 0x5883 "境" */
+0x20,0x20,0x23,0x21,0xf8,0x27,0x20,0x23,0x22,0x23,0x22,0x3b,0xe1,0x41,0x02,0x0c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 22660 0x5884 "墄" */
+0x20,0x20,0x20,0x27,0x24,0xfc,0x24,0x24,0x27,0x24,0x3c,0xe5,0x4a,0x08,0x11,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 22661 0x5885 "墅" */
+0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x7c,0x04,0x28,0x10,0x7e,0x12,0x14,0x10,0x50,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22662 0x5886 "墆" */
+0x22,0x22,0x27,0x22,0xfa,0x24,0x28,0x27,0x24,0x20,0x23,0x3a,0xe2,0x42,0x02,0x00,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 22663 0x5887 "墇" */
+0x10,0x11,0x10,0x10,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22664 0x5888 "墈" */
+0x22,0x22,0x2f,0x22,0x23,0xf2,0x23,0x22,0x22,0x2f,0x24,0x35,0xe6,0x44,0x07,0x00,
+0x48,0x48,0xe8,0x48,0xde,0x4a,0xca,0x4a,0x4a,0xea,0x0a,0x4a,0x32,0x12,0xea,0x44,
+/* 22665 0x5889 "墉" */
+0x20,0x27,0x24,0x25,0xf4,0x27,0x24,0x25,0x24,0x25,0x35,0xe5,0x45,0x09,0x09,0x11,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 22666 0x588a "墊" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x08,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22667 0x588b "墋" */
+0x20,0x20,0x21,0x21,0x22,0xfb,0x20,0x21,0x26,0x20,0x23,0x38,0xe3,0x40,0x00,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 22668 0x588c "墌" */
+0x20,0x20,0x23,0x22,0x22,0xfa,0x23,0x22,0x22,0x22,0x3a,0xe2,0x45,0x05,0x0a,0x10,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 22669 0x588d "墍" */
+0x10,0x7e,0x42,0x7e,0x42,0x7e,0x00,0x40,0x7e,0x40,0x4c,0x71,0x01,0x3f,0x01,0xff,
+0x00,0xfc,0x10,0x90,0x90,0xfe,0x10,0x28,0x28,0x48,0x8a,0x06,0x00,0xf8,0x00,0xfe,
+/* 22670 0x588e "墎" */
+0x22,0x21,0x27,0x20,0x27,0xfc,0x27,0x20,0x27,0x20,0x21,0x39,0xe7,0x41,0x05,0x02,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 22671 0x588f "墏" */
+0x04,0x24,0x24,0x3d,0x04,0x05,0x7c,0x25,0x24,0x24,0x44,0x81,0x3f,0x01,0x01,0xff,
+0x20,0x7e,0x94,0x48,0x30,0xc8,0x08,0xfe,0x88,0x48,0x18,0x00,0xf8,0x00,0x00,0xfe,
+/* 22672 0x5890 "墐" */
+0x10,0x10,0x13,0x10,0x10,0xfc,0x11,0x11,0x11,0x10,0x13,0x1c,0xe1,0x40,0x03,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 22673 0x5891 "墑" */
+0x20,0x20,0x23,0x20,0x20,0xfb,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 22674 0x5892 "墒" */
+0x20,0x20,0x23,0x20,0x20,0xfb,0x22,0x22,0x23,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x52,0x8a,0x06,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 22675 0x5893 "墓" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x10,0x21,0xcf,0x01,0x01,0x3f,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0x08,0xe6,0x00,0x00,0xf8,
+/* 22676 0x5894 "墔" */
+0x10,0x12,0x13,0x10,0x10,0xfd,0x13,0x15,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 22677 0x5895 "墕" */
+0x20,0x27,0x20,0x22,0xf2,0x2f,0x21,0x21,0x22,0x23,0x30,0xe5,0x45,0x08,0x00,0x00,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 22678 0x5896 "墖" */
+0x20,0x20,0x21,0x22,0x2d,0xf0,0x23,0x22,0x23,0x20,0x27,0x34,0xe7,0x44,0x07,0x04,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 22679 0x5897 "増" */
+0x21,0x20,0x20,0x23,0x22,0xfb,0x22,0x22,0x23,0x20,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xfe,0x22,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 22680 0x5898 "墘" */
+0x21,0x21,0x21,0x2f,0xf1,0x27,0x24,0x27,0x24,0x27,0x31,0xef,0x41,0x01,0x01,0x01,
+0x10,0x10,0x10,0xde,0x20,0xc0,0x5c,0xc4,0x48,0xc8,0x10,0xd0,0x22,0x22,0x1e,0x00,
+/* 22681 0x5899 "墙" */
+0x20,0x20,0x27,0x20,0x22,0xf9,0x27,0x20,0x23,0x22,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x40,0x40,0xfc,0x40,0x48,0x50,0xfe,0x00,0xf8,0x08,0xe8,0xa8,0xe8,0x08,0xf8,0x08,
+/* 22682 0x589a "墚" */
+0x22,0x21,0x24,0x22,0x20,0xf9,0x22,0x20,0x20,0x27,0x20,0x39,0xe2,0x4c,0x00,0x00,
+0x78,0x28,0x6c,0xaa,0x2a,0x48,0x98,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 22683 0x589b "墛" */
+0x20,0x27,0x24,0x24,0x27,0xfc,0x25,0x24,0x24,0x27,0x3c,0xe4,0x4a,0x0a,0x14,0x01,
+0x04,0xc4,0x44,0x44,0xde,0x04,0xc4,0x04,0x14,0xec,0x84,0xc4,0xa4,0x84,0x94,0x88,
+/* 22684 0x589c "墜" */
+0x00,0x7c,0x45,0x48,0x50,0x4b,0x44,0x67,0x58,0x43,0x40,0x01,0x3f,0x01,0x01,0xff,
+0x88,0x50,0xfc,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,0x00,0xf8,0x00,0x00,0xfe,
+/* 22685 0x589d "墝" */
+0x20,0x20,0x21,0x20,0x23,0xf9,0x23,0x21,0x21,0x26,0x20,0x3b,0xe0,0x40,0x01,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 22686 0x589e "增" */
+0x22,0x21,0x20,0x27,0x24,0xfd,0x24,0x24,0x27,0x20,0x23,0x3a,0xe3,0x42,0x03,0x02,
+0x08,0x10,0x00,0xfc,0x44,0x54,0xe4,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 22687 0x589f "墟" */
+0x20,0x20,0x20,0x23,0x22,0xfa,0x23,0x22,0x22,0x22,0x22,0x3b,0xe4,0x44,0x09,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0x50,0x54,0x54,0xd8,0x50,0xfe,0x00,
+/* 22688 0x58a0 "墠" */
+0x10,0x13,0x12,0x12,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22689 0x58a1 "墡" */
+0x10,0x10,0x13,0x10,0x11,0xfc,0x13,0x11,0x10,0x13,0x10,0x1d,0xe1,0x41,0x01,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 22690 0x58a2 "墢" */
+0x20,0x23,0x20,0x25,0xf2,0x2c,0x27,0x20,0x27,0x24,0x37,0xe0,0x40,0x00,0x05,0x02,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x00,0xbc,0x84,0xa8,0x90,0x28,0x44,
+/* 22691 0x58a3 "墣" */
+0x20,0x24,0x22,0x20,0x27,0xf9,0x20,0x27,0x20,0x23,0x38,0xe7,0x40,0x01,0x02,0x0c,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 22692 0x58a4 "墤" */
+0x20,0x23,0x22,0x23,0xf8,0x27,0x20,0x23,0x22,0x23,0x22,0x3b,0xe2,0x43,0x01,0x02,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 22693 0x58a5 "墥" */
+0x10,0x11,0x10,0x10,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1c,0xe1,0x40,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 22694 0x58a6 "墦" */
+0x10,0x13,0x11,0x10,0x13,0xfc,0x11,0x12,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 22695 0x58a7 "墧" */
+0x20,0x23,0x20,0x27,0x21,0xfa,0x25,0x29,0x21,0x20,0x27,0x3c,0xe5,0x45,0x05,0x04,
+0x38,0xc0,0x80,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x0c,
+/* 22696 0x58a8 "墨" */
+0x00,0x3f,0x29,0x25,0x3f,0x01,0x3f,0x01,0xff,0x24,0x42,0x01,0x3f,0x01,0x01,0xff,
+0x00,0xf8,0x28,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x48,0x24,0x00,0xf8,0x00,0x00,0xfe,
+/* 22697 0x58a9 "墩" */
+0x22,0x21,0x2f,0x20,0x27,0xfc,0x27,0x20,0x27,0x20,0x21,0x39,0xef,0x41,0x05,0x02,
+0x10,0x10,0xd0,0x10,0xbe,0xa4,0xd4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 22698 0x58aa "墪" */
+0x08,0x7f,0x00,0x3e,0x23,0x3e,0x00,0x3e,0x04,0x7f,0x08,0x29,0x11,0x3f,0x01,0xff,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x50,0x20,0x50,0x88,0x04,0x00,0xf8,0x00,0xfe,
+/* 22699 0x58ab "墫" */
+0x21,0x20,0x27,0x20,0x23,0xfa,0x23,0x22,0x23,0x22,0x3b,0xe0,0x47,0x01,0x00,0x00,
+0x08,0x90,0xfe,0x90,0xfc,0x94,0x1c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x08,0xa8,0x10,
+/* 22700 0x58ac "墬" */
+0x00,0x3c,0x24,0x28,0x30,0x2b,0x24,0x25,0x34,0x29,0x20,0x21,0x01,0x3f,0x01,0xff,
+0x40,0x78,0x88,0xf0,0x10,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,0x00,0xf8,0x00,0xfe,
+/* 22701 0x58ad "墭" */
+0x20,0x20,0x23,0x22,0x22,0xfb,0x22,0x24,0x25,0x28,0x23,0x3a,0xe2,0x42,0x0f,0x00,
+0x28,0x24,0xfe,0x20,0x24,0xa4,0x98,0x90,0xaa,0x46,0xfa,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 22702 0x58ae "墮" */
+0x00,0x7b,0x48,0x51,0x62,0x55,0x48,0x48,0x68,0x50,0x40,0x41,0x3f,0x01,0x01,0xff,
+0x40,0xfc,0x80,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x88,0x00,0xf8,0x00,0x00,0xfe,
+/* 22703 0x58af "墯" */
+0x10,0x13,0x18,0x55,0x52,0x95,0x10,0x10,0x10,0x10,0x10,0x01,0x3f,0x01,0x01,0xff,
+0x40,0xfe,0x80,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x88,0x00,0xf8,0x00,0x00,0xfe,
+/* 22704 0x58b0 "墰" */
+0x20,0x23,0x20,0x23,0x22,0xfb,0x20,0x21,0x21,0x21,0x21,0x39,0xe0,0x43,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 22705 0x58b1 "墱" */
+0x20,0x27,0x20,0x22,0x21,0xfa,0x25,0x28,0x23,0x22,0x22,0x3b,0xe2,0x41,0x0f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 22706 0x58b2 "墲" */
+0x21,0x21,0x23,0x26,0x2a,0xf2,0x27,0x22,0x22,0x22,0x2f,0x30,0xe2,0x42,0x04,0x00,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 22707 0x58b3 "墳" */
+0x10,0x11,0x10,0x10,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x01,0x02,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 22708 0x58b4 "墴" */
+0x21,0x21,0x27,0x21,0x21,0xf7,0x20,0x27,0x24,0x27,0x24,0x37,0xe0,0x41,0x02,0x04,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x10,0x08,0x04,
+/* 22709 0x58b5 "墵" */
+0x10,0x11,0x10,0x13,0x12,0xfd,0x10,0x11,0x10,0x11,0x1c,0xe3,0x40,0x00,0x01,0x00,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x40,0x88,0xfc,0x84,
+/* 22710 0x58b6 "墶" */
+0x20,0x24,0x22,0x20,0x20,0xf8,0x26,0x22,0x22,0x22,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 22711 0x58b7 "墷" */
+0x10,0x13,0x10,0x10,0x11,0xfc,0x10,0x13,0x10,0x10,0x11,0x1c,0xe3,0x40,0x00,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 22712 0x58b8 "墸" */
+0x21,0x21,0x27,0x21,0x20,0xfb,0x20,0x20,0x27,0x20,0x21,0x3b,0xe5,0x49,0x01,0x01,
+0x08,0x08,0xfe,0x08,0x44,0xf4,0x48,0x50,0xfe,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 22713 0x58b9 "墹" */
+0x20,0x27,0x24,0x27,0x24,0xff,0x24,0x25,0x25,0x25,0x25,0x3d,0xe5,0x44,0x04,0x04,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x14,0x04,0x14,0x08,
+/* 22714 0x58ba "墺" */
+0x20,0x21,0x27,0x24,0x25,0xfc,0x27,0x24,0x25,0x24,0x38,0xe7,0x40,0x01,0x02,0x0c,
+0x80,0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x04,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 22715 0x58bb "墻" */
+0x20,0x20,0x27,0x22,0xfa,0x25,0x2f,0x20,0x23,0x22,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x40,0x40,0xfc,0x48,0x48,0x54,0xfe,0x00,0xf8,0x08,0xe8,0xa8,0xe8,0x08,0xf8,0x08,
+/* 22716 0x58bc "墼" */
+0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x49,0x7f,0x01,0x3f,0x01,0xff,
+0x00,0x78,0x48,0x48,0x86,0x00,0x78,0x48,0x28,0x90,0x28,0x44,0x00,0xf8,0x00,0xfe,
+/* 22717 0x58bd "墽" */
+0x22,0x24,0x2f,0x28,0x2f,0xf8,0x2f,0x24,0x22,0x2f,0x24,0x37,0xe4,0x48,0x0a,0x11,
+0x10,0x10,0x90,0x90,0xbe,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x88,0x88,0x94,0x94,0x22,
+/* 22718 0x58be "墾" */
+0x06,0xf8,0x4a,0x24,0x38,0xcc,0x36,0xca,0x12,0x6a,0x04,0x01,0x3f,0x01,0x01,0xff,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0xa2,0x94,0xa8,0xc4,0x82,0x00,0xf8,0x00,0x00,0xfe,
+/* 22719 0x58bf "墿" */
+0x20,0x27,0x24,0x27,0x20,0xfb,0x20,0x27,0x21,0x20,0x3b,0xe0,0x4f,0x00,0x00,0x00,
+0x00,0xfc,0xa4,0xfc,0x40,0xf8,0x40,0xfc,0x10,0xa0,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 22720 0x58c0 "壀" */
+0x20,0x20,0x27,0x24,0xf4,0x24,0x27,0x24,0x24,0x27,0x36,0xea,0x4a,0x0b,0x12,0x00,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0x7e,0x08,0x88,0xbe,0x88,0x88,0x88,0x88,0x08,
+/* 22721 0x58c1 "壁" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3d,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22722 0x58c2 "壂" */
+0x3f,0x21,0x3f,0x20,0x2a,0x3f,0x2a,0x3f,0x20,0x4a,0x91,0x20,0x01,0x3f,0x01,0xff,
+0x78,0x48,0x48,0x86,0x78,0x48,0x48,0x28,0x10,0x28,0x46,0x00,0x00,0xf8,0x00,0xfe,
+/* 22723 0x58c3 "壃" */
+0x10,0x13,0x10,0x11,0x11,0xfd,0x11,0x13,0x10,0x11,0x11,0x1d,0xe1,0x41,0x00,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 22724 0x58c4 "壄" */
+0x00,0x27,0x20,0xfa,0x21,0x77,0x6b,0xa5,0x29,0x25,0x22,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x88,0x88,0xbe,0x08,0xd8,0x5c,0x2a,0x48,0x08,0x08,0x00,0xf8,0x00,0x00,0xfe,
+/* 22725 0x58c5 "壅" */
+0x02,0x01,0xff,0x10,0x24,0x79,0x10,0x22,0x7c,0x08,0x30,0xc0,0x01,0x3f,0x01,0xff,
+0x00,0x00,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0x00,0xf8,0x00,0xfe,
+/* 22726 0x58c6 "壆" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x40,0x81,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 22727 0x58c7 "壇" */
+0x20,0x2f,0x20,0x27,0x24,0xfd,0x25,0x27,0x20,0x23,0x22,0x3b,0xe2,0x43,0x00,0x0f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 22728 0x58c8 "壈" */
+0x20,0x2f,0x20,0x27,0x24,0xfd,0x25,0x25,0x24,0x27,0x20,0x3b,0xe0,0x4f,0x01,0x0e,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 22729 0x58c9 "壉" */
+0x20,0x20,0x20,0x23,0x22,0xfa,0x23,0x22,0x22,0x23,0x22,0x3b,0xe2,0x45,0x04,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 22730 0x58ca "壊" */
+0x20,0x20,0x27,0x20,0x23,0xfa,0x22,0x23,0x20,0x20,0x27,0x38,0xe1,0x42,0x04,0x00,
+0x20,0x20,0xfe,0x20,0xfe,0x52,0x52,0xfe,0x40,0x20,0xfe,0xa4,0xa8,0x90,0x88,0xc6,
+/* 22731 0x58cb "壋" */
+0x20,0x22,0x21,0x27,0x24,0xf8,0x23,0x22,0x23,0x20,0x27,0x3c,0xe7,0x44,0x07,0x04,
+0x40,0x48,0x50,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 22732 0x58cc "壌" */
+0x20,0x20,0x27,0x21,0xfa,0x25,0x23,0x21,0x23,0x21,0x27,0x39,0xe3,0x4d,0x01,0x01,
+0x80,0x40,0xfe,0x10,0x08,0x14,0xf8,0x10,0xf8,0x10,0xfc,0x28,0x10,0x48,0x86,0x00,
+/* 22733 0x58cd "壍" */
+0x42,0x2f,0x82,0x4f,0x0a,0x2f,0x4a,0xcf,0x42,0x5f,0x42,0x02,0x01,0x3f,0x01,0xff,
+0x0c,0xb0,0x20,0xa0,0xbe,0xa8,0xa8,0xa8,0x28,0xa8,0x48,0x88,0x00,0xf8,0x00,0xfe,
+/* 22734 0x58ce "壎" */
+0x20,0x27,0x20,0x2f,0xf0,0x27,0x25,0x24,0x27,0x20,0x37,0xe0,0x4f,0x00,0x05,0x08,
+0x3c,0xc0,0x40,0xfe,0x40,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0x00,0x24,0x92,
+/* 22735 0x58cf "壏" */
+0x20,0x27,0x25,0x27,0xfc,0x27,0x25,0x27,0x20,0x23,0x22,0x3a,0xe2,0x42,0x0f,0x00,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 22736 0x58d0 "壐" */
+0x7f,0x11,0x21,0x7f,0xb5,0x29,0x35,0x21,0x35,0x29,0x34,0x20,0x01,0x3f,0x01,0xff,
+0xfc,0x10,0x08,0xfc,0x5a,0x28,0x58,0x08,0x58,0x28,0x58,0x18,0x00,0xf8,0x00,0xfe,
+/* 22737 0x58d1 "壑" */
+0x08,0x0f,0x08,0xff,0x80,0x7f,0x49,0x94,0x22,0x7f,0xa2,0x3e,0x01,0x3f,0x01,0xff,
+0x00,0x00,0x7c,0xa4,0xa4,0x24,0x24,0xa8,0x10,0x28,0x44,0x02,0x00,0xf8,0x00,0xfe,
+/* 22738 0x58d2 "壒" */
+0x21,0x27,0x21,0x20,0x23,0xf8,0x27,0x20,0x21,0x23,0x20,0x3b,0xe2,0x42,0x0f,0x00,
+0x10,0xfc,0x10,0x40,0xf8,0x40,0xfc,0x80,0x10,0xf8,0x00,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 22739 0x58d3 "壓" */
+0x00,0x3f,0x28,0x2f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x40,0x47,0x80,0x1f,
+0x00,0xfe,0x8c,0x8a,0x88,0xbe,0x08,0x88,0x88,0x94,0x94,0xa2,0x40,0xfc,0x40,0xfe,
+/* 22740 0x58d4 "壔" */
+0x20,0x27,0x20,0x23,0x20,0xf7,0x20,0x23,0x20,0x27,0x20,0x37,0xe0,0x47,0x04,0x07,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 22741 0x58d5 "壕" */
+0x20,0x27,0x20,0x21,0xf9,0x21,0x20,0x27,0x24,0x23,0x29,0x36,0xe1,0x46,0x01,0x0e,
+0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x80,0x44,0xb8,0x68,0xa6,0x60,
+/* 22742 0x58d6 "壖" */
+0x10,0x11,0x10,0x13,0x12,0xfd,0x10,0x11,0x10,0x13,0x10,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 22743 0x58d7 "壗" */
+0x20,0x23,0x20,0x27,0x20,0xfb,0x20,0x27,0x20,0x22,0x24,0x3b,0xe2,0x42,0x0f,0x00,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 22744 0x58d8 "壘" */
+0x00,0x1f,0x11,0x1f,0x11,0x1f,0x00,0x3e,0x2a,0x3e,0x2a,0x3e,0x01,0x3f,0x01,0xff,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xf8,0x00,0xfe,
+/* 22745 0x58d9 "壙" */
+0x20,0x20,0x27,0x24,0x25,0xfc,0x27,0x24,0x25,0x25,0x3d,0xe5,0x45,0x04,0x04,0x09,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 22746 0x58da "壚" */
+0x20,0x20,0x20,0x23,0x22,0xfb,0x22,0x22,0x22,0x22,0x22,0x3a,0xe2,0x45,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 22747 0x58db "壛" */
+0x27,0x24,0x27,0x24,0x27,0xfc,0x24,0x25,0x26,0x25,0x25,0x3d,0xe5,0x45,0x04,0x04,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x84,0xf4,0x14,0x24,0xb4,0x14,0xb4,0x14,0xf4,0x14,0x08,
+/* 22748 0x58dc "壜" */
+0x11,0x11,0x11,0x11,0x13,0xfc,0x13,0x12,0x11,0x10,0x11,0x1c,0xe3,0x40,0x00,0x01,
+0xfc,0x04,0xfc,0x04,0xfe,0x20,0xfe,0x22,0xac,0x20,0xfc,0x00,0xfe,0x40,0x88,0xfc,
+/* 22749 0x58dd "壝" */
+0x20,0x29,0x25,0x21,0xf8,0x23,0x2d,0x25,0x25,0x25,0x25,0x3d,0xe4,0x45,0x0b,0x10,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0xfe,0x00,
+/* 22750 0x58de "壞" */
+0x20,0x20,0x2f,0x20,0x27,0xfc,0x27,0x22,0x21,0x22,0x24,0x38,0xe1,0x43,0x0d,0x01,
+0x80,0x40,0xfe,0x00,0xfc,0xa4,0xfc,0x48,0x50,0x08,0x44,0xa8,0x10,0x08,0x46,0x80,
+/* 22751 0x58df "壟" */
+0x08,0x7e,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,0x01,0x3f,0x01,0xff,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,0x00,0xf8,0x00,0xfe,
+/* 22752 0x58e0 "壠" */
+0x22,0x21,0x27,0x20,0x24,0xfa,0x27,0x20,0x27,0x24,0x27,0x3c,0xe7,0x44,0x04,0x04,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 22753 0x58e1 "壡" */
+0x10,0x1f,0x10,0xff,0x80,0x7f,0x2a,0x55,0xa2,0x7f,0xa2,0x3e,0x22,0x3e,0x22,0x3e,
+0x00,0x7c,0x24,0xa4,0xa8,0x10,0x28,0x46,0x10,0x10,0xbc,0x10,0x10,0x10,0xfe,0x00,
+/* 22754 0x58e2 "壢" */
+0x20,0x27,0x24,0x25,0x24,0xf7,0x24,0x25,0x26,0x24,0x24,0x35,0xe5,0x49,0x09,0x17,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 22755 0x58e3 "壣" */
+0x40,0x5f,0x4a,0x4a,0x4e,0xea,0x4a,0x4e,0x4a,0x4a,0x6b,0x4e,0x9a,0x02,0x02,0x02,
+0x44,0x44,0xaa,0xee,0x44,0xaa,0xee,0x00,0x28,0xaa,0xaa,0xee,0x28,0x28,0x48,0x88,
+/* 22756 0x58e4 "壤" */
+0x20,0x27,0x20,0x23,0xf2,0x23,0x21,0x27,0x21,0x27,0x31,0xef,0x41,0x03,0x0d,0x01,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 22757 0x58e5 "壥" */
+0x27,0x24,0x25,0x25,0x25,0xfd,0x24,0x25,0x24,0x27,0x3c,0xe5,0x48,0x09,0x10,0x03,
+0xfe,0x00,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x20,0xfc,0x20,0xfe,
+/* 22758 0x58e6 "壦" */
+0x21,0x2f,0x21,0x27,0x24,0xf7,0x21,0x21,0x23,0x22,0x27,0x3a,0xe3,0x42,0x03,0x02,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 22759 0x58e7 "壧" */
+0x27,0x24,0x27,0x20,0x27,0xfc,0x25,0x24,0x27,0x25,0x25,0x3d,0xe5,0x45,0x0b,0x10,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 22760 0x58e8 "壨" */
+0x00,0x3e,0x2a,0x3e,0x2a,0x3e,0x00,0x3e,0x2a,0x3e,0x2a,0x3e,0x01,0x3f,0x01,0xff,
+0x00,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xf8,0x00,0xfe,
+/* 22761 0x58e9 "壩" */
+0x27,0x20,0x2f,0x28,0x23,0xf5,0x2f,0x25,0x27,0x22,0x2f,0x3a,0xef,0x42,0x1f,0x02,
+0xfc,0x40,0xfe,0x42,0x58,0x00,0xbc,0x24,0x24,0x3c,0xa4,0xa4,0xbc,0x24,0xa4,0x4c,
+/* 22762 0x58ea "壪" */
+0x24,0x28,0x2e,0x24,0xfa,0x2e,0x20,0x2a,0x20,0x23,0x20,0x3b,0xe2,0x43,0x00,0x00,
+0x44,0xe8,0x0e,0xe4,0x0a,0xee,0xa0,0xea,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x38,
+/* 22763 0x58eb "士" */
+0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,
+/* 22764 0x58ec "壬" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x00,
+0x10,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,
+/* 22765 0x58ed "壭" */
+0x01,0x01,0xff,0x01,0x01,0x7f,0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x00,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,0x00,
+/* 22766 0x58ee "壮" */
+0x08,0x08,0x08,0x48,0x28,0x28,0x0b,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x09,0x08,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 22767 0x58ef "壯" */
+0x04,0x24,0x24,0x24,0x24,0x3c,0x07,0x04,0xfc,0x24,0x24,0x24,0x24,0x45,0x44,0x84,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,0x00,
+/* 22768 0x58f0 "声" */
+0x01,0x01,0xff,0x01,0x7f,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0x00,0xfe,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 22769 0x58f1 "壱" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x00,0x7f,0x40,0x80,0x10,0x10,0x1f,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0xfe,0x02,0x04,0x10,0xe0,0x08,0x08,0x08,0xf8,
+/* 22770 0x58f2 "売" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x00,0x7f,0x40,0x84,0x04,0x04,0x04,0x08,0x10,0x20,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0xfe,0x02,0x44,0x40,0x40,0x40,0x44,0x44,0x3c,
+/* 22771 0x58f3 "壳" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x00,0x7f,0x40,0x80,0x0f,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0xfe,0x02,0x04,0xe0,0x20,0x20,0x22,0x22,0x1e,
+/* 22772 0x58f4 "壴" */
+0x01,0x01,0xff,0x01,0x01,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x00,0x08,0x04,0xff,0x00,
+0x00,0x00,0xfe,0x00,0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x00,0x20,0x40,0xfe,0x00,
+/* 22773 0x58f5 "壵" */
+0x01,0x01,0x7f,0x01,0x01,0x01,0x3f,0x00,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x00,
+/* 22774 0x58f6 "壶" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x00,0x7f,0x40,0x84,0x04,0x24,0x14,0x14,0x04,0x7f,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0xfe,0x02,0x44,0x40,0x48,0x48,0x50,0x40,0xfc,
+/* 22775 0x58f7 "壷" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x7f,0x44,0x84,0x3f,0x24,0x24,0x3f,0x04,0x04,0xff,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x42,0x44,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfe,
+/* 22776 0x58f8 "壸" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x7f,0x40,0xbf,0x04,0x24,0x14,0x14,0x04,0xff,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x02,0xfc,0x40,0x48,0x48,0x50,0x40,0xfe,0x00,
+/* 22777 0x58f9 "壹" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x7f,0x40,0x9f,0x00,0x1f,0x10,0x1f,0x08,0x04,0xff,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x02,0xf4,0x00,0xf0,0x10,0xf0,0x20,0x40,0xfe,
+/* 22778 0x58fa "壺" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x7f,0x44,0x84,0x3c,0x20,0x3c,0x04,0x04,0xff,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x42,0x44,0x78,0x08,0x78,0x40,0x40,0xfe,0x00,
+/* 22779 0x58fb "壻" */
+0x10,0x13,0x10,0x11,0x11,0xfd,0x12,0x14,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 22780 0x58fc "壼" */
+0x01,0x01,0x7f,0x01,0x1f,0x00,0x7f,0x40,0xbf,0x04,0x3c,0x20,0x3c,0x04,0xff,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x02,0xfc,0x40,0x78,0x08,0x78,0x40,0xfe,0x00,
+/* 22781 0x58fd "壽" */
+0x01,0x7f,0x01,0x3f,0x00,0xff,0x00,0x3f,0x01,0xff,0x00,0x7f,0x00,0x7d,0x44,0x7c,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x02,0xf0,0x00,0xfe,0x00,0xfc,0x10,0xfc,0x90,0x30,
+/* 22782 0x58fe "壾" */
+0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,0x40,
+0x00,0x7e,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x7c,0x40,0x40,0x40,0x7e,0x00,
+/* 22783 0x58ff "壿" */
+0x10,0x10,0x13,0x10,0x11,0xff,0x11,0x11,0x11,0x11,0x1c,0x73,0x21,0x00,0x00,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 22784 0x5900 "夀" */
+0x01,0x3f,0x01,0x1f,0x01,0x7f,0x01,0x1f,0x11,0x1f,0x01,0xff,0x00,0x3e,0x22,0x3e,
+0x00,0xf8,0x00,0xf0,0x00,0xfc,0x04,0xf0,0x10,0xf0,0x00,0xfe,0x08,0xfe,0x48,0x18,
+/* 22785 0x5901 "夁" */
+0x01,0xff,0x01,0x3f,0x00,0x7f,0x44,0x7f,0x00,0x3f,0x21,0x2f,0x21,0x27,0x24,0x3f,
+0x00,0xfe,0x00,0xf8,0x00,0xfc,0x44,0xfc,0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0xf8,
+/* 22786 0x5902 "夂" */
+0x04,0x04,0x04,0x0f,0x08,0x10,0x30,0x48,0x84,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 22787 0x5903 "夃" */
+0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x04,0x0b,0x08,0x09,0x10,0x11,0x22,0x4c,0x80,
+0x00,0xf0,0x10,0x20,0x20,0x40,0x7c,0x04,0xe4,0x24,0x44,0x84,0x44,0x24,0x28,0x10,
+/* 22788 0x5904 "处" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x94,0x14,0x08,0x08,0x14,0x23,0x40,0x80,
+0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 22789 0x5905 "夅" */
+0x04,0x04,0x0f,0x18,0x64,0x03,0x1c,0xe1,0x01,0x1f,0x01,0x21,0x3f,0x01,0x01,0x01,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0x00,0xf0,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 22790 0x5906 "夆" */
+0x04,0x04,0x0f,0x18,0x64,0x03,0x1c,0xe1,0x1f,0x01,0x1f,0x01,0x7f,0x01,0x01,0x01,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x00,0xf0,0x00,0xfc,0x00,0x00,0x00,
+/* 22791 0x5907 "备" */
+0x04,0x04,0x0f,0x18,0x64,0x03,0x1c,0xe0,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x10,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 22792 0x5908 "夈" */
+0x04,0x04,0x0f,0x18,0x64,0x03,0x1c,0xe1,0x11,0x09,0x7f,0x05,0x09,0x11,0x61,0x01,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0x10,0x20,0xfc,0x40,0x20,0x10,0x08,0x00,
+/* 22793 0x5909 "変" */
+0x01,0x01,0xff,0x04,0x14,0x24,0x48,0x14,0x27,0x08,0x14,0x22,0x41,0x06,0x18,0xe0,
+0x00,0x00,0xfe,0x40,0x50,0x48,0xc4,0x00,0xf0,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 22794 0x590a "夊" */
+0x04,0x04,0x04,0x2f,0x28,0x10,0x30,0x48,0x84,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 22795 0x590b "夋" */
+0x04,0x08,0x10,0x3f,0x00,0x08,0x12,0x22,0x47,0x08,0x14,0x22,0x01,0x06,0x18,0xe0,
+0x00,0x20,0x10,0xf8,0x08,0x20,0x10,0x08,0xe4,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 22796 0x590c "夌" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x12,0x22,0x47,0x88,0x14,0x22,0x01,0x06,0x18,0xe0,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x10,0x08,0xe4,0x22,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 22797 0x590d "复" */
+0x10,0x10,0x1f,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x04,0x0f,0x18,0x64,0x03,0x1c,0xe0,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 22798 0x590e "夎" */
+0x01,0x11,0x11,0x29,0x45,0x3f,0x01,0x01,0xff,0x08,0x0f,0x14,0x22,0x41,0x0e,0x70,
+0x00,0x10,0x10,0x28,0x44,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x20,0x40,0x80,0x60,0x1c,
+/* 22799 0x590f "夏" */
+0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe0,
+0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 22800 0x5910 "夐" */
+0x10,0x1f,0x20,0x7f,0xa3,0x24,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x28,0x07,0xf8,
+0x00,0xe0,0x20,0xf8,0x08,0x88,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x20,0xc0,0x3e,
+/* 22801 0x5911 "夑" */
+0x21,0x27,0x20,0x6b,0xb0,0x23,0x20,0x53,0x4a,0x8b,0x04,0x0f,0x14,0x03,0x1c,0xe0,
+0x08,0xc8,0x08,0x9a,0x2c,0x88,0x08,0x94,0x92,0xa2,0x00,0xe0,0x40,0x80,0x70,0x0e,
+/* 22802 0x5912 "夒" */
+0x00,0xff,0x11,0x13,0x52,0x5b,0x52,0x53,0x5a,0xe3,0x24,0x4f,0x94,0x03,0x1c,0xe0,
+0x00,0xfe,0x00,0xdc,0x54,0xd4,0x5c,0xd0,0x52,0xce,0x08,0xe4,0x42,0x80,0x70,0x0e,
+/* 22803 0x5913 "夓" */
+0x17,0x62,0x47,0x44,0x77,0x44,0x47,0x74,0x47,0x00,0x24,0x4f,0x94,0x03,0x1c,0xe0,
+0xc0,0x1c,0xc4,0x44,0xdc,0x44,0xc4,0x5c,0xc4,0x00,0x08,0xe4,0x42,0x80,0x70,0x0e,
+/* 22804 0x5914 "夔" */
+0x04,0xff,0x11,0x13,0x52,0x5b,0x52,0x53,0x5a,0xe3,0x24,0x4f,0x94,0x03,0x1c,0xe0,
+0x40,0xfe,0x00,0xdc,0x54,0xd4,0x5c,0xd0,0x52,0xce,0x08,0xe4,0x42,0x80,0x70,0x0e,
+/* 22805 0x5915 "夕" */
+0x02,0x02,0x02,0x02,0x07,0x04,0x08,0x10,0x24,0x42,0x01,0x00,0x01,0x02,0x0c,0x70,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 22806 0x5916 "外" */
+0x10,0x10,0x10,0x10,0x3e,0x22,0x42,0x42,0xa4,0x14,0x08,0x08,0x10,0x20,0x40,0x80,
+0x40,0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 22807 0x5917 "夗" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x8a,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xa8,0x90,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 22808 0x5918 "夘" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x8a,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 22809 0x5919 "夙" */
+0x00,0x3f,0x20,0x20,0x2f,0x22,0x22,0x27,0x24,0x28,0x34,0x22,0x21,0x42,0x44,0x88,
+0x00,0xf8,0x08,0x08,0xe8,0x08,0x08,0xc8,0x48,0x48,0x88,0x8a,0x0a,0x0a,0x06,0x02,
+/* 22810 0x591a "多" */
+0x02,0x02,0x07,0x08,0x38,0x04,0x03,0x0c,0x71,0x02,0x0c,0x32,0x01,0x01,0x0e,0x70,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x40,0x80,0xf8,0x08,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 22811 0x591b "夛" */
+0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0xff,0x02,0x07,0x08,0x34,0x02,0x01,0x0e,0x70,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 22812 0x591c "夜" */
+0x02,0x01,0xff,0x08,0x08,0x10,0x11,0x31,0x52,0x95,0x11,0x10,0x10,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x80,0x80,0xf8,0x08,0x48,0x28,0x10,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 22813 0x591d "夝" */
+0x20,0x20,0x21,0x3d,0x25,0x45,0x46,0xa4,0x14,0x09,0x08,0x10,0x10,0x20,0x43,0x80,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22814 0x591e "夞" */
+0x10,0x10,0x3f,0x41,0xa2,0x14,0x08,0x30,0xc0,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x20,0x20,0x30,0x28,0x24,0x22,0x20,0x20,0x20,0x00,0x44,0x58,0x60,0x42,0x42,0x3e,
+/* 22815 0x591f "够" */
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x14,0x08,
+0x20,0x20,0x7c,0x44,0xa8,0x10,0x20,0xd0,0x1e,0x22,0x64,0x94,0x08,0x10,0x20,0xc0,
+/* 22816 0x5920 "夠" */
+0x10,0x10,0x3e,0x42,0xa4,0x19,0x10,0x28,0xcf,0x11,0x32,0x4a,0x04,0x08,0x30,0xc0,
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x14,0x08,
+/* 22817 0x5921 "夡" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x28,0xcf,0x11,0x32,0x4a,0x04,0x08,0x30,0xc0,
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 22818 0x5922 "夢" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x00,0x7f,0x42,0x87,0x08,0x34,0x02,0x01,0x0e,0x70,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xfe,0x02,0xf4,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 22819 0x5923 "夣" */
+0x01,0xff,0x10,0x3f,0x00,0x3f,0x24,0x3f,0x00,0x7f,0x44,0x8f,0x34,0x02,0x07,0x78,
+0x00,0xfe,0x10,0xf8,0x00,0xf8,0x48,0xf8,0x00,0xfe,0x02,0xf4,0x20,0xc0,0x00,0x00,
+/* 22820 0x5924 "夤" */
+0x02,0x0f,0x34,0x03,0x1d,0x7f,0x40,0xbf,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x10,0x20,
+0x00,0xf0,0x60,0x80,0x00,0xfe,0x02,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 22821 0x5925 "夥" */
+0x00,0x7e,0x4a,0x4a,0x7e,0x4a,0x4a,0x7e,0x08,0xff,0x18,0x2c,0x2a,0x4a,0x88,0x08,
+0x20,0x20,0x7c,0x44,0xa8,0x10,0x20,0xd0,0x1e,0x22,0x64,0x94,0x08,0x10,0x20,0xc0,
+/* 22822 0x5926 "夦" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x00,
+0x20,0x20,0x7c,0x44,0xa8,0x10,0x20,0xd0,0x1e,0x22,0x64,0x94,0x08,0x10,0x20,0xc0,
+/* 22823 0x5927 "大" */
+0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 22824 0x5928 "夨" */
+0x10,0x10,0x10,0x20,0x20,0x7f,0x00,0x01,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 22825 0x5929 "天" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 22826 0x592a "太" */
+0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x02,0x02,0x04,0x04,0x0a,0x11,0x21,0xc0,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 22827 0x592b "夫" */
+0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 22828 0x592c "夬" */
+0x01,0x01,0x01,0x1f,0x01,0x01,0x01,0x01,0x01,0xff,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfe,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 22829 0x592d "夭" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0xc0,
+0x10,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 22830 0x592e "央" */
+0x01,0x01,0x01,0x1f,0x11,0x11,0x11,0x11,0x11,0xff,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfe,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 22831 0x592f "夯" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc1,0x01,0x3f,0x02,0x02,0x04,0x08,0x10,0x60,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 22832 0x5930 "夰" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc4,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x46,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 22833 0x5931 "失" */
+0x01,0x11,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x01,0x02,0x02,0x04,0x08,0x10,0x60,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x80,0x80,0x40,0x20,0x10,0x0c,
+/* 22834 0x5932 "夲" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x31,0xc1,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 22835 0x5933 "夳" */
+0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x10,0x20,0xcf,0x00,0x00,0x00,0x00,0x7f,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0xe6,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 22836 0x5934 "头" */
+0x00,0x00,0x08,0x04,0x24,0x10,0x10,0x00,0xff,0x01,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfe,0x00,0x40,0x20,0x10,0x08,0x04,0x04,
+/* 22837 0x5935 "夵" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc1,0x01,0x09,0x09,0x11,0x21,0x41,0x05,0x02,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,
+/* 22838 0x5936 "夶" */
+0x08,0x08,0x08,0x08,0x08,0x7e,0x08,0x08,0x08,0x14,0x12,0x12,0x20,0x21,0x42,0x84,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x04,0x02,
+/* 22839 0x5937 "夷" */
+0x01,0x01,0xff,0x01,0x3f,0x01,0x01,0x3f,0x21,0x21,0x3f,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x84,0x4c,0x20,0x18,0x06,
+/* 22840 0x5938 "夸" */
+0x01,0x01,0x7f,0x04,0x08,0x17,0x20,0xc0,0x3f,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x40,0x20,0xd0,0x08,0x06,0xf8,0x00,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 22841 0x5939 "夹" */
+0x01,0x01,0x01,0x7f,0x01,0x11,0x09,0x01,0xff,0x01,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x20,0x00,0xfe,0x00,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 22842 0x593a "夺" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,0x00,0xff,0x00,0x10,0x08,0x08,0x01,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x46,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 22843 0x593b "夻" */
+0x01,0x01,0x7f,0x01,0x02,0x04,0x08,0x30,0xc0,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x00,0x80,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 22844 0x593c "夼" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc9,0x09,0x09,0x09,0x09,0x11,0x11,0x21,0x40,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x26,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 22845 0x593d "夽" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xcf,0x00,0x00,0x7f,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x00,0xfc,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 22846 0x593e "夾" */
+0x01,0x01,0x01,0x7f,0x01,0x11,0x11,0x11,0x29,0x45,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x10,0x28,0x44,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 22847 0x593f "夿" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xdf,0x11,0x11,0x11,0x1f,0x10,0x10,0x0f,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0xf6,0x10,0x10,0x10,0xf0,0x04,0x04,0xfc,0x00,
+/* 22848 0x5940 "奀" */
+0x00,0x7f,0x01,0x03,0x05,0x19,0x61,0x00,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xfc,0x00,0x00,0x60,0x18,0x04,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22849 0x5941 "奁" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xdf,0x10,0x12,0x11,0x10,0x11,0x12,0x10,0x1f,0x00,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0xf8,0x00,
+/* 22850 0x5942 "奂" */
+0x08,0x08,0x0f,0x10,0x20,0x5f,0x91,0x11,0x11,0x11,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xe0,0x20,0x40,0xf0,0x10,0x10,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22851 0x5943 "奃" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc0,0x3f,0x21,0x21,0x3f,0x20,0x20,0x2a,0x31,0x21,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x00,0x00,0x00,0xfc,0x80,0x40,0x24,0x14,0x0c,
+/* 22852 0x5944 "奄" */
+0x02,0x02,0x7f,0x04,0x09,0x31,0xdf,0x11,0x11,0x1f,0x11,0x11,0x1f,0x01,0x01,0x00,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf4,0x04,0x04,0xfc,
+/* 22853 0x5945 "奅" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc6,0x38,0x20,0x22,0x22,0x2e,0x32,0x24,0x04,0x08,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0xf8,0x88,0x88,0x88,0x88,0xa8,0x90,0x80,0x80,
+/* 22854 0x5946 "奆" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xdf,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x00,0x00,0xe0,0x20,0x20,0xe0,0x00,0x00,0xf8,
+/* 22855 0x5947 "奇" */
+0x01,0x01,0x3f,0x02,0x04,0x08,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x80,0x40,0x20,0xfe,0x10,0x10,0x90,0x90,0x90,0x90,0x10,0x50,0x20,
+/* 22856 0x5948 "奈" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xcf,0x00,0x00,0x7f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x00,0xfc,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 22857 0x5949 "奉" */
+0x01,0x01,0x7f,0x01,0x3f,0x02,0xff,0x04,0x09,0x31,0xcf,0x01,0x01,0x3f,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x18,0xe6,0x00,0x00,0xf8,0x00,0x00,
+/* 22858 0x594a "奊" */
+0x00,0x0f,0x40,0x5f,0x40,0x4f,0x40,0x5f,0x40,0x7f,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x80,0xf8,0x80,0xfc,0x80,0xf8,0x80,0xfc,0x00,0x00,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22859 0x594b "奋" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x10,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 22860 0x594c "奌" */
+0x01,0x01,0x01,0x01,0x01,0x1f,0x10,0x10,0x1f,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22861 0x594d "奍" */
+0x01,0x11,0x09,0x3f,0x02,0x02,0x7f,0x08,0x10,0x24,0xc4,0x04,0x08,0x08,0x10,0x20,
+0x00,0x10,0x20,0xf8,0x00,0x00,0xfc,0x20,0x10,0x48,0x46,0x40,0x40,0x40,0x40,0x40,
+/* 22862 0x594e "奎" */
+0x02,0x02,0x7f,0x04,0x09,0x31,0xcf,0x01,0x01,0x7f,0x00,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 22863 0x594f "奏" */
+0x01,0x01,0x7f,0x01,0x3f,0x02,0xff,0x04,0x08,0x37,0xc1,0x1f,0x01,0x02,0x0c,0x30,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0xd8,0x06,0xf0,0x00,0xc0,0x30,0x08,
+/* 22864 0x5950 "奐" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x22,0x24,0x28,0x21,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x88,0x48,0x28,0x08,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 22865 0x5951 "契" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x09,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x7c,0x24,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22866 0x5952 "奒" */
+0x02,0x02,0x7f,0x04,0x0a,0x31,0xdf,0x04,0x08,0x1f,0x01,0x06,0x38,0x01,0x0e,0x70,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x00,0x40,0x80,0x10,0x20,0x40,0xa0,0x10,0x08,
+/* 22867 0x5953 "奓" */
+0x02,0x02,0x7f,0x04,0x08,0x32,0xc7,0x18,0x05,0x06,0x39,0x06,0x19,0x00,0x03,0x3c,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x40,0x80,0x80,0xf8,0x10,0x20,0xc0,0x00,0x00,
+/* 22868 0x5954 "奔" */
+0x02,0x02,0x7f,0x04,0x09,0x31,0xcf,0x01,0x09,0x08,0x7f,0x08,0x08,0x10,0x10,0x20,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 22869 0x5955 "奕" */
+0x02,0x01,0x7f,0x04,0x24,0x44,0x89,0x10,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22870 0x5956 "奖" */
+0x08,0x48,0x28,0x09,0x1a,0x28,0x48,0x88,0x09,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22871 0x5957 "套" */
+0x01,0x01,0x7f,0x02,0x04,0x0f,0x34,0xc7,0x04,0x07,0x04,0xff,0x04,0x08,0x1f,0x00,
+0x00,0x00,0xfc,0x80,0x40,0xf0,0x18,0xe6,0x00,0xe0,0x00,0xfe,0x00,0x10,0xf8,0x08,
+/* 22872 0x5958 "奘" */
+0x24,0x24,0x24,0x3d,0x04,0xfc,0x24,0x24,0x45,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22873 0x5959 "奙" */
+0x04,0x08,0x1f,0x02,0xff,0x08,0x31,0xdf,0x11,0x1f,0x11,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x20,0xf0,0x10,0xfe,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf4,0x04,0x04,0xfc,0x00,
+/* 22874 0x595a "奚" */
+0x00,0x7f,0x22,0x15,0x08,0x1f,0x03,0x0c,0x3f,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0xfc,0x00,0x08,0x10,0x40,0x80,0x20,0x10,0xf8,0x08,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22875 0x595b "奛" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc0,0x3c,0x24,0x3c,0x24,0x24,0x3c,0x24,0x01,0x02,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x88,0x28,0x10,
+/* 22876 0x595c "奜" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x05,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22877 0x595d "奝" */
+0x02,0x02,0x7f,0x04,0x08,0x3f,0xd1,0x17,0x11,0x1f,0x10,0x17,0x24,0x27,0x40,0x80,
+0x00,0x00,0xfc,0x40,0x20,0xf8,0x16,0xd0,0x10,0xf0,0x10,0xd0,0x50,0xd0,0x10,0x30,
+/* 22878 0x595e "奞" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc9,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 22879 0x595f "奟" */
+0x02,0x02,0x7f,0x04,0x08,0x3e,0xd2,0x12,0x1e,0x12,0x12,0x1e,0x12,0x22,0x2a,0x45,
+0x00,0x00,0xfc,0x40,0x20,0x78,0x4e,0x48,0x78,0x48,0x48,0x78,0x48,0x88,0xa8,0x10,
+/* 22880 0x5960 "奠" */
+0x08,0x04,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x20,0x40,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22881 0x5961 "奡" */
+0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x02,0xff,0x08,0x34,0xc4,0x08,0x10,
+0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x58,0x46,0x40,0x40,
+/* 22882 0x5962 "奢" */
+0x02,0x02,0x7f,0x04,0x08,0x32,0xdf,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,0x08,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xd6,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 22883 0x5963 "奣" */
+0x00,0x3f,0x02,0x7f,0x04,0x18,0xe0,0x3c,0x24,0x24,0x3c,0x24,0x24,0x3c,0x01,0x02,
+0x00,0xf8,0x00,0xfc,0x40,0x30,0x0e,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x88,0x28,0x10,
+/* 22884 0x5964 "奤" */
+0x02,0x02,0x7f,0x04,0x08,0x3f,0xc1,0x02,0x3f,0x24,0x27,0x24,0x27,0x24,0x3f,0x20,
+0x00,0x00,0xfc,0x40,0x20,0xf8,0x06,0x00,0xf8,0x48,0xc8,0x48,0xc8,0x48,0xf8,0x08,
+/* 22885 0x5965 "奥" */
+0x02,0x04,0x3f,0x20,0x29,0x25,0x2f,0x25,0x29,0x20,0x01,0xff,0x02,0x0c,0x30,0xc0,
+0x00,0x00,0xf8,0x08,0x28,0x48,0xe8,0x48,0x28,0x08,0x00,0xfe,0x80,0x60,0x18,0x06,
+/* 22886 0x5966 "奦" */
+0x00,0x7e,0x15,0x08,0xfe,0x1a,0x2c,0x48,0xa8,0x11,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x40,0xfc,0x44,0x38,0x44,0xa2,0xfc,0x44,0x94,0x08,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22887 0x5967 "奧" */
+0x02,0x04,0x3f,0x20,0x2f,0x25,0x2f,0x23,0x25,0x28,0x01,0x7f,0x02,0x0c,0x30,0xc0,
+0x00,0x00,0xf8,0x68,0xa8,0x48,0xe8,0x48,0x28,0x08,0x00,0xfc,0x80,0x60,0x18,0x06,
+/* 22888 0x5968 "奨" */
+0x08,0x4b,0x2a,0x29,0x08,0x1b,0x29,0xc8,0x08,0x09,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x3e,0xc4,0x48,0x20,0x08,0xfe,0x08,0x88,0x28,0x10,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22889 0x5969 "奩" */
+0x02,0x7f,0x04,0x18,0xe0,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x29,0x2f,0x20,0x3f,
+0x00,0xfc,0x20,0x18,0x06,0xf8,0x00,0xf0,0x10,0xf0,0x00,0x78,0x48,0x78,0x00,0xfc,
+/* 22890 0x596a "奪" */
+0x02,0x7f,0x04,0x18,0xe8,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x04,
+0x00,0xfc,0x20,0x98,0x46,0xf8,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x20,0xfe,0x20,0x60,
+/* 22891 0x596b "奫" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc1,0x25,0x17,0x84,0x47,0x14,0x27,0xe5,0x25,0x28,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x46,0x48,0x78,0x08,0xf8,0x08,0x78,0x48,0x48,0x08,
+/* 22892 0x596c "奬" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x85,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 22893 0x596d "奭" */
+0x01,0x01,0xff,0x01,0x7d,0x11,0x7d,0x45,0x7d,0x45,0x7d,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x00,0x7c,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x80,0x40,0x20,0x18,0x06,
+/* 22894 0x596e "奮" */
+0x02,0x7f,0x04,0x18,0xe9,0x1f,0x31,0x5f,0x91,0x1f,0x10,0x3f,0x21,0x3f,0x21,0x3f,
+0x00,0xfc,0x20,0x18,0x06,0xf8,0x00,0xf8,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 22895 0x596f "奯" */
+0x02,0x7f,0x04,0x19,0xe9,0x09,0x7f,0x00,0x3f,0x20,0x2f,0x22,0x2a,0x53,0x46,0x98,
+0x00,0xfc,0x20,0x18,0xe6,0x00,0xfc,0x28,0xfe,0x20,0xa4,0x28,0x90,0x2a,0x46,0x82,
+/* 22896 0x5970 "奰" */
+0x00,0x3f,0x24,0x3f,0x00,0xfe,0xaa,0xaa,0xfe,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x00,0xf8,0x48,0xf8,0x00,0xfe,0xaa,0xaa,0xfe,0x00,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22897 0x5971 "奱" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 22898 0x5972 "奲" */
+0x10,0x10,0xfe,0x28,0x44,0x90,0x7a,0x14,0xfe,0x10,0x7c,0xc4,0x7d,0x44,0x7c,0x44,
+0x00,0xee,0xaa,0xaa,0xee,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x10,0x10,0x10,
+/* 22899 0x5973 "女" */
+0x02,0x02,0x02,0x02,0x04,0xff,0x04,0x08,0x08,0x10,0x18,0x06,0x01,0x06,0x18,0x60,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x20,0x20,0x20,0x40,0x40,0x80,0x80,0x60,0x10,0x08,
+/* 22900 0x5974 "奴" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x81,0x02,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 22901 0x5975 "奵" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22902 0x5976 "奶" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x29,0x11,0x29,0x46,0x82,0x04,
+0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 22903 0x5977 "奷" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 22904 0x5978 "奸" */
+0x10,0x11,0x10,0x10,0xfe,0x22,0x22,0x23,0x42,0x24,0x14,0x08,0x14,0x22,0x42,0x80,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 22905 0x5979 "她" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x27,0x25,0x49,0x29,0x11,0x29,0x45,0x84,0x00,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 22906 0x597a "奺" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x26,0x24,0x48,0x28,0x10,0x28,0x45,0x82,0x04,
+0x80,0x80,0x80,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 22907 0x597b "奻" */
+0x10,0x10,0x10,0x10,0xfe,0x22,0x22,0x22,0x42,0x24,0x14,0x08,0x14,0x22,0x42,0x80,
+0x20,0x20,0x20,0x20,0xfe,0x44,0x44,0x44,0x44,0x84,0x48,0x28,0x10,0x28,0x44,0x82,
+/* 22908 0x597c "奼" */
+0x10,0x10,0x11,0x10,0xfe,0x22,0x22,0x22,0x43,0x24,0x14,0x08,0x14,0x22,0x42,0x80,
+0x10,0x38,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 22909 0x597d "好" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22910 0x597e "奾" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x80,0x00,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 22911 0x597f "奿" */
+0x20,0x20,0x20,0x23,0xfc,0x24,0x25,0x24,0x64,0x24,0x34,0x24,0x25,0x44,0x43,0x80,
+0x40,0x40,0x40,0xfe,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x8a,0x02,0x02,0xfe,0x00,
+/* 22912 0x5980 "妀" */
+0x00,0x00,0xfc,0x04,0x07,0x04,0x04,0x7c,0x40,0x41,0x40,0x44,0x58,0x60,0x40,0x03,
+0x40,0x40,0x40,0x40,0xfe,0x88,0x88,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x88,0x04,
+/* 22913 0x5981 "妁" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x25,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 22914 0x5982 "如" */
+0x10,0x10,0x10,0x10,0xfe,0x22,0x22,0x22,0x42,0x24,0x14,0x08,0x14,0x22,0x42,0x80,
+0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 22915 0x5983 "妃" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x84,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 22916 0x5984 "妄" */
+0x02,0x01,0xff,0x10,0x10,0x1f,0x02,0x02,0xff,0x04,0x08,0x1e,0x01,0x06,0x18,0x60,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,0x20,0x20,0x40,0x80,0x60,0x18,0x04,
+/* 22917 0x5985 "妅" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x83,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22918 0x5986 "妆" */
+0x08,0x08,0x08,0x48,0x2b,0x28,0x08,0x08,0x18,0x29,0xc8,0x08,0x08,0x08,0x08,0x0b,
+0x40,0x40,0x40,0x40,0xfe,0x88,0x88,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x88,0x04,
+/* 22919 0x5987 "妇" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x10,0x28,0x45,0x80,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 22920 0x5988 "妈" */
+0x10,0x13,0x10,0x10,0xfd,0x25,0x25,0x25,0x24,0x48,0x28,0x13,0x28,0x44,0x84,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 22921 0x5989 "妉" */
+0x10,0x10,0x10,0x11,0xfd,0x26,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x85,0x02,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 22922 0x598a "妊" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x28,0x44,0x85,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 22923 0x598b "妋" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x27,0x48,0x28,0x10,0x28,0x44,0x85,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 22924 0x598c "妌" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x27,0x48,0x28,0x10,0x28,0x45,0x85,0x02,
+0x88,0x88,0x88,0x88,0xfc,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 22925 0x598d "妍" */
+0x10,0x13,0x10,0x10,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x28,0x44,0x81,0x02,
+0x00,0xfe,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,
+/* 22926 0x598e "妎" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x26,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x81,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 22927 0x598f "妏" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x81,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 22928 0x5990 "妐" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x25,0x26,0x24,0x48,0x28,0x10,0x28,0x45,0x84,0x00,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x20,0x40,0x48,0x44,0x84,0xfe,0x82,0x00,
+/* 22929 0x5991 "妑" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x84,0x00,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 22930 0x5992 "妒" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x2a,0x46,0x84,0x08,
+0x40,0x20,0x20,0xfe,0x02,0x02,0x02,0xfe,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 22931 0x5993 "妓" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x10,0x28,0x44,0x81,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 22932 0x5994 "妔" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 22933 0x5995 "妕" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 22934 0x5996 "妖" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x25,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x81,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 22935 0x5997 "妗" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x26,0x24,0x24,0x49,0x28,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 22936 0x5998 "妘" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x84,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x84,0xfe,0x82,0x00,
+/* 22937 0x5999 "妙" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x25,0x26,0x48,0x28,0x10,0x28,0x44,0x80,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 22938 0x599a "妚" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x24,0x24,0x49,0x2a,0x10,0x28,0x44,0x84,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 22939 0x599b "妛" */
+0x01,0x21,0x21,0x21,0x3f,0x01,0x01,0xff,0x02,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22940 0x599c "妜" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x24,0x27,0x48,0x28,0x10,0x29,0x45,0x82,0x04,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 22941 0x599d "妝" */
+0x04,0x24,0x24,0x24,0x25,0x3c,0x04,0x04,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x85,
+0x20,0x20,0x20,0x20,0xfe,0x44,0x44,0x44,0x44,0x84,0x48,0x28,0x10,0x28,0x44,0x82,
+/* 22942 0x599e "妞" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x10,0x28,0x44,0x83,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 22943 0x599f "妟" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22944 0x59a0 "妠" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 22945 0x59a1 "妡" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 22946 0x59a2 "妢" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x26,0x25,0x24,0x48,0x28,0x10,0x29,0x45,0x82,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 22947 0x59a3 "妣" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 22948 0x59a4 "妤" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x27,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 22949 0x59a5 "妥" */
+0x00,0x7f,0x02,0x21,0x11,0x10,0x02,0x02,0xff,0x04,0x08,0x1e,0x01,0x06,0x18,0x60,
+0xfc,0x00,0x08,0x08,0x10,0x20,0x00,0x00,0xfe,0x20,0x20,0x40,0x80,0x60,0x18,0x04,
+/* 22950 0x59a6 "妦" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x13,0x28,0x44,0x84,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 22951 0x59a7 "妧" */
+0x10,0x11,0x10,0x10,0xfc,0x27,0x24,0x24,0x24,0x48,0x28,0x10,0x29,0x45,0x82,0x04,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 22952 0x59a8 "妨" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x81,0x02,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 22953 0x59a9 "妩" */
+0x20,0x23,0x20,0x20,0xf8,0x48,0x4f,0x48,0x88,0x48,0x30,0x11,0x29,0x4a,0x84,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 22954 0x59aa "妪" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x00,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 22955 0x59ab "妫" */
+0x10,0x11,0x10,0x10,0xfc,0x27,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x82,0x04,
+0x20,0x20,0xa0,0xa0,0x20,0xfe,0x22,0x22,0x42,0x52,0x4a,0x8a,0x82,0x02,0x14,0x08,
+/* 22956 0x59ac "妬" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x25,0x4a,0x2c,0x10,0x28,0x44,0x84,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 22957 0x59ad "妭" */
+0x20,0x20,0x20,0x20,0xfb,0x48,0x48,0x48,0x89,0x49,0x31,0x11,0x2a,0x4a,0x84,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 22958 0x59ae "妮" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 22959 0x59af "妯" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 22960 0x59b0 "妰" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x26,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,
+/* 22961 0x59b1 "妱" */
+0x10,0x13,0x10,0x10,0xfc,0x25,0x25,0x26,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 22962 0x59b2 "妲" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x85,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 22963 0x59b3 "妳" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x26,0x24,0x24,0x48,0x29,0x11,0x2a,0x44,0x80,0x00,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 22964 0x59b4 "妴" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x20,0xc2,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xf8,0x88,0x88,0xa8,0x94,0x84,0x7c,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22965 0x59b5 "妵" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x24,0x25,0x48,0x28,0x10,0x28,0x44,0x83,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22966 0x59b6 "妶" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x24,0x24,0x25,0x48,0x28,0x10,0x28,0x45,0x84,0x00,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 22967 0x59b7 "妷" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x26,0x24,0x25,0x48,0x28,0x10,0x28,0x44,0x85,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 22968 0x59b8 "妸" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x84,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 22969 0x59b9 "妹" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x11,0x29,0x46,0x84,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 22970 0x59ba "妺" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x11,0x29,0x46,0x80,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 22971 0x59bb "妻" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22972 0x59bc "妼" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x25,0x25,0x49,0x2a,0x10,0x28,0x45,0x82,0x00,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 22973 0x59bd "妽" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x80,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 22974 0x59be "妾" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x02,0x02,0x7f,0x04,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0x00,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 22975 0x59bf "妿" */
+0x10,0x10,0x7e,0x12,0x12,0x22,0x4a,0x84,0x02,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22976 0x59c0 "姀" */
+0x10,0x11,0x10,0x10,0xfc,0x27,0x24,0x24,0x24,0x48,0x28,0x11,0x2a,0x44,0x80,0x00,
+0x1c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,
+/* 22977 0x59c1 "姁" */
+0x10,0x10,0x11,0x11,0xfe,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x84,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 22978 0x59c2 "姂" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x25,0x24,0x24,0x48,0x28,0x10,0x28,0x45,0x82,0x00,
+0x04,0x1e,0xe0,0x00,0x20,0x10,0xfe,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x3e,0x00,
+/* 22979 0x59c3 "姃" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x87,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22980 0x59c4 "姄" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 22981 0x59c5 "姅" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x25,0x24,0x24,0x48,0x2b,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 22982 0x59c6 "姆" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x27,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x00,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 22983 0x59c7 "姇" */
+0x08,0x08,0x17,0x30,0x52,0x91,0x11,0x10,0x12,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22984 0x59c8 "姈" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x26,0x24,0x25,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 22985 0x59c9 "姉" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 22986 0x59ca "姊" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x24,0x48,0x28,0x11,0x2e,0x44,0x84,0x00,
+0x20,0x20,0x2e,0xf0,0x20,0x20,0x20,0xfe,0x22,0x62,0xa2,0x2a,0x24,0x20,0x20,0x20,
+/* 22987 0x59cb "始" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x25,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x80,0x00,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 22988 0x59cc "姌" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x2b,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 22989 0x59cd "姍" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x27,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 22990 0x59ce "姎" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x4b,0x28,0x10,0x28,0x44,0x81,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 22991 0x59cf "姏" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 22992 0x59d0 "姐" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x87,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 22993 0x59d1 "姑" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 22994 0x59d2 "姒" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x00,
+0x08,0x48,0x28,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x48,0x94,0x14,0x22,0x42,0x82,
+/* 22995 0x59d3 "姓" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x26,0x24,0x24,0x49,0x28,0x10,0x28,0x44,0x83,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 22996 0x59d4 "委" */
+0x00,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc2,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x70,0x80,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22997 0x59d5 "姕" */
+0x08,0x08,0x28,0x2e,0x28,0x28,0x2e,0xf0,0x02,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x7c,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 22998 0x59d6 "姖" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 22999 0x59d7 "姗" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x27,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0xd4,0x24,0x4c,
+/* 23000 0x59d8 "姘" */
+0x11,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x24,0x4b,0x28,0x10,0x29,0x45,0x82,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 23001 0x59d9 "姙" */
+0x10,0x10,0x10,0x11,0xfd,0x27,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 23002 0x59da "姚" */
+0x20,0x20,0x20,0x22,0xf9,0x48,0x48,0x49,0x8a,0x4c,0x30,0x10,0x29,0x49,0x82,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 23003 0x59db "姛" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 23004 0x59dc "姜" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x02,0x04,0xff,0x08,0x10,0x1c,0x03,0x0c,0x70,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0x00,0xfe,0x20,0x20,0x40,0x80,0x70,0x08,
+/* 23005 0x59dd "姝" */
+0x20,0x21,0x21,0x21,0xf9,0x4a,0x48,0x4b,0x48,0x90,0x50,0x21,0x31,0x4a,0x48,0x80,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 23006 0x59de "姞" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x25,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23007 0x59df "姟" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x25,0x24,0x48,0x28,0x13,0x28,0x44,0x80,0x03,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 23008 0x59e0 "姠" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x40,0xfe,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 23009 0x59e1 "姡" */
+0x10,0x10,0x11,0x10,0xfc,0x27,0x24,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23010 0x59e2 "姢" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0x48,0x84,0xfe,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 23011 0x59e3 "姣" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x25,0x26,0x24,0x48,0x28,0x10,0x28,0x44,0x80,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 23012 0x59e4 "姤" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 23013 0x59e5 "姥" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x27,0x24,0x24,0x49,0x2a,0x10,0x28,0x44,0x84,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 23014 0x59e6 "姦" */
+0x04,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,0x00,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,
+0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,0x10,0x10,0xfe,0x24,0x64,0x18,0x34,0xc2,
+/* 23015 0x59e7 "姧" */
+0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 23016 0x59e8 "姨" */
+0x20,0x20,0x27,0x20,0xfb,0x48,0x4b,0x4a,0x8b,0x48,0x30,0x10,0x28,0x49,0x82,0x04,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xa8,0xa0,0x10,0x08,0x06,
+/* 23017 0x59e9 "姩" */
+0x10,0x10,0x10,0x11,0xfe,0x24,0x24,0x24,0x24,0x48,0x2b,0x10,0x28,0x44,0x84,0x00,
+0x80,0x80,0xfe,0x10,0x10,0x10,0xfc,0x90,0x90,0x90,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 23018 0x59ea "姪" */
+0x10,0x11,0x10,0x10,0xfc,0x25,0x25,0x24,0x24,0x48,0x29,0x10,0x28,0x44,0x83,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 23019 0x59eb "姫" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x00,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23020 0x59ec "姬" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x00,
+0x00,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 23021 0x59ed "姭" */
+0x02,0x1f,0x04,0x08,0x10,0x7e,0x12,0x2a,0x44,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xf0,0x10,0x50,0x20,0xfc,0x24,0x54,0x88,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23022 0x59ee "姮" */
+0x10,0x13,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x83,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 23023 0x59ef "姯" */
+0x10,0x10,0x12,0x11,0xfd,0x24,0x27,0x24,0x24,0x48,0x28,0x10,0x29,0x45,0x82,0x04,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 23024 0x59f0 "姰" */
+0x10,0x10,0x11,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 23025 0x59f1 "姱" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x26,0x24,0x27,0x48,0x28,0x11,0x28,0x44,0x84,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 23026 0x59f2 "姲" */
+0x20,0x20,0x20,0x23,0xfa,0x4c,0x48,0x4b,0x48,0x90,0x51,0x20,0x30,0x48,0x48,0x83,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 23027 0x59f3 "姳" */
+0x10,0x10,0x10,0x11,0xfe,0x24,0x24,0x24,0x24,0x49,0x2a,0x10,0x28,0x44,0x84,0x00,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 23028 0x59f4 "姴" */
+0x00,0x7f,0x10,0x3f,0x51,0x0a,0x0c,0x30,0xc2,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x04,0xa4,0x24,0x24,0x24,0x04,0x04,0x14,0x08,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23029 0x59f5 "姵" */
+0x20,0x27,0x24,0x24,0xf5,0x54,0x54,0x55,0x55,0x95,0x55,0x25,0x25,0x54,0x54,0x88,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0x44,0xf4,0x54,0x54,0x54,0x54,0x74,0x46,0x46,0x42,
+/* 23030 0x59f6 "姶" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x25,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23031 0x59f7 "姷" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x24,0x25,0x26,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 23032 0x59f8 "姸" */
+0x10,0x11,0x10,0x10,0xfc,0x24,0x24,0x27,0x24,0x48,0x28,0x10,0x28,0x45,0x81,0x02,
+0x00,0xdc,0x88,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 23033 0x59f9 "姹" */
+0x10,0x10,0x10,0x11,0xfd,0x26,0x24,0x25,0x24,0x48,0x28,0x13,0x28,0x44,0x84,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x18,0xe0,0x40,0x40,0x7e,0xc0,0x40,0x44,0x44,0x3c,
+/* 23034 0x59fa "姺" */
+0x10,0x11,0x11,0x11,0xfd,0x26,0x24,0x27,0x24,0x48,0x28,0x10,0x29,0x45,0x82,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 23035 0x59fb "姻" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x81,0x01,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 23036 0x59fc "姼" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x25,0x48,0x28,0x11,0x28,0x44,0x84,0x01,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 23037 0x59fd "姽" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x02,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 23038 0x59fe "姾" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x25,0x24,0x24,0x48,0x29,0x10,0x28,0x44,0x83,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23039 0x59ff "姿" */
+0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23040 0x5a00 "娀" */
+0x20,0x20,0x20,0x20,0xfb,0x48,0x49,0x49,0x89,0x4b,0x31,0x11,0x2a,0x4a,0x84,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 23041 0x5a01 "威" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x3f,0x22,0x22,0x3f,0x24,0x28,0x25,0x42,0x45,0x98,
+0x28,0x24,0x20,0xfe,0x20,0x20,0xe4,0x24,0x24,0xa8,0xa8,0x90,0x12,0x2a,0x46,0x82,
+/* 23042 0x5a02 "娂" */
+0x10,0x10,0x10,0x10,0xfd,0x24,0x24,0x24,0x24,0x4b,0x28,0x10,0x28,0x45,0x82,0x04,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 23043 0x5a03 "娃" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x27,0x24,0x24,0x48,0x29,0x10,0x28,0x44,0x83,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23044 0x5a04 "娄" */
+0x01,0x11,0x09,0xff,0x05,0x09,0x31,0xc0,0x02,0xff,0x04,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x10,0x20,0xfe,0x40,0x20,0x18,0x06,0x00,0xfe,0x20,0x20,0x40,0x80,0x70,0x08,
+/* 23045 0x5a05 "娅" */
+0x20,0x23,0x20,0x20,0xf8,0x48,0x4c,0x4a,0x8a,0x4a,0x30,0x10,0x28,0x48,0x87,0x00,
+0x00,0xfc,0x90,0x90,0x90,0x92,0x92,0x94,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 23046 0x5a06 "娆" */
+0x20,0x20,0x20,0x23,0xf8,0x48,0x48,0x4b,0x88,0x4b,0x30,0x10,0x29,0x49,0x82,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 23047 0x5a07 "娇" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x24,0x24,0x25,0x4a,0x28,0x10,0x28,0x44,0x84,0x01,
+0x08,0x1c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 23048 0x5a08 "娈" */
+0x02,0x01,0xff,0x04,0x14,0x14,0x24,0x42,0x02,0x7f,0x04,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x04,0x00,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 23049 0x5a09 "娉" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x24,0x27,0x48,0x29,0x11,0x28,0x44,0x84,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 23050 0x5a0a "娊" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x10,0x28,0x45,0x82,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 23051 0x5a0b "娋" */
+0x10,0x11,0x10,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 23052 0x5a0c "娌" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x48,0x29,0x10,0x28,0x44,0x87,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23053 0x5a0d "娍" */
+0x20,0x20,0x20,0x20,0xfb,0x4a,0x4a,0x4a,0x8b,0x4a,0x32,0x12,0x2a,0x4d,0x84,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 23054 0x5a0e "娎" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23055 0x5a0f "娏" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x24,0x24,0x48,0x29,0x11,0x29,0x46,0x82,0x04,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 23056 0x5a10 "娐" */
+0x10,0x10,0x11,0x10,0xfd,0x24,0x24,0x25,0x24,0x48,0x2b,0x10,0x28,0x44,0x84,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 23057 0x5a11 "娑" */
+0x10,0x08,0x40,0x24,0x09,0x72,0x10,0x17,0x02,0x7f,0x04,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x20,0xa8,0xa4,0x2a,0x30,0xc0,0x00,0x00,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 23058 0x5a12 "娒" */
+0x10,0x10,0x10,0x11,0xfe,0x24,0x24,0x24,0x25,0x48,0x29,0x11,0x29,0x44,0x84,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 23059 0x5a13 "娓" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4a,0x4a,0x8a,0x4a,0x32,0x13,0x2a,0x4c,0x84,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x18,0xe0,0x38,0xe0,0x3c,0xe0,0x22,0x22,0x1e,0x00,
+/* 23060 0x5a14 "娔" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x28,0x44,0x81,0x02,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 23061 0x5a15 "娕" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x25,0x25,0x25,0x48,0x28,0x10,0x29,0x46,0x80,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 23062 0x5a16 "娖" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x24,0x24,0x49,0x29,0x11,0x29,0x46,0x84,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3e,0x20,0x20,0xa0,0x7e,0x00,
+/* 23063 0x5a17 "娗" */
+0x20,0x20,0x23,0x20,0xf8,0x49,0x49,0x4b,0x88,0x4a,0x32,0x11,0x29,0x4a,0x84,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 23064 0x5a18 "娘" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 23065 0x5a19 "娙" */
+0x10,0x11,0x10,0x10,0xfd,0x26,0x25,0x24,0x24,0x49,0x28,0x10,0x28,0x44,0x83,0x00,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 23066 0x5a1a "娚" */
+0x11,0x11,0x11,0x11,0xfd,0x25,0x25,0x24,0x24,0x4b,0x28,0x10,0x28,0x45,0x82,0x04,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x40,0xfe,0x42,0x82,0x82,0x02,0x14,0x08,
+/* 23067 0x5a1b "娛" */
+0x20,0x20,0x20,0x20,0xfa,0x4a,0x4a,0x4b,0x88,0x48,0x37,0x10,0x28,0x49,0x82,0x04,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0x00,0xfc,0x44,0x44,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 23068 0x5a1c "娜" */
+0x20,0x2f,0x22,0x22,0xf2,0x57,0x52,0x52,0x52,0x9f,0x52,0x22,0x22,0x54,0x55,0x88,
+0x00,0xde,0x52,0x52,0x54,0xd4,0x58,0x54,0x52,0xd2,0x52,0x5a,0x54,0x50,0x50,0x90,
+/* 23069 0x5a1d "娝" */
+0x10,0x13,0x10,0x10,0xfc,0x24,0x27,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23070 0x5a1e "娞" */
+0x20,0x20,0x23,0x20,0xfa,0x49,0x49,0x48,0x8b,0x48,0x31,0x13,0x28,0x48,0x81,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 23071 0x5a1f "娟" */
+0x20,0x21,0x21,0x21,0xf9,0x48,0x4b,0x4a,0x4a,0x93,0x52,0x22,0x33,0x4a,0x4a,0x82,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 23072 0x5a20 "娠" */
+0x20,0x23,0x22,0x22,0xfa,0x4a,0x4a,0x4b,0x8a,0x4a,0x32,0x12,0x2a,0x4c,0x84,0x08,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 23073 0x5a21 "娡" */
+0x20,0x20,0x20,0x23,0xf8,0x48,0x48,0x49,0x88,0x48,0x30,0x12,0x2a,0x4a,0x84,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 23074 0x5a22 "娢" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x24,0x24,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 23075 0x5a23 "娣" */
+0x11,0x10,0x10,0x11,0xfc,0x24,0x25,0x25,0x25,0x49,0x28,0x10,0x29,0x46,0x84,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 23076 0x5a24 "娤" */
+0x24,0x24,0x24,0x3d,0x04,0xfc,0x24,0x24,0x46,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xf8,0x00,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23077 0x5a25 "娥" */
+0x10,0x10,0x13,0x10,0xfc,0x27,0x24,0x24,0x24,0x48,0x2b,0x10,0x28,0x44,0x84,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x82,
+/* 23078 0x5a26 "娦" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x2b,0x10,0x28,0x45,0x82,0x04,
+0x10,0x38,0xc0,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,0x02,
+/* 23079 0x5a27 "娧" */
+0x11,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x48,0x28,0x10,0x28,0x45,0x82,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 23080 0x5a28 "娨" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x24,0x24,0x25,0x48,0x28,0x13,0x28,0x44,0x84,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 23081 0x5a29 "娩" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x28,0x44,0x81,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 23082 0x5a2a "娪" */
+0x10,0x13,0x10,0x10,0xfd,0x24,0x24,0x27,0x24,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 23083 0x5a2b "娫" */
+0x20,0x20,0x23,0x20,0xf8,0x49,0x49,0x4b,0x88,0x4a,0x32,0x11,0x29,0x4a,0x84,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 23084 0x5a2c "娬" */
+0x20,0x20,0x23,0x20,0xf8,0x4f,0x48,0x48,0x88,0x4a,0x32,0x12,0x2a,0x4a,0x87,0x02,
+0x10,0x18,0xd4,0x14,0x10,0xfe,0x10,0x90,0x90,0xd0,0x90,0x90,0x8a,0xea,0x06,0x02,
+/* 23085 0x5a2d "娭" */
+0x20,0x20,0x20,0x21,0xfb,0x48,0x48,0x49,0x8a,0x48,0x33,0x10,0x28,0x48,0x81,0x06,
+0x20,0x40,0x88,0x04,0xfe,0x82,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 23086 0x5a2e "娮" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x24,0x24,0x25,0x48,0x28,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 23087 0x5a2f "娯" */
+0x20,0x20,0x20,0x20,0xfa,0x4a,0x4a,0x4b,0x88,0x48,0x37,0x10,0x28,0x49,0x82,0x04,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfe,0x00,0xa0,0x10,0x08,0x06,
+/* 23088 0x5a30 "娰" */
+0x21,0x21,0x21,0x22,0xfa,0x4e,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x08,0x48,0x28,0xa8,0xa8,0x88,0x88,0x88,0x88,0x88,0xa8,0xd4,0x94,0x22,0x42,0x82,
+/* 23089 0x5a31 "娱" */
+0x20,0x23,0x22,0x22,0xfb,0x48,0x48,0x4b,0x88,0x48,0x37,0x10,0x28,0x49,0x82,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 23090 0x5a32 "娲" */
+0x20,0x21,0x21,0x21,0xf9,0x49,0x48,0x48,0x4b,0x92,0x52,0x22,0x33,0x4a,0x4a,0x82,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 23091 0x5a33 "娳" */
+0x20,0x20,0x23,0x20,0xf8,0x48,0x4b,0x48,0x49,0x91,0x52,0x22,0x34,0x48,0x48,0x80,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 23092 0x5a34 "娴" */
+0x11,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xbc,0x04,0x24,0x24,0x24,0xfc,0x24,0x74,0xac,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 23093 0x5a35 "娵" */
+0x20,0x27,0x22,0x22,0xfa,0x4b,0x4a,0x4a,0x4b,0x92,0x52,0x22,0x37,0x48,0x48,0x80,
+0x00,0xe0,0x5e,0x52,0x52,0xd2,0x52,0x54,0xd4,0x54,0x48,0xe8,0x54,0x54,0x62,0x40,
+/* 23094 0x5a36 "娶" */
+0x00,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x7c,0x44,0x44,0x28,0x10,0xa8,0x44,0x82,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23095 0x5a37 "娷" */
+0x10,0x10,0x11,0x10,0xfd,0x24,0x24,0x24,0x27,0x48,0x28,0x13,0x28,0x44,0x85,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 23096 0x5a38 "娸" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x28,0x13,0x28,0x44,0x85,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 23097 0x5a39 "娹" */
+0x20,0x23,0x20,0x20,0xf8,0x4b,0x4a,0x4a,0x4a,0x93,0x50,0x20,0x30,0x48,0x4a,0x81,
+0x10,0x88,0x88,0xfe,0x90,0x90,0x24,0x24,0x38,0x88,0x90,0x90,0xa4,0xbe,0x82,0x00,
+/* 23098 0x5a3a "娺" */
+0x20,0x23,0x20,0x21,0xf8,0x49,0x4a,0x4c,0x88,0x4b,0x30,0x11,0x28,0x49,0x82,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 23099 0x5a3b "娻" */
+0x10,0x10,0x13,0x10,0xfd,0x25,0x25,0x25,0x25,0x48,0x28,0x10,0x29,0x46,0x80,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 23100 0x5a3c "娼" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 23101 0x5a3d "娽" */
+0x10,0x11,0x10,0x10,0xfd,0x24,0x24,0x27,0x24,0x4a,0x29,0x10,0x29,0x46,0x80,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 23102 0x5a3e "娾" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 23103 0x5a3f "娿" */
+0x00,0x7b,0x48,0x51,0x49,0x45,0x54,0x48,0x42,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x28,0x10,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23104 0x5a40 "婀" */
+0x20,0x27,0x25,0x25,0xf5,0x55,0x56,0x55,0x55,0x95,0x55,0x25,0x26,0x54,0x54,0x84,
+0x00,0x7e,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x14,0x08,
+/* 23105 0x5a41 "婁" */
+0x01,0x1f,0x11,0xff,0x11,0x1f,0x01,0x1f,0x11,0x1f,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x00,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23106 0x5a42 "婂" */
+0x20,0x20,0x21,0x21,0xf9,0x49,0x49,0x48,0x48,0x93,0x52,0x22,0x32,0x4a,0x48,0x80,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 23107 0x5a43 "婃" */
+0x20,0x20,0x23,0x22,0xf8,0x49,0x48,0x48,0x4b,0x90,0x51,0x21,0x32,0x4c,0x48,0x80,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 23108 0x5a44 "婄" */
+0x10,0x10,0x11,0x10,0xfd,0x24,0x24,0x27,0x24,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 23109 0x5a45 "婅" */
+0x11,0x11,0x11,0x12,0xfc,0x25,0x24,0x24,0x27,0x48,0x28,0x11,0x2a,0x44,0x84,0x00,
+0x00,0x00,0xfc,0x04,0x44,0x54,0xe4,0x44,0xfc,0x44,0xe4,0x54,0x44,0x44,0x14,0x08,
+/* 23110 0x5a46 "婆" */
+0x20,0x13,0x92,0x42,0x4b,0x12,0xe4,0x24,0x29,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0xfe,0x22,0x20,0xfc,0x84,0x48,0x30,0xce,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23111 0x5a47 "婇" */
+0x20,0x20,0x23,0x20,0xfa,0x49,0x49,0x48,0x8b,0x48,0x30,0x10,0x29,0x4a,0x84,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 23112 0x5a48 "婈" */
+0x20,0x20,0x21,0x20,0xf8,0x4b,0x48,0x49,0x8a,0x48,0x31,0x12,0x28,0x48,0x81,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 23113 0x5a49 "婉" */
+0x20,0x20,0x23,0x22,0xfd,0x49,0x49,0x4a,0x8a,0x4b,0x34,0x10,0x29,0x49,0x82,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 23114 0x5a4a "婊" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x24,0x24,0x27,0x48,0x28,0x11,0x2a,0x44,0x84,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 23115 0x5a4b "婋" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x2a,0x46,0x84,0x09,
+0x20,0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 23116 0x5a4c "婌" */
+0x21,0x21,0x21,0x21,0xf1,0x51,0x57,0x50,0x51,0x91,0x55,0x25,0x29,0x51,0x55,0x82,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 23117 0x5a4d "婍" */
+0x10,0x10,0x11,0x10,0xfc,0x25,0x27,0x24,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 23118 0x5a4e "婎" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x27,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0xa0,0x90,0x90,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 23119 0x5a4f "婏" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x28,0x44,0x81,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x58,0x94,0x92,0x12,0x0e,
+/* 23120 0x5a50 "婐" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x4b,0x28,0x10,0x29,0x46,0x80,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 23121 0x5a51 "婑" */
+0x20,0x21,0x20,0x20,0xfb,0x48,0x49,0x4a,0x48,0x93,0x50,0x21,0x30,0x48,0x48,0x81,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 23122 0x5a52 "婒" */
+0x10,0x10,0x10,0x11,0xfc,0x24,0x27,0x24,0x24,0x48,0x28,0x11,0x28,0x44,0x85,0x02,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 23123 0x5a53 "婓" */
+0x04,0x04,0xfc,0x04,0x7c,0x04,0xfc,0x04,0x06,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x40,0x40,0x7e,0x40,0x7c,0x40,0x7e,0x40,0x40,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23124 0x5a54 "婔" */
+0x20,0x20,0x20,0x27,0xf8,0x48,0x48,0x4b,0x48,0x90,0x50,0x27,0x30,0x48,0x48,0x80,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 23125 0x5a55 "婕" */
+0x20,0x20,0x23,0x20,0xf9,0x48,0x4b,0x48,0x89,0x48,0x31,0x11,0x29,0x4a,0x82,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 23126 0x5a56 "婖" */
+0x20,0x23,0x20,0x20,0xfb,0x48,0x49,0x4a,0x4c,0x90,0x50,0x22,0x32,0x4c,0x49,0x80,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 23127 0x5a57 "婗" */
+0x20,0x20,0x23,0x22,0xfa,0x4b,0x4a,0x4a,0x8b,0x48,0x30,0x10,0x28,0x49,0x82,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 23128 0x5a58 "婘" */
+0x10,0x11,0x10,0x10,0xfd,0x24,0x27,0x24,0x25,0x4a,0x2c,0x10,0x28,0x44,0x84,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 23129 0x5a59 "婙" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x24,0x24,0x25,0x48,0x28,0x11,0x28,0x44,0x84,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 23130 0x5a5a "婚" */
+0x20,0x23,0x22,0x23,0xfa,0x4a,0x4b,0x4a,0x49,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23131 0x5a5b "婛" */
+0x10,0x10,0x13,0x10,0xfc,0x25,0x25,0x25,0x25,0x48,0x29,0x11,0x2a,0x44,0x80,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 23132 0x5a5c "婜" */
+0x00,0x7f,0x48,0x7f,0x41,0x7f,0x48,0x7f,0x00,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x7c,0x44,0x44,0x28,0x10,0x28,0x44,0x82,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23133 0x5a5d "婝" */
+0x20,0x20,0x23,0x22,0xfc,0x48,0x4b,0x48,0x88,0x49,0x31,0x11,0x2a,0x4a,0x84,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 23134 0x5a5e "婞" */
+0x10,0x10,0x11,0x10,0xfc,0x27,0x24,0x24,0x25,0x48,0x28,0x13,0x28,0x44,0x84,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x50,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 23135 0x5a5f "婟" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4b,0x82,
+0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfa,0x8a,0x8a,0x8a,0xfa,0x8a,0x02,0xfe,0x02,
+/* 23136 0x5a60 "婠" */
+0x10,0x10,0x13,0x12,0xfc,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 23137 0x5a61 "婡" */
+0x20,0x20,0x20,0x23,0xf8,0x49,0x49,0x49,0x8a,0x48,0x30,0x10,0x29,0x4a,0x84,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 23138 0x5a62 "婢" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x48,0x29,0x13,0x28,0x44,0x84,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 23139 0x5a63 "婣" */
+0x20,0x22,0x22,0x22,0xfb,0x4a,0x4a,0x4b,0x8a,0x4a,0x33,0x12,0x2a,0x42,0x84,0x08,
+0x50,0x52,0x52,0x52,0xde,0x02,0x02,0xfe,0x02,0x02,0xde,0x52,0x52,0x52,0x52,0x02,
+/* 23140 0x5a64 "婤" */
+0x20,0x23,0x22,0x22,0xfa,0x4a,0x4a,0x4b,0x8a,0x4a,0x32,0x12,0x2a,0x4a,0x82,0x04,
+0x00,0xfe,0x22,0x22,0xfa,0x22,0x22,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 23141 0x5a65 "婥" */
+0x10,0x10,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x28,0x13,0x28,0x44,0x84,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 23142 0x5a66 "婦" */
+0x20,0x21,0x20,0x20,0xf8,0x49,0x48,0x4b,0x4a,0x90,0x51,0x21,0x31,0x49,0x49,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 23143 0x5a67 "婧" */
+0x10,0x10,0x13,0x10,0xfd,0x24,0x27,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 23144 0x5a68 "婨" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 23145 0x5a69 "婩" */
+0x10,0x11,0x11,0x11,0xfd,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 23146 0x5a6a "婪" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x0a,0x7f,0x04,0x08,0x1c,0x03,0x06,0x38,
+0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0x20,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 23147 0x5a6b "婫" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 23148 0x5a6c "婬" */
+0x10,0x10,0x11,0x10,0xfd,0x24,0x24,0x24,0x25,0x48,0x28,0x13,0x28,0x44,0x85,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0xa8,0x90,0x1c,0xe0,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,
+/* 23149 0x5a6d "婭" */
+0x10,0x11,0x10,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x28,0x44,0x85,0x00,
+0x00,0xfe,0x48,0x48,0x48,0xce,0x02,0x02,0x02,0xce,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 23150 0x5a6e "婮" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 23151 0x5a6f "婯" */
+0x00,0xfe,0x00,0x7c,0x44,0x64,0x54,0x44,0x46,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xfe,0x00,0x7c,0x44,0x64,0x54,0x44,0x44,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23152 0x5a70 "婰" */
+0x10,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x13,0x28,0x44,0x81,0x02,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x88,0x04,0x02,
+/* 23153 0x5a71 "婱" */
+0x00,0x7c,0x05,0x7c,0x40,0x7d,0x04,0x04,0x29,0x10,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x40,0x20,0xfc,0x40,0x88,0xf0,0x20,0x48,0xfc,0x04,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23154 0x5a72 "婲" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x25,0x4a,0x28,0x10,0x28,0x44,0x84,0x00,
+0x88,0x88,0xfe,0x88,0x88,0x50,0x50,0x94,0x94,0x98,0x90,0xb2,0xd2,0x92,0x8e,0x80,
+/* 23155 0x5a73 "婳" */
+0x20,0x23,0x20,0x20,0xf8,0x48,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4b,0x80,
+0x00,0xfe,0x00,0x00,0xf8,0xa8,0xaa,0xfa,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0xfe,0x02,
+/* 23156 0x5a74 "婴" */
+0x00,0x3e,0x22,0x2a,0x2a,0x2a,0x14,0x62,0x02,0x7f,0x04,0x08,0x1c,0x03,0x06,0x38,
+0x00,0xf8,0x88,0xa8,0xa8,0xa8,0x50,0x88,0x00,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 23157 0x5a75 "婵" */
+0x11,0x10,0x10,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x2b,0x44,0x84,0x00,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 23158 0x5a76 "婶" */
+0x20,0x20,0x23,0x22,0xf8,0x49,0x49,0x49,0x49,0x91,0x51,0x21,0x31,0x48,0x48,0x80,
+0x40,0x20,0xfe,0x22,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 23159 0x5a77 "婷" */
+0x10,0x10,0x13,0x10,0xfd,0x25,0x25,0x24,0x27,0x4a,0x29,0x10,0x28,0x44,0x84,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 23160 0x5a78 "婸" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x25,0x24,0x48,0x29,0x12,0x28,0x45,0x84,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 23161 0x5a79 "婹" */
+0x20,0x23,0x20,0x20,0xfb,0x4a,0x4a,0x4b,0x48,0x90,0x57,0x20,0x31,0x48,0x48,0x83,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 23162 0x5a7a "婺" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x02,0x7f,0x04,0x08,0x1c,0x03,0x06,0x38,
+0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,0x00,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 23163 0x5a7b "婻" */
+0x20,0x20,0x23,0x20,0xf8,0x4b,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 23164 0x5a7c "婼" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x27,0x24,0x24,0x48,0x29,0x12,0x28,0x44,0x84,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 23165 0x5a7d "婽" */
+0x20,0x23,0x22,0x22,0xfa,0x4b,0x4a,0x4a,0x4b,0x92,0x52,0x23,0x32,0x4a,0x4a,0x82,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 23166 0x5a7e "婾" */
+0x21,0x20,0x21,0x22,0xfd,0x48,0x4b,0x4a,0x4a,0x93,0x52,0x22,0x33,0x4a,0x4a,0x82,
+0xc0,0xa0,0x10,0x08,0xf6,0x00,0xca,0x4a,0x54,0xd4,0x68,0x54,0xd4,0x4a,0x4a,0xc0,
+/* 23167 0x5a7f "婿" */
+0x10,0x13,0x10,0x11,0xfd,0x25,0x26,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x81,0x01,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 23168 0x5a80 "媀" */
+0x21,0x21,0x21,0x21,0xf9,0x49,0x49,0x48,0x48,0x93,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 23169 0x5a81 "媁" */
+0x20,0x20,0x21,0x20,0xfb,0x48,0x49,0x49,0x49,0x90,0x53,0x20,0x32,0x4b,0x48,0x80,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 23170 0x5a82 "媂" */
+0x20,0x20,0x21,0x20,0xf8,0x48,0x4b,0x4a,0x4c,0x91,0x51,0x21,0x31,0x49,0x48,0x80,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 23171 0x5a83 "媃" */
+0x20,0x21,0x20,0x20,0xfb,0x48,0x48,0x49,0x8a,0x48,0x33,0x10,0x28,0x49,0x86,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23172 0x5a84 "媄" */
+0x11,0x10,0x13,0x10,0xfc,0x25,0x24,0x24,0x27,0x48,0x28,0x13,0x28,0x44,0x80,0x03,
+0x04,0x88,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 23173 0x5a85 "媅" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x24,0x4b,0x29,0x11,0x29,0x45,0x85,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 23174 0x5a86 "媆" */
+0x10,0x13,0x10,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x28,0x13,0x28,0x44,0x81,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 23175 0x5a87 "媇" */
+0x10,0x10,0x11,0x10,0xfc,0x24,0x27,0x24,0x24,0x49,0x28,0x10,0x29,0x46,0x80,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 23176 0x5a88 "媈" */
+0x20,0x23,0x22,0x20,0xfb,0x48,0x49,0x49,0x49,0x91,0x51,0x20,0x33,0x48,0x48,0x80,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23177 0x5a89 "媉" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4b,0x4a,0x8a,0x4b,0x32,0x12,0x2d,0x44,0x88,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 23178 0x5a8a "媊" */
+0x21,0x20,0x20,0x27,0xf8,0x4b,0x4a,0x4a,0x4b,0x92,0x52,0x23,0x32,0x4a,0x4a,0x82,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 23179 0x5a8b "媋" */
+0x10,0x10,0x13,0x10,0xfd,0x24,0x27,0x24,0x25,0x4a,0x28,0x10,0x28,0x44,0x84,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 23180 0x5a8c "媌" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 23181 0x5a8d "媍" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x81,0x02,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 23182 0x5a8e "媎" */
+0x10,0x10,0x11,0x10,0xfc,0x27,0x24,0x24,0x24,0x49,0x2a,0x10,0x28,0x44,0x84,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 23183 0x5a8f "媏" */
+0x10,0x11,0x11,0x11,0xfd,0x24,0x27,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 23184 0x5a90 "媐" */
+0x00,0x7f,0x44,0x44,0x5f,0x51,0x5f,0x44,0x7f,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0x7c,0x44,0x44,0x7c,0x40,0x42,0x42,0xbe,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23185 0x5a91 "媑" */
+0x20,0x20,0x21,0x20,0xfb,0x48,0x49,0x49,0x49,0x91,0x51,0x20,0x31,0x48,0x4b,0x80,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 23186 0x5a92 "媒" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x24,0x24,0x24,0x48,0x2b,0x10,0x28,0x45,0x82,0x00,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23187 0x5a93 "媓" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x24,0x27,0x48,0x28,0x11,0x28,0x44,0x83,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 23188 0x5a94 "媔" */
+0x20,0x27,0x20,0x20,0xfb,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4b,0x82,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 23189 0x5a95 "媕" */
+0x10,0x10,0x10,0x11,0xfe,0x24,0x25,0x25,0x25,0x49,0x28,0x10,0x2b,0x44,0x81,0x02,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x88,0x88,0xfe,0x88,0x08,0x08,
+/* 23190 0x5a96 "媖" */
+0x21,0x21,0x27,0x21,0xf9,0x48,0x4b,0x4a,0x8a,0x4a,0x37,0x10,0x28,0x49,0x82,0x04,
+0x10,0x10,0xfc,0x10,0x50,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 23191 0x5a97 "媗" */
+0x20,0x20,0x23,0x22,0xfc,0x49,0x48,0x49,0x49,0x91,0x51,0x21,0x31,0x48,0x4b,0x80,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 23192 0x5a98 "媘" */
+0x11,0x11,0x11,0x11,0xfd,0x25,0x25,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23193 0x5a99 "媙" */
+0x20,0x20,0x20,0x23,0xfa,0x4b,0x4a,0x4a,0x8b,0x4a,0x32,0x12,0x2a,0x4b,0x82,0x04,
+0x0c,0x0a,0x08,0xfe,0x08,0xf8,0x4a,0x4a,0xea,0xac,0xac,0x4c,0xaa,0x0a,0x16,0x22,
+/* 23194 0x5a9a "媚" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 23195 0x5a9b "媛" */
+0x20,0x27,0x22,0x21,0xf8,0x4b,0x48,0x48,0x4f,0x91,0x51,0x22,0x32,0x4c,0x48,0x83,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 23196 0x5a9c "媜" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x85,0x02,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 23197 0x5a9d "媝" */
+0x06,0x38,0x08,0x7e,0x08,0x1c,0x2a,0x48,0x0a,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x10,0x10,0x52,0x54,0x90,0x28,0x28,0x44,0x82,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23198 0x5a9e "媞" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x4b,0x28,0x11,0x29,0x45,0x82,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 23199 0x5a9f "媟" */
+0x10,0x11,0x11,0x13,0xfd,0x25,0x25,0x25,0x25,0x48,0x2b,0x10,0x28,0x45,0x86,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23200 0x5aa0 "媠" */
+0x10,0x10,0x13,0x10,0xfd,0x26,0x25,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 23201 0x5aa1 "媡" */
+0x10,0x10,0x13,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x28,0x45,0x82,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 23202 0x5aa2 "媢" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x84,0x00,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 23203 0x5aa3 "媣" */
+0x21,0x20,0x24,0x22,0xf8,0x49,0x4f,0x49,0x49,0x90,0x53,0x20,0x30,0x49,0x4a,0x80,
+0x20,0xa0,0x78,0x28,0xa8,0x2a,0x2a,0x46,0xa0,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23204 0x5aa4 "媤" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x48,0x28,0x11,0x29,0x45,0x82,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 23205 0x5aa5 "媥" */
+0x20,0x20,0x21,0x21,0xf9,0x49,0x49,0x49,0x89,0x49,0x31,0x12,0x2a,0x4a,0x84,0x00,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 23206 0x5aa6 "媦" */
+0x20,0x23,0x22,0x23,0xfa,0x4b,0x48,0x49,0x49,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 23207 0x5aa7 "媧" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x00,0xfc,0x84,0x84,0xf4,0x94,0x94,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 23208 0x5aa8 "媨" */
+0x21,0x20,0x20,0x27,0xf8,0x48,0x4b,0x4a,0x4a,0x93,0x52,0x23,0x32,0x4a,0x4b,0x82,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23209 0x5aa9 "媩" */
+0x10,0x10,0x10,0x13,0xfc,0x24,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x44,0x84,0x00,
+0x80,0x9e,0x92,0xf2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 23210 0x5aaa "媪" */
+0x20,0x21,0x21,0x21,0xf9,0x49,0x49,0x49,0x88,0x4b,0x32,0x12,0x2a,0x4a,0x87,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 23211 0x5aab "媫" */
+0x20,0x20,0x20,0x20,0xfb,0x48,0x49,0x48,0x8b,0x48,0x32,0x12,0x2a,0x45,0x84,0x08,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 23212 0x5aac "媬" */
+0x21,0x21,0x21,0x22,0xfa,0x4e,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4b,0x4a,0x82,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 23213 0x5aad "媭" */
+0x0b,0x30,0xc1,0x09,0x31,0xc5,0x09,0x30,0xc0,0x03,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0xfe,0x20,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23214 0x5aae "媮" */
+0x20,0x20,0x21,0x22,0xfd,0x48,0x4b,0x4a,0x4a,0x93,0x52,0x22,0x33,0x4a,0x4a,0x82,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 23215 0x5aaf "媯" */
+0x20,0x22,0x21,0x27,0xf8,0x48,0x48,0x49,0x89,0x4b,0x32,0x14,0x2a,0x4a,0x84,0x00,
+0x40,0x40,0x40,0xf8,0x88,0x90,0xfc,0x04,0x08,0xfe,0x02,0x2a,0xaa,0x82,0x14,0x08,
+/* 23216 0x5ab0 "媰" */
+0x20,0x20,0x21,0x22,0xf9,0x49,0x48,0x49,0x4a,0x91,0x52,0x25,0x31,0x48,0x49,0x82,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 23217 0x5ab1 "媱" */
+0x20,0x20,0x23,0x20,0xfa,0x49,0x49,0x4a,0x48,0x93,0x50,0x21,0x31,0x49,0x49,0x80,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 23218 0x5ab2 "媲" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x40,0xfc,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 23219 0x5ab3 "媳" */
+0x20,0x20,0x21,0x21,0xf9,0x49,0x49,0x49,0x89,0x48,0x30,0x10,0x2a,0x4a,0x84,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 23220 0x5ab4 "媴" */
+0x20,0x20,0x21,0x20,0xfb,0x48,0x49,0x49,0x49,0x91,0x50,0x20,0x31,0x4e,0x48,0x80,
+0x20,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x52,0x94,0x88,0xa4,0xc2,0x80,
+/* 23221 0x5ab5 "媵" */
+0x00,0x79,0x48,0x48,0x49,0x78,0x4b,0x48,0x49,0x7a,0x4d,0x48,0x49,0x48,0x48,0x99,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x44,0x42,0xfc,0x88,0xd0,0x30,0x48,0x84,
+/* 23222 0x5ab6 "媶" */
+0x21,0x21,0x27,0x21,0xf8,0x4f,0x49,0x49,0x49,0x91,0x51,0x21,0x37,0x48,0x48,0x80,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,0x08,
+/* 23223 0x5ab7 "媷" */
+0x20,0x23,0x22,0x22,0xfa,0x4b,0x4a,0x4a,0x8a,0x4a,0x32,0x13,0x2a,0x4c,0x84,0x08,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 23224 0x5ab8 "媸" */
+0x20,0x21,0x21,0x21,0xf8,0x4b,0x48,0x48,0x49,0x91,0x51,0x21,0x30,0x48,0x4b,0x81,
+0x20,0x24,0x24,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 23225 0x5ab9 "媹" */
+0x20,0x23,0x22,0x22,0xfa,0x4a,0x4b,0x48,0x4b,0x92,0x52,0x23,0x32,0x4a,0x4b,0x82,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 23226 0x5aba "媺" */
+0x21,0x25,0x25,0x25,0xf7,0x50,0x50,0x5f,0x50,0x97,0x54,0x24,0x24,0x54,0x58,0x90,
+0x08,0x48,0x48,0x50,0xde,0x24,0x14,0xd4,0x14,0x94,0x94,0xa8,0xc8,0x94,0x14,0x22,
+/* 23227 0x5abb "媻" */
+0x10,0x3e,0x22,0x2a,0xff,0x22,0x2a,0x42,0x4a,0x84,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x10,0x28,0xc6,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23228 0x5abc "媼" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x83,0x00,
+0x00,0xf8,0xa8,0xa8,0xd8,0x88,0xf8,0x00,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 23229 0x5abd "媽" */
+0x20,0x21,0x21,0x21,0xf9,0x49,0x49,0x49,0x89,0x48,0x32,0x12,0x2a,0x4a,0x80,0x00,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 23230 0x5abe "媾" */
+0x10,0x10,0x13,0x10,0xfd,0x24,0x27,0x24,0x25,0x49,0x29,0x11,0x2b,0x45,0x85,0x01,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 23231 0x5abf "媿" */
+0x20,0x20,0x23,0x22,0xfa,0x4b,0x4a,0x4a,0x8b,0x48,0x30,0x10,0x29,0x49,0x82,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 23232 0x5ac0 "嫀" */
+0x20,0x20,0x27,0x20,0xfb,0x48,0x4f,0x49,0x8a,0x4d,0x30,0x13,0x28,0x49,0x86,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x68,0xc6,0x40,0xf8,0xe0,0x58,0x44,0x40,
+/* 23233 0x5ac1 "嫁" */
+0x20,0x20,0x23,0x22,0xf8,0x49,0x48,0x48,0x4b,0x90,0x50,0x23,0x30,0x48,0x4b,0x80,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 23234 0x5ac2 "嫂" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x24,0x49,0x28,0x10,0x28,0x44,0x80,0x03,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 23235 0x5ac3 "嫃" */
+0x10,0x10,0x13,0x10,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x2b,0x44,0x81,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 23236 0x5ac4 "嫄" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 23237 0x5ac5 "嫅" */
+0x21,0x20,0x20,0x23,0xf8,0x49,0x48,0x4b,0x48,0x91,0x51,0x22,0x34,0x48,0x4b,0x80,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23238 0x5ac6 "嫆" */
+0x10,0x10,0x13,0x12,0xfc,0x24,0x25,0x24,0x24,0x49,0x2a,0x10,0x28,0x44,0x84,0x00,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 23239 0x5ac7 "嫇" */
+0x10,0x13,0x12,0x10,0xfd,0x25,0x25,0x25,0x25,0x48,0x28,0x13,0x28,0x44,0x81,0x02,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 23240 0x5ac8 "嫈" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x82,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23241 0x5ac9 "嫉" */
+0x20,0x20,0x21,0x21,0xf9,0x4d,0x4b,0x49,0x89,0x4b,0x35,0x11,0x29,0x4a,0x82,0x04,
+0x20,0x10,0xfe,0x00,0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 23242 0x5aca "嫊" */
+0x20,0x20,0x23,0x20,0xf9,0x48,0x4b,0x48,0x48,0x91,0x50,0x23,0x30,0x49,0x4a,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 23243 0x5acb "嫋" */
+0x20,0x23,0x20,0x20,0xfb,0x4a,0x4a,0x4b,0x48,0x92,0x51,0x21,0x32,0x48,0x4a,0x81,
+0x00,0xde,0x42,0x42,0xde,0x10,0x10,0xde,0x42,0x52,0x4a,0x4a,0x52,0x42,0x94,0x08,
+/* 23244 0x5acc "嫌" */
+0x10,0x10,0x10,0x13,0xfc,0x25,0x24,0x27,0x24,0x49,0x28,0x10,0x29,0x46,0x84,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 23245 0x5acd "嫍" */
+0x10,0x11,0x10,0x11,0xfc,0x24,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 23246 0x5ace "嫎" */
+0x20,0x20,0x23,0x21,0xf8,0x4b,0x4a,0x4c,0x48,0x93,0x50,0x20,0x30,0x49,0x49,0x82,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 23247 0x5acf "嫏" */
+0x21,0x20,0x23,0x22,0xfa,0x4b,0x4a,0x4a,0x4b,0x92,0x52,0x22,0x32,0x4b,0x4a,0x80,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 23248 0x5ad0 "嫐" */
+0x20,0x27,0x25,0x25,0xf7,0x55,0x55,0x57,0x52,0x92,0x57,0x22,0x22,0x52,0x55,0x88,
+0x08,0xc8,0x48,0x48,0xfe,0x54,0x54,0xd4,0x14,0x24,0xd4,0x48,0x48,0x54,0x54,0xa0,
+/* 23249 0x5ad1 "嫑" */
+0x7f,0x03,0x0d,0x71,0x01,0x7f,0x04,0x3f,0x24,0x3f,0x04,0xff,0x08,0x1e,0x03,0x3c,
+0xfc,0x00,0x70,0x0c,0x00,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23250 0x5ad2 "嫒" */
+0x20,0x23,0x20,0x22,0xf9,0x4b,0x4a,0x48,0x4b,0x90,0x50,0x21,0x31,0x4a,0x4c,0x81,
+0x0e,0xf0,0x44,0x24,0x08,0xfe,0x42,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 23251 0x5ad3 "嫓" */
+0x10,0x10,0x11,0x12,0xfd,0x25,0x25,0x25,0x25,0x48,0x29,0x11,0x29,0x45,0x85,0x01,
+0x80,0xf8,0x08,0x10,0xfc,0x24,0x54,0x8c,0x04,0x10,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 23252 0x5ad4 "嫔" */
+0x20,0x20,0x23,0x22,0xfc,0x49,0x49,0x49,0x49,0x91,0x51,0x27,0x30,0x48,0x49,0x82,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 23253 0x5ad5 "嫕" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x29,0x45,0x82,0x00,
+0x00,0xfe,0x40,0x7c,0x90,0x10,0xfe,0x28,0x44,0xfe,0x20,0x10,0x44,0x42,0x4a,0x38,
+/* 23254 0x5ad6 "嫖" */
+0x10,0x13,0x10,0x11,0xfd,0x25,0x25,0x24,0x25,0x48,0x2b,0x10,0x28,0x45,0x82,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 23255 0x5ad7 "嫗" */
+0x20,0x23,0x22,0x22,0xfa,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4b,0x80,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 23256 0x5ad8 "嫘" */
+0x10,0x11,0x11,0x11,0xfd,0x25,0x24,0x24,0x25,0x48,0x28,0x13,0x28,0x45,0x82,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 23257 0x5ad9 "嫙" */
+0x24,0x22,0x22,0x2f,0xf4,0x54,0x57,0x55,0x55,0x95,0x55,0x25,0x29,0x5b,0x50,0xa1,
+0x20,0x20,0x20,0x7e,0x80,0x00,0x7c,0x14,0x10,0x50,0x5c,0x50,0x50,0x50,0xbe,0x00,
+/* 23258 0x5ada "嫚" */
+0x20,0x21,0x21,0x21,0xf9,0x49,0x48,0x4b,0x4a,0x93,0x50,0x21,0x30,0x48,0x49,0x86,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 23259 0x5adb "嫛" */
+0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23260 0x5adc "嫜" */
+0x20,0x21,0x20,0x20,0xfb,0x48,0x49,0x49,0x49,0x91,0x51,0x20,0x33,0x48,0x48,0x80,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23261 0x5add "嫝" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x49,0x29,0x11,0x29,0x46,0x82,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 23262 0x5ade "嫞" */
+0x20,0x23,0x22,0x22,0xfa,0x4b,0x4a,0x4a,0x8a,0x4a,0x32,0x12,0x2a,0x4c,0x84,0x08,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0xa4,0xfc,0xa4,0xfc,0xa4,0xac,
+/* 23263 0x5adf "嫟" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4a,0x4b,0x4a,0x92,0x53,0x22,0x32,0x4a,0x4b,0x80,
+0x00,0xfe,0x48,0x48,0xfe,0x48,0x20,0xfe,0x40,0xfc,0x44,0x44,0x7c,0x00,0xfe,0x00,
+/* 23264 0x5ae0 "嫠" */
+0x08,0x3e,0x08,0x7f,0x1c,0x2a,0x49,0x3f,0x21,0x21,0x3f,0x22,0x27,0x40,0x43,0x8c,
+0x20,0x7e,0xa4,0x28,0x10,0x28,0x44,0xfe,0x00,0x00,0xfe,0x10,0x20,0xc0,0x30,0x0c,
+/* 23265 0x5ae1 "嫡" */
+0x20,0x20,0x23,0x20,0xf8,0x4b,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 23266 0x5ae2 "嫢" */
+0x11,0x7d,0x11,0x11,0xfd,0x11,0x29,0x24,0x41,0x86,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x12,0x0e,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23267 0x5ae3 "嫣" */
+0x20,0x27,0x20,0x22,0xfa,0x4f,0x49,0x49,0x4a,0x93,0x50,0x25,0x35,0x48,0x48,0x80,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 23268 0x5ae4 "嫤" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x25,0x25,0x25,0x48,0x2b,0x10,0x29,0x44,0x83,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 23269 0x5ae5 "嫥" */
+0x10,0x13,0x10,0x11,0xfd,0x25,0x25,0x25,0x24,0x4b,0x28,0x13,0x29,0x44,0x84,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 23270 0x5ae6 "嫦" */
+0x20,0x21,0x20,0x23,0xfa,0x48,0x48,0x48,0x48,0x90,0x51,0x21,0x31,0x49,0x49,0x80,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 23271 0x5ae7 "嫧" */
+0x10,0x13,0x10,0x11,0xfc,0x27,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x84,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 23272 0x5ae8 "嫨" */
+0x10,0x10,0x13,0x10,0xfc,0x24,0x25,0x25,0x25,0x48,0x29,0x10,0x2b,0x44,0x80,0x03,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,
+/* 23273 0x5ae9 "嫩" */
+0x21,0x21,0x27,0x21,0xf1,0x57,0x55,0x55,0x57,0x91,0x53,0x25,0x29,0x51,0x51,0x81,
+0x08,0x08,0xc8,0x10,0x1e,0xe4,0x54,0x54,0xd4,0x14,0x94,0x48,0x48,0x14,0x14,0x22,
+/* 23274 0x5aea "嫪" */
+0x20,0x27,0x20,0x24,0xfa,0x4c,0x48,0x49,0x4e,0x90,0x53,0x20,0x33,0x48,0x48,0x87,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 23275 0x5aeb "嫫" */
+0x21,0x21,0x27,0x21,0xf8,0x4b,0x4a,0x4b,0x8a,0x4b,0x30,0x17,0x28,0x49,0x82,0x04,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 23276 0x5aec "嫬" */
+0x20,0x20,0x23,0x22,0xfa,0x4a,0x4b,0x4a,0x8a,0x4a,0x32,0x12,0x2d,0x45,0x8a,0x10,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 23277 0x5aed "嫭" */
+0x20,0x20,0x20,0x23,0xfa,0x4a,0x4b,0x4a,0x8a,0x4a,0x33,0x12,0x2d,0x44,0x88,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 23278 0x5aee "嫮" */
+0x11,0x10,0x13,0x12,0xfd,0x24,0x25,0x24,0x25,0x48,0x2b,0x10,0x28,0x44,0x84,0x00,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,
+/* 23279 0x5aef "嫯" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x82,0xff,0x08,0x1c,0x03,0x3c,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23280 0x5af0 "嫰" */
+0x21,0x21,0x27,0x21,0xf1,0x57,0x55,0x55,0x57,0x91,0x53,0x25,0x29,0x51,0x51,0x81,
+0x08,0x08,0xc8,0x08,0x1e,0xd2,0x64,0x40,0xc8,0x08,0x88,0x48,0x54,0x14,0x24,0x42,
+/* 23281 0x5af1 "嫱" */
+0x10,0x10,0x13,0x10,0xfd,0x24,0x27,0x24,0x25,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x20,0x20,0xfe,0x20,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 23282 0x5af2 "嫲" */
+0x20,0x20,0x27,0x24,0xf4,0x54,0x57,0x54,0x54,0x95,0x55,0x26,0x28,0x58,0x50,0x80,
+0x40,0x20,0xfe,0x90,0x90,0x90,0xfc,0x90,0xd8,0xb8,0xb4,0xd4,0x92,0x90,0x90,0x90,
+/* 23283 0x5af3 "嫳" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23284 0x5af4 "嫴" */
+0x10,0x13,0x10,0x11,0xfd,0x25,0x24,0x25,0x24,0x48,0x2b,0x10,0x29,0x44,0x84,0x00,
+0x20,0xfe,0x20,0xfc,0x04,0xfc,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x20,
+/* 23285 0x5af5 "嫵" */
+0x20,0x20,0x21,0x23,0xfd,0x49,0x4b,0x49,0x49,0x91,0x57,0x20,0x31,0x49,0x4a,0x80,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 23286 0x5af6 "嫶" */
+0x20,0x20,0x21,0x21,0xfb,0x4d,0x49,0x49,0x89,0x49,0x31,0x11,0x29,0x4a,0x82,0x04,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 23287 0x5af7 "嫷" */
+0x20,0x27,0x25,0x25,0xf5,0x56,0x55,0x55,0x55,0x95,0x55,0x26,0x24,0x54,0x54,0x84,
+0x20,0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 23288 0x5af8 "嫸" */
+0x10,0x10,0x13,0x10,0xfd,0x24,0x27,0x25,0x24,0x4b,0x28,0x11,0x29,0x45,0x85,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 23289 0x5af9 "嫹" */
+0x10,0x10,0x11,0x10,0xfc,0x27,0x24,0x25,0x25,0x49,0x29,0x11,0x28,0x44,0x81,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 23290 0x5afa "嫺" */
+0x23,0x22,0x23,0x22,0xfb,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4b,0x4a,0x82,
+0x9c,0x94,0x9c,0x94,0x9c,0x04,0xf4,0x94,0xf4,0x94,0xf4,0x94,0x94,0x34,0x04,0x0c,
+/* 23291 0x5afb "嫻" */
+0x20,0x23,0x22,0x23,0xfa,0x4b,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x33,0x4a,0x4a,0x82,
+0x00,0xde,0x52,0xde,0x52,0xde,0x22,0x22,0xfa,0x22,0x72,0xaa,0x26,0x22,0x2a,0x04,
+/* 23292 0x5afc "嫼" */
+0x20,0x21,0x21,0x21,0xf9,0x49,0x49,0x48,0x89,0x48,0x33,0x10,0x2a,0x4a,0x84,0x00,
+0x00,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 23293 0x5afd "嫽" */
+0x20,0x20,0x23,0x20,0xfa,0x49,0x4b,0x4d,0x49,0x91,0x51,0x20,0x31,0x4a,0x4c,0x80,
+0x20,0x20,0xfe,0x50,0x8a,0x04,0xfe,0x04,0xfc,0x04,0xfc,0x20,0x24,0x22,0xa2,0x40,
+/* 23294 0x5afe "嫾" */
+0x20,0x21,0x20,0x23,0xf8,0x49,0x4a,0x49,0x89,0x49,0x32,0x15,0x28,0x49,0x82,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 23295 0x5aff "嫿" */
+0x20,0x21,0x20,0x23,0xf8,0x49,0x48,0x4b,0x48,0x91,0x51,0x21,0x31,0x49,0x48,0x83,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 23296 0x5b00 "嬀" */
+0x20,0x20,0x27,0x22,0xf1,0x53,0x52,0x53,0x52,0x93,0x54,0x26,0x2a,0x5a,0x50,0x80,
+0x04,0x3e,0xc0,0x44,0x28,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 23297 0x5b01 "嬁" */
+0x20,0x27,0x20,0x22,0xf9,0x4a,0x4d,0x48,0x8b,0x4a,0x32,0x13,0x2a,0x41,0x8f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 23298 0x5b02 "嬂" */
+0x21,0x20,0x23,0x20,0xfa,0x49,0x4f,0x48,0x4b,0x92,0x52,0x23,0x32,0x4a,0x4b,0x80,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 23299 0x5b03 "嬃" */
+0x0b,0x10,0x61,0x09,0x11,0x61,0x05,0x09,0x31,0xc0,0x05,0xff,0x08,0x1e,0x03,0x3c,
+0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0xfe,0x20,0x40,0xc0,0x38,
+/* 23300 0x5b04 "嬄" */
+0x20,0x23,0x20,0x21,0xf8,0x4b,0x4a,0x49,0x48,0x91,0x51,0x21,0x31,0x48,0x4b,0x80,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 23301 0x5b05 "嬅" */
+0x10,0x13,0x10,0x10,0xfd,0x24,0x24,0x27,0x24,0x48,0x29,0x10,0x2b,0x44,0x84,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23302 0x5b06 "嬆" */
+0x20,0x20,0x21,0x26,0xf0,0x53,0x52,0x53,0x50,0x97,0x50,0x24,0x22,0x54,0x52,0x81,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 23303 0x5b07 "嬇" */
+0x10,0x11,0x11,0x11,0xfc,0x27,0x24,0x25,0x25,0x49,0x29,0x11,0x29,0x45,0x84,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 23304 0x5b08 "嬈" */
+0x20,0x20,0x21,0x20,0xfb,0x49,0x4b,0x49,0x49,0x96,0x50,0x23,0x30,0x48,0x49,0x82,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 23305 0x5b09 "嬉" */
+0x10,0x13,0x10,0x11,0xfc,0x25,0x25,0x25,0x24,0x4b,0x28,0x11,0x29,0x45,0x85,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 23306 0x5b0a "嬊" */
+0x04,0xff,0x04,0x17,0xf0,0x17,0x34,0xd7,0x10,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x40,0xfe,0x40,0xd0,0x12,0xdc,0x52,0xd2,0x0e,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23307 0x5b0b "嬋" */
+0x20,0x23,0x22,0x22,0xfb,0x48,0x49,0x49,0x49,0x91,0x51,0x20,0x33,0x48,0x48,0x80,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23308 0x5b0c "嬌" */
+0x10,0x11,0x10,0x13,0xfc,0x25,0x26,0x24,0x24,0x49,0x29,0x11,0x29,0x45,0x85,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 23309 0x5b0d "嬍" */
+0x21,0x25,0x25,0x25,0xf7,0x50,0x57,0x50,0x57,0x91,0x57,0x21,0x21,0x5f,0x50,0x80,
+0x08,0x48,0x48,0x50,0xde,0x14,0xe4,0x14,0xd4,0x14,0xd4,0x08,0x08,0xd4,0x24,0x42,
+/* 23310 0x5b0e "嬎" */
+0x22,0x22,0x23,0x24,0xf9,0x57,0x55,0x55,0x55,0x97,0x52,0x22,0x22,0x54,0x54,0x88,
+0x00,0x08,0xa8,0xa8,0x3e,0xc8,0x48,0x5c,0x48,0xc8,0xbe,0x80,0x82,0x82,0x7e,0x00,
+/* 23311 0x5b0f "嬏" */
+0x20,0x23,0x21,0x20,0xfb,0x48,0x49,0x4a,0x49,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 23312 0x5b10 "嬐" */
+0x10,0x10,0x10,0x10,0xfd,0x26,0x24,0x24,0x25,0x49,0x29,0x11,0x28,0x44,0x85,0x02,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 23313 0x5b11 "嬑" */
+0x20,0x20,0x21,0x20,0xf8,0x4b,0x48,0x49,0x49,0x91,0x51,0x21,0x30,0x4a,0x4a,0x84,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 23314 0x5b12 "嬒" */
+0x10,0x10,0x10,0x11,0xfe,0x25,0x25,0x25,0x25,0x49,0x28,0x10,0x28,0x44,0x84,0x00,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 23315 0x5b13 "嬓" */
+0x21,0x22,0x27,0x24,0xf7,0x54,0x57,0x52,0x51,0x97,0x52,0x23,0x22,0x54,0x55,0x88,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 23316 0x5b14 "嬔" */
+0x22,0x22,0x23,0x24,0xf9,0x57,0x55,0x55,0x55,0x97,0x52,0x22,0x22,0x54,0x54,0x88,
+0x00,0x08,0x88,0xa8,0x3e,0xc8,0x48,0x7e,0x48,0xc8,0xbe,0x80,0xa2,0x92,0x7e,0x00,
+/* 23317 0x5b15 "嬕" */
+0x10,0x11,0x11,0x11,0xfc,0x25,0x24,0x27,0x24,0x48,0x29,0x10,0x2b,0x44,0x84,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23318 0x5b16 "嬖" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23319 0x5b17 "嬗" */
+0x20,0x23,0x20,0x23,0xfa,0x4a,0x4a,0x4b,0x48,0x91,0x51,0x21,0x31,0x49,0x48,0x83,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 23320 0x5b18 "嬘" */
+0x20,0x24,0x22,0x20,0xf8,0x48,0x4e,0x4a,0x8a,0x4a,0x32,0x12,0x2a,0x4a,0x85,0x08,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 23321 0x5b19 "嬙" */
+0x20,0x20,0x23,0x21,0xf9,0x4a,0x4f,0x48,0x49,0x91,0x51,0x21,0x31,0x49,0x49,0x81,
+0x20,0x20,0xfe,0x24,0x24,0xaa,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 23322 0x5b1a "嬚" */
+0x20,0x23,0x22,0x22,0xfb,0x4a,0x4a,0x4a,0x8b,0x4a,0x32,0x12,0x2a,0x4d,0x86,0x08,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 23323 0x5b1b "嬛" */
+0x20,0x23,0x22,0x22,0xfb,0x48,0x4f,0x48,0x4b,0x92,0x53,0x20,0x31,0x4b,0x4d,0x81,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 23324 0x5b1c "嬜" */
+0x10,0x7e,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x20,0x20,0x3e,0x42,0x94,0x10,0x28,0x28,0x44,0x82,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23325 0x5b1d "嬝" */
+0x20,0x23,0x22,0x23,0xfa,0x4b,0x4a,0x4b,0x8a,0x4b,0x30,0x13,0x28,0x49,0x86,0x00,
+0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xfc,0x44,0xfc,0xa0,0x94,0xc8,0x86,
+/* 23326 0x5b1e "嬞" */
+0x20,0x23,0x20,0x21,0xf8,0x4b,0x48,0x49,0x49,0x91,0x51,0x21,0x30,0x4b,0x48,0x87,
+0x88,0xfe,0x88,0xfc,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfe,
+/* 23327 0x5b1f "嬟" */
+0x21,0x20,0x23,0x20,0xf9,0x48,0x4b,0x48,0x49,0x90,0x53,0x20,0x30,0x4b,0x48,0x81,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 23328 0x5b20 "嬠" */
+0x10,0x10,0x10,0x10,0xfc,0x25,0x25,0x25,0x25,0x48,0x2b,0x10,0x28,0x45,0x82,0x00,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23329 0x5b21 "嬡" */
+0x20,0x23,0x20,0x22,0xf1,0x57,0x54,0x52,0x52,0x94,0x50,0x20,0x21,0x52,0x50,0x87,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 23330 0x5b22 "嬢" */
+0x20,0x20,0x27,0x21,0xfa,0x4d,0x4b,0x49,0x4b,0x91,0x57,0x21,0x33,0x4d,0x49,0x81,
+0x80,0x40,0xfe,0x10,0x08,0x14,0xf8,0x10,0xf8,0x10,0xfc,0x28,0x10,0x48,0x86,0x00,
+/* 23331 0x5b23 "嬣" */
+0x20,0x20,0x23,0x22,0xf9,0x49,0x4a,0x48,0x49,0x91,0x53,0x20,0x31,0x48,0x48,0x80,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 23332 0x5b24 "嬤" */
+0x20,0x20,0x27,0x24,0xf7,0x54,0x55,0x56,0x54,0x94,0x54,0x25,0x24,0x54,0x59,0x90,
+0x40,0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x40,0x88,0xf0,0x20,0x48,0xfc,0x84,
+/* 23333 0x5b25 "嬥" */
+0x20,0x23,0x20,0x22,0xf9,0x4a,0x48,0x49,0x4b,0x95,0x51,0x21,0x31,0x49,0x49,0x81,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 23334 0x5b26 "嬦" */
+0x20,0x27,0x20,0x23,0xf0,0x57,0x50,0x53,0x50,0x97,0x50,0x27,0x20,0x57,0x54,0x87,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 23335 0x5b27 "嬧" */
+0x20,0x23,0x20,0x27,0xf8,0x4b,0x48,0x4f,0x48,0x92,0x54,0x23,0x32,0x4a,0x4f,0x80,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 23336 0x5b28 "嬨" */
+0x21,0x20,0x23,0x21,0xf9,0x4a,0x4b,0x49,0x8a,0x4b,0x30,0x10,0x2a,0x4a,0x84,0x00,
+0x08,0x90,0xfe,0x08,0x08,0x52,0x9c,0x08,0x52,0xde,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 23337 0x5b29 "嬩" */
+0x21,0x22,0x22,0x22,0xfb,0x4a,0x4a,0x4b,0x8a,0x4a,0x37,0x10,0x29,0x49,0x82,0x04,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 23338 0x5b2a "嬪" */
+0x20,0x20,0x23,0x22,0xf9,0x49,0x4a,0x49,0x4b,0x91,0x51,0x21,0x31,0x49,0x48,0x81,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 23339 0x5b2b "嬫" */
+0x20,0x22,0x22,0x24,0xf9,0x4a,0x48,0x4b,0x8a,0x48,0x33,0x10,0x28,0x49,0x86,0x00,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x22,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23340 0x5b2c "嬬" */
+0x20,0x21,0x20,0x23,0xfa,0x49,0x48,0x49,0x48,0x93,0x50,0x21,0x31,0x49,0x49,0x81,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 23341 0x5b2d "嬭" */
+0x20,0x27,0x22,0x24,0xff,0x54,0x56,0x55,0x56,0x94,0x56,0x25,0x26,0x54,0x54,0x84,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 23342 0x5b2e "嬮" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x20,0x3f,0x22,0x27,0x40,0x43,0x9c,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0x94,0xa2,0x80,0xfe,0x08,0x10,0xe0,0x1c,0x02,
+/* 23343 0x5b2f "嬯" */
+0x20,0x2f,0x20,0x27,0xf0,0x53,0x52,0x5f,0x58,0x97,0x51,0x23,0x20,0x57,0x50,0x8f,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xfc,0x40,0xfe,
+/* 23344 0x5b30 "嬰" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x22,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23345 0x5b31 "嬱" */
+0x42,0x2f,0x82,0x4f,0x0a,0x2f,0x4a,0xcf,0x42,0x5f,0x42,0xff,0x08,0x1c,0x03,0x3c,
+0x0c,0xb0,0x20,0xa0,0xbe,0xa8,0xa8,0xa8,0x28,0xa8,0x48,0xfe,0x20,0x40,0xc0,0x38,
+/* 23346 0x5b32 "嬲" */
+0x00,0xf9,0xa9,0xa9,0xf9,0xaf,0xaa,0xfa,0x42,0x44,0xfa,0x49,0x49,0x4a,0xac,0x10,
+0x00,0x3e,0x2a,0x2a,0x3e,0xaa,0xaa,0xbe,0x90,0x90,0xbe,0x12,0x12,0x92,0xaa,0x44,
+/* 23347 0x5b33 "嬳" */
+0x10,0x13,0x10,0x10,0xfd,0x27,0x25,0x25,0x25,0x49,0x29,0x11,0x2b,0x44,0x80,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 23348 0x5b34 "嬴" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x01,0x79,0x4f,0x7a,0x4a,0x79,0x4a,0x9c,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x38,0xa8,0xa8,0xb8,0x2a,0xaa,0x46,
+/* 23349 0x5b35 "嬵" */
+0x21,0x21,0x22,0x22,0xf4,0x57,0x51,0x52,0x54,0x97,0x50,0x20,0x25,0x55,0x54,0x80,
+0x08,0x10,0x3e,0x22,0xbe,0x22,0x3e,0x08,0xbe,0xaa,0x2a,0xaa,0x6a,0x2e,0x08,0x08,
+/* 23350 0x5b36 "嬶" */
+0x10,0x10,0x10,0x10,0xfc,0x24,0x24,0x25,0x25,0x49,0x29,0x11,0x28,0x47,0x84,0x01,
+0x40,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x88,0x08,
+/* 23351 0x5b37 "嬷" */
+0x20,0x20,0x27,0x24,0xf7,0x54,0x55,0x56,0x54,0x94,0x54,0x25,0x24,0x54,0x55,0x88,
+0x40,0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x40,0x90,0x20,0x48,0x84,0xfc,0x84,
+/* 23352 0x5b38 "嬸" */
+0x20,0x23,0x22,0x24,0xfb,0x49,0x48,0x4b,0x49,0x92,0x55,0x21,0x31,0x49,0x49,0x81,
+0x20,0xfe,0x02,0x1c,0xe0,0x24,0xa8,0xfe,0x24,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 23353 0x5b39 "嬹" */
+0x22,0x24,0x24,0x24,0xf6,0x54,0x54,0x56,0x54,0x94,0x5f,0x20,0x21,0x51,0x52,0x84,
+0x00,0xec,0xa4,0xa4,0xec,0xa4,0xa4,0xec,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 23354 0x5b3a "嬺" */
+0x23,0x22,0x23,0x22,0xfa,0x4b,0x4a,0x4a,0x8b,0x4a,0x32,0x13,0x28,0x4a,0x82,0x04,
+0xfe,0x48,0xfe,0x48,0x20,0xfe,0x40,0xfc,0x44,0x7c,0x00,0xfe,0x40,0xa4,0x8a,0x7a,
+/* 23355 0x5b3b "嬻" */
+0x20,0x23,0x20,0x21,0xf8,0x4b,0x4a,0x4b,0x49,0x91,0x51,0x21,0x31,0x49,0x48,0x81,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 23356 0x5b3c "嬼" */
+0x22,0x25,0x24,0x26,0xf5,0x56,0x51,0x52,0x54,0x9b,0x51,0x27,0x21,0x55,0x51,0x8e,
+0x02,0xe2,0xa2,0xaa,0x2a,0x6a,0x0a,0x8a,0x4a,0xaa,0x0a,0xca,0x22,0x42,0xea,0x04,
+/* 23357 0x5b3d "嬽" */
+0x23,0x22,0x23,0x20,0xf7,0x54,0x55,0x55,0x55,0x94,0x57,0x20,0x27,0x50,0x51,0x86,
+0xfa,0xaa,0xfa,0x02,0xfe,0x00,0xfc,0x54,0xfc,0x00,0xfe,0x40,0xfe,0xa0,0x18,0x06,
+/* 23358 0x5b3e "嬾" */
+0x21,0x21,0x27,0x21,0xf1,0x57,0x55,0x55,0x57,0x91,0x53,0x25,0x29,0x51,0x51,0x81,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 23359 0x5b3f "嬿" */
+0x21,0x21,0x27,0x21,0xf1,0x52,0x52,0x56,0x52,0x92,0x56,0x2a,0x20,0x52,0x52,0x84,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 23360 0x5b40 "孀" */
+0x21,0x20,0x23,0x22,0xf9,0x48,0x49,0x48,0x48,0x93,0x50,0x21,0x32,0x4c,0x48,0x80,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0x9e,0xf2,0x9e,0xd2,0xbe,0x92,0x9e,0x92,
+/* 23361 0x5b41 "孁" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3b,0x2a,0x3b,0x04,0xff,0x08,0x07,0x78,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xb8,0xa8,0xb8,0x00,0xfe,0x20,0xc0,0x38,
+/* 23362 0x5b42 "孂" */
+0x22,0x23,0x25,0x20,0xfb,0x4a,0x4b,0x4a,0x8b,0x4a,0x32,0x13,0x28,0x4b,0x82,0x0f,
+0x10,0xde,0x28,0x84,0xf8,0x08,0xf8,0x08,0xfa,0x24,0x98,0x06,0x00,0xfc,0x94,0xfe,
+/* 23363 0x5b43 "孃" */
+0x20,0x27,0x20,0x23,0xfa,0x4b,0x49,0x4f,0x49,0x97,0x51,0x27,0x31,0x4b,0x4d,0x81,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 23364 0x5b44 "孄" */
+0x23,0x22,0x23,0x22,0xfb,0x4a,0x4a,0x4a,0x4a,0x92,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 23365 0x5b45 "孅" */
+0x21,0x21,0x22,0x20,0xf7,0x51,0x53,0x51,0x53,0x91,0x53,0x21,0x21,0x53,0x50,0x80,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 23366 0x5b46 "孆" */
+0x23,0x22,0x23,0x22,0xfb,0x4a,0x4b,0x49,0x4a,0x90,0x57,0x20,0x31,0x48,0x48,0x83,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 23367 0x5b47 "孇" */
+0x21,0x22,0x23,0x26,0xfb,0x4a,0x4b,0x4a,0x4b,0x92,0x57,0x21,0x30,0x48,0x49,0x86,
+0x08,0x94,0xde,0xb4,0xde,0x94,0xde,0x94,0xde,0x10,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 23368 0x5b48 "孈" */
+0x22,0x23,0x20,0x21,0xfb,0x4d,0x49,0x49,0x49,0x91,0x51,0x23,0x32,0x4b,0x4a,0x82,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 23369 0x5b49 "孉" */
+0x20,0x23,0x20,0x23,0xfa,0x4b,0x48,0x48,0x49,0x91,0x53,0x25,0x31,0x49,0x49,0x81,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 23370 0x5b4a "孊" */
+0x20,0x23,0x22,0x23,0xfa,0x4a,0x4b,0x4a,0x8a,0x4b,0x32,0x13,0x2a,0x4d,0x84,0x08,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 23371 0x5b4b "孋" */
+0x23,0x20,0x23,0x22,0xfb,0x4a,0x48,0x4b,0x4a,0x93,0x52,0x23,0x32,0x4a,0x4a,0x84,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 23372 0x5b4c "孌" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 23373 0x5b4d "孍" */
+0x27,0x24,0x27,0x20,0xf7,0x54,0x55,0x54,0x57,0x95,0x55,0x25,0x25,0x55,0x5b,0x90,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 23374 0x5b4e "孎" */
+0x23,0x22,0x23,0x22,0xfa,0x4a,0x4a,0x4a,0x4a,0x93,0x52,0x22,0x32,0x4a,0x4d,0x80,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 23375 0x5b4f "孏" */
+0x20,0x23,0x20,0x23,0xfa,0x4b,0x4a,0x4b,0x4a,0x93,0x52,0x22,0x32,0x4a,0x4a,0x82,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0xaa,0xfa,0x22,0x72,0xaa,0x24,
+/* 23376 0x5b50 "子" */
+0x00,0x7f,0x00,0x00,0x00,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23377 0x5b51 "孑" */
+0x00,0x7f,0x00,0x00,0x00,0x01,0x01,0x01,0x03,0x1d,0xe1,0x41,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x10,0x20,0x40,0x84,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23378 0x5b52 "孒" */
+0x00,0x7f,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23379 0x5b53 "孓" */
+0x00,0x7f,0x00,0x00,0x20,0x11,0x09,0x05,0x03,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x80,0x40,0x30,0x0c,0x00,0x00,
+/* 23380 0x5b54 "孔" */
+0x00,0x7e,0x02,0x04,0x08,0x08,0x0a,0x0c,0x38,0xc8,0x08,0x08,0x08,0x08,0x28,0x10,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 23381 0x5b55 "孕" */
+0x00,0x3f,0x08,0x08,0x08,0x10,0x17,0x20,0x40,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf0,0x10,0x20,0x3c,0x04,0xc4,0x54,0x88,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 23382 0x5b56 "孖" */
+0x00,0x7e,0x02,0x04,0x08,0x08,0x0a,0x0d,0x38,0xc8,0x08,0x08,0x08,0x08,0x28,0x10,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 23383 0x5b57 "字" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0x01,0xff,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x02,0x04,0xe0,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23384 0x5b58 "存" */
+0x04,0x04,0xff,0x08,0x08,0x13,0x10,0x30,0x50,0x97,0x10,0x10,0x10,0x10,0x11,0x10,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x10,0x20,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 23385 0x5b59 "孙" */
+0x00,0x7e,0x02,0x04,0x08,0x08,0x0a,0x0c,0x39,0xc9,0x0a,0x08,0x08,0x08,0x28,0x10,
+0x20,0x20,0x20,0x20,0x20,0xa8,0xa4,0xa4,0x22,0x22,0x22,0x20,0x20,0x20,0xa0,0x40,
+/* 23386 0x5b5a "孚" */
+0x00,0x7f,0x22,0x11,0x11,0x00,0x1f,0x00,0x00,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0xf8,0x00,0x10,0x10,0x20,0x00,0xe0,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 23387 0x5b5b "孛" */
+0x01,0x01,0x3f,0x01,0x01,0x7f,0x40,0x80,0x0f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x02,0x04,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 23388 0x5b5c "孜" */
+0x00,0xfc,0x04,0x08,0x10,0x11,0x16,0x18,0x30,0xd0,0x10,0x10,0x10,0x10,0x51,0x22,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 23389 0x5b5d "孝" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x3f,0x10,0x20,0x5f,0x80,0x00,0x02,0x01,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0xe0,0x40,0x80,0xfc,0x80,0x80,0x80,0x00,
+/* 23390 0x5b5e "孞" */
+0x00,0x1f,0x00,0x00,0x01,0xff,0x01,0x01,0x05,0x02,0x09,0x49,0x48,0x48,0x87,0x00,
+0x00,0xe0,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x10,0x08,0x24,0x24,0xe0,0x00,
+/* 23391 0x5b5f "孟" */
+0x00,0x1f,0x00,0x01,0xff,0x01,0x01,0x05,0x02,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 23392 0x5b60 "孠" */
+0x00,0x3f,0x00,0x7f,0x00,0x3f,0x20,0x3f,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x00,0xf8,0x08,0xc8,0x08,0x88,0x88,0xa8,0x10,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23393 0x5b61 "孡" */
+0x00,0x7e,0x02,0x04,0x08,0x08,0x0b,0x0c,0x38,0xc8,0x08,0x08,0x08,0x08,0x28,0x10,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 23394 0x5b62 "孢" */
+0x00,0xfc,0x05,0x09,0x12,0x15,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x11,0x50,0x20,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 23395 0x5b63 "季" */
+0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xcf,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x70,0x80,0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 23396 0x5b64 "孤" */
+0x00,0xf8,0x0b,0x12,0x22,0x22,0x2a,0x32,0x22,0xe2,0x22,0x22,0x22,0x24,0xa4,0x48,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 23397 0x5b65 "孥" */
+0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x00,0x00,0xfc,0x44,0x28,0x10,0x28,0xc6,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23398 0x5b66 "学" */
+0x22,0x11,0x11,0x00,0x7f,0x40,0x80,0x1f,0x00,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0x08,0x08,0x10,0x20,0xfe,0x02,0x04,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 23399 0x5b67 "孧" */
+0x08,0x10,0x22,0x7c,0x08,0x12,0x7f,0x00,0x01,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x20,0x20,0xfc,0x24,0x24,0x44,0x54,0x88,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23400 0x5b68 "孨" */
+0x00,0x1f,0x00,0x01,0xff,0x01,0x01,0x05,0x7a,0x08,0x10,0x1e,0xf0,0x10,0x50,0x20,
+0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,0x7c,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 23401 0x5b69 "孩" */
+0x00,0xfc,0x04,0x0b,0x10,0x10,0x14,0x19,0x30,0xd0,0x10,0x13,0x10,0x10,0x50,0x23,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 23402 0x5b6a "孪" */
+0x02,0x01,0xff,0x04,0x14,0x14,0x24,0x44,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x44,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23403 0x5b6b "孫" */
+0x00,0xfd,0x04,0x08,0x10,0x11,0x14,0x18,0x31,0xd0,0x10,0x10,0x11,0x12,0x50,0x20,
+0x0c,0xf0,0x20,0x44,0x88,0xf0,0x20,0x44,0xfe,0x22,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 23404 0x5b6c "孬" */
+0x7f,0x00,0x03,0x0d,0x71,0x01,0x10,0x10,0xfe,0x22,0x22,0x64,0x14,0x08,0x34,0xc2,
+0xfc,0x80,0x60,0x18,0x04,0x00,0x00,0xfc,0x04,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 23405 0x5b6d "孭" */
+0x00,0xfd,0x05,0x09,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x10,0x51,0x22,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 23406 0x5b6e "孮" */
+0x00,0xfc,0x07,0x0a,0x10,0x11,0x14,0x18,0x33,0xd0,0x11,0x11,0x12,0x14,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 23407 0x5b6f "孯" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23408 0x5b70 "孰" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x01,0x7e,0x04,0x08,0x0e,0xf8,0x08,0x29,0x12,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0xc8,0x48,0x68,0x5a,0x8a,0x8a,0x06,0x02,
+/* 23409 0x5b71 "孱" */
+0x3f,0x20,0x3f,0x20,0x23,0x20,0x3f,0x20,0x20,0x2f,0x21,0x23,0x5e,0x42,0x8a,0x04,
+0xfc,0x04,0xfc,0x00,0xf0,0x20,0xfe,0x40,0xc0,0xbe,0x04,0x88,0x7e,0x08,0x28,0x10,
+/* 23410 0x5b72 "孲" */
+0x00,0xfd,0x04,0x08,0x10,0x11,0x15,0x19,0x31,0xd1,0x10,0x10,0x10,0x10,0x53,0x20,
+0x00,0xfe,0x48,0x48,0x48,0xce,0x02,0x02,0x02,0xce,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 23411 0x5b73 "孳" */
+0x08,0x04,0x7f,0x12,0x3c,0x08,0x14,0x3e,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x20,0x40,0xfc,0x48,0xf0,0x20,0x50,0xf8,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23412 0x5b74 "孴" */
+0x1f,0x00,0xff,0x01,0x03,0x7c,0x08,0x1e,0xf0,0x10,0x30,0x1f,0x10,0x1f,0x10,0x1f,
+0xe0,0x40,0xfe,0x00,0x00,0x7c,0x08,0xfe,0x10,0x50,0x20,0xf0,0x10,0xf0,0x10,0xf0,
+/* 23413 0x5b75 "孵" */
+0x20,0xce,0x8a,0xaa,0xaa,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0xa8,0x28,0x48,0x48,0x88,
+0x0e,0xf0,0x22,0x92,0x54,0x00,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 23414 0x5b76 "孶" */
+0x08,0xff,0x08,0x12,0x3c,0x08,0x14,0x3e,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x20,0xfe,0x20,0x48,0xf0,0x20,0x50,0xf8,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23415 0x5b77 "孷" */
+0x08,0x3e,0x08,0x7f,0x1c,0x2a,0x49,0x3f,0x20,0x23,0x20,0x20,0x2f,0x40,0x41,0x80,
+0x20,0x7e,0xa4,0x28,0x10,0x28,0x44,0xfe,0x00,0xf0,0x20,0x40,0xfe,0x40,0x40,0x80,
+/* 23416 0x5b78 "學" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x40,0xbf,0x00,0x01,0xff,0x01,0x05,0x02,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0xe4,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23417 0x5b79 "孹" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x00,0x3f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xe0,0x80,0x00,0xfe,0x00,0x00,0x00,
+/* 23418 0x5b7a "孺" */
+0x00,0xfd,0x04,0x0b,0x12,0x11,0x14,0x19,0x30,0xd3,0x10,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 23419 0x5b7b "孻" */
+0x00,0xfd,0x04,0x0b,0x10,0x11,0x14,0x1b,0x30,0xd2,0x14,0x11,0x11,0x11,0x57,0x20,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xa4,0x52,0xfc,0x54,0x54,0xfe,0x00,
+/* 23420 0x5b7c "孼" */
+0x52,0x7e,0x28,0x7e,0xa2,0x3e,0x20,0x3e,0x22,0x3e,0x00,0x1f,0x00,0xff,0x01,0x03,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x00,0xe0,0x40,0xfe,0x00,0x00,
+/* 23421 0x5b7d "孽" */
+0x08,0xff,0x28,0x7d,0x44,0x7c,0x41,0x7c,0x45,0x7c,0x00,0x1f,0x00,0xff,0x01,0x03,
+0x20,0xfe,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x00,0xe0,0x40,0xfe,0x00,0x00,
+/* 23422 0x5b7e "孾" */
+0x03,0xfa,0x0b,0x12,0x23,0x22,0x2b,0x31,0x22,0xe0,0x27,0x20,0x21,0x20,0xa0,0x43,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 23423 0x5b7f "孿" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x00,0x1f,0x00,0xff,0x01,0x03,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xe0,0x40,0xfe,0x00,0x00,
+/* 23424 0x5b80 "宀" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23425 0x5b81 "宁" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23426 0x5b82 "宂" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x00,0x0f,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 23427 0x5b83 "它" */
+0x02,0x01,0x7f,0x40,0x80,0x08,0x08,0x08,0x09,0x0e,0x08,0x08,0x08,0x08,0x07,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x08,0x30,0xc0,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 23428 0x5b84 "宄" */
+0x02,0x01,0x01,0x7f,0x40,0x82,0x02,0x1f,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 23429 0x5b85 "宅" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x03,0x3e,0x02,0x03,0xfe,0x02,0x02,0x02,0x01,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x20,0xf0,0x00,0x00,0xfc,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 23430 0x5b86 "宆" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x00,0x00,0x3f,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 23431 0x5b87 "宇" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23432 0x5b88 "守" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x00,0xff,0x00,0x00,0x10,0x08,0x08,0x00,0x01,0x00,
+0x00,0x00,0xfe,0x02,0x44,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 23433 0x5b89 "安" */
+0x02,0x01,0x3f,0x20,0x42,0x02,0x02,0xff,0x04,0x08,0x18,0x06,0x01,0x02,0x0c,0x70,
+0x00,0x00,0xfc,0x04,0x08,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x80,0x60,0x10,0x08,
+/* 23434 0x5b8a "宊" */
+0x02,0x01,0x01,0x7f,0x40,0x81,0x01,0x01,0x7f,0x01,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x20,0x10,0xfc,0x00,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 23435 0x5b8b "宋" */
+0x02,0x01,0x7f,0x40,0x81,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 23436 0x5b8c "完" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 23437 0x5b8d "宍" */
+0x02,0x01,0x7f,0x40,0x82,0x01,0x00,0x00,0xff,0x00,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x80,0x00,0xfe,0x00,0x40,0x20,0x10,0x08,0x04,0x04,
+/* 23438 0x5b8e "宎" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x3f,0x01,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0x00,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 23439 0x5b8f "宏" */
+0x02,0x01,0x7f,0x40,0x82,0x02,0x7f,0x04,0x04,0x08,0x09,0x11,0x22,0x44,0x8f,0x04,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x80,0x80,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 23440 0x5b90 "宐" */
+0x02,0x01,0x7f,0x40,0x84,0x04,0x07,0x08,0x08,0x14,0x22,0x01,0x00,0x00,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0xfe,0x00,
+/* 23441 0x5b91 "宑" */
+0x02,0x01,0x7f,0x40,0x88,0x08,0x3f,0x08,0x08,0x08,0xff,0x08,0x10,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x24,0x20,0xf8,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 23442 0x5b92 "宒" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x3f,0x01,0x01,0x3f,0x01,0x01,0x7f,0x01,0x01,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfc,0x02,0x02,0x02,0xfe,
+/* 23443 0x5b93 "宓" */
+0x02,0x01,0x01,0x7f,0x40,0x81,0x00,0x08,0x48,0x48,0x48,0x89,0x0e,0x18,0xe7,0x00,
+0x00,0x00,0x00,0xfe,0x02,0x04,0x90,0x90,0x24,0x42,0x82,0x02,0x10,0x10,0xf0,0x00,
+/* 23444 0x5b94 "宔" */
+0x02,0x01,0x7f,0x40,0x82,0x01,0x7f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 23445 0x5b95 "宕" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x7f,0x04,0x04,0x08,0x1f,0x28,0xc8,0x08,0x0f,0x08,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23446 0x5b96 "宖" */
+0x02,0x01,0x7f,0x40,0x80,0x7e,0x02,0x02,0x3e,0x20,0x40,0x7e,0x02,0x02,0x14,0x08,
+0x00,0x00,0xfe,0x02,0x04,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 23447 0x5b97 "宗" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0x7f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 23448 0x5b98 "官" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 23449 0x5b99 "宙" */
+0x02,0x01,0x7f,0x40,0x81,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23450 0x5b9a "定" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x3f,0x01,0x01,0x11,0x11,0x11,0x11,0x29,0x47,0x80,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 23451 0x5b9b "宛" */
+0x02,0x01,0x7f,0x40,0x90,0x1e,0x12,0x22,0x22,0x52,0x8c,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x88,0x88,0x88,0xa8,0x90,0x82,0x82,0x82,0x7e,0x00,
+/* 23452 0x5b9c "宜" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 23453 0x5b9d "宝" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x7f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x20,0x10,0xfe,0x00,
+/* 23454 0x5b9e "实" */
+0x02,0x01,0x7f,0x40,0x88,0x04,0x04,0x10,0x08,0x08,0xff,0x01,0x02,0x04,0x18,0x60,
+0x00,0x00,0xfe,0x02,0x84,0x80,0x80,0x80,0x80,0x80,0xfe,0x40,0x20,0x10,0x08,0x04,
+/* 23455 0x5b9f "実" */
+0x02,0x01,0x7f,0x40,0x81,0x01,0x3f,0x01,0x1f,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,
+/* 23456 0x5ba0 "宠" */
+0x02,0x01,0x7f,0x40,0x84,0x04,0x04,0xff,0x04,0x08,0x08,0x10,0x10,0x20,0x41,0x86,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x10,0xfe,0x80,0x88,0x90,0xa0,0xc2,0x82,0x82,0x7e,
+/* 23457 0x5ba1 "审" */
+0x02,0x01,0x7f,0x41,0x81,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 23458 0x5ba2 "客" */
+0x02,0x01,0x7f,0x40,0x88,0x0f,0x10,0x2c,0x03,0x1c,0xe0,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x10,
+/* 23459 0x5ba3 "宣" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x00,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x00,0xfe,0x00,
+/* 23460 0x5ba4 "室" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x04,0x08,0x1f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0x20,0xf0,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 23461 0x5ba5 "宥" */
+0x02,0x01,0x7f,0x42,0x82,0x7f,0x04,0x0f,0x18,0x2f,0x48,0x8f,0x08,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 23462 0x5ba6 "宦" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x21,0x21,0x3f,0x20,0x20,0x20,0x3f,0x21,0x21,0x3f,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0xfc,
+/* 23463 0x5ba7 "宧" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xfc,0x80,0x80,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfe,0x00,
+/* 23464 0x5ba8 "宨" */
+0x02,0x01,0x7f,0x40,0x80,0x04,0x44,0x24,0x24,0x0c,0x34,0xc8,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x04,0x40,0x48,0x50,0x60,0x40,0x60,0x52,0x4a,0x42,0x3e,0x00,
+/* 23465 0x5ba9 "宩" */
+0x02,0x01,0x7f,0x41,0x91,0x09,0x05,0x01,0x7f,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x14,0x20,0x40,0x00,0xfc,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 23466 0x5baa "宪" */
+0x02,0x01,0x7f,0x40,0x81,0x11,0x1f,0x21,0x01,0xff,0x04,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0xfe,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 23467 0x5bab "宫" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23468 0x5bac "宬" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x2a,0x44,0x41,0x86,
+0x00,0x00,0xfe,0x02,0x94,0x88,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 23469 0x5bad "宭" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x04,0xff,0x04,0x3f,0x08,0x1f,0x28,0x48,0x8f,0x08,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 23470 0x5bae "宮" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x02,0x04,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 23471 0x5baf "宯" */
+0x02,0x01,0x7f,0x40,0x81,0x1f,0x01,0xff,0x01,0x1f,0x08,0x30,0xcf,0x00,0x02,0x01,
+0x00,0x00,0xfe,0x02,0x0c,0xd0,0x20,0xfe,0x00,0xf0,0x20,0xc0,0xfc,0x80,0x80,0x00,
+/* 23472 0x5bb0 "宰" */
+0x02,0x01,0x7f,0x42,0x81,0x3f,0x00,0x08,0x04,0xff,0x01,0x01,0x7f,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0x20,0x40,0xfe,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 23473 0x5bb1 "宱" */
+0x02,0x01,0x7f,0x40,0x88,0x08,0x10,0x11,0x32,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x02,0x84,0x80,0xfe,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 23474 0x5bb2 "宲" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 23475 0x5bb3 "害" */
+0x02,0x01,0x7f,0x40,0x81,0x3f,0x01,0x1f,0x01,0xff,0x01,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 23476 0x5bb4 "宴" */
+0x02,0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x08,0x1c,0x03,0x0c,0x30,
+0x00,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 23477 0x5bb5 "宵" */
+0x02,0x01,0x7f,0x40,0x91,0x09,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x02,0x14,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 23478 0x5bb6 "家" */
+0x02,0x01,0x7f,0x40,0x80,0x7f,0x02,0x0d,0x71,0x02,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0x00,0xfe,0x02,0x04,0xfc,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 23479 0x5bb7 "宷" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x11,0x09,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x02,0xf4,0x00,0x10,0x20,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 23480 0x5bb8 "宸" */
+0x02,0x01,0x7f,0x40,0x80,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x24,0x44,0x45,0x86,0x04,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x00,0xfc,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 23481 0x5bb9 "容" */
+0x02,0x01,0x7f,0x40,0x88,0x11,0x22,0x04,0x08,0x30,0xdf,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x88,0x40,0x20,0x18,0xf6,0x10,0x10,0x10,0xf0,0x10,
+/* 23482 0x5bba "宺" */
+0x02,0x01,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x00,0xff,0x09,0x09,0x11,0x11,0x21,0x41,
+0x00,0x00,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x00,0xfe,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 23483 0x5bbb "宻" */
+0x02,0x01,0x7f,0x40,0xbf,0x10,0x48,0x24,0x03,0x1c,0xe0,0x01,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x02,0xf4,0x10,0x24,0x48,0x80,0x70,0x0e,0x00,0x08,0x08,0xf8,0x08,
+/* 23484 0x5bbc "宼" */
+0x02,0x01,0x7f,0x40,0x80,0x3e,0x01,0x00,0x7e,0x14,0x14,0x14,0x14,0x25,0x24,0x43,
+0x00,0x00,0xfe,0x02,0x24,0x20,0xfe,0x44,0x44,0xc8,0x28,0x10,0x6a,0x86,0x02,0xfe,
+/* 23485 0x5bbd "宽" */
+0x02,0x01,0x7f,0x40,0x84,0x3f,0x04,0x00,0x1f,0x10,0x11,0x11,0x12,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x02,0x44,0xf8,0x40,0x00,0xf0,0x10,0x10,0x10,0x90,0x82,0x82,0x7e,
+/* 23486 0x5bbe "宾" */
+0x02,0x01,0x7f,0x40,0x80,0x1f,0x10,0x10,0x1f,0x10,0x10,0xff,0x00,0x08,0x10,0x20,
+0x00,0x00,0xfe,0x02,0x74,0x80,0x00,0x00,0xf8,0x80,0x80,0xfe,0x00,0x40,0x20,0x10,
+/* 23487 0x5bbf "宿" */
+0x02,0x01,0x7f,0x40,0x88,0x0f,0x10,0x30,0x53,0x92,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0x00,0xfe,0x02,0x04,0xfc,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 23488 0x5bc0 "寀" */
+0x02,0x01,0x7f,0x40,0x80,0x00,0x3f,0x11,0x08,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x02,0x14,0xf8,0x00,0x10,0x20,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 23489 0x5bc1 "寁" */
+0x01,0x7f,0x40,0x81,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x11,0x11,0x29,0x47,0x80,
+0x00,0xfe,0x02,0x04,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x00,0xfe,0x00,
+/* 23490 0x5bc2 "寂" */
+0x02,0x01,0x7f,0x40,0x88,0x0f,0x08,0x08,0xff,0x00,0x08,0x2a,0x49,0x89,0x28,0x10,
+0x00,0x00,0xfe,0x02,0x04,0x7c,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 23491 0x5bc3 "寃" */
+0x02,0x01,0x7f,0x48,0x8f,0x10,0x20,0x5f,0x11,0x11,0x1f,0x02,0x04,0x08,0x10,0x60,
+0x00,0x00,0xfe,0x02,0xe4,0x20,0x40,0xf8,0x08,0x08,0xf8,0x80,0xa0,0x92,0x82,0x7e,
+/* 23492 0x5bc4 "寄" */
+0x02,0x01,0x7f,0x42,0x82,0x3f,0x04,0x08,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x80,0x40,0xfe,0x10,0x90,0x90,0x90,0x90,0x50,0x20,
+/* 23493 0x5bc5 "寅" */
+0x02,0x01,0x7f,0x40,0x9f,0x01,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x04,0x08,0x10,
+0x00,0x00,0xfe,0x02,0xf4,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x40,0x20,0x10,
+/* 23494 0x5bc6 "密" */
+0x02,0x01,0x7f,0x40,0x82,0x09,0x28,0x4b,0x1c,0xe7,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x02,0x24,0x40,0x88,0x14,0x10,0xf0,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23495 0x5bc7 "寇" */
+0x02,0x01,0x7f,0x40,0x80,0x3e,0x00,0x00,0x7e,0x14,0x14,0x14,0x14,0x24,0x24,0x43,
+0x00,0x00,0xfe,0x02,0x24,0x38,0x20,0x20,0xf8,0x08,0x50,0x20,0x54,0x84,0x04,0xfc,
+/* 23496 0x5bc8 "寈" */
+0x01,0x7f,0x41,0xbf,0x01,0x1f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x00,0xfe,0x02,0xfc,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 23497 0x5bc9 "寉" */
+0x02,0x01,0x7f,0x49,0x88,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x02,0x84,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,
+/* 23498 0x5bca "寊" */
+0x02,0x01,0x7f,0x42,0x83,0x02,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x00,0x00,0xfe,0x02,0xf4,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 23499 0x5bcb "寋" */
+0x02,0x01,0x7f,0x48,0xbf,0x08,0x3f,0x08,0xff,0x10,0x2f,0xc8,0x08,0x08,0x08,0x07,
+0x00,0x00,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfe,0x10,0xe8,0x26,0xa0,0x48,0x08,0xf8,
+/* 23500 0x5bcc "富" */
+0x02,0x01,0x7f,0x40,0xbf,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0x00,0xfe,0x02,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 23501 0x5bcd "寍" */
+0x02,0x01,0x7f,0x40,0x82,0x09,0x49,0x48,0x87,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfe,0x02,0x04,0x08,0x24,0x24,0xe0,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 23502 0x5bce "寎" */
+0x02,0x01,0x7f,0x40,0x84,0x25,0x24,0x3c,0x05,0x05,0x7d,0x25,0x25,0x25,0x45,0x85,
+0x00,0x00,0xfe,0x02,0x04,0xfc,0x20,0x20,0xfc,0x24,0x24,0x54,0x94,0x04,0x14,0x08,
+/* 23503 0x5bcf "寏" */
+0x02,0x01,0x7f,0x48,0x8f,0x10,0x3f,0x52,0x14,0x11,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x02,0xe4,0x40,0xf8,0x48,0x28,0x08,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 23504 0x5bd0 "寐" */
+0x02,0x01,0x7f,0x40,0x84,0x24,0x25,0x3c,0x04,0x07,0x7c,0x24,0x25,0x26,0x44,0x84,
+0x00,0x00,0xfe,0x02,0x24,0x20,0xfc,0x20,0x20,0xfe,0x60,0xb0,0x28,0x26,0x20,0x20,
+/* 23505 0x5bd1 "寑" */
+0x02,0x01,0x7f,0x40,0x8b,0x08,0x11,0x30,0x53,0x90,0x17,0x14,0x13,0x11,0x10,0x17,
+0x00,0x00,0xfe,0x02,0xfc,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 23506 0x5bd2 "寒" */
+0x02,0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x13,0x20,0xc0,0x06,0x01,0x00,
+0x00,0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0x88,0x46,0x00,0x80,0x40,
+/* 23507 0x5bd3 "寓" */
+0x02,0x01,0x7f,0x40,0x9f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x21,0x21,0x2f,0x24,0x20,
+0x00,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x48,0xe8,0x28,0x10,
+/* 23508 0x5bd4 "寔" */
+0x02,0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x11,0x11,0x29,0x47,0x80,
+0x00,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,
+/* 23509 0x5bd5 "寕" */
+0x02,0x01,0x7f,0x40,0xbf,0x02,0x3f,0x24,0x24,0x3f,0x00,0xff,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x02,0xfc,0x00,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 23510 0x5bd6 "寖" */
+0x02,0x01,0x7f,0x40,0xa3,0x10,0x11,0x80,0x43,0x50,0x17,0x24,0xe3,0x21,0x20,0x27,
+0x00,0x00,0xfe,0x02,0xfc,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 23511 0x5bd7 "寗" */
+0x01,0x7f,0x42,0x81,0x08,0x29,0x47,0x18,0x61,0x3f,0x21,0x3f,0x21,0xff,0x20,0x20,
+0x00,0xfe,0x02,0x44,0x80,0x28,0xe4,0x00,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x08,0x18,
+/* 23512 0x5bd8 "寘" */
+0x01,0x7f,0x41,0xbf,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x10,
+0x00,0xfe,0x02,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x10,
+/* 23513 0x5bd9 "寙" */
+0x02,0x01,0x7f,0x40,0x80,0x06,0x38,0x28,0x2c,0x2a,0x2a,0x2a,0x28,0x55,0x5d,0x82,
+0x00,0x00,0xfe,0x02,0x04,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0x54,0x74,0x12,
+/* 23514 0x5bda "寚" */
+0x02,0x01,0x7f,0x40,0xbf,0x01,0x1f,0x01,0x7f,0x10,0x1f,0x21,0xff,0x01,0x21,0x3f,
+0x00,0x00,0xfe,0x02,0xfc,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x00,0xfe,0x00,0x08,0xf8,
+/* 23515 0x5bdb "寛" */
+0x02,0x01,0x7f,0x48,0xbf,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x22,0xfc,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 23516 0x5bdc "寜" */
+0x02,0x01,0x7f,0x41,0x94,0x14,0x23,0x00,0x3f,0x24,0x24,0xff,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x02,0x94,0x28,0xe8,0x00,0xf8,0x48,0x48,0xfe,0x00,0x00,0x00,0x00,
+/* 23517 0x5bdd "寝" */
+0x01,0x7f,0x40,0x80,0x13,0x10,0x91,0x50,0x53,0x10,0x37,0x54,0x93,0x11,0x10,0x17,
+0x00,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 23518 0x5bde "寞" */
+0x01,0x7f,0x40,0x84,0x3f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x04,0x18,0xe0,
+0x00,0xfe,0x02,0x44,0xf8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x30,0x0e,
+/* 23519 0x5bdf "察" */
+0x01,0x7f,0x40,0x90,0x1e,0x22,0x54,0x28,0x17,0x20,0xdf,0x01,0x11,0x21,0x45,0x02,
+0x00,0xfe,0x02,0x84,0xf8,0x88,0x50,0x20,0xd8,0x06,0xf0,0x00,0x10,0x08,0x04,0x00,
+/* 23520 0x5be0 "寠" */
+0x02,0x01,0x7f,0x41,0xbf,0x21,0xff,0x21,0x3f,0x11,0x1f,0x04,0xff,0x08,0x07,0x78,
+0x00,0x00,0xfe,0x02,0xfc,0x08,0xfe,0x08,0xf8,0x10,0xf0,0x00,0xfe,0x20,0xc0,0x38,
+/* 23521 0x5be1 "寡" */
+0x01,0x7f,0x40,0xbf,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x37,0xc2,0x0c,
+0x00,0xfe,0x02,0xf4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0xd8,0x46,0xc0,
+/* 23522 0x5be2 "寢" */
+0x01,0x7f,0x40,0x84,0x24,0x24,0x24,0x3c,0x04,0x04,0x7d,0x25,0x24,0x24,0x44,0x85,
+0x00,0xfe,0x02,0x04,0xfc,0x04,0x7c,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x48,0x30,0xce,
+/* 23523 0x5be3 "寣" */
+0x02,0x01,0x7f,0x40,0x84,0x25,0x24,0x3c,0x04,0x04,0x7c,0x24,0x24,0x24,0x44,0x84,
+0x00,0x00,0xfe,0x42,0x24,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x88,0x88,0xf8,0x88,
+/* 23524 0x5be4 "寤" */
+0x02,0x01,0x7f,0x40,0x85,0x24,0x24,0x3c,0x04,0x05,0x7c,0x24,0x24,0x24,0x44,0x84,
+0x00,0x00,0xfe,0x02,0xfc,0x20,0xf8,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 23525 0x5be5 "寥" */
+0x01,0x7f,0x40,0xbc,0x24,0x14,0x25,0x06,0x18,0xe3,0x0c,0x31,0x06,0x38,0x07,0x38,
+0x00,0xfe,0x02,0xfc,0x48,0x28,0x48,0xc0,0x30,0x0e,0x40,0x80,0x30,0xc0,0x00,0x00,
+/* 23526 0x5be6 "實" */
+0x01,0x7f,0x40,0x9f,0x11,0xff,0x22,0x3f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfe,0x02,0xf4,0x10,0xfe,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 23527 0x5be7 "寧" */
+0x01,0x7f,0x41,0x94,0x14,0x23,0x00,0x3f,0x24,0xff,0x00,0x3f,0x01,0x01,0x05,0x02,
+0x00,0xfe,0x02,0x94,0xa8,0xe8,0x00,0xf8,0x48,0xfe,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 23528 0x5be8 "寨" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x11,0x2f,0xc1,0x09,0x11,0x25,0x02,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0xe8,0x06,0x20,0x10,0x08,0x00,
+/* 23529 0x5be9 "審" */
+0x01,0x7f,0x40,0x80,0x3f,0x11,0x09,0xff,0x09,0x30,0xdf,0x11,0x1f,0x11,0x1f,0x10,
+0x00,0xfe,0x02,0xfc,0x00,0x10,0x20,0xfe,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x10,
+/* 23530 0x5bea "寪" */
+0x01,0x7f,0x40,0x80,0x7f,0x22,0x11,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x2a,0x4a,0x80,
+0x00,0xfe,0x02,0xfc,0x00,0x10,0x20,0xe0,0x20,0xf0,0x10,0xfc,0x04,0xa4,0xa4,0x0c,
+/* 23531 0x5beb "寫" */
+0x01,0x7f,0x40,0x82,0x1c,0x10,0x1e,0x10,0x1f,0x08,0x1f,0x20,0x49,0x24,0x24,0x40,
+0x00,0xfe,0x02,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x24,0x94,0x94,0x08,
+/* 23532 0x5bec "寬" */
+0x02,0x01,0x7f,0x48,0xbf,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x00,0x00,0xfe,0x22,0xfc,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x52,0x4a,0x3e,
+/* 23533 0x5bed "寭" */
+0x01,0x7f,0x41,0xbf,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x7f,0x02,0x49,0x48,0x87,
+0x00,0xfe,0x02,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0xfc,0x04,0x08,0x24,0xe4,
+/* 23534 0x5bee "寮" */
+0x01,0x7f,0x40,0x81,0x7f,0x04,0x28,0x1f,0x28,0xcf,0x08,0x0f,0x01,0x11,0x25,0x02,
+0x00,0xfe,0x02,0x04,0xfc,0x40,0x28,0xf0,0x28,0xe6,0x20,0xe0,0x00,0x10,0x08,0x00,
+/* 23535 0x5bef "寯" */
+0x01,0x7f,0x49,0x88,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3e,0x22,0x23,0x20,
+0x00,0xfe,0x02,0x84,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x7c,0x44,0xd4,0x08,
+/* 23536 0x5bf0 "寰" */
+0x01,0x7f,0x40,0xbf,0x24,0x3f,0x00,0xff,0x00,0x1f,0x10,0x1f,0x05,0x18,0xea,0x0c,
+0x00,0xfe,0x02,0xfc,0x48,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x08,0x90,0x60,0x1c,
+/* 23537 0x5bf1 "寱" */
+0x02,0x01,0x7f,0x40,0x89,0x49,0x49,0x49,0x79,0x09,0x09,0xf8,0x4b,0x48,0x49,0x8a,
+0x00,0x00,0xfe,0x42,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0xa8,0x24,0x22,
+/* 23538 0x5bf2 "寲" */
+0x02,0x01,0x7f,0x40,0xa4,0x3a,0x22,0x1e,0x20,0x3e,0x48,0x08,0x7f,0x14,0x22,0x41,
+0x00,0x00,0xfe,0x02,0x7c,0x04,0x28,0x10,0xfe,0x12,0x50,0x5e,0x50,0xb0,0x9e,0x00,
+/* 23539 0x5bf3 "寳" */
+0x01,0x7f,0x40,0xbe,0x09,0x3e,0x09,0x7e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfe,0x82,0xfc,0x24,0xa8,0x24,0xa0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 23540 0x5bf4 "寴" */
+0x02,0x01,0x7f,0x40,0x88,0x7f,0x22,0x14,0xff,0x08,0x7f,0x08,0x2a,0x49,0xa9,0x10,
+0x00,0x00,0xfe,0x02,0x04,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x2a,0x4a,0x86,
+/* 23541 0x5bf5 "寵" */
+0x01,0xff,0x88,0x7f,0x22,0x14,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x45,0x42,
+0x00,0xfe,0x42,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,
+/* 23542 0x5bf6 "寶" */
+0x01,0x7f,0x40,0xbe,0x09,0x3e,0x08,0x7e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfe,0x82,0xfc,0x20,0xfc,0x20,0xa4,0xfc,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 23543 0x5bf7 "寷" */
+0x01,0x7f,0x48,0x9d,0x49,0x5d,0x49,0x5d,0x49,0x7f,0x00,0x7f,0x10,0x1f,0x08,0xff,
+0x00,0xfe,0x22,0x74,0x24,0x74,0x24,0x74,0x24,0xfc,0x00,0xfc,0x10,0xf0,0x20,0xfe,
+/* 23544 0x5bf8 "寸" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x10,0x08,0x08,0x00,0x00,0x00,0x01,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 23545 0x5bf9 "对" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x24,0x14,0x08,0x08,0x14,0x12,0x22,0x40,0x00,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 23546 0x5bfa "寺" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x00,0x7f,0x08,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 23547 0x5bfb "寻" */
+0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0x3f,0x00,0x00,0xff,0x08,0x04,0x04,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 23548 0x5bfc "导" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0xff,0x08,0x04,0x04,0x00,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 23549 0x5bfd "寽" */
+0x00,0x01,0x7e,0x02,0x21,0x11,0x10,0x00,0xff,0x00,0x10,0x08,0x08,0x00,0x01,0x00,
+0x08,0xfc,0x00,0x08,0x08,0x10,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 23550 0x5bfe "対" */
+0x20,0x10,0x10,0x00,0xfe,0x04,0x04,0x48,0x28,0x10,0x10,0x28,0x24,0x44,0x80,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 23551 0x5bff "寿" */
+0x02,0x02,0x7f,0x02,0x3f,0x04,0xff,0x08,0x08,0x1f,0x10,0x24,0x42,0x82,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 23552 0x5c00 "尀" */
+0x00,0x00,0x7f,0x40,0x40,0x5f,0x51,0x51,0x51,0x51,0x5f,0x51,0x40,0x7f,0x00,0x00,
+0x08,0x08,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x88,0x28,0x10,
+/* 23553 0x5c01 "封" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x08,0x08,0x08,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 23554 0x5c02 "専" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x08,0x04,0x04,0x00,0x00,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 23555 0x5c03 "尃" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x00,0xff,0x08,0x04,0x04,0x00,
+0x20,0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 23556 0x5c04 "射" */
+0x08,0x10,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0xfe,0x06,0x0a,0x12,0x22,0x4a,0x04,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x28,0x10,
+/* 23557 0x5c05 "尅" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x41,0x7f,0x14,0x14,0x14,0x24,0x24,0x43,0x80,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x12,0x02,0xfe,0x00,
+/* 23558 0x5c06 "将" */
+0x08,0x08,0x09,0x4a,0x28,0x28,0x08,0x0b,0x18,0x2b,0xc8,0x09,0x08,0x08,0x08,0x08,
+0x80,0xf8,0x08,0x10,0xa0,0x40,0x90,0x10,0x10,0xfe,0x10,0x10,0x90,0x10,0x50,0x20,
+/* 23559 0x5c07 "將" */
+0x04,0x24,0x24,0x25,0x24,0x3c,0x04,0x05,0xfc,0x25,0x24,0x24,0x24,0x44,0x84,0x04,
+0x40,0x7c,0xc4,0x28,0x90,0xa0,0x48,0x88,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 23560 0x5c08 "專" */
+0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x00,0xff,0x08,0x04,0x04,0x00,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x04,0xfe,0x22,0xfe,0x20,0x20,0xa0,0x40,
+/* 23561 0x5c09 "尉" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x2f,0x20,0x20,0x3f,0x22,0x2a,0x4a,0x52,0x8a,0x04,
+0x04,0x84,0x84,0x84,0xbe,0x04,0x84,0x24,0x14,0xd4,0x04,0x84,0x44,0x44,0x14,0x08,
+/* 23562 0x5c0a "尊" */
+0x08,0x04,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,0x00,0xff,0x08,0x04,0x04,0x00,
+0x20,0x40,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 23563 0x5c0b "尋" */
+0x00,0x3f,0x00,0x1f,0x00,0x3f,0x00,0x3e,0x08,0x7f,0x00,0xff,0x08,0x04,0x04,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x7c,0x44,0x7c,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 23564 0x5c0c "尌" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x00,0x7f,0x41,0x41,0x7f,0x00,0x22,0x17,0xf8,0x40,
+0x08,0x08,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x88,0x28,0x10,
+/* 23565 0x5c0d "對" */
+0x14,0x14,0x55,0x36,0x14,0xff,0x00,0x22,0x14,0x7f,0x08,0x3e,0x08,0x0f,0x78,0x20,
+0x08,0x08,0x08,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 23566 0x5c0e "導" */
+0x21,0x17,0x10,0x03,0xf2,0x13,0x12,0x13,0x12,0x13,0x28,0x47,0x00,0xff,0x08,0x04,
+0x10,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x20,0xfe,0x20,0x60,
+/* 23567 0x5c0f "小" */
+0x01,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x21,0x21,0x41,0x81,0x01,0x01,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x04,0x02,0x02,0x02,0x00,0x00,0x00,0x00,
+/* 23568 0x5c10 "尐" */
+0x01,0x01,0x01,0x09,0x09,0x11,0x11,0x21,0x41,0x01,0x00,0x18,0x24,0x03,0x00,0x00,
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x80,0x7e,0x00,
+/* 23569 0x5c11 "少" */
+0x01,0x01,0x01,0x09,0x09,0x11,0x11,0x21,0x41,0x01,0x00,0x00,0x01,0x02,0x0c,0x70,
+0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x14,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 23570 0x5c12 "尒" */
+0x01,0x01,0x02,0x04,0x08,0x31,0xc1,0x01,0x09,0x09,0x11,0x21,0x41,0x01,0x05,0x02,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,
+/* 23571 0x5c13 "尓" */
+0x08,0x08,0x08,0x1f,0x10,0x21,0x41,0x81,0x01,0x11,0x11,0x21,0x41,0x81,0x05,0x02,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x02,0x00,0x00,
+/* 23572 0x5c14 "尔" */
+0x08,0x08,0x08,0x1f,0x10,0x21,0x41,0x81,0x01,0x11,0x11,0x21,0x41,0x81,0x05,0x02,
+0x00,0x00,0x00,0xfc,0x04,0x08,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x02,0x00,0x00,
+/* 23573 0x5c15 "尕" */
+0x00,0x3f,0x08,0x08,0x08,0x10,0x10,0x21,0x41,0x09,0x09,0x11,0x21,0x41,0x05,0x02,
+0x00,0xf0,0x10,0x20,0x3c,0x04,0x04,0x14,0x08,0x20,0x10,0x08,0x04,0x04,0x00,0x00,
+/* 23574 0x5c16 "尖" */
+0x01,0x01,0x09,0x09,0x11,0x21,0x41,0x00,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 23575 0x5c17 "尗" */
+0x02,0x02,0x03,0x02,0x02,0x02,0xff,0x01,0x01,0x09,0x11,0x21,0x41,0x01,0x05,0x02,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0x08,0x04,0x00,0x00,0x00,
+/* 23576 0x5c18 "尘" */
+0x01,0x01,0x09,0x09,0x11,0x21,0x41,0x00,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 23577 0x5c19 "尙" */
+0x01,0x11,0x11,0x21,0x41,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x20,0x20,0x20,
+0x00,0x10,0x08,0x04,0x04,0xf8,0x08,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 23578 0x5c1a "尚" */
+0x01,0x21,0x11,0x09,0x01,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x20,0x20,0x20,
+0x00,0x08,0x10,0x20,0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 23579 0x5c1b "尛" */
+0x01,0x01,0x09,0x09,0x11,0x21,0x41,0x10,0x10,0x10,0x54,0x52,0x92,0x10,0x50,0x20,
+0x00,0x00,0x20,0x10,0x08,0x04,0x04,0x10,0x10,0x10,0x54,0x52,0x92,0x10,0x50,0x20,
+/* 23580 0x5c1c "尜" */
+0x01,0x09,0x11,0x21,0x00,0x01,0xff,0x02,0x0c,0x30,0xc1,0x09,0x09,0x11,0x25,0x02,
+0x00,0x20,0x10,0x08,0x00,0x00,0xfe,0x80,0x60,0x18,0x06,0x20,0x10,0x08,0x08,0x00,
+/* 23581 0x5c1d "尝" */
+0x01,0x11,0x09,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0x7f,0x04,0x08,0x10,0x3f,0x10,
+0x00,0x10,0x20,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x00,0x20,0x10,0xf8,0x08,
+/* 23582 0x5c1e "尞" */
+0x01,0x01,0x7f,0x22,0x14,0x08,0x3f,0xd0,0x1f,0x10,0x1f,0x01,0x11,0x21,0x45,0x02,
+0x00,0x00,0xfc,0x88,0x50,0x20,0xf8,0x16,0xf0,0x10,0xf0,0x00,0x10,0x08,0x04,0x00,
+/* 23583 0x5c1f "尟" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x29,0x58,0x4f,0x80,
+0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x12,0x04,0x08,0x10,0x60,0x80,0x00,0xfe,0x00,
+/* 23584 0x5c20 "尠" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x00,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 23585 0x5c21 "尡" */
+0x10,0x11,0x91,0x55,0x59,0x11,0xfd,0x29,0x28,0x29,0x29,0x29,0x2b,0x4d,0x49,0x81,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 23586 0x5c22 "尢" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 23587 0x5c23 "尣" */
+0x04,0x04,0x08,0x10,0x20,0x44,0x84,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x40,0x20,0x10,0x08,0x04,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 23588 0x5c24 "尤" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 23589 0x5c25 "尥" */
+0x20,0x20,0x20,0x21,0xfd,0x2a,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x48,0x47,0x80,
+0x80,0x80,0x80,0xf8,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x50,0x22,0x02,0xfe,0x00,
+/* 23590 0x5c26 "尦" */
+0x00,0x24,0x22,0x42,0x80,0x25,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x40,0x40,0x40,0x7c,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 23591 0x5c27 "尧" */
+0x02,0x02,0x02,0x7f,0x01,0x00,0x07,0x38,0x00,0xff,0x04,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x20,0x40,0x84,0x64,0x1c,0x00,0xfe,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 23592 0x5c28 "尨" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x21,0x4e,0x80,
+0x20,0x10,0x10,0x00,0xfe,0x90,0xa0,0xc8,0x90,0xa4,0xc8,0x92,0xe2,0x82,0x7e,0x00,
+/* 23593 0x5c29 "尩" */
+0x00,0x24,0x22,0x42,0x80,0x24,0x24,0x24,0x24,0x24,0x25,0x24,0x24,0x44,0x43,0x80,
+0x00,0xfc,0x20,0x20,0x20,0xf8,0x20,0x20,0x20,0x20,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 23594 0x5c2a "尪" */
+0x20,0x23,0x20,0x20,0xfc,0x28,0x29,0x28,0x28,0x28,0x28,0x2b,0x28,0x48,0x47,0x80,
+0x00,0xf8,0x40,0x40,0x40,0x40,0xf0,0x40,0x40,0x40,0x40,0xf8,0x02,0x02,0xfe,0x00,
+/* 23595 0x5c2b "尫" */
+0x00,0x01,0xfe,0x24,0x24,0x25,0x24,0x24,0x24,0x24,0x27,0x24,0x24,0x44,0x43,0x80,
+0x00,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,0x02,0xfe,0x00,
+/* 23596 0x5c2c "尬" */
+0x20,0x20,0x20,0x20,0xfd,0x2a,0x28,0x28,0x28,0x28,0x29,0x29,0x2a,0x48,0x47,0x80,
+0x20,0x20,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x08,0x08,0x0a,0x02,0xfe,0x00,
+/* 23597 0x5c2d "尭" */
+0x01,0x01,0x7f,0x01,0x09,0x08,0xff,0x08,0x08,0x7f,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xfc,0x00,0x20,0x20,0xfe,0x20,0x20,0xfc,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 23598 0x5c2e "尮" */
+0x20,0x23,0x20,0x20,0xfc,0x29,0x29,0x2a,0x28,0x2b,0x28,0x29,0x2a,0x48,0x47,0x80,
+0x00,0xf8,0x88,0x90,0xbc,0x04,0x14,0x48,0x40,0xfc,0xe0,0x50,0x4a,0x42,0xfe,0x00,
+/* 23599 0x5c2f "尯" */
+0x20,0x20,0x21,0x22,0xfd,0x29,0x29,0x29,0x29,0x29,0x29,0x2a,0x2c,0x48,0x47,0x80,
+0x80,0x80,0xf8,0x08,0xfe,0x00,0x78,0x48,0x68,0x50,0x44,0x44,0x3e,0x02,0xfe,0x00,
+/* 23600 0x5c30 "尰" */
+0x20,0x21,0x20,0x23,0xfc,0x29,0x29,0x29,0x29,0x29,0x28,0x29,0x28,0x4b,0x48,0x87,
+0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xfe,
+/* 23601 0x5c31 "就" */
+0x20,0x10,0xfe,0x00,0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x54,0x92,0x11,0x51,0x22,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 23602 0x5c32 "尲" */
+0x20,0x20,0x23,0x20,0xfd,0x28,0x2b,0x28,0x29,0x28,0x28,0x29,0x2a,0x48,0x47,0x80,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x52,0xfe,0x00,
+/* 23603 0x5c33 "尳" */
+0x20,0x20,0x20,0x20,0xfd,0x29,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x48,0x48,0x87,
+0xf8,0x88,0xe8,0xa8,0xfc,0x04,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x88,0xaa,0x92,0xfe,
+/* 23604 0x5c34 "尴" */
+0x20,0x22,0x22,0x22,0xfe,0x2a,0x28,0x2b,0x2a,0x2a,0x2a,0x2f,0x28,0x48,0x47,0x80,
+0x90,0x90,0xbc,0xd0,0x88,0x88,0x00,0xf8,0xa8,0xa8,0xa8,0xfe,0x02,0x02,0xfe,0x00,
+/* 23605 0x5c35 "尵" */
+0x20,0x21,0x21,0x21,0xfc,0x2b,0x29,0x29,0x29,0x29,0x29,0x29,0x28,0x49,0x48,0x87,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x06,0x02,0xfe,
+/* 23606 0x5c36 "尶" */
+0x03,0xfe,0x2b,0x2a,0x2b,0x2a,0x2b,0x28,0x29,0x29,0x29,0x29,0x2b,0x48,0x47,0x80,
+0xe8,0x88,0xce,0x50,0xe4,0x82,0xe0,0x00,0xfc,0x54,0x54,0x54,0xfe,0x02,0xfe,0x00,
+/* 23607 0x5c37 "尷" */
+0x23,0x22,0x23,0x22,0xff,0x2a,0x2b,0x28,0x29,0x29,0x29,0x29,0x2b,0x48,0x47,0x80,
+0xe8,0x88,0xce,0x50,0xe4,0x82,0xe0,0x00,0xfc,0x54,0x54,0x54,0xfe,0x02,0xfe,0x00,
+/* 23608 0x5c38 "尸" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23609 0x5c39 "尹" */
+0x00,0x00,0x3f,0x04,0x04,0xff,0x04,0x04,0x3f,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xf0,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23610 0x5c3a "尺" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x80,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 23611 0x5c3b "尻" */
+0x00,0x3f,0x20,0x20,0x3f,0x21,0x21,0x2f,0x21,0x21,0x22,0x22,0x44,0x44,0x88,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 23612 0x5c3c "尼" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x12,0x12,0x12,0x13,0x12,0x22,0x22,0x41,0x80,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0x0c,0x30,0xc0,0x02,0x02,0x02,0xfe,0x00,
+/* 23613 0x5c3d "尽" */
+0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x23,0x20,0x40,0x8c,0x03,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x48,0x40,0x20,0x10,0x88,0x06,0x00,0x00,0x80,0x40,
+/* 23614 0x5c3e "尾" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x21,0x21,0x2f,0x21,0x21,0x5f,0x41,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xf8,0x02,0x02,0xfe,
+/* 23615 0x5c3f "尿" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x2e,0x22,0x22,0x24,0x44,0x48,0x92,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x80,0x80,0x88,0xd0,0xe0,0xa0,0xa0,0x90,0x88,0x84,0x00,
+/* 23616 0x5c40 "局" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x27,0x24,0x24,0x47,0x40,0x80,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 23617 0x5c41 "屁" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x28,0x28,0x28,0x2f,0x28,0x28,0x48,0x49,0x8a,0x0c,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x40,0x40,0x44,0x48,0x50,0x60,0x44,0x44,0x44,0x3c,
+/* 23618 0x5c42 "层" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x21,0x22,0x44,0x4f,0x84,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfe,0x00,0x10,0x08,0xfc,0x04,
+/* 23619 0x5c43 "屃" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x41,0x46,0x98,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x04,0x44,0x44,0x44,0xb4,0x08,0x04,0x02,
+/* 23620 0x5c44 "屄" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x28,0x31,0x21,0x22,0x22,0x44,0x48,0x90,
+0x00,0xfc,0x04,0x04,0xfc,0x80,0x40,0xfe,0x02,0x24,0x20,0x10,0x10,0x08,0x04,0x02,
+/* 23621 0x5c45 "居" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x28,0x48,0x48,0x8f,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfe,0x80,0x80,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23622 0x5c46 "屆" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x28,0x2b,0x28,0x28,0x2f,0x28,0x48,0x4f,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x80,0x84,0xe4,0x84,0x84,0xf4,0x04,0x04,0xfc,0x04,
+/* 23623 0x5c47 "屇" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x24,0x44,0x47,0x84,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x04,
+/* 23624 0x5c48 "屈" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x28,0x28,0x28,0x2f,0x20,0x30,0x50,0x50,0x9f,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x80,0x88,0x88,0x88,0xf8,0x80,0x84,0x84,0x84,0xfc,0x04,
+/* 23625 0x5c49 "屉" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x24,0x24,0x24,0x3f,0x24,0x24,0x44,0x44,0x84,0x07,
+0x00,0xf8,0x08,0x08,0xf8,0x90,0x90,0x90,0x90,0xfc,0x90,0x90,0xf0,0x00,0x00,0xfe,
+/* 23626 0x5c4a "届" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x2f,0x28,0x28,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x80,0x80,0x80,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x08,
+/* 23627 0x5c4b "屋" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x2f,0x21,0x22,0x27,0x20,0x20,0x2f,0x40,0x40,0xbf,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x00,0x10,0xf8,0x88,0x80,0xfc,0x80,0x80,0xfe,
+/* 23628 0x5c4c "屌" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x27,0x24,0x24,0x27,0x20,0x2f,0x28,0x48,0x48,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x40,0xfe,0x42,0x4a,0x44,0x40,
+/* 23629 0x5c4d "屍" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x24,0x24,0x27,0x28,0x35,0x42,0x44,0x98,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x24,0xa8,0xb0,0x20,0x22,0x22,0x1e,
+/* 23630 0x5c4e "屎" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x24,0x22,0x20,0x3f,0x21,0x22,0x24,0x48,0x50,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x80,0x90,0xa0,0x80,0xfc,0xc0,0xa0,0x90,0x88,0x86,0x80,
+/* 23631 0x5c4f "屏" */
+0x00,0x3f,0x20,0x20,0x3f,0x24,0x22,0x2f,0x22,0x22,0x3f,0x22,0x42,0x44,0x84,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x10,0x20,0xf8,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 23632 0x5c50 "屐" */
+0x00,0x3f,0x20,0x3f,0x20,0x24,0x29,0x30,0x22,0x25,0x2c,0x34,0x44,0x44,0x84,0x07,
+0x00,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 23633 0x5c51 "屑" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x24,0x22,0x2f,0x28,0x2f,0x28,0x4f,0x48,0x88,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x80,0x90,0xa0,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 23634 0x5c52 "屒" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x2b,0x28,0x2f,0x2a,0x2a,0x52,0x52,0xa3,0x02,
+0x00,0xfc,0x04,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xfc,0x48,0x50,0x20,0x98,0x06,0x00,
+/* 23635 0x5c53 "屓" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x27,0x41,0x42,0x84,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x10,0x08,0x04,
+/* 23636 0x5c54 "屔" */
+0x00,0x02,0x3c,0x20,0x20,0x20,0x3e,0x24,0x24,0x24,0x24,0x2e,0xf1,0x41,0x02,0x04,
+0x00,0xfe,0x82,0x82,0x82,0xfe,0x80,0xa0,0xa2,0xa4,0xb8,0xa0,0x22,0x22,0x1e,0x00,
+/* 23637 0x5c55 "展" */
+0x3f,0x20,0x20,0x3f,0x22,0x22,0x3f,0x22,0x22,0x3f,0x24,0x24,0x24,0x45,0x46,0x84,
+0xfc,0x04,0x04,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfc,0x40,0x44,0x28,0x10,0x08,0x06,
+/* 23638 0x5c56 "屖" */
+0x00,0x3f,0x20,0x3f,0x21,0x20,0x2f,0x24,0x22,0x3f,0x20,0x20,0x4f,0x40,0x80,0x00,
+0x00,0xfc,0x04,0xfc,0x00,0x80,0xf8,0x10,0x20,0xfc,0x80,0x80,0xf8,0x80,0x80,0x80,
+/* 23639 0x5c57 "屗" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x23,0x3c,0x27,0x3c,0x27,0x3c,0x24,0x44,0x43,0x80,
+0x08,0x08,0x08,0x7e,0x08,0x48,0x28,0x28,0x08,0x08,0xa8,0x12,0x02,0x02,0xfe,0x00,
+/* 23640 0x5c58 "屘" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x23,0x3c,0x27,0x3c,0x27,0x3c,0x24,0x44,0x43,0x80,
+0x00,0x7e,0x02,0x04,0x08,0x08,0x7e,0x08,0x08,0x08,0x88,0x2a,0x12,0x02,0xfe,0x00,
+/* 23641 0x5c59 "屙" */
+0x00,0x3f,0x20,0x3f,0x20,0x2e,0x2a,0x2a,0x2c,0x2a,0x2a,0x2a,0x4a,0x4e,0x88,0x08,
+0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0xe8,0xa8,0xa8,0xa8,0xe8,0xa8,0x08,0x28,0x10,
+/* 23642 0x5c5a "屚" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x2c,0x2a,0x28,0x4c,0x4a,0x88,0x08,
+0x00,0xfc,0x04,0xfc,0x00,0xfe,0x80,0xfc,0x84,0xa4,0x94,0x84,0xa4,0x94,0x84,0x0c,
+/* 23643 0x5c5b "屛" */
+0x00,0x3f,0x20,0x20,0x3f,0x21,0x22,0x2f,0x22,0x22,0x3f,0x22,0x22,0x44,0x44,0x88,
+0x00,0xfc,0x04,0x04,0xfc,0x08,0x10,0x7c,0x10,0x10,0x7e,0x10,0x10,0x10,0x10,0x10,
+/* 23644 0x5c5c "屜" */
+0x00,0x3f,0x20,0x20,0x3f,0x22,0x24,0x2a,0x23,0x24,0x2c,0x34,0x24,0x44,0x44,0x84,
+0x00,0xfc,0x04,0x04,0xfc,0x28,0xa8,0xa8,0xfe,0xa8,0xa8,0xa8,0xb8,0x80,0xfe,0x00,
+/* 23645 0x5c5d "屝" */
+0x00,0x3f,0x20,0x20,0x3f,0x21,0x21,0x2f,0x21,0x21,0x27,0x21,0x21,0x4f,0x41,0x81,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0x3c,0x20,0x20,0x38,0x20,0x20,0x3c,0x20,0x20,
+/* 23646 0x5c5e "属" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x2f,0x20,0x3f,0x50,0x57,0x90,0x10,
+0x00,0xfc,0x04,0xfc,0x00,0xf8,0x80,0xf8,0x88,0xf8,0x80,0xfc,0x94,0xf4,0x14,0x08,
+/* 23647 0x5c5f "屟" */
+0x3f,0x20,0x3f,0x20,0x24,0x3f,0x24,0x24,0x24,0x27,0x20,0x2f,0x41,0x42,0x8c,0x00,
+0xfc,0x04,0xfc,0x00,0x88,0xfe,0x88,0xf8,0x00,0xfc,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 23648 0x5c60 "屠" */
+0x00,0x3f,0x20,0x3f,0x20,0x20,0x27,0x20,0x3f,0x20,0x23,0x26,0x5b,0x42,0x83,0x02,
+0x00,0xfc,0x04,0xfc,0x80,0x88,0xf0,0xa0,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 23649 0x5c61 "屡" */
+0x3f,0x20,0x3f,0x24,0x22,0x3f,0x22,0x24,0x28,0x21,0x3f,0x22,0x47,0x40,0x83,0x0c,
+0xfc,0x04,0xfc,0x90,0xa0,0xfc,0xa0,0x90,0x88,0x00,0xfc,0x10,0x20,0xc0,0x30,0x08,
+/* 23650 0x5c62 "屢" */
+0x3f,0x20,0x3f,0x20,0x2f,0x28,0x3f,0x28,0x2f,0x24,0x27,0x21,0x5f,0x44,0x83,0x1c,
+0xfc,0x04,0xfc,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x90,0xf0,0x00,0xfe,0x10,0xe0,0x1c,
+/* 23651 0x5c63 "屣" */
+0x3f,0x20,0x3f,0x22,0x24,0x28,0x30,0x22,0x25,0x2c,0x34,0x24,0x44,0x45,0x86,0x04,
+0xfc,0x04,0xfc,0x10,0x10,0x9c,0x90,0x90,0xfe,0x10,0x90,0x9c,0x90,0x50,0x3e,0x00,
+/* 23652 0x5c64 "層" */
+0x3f,0x20,0x3f,0x22,0x21,0x2f,0x2a,0x29,0x2f,0x20,0x27,0x24,0x47,0x44,0x87,0x04,
+0xfc,0x04,0xfc,0x10,0x20,0xfc,0x94,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 23653 0x5c65 "履" */
+0x3f,0x20,0x3f,0x21,0x29,0x32,0x21,0x25,0x29,0x39,0x29,0x28,0x49,0x4a,0x88,0x0b,
+0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x88,0x70,0x8e,
+/* 23654 0x5c66 "屦" */
+0x00,0x3f,0x20,0x3f,0x20,0x25,0x28,0x31,0x24,0x29,0x38,0x2b,0x48,0x49,0x88,0x0b,
+0x00,0xfc,0x04,0xfc,0x00,0x24,0xa8,0xfc,0xa8,0x24,0x40,0xfe,0x88,0x90,0x70,0x8c,
+/* 23655 0x5c67 "屧" */
+0x3f,0x20,0x3f,0x24,0x25,0x2b,0x35,0x25,0x2d,0x35,0x24,0x27,0x44,0x45,0x86,0x04,
+0xfc,0x04,0xfc,0x48,0x48,0xfe,0x48,0x78,0x00,0xfe,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 23656 0x5c68 "屨" */
+0x3f,0x20,0x3f,0x24,0x29,0x31,0x23,0x25,0x2d,0x34,0x24,0x24,0x45,0x44,0x84,0x05,
+0xfc,0x04,0xfc,0x20,0xfc,0x24,0xfe,0x24,0xfc,0xa8,0xf8,0x40,0xfe,0x88,0x70,0x8c,
+/* 23657 0x5c69 "屩" */
+0x3f,0x20,0x3f,0x22,0x25,0x28,0x33,0x24,0x2d,0x36,0x25,0x25,0x45,0x45,0x85,0x05,
+0xfc,0x04,0xfc,0x00,0xfc,0x40,0xfe,0x88,0x74,0x52,0xfc,0x04,0x74,0x54,0x74,0x0c,
+/* 23658 0x5c6a "屪" */
+0x3f,0x20,0x3f,0x20,0x2f,0x28,0x27,0x21,0x2b,0x26,0x2b,0x22,0x43,0x40,0x84,0x08,
+0xfc,0x04,0xfc,0x40,0xfe,0x82,0xfc,0x10,0xfa,0x0c,0xfa,0x08,0xf8,0x40,0x48,0xc4,
+/* 23659 0x5c6b "屫" */
+0x3f,0x20,0x3f,0x20,0x22,0x2a,0x2b,0x2e,0x22,0x23,0x3e,0x2a,0x4a,0x4a,0x92,0x22,
+0xfc,0x04,0xfc,0x00,0xfe,0x20,0xfe,0x44,0xba,0x28,0xfe,0x82,0xba,0xaa,0xba,0x86,
+/* 23660 0x5c6c "屬" */
+0x3f,0x20,0x3f,0x24,0x22,0x24,0x2f,0x29,0x2f,0x24,0x2f,0x34,0x47,0x40,0x8f,0x00,
+0xfc,0x04,0xfc,0x90,0xa0,0x90,0xf8,0x48,0xfc,0x84,0xf4,0x94,0xf4,0x94,0xf4,0x08,
+/* 23661 0x5c6d "屭" */
+0x3f,0x20,0x3f,0x22,0x23,0x22,0x23,0x21,0x22,0x2f,0x28,0x2f,0x48,0x4f,0x85,0x08,
+0xfc,0x04,0xfc,0x08,0xf8,0x08,0xf8,0x10,0x08,0xbe,0xa2,0xbe,0xa2,0xbe,0x14,0xa2,
+/* 23662 0x5c6e "屮" */
+0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23663 0x5c6f "屯" */
+0x01,0x01,0x01,0xff,0x01,0x21,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x08,0x08,0x08,0x08,0xf8,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 23664 0x5c70 "屰" */
+0x10,0x08,0x08,0xff,0x01,0x01,0x21,0x21,0x21,0x3f,0x02,0x04,0x04,0x08,0x30,0xc0,
+0x10,0x10,0x20,0xfe,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 23665 0x5c71 "山" */
+0x01,0x01,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 23666 0x5c72 "屲" */
+0x00,0x00,0x07,0x78,0x01,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,0x00,
+0x08,0x7c,0x80,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 23667 0x5c73 "屳" */
+0x06,0x01,0x02,0x04,0x08,0x31,0xc1,0x01,0x21,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 23668 0x5c74 "屴" */
+0x01,0x01,0x21,0x21,0x21,0x3f,0x02,0x02,0x7f,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 23669 0x5c75 "屵" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 23670 0x5c76 "屶" */
+0x01,0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 23671 0x5c77 "屷" */
+0x10,0x10,0x13,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 23672 0x5c78 "屸" */
+0x10,0x10,0x11,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x03,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 23673 0x5c79 "屹" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x54,0x54,0x54,0x5c,0x65,0x01,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 23674 0x5c7a "屺" */
+0x10,0x10,0x11,0x10,0x54,0x54,0x54,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 23675 0x5c7b "屻" */
+0x10,0x10,0x11,0x10,0x54,0x55,0x55,0x55,0x55,0x56,0x54,0x5c,0x64,0x01,0x02,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 23676 0x5c7c "屼" */
+0x10,0x10,0x13,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 23677 0x5c7d "屽" */
+0x10,0x11,0x10,0x10,0x54,0x54,0x54,0x57,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 23678 0x5c7e "屾" */
+0x10,0x10,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x00,0x00,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 23679 0x5c7f "屿" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5d,0x64,0x00,0x00,0x00,
+0x40,0x40,0x40,0x7e,0x40,0x80,0x80,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 23680 0x5c80 "岀" */
+0x01,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,0x01,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 23681 0x5c81 "岁" */
+0x00,0x10,0x10,0x10,0x1f,0x01,0x01,0x03,0x04,0x0a,0x11,0x00,0x00,0x01,0x0e,0x70,
+0x80,0x84,0x84,0x84,0xfc,0x00,0x00,0xf8,0x08,0x08,0x10,0xa0,0x40,0x80,0x00,0x00,
+/* 23682 0x5c82 "岂" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x04,0x04,0xfc,
+/* 23683 0x5c83 "岃" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x3f,0x02,0x12,0x12,0x22,0x04,0x08,0x10,0x60,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 23684 0x5c84 "岄" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 23685 0x5c85 "岅" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 23686 0x5c86 "岆" */
+0x10,0x10,0x11,0x10,0x54,0x54,0x57,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x01,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 23687 0x5c87 "岇" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x0c,0x70,0x40,0x40,0x40,0x4c,0x70,0x40,0x00,0x00,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,
+/* 23688 0x5c88 "岈" */
+0x10,0x11,0x10,0x10,0x54,0x54,0x55,0x55,0x54,0x54,0x54,0x5c,0x65,0x02,0x00,0x00,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 23689 0x5c89 "岉" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x54,0x55,0x56,0x5c,0x64,0x00,0x01,0x00,
+0x80,0x80,0x80,0xfc,0x54,0x54,0x54,0x94,0x94,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 23690 0x5c8a "岊" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x20,0x1f,0x01,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x02,0x02,0xfe,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23691 0x5c8b "岋" */
+0x10,0x13,0x10,0x10,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x66,0x02,0x04,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 23692 0x5c8c "岌" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x08,0x08,0x0c,0x0a,0x11,0x10,0x20,0x20,0x43,0x8c,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x20,0x40,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 23693 0x5c8d "岍" */
+0x10,0x11,0x10,0x10,0x54,0x54,0x54,0x57,0x54,0x54,0x54,0x5c,0x64,0x01,0x01,0x02,
+0x00,0xfc,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 23694 0x5c8e "岎" */
+0x10,0x10,0x10,0x10,0x55,0x55,0x56,0x55,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 23695 0x5c8f "岏" */
+0x10,0x11,0x10,0x10,0x54,0x57,0x54,0x54,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 23696 0x5c90 "岐" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x5c,0x64,0x00,0x01,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 23697 0x5c91 "岑" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x04,0x0a,0x31,0xc1,0x1f,0x00,0x00,0x00,0x00,0x01,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x40,0x20,0x18,0x06,0xe0,0x20,0x40,0x40,0x80,0x00,
+/* 23698 0x5c92 "岒" */
+0x10,0x10,0x10,0x10,0x54,0x55,0x56,0x54,0x54,0x55,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 23699 0x5c93 "岓" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 23700 0x5c94 "岔" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,0x01,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23701 0x5c95 "岕" */
+0x01,0x21,0x21,0x21,0x3f,0x01,0x02,0x04,0x08,0x34,0xc4,0x04,0x04,0x08,0x08,0x10,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x80,0x40,0x20,0x58,0x46,0x40,0x40,0x40,0x40,0x40,
+/* 23702 0x5c96 "岖" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x00,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 23703 0x5c97 "岗" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x20,0x20,0x24,0x22,0x21,0x22,0x24,0x28,0x20,0x20,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0x48,0x48,0x88,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 23704 0x5c98 "岘" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x5c,0x64,0x01,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 23705 0x5c99 "岙" */
+0x00,0x00,0x3f,0x01,0x02,0x7f,0x04,0x08,0x30,0xc1,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x10,0xf8,0x00,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23706 0x5c9a "岚" */
+0x01,0x21,0x21,0x3f,0x00,0x1f,0x10,0x10,0x14,0x12,0x11,0x12,0x24,0x28,0x40,0x80,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0x50,0x50,0x90,0x10,0x92,0x4a,0x4a,0x06,0x02,
+/* 23707 0x5c9b "岛" */
+0x01,0x02,0x1f,0x10,0x12,0x11,0x10,0x10,0x1f,0x02,0x22,0x22,0x3f,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x10,0x10,0x50,0x20,0x00,0xfc,0x04,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 23708 0x5c9c "岜" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 23709 0x5c9d "岝" */
+0x01,0x21,0x21,0x3f,0x08,0x08,0x1f,0x24,0x44,0x87,0x04,0x04,0x07,0x04,0x04,0x04,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 23710 0x5c9e "岞" */
+0x10,0x10,0x10,0x10,0x55,0x55,0x56,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 23711 0x5c9f "岟" */
+0x10,0x10,0x10,0x11,0x55,0x55,0x55,0x55,0x55,0x57,0x54,0x5c,0x64,0x00,0x01,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 23712 0x5ca0 "岠" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 23713 0x5ca1 "岡" */
+0x00,0x7f,0x40,0x48,0x44,0x44,0x5f,0x41,0x41,0x49,0x49,0x49,0x4f,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x24,0x24,0x44,0xf4,0x04,0x04,0x24,0x24,0x24,0xe4,0x04,0x14,0x08,
+/* 23714 0x5ca2 "岢" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfe,0x10,0x10,0x90,0x90,0x90,0x90,0x10,0x50,0x20,
+/* 23715 0x5ca3 "岣" */
+0x10,0x10,0x11,0x11,0x56,0x54,0x55,0x55,0x55,0x55,0x55,0x5d,0x64,0x00,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 23716 0x5ca4 "岤" */
+0x20,0x20,0x20,0x23,0xaa,0xac,0xa8,0xa8,0xa8,0xa8,0xa8,0xb9,0xc9,0x01,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 23717 0x5ca5 "岥" */
+0x10,0x10,0x10,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 23718 0x5ca6 "岦" */
+0x01,0x21,0x21,0x21,0x3f,0x02,0x01,0x01,0x7f,0x00,0x10,0x08,0x04,0x00,0xff,0x00,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x00,0x10,0x20,0x40,0x00,0xfe,0x00,
+/* 23719 0x5ca7 "岧" */
+0x01,0x21,0x21,0x3f,0x00,0x7f,0x04,0x08,0x10,0x20,0xdf,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0x08,0x50,0x20,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23720 0x5ca8 "岨" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x03,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 23721 0x5ca9 "岩" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x18,0x28,0xc8,0x0f,0x08,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23722 0x5caa "岪" */
+0x01,0x21,0x21,0x3f,0x04,0x3f,0x04,0x04,0x1f,0x14,0x24,0x3f,0x08,0x10,0x20,0x40,
+0x00,0x08,0x08,0xf8,0x40,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0x44,0x54,0x48,0x40,
+/* 23723 0x5cab "岫" */
+0x10,0x10,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 23724 0x5cac "岬" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5c,0x64,0x00,0x00,0x00,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 23725 0x5cad "岭" */
+0x10,0x10,0x10,0x10,0x54,0x55,0x56,0x54,0x55,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 23726 0x5cae "岮" */
+0x10,0x10,0x10,0x11,0x55,0x56,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 23727 0x5caf "岯" */
+0x10,0x11,0x10,0x10,0x54,0x54,0x54,0x54,0x55,0x56,0x54,0x5c,0x64,0x00,0x03,0x00,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 23728 0x5cb0 "岰" */
+0x20,0x20,0x20,0x21,0xa9,0xaa,0xab,0xa8,0xa9,0xa9,0xaa,0xbb,0xc8,0x00,0x00,0x00,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 23729 0x5cb1 "岱" */
+0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x11,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x90,0x88,0x80,0x9e,0xe0,0x80,0x44,0x34,0x0c,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 23730 0x5cb2 "岲" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x54,0x54,0x54,0x54,0x5c,0x64,0x01,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 23731 0x5cb3 "岳" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0xff,0x01,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x70,0x80,0x00,0x00,0xf8,0x80,0x80,0x80,0xfe,0x00,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23732 0x5cb4 "岴" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x00,0x01,0x00,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 23733 0x5cb5 "岵" */
+0x10,0x10,0x10,0x10,0x55,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23734 0x5cb6 "岶" */
+0x10,0x10,0x10,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23735 0x5cb7 "岷" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 23736 0x5cb8 "岸" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x20,0x2f,0x20,0x20,0x3f,0x20,0x40,0x40,0x80,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xfc,0x00,0xf8,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,0x80,
+/* 23737 0x5cb9 "岹" */
+0x10,0x13,0x10,0x10,0x54,0x55,0x55,0x56,0x54,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23738 0x5cba "岺" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x0c,0x32,0xc1,0x1f,0x00,0x00,0x0c,0x03,0x00,0x00,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x60,0x18,0x06,0xe0,0x20,0x40,0x80,0x00,0x80,0x40,
+/* 23739 0x5cbb "岻" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 23740 0x5cbc "岼" */
+0x10,0x11,0x10,0x10,0x55,0x54,0x54,0x54,0x57,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 23741 0x5cbd "岽" */
+0x01,0x21,0x21,0x3f,0x02,0x02,0x7f,0x04,0x09,0x11,0x3f,0x01,0x11,0x21,0x45,0x02,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x10,0x08,0x04,0x00,
+/* 23742 0x5cbe "岾" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23743 0x5cbf "岿" */
+0x01,0x21,0x21,0x3f,0x00,0x08,0x4b,0x48,0x48,0x48,0x49,0x48,0x48,0x10,0x13,0x20,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23744 0x5cc0 "峀" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 23745 0x5cc1 "峁" */
+0x01,0x21,0x21,0x3f,0x00,0x0c,0x70,0x40,0x44,0x44,0x5c,0x64,0x48,0x08,0x10,0x60,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,
+/* 23746 0x5cc2 "峂" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x54,0x57,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 23747 0x5cc3 "峃" */
+0x02,0x21,0x11,0x10,0x00,0x7f,0x40,0x81,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x08,0x08,0x10,0x20,0x00,0xfe,0x02,0x04,0x00,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 23748 0x5cc4 "峄" */
+0x10,0x13,0x11,0x10,0x54,0x54,0x54,0x57,0x54,0x55,0x54,0x5c,0x67,0x00,0x00,0x00,
+0x00,0xfc,0x04,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 23749 0x5cc5 "峅" */
+0x10,0x10,0x10,0x10,0x55,0x57,0x54,0x54,0x54,0x57,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 23750 0x5cc6 "峆" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x55,0x54,0x54,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 23751 0x5cc7 "峇" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 23752 0x5cc8 "峈" */
+0x20,0x20,0x20,0x21,0xab,0xac,0xa8,0xa8,0xa9,0xaa,0xad,0xb9,0xc9,0x01,0x01,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23753 0x5cc9 "峉" */
+0x01,0x21,0x21,0x3f,0x08,0x0f,0x10,0x2c,0x03,0x1c,0xe0,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x10,
+/* 23754 0x5cca "峊" */
+0x04,0x08,0x3f,0x20,0x20,0x3f,0x20,0x3f,0x20,0x20,0x3f,0x01,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x00,0x08,0x08,0xf8,0x08,
+/* 23755 0x5ccb "峋" */
+0x10,0x10,0x11,0x11,0x56,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x00,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 23756 0x5ccc "峌" */
+0x10,0x11,0x10,0x10,0x54,0x55,0x55,0x54,0x54,0x54,0x55,0x5c,0x64,0x00,0x03,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 23757 0x5ccd "峍" */
+0x20,0x20,0x21,0x20,0xab,0xa8,0xa9,0xa8,0xa8,0xa9,0xa8,0xb8,0xcb,0x00,0x00,0x00,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 23758 0x5cce "峎" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x22,0x21,0x20,0x24,0x28,0x30,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x10,0xa0,0x40,0x30,0x0e,
+/* 23759 0x5ccf "峏" */
+0x10,0x13,0x10,0x10,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 23760 0x5cd0 "峐" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x5f,0x64,0x00,0x00,0x03,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 23761 0x5cd1 "峑" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x04,0x08,0x30,0xcf,0x01,0x01,0x1f,0x01,0x01,0x7f,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf0,0x00,0x00,0xfc,
+/* 23762 0x5cd2 "峒" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 23763 0x5cd3 "峓" */
+0x10,0x10,0x13,0x10,0x55,0x54,0x55,0x55,0x55,0x54,0x54,0x5c,0x64,0x00,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 23764 0x5cd4 "峔" */
+0x10,0x10,0x10,0x11,0x54,0x54,0x57,0x54,0x54,0x55,0x56,0x5c,0x64,0x00,0x00,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 23765 0x5cd5 "峕" */
+0x01,0x21,0x21,0x3f,0x02,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 23766 0x5cd6 "峖" */
+0x20,0x20,0x20,0x23,0xaa,0xac,0xa8,0xab,0xa8,0xa8,0xa9,0xb8,0xc8,0x00,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 23767 0x5cd7 "峗" */
+0x10,0x10,0x10,0x11,0x56,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 23768 0x5cd8 "峘" */
+0x10,0x13,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x64,0x00,0x03,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 23769 0x5cd9 "峙" */
+0x10,0x10,0x10,0x11,0x54,0x54,0x57,0x54,0x54,0x55,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 23770 0x5cda "峚" */
+0x01,0x21,0x21,0x3f,0x00,0x02,0x7f,0x04,0x18,0xe1,0x01,0x1f,0x01,0x01,0x7f,0x00,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfc,0x40,0x30,0x0e,0x00,0xf0,0x00,0x00,0xfc,0x00,
+/* 23771 0x5cdb "峛" */
+0x01,0x21,0x21,0x3f,0x00,0x7f,0x08,0x08,0x1f,0x21,0x51,0x0a,0x04,0x08,0x30,0xc0,
+0x00,0x08,0x08,0xf8,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 23772 0x5cdc "峜" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x04,0x08,0x31,0xc1,0x09,0x09,0x09,0x09,0x7f,0x00,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x40,0x20,0x18,0x06,0xf0,0x00,0x00,0x00,0xfc,0x00,
+/* 23773 0x5cdd "峝" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x20,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 23774 0x5cde "峞" */
+0x01,0x21,0x21,0x3f,0x08,0x1f,0x20,0x5f,0x90,0x17,0x14,0x14,0x24,0x24,0x43,0x80,
+0x00,0x08,0x08,0xf8,0x00,0xe0,0x20,0xfc,0x00,0xf0,0x10,0x54,0x24,0x04,0xfc,0x00,
+/* 23775 0x5cdf "峟" */
+0x01,0x21,0x21,0x3f,0x04,0x04,0x7f,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x08,0x08,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 23776 0x5ce0 "峠" */
+0x10,0x10,0x10,0x10,0x54,0x55,0x54,0x54,0x55,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x20,0x20,0x20,
+/* 23777 0x5ce1 "峡" */
+0x10,0x10,0x10,0x11,0x54,0x55,0x54,0x54,0x54,0x57,0x54,0x5c,0x64,0x00,0x01,0x02,
+0x20,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 23778 0x5ce2 "峢" */
+0x20,0x20,0x27,0x21,0xa9,0xa9,0xa9,0xaa,0xab,0xaa,0xac,0xb8,0xc8,0x01,0x02,0x04,
+0x02,0x02,0xe2,0x0a,0x0a,0xea,0x2a,0x2a,0x2a,0xaa,0x4a,0x4a,0x82,0x02,0x0a,0x04,
+/* 23779 0x5ce3 "峣" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x54,0x57,0x54,0x57,0x54,0x5c,0x65,0x01,0x02,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 23780 0x5ce4 "峤" */
+0x10,0x10,0x11,0x10,0x54,0x57,0x54,0x54,0x55,0x56,0x54,0x5c,0x64,0x01,0x01,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 23781 0x5ce5 "峥" */
+0x10,0x10,0x10,0x11,0x56,0x55,0x54,0x54,0x55,0x54,0x54,0x5d,0x64,0x00,0x00,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 23782 0x5ce6 "峦" */
+0x02,0x01,0xff,0x04,0x14,0x14,0x24,0x44,0x01,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 23783 0x5ce7 "峧" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x55,0x56,0x54,0x54,0x54,0x5c,0x64,0x00,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 23784 0x5ce8 "峨" */
+0x10,0x10,0x13,0x10,0x54,0x57,0x54,0x54,0x54,0x54,0x57,0x5c,0x64,0x00,0x02,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 23785 0x5ce9 "峩" */
+0x01,0x41,0x7f,0x00,0x06,0x38,0x08,0xff,0x08,0x08,0x0e,0x78,0x08,0x08,0x28,0x13,
+0x00,0x04,0xfc,0x00,0x40,0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x02,
+/* 23786 0x5cea "峪" */
+0x10,0x10,0x10,0x10,0x55,0x54,0x54,0x54,0x55,0x56,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 23787 0x5ceb "峫" */
+0x20,0x27,0x20,0x22,0xaa,0xaa,0xab,0xa8,0xa9,0xa9,0xaa,0xba,0xcc,0x08,0x02,0x01,
+0x00,0xde,0x92,0x92,0x94,0x94,0xd8,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x90,0x10,
+/* 23788 0x5cec "峬" */
+0x10,0x10,0x13,0x10,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 23789 0x5ced "峭" */
+0x10,0x11,0x10,0x10,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 23790 0x5cee "峮" */
+0x20,0x23,0x20,0x20,0xaf,0xa8,0xa8,0xab,0xa9,0xa9,0xab,0xbd,0xc9,0x01,0x01,0x01,
+0x00,0xf8,0x88,0x88,0xfe,0x88,0x88,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 23791 0x5cef "峯" */
+0x01,0x41,0x7f,0x08,0x1f,0x28,0x07,0x18,0xe1,0x1f,0x01,0x1f,0x01,0x7f,0x01,0x01,
+0x00,0x04,0xfc,0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x00,0xf0,0x00,0xfc,0x00,0x00,
+/* 23792 0x5cf0 "峰" */
+0x10,0x10,0x10,0x10,0x55,0x54,0x54,0x57,0x54,0x54,0x54,0x5c,0x67,0x00,0x00,0x00,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 23793 0x5cf1 "峱" */
+0x00,0x45,0x28,0x10,0x29,0x48,0x88,0x0b,0x18,0x28,0x48,0x89,0x09,0x09,0x51,0x20,
+0x00,0xfc,0x24,0x24,0xfc,0x44,0x44,0xfe,0x00,0x20,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 23794 0x5cf2 "峲" */
+0x01,0x21,0x21,0x3f,0x00,0x06,0x78,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x00,0x08,0x08,0xf8,0x00,0x08,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 23795 0x5cf3 "峳" */
+0x01,0x21,0x21,0x3f,0x00,0x10,0x10,0x24,0x24,0x64,0xa5,0x24,0x24,0x20,0x20,0x23,
+0x00,0x08,0x08,0xf8,0x00,0x40,0x40,0x7e,0x88,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 23796 0x5cf4 "峴" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5c,0x64,0x00,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 23797 0x5cf5 "峵" */
+0x20,0x20,0x23,0x22,0xac,0xa8,0xab,0xa8,0xa8,0xa8,0xa9,0xb9,0xca,0x02,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x90,0x90,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 23798 0x5cf6 "島" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x22,0x3f,0x00,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x04,0x24,0xe4,0x28,0x10,
+/* 23799 0x5cf7 "峷" */
+0x01,0x21,0x21,0x3f,0x02,0x01,0x3f,0x08,0x04,0xff,0x01,0x01,0x7f,0x01,0x01,0x01,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 23800 0x5cf8 "峸" */
+0x20,0x20,0x20,0x20,0xab,0xaa,0xaa,0xaa,0xab,0xaa,0xaa,0xba,0xca,0x05,0x04,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 23801 0x5cf9 "峹" */
+0x01,0x02,0x0c,0x30,0xcf,0x01,0x3f,0x01,0x11,0x25,0x02,0x01,0x21,0x21,0x3f,0x00,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf8,0x00,0x10,0x08,0x00,0x00,0x08,0x08,0xf8,0x08,
+/* 23802 0x5cfa "峺" */
+0x10,0x13,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x64,0x00,0x00,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 23803 0x5cfb "峻" */
+0x20,0x20,0x20,0x21,0xab,0xa8,0xa8,0xa9,0xaa,0xa8,0xa9,0xba,0xc8,0x00,0x01,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 23804 0x5cfc "峼" */
+0x10,0x11,0x11,0x11,0x55,0x56,0x54,0x57,0x54,0x54,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 23805 0x5cfd "峽" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x55,0x55,0x55,0x56,0x54,0x5c,0x64,0x00,0x01,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 23806 0x5cfe "峾" */
+0x20,0x11,0x81,0x49,0x09,0x11,0xe1,0x22,0x22,0x25,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23807 0x5cff "峿" */
+0x10,0x13,0x10,0x10,0x55,0x54,0x54,0x57,0x54,0x54,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 23808 0x5d00 "崀" */
+0x01,0x21,0x21,0x3f,0x02,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x10,0x12,0x14,0x18,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x18,0x06,
+/* 23809 0x5d01 "崁" */
+0x01,0x21,0x21,0x3f,0x10,0x10,0x10,0x7d,0x12,0x10,0x10,0x1c,0xe0,0x41,0x02,0x0c,
+0x00,0x08,0x08,0xf8,0x80,0x80,0xfc,0x04,0x48,0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 23810 0x5d02 "崂" */
+0x20,0x20,0x23,0x20,0xa8,0xab,0xaa,0xac,0xa8,0xab,0xa8,0xb8,0xc8,0x01,0x02,0x04,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x44,0x40,0xfc,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 23811 0x5d03 "崃" */
+0x20,0x20,0x20,0x27,0xa8,0xaa,0xa9,0xa9,0xaf,0xa8,0xa9,0xb9,0xca,0x04,0x08,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x50,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 23812 0x5d04 "崄" */
+0x10,0x10,0x10,0x10,0x54,0x55,0x56,0x54,0x54,0x54,0x55,0x5c,0x64,0x00,0x03,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x44,0x24,0x24,0xa8,0x88,0x10,0xfe,0x00,
+/* 23813 0x5d05 "崅" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x54,0x54,0x54,0x5c,0x64,0x01,0x01,0x02,
+0x40,0x40,0x7c,0x84,0x08,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x12,0x0a,0x04,
+/* 23814 0x5d06 "崆" */
+0x20,0x20,0x20,0x23,0xaa,0xac,0xa9,0xaa,0xa8,0xa9,0xa8,0xb8,0xc8,0x00,0x07,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 23815 0x5d07 "崇" */
+0x01,0x21,0x21,0x3f,0x02,0x01,0x7f,0x40,0x9f,0x00,0x7f,0x01,0x11,0x21,0x45,0x02,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfe,0x02,0xf4,0x00,0xfc,0x00,0x10,0x08,0x04,0x00,
+/* 23816 0x5d08 "崈" */
+0x02,0x01,0x7f,0x40,0x9f,0x00,0x7f,0x11,0x21,0x45,0x02,0x01,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x02,0xf4,0x00,0xfc,0x10,0x08,0x04,0x00,0x00,0x08,0x08,0xf8,0x08,
+/* 23817 0x5d09 "崉" */
+0x10,0x10,0x13,0x10,0x54,0x55,0x56,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23818 0x5d0a "崊" */
+0x20,0x20,0x20,0x20,0xab,0xa8,0xa8,0xa9,0xa9,0xaa,0xaa,0xbc,0xc8,0x00,0x00,0x00,
+0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x9c,0xdc,0xaa,0xaa,0xc8,0x88,0x88,0x88,0x88,
+/* 23819 0x5d0b "崋" */
+0x01,0x21,0x21,0x3f,0x00,0x7f,0x11,0x11,0xff,0x11,0x11,0x7f,0x01,0xff,0x01,0x01,
+0x00,0x08,0x08,0xf8,0x00,0xfc,0x10,0x10,0xfe,0x10,0x10,0xfc,0x00,0xfe,0x00,0x00,
+/* 23820 0x5d0c "崌" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x10,0xfe,0x10,0x10,0x7e,0x42,0x42,0x42,0x7e,0x42,
+/* 23821 0x5d0d "崍" */
+0x10,0x10,0x10,0x13,0x54,0x55,0x55,0x55,0x56,0x54,0x54,0x5c,0x65,0x02,0x04,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 23822 0x5d0e "崎" */
+0x10,0x10,0x11,0x10,0x54,0x55,0x57,0x54,0x55,0x55,0x55,0x5d,0x65,0x00,0x00,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 23823 0x5d0f "崏" */
+0x20,0x23,0x22,0x23,0xaa,0xaa,0xab,0xaa,0xa9,0xa9,0xa9,0xb9,0xc9,0x01,0x01,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23824 0x5d10 "崐" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x54,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 23825 0x5d11 "崑" */
+0x01,0x21,0x21,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x20,0x3e,0x20,0x26,0x38,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x8c,0xf0,0x82,0x82,0x7e,
+/* 23826 0x5d12 "崒" */
+0x01,0x21,0x21,0x3f,0x02,0x01,0x7f,0x08,0x14,0x22,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfc,0x20,0x50,0x88,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 23827 0x5d13 "崓" */
+0x20,0x23,0x22,0x22,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x03,0x02,
+0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfa,0x8a,0x8a,0x8a,0xfa,0x8a,0x02,0xfe,0x02,
+/* 23828 0x5d14 "崔" */
+0x01,0x41,0x7f,0x09,0x08,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x04,0xfc,0x00,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,
+/* 23829 0x5d15 "崕" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 23830 0x5d16 "崖" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x20,0x4f,0x40,0x9f,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xfc,0x80,0xf8,0x80,0xfc,0x00,0x80,0xf8,0x80,0xfe,0x00,
+/* 23831 0x5d17 "崗" */
+0x01,0x21,0x21,0x3f,0x00,0x7f,0x48,0x44,0x5f,0x41,0x49,0x49,0x49,0x4f,0x40,0x40,
+0x00,0x08,0x08,0xf8,0x00,0xfc,0x24,0x44,0xf4,0x04,0x24,0x24,0x24,0xe4,0x14,0x08,
+/* 23832 0x5d18 "崘" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 23833 0x5d19 "崙" */
+0x01,0x21,0x21,0x3f,0x02,0x0c,0x37,0xc0,0x3f,0x24,0x24,0x3f,0x24,0x24,0x24,0x20,
+0x00,0x08,0x08,0xf8,0x80,0x60,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,0x88,0xa8,0x10,
+/* 23834 0x5d1a "崚" */
+0x20,0x20,0x21,0x20,0xa8,0xab,0xa8,0xa9,0xaa,0xa8,0xa9,0xba,0xc8,0x00,0x01,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 23835 0x5d1b "崛" */
+0x20,0x23,0x22,0x22,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x04,0x04,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 23836 0x5d1c "崜" */
+0x20,0x20,0x21,0x20,0xab,0xa8,0xa8,0xa8,0xab,0xa8,0xa8,0xbb,0xc8,0x00,0x01,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 23837 0x5d1d "崝" */
+0x10,0x10,0x13,0x10,0x55,0x54,0x57,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 23838 0x5d1e "崞" */
+0x20,0x20,0x23,0x20,0xa9,0xa9,0xa9,0xa8,0xa9,0xa8,0xa8,0xbb,0xc8,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 23839 0x5d1f "崟" */
+0x01,0x21,0x21,0x3f,0x01,0x02,0x0c,0x30,0xcf,0x01,0x01,0x3f,0x11,0x09,0xff,0x00,
+0x00,0x08,0x08,0xf8,0x00,0x80,0x60,0x18,0xe6,0x00,0x00,0xf8,0x10,0x20,0xfe,0x00,
+/* 23840 0x5d20 "崠" */
+0x10,0x10,0x13,0x10,0x55,0x55,0x55,0x55,0x55,0x54,0x54,0x5c,0x61,0x06,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 23841 0x5d21 "崡" */
+0x20,0x21,0x20,0x20,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xab,0xba,0xca,0x02,0x03,0x00,
+0x00,0xfc,0x08,0x10,0x22,0xaa,0x72,0x22,0x72,0xaa,0x26,0xa2,0x42,0x02,0xfe,0x02,
+/* 23842 0x5d22 "崢" */
+0x10,0x13,0x11,0x10,0x54,0x55,0x54,0x54,0x57,0x54,0x54,0x5d,0x64,0x00,0x00,0x00,
+0x1e,0xe0,0x22,0x94,0x00,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 23843 0x5d23 "崣" */
+0x01,0x41,0x7f,0x00,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x04,0x7f,0x08,0x1c,0x03,0x7c,
+0x00,0x04,0xfc,0x70,0x80,0x00,0xfc,0x40,0x30,0x0e,0x00,0xfc,0x20,0x40,0x80,0x78,
+/* 23844 0x5d24 "崤" */
+0x21,0x20,0x20,0x20,0xab,0xa8,0xab,0xa8,0xa8,0xa9,0xaa,0xb8,0xc8,0x00,0x00,0x00,
+0x84,0x68,0x30,0xc8,0x24,0x20,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 23845 0x5d25 "崥" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x54,0x55,0x5f,0x64,0x00,0x00,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 23846 0x5d26 "崦" */
+0x20,0x20,0x27,0x21,0xaa,0xac,0xab,0xaa,0xaa,0xab,0xaa,0xba,0xcb,0x00,0x00,0x00,
+0x40,0x80,0xfe,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 23847 0x5d27 "崧" */
+0x01,0x21,0x21,0x3f,0x10,0x10,0x10,0xfd,0x31,0x3a,0x54,0x50,0x90,0x11,0x13,0x11,
+0x00,0x08,0x08,0xf8,0x10,0x90,0x90,0x08,0x48,0x44,0x42,0x90,0x88,0x08,0xfc,0x04,
+/* 23848 0x5d28 "崨" */
+0x10,0x10,0x13,0x10,0x55,0x54,0x57,0x54,0x55,0x54,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 23849 0x5d29 "崩" */
+0x01,0x21,0x21,0x3f,0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x4a,0x85,
+0x00,0x08,0x08,0xf8,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x94,0x08,
+/* 23850 0x5d2a "崪" */
+0x10,0x10,0x13,0x10,0x54,0x54,0x55,0x56,0x54,0x54,0x57,0x5c,0x64,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 23851 0x5d2b "崫" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x20,0x3f,0x20,0x24,0x24,0x27,0x20,0x48,0x48,0x8f,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x80,0x90,0x90,0xf0,0x80,0x88,0x88,0xf8,
+/* 23852 0x5d2c "崬" */
+0x01,0x21,0x21,0x3f,0x01,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x03,0x0d,0x31,0xc1,
+0x00,0x08,0x08,0xf8,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x60,0x18,0x06,
+/* 23853 0x5d2d "崭" */
+0x01,0x21,0x21,0x3f,0x10,0x10,0xfe,0x20,0x48,0x7e,0x08,0x0e,0xf8,0x49,0x09,0x0a,
+0x00,0x08,0x08,0xf8,0x00,0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 23854 0x5d2e "崮" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x21,0x21,0x2f,0x21,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x00,0x08,0x08,0xf8,0x00,0xf8,0x08,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 23855 0x5d2f "崯" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x54,0x55,0x54,0x5d,0x64,0x00,0x03,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 23856 0x5d30 "崰" */
+0x10,0x10,0x11,0x12,0x55,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 23857 0x5d31 "崱" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,0x3f,0x12,0x21,0x40,
+0x00,0x08,0x08,0xf8,0x00,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x88,
+/* 23858 0x5d32 "崲" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x54,0x57,0x54,0x54,0x5d,0x64,0x00,0x03,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 23859 0x5d33 "崳" */
+0x20,0x20,0x21,0x22,0xad,0xa8,0xab,0xaa,0xaa,0xab,0xaa,0xba,0xcb,0x02,0x02,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 23860 0x5d34 "崴" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x3f,0x20,0x2f,0x22,0x2f,0x24,0x2d,0x42,0x45,0x88,
+0x00,0x08,0x08,0xf8,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x12,0x2a,0x46,0x82,
+/* 23861 0x5d35 "崵" */
+0x10,0x10,0x10,0x10,0x54,0x54,0x54,0x55,0x54,0x54,0x55,0x5e,0x64,0x01,0x00,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 23862 0x5d36 "崶" */
+0x01,0x21,0x21,0x3f,0x08,0x08,0x7f,0x08,0xff,0x08,0x08,0x7f,0x08,0x0f,0xf0,0x40,
+0x00,0x08,0x08,0xf8,0x00,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 23863 0x5d37 "崷" */
+0x10,0x10,0x10,0x13,0x54,0x54,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23864 0x5d38 "崸" */
+0x10,0x13,0x10,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x00,0x00,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 23865 0x5d39 "崹" */
+0x20,0x20,0x21,0x20,0xa8,0xa8,0xab,0xaa,0xac,0xa9,0xa9,0xb9,0xc9,0x01,0x00,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 23866 0x5d3a "崺" */
+0x01,0x21,0x21,0x3f,0x20,0x10,0xfe,0x21,0x20,0x3c,0x25,0x24,0x24,0x44,0x54,0x88,
+0x00,0x08,0x08,0xf8,0x40,0x40,0xfe,0x20,0xac,0xb4,0xe4,0xac,0xa0,0xa2,0x82,0x7e,
+/* 23867 0x5d3b "崻" */
+0x21,0x21,0x22,0x24,0xa9,0xa9,0xaa,0xae,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x02,0x02,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 23868 0x5d3c "崼" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x54,0x57,0x54,0x5d,0x65,0x01,0x02,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 23869 0x5d3d "崽" */
+0x01,0x21,0x21,0x3f,0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x01,0x48,0x48,0x87,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x84,0x12,0xf2,
+/* 23870 0x5d3e "崾" */
+0x20,0x23,0x20,0x20,0xab,0xaa,0xaa,0xab,0xa8,0xa8,0xaf,0xb8,0xc9,0x00,0x00,0x03,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 23871 0x5d3f "崿" */
+0x10,0x11,0x11,0x11,0x55,0x54,0x55,0x54,0x57,0x54,0x54,0x5c,0x64,0x00,0x00,0x00,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,
+/* 23872 0x5d40 "嵀" */
+0x01,0x21,0x21,0x3f,0x00,0x08,0x08,0x7e,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x89,0x08,
+0x00,0x08,0x08,0xf8,0x00,0x40,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23873 0x5d41 "嵁" */
+0x10,0x10,0x13,0x10,0x54,0x54,0x54,0x54,0x54,0x57,0x55,0x5d,0x65,0x01,0x01,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 23874 0x5d42 "嵂" */
+0x01,0x21,0x21,0x3f,0x00,0x13,0x20,0x47,0x88,0x13,0x30,0x53,0x90,0x17,0x10,0x10,
+0x00,0x08,0x08,0xf8,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,
+/* 23875 0x5d43 "嵃" */
+0x10,0x10,0x11,0x10,0x54,0x54,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x20,0x10,0xfe,0x00,0x84,0x48,0xfe,0x08,0x10,0x64,0x08,0x12,0x64,0x08,0x30,0xc0,
+/* 23876 0x5d44 "嵄" */
+0x21,0x20,0x23,0x20,0xa8,0xa9,0xa8,0xa8,0xab,0xa8,0xa8,0xbb,0xc8,0x00,0x00,0x03,
+0x04,0x88,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 23877 0x5d45 "嵅" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x28,0x4f,0x40,0x80,
+0x00,0x08,0x08,0xf8,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x92,0xaa,0x46,0x82,
+/* 23878 0x5d46 "嵆" */
+0x0c,0x70,0x10,0x13,0xfc,0x38,0x54,0x91,0x12,0x11,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x48,0x44,0x40,0xfe,0x50,0x90,0x90,0x12,0x12,0x0e,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23879 0x5d47 "嵇" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x10,0x38,0x35,0x54,0x50,0x91,0x11,0x11,0x11,0x10,
+0x48,0x44,0x40,0xfe,0x50,0x50,0x92,0x92,0x0e,0x20,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 23880 0x5d48 "嵈" */
+0x20,0x27,0x22,0x21,0xa8,0xab,0xa8,0xa8,0xaf,0xa9,0xa9,0xba,0xca,0x04,0x08,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 23881 0x5d49 "嵉" */
+0x20,0x20,0x23,0x20,0xa9,0xa9,0xa9,0xa8,0xab,0xaa,0xa9,0xb8,0xc8,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 23882 0x5d4a "嵊" */
+0x20,0x23,0x20,0x27,0xa9,0xa9,0xaf,0xa9,0xab,0xad,0xa8,0xb9,0xca,0x04,0x08,0x00,
+0x38,0xc0,0x40,0xfc,0x50,0x54,0x58,0x54,0x54,0x4c,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 23883 0x5d4b "嵋" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x62,0x02,0x04,0x08,
+0x00,0xfe,0x12,0x12,0xfe,0x00,0x7e,0x42,0x42,0x7e,0x42,0x7e,0x42,0x42,0x7e,0x42,
+/* 23884 0x5d4c "嵌" */
+0x01,0x21,0x21,0x3f,0x00,0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x00,
+0x00,0x08,0x08,0xf8,0x20,0x20,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 23885 0x5d4d "嵍" */
+0x00,0x7f,0x12,0x0c,0xff,0x19,0x2a,0x48,0xa8,0x11,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23886 0x5d4e "嵎" */
+0x21,0x21,0x21,0x21,0xa9,0xa9,0xa9,0xa8,0xa8,0xab,0xaa,0xba,0xca,0x02,0x02,0x02,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 23887 0x5d4f "嵏" */
+0x01,0x41,0x7f,0x00,0x24,0x23,0x24,0x3f,0x10,0x22,0x47,0x08,0x14,0x03,0x1c,0xe0,
+0x00,0x04,0xfc,0x00,0x48,0x88,0x48,0xf8,0x10,0x08,0xe4,0x20,0x40,0x80,0x70,0x0e,
+/* 23888 0x5d50 "嵐" */
+0x01,0x21,0x21,0x3f,0x00,0x1f,0x10,0x10,0x17,0x11,0x17,0x15,0x27,0x21,0x4f,0x80,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0xd0,0x10,0x10,0xd0,0x50,0xca,0x2a,0xe6,0x22,
+/* 23889 0x5d51 "嵑" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x54,0x55,0x56,0x55,0x55,0x5d,0x65,0x00,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 23890 0x5d52 "嵒" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x7c,0x44,0x44,0x7d,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x7c,0x44,0x44,0x7c,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23891 0x5d53 "嵓" */
+0x01,0x21,0x21,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x00,0x7e,0x42,0x42,0x42,0x7e,0x42,
+0x00,0x08,0x08,0xf8,0x00,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 23892 0x5d54 "嵔" */
+0x01,0x41,0x7f,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x00,0xff,0x11,0x10,0x14,0x18,0x10,
+0x00,0x04,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xa0,0x40,0x30,0x0e,
+/* 23893 0x5d55 "嵕" */
+0x20,0x20,0x22,0x22,0xaa,0xaa,0xaa,0xab,0xa8,0xa9,0xaa,0xb8,0xc9,0x00,0x00,0x07,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 23894 0x5d56 "嵖" */
+0x10,0x10,0x13,0x10,0x54,0x55,0x56,0x55,0x55,0x55,0x55,0x5d,0x65,0x00,0x03,0x00,
+0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 23895 0x5d57 "嵗" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x3f,0x20,0x2f,0x22,0x2a,0x2a,0x31,0x42,0x44,0x9b,
+0x00,0x08,0x08,0xf8,0x48,0x44,0xfe,0x40,0x44,0x44,0x28,0xa8,0x12,0x2a,0xc6,0x02,
+/* 23896 0x5d58 "嵘" */
+0x20,0x20,0x23,0x20,0xa8,0xab,0xaa,0xac,0xa8,0xab,0xa8,0xb8,0xc8,0x01,0x02,0x00,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x24,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,
+/* 23897 0x5d59 "嵙" */
+0x01,0x21,0x21,0x3f,0x00,0x0c,0x70,0x10,0xfc,0x30,0x38,0x55,0x50,0x90,0x10,0x10,
+0x00,0x08,0x08,0xf8,0x00,0x10,0x90,0x50,0x90,0x50,0x1e,0xf0,0x10,0x10,0x10,0x10,
+/* 23898 0x5d5a "嵚" */
+0x01,0x21,0x21,0x3f,0x10,0x10,0x3e,0x40,0xbd,0x10,0x10,0xfe,0x10,0x14,0x19,0x12,
+0x00,0x08,0x08,0xf8,0x40,0x40,0x7c,0x84,0x28,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 23899 0x5d5b "嵛" */
+0x01,0x21,0x21,0x3f,0x02,0x0c,0x37,0xc0,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0x26,
+0x00,0x08,0x08,0xf8,0x80,0x60,0xd8,0x06,0x08,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 23900 0x5d5c "嵜" */
+0x01,0x41,0x7f,0x02,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x04,0xfc,0x00,0x00,0xf8,0x20,0x40,0xfe,0x10,0x90,0x90,0x90,0x90,0x50,0x20,
+/* 23901 0x5d5d "嵝" */
+0x20,0x21,0x20,0x20,0xab,0xa8,0xa9,0xaa,0xa8,0xaf,0xa8,0xb9,0xc9,0x00,0x01,0x06,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 23902 0x5d5e "嵞" */
+0x01,0x02,0x0c,0x30,0xcf,0x01,0x3f,0x01,0x11,0x25,0x02,0x10,0x92,0x92,0xfe,0x02,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf8,0x00,0x10,0x08,0x00,0x10,0x92,0x92,0xfe,0x02,
+/* 23903 0x5d5f "嵟" */
+0x01,0x41,0x7f,0x00,0x3f,0x22,0x22,0x27,0x2c,0x37,0x24,0x27,0x24,0x44,0x47,0x84,
+0x00,0x04,0xfc,0x00,0xfc,0x80,0x40,0xfc,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x00,
+/* 23904 0x5d60 "嵠" */
+0x10,0x13,0x11,0x10,0x54,0x54,0x55,0x54,0x54,0x55,0x54,0x5c,0x63,0x00,0x00,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 23905 0x5d61 "嵡" */
+0x01,0x41,0x7f,0x04,0x08,0x32,0xc4,0x0f,0x00,0x7e,0x22,0x12,0x0a,0x12,0x2a,0x44,
+0x00,0x04,0xfc,0x40,0x20,0x18,0x46,0xe0,0x20,0xfc,0x44,0x24,0x14,0x24,0x54,0x88,
+/* 23906 0x5d62 "嵢" */
+0x10,0x10,0x10,0x10,0x54,0x55,0x56,0x54,0x54,0x54,0x54,0x5c,0x65,0x01,0x02,0x00,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 23907 0x5d63 "嵣" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 23908 0x5d64 "嵤" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x81,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 23909 0x5d65 "嵥" */
+0x21,0x21,0x21,0x22,0xad,0xa8,0xa9,0xaa,0xac,0xab,0xa8,0xb8,0xc9,0x06,0x00,0x00,
+0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x24,0x24,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 23910 0x5d66 "嵦" */
+0x10,0x11,0x11,0x11,0x55,0x54,0x57,0x54,0x55,0x55,0x55,0x5d,0x64,0x00,0x03,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 23911 0x5d67 "嵧" */
+0x20,0x23,0x22,0x22,0xaa,0xaa,0xab,0xa8,0xab,0xaa,0xaa,0xbb,0xca,0x02,0x03,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 23912 0x5d68 "嵨" */
+0x20,0x20,0x21,0x21,0xa9,0xa9,0xa9,0xa9,0xa9,0xa9,0xa8,0xba,0xca,0x04,0x00,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 23913 0x5d69 "嵩" */
+0x01,0x41,0x7f,0x02,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,
+0x00,0x04,0xfc,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x0c,
+/* 23914 0x5d6a "嵪" */
+0x20,0x20,0x23,0x20,0xa9,0xa9,0xa9,0xa8,0xab,0xaa,0xaa,0xba,0xca,0x02,0x02,0x02,
+0x40,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf4,0x94,0xf4,0x04,0x14,0x08,
+/* 23915 0x5d6b "嵫" */
+0x20,0x20,0x20,0x23,0xa8,0xa8,0xa9,0xa9,0xaa,0xab,0xa8,0xb9,0xc9,0x02,0x03,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 23916 0x5d6c "嵬" */
+0x01,0x21,0x21,0x3f,0x02,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x90,0xa8,0xfa,0x8a,0x7e,
+/* 23917 0x5d6d "嵭" */
+0x20,0x20,0x23,0x21,0xa8,0xab,0xaa,0xac,0xa8,0xab,0xa8,0xb8,0xc8,0x01,0x01,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 23918 0x5d6e "嵮" */
+0x10,0x10,0x13,0x10,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x63,0x00,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 23919 0x5d6f "嵯" */
+0x11,0x10,0x10,0x13,0x54,0x55,0x54,0x57,0x54,0x55,0x55,0x5e,0x64,0x08,0x03,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 23920 0x5d70 "嵰" */
+0x10,0x10,0x10,0x11,0x54,0x55,0x54,0x57,0x54,0x55,0x54,0x5c,0x65,0x02,0x00,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 23921 0x5d71 "嵱" */
+0x20,0x20,0x23,0x22,0xac,0xa9,0xaa,0xa8,0xa9,0xaa,0xad,0xb9,0xc9,0x01,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x94,0x08,0x64,0x90,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x08,
+/* 23922 0x5d72 "嵲" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x54,0x57,0x5c,0x64,0x01,0x02,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23923 0x5d73 "嵳" */
+0x01,0x21,0x21,0x3f,0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x08,0x37,0xc0,0x1f,0x00,
+0x00,0x08,0x08,0xf8,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x80,0xfc,0x00,
+/* 23924 0x5d74 "嵴" */
+0x20,0x22,0x21,0x22,0xac,0xa9,0xae,0xab,0xaa,0xab,0xaa,0xbb,0xca,0x02,0x02,0x02,
+0x40,0x48,0x50,0x48,0xa4,0x18,0x06,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 23925 0x5d75 "嵵" */
+0x01,0x21,0x21,0x3f,0x00,0x78,0x4b,0x48,0x4f,0x78,0x4f,0x48,0x4a,0x79,0x48,0x00,
+0x00,0x08,0x08,0xf8,0x40,0x40,0xfc,0x40,0xfe,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 23926 0x5d76 "嵶" */
+0x20,0x23,0x20,0x20,0xab,0xaa,0xaa,0xab,0xa8,0xaa,0xa9,0xb9,0xca,0x00,0x02,0x01,
+0x00,0xde,0x42,0x42,0xde,0x10,0x10,0xde,0x42,0x52,0x4a,0x4a,0x52,0x42,0x94,0x08,
+/* 23927 0x5d77 "嵷" */
+0x21,0x21,0x22,0x24,0xa9,0xa9,0xaa,0xae,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 23928 0x5d78 "嵸" */
+0x01,0x21,0x21,0x3f,0x11,0x21,0x41,0x8a,0x14,0x30,0x52,0x92,0x12,0x15,0x14,0x18,
+0x00,0x08,0x08,0xf8,0x10,0x10,0x10,0xa8,0x44,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 23929 0x5d79 "嵹" */
+0x01,0x41,0x7f,0x00,0x7c,0x04,0x04,0x7c,0x41,0x41,0x7d,0x05,0x04,0x04,0x2b,0x10,
+0x00,0x04,0xfc,0x00,0xf8,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 23930 0x5d7a "嵺" */
+0x20,0x27,0x20,0x24,0xaa,0xac,0xa8,0xa9,0xae,0xa8,0xab,0xb8,0xcb,0x00,0x00,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 23931 0x5d7b "嵻" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 23932 0x5d7c "嵼" */
+0x20,0x20,0x23,0x20,0xa9,0xa8,0xab,0xaa,0xaa,0xaa,0xab,0xba,0xca,0x04,0x04,0x09,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 23933 0x5d7d "嵽" */
+0x21,0x21,0x23,0x21,0xa9,0xaa,0xac,0xab,0xaa,0xa8,0xa9,0xb9,0xc9,0x01,0x01,0x00,
+0x54,0x54,0xfe,0x54,0x54,0x72,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x24,0x2c,0x20,
+/* 23934 0x5d7e "嵾" */
+0x01,0x41,0x7f,0x08,0x1f,0x10,0x25,0x7e,0x04,0x19,0xe6,0x19,0x06,0x18,0x07,0x38,
+0x00,0x04,0xfc,0x20,0xf0,0x20,0x48,0xfc,0x40,0x30,0x4e,0x90,0x20,0xc0,0x00,0x00,
+/* 23935 0x5d7f "嵿" */
+0x01,0x41,0x7f,0x00,0x00,0xfd,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x50,0x21,
+0x00,0x04,0xfc,0x00,0x00,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,
+/* 23936 0x5d80 "嶀" */
+0x11,0x10,0x13,0x12,0x55,0x54,0x55,0x54,0x55,0x54,0x57,0x5c,0x64,0x00,0x00,0x00,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,
+/* 23937 0x5d81 "嶁" */
+0x10,0x11,0x11,0x13,0x55,0x55,0x54,0x55,0x55,0x55,0x54,0x5f,0x64,0x01,0x00,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 23938 0x5d82 "嶂" */
+0x10,0x11,0x10,0x10,0x57,0x54,0x55,0x55,0x55,0x55,0x55,0x5c,0x67,0x00,0x00,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23939 0x5d83 "嶃" */
+0x22,0x22,0x22,0x2f,0xaa,0xaf,0xaa,0xaf,0xaa,0xaf,0xaa,0xbf,0xca,0x02,0x02,0x02,
+0x00,0x02,0x3c,0xa0,0x20,0xa0,0xbe,0xa4,0xa4,0xa4,0x24,0xa4,0x24,0x44,0x44,0x84,
+/* 23940 0x5d84 "嶄" */
+0x01,0x21,0x21,0x3f,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x09,
+0x00,0x08,0x08,0xf8,0x06,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 23941 0x5d85 "嶅" */
+0x08,0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x81,0x21,0x21,0x3f,0x00,
+0x20,0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0x00,0x08,0x08,0xf8,0x08,
+/* 23942 0x5d86 "嶆" */
+0x20,0x20,0x27,0x20,0xab,0xaa,0xab,0xaa,0xab,0xa8,0xa9,0xb9,0xc9,0x01,0x01,0x01,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 23943 0x5d87 "嶇" */
+0x20,0x23,0x22,0x22,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x03,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 23944 0x5d88 "嶈" */
+0x01,0x21,0x21,0x3f,0x04,0x24,0x24,0x3d,0x04,0x04,0x7d,0x24,0x24,0x24,0x44,0x84,
+0x00,0x08,0x08,0xf8,0x40,0x7c,0xa8,0x50,0x28,0x48,0xfe,0x88,0x48,0x48,0x08,0x18,
+/* 23945 0x5d89 "嶉" */
+0x01,0x21,0x21,0x3f,0x00,0x00,0x79,0x49,0x4b,0x4d,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0x08,0x08,0xf8,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 23946 0x5d8a "嶊" */
+0x01,0x21,0x21,0x3f,0x10,0x10,0xf9,0x11,0x1b,0x15,0x31,0xd1,0x11,0x11,0x51,0x21,
+0x00,0x08,0x08,0xf8,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 23947 0x5d8b "嶋" */
+0x10,0x10,0x11,0x11,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5c,0x62,0x02,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 23948 0x5d8c "嶌" */
+0x01,0x41,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x84,0x00,
+0x00,0x04,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x94,0x08,
+/* 23949 0x5d8d "嶍" */
+0x10,0x13,0x10,0x12,0x55,0x56,0x54,0x54,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 23950 0x5d8e "嶎" */
+0x01,0x21,0x21,0x3f,0x00,0x3f,0x21,0x3f,0x20,0x2e,0x20,0x3f,0x44,0x55,0xa4,0x0c,
+0x00,0x08,0x08,0xf8,0x00,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0xa8,0x10,
+/* 23951 0x5d8f "嶏" */
+0x01,0x41,0x7f,0x00,0x7f,0x40,0x5f,0x45,0x5f,0x55,0x59,0x50,0x5f,0x50,0x5f,0x90,
+0x00,0x04,0xfc,0x00,0xfe,0x00,0xdc,0x04,0xc4,0x44,0xdc,0x50,0xd0,0x52,0xd2,0x4e,
+/* 23952 0x5d90 "嶐" */
+0x01,0x41,0x7f,0x01,0x79,0x4a,0x50,0x61,0x56,0x49,0x4a,0x6b,0x54,0x43,0x40,0x47,
+0x00,0x04,0xfc,0x00,0xf0,0x90,0x60,0x98,0x06,0xf0,0x40,0xf8,0x40,0xf8,0x40,0xfc,
+/* 23953 0x5d91 "嶑" */
+0x20,0x20,0x21,0x23,0xad,0xa9,0xa9,0xa8,0xa8,0xab,0xa8,0xbb,0xc8,0x00,0x03,0x00,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 23954 0x5d92 "嶒" */
+0x21,0x20,0x20,0x23,0xaa,0xaa,0xaa,0xaa,0xab,0xa8,0xa9,0xb9,0xc9,0x01,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 23955 0x5d93 "嶓" */
+0x10,0x13,0x11,0x10,0x55,0x54,0x55,0x56,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 23956 0x5d94 "嶔" */
+0x01,0x21,0x21,0x3f,0x08,0x14,0x22,0x5c,0x89,0x3e,0x08,0x4a,0x28,0x0e,0x71,0x22,
+0x00,0x08,0x08,0xf8,0x40,0x40,0x7c,0x84,0x28,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 23957 0x5d95 "嶕" */
+0x20,0x20,0x21,0x21,0xab,0xad,0xa9,0xa9,0xa9,0xa9,0xa9,0xb9,0xc9,0x02,0x02,0x04,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 23958 0x5d96 "嶖" */
+0x20,0x20,0x21,0x26,0xa8,0xab,0xaa,0xab,0xa8,0xaf,0xa8,0xbc,0xc2,0x04,0x02,0x01,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 23959 0x5d97 "嶗" */
+0x20,0x22,0x22,0x24,0xa9,0xaa,0xa8,0xab,0xaa,0xac,0xab,0xb8,0xc8,0x00,0x01,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 23960 0x5d98 "嶘" */
+0x01,0x21,0x21,0x3f,0x10,0x10,0x13,0xfc,0x10,0x31,0x38,0x54,0x53,0x90,0x10,0x11,
+0x00,0x08,0x08,0xf8,0x90,0x88,0xfe,0x48,0x32,0xce,0x90,0x88,0xfe,0x48,0x32,0xce,
+/* 23961 0x5d99 "嶙" */
+0x20,0x21,0x20,0x23,0xa8,0xa9,0xaa,0xa9,0xa9,0xa9,0xaa,0xbd,0xc8,0x01,0x02,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 23962 0x5d9a "嶚" */
+0x01,0x41,0x7f,0x01,0x7f,0x04,0x28,0x1f,0x28,0xcf,0x08,0x0f,0x01,0x11,0x25,0x02,
+0x00,0x04,0xfc,0x00,0xfc,0x40,0x28,0xf0,0x28,0xe6,0x20,0xe0,0x00,0x10,0x08,0x00,
+/* 23963 0x5d9b "嶛" */
+0x10,0x10,0x11,0x10,0x55,0x54,0x55,0x56,0x54,0x54,0x54,0x5c,0x64,0x00,0x01,0x00,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 23964 0x5d9c "嶜" */
+0x01,0x41,0x7f,0x00,0x3e,0x08,0x48,0x7e,0x14,0x24,0x46,0x3f,0x20,0x3f,0x20,0x3f,
+0x00,0x04,0xfc,0x00,0x7c,0x10,0x90,0xfe,0x28,0x4a,0x86,0xf8,0x08,0xf8,0x08,0xf8,
+/* 23965 0x5d9d "嶝" */
+0x20,0x27,0x20,0x22,0xa9,0xaa,0xad,0xa8,0xab,0xaa,0xaa,0xbb,0xca,0x01,0x0f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 23966 0x5d9e "嶞" */
+0x00,0x7b,0x48,0x51,0x62,0x55,0x48,0x48,0x68,0x50,0x40,0x41,0x21,0x21,0x3f,0x00,
+0x40,0xfc,0x80,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x88,0x00,0x08,0x08,0xf8,0x08,
+/* 23967 0x5d9f "嶟" */
+0x20,0x20,0x23,0x20,0xa9,0xa9,0xa9,0xa9,0xa9,0xa9,0xa8,0xbb,0xc9,0x00,0x00,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 23968 0x5da0 "嶠" */
+0x10,0x11,0x10,0x13,0x54,0x55,0x56,0x54,0x54,0x55,0x55,0x5d,0x65,0x01,0x01,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 23969 0x5da1 "嶡" */
+0x01,0x41,0x7f,0x00,0x3f,0x28,0x25,0x2f,0x22,0x2a,0x2a,0x2f,0x22,0x44,0x44,0x88,
+0x00,0x04,0xfc,0x00,0xfe,0x90,0x10,0xbe,0x22,0xd4,0x90,0x90,0x28,0x28,0x44,0x82,
+/* 23970 0x5da2 "嶢" */
+0x20,0x20,0x21,0x20,0xab,0xa9,0xab,0xa9,0xa9,0xae,0xa8,0xbb,0xc8,0x00,0x01,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 23971 0x5da3 "嶣" */
+0x01,0x41,0x7f,0x01,0x08,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x10,0x24,0x22,0x42,
+0x00,0x04,0xfc,0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x88,0x44,0x44,
+/* 23972 0x5da4 "嶤" */
+0x01,0x41,0x7f,0x01,0x3f,0x01,0xff,0x08,0x3e,0x08,0x7e,0x00,0x7f,0x04,0x18,0xe0,
+0x00,0x04,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf8,0x20,0xfc,0x00,0xfc,0x40,0x42,0x3e,
+/* 23973 0x5da5 "嶥" */
+0x20,0x2f,0x28,0x2a,0xa9,0xab,0xa8,0xa8,0xaa,0xaa,0xab,0xb8,0xc8,0x09,0x09,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 23974 0x5da6 "嶦" */
+0x10,0x10,0x11,0x13,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x65,0x02,0x02,0x04,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 23975 0x5da7 "嶧" */
+0x10,0x11,0x11,0x11,0x54,0x55,0x54,0x57,0x54,0x54,0x55,0x5c,0x67,0x00,0x00,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 23976 0x5da8 "嶨" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x40,0x81,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0x04,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 23977 0x5da9 "嶩" */
+0x10,0x11,0x11,0x11,0x55,0x55,0x54,0x55,0x55,0x55,0x55,0x5d,0x65,0x01,0x01,0x02,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfe,0x00,0x7c,0x00,0xfe,0x50,0x54,0x48,0x66,
+/* 23978 0x5daa "嶪" */
+0x01,0x41,0x7f,0x24,0x14,0xff,0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x05,0x19,0xe1,
+0x00,0x04,0xfc,0x48,0x50,0xfe,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x30,0x0e,
+/* 23979 0x5dab "嶫" */
+0x20,0x22,0x21,0x20,0xab,0xa8,0xa8,0xab,0xa8,0xa9,0xa8,0xbb,0xc8,0x01,0x06,0x00,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 23980 0x5dac "嶬" */
+0x21,0x20,0x23,0x20,0xa9,0xa8,0xab,0xa8,0xa9,0xa8,0xab,0xb8,0xc8,0x03,0x00,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 23981 0x5dad "嶭" */
+0x01,0x21,0x21,0x3f,0x10,0x7c,0x45,0x44,0x7c,0x43,0x40,0x7c,0x45,0x44,0x7c,0x44,
+0x00,0x08,0x08,0xf8,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,
+/* 23982 0x5dae "嶮" */
+0x10,0x10,0x10,0x10,0x55,0x56,0x54,0x54,0x55,0x55,0x55,0x5d,0x64,0x00,0x01,0x02,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 23983 0x5daf "嶯" */
+0x41,0x7f,0x00,0x3e,0x22,0x3e,0x00,0xff,0x22,0x3e,0x22,0x3e,0x22,0x2f,0xf2,0x42,
+0x04,0xfc,0x00,0x28,0x24,0x24,0x20,0xfe,0x20,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 23984 0x5db0 "嶰" */
+0x21,0x21,0x22,0x24,0xab,0xaa,0xaa,0xab,0xaa,0xaa,0xab,0xba,0xca,0x02,0x02,0x04,
+0x00,0xde,0x4a,0x8a,0xea,0xb6,0xa4,0xf4,0xbe,0xa4,0xe4,0xbe,0xa4,0xa4,0x24,0x64,
+/* 23985 0x5db1 "嶱" */
+0x10,0x13,0x10,0x11,0x55,0x55,0x55,0x55,0x54,0x55,0x56,0x5d,0x65,0x01,0x00,0x00,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 23986 0x5db2 "嶲" */
+0x01,0x41,0x7f,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3e,0x22,0x23,0x20,
+0x00,0x04,0xfc,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x7c,0x44,0xd4,0x08,
+/* 23987 0x5db3 "嶳" */
+0x21,0x3f,0x00,0x7f,0x06,0x3b,0x04,0x19,0x62,0x0c,0x73,0x10,0x7c,0x10,0x1e,0xf1,
+0x08,0xf8,0x00,0xfc,0x00,0x08,0xb0,0xc0,0xa0,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,
+/* 23988 0x5db4 "嶴" */
+0x04,0x3f,0x20,0x29,0x25,0x2f,0x25,0x29,0x02,0xff,0x08,0x31,0xd1,0x11,0x1f,0x00,
+0x00,0xf8,0x08,0x28,0x48,0xe8,0x48,0x28,0x00,0xfe,0x20,0x18,0x16,0x10,0xf0,0x10,
+/* 23989 0x5db5 "嶵" */
+0x20,0x23,0x22,0x22,0xab,0xa8,0xa8,0xaf,0xa8,0xa8,0xab,0xb8,0xc8,0x07,0x00,0x00,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0x90,0x9e,0x90,0x90,0x9c,0x90,0x90,0x9e,0x90,0x90,
+/* 23990 0x5db6 "嶶" */
+0x01,0x41,0x7f,0x00,0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x29,0x29,0x29,0x30,
+0x00,0x04,0xfc,0x00,0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0x28,0x10,0xa8,0x44,0x82,
+/* 23991 0x5db7 "嶷" */
+0x01,0x41,0x7f,0x00,0x24,0x3a,0x22,0x1e,0x20,0x3e,0x48,0x08,0x7f,0x14,0x22,0x41,
+0x00,0x04,0xfc,0x00,0x7c,0x04,0x28,0x10,0xfe,0x12,0x50,0x5e,0x50,0xb0,0x9e,0x00,
+/* 23992 0x5db8 "嶸" */
+0x20,0x22,0x22,0x24,0xa9,0xaa,0xa8,0xab,0xaa,0xa8,0xab,0xb8,0xc8,0x01,0x06,0x00,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x22,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 23993 0x5db9 "嶹" */
+0x20,0x23,0x20,0x21,0xa8,0xab,0xa8,0xa9,0xa8,0xab,0xa8,0xbb,0xc8,0x03,0x02,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 23994 0x5dba "嶺" */
+0x01,0x41,0x7f,0x10,0x13,0x28,0x45,0x93,0x09,0xfd,0x05,0x09,0x51,0x20,0x10,0x01,
+0x00,0x04,0xfc,0x00,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x90,0x08,
+/* 23995 0x5dbb "嶻" */
+0x01,0x41,0x7f,0x08,0x7f,0x08,0xff,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x00,0x04,0xfc,0x20,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x18,0x92,0x2a,0xc6,0x82,
+/* 23996 0x5dbc "嶼" */
+0x21,0x22,0x22,0x22,0xab,0xaa,0xaa,0xab,0xaa,0xaa,0xaf,0xb8,0xc9,0x01,0x02,0x04,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 23997 0x5dbd "嶽" */
+0x01,0x21,0x21,0x3f,0x00,0x52,0x2f,0x50,0x97,0x10,0x37,0x50,0x97,0x15,0x57,0x20,
+0x00,0x08,0x08,0xf8,0x10,0x18,0x94,0x14,0x7e,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 23998 0x5dbe "嶾" */
+0x20,0x27,0x22,0x21,0xab,0xa8,0xaf,0xa8,0xab,0xa8,0xab,0xb8,0xcb,0x05,0x05,0x08,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 23999 0x5dbf "嶿" */
+0x20,0x21,0x20,0x23,0xaa,0xa9,0xa8,0xa9,0xa8,0xab,0xa8,0xb9,0xc9,0x01,0x01,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 24000 0x5dc0 "巀" */
+0x01,0x41,0x7f,0x08,0x2a,0x4d,0x08,0x14,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x00,0x04,0xfc,0x00,0x28,0x24,0x20,0x2e,0x70,0x24,0x24,0x28,0x12,0x2a,0x46,0x82,
+/* 24001 0x5dc1 "巁" */
+0x20,0x23,0x22,0x23,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xbb,0xc3,0x05,0x05,0x09,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 24002 0x5dc2 "巂" */
+0x21,0x3f,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3f,0x24,0x2b,0x22,0x23,
+0x08,0xf8,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xfc,0x24,0xd4,0x44,0xcc,
+/* 24003 0x5dc3 "巃" */
+0x41,0x7f,0x08,0x7f,0x22,0x14,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x45,0x42,
+0x04,0xfc,0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,
+/* 24004 0x5dc4 "巄" */
+0x21,0x20,0x23,0x20,0xaa,0xa9,0xab,0xa8,0xab,0xaa,0xab,0xba,0xcb,0x02,0x02,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 24005 0x5dc5 "巅" */
+0x21,0x3f,0x08,0x7e,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x22,0xff,0x24,0x42,
+0x08,0xf8,0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x28,0x44,0x82,
+/* 24006 0x5dc6 "巆" */
+0x20,0x22,0x22,0x24,0xa9,0xaa,0xab,0xaa,0xa8,0xa8,0xa8,0xb8,0xc9,0x01,0x01,0x01,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xf8,0x88,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 24007 0x5dc7 "巇" */
+0x20,0x20,0x20,0x23,0xaa,0xaa,0xab,0xaa,0xaa,0xab,0xac,0xbf,0xca,0x03,0x01,0x07,
+0x88,0xcc,0x8a,0xe8,0xa8,0xde,0xa8,0x6a,0x0a,0xea,0x0c,0xec,0x2a,0xea,0x56,0xe2,
+/* 24008 0x5dc8 "巈" */
+0x01,0x41,0x7f,0x00,0x29,0x7d,0x29,0x3a,0x11,0x7c,0x55,0x7c,0x10,0xfd,0x10,0x10,
+0x00,0x04,0xfc,0x00,0x00,0xfc,0x04,0x44,0x54,0xe4,0xf4,0x44,0xe4,0x54,0x54,0x08,
+/* 24009 0x5dc9 "巉" */
+0x21,0x22,0x27,0x22,0xab,0xaa,0xab,0xaa,0xa9,0xaa,0xaf,0xba,0xcb,0x00,0x01,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 24010 0x5dca "巊" */
+0x23,0x22,0x23,0x22,0xab,0xaa,0xab,0xa9,0xaa,0xa8,0xaf,0xb8,0xc9,0x00,0x00,0x03,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 24011 0x5dcb "巋" */
+0x01,0x41,0x7f,0x10,0x7d,0x44,0x7c,0x40,0x7d,0x44,0x7d,0x11,0x5c,0x50,0x5e,0xf0,
+0x00,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0xfc,0xa4,0xac,0x20,
+/* 24012 0x5dcc "巌" */
+0x41,0x7f,0x22,0x11,0x3f,0x20,0x2e,0x22,0x3f,0x29,0x2f,0x29,0x2f,0x49,0x7f,0x81,
+0x04,0xfc,0x08,0x10,0xfc,0x00,0x20,0x3c,0xa8,0x48,0x28,0x28,0x10,0xd0,0x28,0x44,
+/* 24013 0x5dcd "巍" */
+0x01,0x41,0x7f,0x0c,0x70,0x11,0xfd,0x39,0x55,0x93,0xfc,0x24,0x68,0x10,0x29,0xc6,
+0x00,0x04,0xfc,0x20,0x40,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x5a,0x5e,0x90,0x12,0x0e,
+/* 24014 0x5dce "巎" */
+0x20,0x27,0x20,0x22,0xaa,0xab,0xaa,0xaa,0xab,0xac,0xaa,0xbd,0xca,0x00,0x01,0x06,
+0x00,0xfe,0x40,0xee,0xaa,0xea,0xae,0xe8,0xaa,0xe6,0x88,0xf4,0x90,0x60,0x98,0x06,
+/* 24015 0x5dcf "巏" */
+0x20,0x23,0x20,0x23,0xaa,0xab,0xa8,0xa8,0xa9,0xa9,0xab,0xbd,0xc9,0x01,0x01,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 24016 0x5dd0 "巐" */
+0x01,0x41,0x7f,0x08,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x43,
+0x00,0x04,0xfc,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x64,0x24,0xfe,0x24,0x24,0x44,
+/* 24017 0x5dd1 "巑" */
+0x25,0x27,0x29,0x27,0xab,0xad,0xa9,0xab,0xaa,0xab,0xaa,0xbb,0xca,0x03,0x01,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 24018 0x5dd2 "巒" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 24019 0x5dd3 "巓" */
+0x01,0x41,0x7f,0x22,0x3c,0x21,0x1f,0x52,0x5e,0x52,0x5e,0x52,0x7f,0x00,0x24,0x42,
+0x00,0x04,0xfc,0x00,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x82,
+/* 24020 0x5dd4 "巔" */
+0x21,0x3f,0x08,0x7e,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x22,0xff,0x24,0x42,
+0x08,0xf8,0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x82,
+/* 24021 0x5dd5 "巕" */
+0x21,0x20,0x27,0x21,0xab,0xaa,0xab,0xaa,0xab,0xaa,0xab,0xb8,0xcb,0x00,0x00,0x03,
+0x08,0x90,0xfe,0x08,0xfe,0x54,0xc8,0x3e,0xc8,0x5c,0xc8,0x40,0xfe,0x88,0x70,0x8c,
+/* 24022 0x5dd6 "巖" */
+0x01,0x41,0x7f,0x00,0x1e,0x12,0x3f,0x20,0x2e,0x22,0x3f,0x29,0x2f,0x49,0x5f,0x81,
+0x00,0x04,0xfc,0x00,0x78,0x48,0xfc,0x20,0x20,0x3c,0xc8,0x28,0x28,0x90,0x28,0x44,
+/* 24023 0x5dd7 "巗" */
+0x23,0x22,0x23,0x20,0xab,0xaa,0xaa,0xaa,0xab,0xaa,0xaa,0xba,0xca,0x02,0x05,0x08,
+0xde,0x52,0xde,0x00,0xfe,0x00,0xc8,0x4e,0xea,0xb2,0xea,0xaa,0xea,0xb4,0xe4,0x2a,
+/* 24024 0x5dd8 "巘" */
+0x21,0x21,0x21,0x2f,0xa9,0xab,0xa9,0xaf,0xa9,0xab,0xaa,0xbb,0xca,0x0b,0x0a,0x12,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 24025 0x5dd9 "巙" */
+0x21,0x27,0x20,0x22,0xaa,0xab,0xaa,0xaa,0xab,0xac,0xaa,0xbd,0xca,0x00,0x01,0x06,
+0x10,0xfe,0x40,0xee,0xaa,0xea,0xae,0xe8,0xaa,0xe6,0x88,0xf4,0x90,0x60,0x98,0x06,
+/* 24026 0x5dda "巚" */
+0x01,0x41,0x7f,0x08,0x0f,0x08,0x7f,0x48,0x7e,0x48,0x5f,0x51,0x5f,0x55,0x55,0x93,
+0x00,0x04,0xfc,0x00,0x90,0x14,0x92,0xfe,0x10,0x90,0xa8,0x28,0x28,0x44,0x44,0x82,
+/* 24027 0x5ddb "巛" */
+0x00,0x00,0x08,0x08,0x08,0x11,0x11,0x22,0x22,0x11,0x11,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x88,0x88,0x88,0x10,0x10,0x20,0x20,0x10,0x10,0x88,0x88,0x88,0x00,0x00,
+/* 24028 0x5ddc "巜" */
+0x00,0x04,0x04,0x08,0x08,0x10,0x20,0x41,0x20,0x10,0x08,0x08,0x04,0x04,0x00,0x00,
+0x00,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x20,0x10,0x10,0x00,0x00,
+/* 24029 0x5ddd "川" */
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,
+/* 24030 0x5dde "州" */
+0x10,0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x04,0x84,0x84,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,
+/* 24031 0x5ddf "巟" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x1f,0x00,0x11,0x11,0x11,0x11,0x21,0x21,0x41,0x80,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x0e,
+/* 24032 0x5de0 "巠" */
+0x00,0x7f,0x00,0x08,0x11,0x22,0x11,0x08,0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfe,0x00,0x88,0x10,0x20,0x10,0x88,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 24033 0x5de1 "巡" */
+0x00,0x21,0x11,0x11,0x02,0x02,0xf4,0x12,0x12,0x11,0x11,0x11,0x10,0x28,0x47,0x00,
+0x00,0x24,0x24,0x24,0x48,0x48,0x90,0x48,0x48,0x24,0x24,0x24,0x00,0x00,0xfe,0x00,
+/* 24034 0x5de2 "巢" */
+0x08,0x11,0x22,0x11,0x08,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x88,0x10,0x20,0x10,0x88,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 24035 0x5de3 "巣" */
+0x22,0x11,0x11,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x08,0x08,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 24036 0x5de4 "巤" */
+0x10,0x21,0x10,0x3f,0x24,0x23,0x24,0x3f,0x00,0x29,0x25,0x29,0x25,0x21,0x29,0x31,
+0x84,0x08,0x84,0xf8,0x48,0x88,0x48,0xf8,0x00,0x48,0x28,0x48,0x2a,0x0a,0x46,0x82,
+/* 24037 0x5de5 "工" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 24038 0x5de6 "左" */
+0x02,0x02,0x02,0xff,0x04,0x04,0x04,0x08,0x0f,0x10,0x10,0x20,0x40,0x80,0x3f,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0x80,0xfe,0x00,
+/* 24039 0x5de7 "巧" */
+0x00,0x03,0xfc,0x10,0x10,0x10,0x11,0x11,0x10,0x10,0x1e,0xe0,0x40,0x00,0x00,0x00,
+0x00,0xfe,0x40,0x40,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 24040 0x5de8 "巨" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x00,
+0x00,0xf8,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 24041 0x5de9 "巩" */
+0x00,0x01,0x7d,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 24042 0x5dea "巪" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x00,0x7f,0x00,0x00,0x00,
+0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x00,0xf8,0x08,0x08,0x08,
+/* 24043 0x5deb "巫" */
+0x00,0x00,0x7f,0x01,0x01,0x11,0x11,0x11,0x29,0x29,0x45,0x85,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x10,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0x00,0xfe,0x00,
+/* 24044 0x5dec "巬" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x01,0x3f,0x01,0xff,0x02,0x04,0x18,0x60,
+0x00,0xf0,0x10,0x10,0x12,0x12,0x0e,0x00,0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x0c,
+/* 24045 0x5ded "巭" */
+0x00,0x7c,0x13,0x10,0x10,0x1c,0xe1,0x42,0x01,0x3f,0x01,0xff,0x02,0x04,0x18,0x60,
+0x40,0x40,0xfc,0x44,0x44,0x84,0x14,0x08,0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x0c,
+/* 24046 0x5dee "差" */
+0x08,0x04,0x7f,0x01,0x01,0x3f,0x02,0x02,0xff,0x04,0x08,0x17,0x20,0x40,0x80,0x1f,
+0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x80,0x80,0x80,0xfc,
+/* 24047 0x5def "巯" */
+0x00,0x7c,0x05,0x08,0x10,0x28,0x45,0x82,0x00,0x7c,0x10,0x10,0x10,0x1d,0xe1,0x42,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x26,0x00,
+/* 24048 0x5df0 "巰" */
+0x00,0xfe,0x55,0x54,0xa8,0x54,0x55,0x00,0xfe,0x10,0x10,0x10,0x1e,0xf1,0x41,0x02,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x26,0x00,
+/* 24049 0x5df1 "己" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 24050 0x5df2 "已" */
+0x00,0x3f,0x00,0x00,0x00,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 24051 0x5df3 "巳" */
+0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 24052 0x5df4 "巴" */
+0x00,0x3f,0x21,0x21,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 24053 0x5df5 "巵" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x28,0x28,0x28,0x2f,0x28,0x48,0x48,0x87,
+0x7c,0x80,0x00,0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xf8,0x08,0x02,0x02,0xfe,
+/* 24054 0x5df6 "巶" */
+0x00,0xfe,0x22,0x22,0x42,0x4a,0x84,0x00,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x00,
+0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 24055 0x5df7 "巷" */
+0x04,0x04,0x3f,0x04,0x04,0xff,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x08,0x08,0x08,0x07,
+0x40,0x40,0xf8,0x40,0x40,0xfe,0x40,0x20,0xf0,0x28,0x26,0xe0,0x20,0x08,0x08,0xf8,
+/* 24056 0x5df8 "巸" */
+0x00,0x7f,0x48,0x48,0x48,0x5e,0x52,0x52,0x52,0x52,0x5e,0x48,0x48,0x48,0x7f,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 24057 0x5df9 "巹" */
+0x1f,0x00,0x7d,0x05,0x09,0x31,0xc5,0x02,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x20,0x1f,
+0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x04,0x04,0xfc,
+/* 24058 0x5dfa "巺" */
+0x00,0x7c,0x44,0x44,0x7c,0x40,0x42,0x42,0x3e,0x00,0x00,0xff,0x00,0x08,0x10,0x20,
+0x00,0xf8,0x88,0x88,0xf8,0x80,0x84,0x84,0x7c,0x00,0x00,0xfe,0x00,0x20,0x10,0x08,
+/* 24059 0x5dfb "巻" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x2f,0xc0,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0xe8,0x26,0x20,0xe0,0x00,0x08,0x08,0xf8,
+/* 24060 0x5dfc "巼" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x20,0x1f,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x04,0x04,0xfc,0x00,0x44,0x58,0x60,0x42,0x42,0x3e,
+/* 24061 0x5dfd "巽" */
+0x00,0x7c,0x44,0x7c,0x40,0x42,0x3e,0x04,0x04,0x3f,0x04,0x04,0xff,0x08,0x10,0x20,
+0x00,0xf8,0x88,0xf8,0x80,0x84,0x7c,0x40,0x40,0xf8,0x40,0x40,0xfe,0x20,0x10,0x08,
+/* 24062 0x5dfe "巾" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,0x01,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,
+/* 24063 0x5dff "巿" */
+0x01,0x01,0xff,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,
+/* 24064 0x5e00 "帀" */
+0x00,0x7f,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,0x01,
+0x00,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,
+/* 24065 0x5e01 "币" */
+0x00,0x01,0x7f,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,0x01,
+0x08,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,0x00,
+/* 24066 0x5e02 "市" */
+0x02,0x01,0x00,0x7f,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24067 0x5e03 "布" */
+0x02,0x02,0x02,0xff,0x04,0x09,0x11,0x3f,0x51,0x91,0x11,0x11,0x11,0x11,0x01,0x01,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24068 0x5e04 "帄" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x4b,0x08,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 24069 0x5e05 "帅" */
+0x08,0x08,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x09,0x11,0x10,0x20,0x40,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 24070 0x5e06 "帆" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x12,0x12,0x14,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 24071 0x5e07 "帇" */
+0x01,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24072 0x5e08 "师" */
+0x08,0x0b,0x48,0x48,0x48,0x49,0x49,0x49,0x49,0x49,0x49,0x09,0x11,0x10,0x20,0x40,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 24073 0x5e09 "帉" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x56,0x55,0x54,0x54,0x54,0x5c,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 24074 0x5e0a "帊" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x10,0x10,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 24075 0x5e0b "帋" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x28,0x31,0x21,0x1f,0x11,0x11,0x11,0x11,0x01,0x01,
+0x78,0x80,0x80,0x80,0xfc,0x40,0x22,0x1a,0x06,0xf0,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 24076 0x5e0c "希" */
+0x18,0x06,0x01,0x06,0x3a,0x02,0xff,0x04,0x08,0x1f,0x28,0x48,0x88,0x08,0x00,0x00,
+0x18,0x60,0x80,0x60,0x18,0x00,0xfe,0x80,0x80,0xf8,0x88,0x88,0xa8,0x90,0x80,0x80,
+/* 24077 0x5e0d "帍" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x44,0x44,0x80,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x40,0x40,0xfc,0x44,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 24078 0x5e0e "帎" */
+0x10,0x10,0x10,0x7d,0x55,0x56,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 24079 0x5e0f "帏" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x54,0x55,0x54,0x5c,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 24080 0x5e10 "帐" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x57,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,0x10,
+0x80,0x84,0x84,0x88,0x90,0xa0,0x80,0xfe,0xa0,0x90,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 24081 0x5e11 "帑" */
+0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc3,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0xfc,0x44,0x28,0x10,0x28,0x46,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24082 0x5e12 "帒" */
+0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x11,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0xa0,0x90,0xbe,0xc0,0x40,0x24,0x14,0x0c,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24083 0x5e13 "帓" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x5d,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 24084 0x5e14 "帔" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x12,0x12,0x14,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 24085 0x5e15 "帕" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24086 0x5e16 "帖" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24087 0x5e17 "帗" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x54,0x54,0x54,0x5d,0x11,0x12,0x10,0x10,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 24088 0x5e18 "帘" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x21,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xf8,0x08,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24089 0x5e19 "帙" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x56,0x54,0x57,0x54,0x54,0x5c,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 24090 0x5e1a "帚" */
+0x00,0x1f,0x00,0x0f,0x00,0x1f,0x00,0x7f,0x41,0x81,0x1f,0x11,0x11,0x11,0x11,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0x50,0x20,0x00,
+/* 24091 0x5e1b "帛" */
+0x01,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24092 0x5e1c "帜" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x5c,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 24093 0x5e1d "帝" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0x7f,0x41,0x81,0x1f,0x11,0x11,0x11,0x11,0x01,0x01,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x02,0x04,0xf0,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 24094 0x5e1e "帞" */
+0x10,0x13,0x10,0x7c,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24095 0x5e1f "帟" */
+0x02,0x01,0x7f,0x04,0x24,0x44,0x89,0x10,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24096 0x5e20 "帠" */
+0x02,0x1c,0x10,0x10,0x1e,0x10,0x10,0x1f,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,0x01,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 24097 0x5e21 "帡" */
+0x11,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x54,0x57,0x54,0x5c,0x11,0x11,0x12,0x14,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 24098 0x5e22 "帢" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x55,0x54,0x54,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24099 0x5e23 "帣" */
+0x11,0x09,0x09,0x7f,0x02,0x04,0xff,0x11,0x21,0xdf,0x11,0x11,0x11,0x11,0x01,0x01,
+0x10,0x10,0x20,0xfc,0x00,0x00,0xfe,0x10,0x08,0xf6,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 24100 0x5e24 "帤" */
+0x10,0x10,0xfe,0x22,0x42,0x34,0x08,0x34,0xc2,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,
+/* 24101 0x5e25 "帥" */
+0x10,0x20,0x7c,0x44,0x45,0x45,0x7d,0x41,0x41,0x7d,0x45,0x45,0x45,0x7c,0x44,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 24102 0x5e26 "带" */
+0x09,0x09,0x7f,0x09,0x09,0x00,0x7f,0x41,0x81,0x1f,0x11,0x11,0x11,0x11,0x01,0x01,
+0x20,0x20,0xfc,0x20,0x20,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 24103 0x5e27 "帧" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x10,0x10,0x10,0x11,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 24104 0x5e28 "帨" */
+0x11,0x10,0x10,0x7c,0x55,0x55,0x55,0x55,0x55,0x54,0x54,0x5c,0x10,0x11,0x12,0x14,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 24105 0x5e29 "帩" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 24106 0x5e2a "帪" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 24107 0x5e2b "師" */
+0x10,0x23,0x7c,0x44,0x44,0x45,0x7d,0x41,0x41,0x7d,0x45,0x45,0x45,0x7c,0x44,0x00,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 24108 0x5e2c "帬" */
+0x00,0x3f,0x02,0xff,0x04,0x3f,0x08,0x1f,0x28,0xcf,0x00,0x1f,0x10,0x10,0x10,0x00,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x80,0xfc,0x84,0x94,0x88,0x80,
+/* 24109 0x5e2d "席" */
+0x01,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x23,0x20,0x2f,0x28,0x48,0x48,0x88,0x00,
+0x00,0x80,0xfe,0x20,0x20,0xfc,0x20,0x20,0xe0,0x80,0xf8,0x88,0x88,0xa8,0x90,0x80,
+/* 24110 0x5e2e "帮" */
+0x08,0x08,0xff,0x08,0x7e,0x08,0xff,0x10,0x20,0x41,0xbf,0x21,0x21,0x21,0x21,0x01,
+0x00,0x7c,0x48,0x50,0x48,0x44,0x54,0x48,0x40,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,
+/* 24111 0x5e2f "帯" */
+0x09,0x09,0x7f,0x09,0x0f,0x00,0x7f,0x41,0x81,0x1f,0x11,0x11,0x11,0x11,0x01,0x01,
+0x20,0x20,0xfc,0x20,0xe0,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 24112 0x5e30 "帰" */
+0x08,0x09,0x48,0x48,0x48,0x49,0x48,0x4b,0x4a,0x48,0x49,0x09,0x11,0x11,0x21,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 24113 0x5e31 "帱" */
+0x20,0x20,0x27,0xf8,0xab,0xa8,0xaf,0xa8,0xa9,0xa9,0xaa,0xba,0x24,0x28,0x20,0x20,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x90,0x10,0xfe,0x10,0x90,0x50,0x10,0x50,0x20,
+/* 24114 0x5e32 "帲" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x55,0x54,0x54,0x5c,0x10,0x10,0x10,0x11,
+0x44,0x44,0x88,0xdc,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 24115 0x5e33 "帳" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x57,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 24116 0x5e34 "帴" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x55,0x54,0x54,0x55,0x5c,0x10,0x10,0x10,0x11,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 24117 0x5e35 "帵" */
+0x20,0x20,0x23,0xfa,0xad,0xa9,0xa9,0xaa,0xaa,0xab,0xac,0xb8,0x21,0x21,0x22,0x24,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 24118 0x5e36 "帶" */
+0x14,0x14,0x7f,0x14,0x24,0x47,0x80,0x7f,0x41,0x1f,0x11,0x11,0x11,0x11,0x01,0x01,
+0x50,0x50,0xfc,0x50,0x52,0xce,0x00,0xfc,0x04,0xf0,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 24119 0x5e37 "帷" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,0x10,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 24120 0x5e38 "常" */
+0x01,0x11,0x09,0x7f,0x40,0x8f,0x08,0x08,0x0f,0x01,0x1f,0x11,0x11,0x11,0x11,0x01,
+0x00,0x10,0x20,0xfe,0x02,0xe4,0x20,0x20,0xe0,0x00,0xf0,0x10,0x10,0x50,0x20,0x00,
+/* 24121 0x5e39 "帹" */
+0x20,0x20,0x23,0xf8,0xa9,0xa8,0xaf,0xa8,0xa8,0xaf,0xa8,0xb9,0x20,0x20,0x21,0x26,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 24122 0x5e3a "帺" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5d,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfc,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 24123 0x5e3b "帻" */
+0x20,0x20,0x27,0xf8,0xab,0xa8,0xaf,0xa8,0xab,0xaa,0xaa,0xba,0x22,0x20,0x21,0x26,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x48,0x48,0x48,0xa0,0x10,0x08,
+/* 24124 0x5e3c "帼" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xbb,0x22,0x22,0x23,0x22,
+0x00,0xfe,0x02,0x02,0xfe,0x22,0x22,0xfa,0x22,0x32,0x2a,0xfe,0x02,0x02,0xfe,0x02,
+/* 24125 0x5e3d "帽" */
+0x20,0x23,0x22,0xfa,0xaa,0xaa,0xaa,0xa8,0xa9,0xa9,0xa9,0xb9,0x21,0x21,0x21,0x21,
+0x00,0xfc,0x04,0xf4,0x04,0xf4,0x04,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 24126 0x5e3e "帾" */
+0x10,0x10,0x11,0x7c,0x54,0x57,0x54,0x54,0x54,0x55,0x56,0x5c,0x10,0x10,0x10,0x10,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 24127 0x5e3f "帿" */
+0x21,0x21,0x21,0xfa,0xaa,0xae,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x22,0x22,0x22,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 24128 0x5e40 "幀" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x10,0x10,0x11,0x12,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 24129 0x5e41 "幁" */
+0x10,0x13,0x10,0x7c,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x10,0x10,0x11,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 24130 0x5e42 "幂" */
+0x00,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x02,0xff,0x09,0x3f,0xd1,0x11,0x11,0x01,
+0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0xf8,0x16,0x50,0x20,0x00,
+/* 24131 0x5e43 "幃" */
+0x10,0x10,0x11,0x7c,0x57,0x54,0x55,0x55,0x55,0x54,0x57,0x5c,0x12,0x13,0x10,0x10,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 24132 0x5e44 "幄" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xab,0xaa,0xaa,0xab,0xaa,0xba,0x25,0x24,0x28,0x33,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 24133 0x5e45 "幅" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 24134 0x5e46 "幆" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x55,0x56,0x55,0x55,0x5d,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 24135 0x5e47 "幇" */
+0x08,0x08,0x7e,0x08,0xfe,0x08,0x7e,0x08,0x0f,0xf1,0x01,0x3f,0x21,0x21,0x21,0x01,
+0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x00,0xf8,0x08,0x28,0x10,0x00,
+/* 24136 0x5e48 "幈" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xbb,0x24,0x24,0x28,0x31,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x84,0x48,0xfc,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 24137 0x5e49 "幉" */
+0x20,0x21,0x21,0xfb,0xa9,0xa9,0xa9,0xa9,0xa9,0xa8,0xab,0xb8,0x20,0x21,0x26,0x20,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 24138 0x5e4a "幊" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x10,0x11,0x12,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 24139 0x5e4b "幋" */
+0x10,0x3e,0x22,0x2a,0xff,0x22,0x2a,0x42,0x4a,0x85,0x01,0x3f,0x21,0x21,0x21,0x01,
+0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x10,0x28,0x46,0x00,0xf8,0x08,0x28,0x10,0x00,
+/* 24140 0x5e4c "幌" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x55,0x54,0x54,0x57,0x5c,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x50,0x50,0x92,0x12,0x0e,
+/* 24141 0x5e4d "幍" */
+0x10,0x11,0x10,0x7d,0x54,0x54,0x54,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x11,0x11,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 24142 0x5e4e "幎" */
+0x20,0x23,0x22,0xf8,0xa9,0xa9,0xa9,0xa9,0xa9,0xa8,0xa8,0xbb,0x20,0x20,0x21,0x22,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 24143 0x5e4f "幏" */
+0x20,0x20,0x23,0xfa,0xa8,0xa9,0xa8,0xa8,0xab,0xa8,0xa8,0xbb,0x20,0x20,0x23,0x20,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 24144 0x5e50 "幐" */
+0x00,0x79,0x48,0x49,0x48,0x7b,0x49,0x4a,0x4c,0x79,0x49,0x49,0x49,0x49,0x48,0x98,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x08,0x24,0x22,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 24145 0x5e51 "幑" */
+0x12,0x1a,0x2a,0x4a,0x8f,0x10,0x2f,0x62,0xa2,0x2f,0x2a,0x2a,0x2a,0x2b,0x22,0x22,
+0x10,0x90,0x90,0xa0,0xbe,0x44,0xa4,0x24,0x24,0xa8,0xa8,0x90,0xa8,0xa8,0x44,0x82,
+/* 24146 0x5e52 "幒" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x5c,0x12,0x12,0x14,0x10,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 24147 0x5e53 "幓" */
+0x20,0x20,0x21,0xf9,0xaa,0xab,0xa8,0xa9,0xae,0xa8,0xab,0xb8,0x23,0x20,0x20,0x27,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 24148 0x5e54 "幔" */
+0x20,0x21,0x21,0xf9,0xa9,0xa9,0xa8,0xab,0xaa,0xab,0xa8,0xb9,0x20,0x20,0x21,0x26,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 24149 0x5e55 "幕" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x11,0x3f,0xd1,0x11,0x11,0x01,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xf8,0x16,0x50,0x20,0x00,
+/* 24150 0x5e56 "幖" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x55,0x54,0x55,0x54,0x57,0x5c,0x10,0x11,0x12,0x10,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 24151 0x5e57 "幗" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0x23,0x22,0x23,0x22,
+0x00,0xfe,0x1a,0x16,0xfe,0x12,0xea,0xaa,0xaa,0xea,0x0e,0x6a,0x9a,0x26,0xfe,0x02,
+/* 24152 0x5e58 "幘" */
+0x10,0x13,0x10,0x7d,0x54,0x57,0x54,0x55,0x55,0x55,0x55,0x5d,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 24153 0x5e59 "幙" */
+0x10,0x10,0x13,0x7c,0x54,0x55,0x55,0x55,0x55,0x55,0x54,0x5d,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 24154 0x5e5a "幚" */
+0x08,0xff,0x08,0x7e,0x08,0xff,0x10,0x22,0x5f,0x90,0x1f,0x10,0x3f,0x21,0x21,0x01,
+0x7c,0x48,0x50,0x48,0x44,0x54,0x48,0x40,0xf0,0x10,0xf0,0x10,0xf8,0x08,0x18,0x00,
+/* 24155 0x5e5b "幛" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x55,0x55,0x55,0x55,0x5c,0x13,0x10,0x10,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 24156 0x5e5c "幜" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x57,0x54,0x55,0x55,0x5d,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 24157 0x5e5d "幝" */
+0x20,0x23,0x22,0xfa,0xab,0xa8,0xa9,0xa9,0xa9,0xa9,0xa9,0xb8,0x23,0x20,0x20,0x20,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 24158 0x5e5e "幞" */
+0x20,0x22,0x21,0xf8,0xab,0xa8,0xa8,0xab,0xa8,0xa9,0xa8,0xbb,0x20,0x20,0x21,0x26,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 24159 0x5e5f "幟" */
+0x21,0x20,0x23,0xf8,0xaa,0xa9,0xaf,0xa8,0xab,0xaa,0xaa,0xbb,0x22,0x22,0x23,0x20,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 24160 0x5e60 "幠" */
+0x20,0x20,0x21,0xfb,0xad,0xa9,0xab,0xa9,0xa9,0xa9,0xaf,0xb8,0x21,0x21,0x22,0x20,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 24161 0x5e61 "幡" */
+0x20,0x27,0x22,0xf9,0xab,0xa9,0xaa,0xac,0xab,0xaa,0xaa,0xbb,0x22,0x22,0x23,0x22,
+0x78,0xc0,0x48,0x50,0xfc,0x50,0x48,0x06,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x08,
+/* 24162 0x5e62 "幢" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x55,0x55,0x55,0x55,0x5c,0x11,0x10,0x13,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 24163 0x5e63 "幣" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x49,0x40,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,
+0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0x28,0x46,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,
+/* 24164 0x5e64 "幤" */
+0x08,0x49,0x2a,0x7f,0x41,0x5d,0x55,0x5d,0x42,0x01,0x3f,0x21,0x21,0x21,0x21,0x01,
+0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0x28,0x46,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,
+/* 24165 0x5e65 "幥" */
+0x21,0x20,0x23,0xfa,0xa8,0xa8,0xa8,0xa8,0xa9,0xa8,0xa9,0xb8,0x23,0x20,0x20,0x20,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 24166 0x5e66 "幦" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3d,0x01,0x3f,0x21,0x21,0x21,0x01,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xf8,0x08,0x28,0x10,0x00,
+/* 24167 0x5e67 "幧" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x55,0x55,0x55,0x54,0x57,0x5c,0x10,0x11,0x12,0x10,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 24168 0x5e68 "幨" */
+0x21,0x21,0x22,0xff,0xaa,0xab,0xab,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x24,0x24,0x28,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 24169 0x5e69 "幩" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x55,0x55,0x55,0x55,0x5d,0x11,0x10,0x11,0x12,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 24170 0x5e6a "幪" */
+0x20,0x23,0x20,0xfb,0xaa,0xa9,0xa8,0xab,0xa8,0xa8,0xab,0xb8,0x23,0x20,0x23,0x20,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 24171 0x5e6b "幫" */
+0x08,0x3e,0x08,0x7f,0x08,0x3e,0x09,0x7f,0x28,0x0f,0x08,0x0f,0x01,0x3f,0x21,0x21,
+0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0xf0,0x20,0xe0,0x20,0xe0,0x00,0xf8,0x08,0x18,
+/* 24172 0x5e6c "幬" */
+0x20,0x23,0x20,0xf9,0xa8,0xab,0xa8,0xa9,0xa8,0xab,0xa8,0xbb,0x20,0x23,0x22,0x23,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 24173 0x5e6d "幭" */
+0x21,0x27,0x21,0xf8,0xab,0xaa,0xaa,0xab,0xa8,0xab,0xaa,0xbb,0x22,0x22,0x24,0x28,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 24174 0x5e6e "幮" */
+0x20,0x20,0x23,0xfa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x24,0x25,0x28,
+0x40,0x20,0xfe,0x44,0xf4,0x44,0xee,0x04,0xf4,0xac,0xe4,0x14,0xa4,0x74,0x94,0x08,
+/* 24175 0x5e6f "幯" */
+0x21,0x21,0x21,0xfa,0xa8,0xa8,0xab,0xaa,0xab,0xaa,0xab,0xba,0x22,0x23,0x22,0x20,
+0x08,0x08,0xee,0x94,0x42,0x00,0xde,0x52,0xd2,0x52,0xd2,0x1a,0x94,0x50,0x10,0x10,
+/* 24176 0x5e70 "幰" */
+0x10,0x13,0x12,0x7d,0x54,0x54,0x54,0x55,0x54,0x55,0x55,0x5d,0x10,0x12,0x12,0x14,
+0x20,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfc,0x20,0xfc,0x54,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 24177 0x5e71 "幱" */
+0x23,0x22,0x23,0xfa,0xab,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xba,0x22,0x22,0x22,0x22,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 24178 0x5e72 "干" */
+0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 24179 0x5e73 "平" */
+0x00,0x7f,0x01,0x01,0x11,0x09,0x09,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0xfc,0x00,0x00,0x10,0x10,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 24180 0x5e74 "年" */
+0x10,0x10,0x1f,0x20,0x20,0x40,0x1f,0x10,0x10,0x10,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,0x80,
+/* 24181 0x5e75 "幵" */
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 24182 0x5e76 "并" */
+0x10,0x08,0x08,0x00,0x7f,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x40,
+0x10,0x10,0x20,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24183 0x5e77 "幷" */
+0x08,0x08,0x10,0x7c,0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x08,0x08,0x10,0x7c,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 24184 0x5e78 "幸" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x08,0x04,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x20,0x40,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 24185 0x5e79 "幹" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x46,0x7c,0x44,0x7c,0x11,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 24186 0x5e7a "幺" */
+0x02,0x02,0x04,0x08,0x10,0x20,0x7f,0x20,0x01,0x02,0x04,0x08,0x10,0x3f,0x10,0x00,
+0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x80,0x00,0x00,0x00,0x20,0x10,0xf8,0x08,0x00,
+/* 24187 0x5e7b "幻" */
+0x08,0x08,0x11,0x10,0x22,0x42,0xfc,0x04,0x08,0x10,0x24,0x42,0xfe,0x42,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 24188 0x5e7c "幼" */
+0x10,0x10,0x20,0x20,0x45,0x44,0xf8,0x08,0x10,0x10,0x28,0x44,0xfd,0x45,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 24189 0x5e7d "幽" */
+0x01,0x01,0x09,0x09,0x51,0x55,0x7d,0x49,0x49,0x55,0x7d,0x45,0x41,0x41,0x7f,0x00,
+0x00,0x00,0x20,0x20,0x44,0x54,0xf4,0x24,0x24,0x54,0xf4,0x14,0x04,0x04,0xfc,0x04,
+/* 24190 0x5e7e "幾" */
+0x11,0x21,0x45,0x79,0x11,0x25,0x7d,0x15,0x11,0xff,0x10,0x10,0x28,0x24,0x40,0x81,
+0x10,0x20,0x44,0x78,0x10,0x24,0x7c,0x24,0x10,0xfe,0x80,0x88,0x52,0x22,0x5a,0x86,
+/* 24191 0x5e7f "广" */
+0x01,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0x80,0x80,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 24192 0x5e80 "庀" */
+0x01,0x00,0x3f,0x20,0x20,0x22,0x22,0x22,0x22,0x23,0x22,0x22,0x22,0x42,0x41,0x80,
+0x00,0x80,0xfe,0x00,0x00,0x00,0x04,0x18,0x60,0x80,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 24193 0x5e81 "庁" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x81,0x00,
+0x00,0x80,0xfe,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 24194 0x5e82 "庂" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x21,0x21,0x22,0x42,0x44,0x88,0x10,
+0x00,0x80,0xfe,0x00,0x80,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 24195 0x5e83 "広" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x20,0x21,0x21,0x21,0x22,0x22,0x44,0x4f,0x84,0x00,
+0x00,0x80,0xfe,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x10,0x08,0x08,0xfc,0x04,0x04,
+/* 24196 0x5e84 "庄" */
+0x01,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x40,0x5f,0x80,
+0x00,0x80,0x80,0xfc,0x00,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,0x80,0xfe,0x00,
+/* 24197 0x5e85 "庅" */
+0x01,0x00,0x3f,0x20,0x21,0x21,0x22,0x22,0x24,0x28,0x21,0x22,0x44,0x4f,0x84,0x00,
+0x00,0x80,0xfe,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x08,0x04,0xfe,0x02,0x00,
+/* 24198 0x5e86 "庆" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x20,0x2f,0x20,0x21,0x21,0x22,0x42,0x44,0x88,0x10,
+0x00,0x80,0xfe,0x00,0x80,0x80,0x80,0xfc,0x80,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 24199 0x5e87 "庇" */
+0x01,0x00,0x3f,0x20,0x24,0x24,0x24,0x24,0x27,0x24,0x24,0x24,0x45,0x46,0x84,0x00,
+0x00,0x80,0xfe,0x00,0x20,0x20,0x24,0x28,0x30,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 24200 0x5e88 "庈" */
+0x01,0x00,0x3f,0x20,0x21,0x22,0x24,0x29,0x30,0x20,0x2f,0x20,0x40,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x80,0x40,0x20,0x10,0x08,0x86,0x80,0xf0,0x10,0x20,0x20,0x40,0x80,
+/* 24201 0x5e89 "庉" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x24,0x24,0x24,0x27,0x20,0x20,0x40,0x40,0x80,
+0x00,0x80,0xfe,0x40,0x40,0xfe,0x40,0x44,0x44,0x44,0xfc,0x42,0x42,0x42,0x3e,0x00,
+/* 24202 0x5e8a "床" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x2f,0x20,0x21,0x22,0x22,0x24,0x48,0x50,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x80,0x80,0xfc,0x80,0xc0,0xa0,0xa0,0x90,0x88,0x86,0x80,0x80,
+/* 24203 0x5e8b "庋" */
+0x01,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x24,0x22,0x21,0x40,0x41,0x86,0x38,
+0x00,0x80,0xfe,0x80,0x80,0xfc,0x80,0x80,0xf0,0x10,0x20,0x40,0x80,0x60,0x18,0x06,
+/* 24204 0x5e8c "庌" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x24,0x28,0x2f,0x20,0x21,0x46,0x58,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x20,0x20,0x20,0xfe,0xa0,0x20,0x20,0x20,0xa0,0x40,
+/* 24205 0x5e8d "庍" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x24,0x48,0x48,0x90,0x20,
+0x00,0x80,0xfe,0x00,0x1c,0xe0,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24206 0x5e8e "庎" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x21,0x22,0x2d,0x21,0x21,0x21,0x41,0x42,0x82,0x04,
+0x00,0x80,0xfe,0x40,0x40,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 24207 0x5e8f "序" */
+0x01,0x00,0x3f,0x20,0x23,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x40,0x40,0x81,0x00,
+0x00,0x80,0xfe,0x00,0xf8,0x10,0xa0,0x40,0xfe,0x42,0x44,0x40,0x40,0x40,0x40,0x80,
+/* 24208 0x5e90 "庐" */
+0x01,0x00,0x3f,0x21,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x24,0x44,0x48,0x88,0x10,
+0x00,0x80,0xfe,0x00,0x80,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 24209 0x5e91 "庑" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x21,0x21,0x22,0x42,0x44,0x88,0x10,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x80,0x80,0xfe,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 24210 0x5e92 "庒" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x20,0x2f,0x20,0x20,0x20,0x20,0x40,0x40,0x9f,0x00,
+0x00,0x80,0xfe,0x80,0x80,0x80,0x80,0xfc,0x80,0x80,0x90,0x88,0x88,0x80,0xfe,0x00,
+/* 24211 0x5e93 "库" */
+0x01,0x00,0x3f,0x21,0x21,0x3f,0x22,0x24,0x28,0x2f,0x20,0x20,0x5f,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x00,0x80,0x80,0xf8,0x80,0x80,0xfe,0x80,0x80,0x80,
+/* 24212 0x5e94 "应" */
+0x01,0x00,0x3f,0x20,0x20,0x21,0x28,0x24,0x24,0x22,0x22,0x22,0x40,0x40,0x9f,0x00,
+0x00,0x80,0xfe,0x00,0x00,0x04,0x84,0x84,0x48,0x48,0x10,0x10,0x20,0x40,0xfe,0x00,
+/* 24213 0x5e95 "底" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x24,0x24,0x24,0x45,0x46,0x84,
+0x00,0x80,0xfe,0x00,0x3c,0xc0,0x40,0x40,0x40,0xfe,0x20,0x20,0x12,0x0a,0x46,0x22,
+/* 24214 0x5e96 "庖" */
+0x01,0x00,0x3f,0x22,0x22,0x27,0x28,0x37,0x24,0x24,0x27,0x24,0x24,0x44,0x43,0x80,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x08,0xc8,0x48,0x48,0xc8,0x28,0x12,0x02,0xfe,0x00,
+/* 24215 0x5e97 "店" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x27,0x24,0x24,0x44,0x44,0x87,0x04,
+0x00,0x80,0xfe,0x80,0x80,0x80,0xfc,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 24216 0x5e98 "庘" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x24,0x40,0x40,0x80,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,
+/* 24217 0x5e99 "庙" */
+0x01,0x00,0x3f,0x20,0x20,0x20,0x2f,0x28,0x28,0x28,0x2f,0x28,0x48,0x48,0x8f,0x08,
+0x00,0x80,0xfe,0x00,0x80,0x80,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x08,
+/* 24218 0x5e9a "庚" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x41,0x42,0x8c,0x30,
+0x00,0x80,0xfe,0x00,0x80,0xf8,0x88,0x88,0xfe,0x88,0x88,0xf8,0x40,0x20,0x18,0x06,
+/* 24219 0x5e9b "庛" */
+0x01,0x00,0x3f,0x20,0x21,0x21,0x25,0x25,0x25,0x25,0x25,0x25,0x25,0x45,0x5e,0x88,
+0x00,0x80,0xfe,0x00,0x10,0x10,0x12,0x14,0xd8,0x10,0x10,0x10,0x12,0xd2,0x12,0x0e,
+/* 24220 0x5e9c "府" */
+0x01,0x00,0x3f,0x20,0x22,0x22,0x24,0x24,0x2c,0x34,0x24,0x24,0x44,0x44,0x84,0x04,
+0x00,0x80,0xfe,0x00,0x08,0x08,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 24221 0x5e9d "庝" */
+0x01,0x00,0x3f,0x21,0x21,0x23,0x26,0x29,0x20,0x23,0x3c,0x20,0x40,0x43,0x80,0x00,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x10,0x20,0xc0,0x30,0x0e,0xc0,0x20,0x00,0xc0,0x20,
+/* 24222 0x5e9e "庞" */
+0x01,0x00,0x3f,0x22,0x22,0x22,0x2f,0x22,0x22,0x22,0x24,0x24,0x48,0x48,0x93,0x20,
+0x00,0x80,0xfe,0x20,0x10,0x00,0xfc,0x40,0x40,0x48,0x50,0x60,0x42,0xc2,0x3e,0x00,
+/* 24223 0x5e9f "废" */
+0x01,0x00,0x3f,0x20,0x24,0x28,0x2f,0x21,0x21,0x22,0x22,0x24,0x24,0x48,0x51,0x86,
+0x00,0x80,0xfe,0x80,0x90,0x88,0xfe,0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 24224 0x5ea0 "庠" */
+0x01,0x00,0x3f,0x24,0x22,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x20,0x40,0x40,0x80,
+0x00,0x80,0xfe,0x10,0x20,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,
+/* 24225 0x5ea1 "庡" */
+0x01,0x00,0x3f,0x20,0x20,0x3f,0x20,0x21,0x22,0x26,0x2a,0x32,0x42,0x42,0x83,0x02,
+0x00,0x80,0xfe,0x80,0x40,0xfe,0x80,0x00,0x84,0x88,0x50,0x20,0x10,0x88,0x06,0x00,
+/* 24226 0x5ea2 "庢" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x21,0x22,0x27,0x20,0x20,0x2f,0x40,0x40,0xbf,0x00,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x00,0x10,0xf8,0x88,0x80,0xfc,0x80,0x80,0xfe,0x00,
+/* 24227 0x5ea3 "庣" */
+0x01,0x00,0x3f,0x21,0x21,0x29,0x25,0x21,0x21,0x23,0x25,0x29,0x22,0x42,0x44,0x88,
+0x00,0x80,0xfe,0x20,0x20,0x24,0x28,0x30,0x20,0x30,0x28,0x24,0x20,0x22,0x22,0x1e,
+/* 24228 0x5ea4 "庤" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x20,0x20,0x3f,0x20,0x20,0x2f,0x42,0x41,0x81,0x00,
+0x00,0x80,0xfe,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,0x10,0xfc,0x10,0x10,0x50,0x20,
+/* 24229 0x5ea5 "庥" */
+0x01,0x00,0x3f,0x20,0x22,0x22,0x24,0x2d,0x34,0x24,0x24,0x25,0x26,0x44,0x44,0x84,
+0x00,0x80,0xfe,0x00,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,
+/* 24230 0x5ea6 "度" */
+0x01,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x23,0x20,0x2f,0x24,0x42,0x41,0x86,0x38,
+0x00,0x80,0xfe,0x20,0x20,0xfc,0x20,0x20,0xe0,0x00,0xf0,0x10,0x20,0xc0,0x30,0x0e,
+/* 24231 0x5ea7 "座" */
+0x01,0x00,0x3f,0x20,0x24,0x24,0x24,0x2a,0x31,0x20,0x2f,0x20,0x40,0x40,0xbf,0x00,
+0x00,0x80,0xfe,0x80,0x90,0x90,0x90,0xa8,0xc4,0x80,0xf8,0x80,0x80,0x80,0xfe,0x00,
+/* 24232 0x5ea8 "庨" */
+0x01,0x00,0x3f,0x20,0x20,0x27,0x20,0x3f,0x20,0x2f,0x26,0x38,0x47,0x40,0x81,0x00,
+0x00,0x80,0xfe,0x80,0x88,0xf0,0xa0,0xfe,0x80,0xf0,0x20,0x40,0xfc,0x40,0x40,0x80,
+/* 24233 0x5ea9 "庩" */
+0x01,0x00,0x3f,0x20,0x21,0x22,0x24,0x3b,0x20,0x20,0x2f,0x20,0x44,0x48,0x92,0x01,
+0x00,0x80,0xfe,0x80,0x40,0x20,0x10,0xec,0x80,0x80,0xf8,0x80,0x90,0x88,0x84,0x00,
+/* 24234 0x5eaa "庪" */
+0x01,0x00,0x3f,0x24,0x24,0x24,0x3f,0x24,0x25,0x26,0x3c,0x24,0x44,0x44,0x94,0x08,
+0x00,0x80,0xfe,0x10,0x10,0x7e,0x10,0x10,0x7c,0x44,0x44,0x28,0x10,0x28,0x44,0x82,
+/* 24235 0x5eab "庫" */
+0x01,0x00,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x5f,0x40,0x80,0x00,
+0x00,0x80,0xfe,0x80,0xfc,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfe,0x80,0x80,0x80,
+/* 24236 0x5eac "庬" */
+0x01,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x22,0x22,0x22,0x22,0x44,0x44,0x88,0x13,
+0x00,0x80,0xfe,0x10,0x08,0xfe,0x48,0x50,0x64,0x48,0x52,0x64,0x4a,0x72,0xc2,0x3e,
+/* 24237 0x5ead "庭" */
+0x01,0x00,0x3f,0x20,0x2e,0x22,0x24,0x24,0x2e,0x22,0x22,0x2a,0x44,0x46,0x89,0x10,
+0x00,0x80,0xfe,0x00,0x0e,0xf0,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 24238 0x5eae "庮" */
+0x01,0x00,0x3f,0x20,0x2f,0x21,0x2f,0x29,0x29,0x2a,0x2c,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0x80,0xfe,0x00,0xfc,0x20,0xfc,0x24,0x24,0x1c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 24239 0x5eaf "庯" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x44,0x44,0x84,
+0x00,0x80,0xfe,0x48,0x44,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 24240 0x5eb0 "庰" */
+0x01,0x00,0x3f,0x22,0x21,0x21,0x27,0x21,0x21,0x21,0x2f,0x21,0x41,0x42,0x84,0x08,
+0x00,0x80,0xfe,0x08,0x08,0x10,0xfc,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 24241 0x5eb1 "庱" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x3f,0x24,0x29,0x33,0x26,0x49,0x40,0x87,0x38,
+0x00,0x80,0xfe,0x80,0x80,0xfc,0x80,0xfe,0x08,0x04,0xf2,0x10,0x20,0xc0,0x30,0x0e,
+/* 24242 0x5eb2 "庲" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x20,0x22,0x22,0x25,0x28,0x21,0x42,0x4c,0x80,0x00,
+0x00,0x80,0xfe,0x40,0x40,0xfe,0x40,0x48,0x48,0x54,0xe2,0x50,0x48,0x46,0x40,0x40,
+/* 24243 0x5eb3 "庳" */
+0x01,0x00,0x3f,0x20,0x21,0x27,0x24,0x27,0x24,0x27,0x21,0x22,0x3f,0x40,0x40,0x80,
+0x00,0x80,0xfe,0x80,0x00,0xfc,0x44,0xfc,0x84,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 24244 0x5eb4 "庴" */
+0x00,0x3f,0x22,0x22,0x2f,0x22,0x22,0x3f,0x20,0x27,0x24,0x24,0x47,0x44,0x84,0x07,
+0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 24245 0x5eb5 "庵" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x21,0x22,0x24,0x2f,0x34,0x27,0x24,0x47,0x40,0x80,
+0x00,0x80,0xfe,0x00,0x80,0xfc,0x20,0x10,0x88,0xf6,0x90,0xf0,0x90,0xf2,0x82,0x7e,
+/* 24246 0x5eb6 "庶" */
+0x01,0x00,0x3f,0x20,0x22,0x22,0x3f,0x22,0x22,0x22,0x23,0x20,0x4a,0x49,0x91,0x00,
+0x00,0x80,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xe0,0x00,0x48,0x24,0x24,0x00,
+/* 24247 0x5eb7 "康" */
+0x01,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x28,0x24,0x22,0x44,0x48,0x92,0x01,
+0x00,0x80,0xfe,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x80,0xc4,0xa8,0x90,0x88,0x86,0x00,
+/* 24248 0x5eb8 "庸" */
+0x00,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x2f,0x48,0x4f,0x88,0x08,
+0x80,0xfe,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x98,
+/* 24249 0x5eb9 "庹" */
+0x01,0x00,0x3f,0x22,0x22,0x3f,0x22,0x23,0x20,0x27,0x24,0x27,0x44,0x44,0x88,0x10,
+0x00,0x80,0xfe,0x10,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x20,0x10,0x08,0x06,
+/* 24250 0x5eba "庺" */
+0x01,0x00,0x3f,0x22,0x24,0x29,0x22,0x27,0x20,0x20,0x2f,0x21,0x42,0x44,0x98,0x00,
+0x00,0x80,0xfe,0x10,0x88,0x24,0x10,0xf8,0x88,0x80,0xfc,0xc0,0xa0,0x98,0x86,0x80,
+/* 24251 0x5ebb "庻" */
+0x01,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x23,0x20,0x24,0x24,0x44,0x4a,0x91,0x20,
+0x00,0x80,0xfe,0x20,0x20,0xfc,0x20,0x20,0xe0,0x00,0x10,0x10,0x10,0x28,0x44,0x82,
+/* 24252 0x5ebc "庼" */
+0x01,0x00,0x3f,0x28,0x29,0x28,0x2e,0x29,0x29,0x29,0x29,0x2b,0x2d,0x48,0x40,0x83,
+0x00,0x80,0xfe,0x00,0xfc,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 24253 0x5ebd "庽" */
+0x01,0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x20,0x2f,0x28,0x48,0x4b,0x89,0x08,
+0x00,0x80,0xfe,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfc,0x84,0xa4,0xf4,0x14,0x08,
+/* 24254 0x5ebe "庾" */
+0x01,0x00,0x3f,0x20,0x22,0x2c,0x28,0x28,0x2e,0x28,0x28,0x2f,0x41,0x42,0x8c,0x30,
+0x00,0x80,0xfe,0x00,0x80,0xb8,0x88,0x88,0xb8,0x88,0x88,0xf8,0x40,0x20,0x18,0x06,
+/* 24255 0x5ebf "庿" */
+0x01,0x00,0x3f,0x21,0x21,0x2f,0x21,0x20,0x27,0x24,0x24,0x27,0x24,0x44,0x47,0x84,
+0x00,0x80,0xfe,0x10,0x10,0xfe,0x10,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 24256 0x5ec0 "廀" */
+0x01,0x00,0x3f,0x20,0x2f,0x28,0x22,0x24,0x23,0x2c,0x27,0x22,0x21,0x40,0x43,0x9c,
+0x00,0x80,0xfe,0x40,0xfe,0x42,0x48,0xb0,0x08,0x04,0xf8,0x08,0x10,0xe0,0x18,0x06,
+/* 24257 0x5ec1 "廁" */
+0x01,0x00,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x28,0x2f,0x28,0x2f,0x40,0x49,0x88,0x10,
+0x00,0x80,0xfe,0x00,0x84,0x84,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x04,0x94,0x88,
+/* 24258 0x5ec2 "廂" */
+0x01,0x00,0x3f,0x20,0x22,0x22,0x3f,0x22,0x26,0x27,0x2a,0x2a,0x52,0x62,0x82,0x02,
+0x00,0x80,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0xc4,0xfc,0x44,0x44,0x7c,0x44,
+/* 24259 0x5ec3 "廃" */
+0x01,0x00,0x3f,0x20,0x2f,0x21,0x2a,0x24,0x3b,0x21,0x21,0x2f,0x21,0x42,0x44,0x88,
+0x00,0x80,0xfe,0x40,0x50,0x24,0x18,0x08,0xf6,0x20,0x20,0xfc,0x20,0x24,0x24,0x1c,
+/* 24260 0x5ec4 "廄" */
+0x01,0x00,0x3f,0x20,0x2f,0x29,0x29,0x2f,0x29,0x29,0x2f,0x28,0x2a,0x49,0x4b,0x8d,
+0x00,0x80,0xfe,0x00,0x78,0x48,0x48,0x86,0x00,0x7c,0x44,0x44,0x28,0x10,0x28,0x46,
+/* 24261 0x5ec5 "廅" */
+0x01,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x22,0x24,0x2f,0x20,0x2f,0x49,0x49,0xbf,0x00,
+0x00,0x80,0xfe,0x80,0xfc,0x80,0xfe,0x00,0x08,0xfc,0x00,0xfc,0x24,0x24,0xfe,0x00,
+/* 24262 0x5ec6 "廆" */
+0x01,0x00,0x3f,0x20,0x21,0x2f,0x28,0x2f,0x28,0x2f,0x21,0x21,0x42,0x44,0x88,0x30,
+0x00,0x80,0xfe,0x80,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x54,0x5c,0x46,0x42,0x3e,
+/* 24263 0x5ec7 "廇" */
+0x00,0x3f,0x20,0x27,0x24,0x25,0x24,0x25,0x26,0x20,0x27,0x24,0x47,0x44,0x87,0x04,
+0x80,0xfe,0x80,0x7c,0x24,0x24,0xa4,0x54,0x48,0x80,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 24264 0x5ec8 "廈" */
+0x01,0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x27,0x24,0x27,0x22,0x27,0x4a,0x41,0x9e,
+0x00,0x80,0xfe,0x00,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf0,0x0e,
+/* 24265 0x5ec9 "廉" */
+0x01,0x00,0x3f,0x22,0x21,0x2f,0x21,0x27,0x21,0x3f,0x21,0x27,0x23,0x45,0x59,0x81,
+0x00,0x80,0xfe,0x08,0x10,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x30,0x28,0x26,0x20,
+/* 24266 0x5eca "廊" */
+0x01,0x00,0x3f,0x22,0x21,0x2f,0x28,0x2f,0x28,0x2f,0x2a,0x29,0x2a,0x4c,0x48,0x80,
+0x00,0x80,0xfe,0x00,0x00,0xbe,0xa2,0xa4,0xa8,0xa4,0x22,0x22,0xaa,0xa4,0x20,0x20,
+/* 24267 0x5ecb "廋" */
+0x01,0x00,0x3f,0x21,0x26,0x24,0x27,0x24,0x27,0x20,0x2f,0x22,0x21,0x40,0x43,0x8c,
+0x00,0x80,0xfe,0x40,0x5c,0x44,0x5c,0x44,0xfc,0x40,0xfc,0x08,0x10,0xe0,0x18,0x06,
+/* 24268 0x5ecc "廌" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x20,0x22,0x49,0x50,0x80,
+0x00,0x80,0xfe,0x20,0xfe,0x22,0xfe,0x00,0xfc,0x00,0xfe,0x02,0x4a,0x26,0x0a,0x04,
+/* 24269 0x5ecd "廍" */
+0x01,0x00,0x3f,0x24,0x22,0x2f,0x20,0x28,0x25,0x3f,0x20,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0x80,0xfe,0x00,0x1e,0x92,0x14,0x98,0x14,0xd2,0x12,0x9a,0x94,0x90,0x90,0x90,
+/* 24270 0x5ece "廎" */
+0x01,0x00,0x3f,0x20,0x29,0x28,0x28,0x2e,0x28,0x28,0x28,0x2a,0x4c,0x48,0x80,0x00,
+0x00,0x80,0xfe,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 24271 0x5ecf "廏" */
+0x01,0x00,0x3f,0x24,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x29,0x2a,0x2c,0x48,0x47,0x80,
+0x00,0x80,0xfe,0x00,0xbc,0xa4,0xa4,0xc2,0x80,0x7e,0x22,0x22,0x94,0x88,0x94,0x62,
+/* 24272 0x5ed0 "廐" */
+0x00,0x3f,0x20,0x2f,0x29,0x29,0x2f,0x29,0x29,0x2f,0x28,0x2a,0x49,0x4b,0x8d,0x08,
+0x80,0xfe,0x00,0x7e,0x10,0x10,0x50,0x50,0x7e,0x10,0x28,0x28,0x28,0x4a,0x4a,0x86,
+/* 24273 0x5ed1 "廑" */
+0x00,0x3f,0x24,0x3f,0x24,0x27,0x20,0x2f,0x28,0x2f,0x20,0x3f,0x40,0x4f,0x80,0x3f,
+0x80,0xfe,0x10,0xfe,0x10,0xf0,0x80,0xf8,0x88,0xf8,0x80,0xfc,0x80,0xf8,0x80,0xfe,
+/* 24274 0x5ed2 "廒" */
+0x01,0x00,0x3f,0x22,0x2f,0x22,0x2f,0x22,0x3f,0x24,0x27,0x24,0x44,0x48,0x8a,0x11,
+0x00,0x80,0xfe,0x10,0x90,0x1e,0xa4,0x24,0xd4,0x14,0x94,0x88,0x88,0x94,0xa4,0x42,
+/* 24275 0x5ed3 "廓" */
+0x00,0x3f,0x22,0x3f,0x20,0x2f,0x28,0x2f,0x20,0x2f,0x21,0x23,0x5e,0x42,0x8a,0x04,
+0x80,0xfe,0x00,0xbc,0x24,0xa4,0xa8,0xa8,0x24,0xa4,0x24,0xf4,0x28,0x20,0x20,0x20,
+/* 24276 0x5ed4 "廔" */
+0x01,0x00,0x3f,0x20,0x2f,0x28,0x3f,0x28,0x2f,0x24,0x27,0x21,0x3f,0x44,0x43,0x9c,
+0x00,0x80,0xfe,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x90,0xf0,0x00,0xfe,0x10,0xe0,0x1c,
+/* 24277 0x5ed5 "廕" */
+0x01,0x00,0x3f,0x20,0x2f,0x29,0x2a,0x2c,0x2a,0x29,0x29,0x2d,0x2a,0x48,0x48,0x88,
+0x00,0x80,0xfe,0x10,0x28,0x44,0x92,0x7c,0x08,0x10,0x7e,0x00,0xfe,0x20,0x44,0xfe,
+/* 24278 0x5ed6 "廖" */
+0x00,0x3f,0x20,0x2f,0x29,0x25,0x29,0x21,0x26,0x38,0x23,0x2c,0x41,0x4e,0x81,0x0e,
+0x80,0xfe,0x00,0x7c,0x24,0x14,0xa4,0x60,0x18,0x86,0x20,0x40,0x88,0x30,0xc0,0x00,
+/* 24279 0x5ed7 "廗" */
+0x01,0x00,0x3f,0x22,0x22,0x2f,0x22,0x24,0x28,0x2f,0x28,0x23,0x42,0x42,0x82,0x00,
+0x00,0x80,0xfe,0xa8,0xa8,0xfc,0xaa,0xe6,0x00,0xfe,0x42,0xf8,0x48,0x48,0x58,0x40,
+/* 24280 0x5ed8 "廘" */
+0x01,0x00,0x3f,0x20,0x20,0x2f,0x29,0x2f,0x29,0x2f,0x2a,0x2a,0x4b,0x52,0x92,0x23,
+0x00,0x80,0xfe,0x80,0x40,0xfc,0x20,0xfc,0x24,0xfc,0x20,0x24,0xb8,0x24,0xa4,0x1c,
+/* 24281 0x5ed9 "廙" */
+0x01,0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x21,0x27,0x21,0x2f,0x40,0x42,0x84,
+0x00,0x80,0xfe,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x10,0xfc,0x10,0xfe,0x00,0x08,0x04,
+/* 24282 0x5eda "廚" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x45,0x43,0x9c,0x08,
+0x00,0x80,0xfe,0x04,0xc4,0x04,0xbe,0x04,0xa4,0x94,0x94,0x84,0x04,0x84,0x14,0x08,
+/* 24283 0x5edb "廛" */
+0x00,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x2f,0x20,0x3f,0x48,0x53,0x80,0x3f,
+0x80,0xfe,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xf8,0x80,0xfe,0x88,0xe4,0x80,0xfe,
+/* 24284 0x5edc "廜" */
+0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x25,0x24,0x27,0x24,0x24,0x49,0x4a,0x94,0x00,
+0x80,0xfe,0x00,0xfc,0x04,0xfc,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x88,0xf8,0x88,0xf8,
+/* 24285 0x5edd "廝" */
+0x00,0x3f,0x29,0x29,0x3f,0x29,0x29,0x2f,0x29,0x2f,0x29,0x29,0x5f,0x40,0x8a,0x11,
+0x80,0xfe,0x00,0x0c,0xb0,0x20,0x20,0x3e,0x28,0x28,0x28,0x28,0xa8,0x48,0x88,0x08,
+/* 24286 0x5ede "廞" */
+0x01,0x00,0x3f,0x22,0x22,0x25,0x28,0x37,0x22,0x2f,0x22,0x32,0x4a,0x43,0x9c,0x08,
+0x00,0x80,0xfe,0x00,0x20,0x20,0xbe,0x42,0x94,0x90,0x10,0x90,0x28,0xa8,0x44,0x82,
+/* 24287 0x5edf "廟" */
+0x01,0x00,0x3f,0x22,0x2f,0x22,0x2f,0x28,0x2f,0x28,0x2f,0x22,0x5f,0x42,0x82,0x02,
+0x00,0x80,0xfe,0x00,0xbc,0x24,0xa4,0xbc,0xa4,0xa4,0xbc,0x24,0xa4,0x44,0x54,0x88,
+/* 24288 0x5ee0 "廠" */
+0x00,0x7f,0x42,0x52,0x4a,0x4a,0x5f,0x50,0x57,0x55,0x55,0x57,0x50,0x51,0x50,0x80,
+0x80,0xfe,0x08,0x48,0x50,0x9e,0xe4,0x54,0x54,0x54,0x48,0x48,0x48,0x54,0x94,0x22,
+/* 24289 0x5ee1 "廡" */
+0x01,0x00,0x3f,0x22,0x24,0x2f,0x35,0x25,0x2f,0x25,0x25,0x3f,0x40,0x4a,0x89,0x11,
+0x00,0x80,0xfe,0x00,0x00,0xfc,0x50,0x50,0xfc,0x50,0x50,0xfe,0x00,0x48,0x24,0x24,
+/* 24290 0x5ee2 "廢" */
+0x01,0x00,0x3f,0x20,0x2f,0x21,0x2a,0x24,0x3b,0x21,0x2f,0x28,0x2f,0x41,0x45,0x82,
+0x00,0x80,0xfe,0x40,0x50,0x24,0x18,0x08,0x76,0x50,0x8c,0x78,0x48,0x30,0x48,0x84,
+/* 24291 0x5ee3 "廣" */
+0x01,0x00,0x3f,0x22,0x2f,0x22,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x4f,0x42,0x84,0x08,
+0x00,0x80,0xfe,0x20,0xf8,0x20,0xfc,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x20,0x10,0x08,
+/* 24292 0x5ee4 "廤" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x3f,0x40,0x5f,0x91,0x1f,
+0x80,0xfe,0x80,0xfc,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfc,0xa4,0x3a,0x22,0x1e,
+/* 24293 0x5ee5 "廥" */
+0x00,0x3f,0x21,0x26,0x3b,0x20,0x2f,0x2a,0x29,0x2f,0x20,0x27,0x44,0x47,0x84,0x07,
+0x80,0xfe,0x40,0x30,0xec,0x00,0xf8,0xa8,0xc8,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 24294 0x5ee6 "廦" */
+0x01,0x00,0x3f,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x2f,0x2c,0x54,0x47,0x84,0x00,
+0x00,0x80,0xfe,0x10,0x88,0xbe,0x80,0xa2,0x94,0x3e,0x88,0x88,0xbe,0x88,0x88,0x08,
+/* 24295 0x5ee7 "廧" */
+0x00,0x3f,0x20,0x27,0x22,0x22,0x25,0x3f,0x20,0x27,0x24,0x25,0x45,0x45,0x84,0x07,
+0x80,0xfe,0x40,0xfc,0x48,0x48,0x54,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,
+/* 24296 0x5ee8 "廨" */
+0x00,0x3f,0x24,0x2f,0x31,0x22,0x2f,0x2a,0x2f,0x2a,0x2f,0x2a,0x4a,0x4a,0x88,0x11,
+0x80,0xfe,0x00,0x3c,0x14,0x24,0xcc,0x80,0xa8,0xbe,0xc8,0x88,0xbe,0x88,0x88,0x88,
+/* 24297 0x5ee9 "廩" */
+0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x25,0x25,0x27,0x20,0x23,0x40,0x4f,0x81,0x0e,
+0x80,0xfe,0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 24298 0x5eea "廪" */
+0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x25,0x25,0x27,0x20,0x27,0x40,0x4f,0x82,0x04,
+0x80,0xfe,0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xfc,0x00,0xfe,0x48,0xc4,
+/* 24299 0x5eeb "廫" */
+0x00,0x3f,0x20,0x2e,0x2a,0x2a,0x2a,0x2e,0x2a,0x2a,0x2e,0x2a,0x4a,0x52,0x92,0x26,
+0x80,0xfe,0x00,0xee,0x22,0xaa,0x66,0xaa,0x10,0x28,0x54,0xaa,0x50,0x24,0x48,0x10,
+/* 24300 0x5eec "廬" */
+0x00,0x3f,0x20,0x20,0x20,0x27,0x24,0x25,0x24,0x24,0x24,0x24,0x44,0x49,0x89,0x13,
+0x80,0xfe,0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0xa8,0xf8,0xa8,0xfc,0x54,0xfe,
+/* 24301 0x5eed "廭" */
+0x00,0x3f,0x20,0x23,0x2e,0x22,0x2f,0x22,0x26,0x27,0x2a,0x2a,0x52,0x42,0x82,0x02,
+0x80,0xfe,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x44,0x7c,0xc4,0x7c,0x44,0x7c,0x28,0x44,
+/* 24302 0x5eee "廮" */
+0x00,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x2f,0x25,0x28,0x4f,0x43,0x80,0x0f,
+0x80,0xfe,0x00,0xbe,0xa2,0xbe,0xa2,0xbe,0xa2,0xbe,0x14,0xa2,0xfe,0x10,0xe0,0x1c,
+/* 24303 0x5eef "廯" */
+0x01,0x00,0x3f,0x24,0x27,0x29,0x32,0x2f,0x2a,0x2f,0x2a,0x2f,0x40,0x55,0x95,0x00,
+0x00,0x80,0xfe,0x00,0x22,0x14,0x3e,0x88,0x88,0x9c,0x88,0x88,0x3e,0x48,0x48,0x08,
+/* 24304 0x5ef0 "廰" */
+0x00,0x7f,0x40,0x7e,0x55,0x54,0x5d,0x55,0x55,0x5d,0x54,0x56,0x5c,0x75,0x45,0x86,
+0x80,0xfe,0x20,0x20,0xfe,0x20,0xfc,0x54,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 24305 0x5ef1 "廱" */
+0x00,0x3f,0x20,0x2a,0x35,0x2a,0x2f,0x29,0x2f,0x20,0x2f,0x2a,0x4f,0x48,0x88,0x07,
+0x80,0xfe,0x00,0xa8,0x24,0xbe,0x68,0x68,0xbe,0x28,0xa8,0xbe,0xa8,0x28,0xbe,0xa0,
+/* 24306 0x5ef2 "廲" */
+0x00,0x3f,0x20,0x2f,0x25,0x27,0x25,0x2f,0x29,0x2f,0x29,0x2f,0x4a,0x4b,0x92,0x23,
+0x80,0xfe,0x00,0xbe,0x14,0x1c,0x54,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xb8,0x22,0x9e,
+/* 24307 0x5ef3 "廳" */
+0x00,0x7f,0x40,0x7f,0x52,0x5e,0x52,0x5e,0x52,0x7e,0x42,0x7e,0x4a,0x5e,0x4a,0xbe,
+0x80,0xfe,0x10,0x10,0xfe,0x10,0xfe,0xaa,0xaa,0xfe,0x00,0xfe,0x24,0x12,0xa4,0x9c,
+/* 24308 0x5ef4 "廴" */
+0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0x78,0x08,0x08,0x48,0x30,0x10,0x2c,0x43,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 24309 0x5ef5 "廵" */
+0x00,0x01,0xf9,0x09,0x12,0x12,0x24,0x7a,0x0a,0x09,0x49,0x31,0x10,0x2c,0x43,0x80,
+0x00,0x24,0x24,0x24,0x48,0x48,0x90,0x48,0x48,0x24,0x24,0x24,0x00,0x00,0xfe,0x00,
+/* 24310 0x5ef6 "延" */
+0x00,0x00,0xf9,0x08,0x10,0x11,0x21,0x79,0x09,0x09,0x49,0x31,0x10,0x2c,0x43,0x80,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 24311 0x5ef7 "廷" */
+0x00,0x00,0xf9,0x08,0x10,0x10,0x21,0x78,0x08,0x08,0x48,0x33,0x10,0x2c,0x43,0x80,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,0x00,0xfe,0x00,
+/* 24312 0x5ef8 "廸" */
+0x00,0x00,0xf8,0x09,0x11,0x11,0x21,0x79,0x09,0x09,0x49,0x31,0x10,0x2c,0x43,0x80,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0xfe,0x00,
+/* 24313 0x5ef9 "廹" */
+0x00,0x00,0xf8,0x09,0x11,0x11,0x21,0x79,0x09,0x09,0x49,0x31,0x11,0x2c,0x43,0x80,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 24314 0x5efa "建" */
+0x00,0x00,0xfb,0x08,0x17,0x10,0x23,0x78,0x0b,0x08,0x48,0x37,0x10,0x2c,0x43,0x80,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 24315 0x5efb "廻" */
+0x00,0x03,0xfa,0x0a,0x12,0x12,0x22,0x7a,0x0a,0x0a,0x4b,0x32,0x10,0x2c,0x43,0x80,
+0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0xf4,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 24316 0x5efc "廼" */
+0x00,0x07,0xf8,0x08,0x13,0x12,0x22,0x7a,0x0a,0x0b,0x4a,0x33,0x12,0x2c,0x43,0x80,
+0x00,0xfe,0x90,0x90,0xfc,0x94,0x94,0x94,0x9c,0x04,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 24317 0x5efd "廽" */
+0x00,0x03,0xfa,0x0a,0x12,0x12,0x22,0x7a,0x0a,0x0a,0x4a,0x33,0x12,0x2c,0x43,0x80,
+0x00,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,0x00,0xfe,0x00,
+/* 24318 0x5efe "廾" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24319 0x5eff "廿" */
+0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,
+0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 24320 0x5f00 "开" */
+0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24321 0x5f01 "弁" */
+0x02,0x04,0x08,0x10,0x3f,0x00,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0x00,0x20,0x10,0xf8,0x08,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24322 0x5f02 "异" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x00,0xf0,0x10,0x10,0xf0,0x04,0x04,0xfc,0x00,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24323 0x5f03 "弃" */
+0x01,0x00,0x3f,0x02,0x04,0x08,0x1f,0x00,0x04,0x04,0x7f,0x04,0x04,0x08,0x10,0x20,
+0x00,0x80,0xfc,0x00,0x20,0x10,0xf8,0x08,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 24324 0x5f04 "弄" */
+0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24325 0x5f05 "弅" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24326 0x5f06 "弆" */
+0x01,0x01,0x3f,0x01,0xff,0x04,0x08,0x1f,0x00,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x00,0x00,0xf8,0x00,0xfe,0x00,0x20,0xf0,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24327 0x5f07 "弇" */
+0x01,0x02,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x1f,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0xf0,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24328 0x5f08 "弈" */
+0x02,0x01,0x7f,0x04,0x24,0x44,0x89,0x10,0x00,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,0x00,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24329 0x5f09 "弉" */
+0x24,0x24,0x24,0x3d,0x04,0xfc,0x24,0x24,0x44,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xf8,0x00,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24330 0x5f0a "弊" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x43,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x20,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24331 0x5f0b "弋" */
+0x02,0x02,0x02,0x02,0x02,0xff,0x02,0x02,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x20,0x10,0x10,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x42,0x22,0x1a,0x06,
+/* 24332 0x5f0c "弌" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x20,0x22,0x92,0x0a,0x06,0x02,
+/* 24333 0x5f0d "弍" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x0f,0xf0,0x40,0x00,
+0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 24334 0x5f0e "弎" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x7f,0x00,0x00,0x3e,0x00,0x00,0x07,0xf8,0x40,
+0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x8a,0x06,0x02,
+/* 24335 0x5f0f "式" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x0f,0x78,0x20,0x00,
+0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 24336 0x5f10 "弐" */
+0x00,0x3e,0x00,0x00,0xff,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x0f,0xf0,0x40,0x00,
+0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 24337 0x5f11 "弑" */
+0x00,0x44,0x28,0x13,0x28,0x44,0x10,0x11,0xfc,0x10,0x58,0x54,0x94,0x13,0x51,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x10,0x10,0xf0,0x90,0x90,0x90,0x88,0xea,0x8a,0x06,0x02,
+/* 24338 0x5f12 "弒" */
+0x44,0x28,0x10,0x28,0x45,0x10,0x14,0x11,0xfc,0x30,0x38,0x54,0x50,0x93,0x10,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x90,0x90,0x90,0x88,0xea,0x8a,0x06,0x02,
+/* 24339 0x5f13 "弓" */
+0x00,0x7f,0x00,0x00,0x00,0x3f,0x20,0x20,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 24340 0x5f14 "弔" */
+0x00,0x3f,0x01,0x01,0x01,0x1f,0x11,0x11,0x21,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x04,0x04,0x14,0x08,0x00,0x00,
+/* 24341 0x5f15 "引" */
+0x00,0x7f,0x01,0x01,0x01,0x3f,0x20,0x20,0x40,0x7f,0x01,0x01,0x01,0x01,0x0a,0x04,
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 24342 0x5f16 "弖" */
+0x00,0x3f,0x00,0x00,0x1f,0x10,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x28,0x10,0x00,0xfe,0x00,
+/* 24343 0x5f17 "弗" */
+0x04,0x04,0x04,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x04,0x08,0x08,0x10,0x20,0x40,
+0x40,0x40,0x40,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 24344 0x5f18 "弘" */
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x40,0x40,0x40,0x7c,0x04,0x05,0x07,0x05,0x28,0x10,
+0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x40,0x80,0x88,0x84,0x04,0xfe,0x02,0x02,0x00,
+/* 24345 0x5f19 "弙" */
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x40,0x41,0x40,0x7c,0x04,0x04,0x04,0x04,0x28,0x10,
+0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 24346 0x5f1a "弚" */
+0x08,0x04,0x04,0x7f,0x01,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,
+0x20,0x20,0x40,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x14,0x08,0x00,0x00,
+/* 24347 0x5f1b "弛" */
+0x00,0xf8,0x08,0x09,0x09,0x79,0x41,0x43,0x41,0x79,0x09,0x09,0x09,0x09,0x50,0x20,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 24348 0x5f1c "弜" */
+0x00,0x7d,0x04,0x04,0x04,0x7c,0x40,0x40,0x41,0x7d,0x04,0x04,0x04,0x04,0x28,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 24349 0x5f1d "弝" */
+0x00,0x7d,0x05,0x05,0x05,0x7d,0x41,0x41,0x41,0x7d,0x05,0x05,0x05,0x05,0x28,0x10,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 24350 0x5f1e "弞" */
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x41,0x40,0x40,0x7c,0x04,0x04,0x04,0x04,0x29,0x12,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 24351 0x5f1f "弟" */
+0x08,0x04,0x04,0x7f,0x01,0x01,0x3f,0x21,0x21,0x3f,0x03,0x05,0x09,0x11,0x61,0x01,
+0x20,0x20,0x40,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x14,0x08,0x00,0x00,
+/* 24352 0x5f20 "张" */
+0x01,0xf9,0x09,0x09,0x09,0x79,0x41,0x47,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x00,0x08,0x08,0x10,0x20,0x40,0x00,0xfe,0x40,0x20,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 24353 0x5f21 "弡" */
+0x00,0x7c,0x04,0x04,0x04,0x7c,0x40,0x40,0x40,0x7c,0x04,0x04,0x04,0x04,0x28,0x10,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 24354 0x5f22 "弢" */
+0x00,0x7d,0x05,0x05,0x05,0x7c,0x40,0x43,0x41,0x7c,0x04,0x04,0x04,0x04,0x29,0x16,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x20,0xfc,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 24355 0x5f23 "弣" */
+0x00,0xf8,0x08,0x09,0x09,0x7b,0x45,0x41,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 24356 0x5f24 "弤" */
+0x00,0xf8,0x09,0x09,0x09,0x79,0x41,0x41,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 24357 0x5f25 "弥" */
+0x00,0xf8,0x08,0x09,0x09,0x7a,0x44,0x40,0x41,0x79,0x0a,0x0a,0x0c,0x08,0x50,0x20,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 24358 0x5f26 "弦" */
+0x00,0xf8,0x08,0x0b,0x08,0x78,0x40,0x41,0x43,0x78,0x08,0x08,0x09,0x0b,0x51,0x20,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x88,0x08,0xf0,0x20,0x40,0x88,0x04,0xfc,0x04,0x00,
+/* 24359 0x5f27 "弧" */
+0x00,0xf8,0x0b,0x0a,0x0a,0x7a,0x42,0x42,0x42,0x7a,0x0a,0x0a,0x0a,0x0c,0x54,0x28,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 24360 0x5f28 "弨" */
+0x00,0xfb,0x08,0x08,0x08,0x79,0x41,0x42,0x44,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24361 0x5f29 "弩" */
+0x08,0x7f,0x11,0x32,0x0c,0x12,0x61,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x7c,0x44,0x28,0x10,0x28,0x46,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x50,0x20,
+/* 24362 0x5f2a "弪" */
+0x00,0x7d,0x04,0x04,0x04,0x7c,0x40,0x43,0x40,0x7d,0x04,0x04,0x04,0x04,0x2b,0x10,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24363 0x5f2b "弫" */
+0x00,0x7d,0x05,0x05,0x05,0x7d,0x41,0x41,0x41,0x7d,0x05,0x05,0x05,0x05,0x29,0x10,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 24364 0x5f2c "弬" */
+0x00,0x7d,0x05,0x05,0x05,0x7d,0x41,0x41,0x41,0x7d,0x05,0x05,0x05,0x05,0x29,0x10,
+0x00,0xfe,0x10,0x10,0x50,0x5c,0x44,0x44,0x44,0x44,0x5c,0x50,0x10,0x10,0xfe,0x00,
+/* 24365 0x5f2d "弭" */
+0x00,0xfb,0x09,0x09,0x09,0x79,0x41,0x41,0x41,0x79,0x09,0x09,0x0b,0x08,0x50,0x20,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 24366 0x5f2e "弮" */
+0x11,0x09,0x7f,0x04,0xff,0x10,0x20,0xdf,0x00,0x0f,0x08,0x10,0x1f,0x00,0x00,0x00,
+0x10,0x20,0xfc,0x00,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x00,0x00,0xf8,0x08,0x28,0x10,
+/* 24367 0x5f2f "弯" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x44,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x50,0x20,
+/* 24368 0x5f30 "弰" */
+0x00,0x7d,0x04,0x04,0x04,0x7d,0x41,0x41,0x41,0x7d,0x05,0x05,0x05,0x05,0x29,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 24369 0x5f31 "弱" */
+0x00,0x7e,0x02,0x02,0x7e,0x40,0x40,0x7e,0x22,0x12,0x06,0x1a,0x62,0x02,0x14,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x80,0x80,0xfc,0x44,0x24,0x0c,0x34,0xc4,0x04,0x28,0x10,
+/* 24370 0x5f32 "弲" */
+0x00,0xf9,0x09,0x09,0x09,0x78,0x43,0x42,0x42,0x7b,0x0a,0x0a,0x0b,0x0a,0x52,0x22,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 24371 0x5f33 "弳" */
+0x00,0xfb,0x08,0x09,0x0a,0x7c,0x42,0x41,0x40,0x7b,0x08,0x08,0x08,0x08,0x57,0x20,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 24372 0x5f34 "弴" */
+0x00,0xf8,0x0b,0x08,0x09,0x79,0x41,0x40,0x41,0x78,0x08,0x0b,0x08,0x08,0x50,0x20,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 24373 0x5f35 "張" */
+0x00,0xf8,0x08,0x08,0x08,0x78,0x40,0x47,0x41,0x79,0x09,0x09,0x09,0x09,0x51,0x21,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 24374 0x5f36 "弶" */
+0x00,0xf8,0x0b,0x08,0x08,0x79,0x41,0x41,0x41,0x79,0x08,0x08,0x09,0x0a,0x50,0x20,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 24375 0x5f37 "強" */
+0x00,0xf8,0x08,0x09,0x0b,0x78,0x40,0x43,0x42,0x7a,0x0b,0x08,0x08,0x08,0x57,0x20,
+0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0xfe,0x22,0x22,0xfe,0x20,0x24,0x22,0xfe,0x02,
+/* 24376 0x5f38 "弸" */
+0x00,0xfb,0x0a,0x0a,0x0a,0x7b,0x42,0x42,0x42,0x7b,0x0a,0x0a,0x0a,0x0a,0x55,0x28,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 24377 0x5f39 "弹" */
+0x01,0xf8,0x08,0x09,0x09,0x79,0x41,0x41,0x41,0x79,0x08,0x08,0x0b,0x08,0x50,0x20,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 24378 0x5f3a "强" */
+0x00,0xf9,0x09,0x09,0x09,0x78,0x40,0x43,0x42,0x7a,0x0b,0x08,0x08,0x08,0x57,0x20,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0xfe,0x20,0x24,0x22,0xfe,0x02,
+/* 24379 0x5f3b "弻" */
+0x00,0xf0,0x17,0x11,0x11,0xf7,0x85,0x85,0x85,0xf6,0x14,0x14,0x14,0x17,0xa4,0x40,
+0x00,0x1e,0xc2,0x02,0x02,0xde,0x50,0x50,0x50,0xde,0x42,0x42,0x42,0xc2,0x54,0x08,
+/* 24380 0x5f3c "弼" */
+0x00,0xf0,0x17,0x11,0x12,0xf7,0x84,0x84,0x84,0xf7,0x14,0x14,0x14,0x17,0xa4,0x40,
+0x00,0x1e,0xc2,0x02,0x02,0xde,0x50,0x50,0x50,0xde,0x42,0x42,0x42,0xc2,0x54,0x08,
+/* 24381 0x5f3d "弽" */
+0x00,0xf9,0x09,0x0b,0x09,0x79,0x41,0x41,0x41,0x78,0x0b,0x08,0x08,0x09,0x56,0x20,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 24382 0x5f3e "弾" */
+0x02,0xf9,0x08,0x09,0x09,0x79,0x41,0x41,0x41,0x79,0x08,0x08,0x0b,0x08,0x50,0x20,
+0x42,0x24,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 24383 0x5f3f "弿" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x1f,0x20,0xdf,0x10,0x1f,0x00,0x00,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x28,0xe6,0x00,0xf0,0x10,0xe0,
+/* 24384 0x5f40 "彀" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x04,0x7c,0x40,0x7c,0x04,0x0d,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 24385 0x5f41 "彁" */
+0x00,0xfb,0x08,0x09,0x09,0x79,0x40,0x43,0x40,0x79,0x09,0x09,0x09,0x08,0x50,0x20,
+0x00,0xfe,0x08,0xe8,0x28,0xe8,0x00,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x08,0x28,0x10,
+/* 24386 0x5f42 "彂" */
+0x04,0x24,0x14,0x04,0xff,0x00,0xfc,0x04,0x7d,0x40,0x81,0xfc,0x04,0x04,0x28,0x11,
+0x40,0x48,0x50,0x40,0xfe,0x00,0x80,0xf8,0x20,0x20,0xfc,0x20,0x50,0x50,0x88,0x04,
+/* 24387 0x5f43 "彃" */
+0x00,0xf9,0x09,0x09,0x09,0x79,0x40,0x40,0x43,0x78,0x08,0x09,0x08,0x0b,0x50,0x20,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 24388 0x5f44 "彄" */
+0x00,0xfb,0x0a,0x0a,0x0a,0x7a,0x42,0x42,0x42,0x7a,0x0a,0x0a,0x0a,0x0a,0x53,0x20,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 24389 0x5f45 "彅" */
+0x01,0xf8,0x0f,0x08,0x0b,0x7a,0x43,0x42,0x43,0x7a,0x0a,0x08,0x0b,0x08,0x51,0x26,
+0x08,0x90,0xfe,0x00,0xc4,0x54,0xd4,0x54,0xd4,0x44,0xcc,0x00,0xfc,0x84,0x14,0x08,
+/* 24390 0x5f46 "彆" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x00,0x00,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x50,0x20,
+/* 24391 0x5f47 "彇" */
+0x00,0xf9,0x08,0x0b,0x08,0x79,0x40,0x42,0x43,0x7a,0x0b,0x0a,0x0b,0x0a,0x52,0x24,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 24392 0x5f48 "彈" */
+0x00,0xfb,0x0a,0x0a,0x0b,0x78,0x41,0x41,0x41,0x79,0x09,0x08,0x0b,0x08,0x50,0x20,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 24393 0x5f49 "彉" */
+0x00,0xf8,0x09,0x08,0x08,0x7b,0x40,0x41,0x41,0x79,0x09,0x09,0x08,0x08,0x51,0x22,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 24394 0x5f4a "彊" */
+0x00,0xfb,0x08,0x09,0x09,0x79,0x41,0x43,0x40,0x79,0x09,0x09,0x09,0x09,0x50,0x23,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 24395 0x5f4b "彋" */
+0x00,0xfb,0x0a,0x0a,0x0b,0x78,0x47,0x40,0x43,0x7a,0x0b,0x08,0x09,0x0b,0x5d,0x21,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 24396 0x5f4c "彌" */
+0x00,0xf7,0x12,0x14,0x1f,0xf4,0x86,0x85,0x86,0xf4,0x16,0x15,0x16,0x14,0xa4,0x44,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 24397 0x5f4d "彍" */
+0x00,0xf0,0x17,0x14,0x15,0xf4,0x87,0x84,0x85,0xf5,0x15,0x15,0x15,0x14,0xa4,0x49,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 24398 0x5f4e "彎" */
+0x21,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x00,
+0x08,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x70,
+/* 24399 0x5f4f "彏" */
+0x03,0xfa,0x0b,0x0a,0x0b,0x78,0x41,0x43,0x45,0x79,0x09,0x08,0x09,0x08,0x50,0x27,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 24400 0x5f50 "彐" */
+0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,
+/* 24401 0x5f51 "彑" */
+0x04,0x04,0x04,0x08,0x0f,0x08,0x10,0x10,0x20,0x3f,0x00,0x00,0x00,0x00,0xff,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0xe0,0x40,0x40,0x80,0x80,0xfe,0x00,
+/* 24402 0x5f52 "归" */
+0x08,0x08,0x4b,0x48,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x08,0x10,0x13,0x20,0x40,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 24403 0x5f53 "当" */
+0x01,0x21,0x11,0x09,0x09,0x01,0x7f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x7f,0x00,
+0x00,0x08,0x08,0x10,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 24404 0x5f54 "彔" */
+0x08,0x0f,0x08,0x10,0x1f,0x00,0x00,0xff,0x01,0x21,0x11,0x05,0x09,0x31,0xc5,0x02,
+0x00,0xe0,0x20,0x20,0xc0,0x40,0x40,0xfe,0x00,0x08,0x90,0x60,0x20,0x18,0x06,0x00,
+/* 24405 0x5f55 "录" */
+0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0xff,0x01,0x21,0x11,0x05,0x09,0x31,0xc5,0x02,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,0x08,0x90,0x60,0x20,0x18,0x06,0x00,
+/* 24406 0x5f56 "彖" */
+0x08,0x0f,0x10,0x1f,0x00,0xff,0x02,0x0d,0x71,0x02,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0xf0,0x10,0xe0,0x20,0xfe,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 24407 0x5f57 "彗" */
+0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x00,0x7f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,
+0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 24408 0x5f58 "彘" */
+0x08,0x0f,0x10,0x1f,0x00,0xff,0x02,0x42,0x43,0x75,0x41,0x4f,0x41,0x62,0x44,0x08,
+0x00,0xf0,0x10,0xe0,0x20,0xfe,0x00,0x10,0xd2,0x14,0x18,0xd0,0x12,0x92,0x4e,0x20,
+/* 24409 0x5f59 "彙" */
+0x08,0x0f,0x10,0x1f,0x00,0x7f,0x40,0x9f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x11,0x61,
+0x00,0xf0,0x10,0xe0,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0x0c,
+/* 24410 0x5f5a "彚" */
+0x00,0x3f,0x00,0x1f,0x00,0x7f,0x40,0x9f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x11,0x61,
+0x00,0xf0,0x10,0xf0,0x10,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0x0c,
+/* 24411 0x5f5b "彛" */
+0x3f,0x00,0x1f,0x00,0xff,0x92,0x54,0xff,0x38,0x54,0x92,0x08,0xff,0x08,0x10,0x20,
+0xf0,0x10,0xf0,0x10,0xfe,0x48,0x84,0x7a,0x28,0x48,0x98,0x20,0xfe,0x20,0x20,0x20,
+/* 24412 0x5f5c "彜" */
+0x08,0x0f,0x10,0x1f,0x00,0xff,0x92,0x54,0xff,0x38,0x54,0x92,0x08,0xff,0x08,0x10,
+0x00,0xf0,0x10,0xe0,0x20,0xfe,0x48,0x84,0x7a,0x28,0x48,0x98,0x20,0xfe,0x20,0x20,
+/* 24413 0x5f5d "彝" */
+0x08,0x0f,0x10,0x1f,0x00,0xff,0x92,0x54,0xfe,0x38,0x54,0x92,0x08,0xff,0x08,0x10,
+0x00,0xe0,0x20,0xc0,0x40,0xfe,0x24,0x78,0x12,0xfe,0x54,0x92,0x20,0xfe,0x20,0x20,
+/* 24414 0x5f5e "彞" */
+0x3f,0x00,0x1f,0x00,0xff,0x92,0x54,0xfe,0x38,0x54,0x92,0x08,0xff,0x08,0x10,0x20,
+0xf0,0x10,0xf0,0x10,0xfe,0x24,0x78,0x12,0xfe,0x54,0x92,0x20,0xfe,0x20,0x20,0x20,
+/* 24415 0x5f5f "彟" */
+0x00,0xfd,0x04,0x04,0xfc,0x05,0x04,0xfc,0x00,0x08,0xfe,0x08,0x49,0x28,0x08,0x19,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 24416 0x5f60 "彠" */
+0x7e,0x03,0x3e,0x02,0x7e,0x01,0xee,0x4a,0x6e,0xc0,0x04,0xfe,0x45,0x24,0x24,0x0d,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 24417 0x5f61 "彡" */
+0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x01,0x06,0x38,
+0x40,0x80,0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 24418 0x5f62 "形" */
+0x00,0x7f,0x12,0x12,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x82,
+0x00,0x84,0x04,0x08,0x10,0x22,0x02,0xc4,0x08,0x10,0x22,0x02,0x04,0x08,0x10,0x60,
+/* 24419 0x5f63 "彣" */
+0x10,0x08,0x08,0xff,0x22,0x22,0x22,0x22,0x14,0x14,0x08,0x08,0x14,0x23,0x40,0x80,
+0x04,0x04,0x08,0x90,0x24,0x44,0x08,0x12,0x22,0x44,0x08,0x10,0x20,0x00,0xfe,0x00,
+/* 24420 0x5f64 "彤" */
+0x00,0x3f,0x21,0x21,0x29,0x25,0x25,0x21,0xff,0x21,0x21,0x21,0x21,0x41,0x45,0x82,
+0x00,0x04,0x04,0x08,0x10,0x22,0x02,0x04,0xc8,0x10,0x22,0x02,0x04,0x08,0x10,0x60,
+/* 24421 0x5f65 "彥" */
+0x02,0x01,0x3f,0x04,0x03,0x04,0x3f,0x20,0x21,0x2e,0x20,0x21,0x2e,0x40,0x43,0x9c,
+0x00,0x00,0xf8,0x20,0xc0,0x20,0xfc,0x20,0xc0,0x10,0x60,0x88,0x10,0x60,0x80,0x00,
+/* 24422 0x5f66 "彦" */
+0x02,0x01,0x3f,0x08,0x04,0x3f,0x20,0x20,0x21,0x2e,0x20,0x21,0x2e,0x40,0x43,0x9c,
+0x00,0x00,0xf8,0x20,0x40,0xfc,0x00,0x20,0xc0,0x10,0x60,0x88,0x10,0x60,0x80,0x00,
+/* 24423 0x5f67 "彧" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x7c,0x45,0x44,0x44,0x7d,0x00,0x0e,0xf0,0x43,0x00,
+0x50,0x48,0x40,0xfe,0x40,0x50,0x60,0xc8,0x50,0x64,0xa8,0x12,0x32,0xca,0x06,0x02,
+/* 24424 0x5f68 "彨" */
+0x00,0xff,0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x6b,0x5a,0x4a,0x4a,0x4a,0x4a,0x4a,0x5a,
+0x02,0xe2,0x04,0x08,0xd0,0x42,0x42,0x44,0x48,0xd0,0x42,0x42,0x44,0x48,0x50,0xe0,
+/* 24425 0x5f69 "彩" */
+0x01,0x07,0x78,0x08,0x44,0x25,0x20,0x04,0x7f,0x0c,0x16,0x15,0x24,0x44,0x84,0x04,
+0x00,0x84,0x04,0x88,0x90,0x22,0x02,0x04,0x88,0x10,0x22,0x02,0x84,0x08,0x10,0x60,
+/* 24426 0x5f6a "彪" */
+0x04,0x07,0x04,0x3f,0x24,0x27,0x3c,0x23,0x20,0x2f,0x29,0x29,0x49,0x51,0x90,0x20,
+0x00,0x84,0x04,0xc8,0x50,0x24,0x84,0x88,0x10,0x24,0x04,0x08,0x12,0x22,0xfe,0x00,
+/* 24427 0x5f6b "彫" */
+0x00,0x3f,0x24,0x24,0x2e,0x24,0x3f,0x20,0x2e,0x2a,0x2a,0x2e,0x20,0x40,0x42,0x81,
+0x00,0x84,0x84,0x88,0x90,0xa2,0x82,0x84,0x88,0x90,0xa2,0x82,0x84,0x88,0x90,0x60,
+/* 24428 0x5f6c "彬" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x30,0x39,0x55,0x52,0x92,0x14,0x10,0x10,0x10,0x10,
+0x82,0x82,0x84,0x88,0xd0,0x82,0x82,0xc4,0xa8,0x90,0x82,0x82,0x84,0x88,0x90,0xa0,
+/* 24429 0x5f6d "彭" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x00,0x7f,0x41,0x41,0x7f,0x00,0x22,0x17,0xf8,0x40,
+0x00,0x04,0x84,0x08,0x10,0x22,0x02,0x04,0x08,0x10,0x22,0x02,0x04,0x88,0x10,0x60,
+/* 24430 0x5f6e "彮" */
+0x10,0x08,0xff,0x80,0x14,0x22,0x49,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x3e,0x22,
+0x00,0x04,0x84,0x88,0x10,0x22,0x02,0x04,0x08,0x10,0xa2,0x02,0x04,0x08,0x10,0x60,
+/* 24431 0x5f6f "彯" */
+0x00,0xff,0x14,0x7f,0x55,0x55,0x7f,0x00,0x7f,0x00,0xff,0x08,0x2a,0x49,0xa8,0x10,
+0x00,0x84,0x04,0x08,0x10,0x22,0x02,0x04,0x08,0x10,0xa2,0x02,0x04,0x08,0x90,0x60,
+/* 24432 0x5f70 "彰" */
+0x10,0x08,0x7f,0x22,0x14,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x08,0x08,
+0x00,0x04,0x04,0x08,0x10,0xa2,0x02,0x04,0x08,0x10,0x22,0x02,0x04,0x88,0x10,0x60,
+/* 24433 0x5f71 "影" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x00,0x7f,0x41,0x7f,0x08,0x49,0x88,0x18,
+0x00,0x04,0x04,0x08,0x10,0x22,0x02,0xc4,0x08,0x10,0x22,0x02,0x04,0x08,0x90,0x60,
+/* 24434 0x5f72 "彲" */
+0x7b,0x00,0x7b,0x4a,0x6b,0x4a,0x04,0x7f,0x4a,0x7f,0x4a,0x7f,0x52,0x5b,0x52,0x99,
+0xc2,0x02,0xc4,0x48,0x50,0x42,0x02,0xc4,0x08,0xd0,0x42,0xc2,0x44,0x88,0x50,0xe0,
+/* 24435 0x5f73 "彳" */
+0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0x80,0x10,0x10,0x20,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 24436 0x5f74 "彴" */
+0x08,0x08,0x10,0x20,0x49,0x09,0x12,0x34,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x84,0x44,0x24,0x24,0x04,0x04,0x04,0x28,0x10,
+/* 24437 0x5f75 "彵" */
+0x08,0x08,0x10,0x22,0x4a,0x0a,0x12,0x37,0x52,0x92,0x12,0x12,0x12,0x12,0x11,0x10,
+0x40,0x40,0x40,0x40,0x58,0x68,0xc8,0x48,0x48,0x68,0x50,0x44,0x44,0x04,0xfc,0x00,
+/* 24438 0x5f76 "彶" */
+0x10,0x17,0x21,0x41,0x91,0x11,0x21,0x61,0xa1,0x22,0x22,0x22,0x24,0x24,0x28,0x23,
+0x00,0xf8,0x08,0x10,0x10,0x20,0x3c,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 24439 0x5f77 "彷" */
+0x08,0x08,0x10,0x23,0x48,0x08,0x10,0x30,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 24440 0x5f78 "彸" */
+0x08,0x09,0x11,0x21,0x49,0x0a,0x12,0x34,0x58,0x90,0x11,0x11,0x12,0x17,0x12,0x10,
+0x20,0x20,0x20,0x10,0x10,0x48,0x48,0x44,0x82,0x80,0x10,0x08,0x08,0xfc,0x04,0x00,
+/* 24441 0x5f79 "役" */
+0x08,0x09,0x11,0x21,0x49,0x0a,0x14,0x33,0x51,0x91,0x10,0x10,0x10,0x10,0x13,0x1c,
+0x00,0xf0,0x10,0x10,0x10,0x0e,0x00,0xf8,0x08,0x10,0x90,0xa0,0x40,0xa0,0x18,0x06,
+/* 24442 0x5f7a "彺" */
+0x08,0x08,0x13,0x20,0x48,0x08,0x10,0x30,0x51,0x90,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24443 0x5f7b "彻" */
+0x10,0x12,0x22,0x42,0x92,0x12,0x23,0x6e,0xa2,0x22,0x22,0x23,0x22,0x20,0x20,0x21,
+0x00,0x00,0xfc,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0xa4,0x24,0x44,0x44,0x94,0x08,
+/* 24444 0x5f7c "彼" */
+0x08,0x08,0x10,0x23,0x4a,0x0a,0x12,0x33,0x52,0x92,0x12,0x12,0x12,0x14,0x14,0x19,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 24445 0x5f7d "彽" */
+0x08,0x08,0x13,0x22,0x4a,0x0a,0x12,0x33,0x52,0x92,0x12,0x12,0x12,0x12,0x13,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 24446 0x5f7e "彾" */
+0x08,0x08,0x10,0x20,0x49,0x0a,0x14,0x30,0x53,0x90,0x10,0x11,0x10,0x10,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 24447 0x5f7f "彿" */
+0x08,0x08,0x10,0x23,0x48,0x08,0x13,0x32,0x52,0x93,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 24448 0x5f80 "往" */
+0x08,0x08,0x10,0x27,0x48,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x80,0x40,0x00,0xfc,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 24449 0x5f81 "征" */
+0x08,0x08,0x13,0x20,0x48,0x08,0x11,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24450 0x5f82 "徂" */
+0x08,0x09,0x11,0x21,0x49,0x09,0x11,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 24451 0x5f83 "徃" */
+0x08,0x09,0x11,0x21,0x49,0x0a,0x12,0x34,0x50,0x91,0x10,0x10,0x10,0x10,0x17,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24452 0x5f84 "径" */
+0x08,0x0b,0x10,0x20,0x48,0x08,0x11,0x36,0x50,0x93,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xf8,0x10,0x20,0x60,0x98,0x04,0x02,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 24453 0x5f85 "待" */
+0x08,0x08,0x10,0x23,0x48,0x08,0x17,0x30,0x50,0x97,0x10,0x12,0x11,0x11,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 24454 0x5f86 "徆" */
+0x08,0x0f,0x10,0x20,0x48,0x0b,0x12,0x32,0x52,0x92,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 24455 0x5f87 "徇" */
+0x08,0x08,0x11,0x21,0x4a,0x0c,0x13,0x32,0x52,0x93,0x12,0x12,0x13,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 24456 0x5f88 "很" */
+0x08,0x0b,0x12,0x22,0x4b,0x0a,0x12,0x33,0x52,0x92,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 24457 0x5f89 "徉" */
+0x09,0x08,0x10,0x20,0x4b,0x08,0x10,0x31,0x50,0x90,0x13,0x10,0x10,0x10,0x10,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 24458 0x5f8a "徊" */
+0x08,0x08,0x13,0x22,0x4a,0x0a,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0xfc,0x04,0x00,
+/* 24459 0x5f8b "律" */
+0x08,0x08,0x13,0x20,0x4f,0x08,0x13,0x30,0x50,0x93,0x10,0x10,0x17,0x10,0x10,0x10,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,
+/* 24460 0x5f8c "後" */
+0x08,0x08,0x10,0x21,0x4b,0x08,0x10,0x33,0x50,0x90,0x11,0x13,0x14,0x10,0x11,0x16,
+0x20,0x40,0x88,0x10,0xe0,0x40,0x88,0xfc,0x84,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 24461 0x5f8d "徍" */
+0x08,0x08,0x11,0x20,0x48,0x08,0x17,0x30,0x50,0x90,0x11,0x10,0x10,0x10,0x17,0x10,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 24462 0x5f8e "徎" */
+0x08,0x09,0x11,0x21,0x49,0x09,0x10,0x30,0x53,0x90,0x10,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 24463 0x5f8f "徏" */
+0x08,0x08,0x11,0x21,0x49,0x09,0x17,0x30,0x50,0x91,0x11,0x12,0x14,0x10,0x10,0x17,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x24,0x24,0x28,0x10,0x20,0xc0,0x00,
+/* 24464 0x5f90 "徐" */
+0x10,0x10,0x20,0x41,0x92,0x15,0x20,0x60,0xa7,0x20,0x22,0x22,0x24,0x28,0x21,0x20,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 24465 0x5f91 "徑" */
+0x08,0x0b,0x10,0x21,0x4a,0x0c,0x12,0x31,0x50,0x93,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 24466 0x5f92 "徒" */
+0x08,0x08,0x11,0x20,0x48,0x08,0x13,0x30,0x50,0x91,0x11,0x11,0x12,0x12,0x14,0x18,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 24467 0x5f93 "従" */
+0x08,0x09,0x10,0x20,0x48,0x0b,0x10,0x30,0x51,0x91,0x11,0x11,0x12,0x12,0x14,0x18,
+0x04,0x04,0x88,0x90,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 24468 0x5f94 "徔" */
+0x08,0x08,0x13,0x20,0x48,0x08,0x10,0x33,0x50,0x90,0x10,0x10,0x10,0x11,0x12,0x14,
+0x88,0x88,0xfe,0x88,0x88,0x40,0x20,0xfc,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x7e,
+/* 24469 0x5f95 "徕" */
+0x10,0x10,0x20,0x47,0x90,0x12,0x21,0x61,0xaf,0x20,0x21,0x21,0x22,0x24,0x28,0x20,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x50,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 24470 0x5f96 "徖" */
+0x08,0x08,0x13,0x22,0x48,0x09,0x10,0x30,0x53,0x90,0x11,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 24471 0x5f97 "得" */
+0x08,0x0b,0x12,0x23,0x4a,0x0b,0x10,0x33,0x50,0x97,0x10,0x12,0x11,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 24472 0x5f98 "徘" */
+0x08,0x08,0x10,0x27,0x48,0x08,0x10,0x33,0x50,0x90,0x10,0x17,0x10,0x10,0x10,0x10,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 24473 0x5f99 "徙" */
+0x08,0x08,0x11,0x21,0x49,0x09,0x17,0x30,0x50,0x91,0x11,0x11,0x12,0x14,0x18,0x10,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 24474 0x5f9a "徚" */
+0x10,0x10,0x2f,0x40,0x97,0x14,0x25,0x64,0xa4,0x27,0x20,0x21,0x22,0x2c,0x20,0x20,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0x54,0xe4,0x44,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 24475 0x5f9b "徛" */
+0x08,0x08,0x13,0x20,0x49,0x0a,0x17,0x30,0x53,0x92,0x12,0x12,0x13,0x10,0x10,0x10,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 24476 0x5f9c "徜" */
+0x08,0x09,0x10,0x20,0x48,0x0b,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 24477 0x5f9d "徝" */
+0x08,0x08,0x17,0x20,0x48,0x0b,0x12,0x33,0x52,0x93,0x12,0x13,0x12,0x12,0x1f,0x10,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 24478 0x5f9e "從" */
+0x08,0x08,0x10,0x20,0x49,0x0a,0x14,0x30,0x50,0x91,0x11,0x11,0x12,0x12,0x14,0x18,
+0x88,0x88,0x88,0x88,0x54,0x22,0x42,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 24479 0x5f9f "徟" */
+0x10,0x17,0x24,0x44,0x95,0x14,0x24,0x67,0xa4,0x25,0x25,0x25,0x25,0x24,0x24,0x28,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 24480 0x5fa0 "徠" */
+0x08,0x08,0x10,0x27,0x48,0x0a,0x12,0x32,0x55,0x90,0x11,0x11,0x12,0x14,0x18,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 24481 0x5fa1 "御" */
+0x14,0x14,0x27,0x49,0x91,0x11,0x2f,0x61,0xa1,0x25,0x25,0x25,0x25,0x3e,0x28,0x20,
+0x00,0x00,0xde,0x12,0x12,0x12,0xd2,0x12,0x12,0xd2,0x12,0x1a,0xd4,0x10,0x10,0x10,
+/* 24482 0x5fa2 "徢" */
+0x10,0x10,0x27,0x40,0x93,0x10,0x27,0x60,0xa3,0x20,0x22,0x22,0x22,0x25,0x24,0x28,
+0x40,0x40,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 24483 0x5fa3 "徣" */
+0x11,0x11,0x21,0x47,0x91,0x11,0x2f,0x60,0xa3,0x22,0x22,0x23,0x22,0x22,0x23,0x22,
+0x10,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 24484 0x5fa4 "徤" */
+0x08,0x08,0x17,0x21,0x49,0x0a,0x12,0x37,0x51,0x95,0x15,0x12,0x12,0x15,0x18,0x10,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 24485 0x5fa5 "徥" */
+0x08,0x09,0x11,0x21,0x49,0x09,0x11,0x31,0x50,0x93,0x10,0x11,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 24486 0x5fa6 "徦" */
+0x10,0x17,0x24,0x44,0x94,0x17,0x24,0x64,0xa7,0x24,0x24,0x27,0x24,0x24,0x24,0x24,
+0x00,0xbc,0x84,0x84,0x84,0xbc,0x00,0x00,0xbc,0x24,0x24,0xa8,0x10,0x28,0x44,0x82,
+/* 24487 0x5fa7 "徧" */
+0x08,0x08,0x13,0x22,0x4a,0x0b,0x12,0x32,0x53,0x93,0x15,0x15,0x15,0x15,0x19,0x11,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0x52,0x52,0xfe,0x52,0x52,0x52,0x06,
+/* 24488 0x5fa8 "徨" */
+0x08,0x08,0x13,0x22,0x4b,0x0a,0x13,0x30,0x57,0x90,0x10,0x13,0x10,0x10,0x17,0x10,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,
+/* 24489 0x5fa9 "復" */
+0x09,0x09,0x11,0x22,0x4d,0x09,0x11,0x31,0x51,0x90,0x10,0x11,0x12,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 24490 0x5faa "循" */
+0x10,0x17,0x24,0x44,0x97,0x14,0x25,0x65,0xa5,0x25,0x25,0x25,0x29,0x29,0x31,0x21,
+0x3c,0xe0,0x20,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 24491 0x5fab "徫" */
+0x08,0x08,0x13,0x21,0x4f,0x08,0x13,0x32,0x53,0x90,0x17,0x10,0x14,0x17,0x10,0x10,
+0x80,0x80,0xf8,0x08,0xfe,0x00,0xf8,0x08,0xf8,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,
+/* 24492 0x5fac "徬" */
+0x08,0x08,0x13,0x21,0x48,0x0b,0x12,0x34,0x50,0x93,0x10,0x10,0x10,0x11,0x11,0x12,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 24493 0x5fad "徭" */
+0x08,0x08,0x13,0x20,0x4a,0x09,0x11,0x32,0x50,0x93,0x10,0x11,0x11,0x11,0x11,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 24494 0x5fae "微" */
+0x11,0x15,0x25,0x45,0x97,0x10,0x20,0x6f,0xa0,0x27,0x24,0x24,0x24,0x24,0x28,0x30,
+0x08,0x48,0x48,0x50,0xde,0x24,0x14,0xd4,0x14,0x94,0x94,0xa8,0xc8,0x94,0x14,0x22,
+/* 24495 0x5faf "徯" */
+0x08,0x0f,0x12,0x21,0x48,0x09,0x13,0x30,0x51,0x93,0x10,0x10,0x17,0x10,0x11,0x16,
+0x3c,0xc0,0x44,0x28,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x40,0xfc,0xa0,0x10,0x0e,
+/* 24496 0x5fb0 "徰" */
+0x08,0x0b,0x10,0x21,0x49,0x09,0x17,0x30,0x57,0x90,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0xfe,0x20,0x3c,0x20,0x20,0xfe,0x00,0xfe,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,
+/* 24497 0x5fb1 "徱" */
+0x10,0x17,0x20,0x47,0x94,0x14,0x27,0x60,0xa7,0x20,0x2f,0x20,0x22,0x24,0x29,0x20,
+0x00,0xfc,0xa0,0xfc,0xa4,0xa4,0xfc,0x00,0xfc,0x00,0xfe,0x40,0x48,0x44,0x42,0x80,
+/* 24498 0x5fb2 "徲" */
+0x10,0x17,0x24,0x47,0x94,0x14,0x24,0x64,0xa5,0x24,0x24,0x25,0x24,0x2b,0x28,0x30,
+0x00,0xfc,0x04,0xfc,0x20,0xa8,0x70,0xa8,0x04,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,
+/* 24499 0x5fb3 "徳" */
+0x08,0x08,0x17,0x20,0x48,0x0b,0x12,0x32,0x53,0x90,0x10,0x15,0x15,0x19,0x10,0x10,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x94,0x94,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,0x00,
+/* 24500 0x5fb4 "徴" */
+0x12,0x1a,0x2a,0x4a,0x8f,0x10,0x20,0x6f,0xa2,0x22,0x2f,0x22,0x22,0x2f,0x20,0x20,
+0x10,0x90,0x90,0xa0,0xbe,0x44,0x24,0xa4,0x24,0x28,0xa8,0x10,0x28,0xa8,0x44,0x82,
+/* 24501 0x5fb5 "徵" */
+0x11,0x15,0x25,0x45,0x97,0x10,0x27,0x60,0xa7,0x21,0x27,0x21,0x21,0x2f,0x20,0x20,
+0x08,0x48,0x48,0x50,0xde,0x14,0xe4,0x14,0xd4,0x14,0xd4,0x08,0x08,0xd4,0x24,0x42,
+/* 24502 0x5fb6 "徶" */
+0x11,0x11,0x25,0x43,0x91,0x17,0x25,0x65,0xa5,0x27,0x25,0x25,0x25,0x25,0x24,0x24,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 24503 0x5fb7 "德" */
+0x10,0x10,0x2f,0x40,0x97,0x14,0x24,0x67,0xa0,0x2f,0x20,0x20,0x25,0x25,0x29,0x20,
+0x40,0x40,0xfe,0x40,0xfc,0xa4,0xa4,0xfc,0x00,0xfe,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 24504 0x5fb8 "徸" */
+0x08,0x0b,0x11,0x20,0x4b,0x08,0x13,0x32,0x53,0x92,0x13,0x10,0x13,0x10,0x17,0x10,
+0x40,0xf8,0x10,0xa0,0xfc,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xf8,0x40,0xfe,0x00,
+/* 24505 0x5fb9 "徹" */
+0x12,0x11,0x27,0x42,0x94,0x1f,0x20,0x67,0xa4,0x27,0x24,0x27,0x24,0x24,0x24,0x25,
+0x10,0x10,0xd0,0x10,0xbe,0xe4,0x54,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0x94,0xa2,
+/* 24506 0x5fba "徺" */
+0x08,0x08,0x11,0x20,0x4b,0x09,0x13,0x31,0x51,0x96,0x10,0x13,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 24507 0x5fbb "徻" */
+0x10,0x10,0x23,0x4d,0x90,0x17,0x25,0x64,0xa7,0x20,0x23,0x22,0x23,0x22,0x23,0x22,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 24508 0x5fbc "徼" */
+0x12,0x14,0x2f,0x48,0x9f,0x18,0x2f,0x64,0xa2,0x2f,0x24,0x27,0x24,0x28,0x2a,0x31,
+0x10,0x10,0x90,0x90,0xbe,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x88,0x88,0x94,0x94,0x22,
+/* 24509 0x5fbd "徽" */
+0x12,0x1a,0x2a,0x4f,0x80,0x1f,0x24,0x68,0xaf,0x22,0x24,0x3f,0x22,0x2a,0x32,0x26,
+0x10,0x90,0x90,0xa0,0x3e,0xc4,0x24,0xa4,0x24,0x28,0xa8,0xd0,0x28,0xa8,0x44,0x82,
+/* 24510 0x5fbe "徾" */
+0x12,0x1a,0x2a,0x4f,0x94,0x12,0x2f,0x60,0xaf,0x20,0x2f,0x20,0x2f,0x28,0x2f,0x20,
+0x10,0x90,0x90,0x90,0x3e,0x24,0xd4,0x14,0x94,0x14,0x94,0x08,0x88,0x94,0x94,0x22,
+/* 24511 0x5fbf "徿" */
+0x09,0x08,0x13,0x20,0x4a,0x09,0x13,0x30,0x53,0x92,0x13,0x12,0x13,0x12,0x12,0x12,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 24512 0x5fc0 "忀" */
+0x10,0x17,0x20,0x43,0x92,0x13,0x21,0x67,0xa1,0x27,0x21,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 24513 0x5fc1 "忁" */
+0x0b,0x0a,0x13,0x22,0x4b,0x0a,0x13,0x34,0x57,0x90,0x1f,0x12,0x15,0x18,0x11,0x16,
+0xf8,0x08,0xf8,0x08,0xf8,0x48,0xf8,0x44,0xfc,0x80,0xfe,0x48,0x54,0xe2,0x50,0xc8,
+/* 24514 0x5fc2 "忂" */
+0x17,0x14,0x27,0x44,0x97,0x14,0x27,0x61,0xa3,0x22,0x27,0x2a,0x23,0x22,0x23,0x22,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 24515 0x5fc3 "心" */
+0x00,0x02,0x01,0x00,0x00,0x04,0x04,0x24,0x24,0x24,0x44,0x44,0x84,0x04,0x03,0x00,
+0x00,0x00,0x00,0x80,0x80,0x00,0x08,0x04,0x04,0x02,0x02,0x12,0x10,0x10,0xf0,0x00,
+/* 24516 0x5fc4 "忄" */
+0x10,0x10,0x10,0x10,0x18,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 24517 0x5fc5 "必" */
+0x00,0x04,0x02,0x01,0x01,0x08,0x28,0x28,0x28,0x49,0x4a,0x8c,0x08,0x18,0x27,0x40,
+0x00,0x00,0x10,0x10,0x20,0x20,0x48,0x44,0x84,0x02,0x02,0x12,0x10,0x10,0xf0,0x00,
+/* 24518 0x5fc6 "忆" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x50,0x90,0x11,0x11,0x12,0x12,0x12,0x11,0x10,
+0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x80,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 24519 0x5fc7 "忇" */
+0x10,0x10,0x10,0x10,0x19,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 24520 0x5fc8 "忈" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0xff,0x00,0x01,0x08,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x80,0x88,0x04,0x12,0x12,0xf0,0x00,
+/* 24521 0x5fc9 "忉" */
+0x10,0x10,0x17,0x10,0x18,0x54,0x50,0x50,0x90,0x10,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 24522 0x5fca "忊" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 24523 0x5fcb "忋" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x11,0x10,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 24524 0x5fcc "忌" */
+0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x04,0x04,0xfc,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24525 0x5fcd "忍" */
+0x00,0x3f,0x02,0x12,0x12,0x24,0x08,0x10,0x60,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24526 0x5fce "忎" */
+0x00,0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x10,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24527 0x5fcf "忏" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x57,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 24528 0x5fd0 "忐" */
+0x02,0x02,0x02,0x03,0x02,0x02,0x02,0xff,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24529 0x5fd1 "忑" */
+0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xfe,0x00,0x40,0x20,0x10,0x08,0x00,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24530 0x5fd2 "忒" */
+0x00,0x00,0x00,0x00,0xff,0x00,0x08,0x04,0x14,0x55,0x50,0x50,0x92,0x12,0x0e,0x00,
+0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0xa0,0xa2,0x92,0x0a,0x06,0x02,
+/* 24531 0x5fd3 "忓" */
+0x10,0x11,0x10,0x10,0x18,0x54,0x50,0x53,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24532 0x5fd4 "忔" */
+0x10,0x10,0x11,0x11,0x1a,0x54,0x51,0x50,0x90,0x10,0x10,0x11,0x12,0x12,0x11,0x10,
+0x80,0x80,0x00,0xfe,0x00,0x00,0xf8,0x08,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 24533 0x5fd5 "忕" */
+0x10,0x10,0x10,0x18,0x54,0x53,0x50,0x90,0x10,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 24534 0x5fd6 "忖" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x91,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 24535 0x5fd7 "志" */
+0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x3f,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24536 0x5fd8 "忘" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x10,0x1f,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24537 0x5fd9 "忙" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfe,0x00,
+/* 24538 0x5fda "忚" */
+0x10,0x10,0x10,0x11,0x19,0x55,0x51,0x53,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 24539 0x5fdb "忛" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 24540 0x5fdc "応" */
+0x01,0x00,0x3f,0x20,0x21,0x20,0x22,0x22,0x22,0x2a,0x2a,0x2a,0x52,0x42,0x81,0x00,
+0x00,0x80,0xfe,0x00,0x00,0x80,0x40,0x00,0x00,0x08,0x04,0x14,0x10,0x10,0xf0,0x00,
+/* 24541 0x5fdd "忝" */
+0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x09,0x31,0xc1,0x11,0x11,0x21,0x41,0x05,0x02,
+0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x90,0x48,0x24,0x24,0x00,0x00,
+/* 24542 0x5fde "忞" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x0c,0x30,0xc0,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x60,0x18,0x06,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24543 0x5fdf "忟" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x11,0x16,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 24544 0x5fe0 "忠" */
+0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24545 0x5fe1 "忡" */
+0x10,0x10,0x10,0x10,0x1b,0x56,0x52,0x52,0x92,0x12,0x13,0x12,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x22,0xfe,0x22,0x20,0x20,0x20,0x20,
+/* 24546 0x5fe2 "忢" */
+0x00,0x7f,0x02,0x02,0x3f,0x04,0x04,0x08,0xff,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24547 0x5fe3 "忣" */
+0x10,0x13,0x10,0x10,0x18,0x54,0x50,0x50,0x91,0x11,0x11,0x11,0x12,0x12,0x14,0x11,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 24548 0x5fe4 "忤" */
+0x10,0x10,0x10,0x11,0x19,0x56,0x50,0x50,0x93,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 24549 0x5fe5 "忥" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x08,0x04,0x14,0x50,0x51,0x51,0x8f,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x90,0x50,0x4a,0x4a,0x06,0x02,
+/* 24550 0x5fe6 "忦" */
+0x10,0x10,0x10,0x18,0x55,0x52,0x54,0x91,0x11,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 24551 0x5fe7 "忧" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x10,0x11,0x11,0x11,0x12,0x12,0x14,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 24552 0x5fe8 "忨" */
+0x10,0x10,0x13,0x18,0x54,0x50,0x57,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 24553 0x5fe9 "忩" */
+0x04,0x04,0x08,0x10,0x22,0xc4,0x08,0x1f,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x40,0x40,0x20,0x10,0x08,0x46,0x20,0xf0,0x10,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24554 0x5fea "忪" */
+0x10,0x11,0x11,0x19,0x55,0x52,0x52,0x94,0x18,0x10,0x11,0x11,0x12,0x17,0x12,0x10,
+0x20,0x20,0x20,0x10,0x10,0x48,0x48,0x44,0x82,0x80,0x10,0x08,0x08,0xfc,0x04,0x00,
+/* 24555 0x5feb "快" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x50,0x97,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 24556 0x5fec "忬" */
+0x10,0x13,0x10,0x19,0x54,0x50,0x57,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x11,0x10,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xfe,0x42,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 24557 0x5fed "忭" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0x20,0x00,0xfe,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,
+/* 24558 0x5fee "忮" */
+0x10,0x10,0x10,0x17,0x18,0x54,0x50,0x57,0x92,0x12,0x11,0x10,0x10,0x10,0x11,0x16,
+0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 24559 0x5fef "忯" */
+0x10,0x10,0x13,0x12,0x1a,0x56,0x52,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x06,0x02,
+/* 24560 0x5ff0 "忰" */
+0x10,0x10,0x13,0x18,0x54,0x51,0x51,0x92,0x14,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0xf0,0x90,0x90,0x12,0x12,0x4e,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 24561 0x5ff1 "忱" */
+0x10,0x10,0x10,0x13,0x1a,0x54,0x50,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0xfc,0x44,0x48,0x40,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 24562 0x5ff2 "忲" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x10,0x11,0x11,0x12,0x12,0x14,0x18,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x88,0x48,0x44,0x02,
+/* 24563 0x5ff3 "忳" */
+0x10,0x10,0x10,0x13,0x18,0x55,0x51,0x51,0x91,0x11,0x10,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 24564 0x5ff4 "忴" */
+0x10,0x10,0x10,0x18,0x55,0x52,0x54,0x90,0x10,0x13,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x88,0x46,0x40,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,
+/* 24565 0x5ff5 "念" */
+0x01,0x01,0x02,0x04,0x0a,0x31,0xc1,0x0f,0x00,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0x80,0x40,0x20,0x18,0x06,0xe0,0x40,0x80,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24566 0x5ff6 "忶" */
+0x10,0x10,0x11,0x18,0x54,0x50,0x53,0x90,0x10,0x10,0x10,0x10,0x11,0x13,0x11,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 24567 0x5ff7 "忷" */
+0x10,0x10,0x11,0x10,0x1a,0x56,0x52,0x52,0x92,0x12,0x13,0x12,0x12,0x13,0x10,0x10,
+0x00,0x08,0x08,0x88,0x52,0x52,0x22,0x22,0x52,0x92,0x0a,0x0a,0x02,0xfe,0x02,0x00,
+/* 24568 0x5ff8 "忸" */
+0x10,0x13,0x10,0x10,0x18,0x54,0x50,0x57,0x91,0x11,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 24569 0x5ff9 "忹" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x50,0x91,0x10,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24570 0x5ffa "忺" */
+0x10,0x10,0x10,0x10,0x19,0x55,0x52,0x54,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 24571 0x5ffb "忻" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 24572 0x5ffc "忼" */
+0x10,0x10,0x10,0x17,0x18,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 24573 0x5ffd "忽" */
+0x08,0x08,0x1f,0x12,0x22,0x44,0x08,0x11,0x22,0x04,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xf8,0x48,0x48,0x88,0x88,0x08,0x28,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24574 0x5ffe "忾" */
+0x11,0x11,0x11,0x1a,0x54,0x51,0x50,0x90,0x13,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 24575 0x5fff "忿" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24576 0x6000 "怀" */
+0x10,0x10,0x17,0x10,0x18,0x54,0x50,0x50,0x91,0x12,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x42,0x40,0x40,0x40,0x40,0x40,
+/* 24577 0x6001 "态" */
+0x01,0x01,0x7f,0x01,0x02,0x04,0x0a,0x31,0xc0,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfc,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24578 0x6002 "怂" */
+0x08,0x08,0x08,0x08,0x14,0x12,0x22,0x20,0x41,0x82,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x02,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24579 0x6003 "怃" */
+0x10,0x13,0x10,0x18,0x54,0x50,0x57,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 24580 0x6004 "怄" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x13,0x10,
+0x00,0xfc,0x00,0x08,0x88,0x50,0x50,0x20,0x20,0x50,0x50,0x88,0x08,0x00,0xfe,0x00,
+/* 24581 0x6005 "怅" */
+0x11,0x11,0x11,0x11,0x19,0x55,0x51,0x57,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0x08,0x08,0x10,0x20,0x40,0x00,0xfe,0x40,0x20,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 24582 0x6006 "怆" */
+0x10,0x10,0x10,0x18,0x55,0x52,0x54,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 24583 0x6007 "怇" */
+0x10,0x13,0x12,0x12,0x1a,0x57,0x52,0x52,0x92,0x12,0x13,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 24584 0x6008 "怈" */
+0x10,0x12,0x12,0x12,0x1a,0x57,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x10,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 24585 0x6009 "怉" */
+0x10,0x10,0x11,0x11,0x1a,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 24586 0x600a "怊" */
+0x10,0x13,0x10,0x10,0x18,0x55,0x51,0x52,0x94,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24587 0x600b "怋" */
+0x10,0x13,0x12,0x12,0x1a,0x57,0x52,0x52,0x93,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 24588 0x600c "怌" */
+0x10,0x13,0x10,0x10,0x18,0x54,0x50,0x51,0x92,0x14,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 24589 0x600d "怍" */
+0x10,0x10,0x10,0x18,0x55,0x51,0x52,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 24590 0x600e "怎" */
+0x08,0x08,0x0f,0x14,0x24,0x47,0x04,0x04,0x07,0x04,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0x00,0xf8,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24591 0x600f "怏" */
+0x10,0x10,0x10,0x13,0x1a,0x56,0x52,0x52,0x92,0x17,0x10,0x10,0x10,0x11,0x12,0x14,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 24592 0x6010 "怐" */
+0x10,0x10,0x11,0x11,0x1a,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x10,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 24593 0x6011 "怑" */
+0x20,0x22,0x21,0x31,0xa8,0xa7,0xa0,0xa0,0x20,0x2f,0x20,0x20,0x20,0x20,0x20,0x20,
+0x40,0x44,0x48,0x50,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 24594 0x6012 "怒" */
+0x10,0x10,0xfe,0x22,0x44,0x28,0x10,0x28,0xc5,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfc,0x84,0x88,0x50,0x20,0x58,0x86,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24595 0x6013 "怓" */
+0x21,0x21,0x21,0x21,0x37,0xaa,0xa2,0xa2,0xa2,0x24,0x22,0x21,0x22,0x24,0x28,0x20,
+0x00,0x00,0x3e,0x12,0xd2,0x52,0x52,0x54,0x54,0x94,0x88,0x08,0x94,0xa4,0x42,0x80,
+/* 24596 0x6014 "怔" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24597 0x6015 "怕" */
+0x10,0x10,0x10,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24598 0x6016 "怖" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x51,0x93,0x15,0x11,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 24599 0x6017 "怗" */
+0x10,0x10,0x10,0x18,0x54,0x50,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24600 0x6018 "怘" */
+0x01,0x01,0x7f,0x01,0x01,0x1f,0x10,0x10,0x1f,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24601 0x6019 "怙" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24602 0x601a "怚" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 24603 0x601b "怛" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x10,0x10,0x13,0x10,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 24604 0x601c "怜" */
+0x10,0x10,0x10,0x18,0x55,0x52,0x54,0x90,0x13,0x10,0x10,0x11,0x10,0x10,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 24605 0x601d "思" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24606 0x601e "怞" */
+0x10,0x10,0x10,0x10,0x1b,0x56,0x52,0x52,0x92,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0xfe,0x22,0x22,0x22,0x22,0xfe,0x02,
+/* 24607 0x601f "怟" */
+0x10,0x10,0x13,0x12,0x1a,0x56,0x52,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 24608 0x6020 "怠" */
+0x02,0x04,0x08,0x10,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0x20,0x10,0xf8,0x08,0xf0,0x10,0x10,0xf0,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24609 0x6021 "怡" */
+0x10,0x10,0x10,0x18,0x54,0x51,0x53,0x90,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24610 0x6022 "怢" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x52,0x50,0x93,0x10,0x10,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 24611 0x6023 "怣" */
+0x09,0x09,0x1f,0x21,0x01,0x7f,0x02,0x04,0x08,0x30,0xc1,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xf0,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x84,0x92,0x12,0xf0,0x00,
+/* 24612 0x6024 "怤" */
+0x08,0x08,0x17,0x30,0x52,0x91,0x11,0x10,0x10,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24613 0x6025 "急" */
+0x08,0x0f,0x10,0x20,0x5f,0x00,0x00,0x1f,0x00,0x00,0x3f,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x04,0x12,0x12,0xf0,
+/* 24614 0x6026 "怦" */
+0x10,0x13,0x10,0x10,0x1a,0x55,0x51,0x50,0x97,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 24615 0x6027 "性" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x52,0x50,0x90,0x11,0x10,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24616 0x6028 "怨" */
+0x10,0x10,0x3e,0x42,0xa2,0x14,0x08,0x10,0x20,0xc0,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x88,0x88,0xa8,0x90,0x84,0x84,0x7c,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24617 0x6029 "怩" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 24618 0x602a "怪" */
+0x10,0x17,0x12,0x11,0x18,0x54,0x50,0x53,0x9c,0x10,0x17,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x46,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 24619 0x602b "怫" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x53,0x52,0x92,0x13,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 24620 0x602c "怬" */
+0x10,0x10,0x13,0x12,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0x00,0xfe,0x52,0x52,0x52,0x52,0x52,0x52,0x92,0x8e,0x02,0x02,0x02,0xfe,0x02,
+/* 24621 0x602d "怭" */
+0x10,0x10,0x10,0x10,0x18,0x54,0x50,0x52,0x92,0x12,0x14,0x10,0x11,0x12,0x14,0x10,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 24622 0x602e "怮" */
+0x22,0x22,0x22,0x34,0xad,0xa9,0xae,0xa2,0x24,0x24,0x29,0x2f,0x21,0x20,0x20,0x21,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 24623 0x602f "怯" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x97,0x10,0x10,0x10,0x11,0x12,0x17,0x12,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x80,0x80,0x10,0x08,0xfc,0x04,
+/* 24624 0x6030 "怰" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x51,0x93,0x10,0x10,0x10,0x11,0x13,0x11,0x10,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x88,0x08,0xf0,0x20,0x40,0x88,0x04,0xfc,0x04,0x00,
+/* 24625 0x6031 "怱" */
+0x08,0x08,0x1f,0x12,0x2a,0x44,0x0a,0x11,0x22,0x04,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xf8,0x48,0x48,0x88,0x88,0x08,0xa8,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24626 0x6032 "怲" */
+0x10,0x13,0x10,0x10,0x18,0x57,0x52,0x52,0x92,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 24627 0x6033 "怳" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x53,0x50,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,0x00,
+/* 24628 0x6034 "怴" */
+0x10,0x10,0x10,0x10,0x1b,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x10,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 24629 0x6035 "怵" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x10,0x11,0x12,0x14,0x10,0x10,0x10,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 24630 0x6036 "怶" */
+0x10,0x10,0x10,0x13,0x1a,0x56,0x52,0x53,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x19,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 24631 0x6037 "怷" */
+0x01,0x01,0x01,0xff,0x01,0x11,0x11,0x11,0x21,0xc0,0x01,0x08,0x48,0x48,0x87,0x00,
+0x10,0x08,0x00,0xfe,0x00,0x10,0x10,0x10,0x10,0x0e,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24632 0x6038 "怸" */
+0x01,0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x10,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24633 0x6039 "怹" */
+0x10,0x10,0x22,0x22,0x63,0xae,0x22,0x22,0x22,0x22,0x21,0x02,0x51,0x51,0x90,0x0f,
+0x40,0x40,0x40,0x78,0xc8,0x48,0x68,0x52,0x42,0x02,0xfe,0x00,0x04,0x12,0x12,0xf0,
+/* 24634 0x603a "怺" */
+0x10,0x10,0x10,0x19,0x54,0x50,0x53,0x90,0x10,0x10,0x11,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 24635 0x603b "总" */
+0x10,0x08,0x04,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x10,0x20,0x40,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24636 0x603c "怼" */
+0x00,0x00,0x7e,0x02,0x24,0x14,0x08,0x14,0x22,0x40,0x01,0x08,0x48,0x48,0x87,0x00,
+0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24637 0x603d "怽" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x57,0x90,0x11,0x11,0x12,0x14,0x18,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 24638 0x603e "怾" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x10,0x10,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 24639 0x603f "怿" */
+0x10,0x17,0x12,0x11,0x18,0x54,0x51,0x56,0x90,0x13,0x10,0x10,0x17,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,
+/* 24640 0x6040 "恀" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x50,0x51,0x96,0x10,0x10,0x13,0x10,0x10,0x10,0x17,
+0x40,0x40,0xfc,0x08,0x90,0x60,0x48,0x90,0x3e,0x42,0x84,0x48,0x30,0x20,0xc0,0x00,
+/* 24641 0x6041 "恁" */
+0x08,0x0b,0x10,0x30,0x57,0x90,0x10,0x10,0x13,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x38,0xc0,0x40,0x40,0xfc,0x40,0x40,0x40,0xf8,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24642 0x6042 "恂" */
+0x10,0x10,0x11,0x11,0x1a,0x54,0x53,0x52,0x92,0x13,0x12,0x12,0x13,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 24643 0x6043 "恃" */
+0x10,0x10,0x10,0x1b,0x54,0x50,0x57,0x90,0x10,0x17,0x10,0x12,0x11,0x11,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 24644 0x6044 "恄" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x50,0x90,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24645 0x6045 "恅" */
+0x10,0x10,0x10,0x19,0x54,0x50,0x53,0x90,0x10,0x11,0x12,0x14,0x10,0x10,0x10,0x10,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 24646 0x6046 "恆" */
+0x10,0x17,0x10,0x10,0x18,0x54,0x51,0x51,0x91,0x12,0x12,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x80,0x80,0x80,0xf8,0x08,0x48,0x28,0x08,0x88,0x50,0x10,0x10,0xfe,0x00,
+/* 24647 0x6047 "恇" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x52,0x92,0x12,0x12,0x13,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 24648 0x6048 "恈" */
+0x10,0x10,0x10,0x11,0x1b,0x54,0x51,0x51,0x91,0x12,0x10,0x17,0x10,0x10,0x10,0x10,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24649 0x6049 "恉" */
+0x11,0x11,0x11,0x11,0x19,0x55,0x50,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0x04,0x38,0xc0,0x02,0x02,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 24650 0x604a "恊" */
+0x20,0x20,0x23,0x30,0xa8,0xa1,0xa2,0xa0,0x24,0x2f,0x24,0x24,0x24,0x28,0x2a,0x31,
+0x40,0x40,0xfc,0x84,0x84,0x14,0x08,0x10,0x10,0xbe,0x92,0x92,0x92,0xa2,0xaa,0x44,
+/* 24651 0x604b "恋" */
+0x02,0x01,0xff,0x04,0x14,0x14,0x24,0x44,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x44,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24652 0x604c "恌" */
+0x10,0x10,0x10,0x12,0x19,0x54,0x50,0x51,0x92,0x14,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 24653 0x604d "恍" */
+0x10,0x10,0x12,0x19,0x55,0x50,0x57,0x90,0x10,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 24654 0x604e "恎" */
+0x10,0x13,0x10,0x10,0x18,0x55,0x53,0x50,0x90,0x10,0x13,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 24655 0x604f "恏" */
+0x10,0x10,0xfe,0x22,0x22,0x64,0x14,0x08,0x34,0xc2,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xfc,0x04,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24656 0x6050 "恐" */
+0x00,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x44,0x08,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xf0,0x10,0x10,0x90,0x50,0x12,0x12,0x0e,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24657 0x6051 "恑" */
+0x10,0x10,0x10,0x11,0x1a,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 24658 0x6052 "恒" */
+0x10,0x13,0x10,0x10,0x19,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 24659 0x6053 "恓" */
+0x10,0x17,0x10,0x18,0x54,0x53,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 24660 0x6054 "恔" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x52,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 24661 0x6055 "恕" */
+0x10,0x10,0xfe,0x22,0x44,0x34,0x08,0x14,0x22,0xc0,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24662 0x6056 "恖" */
+0x02,0x04,0x3f,0x24,0x22,0x21,0x22,0x24,0x3f,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xf8,0x48,0x88,0x08,0x88,0x48,0xf8,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24663 0x6057 "恗" */
+0x10,0x10,0x13,0x10,0x18,0x55,0x52,0x50,0x93,0x10,0x10,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 24664 0x6058 "恘" */
+0x10,0x10,0x10,0x19,0x55,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 24665 0x6059 "恙" */
+0x08,0x04,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24666 0x605a "恚" */
+0x01,0x3f,0x01,0x01,0xff,0x00,0x01,0x3f,0x01,0x01,0xff,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x04,0x12,0x12,0xf0,
+/* 24667 0x605b "恛" */
+0x10,0x10,0x13,0x12,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x13,0x12,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0xfc,0x04,0x00,
+/* 24668 0x605c "恜" */
+0x10,0x10,0x10,0x18,0x57,0x50,0x50,0x97,0x11,0x11,0x11,0x11,0x11,0x17,0x12,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xe0,0x20,0x10,0x10,0x10,0xca,0x0a,0x06,0x02,
+/* 24669 0x605d "恝" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x08,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0x7c,0x24,0x24,0x24,0x44,0x54,0x88,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24670 0x605e "恞" */
+0x10,0x10,0x17,0x10,0x1b,0x54,0x53,0x52,0x93,0x10,0x10,0x10,0x10,0x11,0x12,0x14,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xa8,0xa0,0x10,0x08,0x06,
+/* 24671 0x605f "恟" */
+0x11,0x11,0x11,0x19,0x56,0x52,0x55,0x98,0x12,0x12,0x13,0x12,0x13,0x10,0x10,0x10,
+0x00,0x00,0x00,0xfe,0x02,0x02,0x12,0xa2,0x4a,0xaa,0x1a,0x0a,0xfa,0x02,0x14,0x08,
+/* 24672 0x6060 "恠" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x51,0x93,0x15,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 24673 0x6061 "恡" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x50,0x57,0x90,0x10,0x11,0x11,0x12,0x14,0x19,0x10,
+0x08,0x90,0x60,0x98,0x04,0x40,0x40,0xfe,0x80,0x90,0x10,0x20,0x48,0x84,0xfc,0x84,
+/* 24674 0x6062 "恢" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x50,0x51,0x91,0x11,0x12,0x12,0x14,0x10,0x10,0x11,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x90,0x12,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 24675 0x6063 "恣" */
+0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24676 0x6064 "恤" */
+0x10,0x10,0x10,0x11,0x1b,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x17,0x10,
+0x40,0x40,0x80,0x00,0xfc,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 24677 0x6065 "恥" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3d,0x25,0x25,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x00,0x20,0x10,0x10,0x00,0x40,0x40,0x44,0x42,0x42,0x42,0x48,0x48,0x48,0x38,0x00,
+/* 24678 0x6066 "恦" */
+0x10,0x10,0x10,0x13,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 24679 0x6067 "恧" */
+0x00,0xff,0x02,0x04,0x3f,0x24,0x24,0x24,0x24,0x20,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xa8,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24680 0x6068 "恨" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 24681 0x6069 "恩" */
+0x00,0x3f,0x21,0x21,0x2f,0x21,0x22,0x24,0x28,0x3f,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x08,0x08,0xe8,0x08,0x88,0x48,0x28,0xf8,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24682 0x606a "恪" */
+0x10,0x10,0x10,0x11,0x1b,0x54,0x50,0x50,0x91,0x12,0x15,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 24683 0x606b "恫" */
+0x20,0x27,0x24,0x24,0x35,0xac,0xa4,0xa5,0xa5,0x25,0x25,0x25,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x04,0x14,0x08,
+/* 24684 0x606c "恬" */
+0x10,0x10,0x11,0x10,0x18,0x55,0x50,0x50,0x90,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 24685 0x606d "恭" */
+0x04,0x04,0x3f,0x04,0x04,0xff,0x04,0x08,0x12,0x22,0xc2,0x12,0x12,0x22,0x0a,0x04,
+0x40,0x40,0xf8,0x40,0x40,0xfe,0x40,0x20,0x10,0x08,0x26,0x90,0x48,0x48,0x00,0x00,
+/* 24686 0x606e "恮" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x53,0x50,0x90,0x10,0x13,0x10,0x10,0x10,0x17,0x10,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 24687 0x606f "息" */
+0x01,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24688 0x6070 "恰" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x53,0x50,0x90,0x13,0x12,0x12,0x12,0x12,0x13,0x12,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 24689 0x6071 "恱" */
+0x10,0x10,0x11,0x11,0x1a,0x54,0x51,0x53,0x90,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x94,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 24690 0x6072 "恲" */
+0x11,0x10,0x10,0x10,0x1b,0x54,0x50,0x50,0x90,0x17,0x10,0x10,0x11,0x11,0x12,0x14,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 24691 0x6073 "恳" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x22,0x21,0x2c,0x30,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x1c,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24692 0x6074 "恴" */
+0x02,0x01,0xff,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24693 0x6075 "恵" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24694 0x6076 "恶" */
+0x00,0x7f,0x04,0x24,0x14,0x14,0x04,0xff,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xfc,0x40,0x48,0x48,0x50,0x40,0xfe,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24695 0x6077 "恷" */
+0x08,0x08,0x10,0x37,0x50,0x91,0x11,0x12,0x14,0x18,0x10,0x02,0x51,0x51,0x90,0x0f,
+0x40,0x40,0x40,0xfc,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x00,0x04,0x12,0x12,0xf0,
+/* 24696 0x6078 "恸" */
+0x20,0x20,0x27,0x30,0xa8,0xa0,0xaf,0xa2,0x22,0x24,0x25,0x28,0x2f,0x20,0x20,0x21,
+0x10,0x10,0x90,0x10,0x7e,0x12,0xd2,0x12,0x12,0x22,0x22,0xa2,0xc2,0x42,0x94,0x08,
+/* 24697 0x6079 "恹" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x53,0x52,0x92,0x12,0x12,0x12,0x14,0x14,0x19,0x12,
+0x00,0xfe,0x20,0x28,0x24,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 24698 0x607a "恺" */
+0x10,0x11,0x11,0x11,0x19,0x54,0x51,0x50,0x90,0x11,0x11,0x11,0x11,0x11,0x10,0x10,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 24699 0x607b "恻" */
+0x20,0x27,0x24,0x24,0x35,0xad,0xa5,0xa5,0xa5,0x25,0x25,0x21,0x22,0x22,0x24,0x28,
+0x04,0xc4,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x04,0x84,0x44,0x14,0x08,
+/* 24700 0x607c "恼" */
+0x10,0x10,0x10,0x17,0x18,0x54,0x50,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x10,
+0x40,0x20,0x20,0xfe,0x00,0x00,0x90,0x54,0x24,0x24,0x54,0x94,0x04,0x04,0xfc,0x04,
+/* 24701 0x607d "恽" */
+0x10,0x13,0x12,0x1c,0x54,0x53,0x50,0x90,0x11,0x11,0x10,0x10,0x17,0x10,0x10,0x10,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 24702 0x607e "恾" */
+0x10,0x10,0x17,0x10,0x18,0x54,0x50,0x57,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x10,
+0x90,0x90,0xfe,0x90,0x90,0x40,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 24703 0x607f "恿" */
+0x3f,0x06,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x20,0x01,0x08,0x48,0x48,0x87,0x00,
+0xf0,0x60,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24704 0x6080 "悀" */
+0x10,0x13,0x10,0x18,0x54,0x53,0x52,0x92,0x13,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x08,0xd0,0x20,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x22,0x22,0x2a,0x04,
+/* 24705 0x6081 "悁" */
+0x10,0x11,0x11,0x11,0x19,0x54,0x53,0x52,0x92,0x13,0x12,0x12,0x13,0x12,0x12,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 24706 0x6082 "悂" */
+0x12,0x12,0x12,0x13,0x1a,0x56,0x52,0x53,0x90,0x10,0x13,0x10,0x10,0x10,0x17,0x10,
+0x20,0x24,0x28,0xb0,0x20,0x22,0xa2,0x1e,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 24707 0x6083 "悃" */
+0x20,0x27,0x24,0x24,0x34,0xaf,0xa4,0xa4,0xa4,0x25,0x26,0x24,0x24,0x24,0x27,0x24,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0xc4,0xe4,0x54,0x44,0x44,0x44,0x04,0xfc,0x04,
+/* 24708 0x6084 "悄" */
+0x10,0x11,0x10,0x10,0x18,0x55,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 24709 0x6085 "悅" */
+0x10,0x10,0x10,0x11,0x1a,0x55,0x51,0x51,0x91,0x11,0x10,0x10,0x10,0x11,0x12,0x14,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 24710 0x6086 "悆" */
+0x01,0x02,0x0c,0x30,0xcf,0x01,0x3f,0x11,0x25,0x02,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf8,0x10,0x08,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24711 0x6087 "悇" */
+0x10,0x10,0x10,0x11,0x1a,0x55,0x50,0x50,0x97,0x10,0x12,0x12,0x14,0x18,0x11,0x10,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 24712 0x6088 "悈" */
+0x10,0x10,0x10,0x10,0x1b,0x54,0x51,0x51,0x97,0x11,0x11,0x11,0x12,0x12,0x14,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x50,0x54,0xf4,0x54,0x54,0x48,0x4a,0x5a,0x26,0x42,
+/* 24713 0x6089 "悉" */
+0x00,0x3f,0x11,0x09,0x01,0xff,0x09,0x11,0x21,0xc0,0x01,0x08,0x48,0x48,0x87,0x00,
+0xf8,0x00,0x10,0x20,0x00,0xfe,0x20,0x10,0x08,0x06,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24714 0x608a "悊" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24715 0x608b "悋" */
+0x10,0x10,0x17,0x11,0x18,0x54,0x50,0x51,0x96,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x08,0x90,0x60,0x60,0x98,0x06,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 24716 0x608c "悌" */
+0x11,0x10,0x10,0x13,0x18,0x54,0x53,0x52,0x92,0x13,0x10,0x10,0x11,0x12,0x14,0x10,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 24717 0x608d "悍" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x50,0x50,0x91,0x10,0x10,0x13,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24718 0x608e "悎" */
+0x10,0x11,0x11,0x11,0x1a,0x54,0x50,0x53,0x90,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 24719 0x608f "悏" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x51,0x51,0x91,0x12,0x10,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 24720 0x6090 "悐" */
+0x44,0x28,0x10,0x28,0x48,0x99,0x28,0x48,0x88,0x08,0x51,0x22,0x01,0x48,0x48,0x87,
+0x20,0x20,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x00,0x84,0x12,0xf2,
+/* 24721 0x6091 "悑" */
+0x10,0x10,0x13,0x18,0x54,0x53,0x52,0x92,0x13,0x12,0x12,0x13,0x12,0x12,0x12,0x12,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 24722 0x6092 "悒" */
+0x10,0x11,0x11,0x11,0x19,0x54,0x53,0x52,0x92,0x12,0x13,0x12,0x12,0x12,0x11,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0x44,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 24723 0x6093 "悓" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x92,0x12,0x13,0x11,0x11,0x12,0x14,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 24724 0x6094 "悔" */
+0x11,0x11,0x11,0x1a,0x55,0x51,0x51,0x91,0x17,0x11,0x12,0x12,0x13,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 24725 0x6095 "悕" */
+0x22,0x21,0x20,0x31,0xaa,0xa0,0xaf,0xa1,0x22,0x27,0x2a,0x22,0x22,0x22,0x20,0x20,
+0x08,0x10,0xe0,0x10,0x08,0x80,0xfe,0x40,0x40,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 24726 0x6096 "悖" */
+0x10,0x10,0x13,0x18,0x54,0x53,0x52,0x94,0x11,0x10,0x10,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 24727 0x6097 "悗" */
+0x10,0x10,0x11,0x1a,0x54,0x53,0x52,0x92,0x12,0x13,0x10,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x44,0x44,0x44,0xfc,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 24728 0x6098 "悘" */
+0x00,0x3f,0x24,0x27,0x28,0x3f,0x21,0x22,0x24,0x3f,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x00,0xf0,0x80,0xfc,0x40,0x20,0x10,0xfc,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24729 0x6099 "悙" */
+0x10,0x10,0x13,0x10,0x19,0x55,0x51,0x51,0x90,0x13,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x08,0x30,0x20,0x20,0xa0,0x40,
+/* 24730 0x609a "悚" */
+0x10,0x10,0x13,0x10,0x18,0x55,0x51,0x51,0x91,0x10,0x10,0x10,0x11,0x12,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 24731 0x609b "悛" */
+0x10,0x10,0x10,0x11,0x1b,0x54,0x50,0x51,0x92,0x10,0x11,0x12,0x10,0x10,0x11,0x16,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 24732 0x609c "悜" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x50,0x50,0x93,0x10,0x10,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 24733 0x609d "悝" */
+0x20,0x27,0x24,0x24,0x37,0xac,0xa4,0xa7,0xa0,0x20,0x27,0x20,0x20,0x20,0x2f,0x20,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 24734 0x609e "悞" */
+0x10,0x10,0x10,0x10,0x1a,0x56,0x52,0x53,0x90,0x10,0x17,0x10,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0x00,0xfc,0x44,0x44,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 24735 0x609f "悟" */
+0x10,0x13,0x10,0x10,0x19,0x54,0x50,0x53,0x90,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 24736 0x60a0 "悠" */
+0x10,0x10,0x24,0x64,0xa5,0x24,0x24,0x20,0x20,0x23,0x01,0x08,0x48,0x48,0x87,0x00,
+0x40,0x40,0x7e,0x88,0x48,0x50,0x20,0x58,0x86,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24737 0x60a1 "悡" */
+0x06,0x78,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x01,0x08,0x48,0x48,0x87,0x00,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x04,0x14,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24738 0x60a2 "悢" */
+0x10,0x10,0x13,0x12,0x1a,0x57,0x52,0x52,0x93,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x80,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 24739 0x60a3 "患" */
+0x01,0x1f,0x11,0x11,0x1f,0x01,0x3f,0x21,0x21,0x3f,0x01,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0x04,0x12,0x12,0xf0,
+/* 24740 0x60a4 "悤" */
+0x02,0x04,0x3f,0x22,0x23,0x24,0x2a,0x21,0x22,0x24,0x3f,0x20,0x01,0x48,0x48,0x87,
+0x00,0x00,0xf8,0x08,0xc8,0x48,0x88,0x08,0x88,0x08,0xf8,0x08,0x00,0x84,0x12,0xf2,
+/* 24741 0x60a5 "悥" */
+0x02,0x01,0xff,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x02,0x51,0x51,0x90,0x0f,
+0x00,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x04,0x12,0x12,0xf0,
+/* 24742 0x60a6 "悦" */
+0x12,0x11,0x11,0x10,0x1b,0x56,0x52,0x52,0x93,0x10,0x10,0x11,0x11,0x12,0x14,0x18,
+0x08,0x08,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 24743 0x60a7 "悧" */
+0x10,0x11,0x17,0x11,0x19,0x55,0x57,0x51,0x93,0x13,0x15,0x15,0x19,0x11,0x11,0x11,
+0x84,0xc4,0x04,0x14,0x14,0x14,0xd4,0x14,0x14,0x94,0x54,0x04,0x04,0x04,0x14,0x08,
+/* 24744 0x60a8 "您" */
+0x09,0x09,0x11,0x32,0x54,0x99,0x11,0x12,0x14,0x11,0x10,0x02,0x51,0x51,0x90,0x0f,
+0x00,0x00,0xfc,0x04,0x48,0x50,0x48,0x44,0x44,0x40,0x80,0x00,0x04,0x12,0x12,0xf0,
+/* 24745 0x60a9 "悩" */
+0x10,0x12,0x11,0x11,0x18,0x54,0x52,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x13,0x10,
+0x42,0x22,0x24,0x04,0x08,0x00,0x0a,0x8a,0x52,0x22,0x52,0x8a,0x0a,0x02,0xfe,0x02,
+/* 24746 0x60aa "悪" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x04,0xff,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x40,0xfe,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24747 0x60ab "悫" */
+0x01,0x7f,0x01,0x3f,0x00,0x7f,0x40,0x8f,0x08,0x10,0x20,0xc1,0x28,0x28,0x48,0x07,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x02,0xe4,0x20,0x22,0x22,0x1e,0x88,0xa4,0x24,0xe0,
+/* 24748 0x60ac "悬" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x10,0x3f,0x10,0x01,0x28,0x28,0x48,0x07,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x10,0xf8,0x08,0x00,0x88,0xa4,0x24,0xe0,
+/* 24749 0x60ad "悭" */
+0x10,0x12,0x12,0x12,0x1a,0x56,0x52,0x50,0x90,0x10,0x11,0x10,0x10,0x10,0x13,0x10,
+0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 24750 0x60ae "悮" */
+0x20,0x23,0x22,0x22,0x33,0xa8,0xa0,0xa7,0xa0,0x20,0x2f,0x20,0x20,0x21,0x22,0x2c,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 24751 0x60af "悯" */
+0x11,0x10,0x12,0x12,0x1a,0x56,0x53,0x52,0x92,0x12,0x12,0x12,0x13,0x12,0x12,0x12,
+0x00,0xbe,0x82,0x02,0x42,0x22,0xfe,0x92,0x52,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 24752 0x60b0 "悰" */
+0x10,0x10,0x13,0x12,0x18,0x55,0x50,0x50,0x93,0x10,0x11,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 24753 0x60b1 "悱" */
+0x10,0x10,0x10,0x17,0x18,0x54,0x50,0x53,0x90,0x10,0x10,0x17,0x10,0x10,0x10,0x10,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 24754 0x60b2 "悲" */
+0x04,0x04,0x7c,0x04,0x04,0x3c,0x04,0x04,0x7c,0x04,0x01,0x08,0x48,0x48,0x87,0x00,
+0x40,0x40,0x7c,0x40,0x40,0x78,0x40,0x40,0x7c,0x40,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24755 0x60b3 "悳" */
+0x00,0x3f,0x00,0x07,0x24,0x27,0x24,0x27,0x24,0x27,0x20,0x3f,0x01,0x48,0x48,0x87,
+0x80,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x84,0x12,0xf2,
+/* 24756 0x60b4 "悴" */
+0x10,0x10,0x13,0x18,0x55,0x51,0x52,0x94,0x10,0x10,0x17,0x10,0x10,0x10,0x10,0x10,
+0x80,0x40,0xfc,0x00,0x10,0x10,0xa8,0x44,0x00,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 24757 0x60b5 "悵" */
+0x10,0x10,0x10,0x18,0x54,0x50,0x50,0x97,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 24758 0x60b6 "悶" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x45,0x54,0x54,0x64,0x43,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x04,0x24,0x54,0x54,0xc4,0x04,0x14,0x08,
+/* 24759 0x60b7 "悷" */
+0x10,0x10,0x13,0x12,0x1a,0x57,0x52,0x52,0x92,0x13,0x12,0x12,0x12,0x14,0x15,0x1a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 24760 0x60b8 "悸" */
+0x20,0x23,0x20,0x27,0x30,0xa9,0xa2,0xac,0xa3,0x20,0x20,0x27,0x20,0x20,0x21,0x20,
+0x38,0xc0,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf0,0x20,0x40,0xfc,0x40,0x40,0x40,0x80,
+/* 24761 0x60b9 "悹" */
+0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xfe,0x02,0xe4,0x20,0xe0,0x00,0xf0,0x10,0x10,0xf0,0x00,0x04,0x12,0x12,0xf0,
+/* 24762 0x60ba "悺" */
+0x10,0x10,0x13,0x1a,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 24763 0x60bb "悻" */
+0x10,0x10,0x13,0x10,0x18,0x57,0x50,0x50,0x93,0x10,0x10,0x17,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x88,0x50,0xfe,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 24764 0x60bc "悼" */
+0x10,0x10,0x10,0x10,0x1b,0x56,0x53,0x52,0x93,0x12,0x10,0x17,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 24765 0x60bd "悽" */
+0x10,0x10,0x17,0x10,0x1b,0x54,0x57,0x50,0x93,0x10,0x17,0x11,0x13,0x10,0x11,0x16,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x80,0xfe,0x08,0x90,0x60,0x98,0x04,
+/* 24766 0x60be "悾" */
+0x10,0x10,0x10,0x13,0x1a,0x54,0x51,0x52,0x90,0x11,0x10,0x10,0x10,0x10,0x17,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 24767 0x60bf "悿" */
+0x10,0x13,0x10,0x10,0x1b,0x54,0x51,0x52,0x94,0x10,0x10,0x12,0x12,0x14,0x11,0x10,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 24768 0x60c0 "惀" */
+0x20,0x20,0x20,0x31,0xaa,0xad,0xa0,0xa7,0x24,0x24,0x27,0x24,0x24,0x24,0x24,0x24,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 24769 0x60c1 "惁" */
+0x08,0x08,0x7e,0x18,0x2c,0x2a,0x48,0x88,0x09,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24770 0x60c2 "惂" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x50,0x53,0x92,0x12,0x13,0x12,0x12,0x12,0x13,0x12,
+0x80,0x80,0xf8,0x08,0x10,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 24771 0x60c3 "惃" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x90,0x12,0x12,0x13,0x12,0x12,0x12,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x20,0x24,0xa8,0x30,0x22,0xa2,0x1e,
+/* 24772 0x60c4 "惄" */
+0x08,0x0f,0x08,0x08,0xff,0x08,0x2a,0x49,0x89,0x28,0x10,0x02,0x51,0x51,0x90,0x0f,
+0x00,0x7c,0x44,0x44,0x48,0x28,0x30,0x10,0x28,0x44,0x82,0x00,0x04,0x12,0x12,0xf0,
+/* 24773 0x60c5 "情" */
+0x10,0x10,0x13,0x10,0x51,0x58,0x57,0x94,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x0c,
+/* 24774 0x60c6 "惆" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x52,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x14,
+0x00,0xfe,0x22,0x22,0xfa,0x22,0x22,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 24775 0x60c7 "惇" */
+0x10,0x10,0x13,0x10,0x19,0x55,0x51,0x50,0x91,0x10,0x10,0x13,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 24776 0x60c8 "惈" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x90,0x17,0x10,0x11,0x12,0x14,0x10,0x10,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 24777 0x60c9 "惉" */
+0x10,0x08,0x40,0x20,0x08,0x13,0x72,0x12,0x13,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x40,0x40,0x7e,0x40,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24778 0x60ca "惊" */
+0x10,0x10,0x13,0x10,0x18,0x55,0x51,0x51,0x91,0x10,0x11,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 24779 0x60cb "惋" */
+0x10,0x10,0x13,0x12,0x1d,0x55,0x51,0x52,0x92,0x13,0x14,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 24780 0x60cc "惌" */
+0x02,0x01,0x7f,0x40,0x90,0x1e,0x22,0x24,0x54,0x08,0x10,0x60,0x01,0x48,0x48,0x87,
+0x00,0x00,0xfe,0x02,0x04,0xf8,0x88,0xa8,0x90,0x84,0x84,0x7c,0x00,0x84,0x12,0xf2,
+/* 24781 0x60cd "惍" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x51,0x50,0x90,0x13,0x10,0x12,0x11,0x11,0x17,0x10,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x40,0x40,0xf8,0x40,0x48,0x48,0x50,0xfc,0x00,
+/* 24782 0x60ce "惎" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x10,0x22,0xc1,0x09,0x28,0x28,0x47,0x00,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0x08,0x06,0x00,0x28,0x24,0xe4,0x00,
+/* 24783 0x60cf "惏" */
+0x21,0x21,0x21,0x21,0x37,0xa9,0xa1,0xa3,0xa3,0x25,0x25,0x29,0x21,0x21,0x21,0x21,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 24784 0x60d0 "惐" */
+0x10,0x10,0x10,0x17,0x18,0x54,0x53,0x52,0x92,0x12,0x13,0x10,0x10,0x17,0x12,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 24785 0x60d1 "惑" */
+0x00,0x00,0xff,0x00,0x3e,0x22,0x3e,0x00,0x0e,0x70,0x03,0x01,0x28,0x28,0x48,0x07,
+0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x02,0x00,0x88,0xa4,0x24,0xe0,
+/* 24786 0x60d2 "惒" */
+0x06,0x78,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24787 0x60d3 "惓" */
+0x10,0x11,0x10,0x1b,0x54,0x50,0x57,0x91,0x12,0x15,0x19,0x11,0x11,0x11,0x11,0x10,
+0x20,0x24,0xa8,0xfe,0x40,0x80,0xfe,0x08,0x04,0xfa,0x08,0x08,0x28,0x12,0x02,0xfe,
+/* 24788 0x60d4 "惔" */
+0x10,0x12,0x12,0x14,0x18,0x55,0x56,0x50,0x90,0x12,0x12,0x14,0x10,0x11,0x12,0x1c,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 24789 0x60d5 "惕" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x50,0x50,0x91,0x12,0x14,0x10,0x11,0x12,0x10,0x11,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0x80,0xfe,0x4a,0x4a,0x92,0x22,0x42,0x94,0x08,
+/* 24790 0x60d6 "惖" */
+0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x22,0x44,0x09,0x12,0x24,0x01,0x48,0x48,0x87,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x48,0x88,0x08,0x28,0x10,0x00,0x84,0x12,0xf2,
+/* 24791 0x60d7 "惗" */
+0x20,0x20,0x20,0x31,0xaa,0xa4,0xa8,0xa3,0x20,0x20,0x20,0x21,0x25,0x25,0x29,0x20,
+0x40,0x40,0xa0,0x10,0x88,0x46,0x00,0xf0,0x10,0x20,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 24792 0x60d8 "惘" */
+0x10,0x13,0x12,0x12,0x1a,0x57,0x52,0x52,0x93,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 24793 0x60d9 "惙" */
+0x20,0x27,0x20,0x22,0x31,0xaa,0xa4,0xa8,0xa0,0x27,0x20,0x22,0x21,0x22,0x24,0x28,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 24794 0x60da "惚" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x51,0x52,0x90,0x11,0x10,0x10,0x12,0x12,0x14,0x10,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 24795 0x60db "惛" */
+0x10,0x13,0x12,0x13,0x1a,0x56,0x53,0x52,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 24796 0x60dc "惜" */
+0x10,0x10,0x10,0x13,0x18,0x54,0x57,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 24797 0x60dd "惝" */
+0x10,0x11,0x10,0x10,0x18,0x57,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 24798 0x60de "惞" */
+0x20,0x20,0x27,0x24,0x34,0xac,0xa7,0xa5,0xa5,0x25,0x25,0x25,0x25,0x29,0x29,0x30,
+0x10,0x90,0x10,0x3e,0x22,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 24799 0x60df "惟" */
+0x10,0x10,0x10,0x11,0x19,0x57,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 24800 0x60e0 "惠" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x01,0x28,0x28,0x48,0x07,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x04,0xfe,0x02,0x88,0xa4,0x24,0xe0,
+/* 24801 0x60e1 "惡" */
+0x00,0x7f,0x04,0x3c,0x20,0x20,0x3c,0x04,0xff,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xfc,0x40,0x78,0x08,0x08,0x78,0x40,0xfe,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24802 0x60e2 "惢" */
+0x01,0x00,0x08,0x48,0x48,0x48,0x87,0x00,0x10,0x08,0x22,0xa1,0xa4,0xa4,0x1d,0x00,
+0x00,0x80,0x88,0x04,0x12,0x12,0xf0,0x00,0x10,0x08,0x20,0x24,0xa2,0xa4,0x1c,0x00,
+/* 24803 0x60e3 "惣" */
+0x10,0x50,0x7c,0x51,0x92,0x1c,0xf1,0x12,0x10,0x11,0x01,0x08,0x48,0x48,0x87,0x00,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24804 0x60e4 "惤" */
+0x10,0x13,0x10,0x10,0x18,0x57,0x52,0x52,0x92,0x13,0x10,0x10,0x10,0x10,0x12,0x11,
+0x10,0x88,0x88,0xfe,0x90,0x90,0x24,0x24,0x38,0x88,0x90,0x90,0xa4,0xbe,0x82,0x00,
+/* 24805 0x60e5 "惥" */
+0x01,0x05,0x39,0x21,0x3d,0x21,0x3f,0x02,0x04,0x18,0xe1,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0x78,0x08,0x78,0x08,0xf8,0x80,0x40,0x30,0x0e,0x84,0x92,0x12,0xf0,0x00,
+/* 24806 0x60e6 "惦" */
+0x10,0x10,0x13,0x12,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x18,
+0x40,0x20,0xfe,0x00,0x20,0x20,0x3e,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 24807 0x60e7 "惧" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x53,0x52,0x93,0x12,0x12,0x1f,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,0x10,0x08,0x04,
+/* 24808 0x60e8 "惨" */
+0x20,0x20,0x21,0x33,0xa8,0xa7,0xa1,0xa2,0x2c,0x23,0x20,0x20,0x23,0x20,0x20,0x27,
+0x80,0x90,0x08,0xfc,0x40,0xfe,0x10,0x48,0x86,0x10,0x20,0xc4,0x08,0x30,0xc0,0x00,
+/* 24809 0x60e9 "惩" */
+0x10,0x23,0x40,0x89,0x11,0x31,0x51,0x91,0x17,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xfe,0x20,0x20,0x3c,0x20,0x20,0x20,0xfe,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24810 0x60ea "惪" */
+0x01,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x01,0x48,0x48,0x87,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x00,0x84,0x12,0xf2,
+/* 24811 0x60eb "惫" */
+0x08,0x0f,0x10,0x2c,0x03,0x1c,0xe0,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x48,0x48,0x87,
+0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x84,0x12,0xf2,
+/* 24812 0x60ec "惬" */
+0x20,0x27,0x24,0x24,0x35,0xac,0xa5,0xa4,0xa7,0x24,0x24,0x24,0x24,0x25,0x27,0x20,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x24,0xa8,0xfe,0x20,0x50,0x48,0x84,0x04,0xfe,0x00,
+/* 24813 0x60ed "惭" */
+0x21,0x21,0x21,0x2f,0x32,0xaa,0xa5,0xa7,0xa1,0x21,0x21,0x2f,0x25,0x21,0x21,0x21,
+0x00,0x02,0x1c,0xd0,0x10,0x10,0x1e,0xd4,0x14,0x14,0xd4,0x14,0x14,0x24,0x24,0x44,
+/* 24814 0x60ee "惮" */
+0x11,0x10,0x10,0x11,0x19,0x55,0x51,0x51,0x91,0x11,0x10,0x10,0x13,0x10,0x10,0x10,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 24815 0x60ef "惯" */
+0x11,0x11,0x11,0x13,0x19,0x55,0x51,0x50,0x91,0x11,0x11,0x11,0x11,0x10,0x10,0x13,
+0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x00,0xfc,0x04,0x24,0x24,0x24,0x58,0x84,0x02,
+/* 24816 0x60f0 "惰" */
+0x10,0x10,0x13,0x10,0x19,0x56,0x55,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 24817 0x60f1 "惱" */
+0x10,0x11,0x12,0x11,0x18,0x54,0x50,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 24818 0x60f2 "惲" */
+0x10,0x13,0x12,0x10,0x1b,0x54,0x51,0x51,0x91,0x11,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 24819 0x60f3 "想" */
+0x08,0x08,0x08,0x7e,0x08,0x18,0x1c,0x2a,0x48,0x08,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0xf8,0x88,0x88,0xf8,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24820 0x60f4 "惴" */
+0x20,0x24,0x24,0x34,0xaf,0xa0,0xaf,0xa0,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x24,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x0c,
+/* 24821 0x60f5 "惵" */
+0x10,0x12,0x12,0x17,0x1a,0x56,0x52,0x52,0x93,0x10,0x17,0x10,0x11,0x12,0x1c,0x10,
+0x90,0x90,0x90,0xfe,0x90,0x90,0xf0,0x00,0xfc,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 24822 0x60f6 "惶" */
+0x10,0x10,0x11,0x11,0x19,0x55,0x51,0x50,0x93,0x10,0x10,0x11,0x10,0x10,0x13,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 24823 0x60f7 "惷" */
+0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x1f,0x28,0xcf,0x08,0x0f,0x01,0x48,0x48,0x87,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf0,0x28,0xe6,0x20,0xe0,0x00,0x84,0x12,0xf2,
+/* 24824 0x60f8 "惸" */
+0x11,0x11,0x12,0x15,0x19,0x55,0x51,0x51,0x90,0x13,0x10,0x10,0x17,0x10,0x10,0x10,
+0x00,0xfe,0x02,0xf2,0x12,0xf2,0x12,0xfa,0x04,0xf8,0x10,0x20,0xfe,0x20,0xa0,0x40,
+/* 24825 0x60f9 "惹" */
+0x08,0x7f,0x08,0x02,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0xfc,0x20,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24826 0x60fa "惺" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x50,0x51,0x91,0x12,0x10,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 24827 0x60fb "惻" */
+0x20,0x27,0x24,0x24,0x37,0xac,0xa4,0xa7,0xa4,0x24,0x27,0x20,0x22,0x22,0x24,0x28,
+0x02,0xc2,0x42,0x52,0xd2,0x52,0x52,0xd2,0x52,0x52,0xd2,0x02,0x82,0x42,0x4a,0x04,
+/* 24828 0x60fc "惼" */
+0x10,0x10,0x13,0x12,0x1a,0x57,0x52,0x52,0x93,0x13,0x15,0x15,0x15,0x15,0x19,0x11,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0x52,0x52,0xfe,0x52,0x52,0x52,0x06,
+/* 24829 0x60fd "惽" */
+0x10,0x13,0x12,0x13,0x1a,0x57,0x52,0x52,0x93,0x10,0x13,0x12,0x13,0x12,0x13,0x12,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 24830 0x60fe "惾" */
+0x10,0x10,0x12,0x12,0x1a,0x56,0x52,0x53,0x90,0x11,0x12,0x10,0x11,0x10,0x10,0x17,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 24831 0x60ff "惿" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x51,0x51,0x90,0x13,0x10,0x11,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 24832 0x6100 "愀" */
+0x20,0x21,0x27,0x31,0xa9,0xa1,0xa7,0xa1,0x23,0x23,0x25,0x25,0x29,0x21,0x21,0x21,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 24833 0x6101 "愁" */
+0x0e,0x78,0x08,0x08,0xfe,0x19,0x2c,0x4a,0x88,0x09,0x0a,0x01,0x28,0x28,0x48,0x07,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x50,0x50,0x88,0x04,0x02,0x00,0x88,0xa4,0x24,0xe0,
+/* 24834 0x6102 "愂" */
+0x08,0x7f,0x08,0x7f,0x41,0x3e,0x04,0x0f,0x78,0x08,0x28,0x10,0x01,0x48,0x48,0x87,
+0x10,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,0x00,0x84,0x12,0xf2,
+/* 24835 0x6103 "愃" */
+0x10,0x10,0x13,0x1a,0x54,0x51,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 24836 0x6104 "愄" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x90,0x17,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 24837 0x6105 "愅" */
+0x21,0x21,0x27,0x21,0x31,0xa8,0xa3,0xa2,0xa2,0x23,0x20,0x2f,0x20,0x20,0x20,0x20,
+0x10,0x10,0xfc,0x10,0xf0,0x40,0xf8,0x48,0x48,0xf8,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 24838 0x6106 "愆" */
+0x12,0x21,0x48,0x94,0x21,0x62,0xae,0x22,0x22,0x22,0x21,0x08,0x48,0x48,0x87,0x00,
+0x00,0x3c,0x00,0x00,0x7e,0x08,0x08,0x08,0x28,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24839 0x6107 "愇" */
+0x10,0x10,0x11,0x10,0x1b,0x54,0x51,0x51,0x91,0x10,0x13,0x10,0x12,0x13,0x10,0x10,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 24840 0x6108 "愈" */
+0x01,0x02,0x0c,0x37,0xc0,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,0x01,0x48,0x48,0x87,
+0x00,0x80,0x60,0xd8,0x06,0x08,0x48,0x48,0x48,0x48,0x08,0x18,0x00,0x84,0x12,0xf2,
+/* 24841 0x6109 "愉" */
+0x10,0x10,0x11,0x12,0x1d,0x54,0x53,0x52,0x92,0x13,0x12,0x12,0x13,0x12,0x12,0x12,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 24842 0x610a "愊" */
+0x10,0x13,0x10,0x11,0x19,0x55,0x51,0x50,0x93,0x12,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 24843 0x610b "愋" */
+0x10,0x17,0x12,0x19,0x54,0x53,0x50,0x90,0x17,0x11,0x11,0x12,0x12,0x14,0x18,0x13,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 24844 0x610c "愌" */
+0x10,0x10,0x10,0x11,0x1a,0x55,0x51,0x51,0x91,0x11,0x10,0x13,0x10,0x10,0x11,0x16,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0x54,0x8c,0x24,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 24845 0x610d "愍" */
+0x00,0x7f,0x41,0x7f,0x48,0x7f,0x48,0x45,0x53,0x61,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24846 0x610e "愎" */
+0x11,0x11,0x11,0x1a,0x55,0x51,0x51,0x91,0x11,0x10,0x10,0x11,0x12,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 24847 0x610f "意" */
+0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x04,0x12,0x12,0xf0,
+/* 24848 0x6110 "愐" */
+0x10,0x17,0x10,0x10,0x1b,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 24849 0x6111 "愑" */
+0x10,0x13,0x10,0x10,0x1b,0x56,0x53,0x52,0x93,0x12,0x10,0x13,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x88,0x50,0xfe,0x22,0xfe,0x22,0xfe,0x22,0x40,0xfe,0x42,0x82,0x14,0x08,
+/* 24850 0x6112 "愒" */
+0x10,0x13,0x12,0x1b,0x56,0x53,0x51,0x93,0x14,0x12,0x12,0x12,0x13,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 24851 0x6113 "愓" */
+0x20,0x23,0x22,0x33,0xaa,0xa3,0xa0,0xaf,0x22,0x23,0x24,0x29,0x22,0x24,0x21,0x22,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 24852 0x6114 "愔" */
+0x20,0x20,0x27,0x30,0xaa,0xa1,0xaf,0xa0,0x23,0x22,0x22,0x23,0x22,0x22,0x23,0x22,
+0x80,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 24853 0x6115 "愕" */
+0x20,0x27,0x24,0x24,0x37,0xa8,0xa3,0xa0,0xa7,0x21,0x22,0x23,0x20,0x20,0x20,0x20,
+0x00,0xbc,0xa4,0xa4,0xbc,0x00,0xf8,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 24854 0x6116 "愖" */
+0x11,0x11,0x17,0x11,0x19,0x55,0x51,0x51,0x91,0x17,0x12,0x12,0x13,0x12,0x13,0x10,
+0x10,0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,0x90,0x08,0x00,0xfc,0x00,
+/* 24855 0x6117 "愗" */
+0x00,0x7f,0x12,0x0c,0xff,0x19,0x2a,0x48,0xa8,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24856 0x6118 "愘" */
+0x10,0x10,0x13,0x12,0x18,0x54,0x51,0x52,0x90,0x11,0x16,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 24857 0x6119 "愙" */
+0x02,0x01,0x7f,0x48,0x9f,0x28,0x07,0x18,0xe0,0x1f,0x10,0x1f,0x01,0x48,0x48,0x87,
+0x00,0x00,0xfe,0x02,0xf4,0x20,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x00,0x84,0x12,0xf2,
+/* 24858 0x611a "愚" */
+0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x21,0x21,0x2f,0x24,0x20,0x01,0x48,0x48,0x87,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x48,0xe8,0x28,0x10,0x00,0x84,0x12,0xf2,
+/* 24859 0x611b "愛" */
+0x00,0x3f,0x11,0x08,0x7f,0x41,0x94,0x14,0x23,0x08,0x0f,0x14,0x22,0x41,0x0e,0x70,
+0x7c,0x80,0x08,0x90,0xfe,0x02,0x94,0x28,0xe8,0x00,0xf0,0x20,0x40,0x80,0x60,0x1c,
+/* 24860 0x611c "愜" */
+0x20,0x27,0x24,0x24,0x35,0xac,0xa4,0xa4,0xa5,0x24,0x24,0x24,0x24,0x25,0x27,0x20,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0xa8,0xa8,0x74,0x20,0x50,0x48,0x84,0x00,0xfe,0x00,
+/* 24861 0x611d "愝" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x52,0x52,0x92,0x13,0x12,0x12,0x12,0x12,0x12,0x13,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 24862 0x611e "愞" */
+0x10,0x13,0x10,0x10,0x1b,0x56,0x52,0x52,0x92,0x12,0x10,0x17,0x10,0x10,0x11,0x16,
+0x00,0xfe,0x20,0x40,0xfe,0x52,0x52,0x52,0x42,0x26,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 24863 0x611f "感" */
+0x00,0x00,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x28,0x4f,0x40,0x80,0x01,0x48,0x48,0x87,
+0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x92,0xaa,0x46,0x82,0x00,0x84,0x12,0xf2,
+/* 24864 0x6120 "愠" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x51,0x51,0x90,0x13,0x12,0x12,0x12,0x12,0x17,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 24865 0x6121 "愡" */
+0x10,0x10,0x10,0x11,0x1a,0x54,0x51,0x52,0x90,0x11,0x10,0x10,0x12,0x12,0x14,0x10,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 24866 0x6122 "愢" */
+0x10,0x13,0x12,0x12,0x1b,0x56,0x52,0x53,0x90,0x10,0x10,0x15,0x15,0x19,0x10,0x10,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x40,0x24,0x22,0x0a,0x08,0xf8,0x00,
+/* 24867 0x6123 "愣" */
+0x10,0x13,0x12,0x1a,0x56,0x53,0x50,0x90,0x17,0x10,0x10,0x10,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x94,0x94,0x94,0xfc,0x80,0x40,0xfe,0x80,0xf8,0x88,0x08,0x08,0x28,0x10,
+/* 24868 0x6124 "愤" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x50,0x51,0x91,0x11,0x11,0x11,0x11,0x10,0x10,0x13,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 24869 0x6125 "愥" */
+0x21,0x21,0x27,0x21,0x31,0xa8,0xa3,0xa2,0xa2,0x22,0x2f,0x20,0x20,0x21,0x22,0x24,
+0x10,0x10,0xfc,0x10,0x50,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 24870 0x6126 "愦" */
+0x10,0x10,0x11,0x19,0x55,0x50,0x53,0x90,0x11,0x11,0x11,0x11,0x11,0x10,0x10,0x13,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 24871 0x6127 "愧" */
+0x20,0x20,0x27,0x24,0x34,0xaf,0xa4,0xa4,0xa7,0x20,0x21,0x21,0x22,0x24,0x28,0x30,
+0x40,0x80,0xfc,0x44,0x44,0xfc,0x44,0x84,0xfc,0x80,0x50,0x64,0x7c,0x42,0x42,0x3e,
+/* 24872 0x6128 "愨" */
+0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0x00,0x3e,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0xce,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24873 0x6129 "愩" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x10,0x11,0x12,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 24874 0x612a "愪" */
+0x10,0x11,0x11,0x11,0x19,0x54,0x53,0x52,0x93,0x12,0x13,0x12,0x13,0x10,0x11,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 24875 0x612b "愫" */
+0x10,0x10,0x17,0x10,0x1b,0x54,0x57,0x50,0x91,0x13,0x10,0x17,0x10,0x12,0x15,0x10,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x10,0xe0,0x48,0xfc,0x44,0x48,0x44,0x80,
+/* 24876 0x612c "愬" */
+0x22,0x14,0xff,0x08,0x49,0x49,0x7f,0x08,0x10,0x21,0x41,0x08,0x48,0x48,0x87,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x94,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24877 0x612d "愭" */
+0x10,0x10,0x11,0x10,0x1b,0x54,0x50,0x51,0x92,0x14,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 24878 0x612e "愮" */
+0x10,0x10,0x13,0x10,0x1a,0x55,0x51,0x52,0x90,0x13,0x10,0x11,0x11,0x11,0x11,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 24879 0x612f "愯" */
+0x10,0x10,0x11,0x1b,0x55,0x51,0x51,0x91,0x11,0x11,0x13,0x11,0x10,0x10,0x11,0x16,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 24880 0x6130 "愰" */
+0x10,0x11,0x11,0x11,0x19,0x55,0x50,0x51,0x90,0x10,0x13,0x10,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 24881 0x6131 "愱" */
+0x10,0x10,0x11,0x19,0x55,0x51,0x55,0x93,0x11,0x13,0x15,0x11,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x00,0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 24882 0x6132 "愲" */
+0x10,0x11,0x11,0x11,0x19,0x57,0x54,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xf8,0x08,0xe8,0x28,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 24883 0x6133 "愳" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x01,0x08,0x48,0x48,0x48,0x87,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x00,0x88,0x84,0x12,0x12,0xf0,0x00,
+/* 24884 0x6134 "愴" */
+0x10,0x10,0x10,0x18,0x55,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x12,0x12,0x14,0x10,
+0x20,0x20,0x50,0xc8,0x24,0xfe,0x04,0xfc,0x04,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 24885 0x6135 "愵" */
+0x10,0x13,0x10,0x10,0x1b,0x56,0x52,0x53,0x90,0x12,0x11,0x11,0x12,0x10,0x12,0x11,
+0x00,0xde,0x42,0x42,0xde,0x10,0x10,0xde,0x42,0x52,0x4a,0x4a,0x52,0x42,0x94,0x08,
+/* 24886 0x6136 "愶" */
+0x10,0x11,0x10,0x10,0x19,0x57,0x51,0x51,0x92,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x40,0xfc,0x44,0x94,0x08,0xde,0x4a,0x4a,0x94,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 24887 0x6137 "愷" */
+0x10,0x12,0x12,0x1a,0x57,0x50,0x57,0x90,0x13,0x12,0x12,0x13,0x11,0x10,0x17,0x10,
+0x40,0x48,0x48,0x48,0xf8,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x10,0xa0,0xfe,0x00,
+/* 24888 0x6138 "愸" */
+0x08,0x08,0x7f,0x2a,0x2a,0x5d,0x08,0x1c,0x2a,0x48,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x44,0x94,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24889 0x6139 "愹" */
+0x20,0x20,0x23,0x22,0x34,0xa9,0xa2,0xa0,0xa1,0x22,0x25,0x21,0x21,0x21,0x21,0x21,
+0x40,0x20,0xfe,0x02,0x94,0x08,0x64,0x90,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x08,
+/* 24890 0x613a "愺" */
+0x10,0x10,0x13,0x10,0x18,0x55,0x51,0x51,0x91,0x11,0x11,0x10,0x13,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 24891 0x613b "愻" */
+0x00,0x7d,0x04,0x08,0x11,0x10,0x1c,0xf3,0x10,0x11,0x52,0x20,0x01,0x48,0x48,0x87,
+0x0c,0xf0,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,0x00,0x84,0x12,0xf2,
+/* 24892 0x613c "愼" */
+0x12,0x13,0x12,0x19,0x54,0x51,0x55,0x95,0x15,0x15,0x15,0x15,0x14,0x17,0x11,0x12,
+0x0c,0xf2,0x02,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x04,0x02,
+/* 24893 0x613d "愽" */
+0x10,0x10,0x13,0x10,0x19,0x55,0x51,0x51,0x91,0x11,0x10,0x13,0x10,0x10,0x10,0x10,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 24894 0x613e "愾" */
+0x11,0x11,0x11,0x1a,0x55,0x50,0x53,0x90,0x12,0x11,0x17,0x10,0x11,0x16,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 24895 0x613f "愿" */
+0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x22,0x24,0x29,0x20,0x20,0x4a,0x4a,0x91,
+0x00,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x50,0x48,0x44,0x80,0x44,0x42,0x12,0xf0,
+/* 24896 0x6140 "慀" */
+0x10,0x17,0x12,0x19,0x54,0x51,0x53,0x90,0x11,0x13,0x10,0x10,0x17,0x10,0x11,0x16,
+0x3c,0xc0,0x44,0x28,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x40,0xfc,0xa0,0x10,0x0e,
+/* 24897 0x6141 "慁" */
+0x3f,0x20,0x2f,0x22,0x2d,0x22,0x2d,0x22,0x2d,0x20,0x3f,0x02,0x51,0x51,0x90,0x0f,
+0xf8,0x08,0xf8,0x08,0x28,0xc8,0xa8,0x98,0x88,0x08,0xf8,0x00,0x04,0x12,0x12,0xf0,
+/* 24898 0x6142 "慂" */
+0x20,0x17,0x91,0x40,0x47,0x14,0x27,0xe4,0x27,0x24,0x24,0x01,0x28,0x28,0x48,0x07,
+0x00,0xf8,0x10,0xa0,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x04,0x00,0x88,0xa4,0x24,0xe0,
+/* 24899 0x6143 "慃" */
+0x21,0x21,0x22,0x34,0xa9,0xa3,0xa0,0xa0,0x27,0x20,0x24,0x22,0x24,0x20,0x22,0x21,
+0x20,0x10,0x08,0x86,0x10,0xf8,0x08,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 24900 0x6144 "慄" */
+0x20,0x27,0x20,0x20,0x37,0xac,0xa4,0xa7,0xa0,0x20,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 24901 0x6145 "慅" */
+0x10,0x13,0x11,0x11,0x18,0x54,0x51,0x56,0x90,0x13,0x12,0x12,0x13,0x10,0x17,0x10,
+0x00,0xf8,0x48,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xf8,0x48,0x48,0xf8,0x44,0xfc,0x04,
+/* 24902 0x6146 "慆" */
+0x10,0x13,0x10,0x12,0x19,0x55,0x50,0x53,0x92,0x12,0x13,0x12,0x12,0x12,0x13,0x12,
+0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 24903 0x6147 "慇" */
+0x06,0x38,0x20,0x3e,0x22,0x3e,0x22,0x3e,0x20,0x3e,0x22,0x4a,0x85,0x48,0x48,0x87,
+0x00,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x28,0x10,0x28,0x46,0x00,0x84,0x12,0xf2,
+/* 24904 0x6148 "慈" */
+0x08,0x04,0xff,0x10,0x10,0x24,0x78,0x10,0x24,0x7e,0x02,0x01,0x28,0x28,0x48,0x07,
+0x20,0x40,0xfe,0x20,0x20,0x48,0xf0,0x20,0x48,0xfc,0x04,0x00,0x88,0xa4,0x24,0xe0,
+/* 24905 0x6149 "慉" */
+0x20,0x20,0x27,0x20,0x31,0xab,0xa0,0xa1,0xa7,0x20,0x27,0x24,0x27,0x24,0x27,0x24,
+0x80,0x40,0xfc,0x80,0x08,0xf0,0x60,0x84,0xfe,0x02,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 24906 0x614a "慊" */
+0x21,0x20,0x20,0x27,0x30,0xab,0xa0,0xa7,0xa0,0x23,0x20,0x21,0x22,0x2c,0x20,0x20,
+0x10,0xa0,0x00,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 24907 0x614b "態" */
+0x10,0x24,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,0x02,0x51,0x51,0x90,0x0f,
+0x80,0x98,0xe0,0x84,0x7c,0x00,0x98,0xe0,0x84,0x84,0x7c,0x00,0x04,0x12,0x12,0xf0,
+/* 24908 0x614c "慌" */
+0x21,0x21,0x27,0x21,0x30,0xaf,0xa2,0xa2,0xa3,0x20,0x22,0x22,0x22,0x24,0x24,0x28,
+0x08,0x08,0xfe,0x48,0x20,0xfe,0x00,0x00,0xfc,0x00,0x48,0x48,0x48,0x4a,0x4a,0x46,
+/* 24909 0x614d "慍" */
+0x20,0x23,0x22,0x22,0x33,0xaa,0xa3,0xa0,0xa0,0x27,0x24,0x24,0x24,0x24,0x2f,0x20,
+0x00,0xf8,0x48,0xa8,0x18,0x08,0xf8,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 24910 0x614e "慎" */
+0x20,0x20,0x27,0x20,0x33,0xaa,0xa3,0xa2,0xa3,0x22,0x23,0x22,0x2f,0x21,0x22,0x24,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 24911 0x614f "慏" */
+0x10,0x13,0x12,0x10,0x19,0x55,0x51,0x51,0x91,0x10,0x10,0x13,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 24912 0x6150 "慐" */
+0x3f,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x11,0x48,0x48,0x87,
+0xf8,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0x84,0x12,0xf2,
+/* 24913 0x6151 "慑" */
+0x20,0x23,0x21,0x21,0x31,0xa9,0xa1,0xa7,0xa0,0x27,0x20,0x22,0x21,0x22,0x24,0x28,
+0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 24914 0x6152 "慒" */
+0x10,0x10,0x13,0x10,0x1b,0x56,0x53,0x52,0x93,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x50,0x50,0xfe,0x50,0xfe,0x52,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 24915 0x6153 "慓" */
+0x20,0x2f,0x20,0x27,0x34,0xac,0xa7,0xa0,0xa7,0x20,0x2f,0x20,0x22,0x24,0x29,0x20,
+0x00,0xfe,0xa0,0xfc,0xa4,0xa4,0xfc,0x00,0xfc,0x00,0xfe,0x40,0x48,0x44,0x42,0x80,
+/* 24916 0x6154 "慔" */
+0x21,0x21,0x27,0x21,0x30,0xab,0xa2,0xa3,0xa2,0x23,0x20,0x27,0x20,0x21,0x22,0x2c,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 24917 0x6155 "慕" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x12,0x22,0xcb,0x12,0x2a,0x04,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0x08,0x26,0x90,0x90,0x00,
+/* 24918 0x6156 "慖" */
+0x20,0x27,0x24,0x24,0x37,0xac,0xa7,0xa6,0xa7,0x24,0x25,0x26,0x24,0x24,0x27,0x24,
+0x00,0xfe,0x2a,0x26,0xfe,0x22,0xaa,0xaa,0xaa,0x32,0x96,0x2e,0x46,0x82,0xfe,0x02,
+/* 24919 0x6157 "慗" */
+0x08,0x08,0xff,0x08,0x7f,0x49,0x7f,0x1c,0x2a,0x49,0x88,0x08,0x01,0x48,0x48,0x87,
+0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 24920 0x6158 "慘" */
+0x20,0x21,0x23,0x22,0x34,0xaf,0xa0,0xa0,0xa3,0x2c,0x21,0x26,0x21,0x26,0x21,0x2e,
+0x80,0x10,0xf8,0x10,0xa4,0xbe,0x42,0xa0,0x18,0x46,0x90,0x64,0x88,0x30,0xc0,0x00,
+/* 24921 0x6159 "慙" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x02,0x51,0x51,0x90,0x0f,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0x04,0x12,0x12,0xf0,
+/* 24922 0x615a "慚" */
+0x22,0x22,0x22,0x2f,0x32,0xaf,0xaa,0xaf,0xaa,0x2f,0x22,0x2f,0x22,0x22,0x22,0x22,
+0x00,0x02,0x3c,0xa0,0x20,0xa0,0xbe,0xa4,0xa4,0xa4,0x24,0xa4,0x24,0x44,0x44,0x84,
+/* 24923 0x615b "慛" */
+0x10,0x12,0x13,0x10,0x18,0x55,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 24924 0x615c "慜" */
+0x20,0x3f,0x40,0xbf,0x29,0x25,0x7f,0x29,0x45,0x7f,0x01,0x02,0x51,0x51,0x90,0x0f,
+0x20,0xa0,0x3e,0x44,0xa4,0x24,0xe8,0x28,0x10,0xa8,0x44,0x82,0x04,0x12,0x12,0xf0,
+/* 24925 0x615d "慝" */
+0x3f,0x24,0x2f,0x25,0x3f,0x22,0x27,0x2a,0x33,0x20,0x3f,0x02,0x51,0x51,0x90,0x0f,
+0xfc,0x20,0xf8,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x00,0x04,0x12,0x12,0xf0,
+/* 24926 0x615e "慞" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x51,0x51,0x91,0x11,0x11,0x10,0x13,0x10,0x10,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 24927 0x615f "慟" */
+0x21,0x27,0x21,0x2f,0x31,0xaf,0xa5,0xa7,0xa5,0x27,0x21,0x27,0x21,0x21,0x2e,0x24,
+0xc8,0x08,0x08,0xe8,0x1e,0xca,0x4a,0xca,0x4a,0xca,0x0a,0xca,0x12,0xd2,0x2a,0x44,
+/* 24928 0x6160 "慠" */
+0x21,0x21,0x21,0x27,0x31,0xaf,0xa1,0xaf,0xa2,0x23,0x22,0x22,0x22,0x24,0x24,0x28,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 24929 0x6161 "慡" */
+0x20,0x20,0x27,0x20,0x35,0xaa,0xa5,0xa0,0xa5,0x22,0x25,0x20,0x20,0x21,0x22,0x2c,
+0x40,0x40,0xfc,0x40,0x54,0x48,0x54,0x40,0x54,0x48,0x54,0xa0,0xa0,0x10,0x08,0x06,
+/* 24930 0x6162 "慢" */
+0x23,0x22,0x23,0x32,0xab,0xa0,0xa7,0xa4,0x24,0x27,0x20,0x23,0x21,0x20,0x23,0x2c,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 24931 0x6163 "慣" */
+0x10,0x11,0x11,0x13,0x19,0x55,0x50,0x51,0x91,0x11,0x11,0x11,0x11,0x11,0x10,0x11,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 24932 0x6164 "慤" */
+0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0x9c,0x15,0x26,0x40,0x02,0x51,0x51,0x90,0x0f,
+0x78,0x48,0x48,0x86,0x78,0x48,0x48,0x28,0x10,0x28,0x46,0x00,0x04,0x12,0x12,0xf0,
+/* 24933 0x6165 "慥" */
+0x10,0x14,0x12,0x12,0x18,0x54,0x50,0x56,0x92,0x12,0x12,0x12,0x12,0x15,0x18,0x10,
+0x10,0x50,0x7c,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 24934 0x6166 "慦" */
+0x0a,0x09,0x7f,0x08,0x6a,0x1c,0x2a,0x49,0x28,0x10,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24935 0x6167 "慧" */
+0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x3f,0x00,0x1f,0x00,0x3f,0x01,0x48,0x48,0x87,
+0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x84,0x12,0xf2,
+/* 24936 0x6168 "慨" */
+0x20,0x27,0x24,0x24,0x37,0xac,0xa4,0xa7,0xa4,0x25,0x24,0x25,0x26,0x24,0x20,0x20,
+0x00,0xbe,0x88,0x88,0xa8,0xa8,0xa8,0xbe,0x10,0x18,0x98,0xa8,0xaa,0x4a,0x46,0x80,
+/* 24937 0x6169 "慩" */
+0x20,0x24,0x22,0x32,0xa8,0xa0,0xa6,0xa2,0x22,0x22,0x22,0x22,0x22,0x25,0x28,0x20,
+0x10,0x10,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 24938 0x616a "慪" */
+0x10,0x13,0x12,0x12,0x1a,0x56,0x52,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 24939 0x616b "慫" */
+0x11,0x21,0x41,0x8a,0x14,0x32,0x52,0x92,0x15,0x18,0x11,0x08,0x48,0x48,0x87,0x00,
+0x10,0x10,0x10,0xa8,0x44,0x40,0x7c,0x40,0x40,0xfe,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24940 0x616c "慬" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x51,0x51,0x91,0x10,0x13,0x10,0x11,0x10,0x13,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 24941 0x616d "慭" */
+0x08,0x08,0x7f,0x4a,0x2c,0xff,0x1c,0x2a,0x49,0x88,0x01,0x08,0x48,0x48,0x87,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0x28,0x28,0x44,0x82,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24942 0x616e "慮" */
+0x01,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x27,0x20,0x4a,0x52,0x81,
+0x00,0xfc,0x00,0xfe,0x02,0xf4,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x80,0x44,0x12,0xf0,
+/* 24943 0x616f "慯" */
+0x11,0x11,0x12,0x15,0x19,0x55,0x51,0x51,0x90,0x17,0x11,0x13,0x14,0x11,0x12,0x10,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 24944 0x6170 "慰" */
+0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2c,0x01,0x08,0x48,0x48,0x87,0x00,
+0x08,0x08,0x7e,0x08,0x48,0x28,0xa8,0x08,0x28,0x90,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24945 0x6171 "慱" */
+0x10,0x13,0x10,0x11,0x19,0x55,0x51,0x51,0x90,0x13,0x10,0x13,0x11,0x10,0x10,0x10,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 24946 0x6172 "慲" */
+0x10,0x10,0x13,0x10,0x18,0x54,0x50,0x53,0x92,0x13,0x12,0x13,0x12,0x12,0x12,0x12,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 24947 0x6173 "慳" */
+0x20,0x27,0x25,0x27,0x34,0xaf,0xa5,0xa5,0xa7,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,
+0x00,0xdc,0x14,0xd4,0x54,0xc8,0x08,0x14,0xe2,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 24948 0x6174 "慴" */
+0x10,0x13,0x10,0x12,0x19,0x56,0x50,0x50,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 24949 0x6175 "慵" */
+0x20,0x27,0x24,0x25,0x34,0xaf,0xa4,0xa5,0xa4,0x25,0x25,0x25,0x25,0x29,0x29,0x31,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 24950 0x6176 "慶" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x3f,0x20,0x2a,0x31,0x22,0x27,0x4a,0x41,0x9e,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfe,0x82,0x54,0xf2,0x00,0xf8,0x08,0xf0,0x0e,
+/* 24951 0x6177 "慷" */
+0x20,0x20,0x27,0x24,0x35,0xac,0xa7,0xa4,0xa5,0x24,0x25,0x24,0x29,0x2a,0x30,0x20,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x62,0xb4,0x28,0x26,0xa0,0x40,
+/* 24952 0x6178 "慸" */
+0x14,0x14,0x7f,0x24,0x47,0x80,0x7f,0x41,0x1f,0x11,0x11,0x11,0x01,0x48,0x48,0x87,
+0x50,0x50,0xfc,0x52,0xce,0x00,0xfc,0x04,0xf0,0x10,0x50,0x20,0x00,0x84,0x12,0xf2,
+/* 24953 0x6179 "慹" */
+0x10,0x7c,0x11,0xfe,0x44,0x28,0x7c,0x10,0xfe,0x11,0x12,0x02,0x51,0x51,0x90,0x0f,
+0x40,0x40,0xf8,0x48,0x48,0xc8,0x68,0x9a,0x8a,0x06,0x02,0x00,0x04,0x12,0x12,0xf0,
+/* 24954 0x617a "慺" */
+0x20,0x23,0x22,0x2f,0x32,0xab,0xa0,0xa3,0xa2,0x23,0x20,0x2f,0x21,0x20,0x23,0x2c,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x48,0xf8,0x80,0xfe,0x10,0xe0,0x18,0x04,
+/* 24955 0x617b "慻" */
+0x10,0x12,0x11,0x13,0x18,0x57,0x51,0x52,0x97,0x1a,0x13,0x12,0x13,0x12,0x13,0x12,
+0x40,0x48,0x50,0xf8,0x80,0xfc,0x10,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 24956 0x617c "慼" */
+0x00,0x00,0x3f,0x22,0x23,0x22,0x2f,0x22,0x2a,0x52,0x46,0x81,0x28,0x28,0x48,0x07,
+0x28,0x24,0xfe,0x20,0x24,0x24,0xa8,0x28,0x92,0x2a,0x46,0x02,0x88,0xa4,0x24,0xe0,
+/* 24957 0x617d "慽" */
+0x20,0x20,0x20,0x27,0x34,0xac,0xa4,0xa4,0xa7,0x24,0x24,0x25,0x2a,0x28,0x31,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 24958 0x617e "慾" */
+0x14,0x22,0x49,0x14,0x22,0x41,0xbe,0x22,0x22,0x3e,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x3e,0x42,0x94,0x10,0x28,0x28,0x44,0x82,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24959 0x617f "慿" */
+0x43,0x22,0x23,0x0a,0x0b,0x12,0xe3,0x21,0x27,0x21,0x02,0x02,0x51,0x51,0x90,0x0f,
+0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x22,0xfa,0x22,0x26,0x00,0x04,0x12,0x12,0xf0,
+/* 24960 0x6180 "憀" */
+0x10,0x17,0x10,0x14,0x1a,0x54,0x50,0x51,0x96,0x10,0x13,0x10,0x13,0x10,0x10,0x17,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 24961 0x6181 "憁" */
+0x10,0x10,0x13,0x12,0x1a,0x57,0x52,0x52,0x92,0x13,0x10,0x10,0x15,0x15,0x19,0x10,
+0x40,0x80,0xfc,0x44,0xf4,0x14,0xa4,0x44,0xa4,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 24962 0x6182 "憂" */
+0x7f,0x02,0x1f,0x10,0x1f,0x10,0x7f,0x41,0x94,0x14,0x23,0x08,0x1f,0x68,0x07,0xf8,
+0xfc,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x02,0x94,0x28,0xe8,0x00,0xf0,0x20,0xc0,0x3e,
+/* 24963 0x6183 "憃" */
+0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x3c,0xd0,0x1c,0x10,0x1f,0x01,0x48,0x48,0x87,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf8,0x16,0xf0,0x10,0xf0,0x00,0x84,0x12,0xf2,
+/* 24964 0x6184 "憄" */
+0x10,0x27,0x40,0x8b,0x12,0x33,0x52,0x93,0x12,0x13,0x12,0x17,0x01,0x48,0x48,0x87,
+0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x00,0x84,0x12,0xf2,
+/* 24965 0x6185 "憅" */
+0x7f,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x02,0x51,0x9f,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,0x08,0x24,0xe4,
+/* 24966 0x6186 "憆" */
+0x10,0x11,0x10,0x13,0x1a,0x54,0x50,0x50,0x90,0x10,0x10,0x11,0x10,0x10,0x13,0x10,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 24967 0x6187 "憇" */
+0x06,0x38,0x09,0x7e,0x08,0x08,0x3e,0x22,0x22,0x3e,0x01,0x08,0x48,0x48,0x87,0x00,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24968 0x6188 "憈" */
+0x10,0x10,0x10,0x13,0x1a,0x56,0x53,0x52,0x92,0x12,0x12,0x13,0x14,0x14,0x19,0x10,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0x50,0x54,0x54,0xd8,0x50,0xfe,0x00,
+/* 24969 0x6189 "憉" */
+0x10,0x10,0x17,0x10,0x18,0x57,0x50,0x53,0x92,0x12,0x13,0x12,0x11,0x10,0x17,0x12,
+0x82,0x82,0xf4,0x88,0x80,0xe2,0x02,0xe4,0x28,0x20,0xe0,0x22,0x42,0x74,0x88,0x10,
+/* 24970 0x618a "憊" */
+0x11,0x17,0x21,0x2f,0x61,0xa3,0x26,0x2b,0x22,0x23,0x22,0x22,0x01,0x48,0x48,0x87,
+0x10,0xfc,0x10,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x48,0x58,0x00,0x84,0x12,0xf2,
+/* 24971 0x618b "憋" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x49,0x43,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x10,0x28,0x46,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24972 0x618c "憌" */
+0x08,0x14,0x22,0x5c,0x89,0x3e,0x08,0x4a,0x28,0x0e,0x70,0x22,0x51,0x51,0x90,0x0f,
+0x40,0x40,0x7c,0x84,0x44,0x2c,0x14,0x24,0xc4,0x28,0x10,0x00,0x04,0x12,0x12,0xf0,
+/* 24973 0x618d "憍" */
+0x20,0x23,0x20,0x27,0x31,0xaa,0xa5,0xa9,0xa1,0x20,0x27,0x24,0x25,0x25,0x25,0x24,
+0x38,0xc0,0x80,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x0c,
+/* 24974 0x618e "憎" */
+0x11,0x10,0x10,0x13,0x1a,0x56,0x52,0x52,0x93,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 24975 0x618f "憏" */
+0x21,0x21,0x23,0x22,0x35,0xaa,0xa1,0xa2,0xa4,0x20,0x23,0x20,0x21,0x22,0x25,0x20,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 24976 0x6190 "憐" */
+0x20,0x22,0x21,0x27,0x31,0xaa,0xa4,0xa2,0xa2,0x23,0x24,0x2a,0x21,0x22,0x24,0x28,
+0x40,0x48,0x50,0xfc,0x50,0x48,0x44,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 24977 0x6191 "憑" */
+0x43,0x22,0x0b,0x0a,0x13,0x22,0xe3,0x20,0x25,0x20,0x01,0x08,0x48,0x48,0x87,0x00,
+0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24978 0x6192 "憒" */
+0x10,0x13,0x12,0x13,0x18,0x57,0x50,0x53,0x92,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 24979 0x6193 "憓" */
+0x20,0x20,0x2f,0x20,0x37,0xac,0xa7,0xa4,0xa7,0x20,0x2f,0x20,0x20,0x25,0x25,0x28,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0xfe,0x42,0x24,0x22,0x0a,0xf8,
+/* 24980 0x6194 "憔" */
+0x21,0x21,0x23,0x22,0x36,0xab,0xa2,0xa2,0xa3,0x22,0x22,0x23,0x22,0x25,0x24,0x28,
+0x40,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x24,0x92,0x92,
+/* 24981 0x6195 "憕" */
+0x20,0x27,0x20,0x22,0x31,0xaa,0xa5,0xa8,0xa3,0x22,0x22,0x23,0x22,0x21,0x2f,0x20,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 24982 0x6196 "憖" */
+0x08,0x08,0x7f,0x2a,0x2a,0x5d,0x1c,0x2a,0x49,0x88,0x01,0x08,0x48,0x48,0x87,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0x28,0x28,0x44,0x82,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24983 0x6197 "憗" */
+0x08,0x08,0x7f,0x2a,0x2a,0x5d,0x08,0x1c,0x2a,0x48,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 24984 0x6198 "憘" */
+0x10,0x13,0x10,0x19,0x54,0x51,0x51,0x91,0x10,0x17,0x10,0x11,0x11,0x11,0x11,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 24985 0x6199 "憙" */
+0x01,0x7f,0x01,0x3f,0x00,0x3f,0x20,0x3f,0x08,0xff,0x20,0x3f,0x01,0x48,0x48,0x87,
+0x00,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x20,0xfe,0x08,0xf8,0x00,0x84,0x12,0xf2,
+/* 24986 0x619a "憚" */
+0x10,0x13,0x12,0x12,0x1b,0x54,0x51,0x51,0x91,0x11,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 24987 0x619b "憛" */
+0x10,0x13,0x10,0x1b,0x56,0x53,0x50,0x91,0x11,0x11,0x11,0x11,0x10,0x13,0x10,0x10,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 24988 0x619c "憜" */
+0x20,0x27,0x25,0x25,0x35,0xae,0xa5,0xa5,0xa5,0x25,0x25,0x26,0x24,0x24,0x24,0x24,
+0x20,0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 24989 0x619d "憝" */
+0x08,0x7f,0x00,0x3e,0x23,0x3e,0x00,0x3e,0x04,0x7f,0x08,0x29,0x11,0x48,0x48,0x87,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x50,0x20,0x50,0x88,0x04,0x00,0x84,0x12,0xf2,
+/* 24990 0x619e "憞" */
+0x22,0x21,0x2f,0x20,0x37,0xac,0xa7,0xa0,0xa7,0x20,0x21,0x21,0x2f,0x21,0x25,0x22,
+0x10,0x10,0xd0,0x10,0xbe,0xa4,0xd4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 24991 0x619f "憟" */
+0x20,0x27,0x20,0x20,0x37,0xac,0xa4,0xa7,0xa2,0x21,0x27,0x20,0x21,0x22,0x2c,0x20,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 24992 0x61a0 "憠" */
+0x3f,0x28,0x25,0x2f,0x22,0x2a,0x2a,0x2f,0x22,0x44,0x44,0x88,0x01,0x48,0x48,0x87,
+0xfe,0x90,0x10,0xbe,0x22,0xd4,0x90,0x90,0x28,0x28,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 24993 0x61a1 "憡" */
+0x12,0x12,0x13,0x15,0x18,0x54,0x53,0x50,0x93,0x12,0x12,0x12,0x10,0x11,0x16,0x10,
+0x10,0x10,0xde,0x28,0xa4,0x20,0xfe,0x20,0xfe,0x22,0x2a,0x74,0xa8,0x24,0x22,0x20,
+/* 24994 0x61a2 "憢" */
+0x10,0x10,0x11,0x10,0x1b,0x55,0x53,0x51,0x91,0x16,0x10,0x13,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 24995 0x61a3 "憣" */
+0x10,0x13,0x11,0x10,0x1b,0x54,0x51,0x52,0x91,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 24996 0x61a4 "憤" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x10,0x11,0x12,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 24997 0x61a5 "憥" */
+0x08,0x2a,0x08,0x14,0x22,0x7f,0x40,0x02,0x3f,0x04,0x08,0x30,0x01,0x48,0x48,0x87,
+0x20,0xa8,0x20,0x50,0x88,0xfc,0x04,0x00,0xf8,0x08,0x50,0x20,0x00,0x84,0x12,0xf2,
+/* 24998 0x61a6 "憦" */
+0x10,0x12,0x12,0x14,0x19,0x56,0x50,0x53,0x92,0x14,0x13,0x10,0x10,0x10,0x11,0x12,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 24999 0x61a7 "憧" */
+0x10,0x11,0x10,0x10,0x1b,0x54,0x51,0x51,0x91,0x11,0x11,0x10,0x11,0x10,0x13,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25000 0x61a8 "憨" */
+0x7c,0x04,0xff,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x42,0x02,0x01,0x28,0x28,0x48,0x07,
+0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x90,0x28,0x44,0x82,0x00,0x88,0xa4,0x24,0xe0,
+/* 25001 0x61a9 "憩" */
+0x1c,0x70,0x10,0xfe,0x10,0x7c,0x44,0x44,0x7c,0x44,0x01,0x08,0x48,0x48,0x87,0x00,
+0x10,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 25002 0x61aa "憪" */
+0x27,0x24,0x27,0x24,0x37,0xac,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x24,0x25,0x24,0x24,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 25003 0x61ab "憫" */
+0x20,0x27,0x24,0x27,0x34,0xaf,0xa4,0xa4,0xa5,0x24,0x24,0x24,0x24,0x25,0x24,0x24,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x84,0x44,0xf4,0x24,0xa4,0x44,0xa4,0x04,0x14,0x08,
+/* 25004 0x61ac "憬" */
+0x10,0x13,0x12,0x1b,0x56,0x53,0x50,0x97,0x10,0x13,0x12,0x13,0x10,0x12,0x14,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x40,0x48,0x44,0xc0,
+/* 25005 0x61ad "憭" */
+0x20,0x20,0x27,0x20,0x35,0xaa,0xa7,0xaa,0xa3,0x22,0x23,0x20,0x22,0x24,0x29,0x20,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 25006 0x61ae "憮" */
+0x21,0x21,0x23,0x36,0xaa,0xa2,0xa7,0xa2,0x22,0x22,0x2f,0x20,0x22,0x22,0x24,0x20,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 25007 0x61af "憯" */
+0x20,0x27,0x21,0x25,0x37,0xab,0xa5,0xa9,0xa0,0x23,0x22,0x22,0x23,0x22,0x22,0x23,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 25008 0x61b0 "憰" */
+0x10,0x13,0x10,0x10,0x1b,0x54,0x50,0x53,0x90,0x13,0x12,0x12,0x13,0x12,0x12,0x12,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 25009 0x61b1 "憱" */
+0x22,0x21,0x2f,0x20,0x30,0xaf,0xa4,0xa4,0xa7,0x21,0x25,0x25,0x29,0x21,0x25,0x22,
+0x14,0x12,0xd2,0x10,0x7e,0x90,0x90,0x90,0x90,0x28,0xa8,0x68,0x28,0x4a,0x4a,0x86,
+/* 25010 0x61b2 "憲" */
+0x01,0x7f,0x41,0x3f,0x01,0x1f,0x01,0xff,0x01,0x3f,0x24,0x3f,0x01,0x48,0x48,0x87,
+0x00,0xfc,0x04,0xf8,0x00,0xf0,0x00,0xfe,0x00,0xf8,0x48,0xf8,0x00,0x84,0x12,0xf2,
+/* 25011 0x61b3 "憳" */
+0x10,0x13,0x10,0x13,0x18,0x57,0x50,0x53,0x91,0x17,0x10,0x13,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 25012 0x61b4 "憴" */
+0x20,0x27,0x24,0x24,0x37,0xa8,0xa7,0xa4,0xa4,0x27,0x24,0x24,0x27,0x24,0x20,0x20,
+0x00,0xfc,0xa4,0xa4,0xbc,0xa0,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa2,0xa2,0x7e,
+/* 25013 0x61b5 "憵" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x01,0x08,0x48,0x48,0x87,0x00,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 25014 0x61b6 "憶" */
+0x10,0x10,0x13,0x19,0x54,0x57,0x50,0x93,0x12,0x13,0x12,0x13,0x10,0x15,0x15,0x18,
+0x80,0x40,0xfc,0x08,0x90,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x24,0x0a,0xfa,
+/* 25015 0x61b7 "憷" */
+0x21,0x21,0x27,0x31,0xab,0xa5,0xa9,0xa0,0x27,0x20,0x22,0x22,0x22,0x25,0x28,0x30,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xfc,0x44,0x40,0x78,0x40,0x40,0xfe,0x00,
+/* 25016 0x61b8 "憸" */
+0x20,0x20,0x20,0x31,0xaa,0xa5,0xa8,0xa7,0x24,0x24,0x27,0x22,0x22,0x25,0x29,0x30,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xbc,0xa4,0xa4,0xbc,0x10,0x10,0x28,0x44,0x82,
+/* 25017 0x61b9 "憹" */
+0x10,0x13,0x12,0x1b,0x56,0x53,0x50,0x93,0x12,0x12,0x12,0x13,0x15,0x15,0x15,0x19,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 25018 0x61ba "憺" */
+0x11,0x11,0x12,0x17,0x1a,0x57,0x53,0x52,0x92,0x12,0x12,0x12,0x12,0x14,0x14,0x18,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 25019 0x61bb "憻" */
+0x10,0x17,0x10,0x13,0x1a,0x56,0x52,0x53,0x90,0x11,0x11,0x11,0x11,0x11,0x10,0x17,
+0x20,0xfe,0x00,0xfe,0x02,0xfa,0x8a,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,
+/* 25020 0x61bc "憼" */
+0x22,0xff,0x22,0x20,0x7f,0x81,0x7d,0x45,0x7d,0x0a,0x04,0x02,0x51,0x51,0x90,0x0f,
+0x20,0xa0,0x3e,0x44,0xa4,0x28,0x28,0x10,0x28,0x44,0x82,0x00,0x04,0x12,0x12,0xf0,
+/* 25021 0x61bd "憽" */
+0x21,0x2f,0x21,0x32,0xab,0xa4,0xab,0xa1,0x22,0x24,0x21,0x20,0x20,0x25,0x25,0x28,
+0x10,0xfe,0x10,0x00,0xfc,0xa4,0xa4,0x64,0x54,0x94,0x08,0x40,0x24,0x22,0x0a,0xf8,
+/* 25022 0x61be "憾" */
+0x20,0x20,0x27,0x24,0x35,0xac,0xa5,0xa5,0xa5,0x24,0x24,0x28,0x22,0x22,0x24,0x20,
+0x14,0x12,0xfe,0x10,0xd0,0x14,0xd4,0x58,0xca,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 25023 0x61bf "憿" */
+0x21,0x22,0x27,0x24,0x37,0xac,0xa7,0xa2,0xa1,0x27,0x22,0x23,0x22,0x24,0x25,0x28,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 25024 0x61c0 "懀" */
+0x20,0x20,0x23,0x2d,0x30,0xaf,0xa5,0xa4,0xa7,0x20,0x23,0x22,0x23,0x22,0x23,0x22,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 25025 0x61c1 "懁" */
+0x20,0x23,0x22,0x32,0xab,0xa0,0xa7,0xa0,0x23,0x22,0x23,0x20,0x21,0x23,0x2d,0x21,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 25026 0x61c2 "懂" */
+0x21,0x27,0x21,0x23,0x30,0xaf,0xa0,0xa3,0xa2,0x23,0x22,0x23,0x20,0x27,0x20,0x2f,
+0x10,0xfe,0x10,0xf8,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,
+/* 25027 0x61c3 "懃" */
+0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x01,0x48,0x48,0x87,
+0x20,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x88,0x00,0x84,0x12,0xf2,
+/* 25028 0x61c4 "懄" */
+0x22,0x22,0x2f,0x22,0x33,0xa9,0xa7,0xa5,0xa7,0x21,0x27,0x21,0x27,0x21,0x21,0x2e,
+0x88,0x88,0xe8,0x88,0xbe,0x0a,0xca,0x4a,0xca,0x0a,0xca,0x0a,0xd2,0x12,0xea,0x44,
+/* 25029 0x61c5 "懅" */
+0x10,0x10,0x10,0x13,0x1a,0x56,0x53,0x52,0x92,0x13,0x12,0x13,0x12,0x15,0x14,0x19,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 25030 0x61c6 "懆" */
+0x23,0x22,0x22,0x33,0xa8,0xa7,0xa4,0xa4,0x27,0x20,0x2f,0x21,0x22,0x24,0x38,0x20,
+0xf8,0x08,0x08,0xf8,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0xfe,0x60,0x50,0x48,0x46,0x40,
+/* 25031 0x61c7 "懇" */
+0x06,0xf8,0x4a,0x24,0x38,0xcc,0x36,0xca,0x12,0x6a,0x04,0x02,0x51,0x51,0x90,0x0f,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0xa2,0x94,0xa8,0xc4,0x82,0x00,0x04,0x12,0x12,0xf0,
+/* 25032 0x61c8 "懈" */
+0x22,0x23,0x24,0x29,0x37,0xad,0xa5,0xa7,0xa5,0x25,0x27,0x25,0x25,0x25,0x24,0x28,
+0x00,0x9e,0x8a,0x0a,0xd2,0x66,0x40,0xd4,0x5e,0x64,0xc4,0x44,0x5e,0x44,0x44,0xc4,
+/* 25033 0x61c9 "應" */
+0x01,0x00,0x3f,0x22,0x24,0x2d,0x34,0x24,0x24,0x24,0x24,0x24,0x42,0x52,0x92,0x21,
+0x00,0x80,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0x44,0x4a,0x0a,0xf8,
+/* 25034 0x61ca "懊" */
+0x20,0x21,0x27,0x24,0x35,0xac,0xa7,0xa4,0xa5,0x24,0x20,0x2f,0x20,0x21,0x22,0x2c,
+0x80,0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x04,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 25035 0x61cb "懋" */
+0x27,0x20,0xfa,0x21,0x77,0x6b,0xa5,0x29,0x25,0x22,0x01,0x08,0x48,0x48,0x87,0x00,
+0x88,0x88,0xbe,0x08,0xd8,0x5c,0x2a,0x48,0x08,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 25036 0x61cc "懌" */
+0x20,0x27,0x24,0x27,0x30,0xab,0xa0,0xa7,0xa1,0x20,0x23,0x20,0x2f,0x20,0x20,0x20,
+0x00,0xfc,0xa4,0xfc,0x40,0xf8,0x40,0xfc,0x10,0xa0,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 25037 0x61cd "懍" */
+0x20,0x2f,0x20,0x27,0x34,0xad,0xa5,0xa5,0xa4,0x27,0x20,0x23,0x20,0x2f,0x21,0x2e,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 25038 0x61ce "懎" */
+0x20,0x20,0x27,0x32,0xaa,0xa5,0xaf,0xa0,0x27,0x24,0x25,0x25,0x25,0x24,0x27,0x24,
+0x40,0x40,0xfc,0x48,0x48,0x54,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x04,
+/* 25039 0x61cf "懏" */
+0x10,0x10,0x11,0x13,0x19,0x55,0x51,0x51,0x91,0x11,0x13,0x12,0x12,0x12,0x12,0x12,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xde,0x52,0x52,0x72,0x02,0x06,
+/* 25040 0x61d0 "懐" */
+0x10,0x10,0x13,0x10,0x19,0x55,0x51,0x51,0x90,0x13,0x10,0x10,0x11,0x12,0x14,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x54,0x54,0xfc,0x20,0xfe,0x50,0x94,0x88,0xa8,0xc4,0x82,
+/* 25041 0x61d1 "懑" */
+0x01,0x4f,0x21,0x27,0x80,0x47,0x54,0x14,0xe5,0x26,0x24,0x24,0x01,0x48,0x48,0x87,
+0x10,0xfe,0x10,0xfc,0xa0,0xfc,0xa4,0xa4,0x64,0x54,0x84,0x0c,0x00,0x84,0x12,0xf2,
+/* 25042 0x61d2 "懒" */
+0x22,0x22,0x2f,0x22,0x32,0xaf,0xaa,0xaa,0xaf,0x22,0x27,0x2a,0x32,0x22,0x22,0x22,
+0x10,0x10,0x9c,0x24,0x48,0xbe,0xa2,0xaa,0xaa,0x2a,0x2a,0xaa,0x88,0x14,0x22,0x42,
+/* 25043 0x61d3 "懓" */
+0x10,0x13,0x10,0x12,0x19,0x57,0x54,0x52,0x92,0x14,0x10,0x10,0x11,0x12,0x10,0x17,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 25044 0x61d4 "懔" */
+0x20,0x2f,0x20,0x37,0xac,0xa5,0xa5,0xa5,0x24,0x27,0x20,0x23,0x20,0x2f,0x22,0x24,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x00,0xf8,0x00,0xfe,0x48,0xc4,
+/* 25045 0x61d5 "懕" */
+0x00,0x3f,0x28,0x2f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x40,0x42,0x8a,0x11,
+0x00,0xfe,0x8c,0x8a,0x88,0xbe,0x08,0x88,0x88,0x94,0x94,0xa2,0x80,0x40,0x14,0xf2,
+/* 25046 0x61d6 "懖" */
+0x08,0x14,0x22,0x5c,0x88,0x3e,0x08,0x4a,0x28,0x0e,0x70,0x22,0x51,0x51,0x90,0x0f,
+0x0c,0x70,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x7c,0x00,0x04,0x12,0x12,0xf0,
+/* 25047 0x61d7 "懗" */
+0x21,0x21,0x21,0x37,0xa9,0xa1,0xaf,0xa2,0x22,0x26,0x2a,0x22,0x22,0x25,0x24,0x28,
+0x10,0x10,0x10,0xbc,0x10,0x10,0xfe,0xa8,0xa8,0xec,0xaa,0xaa,0xa8,0xa8,0x48,0x98,
+/* 25048 0x61d8 "懘" */
+0x42,0x27,0x22,0x84,0x40,0x57,0x14,0xe3,0x22,0x22,0x21,0x08,0x48,0x48,0x87,0x00,
+0xa8,0xfc,0xaa,0xe6,0x00,0xfc,0x44,0xf8,0x48,0x58,0x40,0x84,0x92,0x12,0xf0,0x00,
+/* 25049 0x61d9 "懙" */
+0x11,0x12,0x12,0x12,0x1b,0x56,0x52,0x53,0x92,0x12,0x17,0x10,0x11,0x11,0x12,0x14,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 25050 0x61da "懚" */
+0x20,0x27,0x22,0x21,0x33,0xa8,0xa7,0xa0,0xa3,0x20,0x23,0x20,0x23,0x25,0x25,0x28,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 25051 0x61db "懛" */
+0x20,0x2f,0x20,0x27,0x30,0xab,0xa2,0xaf,0xa8,0x27,0x21,0x23,0x20,0x27,0x20,0x2f,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xfc,0x40,0xfe,
+/* 25052 0x61dc "懜" */
+0x10,0x10,0x13,0x10,0x1b,0x56,0x53,0x50,0x93,0x12,0x10,0x11,0x12,0x10,0x10,0x17,
+0x88,0x88,0xfe,0x88,0xfe,0x52,0xfe,0x00,0xfe,0x42,0xf8,0x08,0x90,0x60,0xc0,0x00,
+/* 25053 0x61dd "懝" */
+0x24,0x25,0x26,0x34,0xab,0xa0,0xa4,0xa7,0x2a,0x22,0x2f,0x22,0x25,0x24,0x28,0x21,
+0x00,0x7c,0x04,0xa8,0x90,0x7c,0x14,0x94,0x50,0x50,0xdc,0x50,0x50,0xb0,0x9e,0x00,
+/* 25054 0x61de "懞" */
+0x10,0x13,0x10,0x13,0x1a,0x55,0x50,0x53,0x90,0x10,0x13,0x10,0x13,0x10,0x13,0x10,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 25055 0x61df "懟" */
+0x14,0x55,0x36,0x14,0x7f,0x14,0x7f,0x08,0x3e,0x08,0x0f,0x78,0x21,0x48,0x48,0x87,
+0x08,0x08,0x08,0x7e,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,0x00,0x84,0x12,0xf2,
+/* 25056 0x61e0 "懠" */
+0x20,0x20,0x27,0x21,0x30,0xaf,0xa5,0xa5,0xab,0x20,0x22,0x23,0x22,0x23,0x22,0x24,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 25057 0x61e1 "懡" */
+0x20,0x20,0x27,0x24,0x37,0xac,0xa5,0xa6,0xa4,0x24,0x24,0x25,0x24,0x24,0x25,0x28,
+0x40,0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x40,0x90,0x20,0x48,0x84,0xfc,0x84,
+/* 25058 0x61e2 "懢" */
+0x20,0x27,0x25,0x27,0x34,0xaf,0xa5,0xa7,0xa0,0x23,0x22,0x22,0x22,0x22,0x2f,0x20,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 25059 0x61e3 "懣" */
+0x01,0x47,0x21,0x81,0x40,0x17,0x16,0xe5,0x26,0x24,0x24,0x02,0x51,0x51,0x90,0x0f,
+0x10,0xfc,0x10,0xf0,0x40,0xfc,0x64,0x54,0xec,0x44,0x4c,0x00,0x04,0x12,0x12,0xf0,
+/* 25060 0x61e4 "懤" */
+0x20,0x27,0x20,0x33,0xa8,0xa7,0xa0,0xa3,0x20,0x27,0x20,0x27,0x20,0x27,0x24,0x27,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 25061 0x61e5 "懥" */
+0x20,0x27,0x20,0x27,0x34,0xab,0xa2,0xa3,0xa2,0x23,0x20,0x27,0x22,0x22,0x25,0x28,
+0x40,0xfc,0x40,0xfe,0x02,0xfc,0x48,0xf8,0x48,0xf8,0x00,0xfc,0x44,0x78,0x40,0xfe,
+/* 25062 0x61e6 "懦" */
+0x20,0x27,0x20,0x2f,0x38,0xab,0xa0,0xa3,0xa0,0x2f,0x20,0x27,0x24,0x24,0x24,0x24,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfe,0x40,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 25063 0x61e7 "懧" */
+0x20,0x20,0x27,0x24,0x32,0xaa,0xa4,0xa0,0xa3,0x22,0x2f,0x20,0x27,0x20,0x21,0x20,
+0x80,0x40,0xfc,0x44,0xa8,0x94,0x74,0x00,0xf8,0xa8,0xfe,0x00,0xfc,0x40,0x40,0x80,
+/* 25064 0x61e8 "懨" */
+0x20,0x2f,0x28,0x2b,0x3a,0xab,0xaa,0xab,0xa8,0x2b,0x2a,0x2b,0x2a,0x2b,0x2a,0x32,
+0x00,0xfe,0x08,0xc8,0x4c,0xca,0x48,0xde,0x08,0xc8,0x48,0xd4,0x54,0xd4,0x54,0xe2,
+/* 25065 0x61e9 "懩" */
+0x22,0x21,0x27,0x30,0xab,0xa0,0xa7,0xa1,0x23,0x26,0x2b,0x22,0x23,0x22,0x22,0x23,
+0x08,0x10,0xfc,0x40,0xf8,0x80,0xfc,0x48,0xfc,0x0a,0xf8,0x08,0xfa,0x34,0x8c,0x02,
+/* 25066 0x61ea "懪" */
+0x23,0x22,0x23,0x22,0x33,0xa9,0xa7,0xa1,0xaf,0x21,0x22,0x25,0x20,0x21,0x22,0x20,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfc,0x10,0xfe,0x10,0x48,0x54,0xe0,0x50,0x48,0xc0,
+/* 25067 0x61eb "懫" */
+0x10,0x13,0x12,0x1b,0x56,0x52,0x54,0x93,0x12,0x13,0x12,0x13,0x12,0x13,0x11,0x12,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 25068 0x61ec "懬" */
+0x00,0x3f,0x22,0x2f,0x22,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x42,0x54,0x92,0x23,
+0x80,0xfe,0x20,0xf8,0x20,0xfc,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x20,0x94,0x4a,0xfa,
+/* 25069 0x61ed "懭" */
+0x20,0x20,0x27,0x24,0x35,0xac,0xa7,0xa4,0xa5,0x25,0x25,0x25,0x25,0x24,0x24,0x29,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 25070 0x61ee "懮" */
+0x27,0x20,0x23,0x32,0xab,0xa2,0xaf,0xa8,0x25,0x25,0x28,0x21,0x23,0x25,0x20,0x2f,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xfe,0x82,0x48,0x14,0xf4,0x00,0xf8,0x08,0xf0,0x0e,
+/* 25071 0x61ef "懯" */
+0x0a,0xff,0x49,0x7f,0x49,0x51,0x08,0xff,0x20,0x3e,0x42,0x86,0x01,0x48,0x48,0x87,
+0x20,0xa0,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 25072 0x61f0 "懰" */
+0x22,0x25,0x24,0x26,0x35,0xae,0xa1,0xa2,0xa4,0x2b,0x21,0x27,0x21,0x25,0x21,0x2e,
+0x02,0xe2,0xa2,0xaa,0x2a,0x6a,0x0a,0x8a,0x4a,0xaa,0x0a,0xca,0x22,0x42,0xea,0x04,
+/* 25073 0x61f1 "懱" */
+0x11,0x17,0x11,0x10,0x1b,0x56,0x52,0x53,0x90,0x13,0x12,0x13,0x12,0x12,0x14,0x18,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 25074 0x61f2 "懲" */
+0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x22,0x2f,0x22,0x2f,0x01,0x48,0x48,0x87,
+0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0xa8,0x10,0xa8,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 25075 0x61f3 "懳" */
+0x10,0x13,0x10,0x19,0x54,0x53,0x50,0x93,0x10,0x11,0x10,0x13,0x10,0x12,0x12,0x14,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 25076 0x61f4 "懴" */
+0x21,0x21,0x27,0x31,0xa9,0xa7,0xa2,0xa6,0x22,0x26,0x22,0x26,0x22,0x22,0x2f,0x20,
+0x14,0x12,0xd2,0x10,0x10,0xfe,0x90,0xd2,0x92,0xd2,0x94,0xd4,0x8a,0xca,0x16,0x22,
+/* 25077 0x61f5 "懵" */
+0x11,0x17,0x11,0x13,0x1a,0x57,0x50,0x57,0x94,0x11,0x11,0x11,0x11,0x11,0x11,0x11,
+0x08,0xfe,0x08,0xfc,0x94,0xfc,0x00,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,
+/* 25078 0x61f6 "懶" */
+0x21,0x21,0x27,0x21,0x31,0xaf,0xa5,0xa5,0xa7,0x21,0x23,0x25,0x29,0x21,0x21,0x21,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 25079 0x61f7 "懷" */
+0x20,0x20,0x2f,0x20,0x37,0xac,0xa7,0xa2,0xa1,0x22,0x24,0x20,0x21,0x23,0x2d,0x21,
+0x80,0x40,0xfe,0x00,0xfc,0xa4,0xfc,0x48,0x50,0x08,0x44,0xa8,0x10,0x08,0x46,0x80,
+/* 25080 0x61f8 "懸" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x7f,0x08,0x2a,0x59,0x01,0x48,0x48,0x87,
+0x0e,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0x54,0x92,0x50,0x20,0x84,0x12,0xf2,
+/* 25081 0x61f9 "懹" */
+0x20,0x27,0x20,0x23,0x32,0xab,0xa1,0xa7,0xa1,0x27,0x21,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 25082 0x61fa "懺" */
+0x24,0x24,0x2a,0x30,0xaf,0xa2,0xae,0xa2,0x2e,0x22,0x2e,0x22,0x22,0x2f,0x24,0x20,
+0x48,0x4c,0xaa,0x08,0xfe,0x88,0xe8,0x8a,0xea,0x8c,0xec,0x88,0xea,0x1a,0x26,0x42,
+/* 25083 0x61fb "懻" */
+0x10,0x13,0x10,0x11,0x1a,0x55,0x51,0x51,0x91,0x11,0x10,0x11,0x10,0x13,0x10,0x11,
+0x94,0x98,0x92,0x8e,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x04,
+/* 25084 0x61fc "懼" */
+0x27,0x24,0x27,0x24,0x37,0xac,0xa7,0xa1,0xa3,0x22,0x27,0x2a,0x23,0x22,0x23,0x22,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25085 0x61fd "懽" */
+0x21,0x2f,0x21,0x27,0x34,0xaf,0xa1,0xa1,0xa3,0x22,0x27,0x2a,0x23,0x22,0x23,0x22,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25086 0x61fe "懾" */
+0x13,0x11,0x11,0x19,0x55,0x51,0x57,0x90,0x17,0x12,0x13,0x12,0x13,0x12,0x17,0x10,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 25087 0x61ff "懿" */
+0x10,0xff,0x10,0x7c,0x00,0xfe,0x83,0x7c,0x00,0x7c,0x44,0x7c,0x45,0x2f,0xf1,0x42,
+0x20,0x20,0xbe,0x44,0x50,0x90,0x90,0xa8,0xa4,0xc2,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 25088 0x6200 "戀" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x08,0x48,0x48,0x87,0x00,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 25089 0x6201 "戁" */
+0x28,0xfe,0x28,0x39,0x12,0x7c,0x54,0x7c,0x10,0x7c,0x10,0xfe,0x28,0x45,0x24,0x43,
+0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,0x04,0x92,0xf0,
+/* 25090 0x6202 "戂" */
+0x20,0x27,0x24,0x27,0x34,0xad,0xa6,0xa4,0xa4,0x27,0x24,0x25,0x24,0x2b,0x28,0x30,
+0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 25091 0x6203 "戃" */
+0x22,0x21,0x27,0x24,0x31,0xa9,0xa7,0xa5,0xa4,0x27,0x20,0x27,0x20,0x2f,0x22,0x24,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 25092 0x6204 "戄" */
+0x13,0x12,0x13,0x12,0x1b,0x54,0x51,0x53,0x95,0x11,0x11,0x10,0x11,0x10,0x10,0x17,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 25093 0x6205 "戅" */
+0x10,0xfe,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x02,0x51,0x9f,
+0x00,0xf8,0x20,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x08,0x24,0xe4,
+/* 25094 0x6206 "戆" */
+0x10,0xfe,0x29,0xfe,0x01,0x7c,0x44,0x7d,0x44,0x7c,0x10,0xfe,0x11,0x48,0x48,0x87,
+0x40,0xf8,0x48,0x30,0xce,0xf8,0x20,0xfc,0x88,0xa8,0xa8,0x50,0x88,0x84,0x12,0xf2,
+/* 25095 0x6207 "戇" */
+0x10,0xfe,0x29,0xfe,0x01,0x7c,0x44,0x7d,0x44,0x7c,0x10,0xfe,0x10,0x02,0x51,0x9f,
+0x40,0xf8,0x48,0x30,0xce,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x50,0x88,0x24,0xe4,
+/* 25096 0x6208 "戈" */
+0x02,0x02,0x02,0x02,0x02,0xff,0x02,0x02,0x02,0x01,0x01,0x00,0x03,0x0c,0x70,0x00,
+0x20,0x10,0x10,0x00,0xfe,0x00,0x08,0x08,0x10,0x20,0x40,0x80,0x42,0x22,0x1a,0x06,
+/* 25097 0x6209 "戉" */
+0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x40,0x40,0x48,0x50,0x61,0x42,0x04,
+0x90,0x88,0x88,0x80,0xfe,0x80,0x80,0x88,0x88,0x90,0x60,0x44,0xa4,0x14,0x0c,0x04,
+/* 25098 0x620a "戊" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x43,0x8c,
+0x90,0x88,0x80,0xfe,0x80,0x80,0x84,0x44,0x48,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 25099 0x620b "戋" */
+0x02,0x02,0x02,0x02,0x7f,0x02,0x02,0x02,0xff,0x02,0x01,0x01,0x01,0x0e,0x70,0x00,
+0x40,0x20,0x20,0xfc,0x00,0x00,0x00,0x3e,0xc0,0x10,0x20,0x40,0x84,0x44,0x34,0x0c,
+/* 25100 0x620c "戌" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x40,0x40,0x81,
+0x50,0x48,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25101 0x620d "戍" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x30,0x28,0x24,0x24,0x20,0x20,0x40,0x40,0x81,
+0x50,0x48,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25102 0x620e "戎" */
+0x00,0x00,0x00,0xff,0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x10,0x10,0x20,0x40,0x03,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25103 0x620f "戏" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x25,0x14,0x08,0x08,0x14,0x12,0x22,0x40,0x00,0x01,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 25104 0x6210 "成" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3e,0x22,0x22,0x22,0x22,0x2a,0x44,0x40,0x81,
+0x50,0x48,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25105 0x6211 "我" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x08,0x0a,0x0c,0x18,0x68,0x08,0x08,0x2b,0x10,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 25106 0x6212 "戒" */
+0x00,0x00,0x00,0xff,0x00,0x12,0x12,0x12,0x7f,0x12,0x12,0x12,0x22,0x22,0x40,0x03,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25107 0x6213 "戓" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,0x03,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25108 0x6214 "戔" */
+0x02,0x02,0x02,0x7f,0x01,0x03,0x1c,0xe0,0x02,0x02,0x02,0x7f,0x01,0x03,0x1c,0xe0,
+0x40,0x20,0xfc,0x10,0x60,0x84,0x64,0x1c,0x40,0x20,0xfc,0x10,0x60,0x84,0x64,0x1c,
+/* 25109 0x6215 "戕" */
+0x04,0x24,0x24,0x24,0x24,0x3c,0x05,0x04,0xfc,0x24,0x24,0x24,0x24,0x44,0x84,0x05,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 25110 0x6216 "或" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x07,0x78,0x20,0x03,
+0x48,0x44,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25111 0x6217 "戗" */
+0x08,0x08,0x14,0x12,0x21,0x40,0xbe,0x22,0x22,0x22,0x2a,0x24,0x21,0x21,0x1f,0x00,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25112 0x6218 "战" */
+0x10,0x10,0x10,0x1e,0x10,0x10,0x11,0x10,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x01,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 25113 0x6219 "戙" */
+0x00,0xff,0x81,0x81,0xbd,0x81,0x81,0xbd,0xa5,0xa5,0xa5,0xbd,0x81,0x81,0x85,0x82,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25114 0x621a "戚" */
+0x00,0x00,0x00,0x3f,0x22,0x23,0x22,0x22,0x3f,0x20,0x22,0x2a,0x32,0x42,0x4a,0x84,
+0x28,0x24,0x20,0xfe,0x20,0xa0,0x24,0x24,0xe4,0x28,0x28,0x90,0x52,0x2a,0x46,0x82,
+/* 25115 0x621b "戛" */
+0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x03,0x7e,0x01,0x00,0x07,0x38,
+0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x40,0xf8,0x20,0x40,0x84,0x64,0x1c,
+/* 25116 0x621c "戜" */
+0x00,0x00,0x00,0xff,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x08,0x3e,0x08,0x0f,0x78,0x23,
+0x50,0x48,0x40,0xfe,0x40,0x40,0x44,0x44,0x44,0x28,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 25117 0x621d "戝" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x00,0x24,0x22,0x41,0x81,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25118 0x621e "戞" */
+0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x7f,0x42,0x83,0x7e,0x01,0x00,0x07,0x38,
+0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x42,0xfc,0x20,0x40,0x84,0x64,0x1c,
+/* 25119 0x621f "戟" */
+0x08,0x08,0xff,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x49,0x08,0xff,0x08,0x08,0x08,0x09,
+0x20,0x28,0xa4,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x90,0x32,0x4a,0x86,0x02,
+/* 25120 0x6220 "戠" */
+0x10,0x08,0xff,0x00,0x42,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+0x40,0x48,0x44,0x44,0x40,0x40,0xfe,0x40,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 25121 0x6221 "戡" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3f,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x01,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 25122 0x6222 "戢" */
+0x3f,0x21,0x21,0x3f,0x00,0xff,0x21,0x3f,0x21,0x3f,0x21,0x27,0xf9,0x41,0x01,0x01,
+0x28,0x24,0x24,0x20,0x20,0xfe,0x20,0x24,0x24,0x28,0x28,0xd0,0x12,0x2a,0x46,0x82,
+/* 25123 0x6223 "戣" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x41,0xbe,0x08,0x08,0x7f,0x08,0x14,0x12,0x22,0x40,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25124 0x6224 "戤" */
+0x00,0x7e,0x22,0x24,0x3f,0x55,0x49,0x55,0xa2,0x00,0x7f,0x55,0x55,0x57,0xfc,0x00,
+0x10,0x14,0x12,0x10,0x16,0x78,0x12,0x12,0x12,0x14,0x14,0x08,0x1a,0xaa,0x46,0x82,
+/* 25125 0x6225 "戥" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x09,0x48,0x7f,0x88,0x7e,0x08,0x0f,0xf0,0x40,0x01,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 25126 0x6226 "戦" */
+0x90,0x49,0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0x08,0xff,0x08,0x08,0x08,
+0xa8,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x92,0x2a,0x46,0x82,
+/* 25127 0x6227 "戧" */
+0x08,0x0c,0x12,0x29,0x44,0xbf,0x21,0x3f,0x21,0x3f,0x20,0x3f,0x51,0x51,0x9f,0x11,
+0x28,0x24,0x24,0x20,0xae,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25128 0x6228 "戨" */
+0x00,0xff,0x02,0x7a,0x4a,0x7a,0x00,0xff,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25129 0x6229 "戩" */
+0x00,0xff,0x22,0x55,0xf7,0x00,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25130 0x622a "截" */
+0x08,0x08,0x7f,0x08,0xff,0x14,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x20,0x20,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x24,0xa4,0x24,0x28,0x28,0x10,0x12,0xaa,0x46,0x82,
+/* 25131 0x622b "戫" */
+0x10,0x10,0xfe,0x11,0x20,0x3c,0x25,0x65,0xbd,0x25,0x25,0x3c,0x24,0x27,0x24,0x2c,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xca,0x1a,0x26,0x42,
+/* 25132 0x622c "戬" */
+0x00,0x7f,0x12,0x52,0x33,0x12,0xff,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,
+0x10,0x94,0x12,0x90,0x16,0x78,0xd2,0x12,0x12,0x14,0x14,0x08,0x1a,0x2a,0x46,0x82,
+/* 25133 0x622d "戭" */
+0x10,0x08,0xff,0x80,0x00,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0x22,0x41,0x80,
+0x10,0x14,0x92,0x90,0x16,0x78,0x12,0x12,0x12,0x14,0x14,0x08,0x1a,0x2a,0x46,0x82,
+/* 25134 0x622e "戮" */
+0x00,0x77,0x11,0x55,0x33,0x55,0x0c,0x33,0xc4,0x18,0x62,0x0c,0x71,0x06,0x18,0xe0,
+0x10,0x14,0x12,0x10,0x16,0x78,0x12,0x12,0x92,0x14,0x14,0x88,0x1a,0x2a,0x46,0x82,
+/* 25135 0x622f "戯" */
+0x10,0x1e,0x10,0x7f,0x51,0x5c,0x72,0x4e,0x40,0x4a,0x6a,0x5b,0x4a,0x8f,0x78,0x00,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0xa8,0x10,0x12,0x2a,0x46,0x82,
+/* 25136 0x6230 "戰" */
+0x00,0xf7,0x94,0x94,0xf7,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x10,0x94,0x92,0x90,0x96,0x78,0x12,0x12,0x12,0x14,0x14,0x08,0x9a,0x2a,0x46,0x82,
+/* 25137 0x6231 "戱" */
+0x08,0x0f,0x08,0x7f,0x48,0x4e,0x79,0x47,0x40,0x4a,0x6a,0xaa,0xbb,0x0a,0x7f,0x20,
+0x10,0x14,0x12,0x90,0x96,0x78,0x12,0x12,0x12,0x14,0x94,0x88,0x9a,0x2a,0x46,0x82,
+/* 25138 0x6232 "戲" */
+0x08,0x0f,0x08,0x7f,0x49,0x4c,0x79,0x47,0x40,0x5f,0x40,0x5f,0x51,0x5f,0x8a,0x3f,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 25139 0x6233 "戳" */
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x01,0x24,0x7f,0xc8,0x7e,0x48,0x7e,0x48,0x7f,0x41,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 25140 0x6234 "戴" */
+0x08,0x7f,0x08,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x22,0x7f,0x22,0xff,0x22,0x41,
+0x20,0x28,0x24,0xfe,0x20,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0xaa,0x46,0x82,
+/* 25141 0x6235 "戵" */
+0x77,0x55,0x77,0x55,0x77,0x55,0x77,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x20,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x24,0xa4,0x28,0x28,0x10,0x12,0x2a,0xc6,0x82,
+/* 25142 0x6236 "戶" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x10,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25143 0x6237 "户" */
+0x02,0x01,0x01,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x20,0x20,0x40,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25144 0x6238 "戸" */
+0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25145 0x6239 "戹" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x20,0x20,0x21,0x42,0x44,0x84,0x03,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xf0,0x20,0xc0,0x00,0x00,0x04,0x04,0xfc,
+/* 25146 0x623a "戺" */
+0x08,0x04,0x04,0x3f,0x21,0x21,0x21,0x3f,0x21,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,
+/* 25147 0x623b "戻" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x2f,0x21,0x21,0x42,0x44,0x88,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x80,0x80,0x80,0xfc,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 25148 0x623c "戼" */
+0x00,0xfc,0x04,0x04,0x04,0x7c,0x44,0x44,0x44,0x7c,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x7e,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x7c,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 25149 0x623d "戽" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x22,0x21,0x24,0x22,0x20,0x5f,0x40,0x80,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x20,0x20,0x20,0x20,0x7e,0xa0,0x20,0x20,0x20,
+/* 25150 0x623e "戾" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x2f,0x21,0x21,0x42,0x44,0x88,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x80,0xa0,0x90,0xfc,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 25151 0x623f "房" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x21,0x20,0x3f,0x22,0x22,0x23,0x44,0x44,0x88,0x10,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x80,0xfc,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,
+/* 25152 0x6240 "所" */
+0x02,0x07,0x38,0x20,0x20,0x3e,0x22,0x22,0x22,0x3e,0x20,0x20,0x41,0x41,0x82,0x04,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 25153 0x6241 "扁" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x29,0x29,0x2f,0x49,0x49,0x89,0x08,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 25154 0x6242 "扂" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x80,0x80,0xfc,0x80,0x80,0xf8,0x08,0x08,0xf8,0x08,
+/* 25155 0x6243 "扃" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2f,0x28,0x29,0x29,0x49,0x49,0x88,0x08,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 25156 0x6244 "扄" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x21,0x22,0x2f,0x28,0x29,0x29,0x49,0x49,0x88,0x08,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 25157 0x6245 "扅" */
+0x01,0x00,0x3f,0x20,0x3f,0x21,0x23,0x2c,0x22,0x23,0x3c,0x23,0x4c,0x40,0x81,0x1e,
+0x00,0x80,0xfc,0x04,0xfc,0x00,0xf0,0x20,0xc0,0x40,0xfc,0x08,0x90,0x60,0x80,0x00,
+/* 25158 0x6246 "扆" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x21,0x20,0x2f,0x21,0x22,0x26,0x4a,0x52,0x83,0x02,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x80,0xfc,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 25159 0x6247 "扇" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x21,0x29,0x25,0x49,0x51,0x85,0x02,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x04,0x24,0x14,0x24,0x44,0x14,0x08,
+/* 25160 0x6248 "扈" */
+0x01,0x00,0x3f,0x20,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x28,0x4f,0x48,0x88,0x07,
+0x00,0x80,0xfc,0x04,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x88,0xf8,0x02,0x02,0xfe,
+/* 25161 0x6249 "扉" */
+0x01,0x00,0x3f,0x20,0x3f,0x21,0x21,0x3f,0x21,0x21,0x2f,0x21,0x41,0x5f,0x81,0x01,
+0x00,0x80,0xfc,0x04,0xfc,0x20,0x20,0x3e,0x20,0x20,0x3c,0x20,0x20,0x3e,0x20,0x20,
+/* 25162 0x624a "扊" */
+0x01,0x00,0x3f,0x20,0x3f,0x24,0x24,0x29,0x22,0x2c,0x34,0x24,0x49,0x42,0x8c,0x30,
+0x00,0x80,0xfc,0x04,0xfc,0x88,0x90,0x60,0x18,0x84,0x8a,0x88,0x50,0x20,0x18,0x06,
+/* 25163 0x624b "手" */
+0x00,0x00,0x3f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x05,0x02,
+0x10,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25164 0x624c "扌" */
+0x10,0x10,0x10,0x10,0xf8,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25165 0x624d "才" */
+0x00,0x00,0x00,0x00,0xff,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x40,0x02,0x01,
+0x80,0x80,0x80,0x80,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 25166 0x624e "扎" */
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x12,0x1c,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 25167 0x624f "扏" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 25168 0x6250 "扐" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 25169 0x6251 "扑" */
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x12,0x1c,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x80,0x80,0x80,0x80,0x80,0xa0,0x90,0x88,0x84,0x84,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 25170 0x6252 "扒" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd2,0x12,0x12,0x14,0x54,0x28,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 25171 0x6253 "打" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 25172 0x6254 "扔" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x18,0x30,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 25173 0x6255 "払" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x14,0x19,0x31,0xd1,0x12,0x17,0x12,0x50,0x20,
+0x40,0x40,0x40,0x40,0x40,0x80,0x80,0x80,0x00,0x10,0x08,0x08,0xfc,0x04,0x04,0x00,
+/* 25174 0x6256 "扖" */
+0x12,0x11,0x10,0x10,0xfc,0x10,0x10,0x14,0x18,0x30,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x00,0x00,0x80,0x80,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 25175 0x6257 "扗" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x11,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x53,0x20,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25176 0x6258 "托" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x08,0x3c,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 25177 0x6259 "扙" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x15,0x19,0x30,0xd0,0x10,0x10,0x10,0x51,0x26,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 25178 0x625a "扚" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x15,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 25179 0x625b "扛" */
+0x10,0x10,0x11,0x10,0xfe,0x10,0x10,0x12,0x1c,0x30,0xd0,0x10,0x10,0x10,0x53,0x20,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25180 0x625c "扜" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 25181 0x625d "扝" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 25182 0x625e "扞" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 25183 0x625f "扟" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x10,0x13,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 25184 0x6260 "扠" */
+0x10,0x17,0x12,0x12,0xfe,0x11,0x11,0x15,0x18,0x30,0xd0,0x10,0x10,0x11,0x52,0x2c,
+0x00,0xf8,0x08,0x88,0x48,0x50,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 25185 0x6261 "扡" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x17,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 25186 0x6262 "扢" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x50,0x20,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 25187 0x6263 "扣" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 25188 0x6264 "扤" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 25189 0x6265 "扥" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x33,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0x20,0x3c,0xe0,0x20,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 25190 0x6266 "扦" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x10,0x17,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 25191 0x6267 "执" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x19,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 25192 0x6268 "扨" */
+0x10,0x10,0x11,0x10,0xfc,0x11,0x11,0x15,0x19,0x32,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 25193 0x6269 "扩" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25194 0x626a "扪" */
+0x11,0x10,0x10,0x12,0xfa,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x12,0x52,0x22,
+0x00,0x80,0xbc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 25195 0x626b "扫" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x15,0x18,0x30,0xd0,0x10,0x10,0x13,0x50,0x20,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 25196 0x626c "扬" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x11,0x14,0x18,0x30,0xd1,0x11,0x12,0x14,0x50,0x21,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 25197 0x626d "扭" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x10,0x15,0x18,0x30,0xd0,0x10,0x10,0x10,0x57,0x20,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfe,0x00,
+/* 25198 0x626e "扮" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x12,0x15,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 25199 0x626f "扯" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x57,0x20,
+0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25200 0x6270 "扰" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x11,0x51,0x22,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 25201 0x6271 "扱" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x10,0x14,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x21,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25202 0x6272 "扲" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x14,0x10,0x18,0x33,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x88,0x46,0x40,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,
+/* 25203 0x6273 "扳" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 25204 0x6274 "扴" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x12,0x10,0x18,0x30,0xd0,0x10,0x10,0x11,0x51,0x22,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 25205 0x6275 "扵" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x15,0x1a,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x60,0x10,0x00,0xc0,0x20,0x10,0x08,0x00,
+/* 25206 0x6276 "扶" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 25207 0x6277 "扷" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x13,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 25208 0x6278 "扸" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x10,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 25209 0x6279 "批" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 25210 0x627a "扺" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x17,0x1a,0x32,0xd2,0x12,0x12,0x12,0x53,0x22,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x06,0x02,
+/* 25211 0x627b "扻" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x12,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 25212 0x627c "扼" */
+0x20,0x23,0x22,0x22,0xfa,0x22,0x22,0x2a,0x32,0xe2,0x22,0x22,0x24,0x24,0xa8,0x50,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xa8,0x90,0x82,0x82,0x82,0x7e,0x00,
+/* 25213 0x627d "扽" */
+0x10,0x10,0x10,0x13,0xfc,0x11,0x11,0x15,0x19,0x31,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 25214 0x627e "找" */
+0x10,0x10,0x10,0x10,0xfc,0x13,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x11,0x52,0x20,
+0x90,0x88,0x88,0x80,0xbc,0xc0,0x80,0x88,0x88,0x90,0x60,0x44,0xa4,0x14,0x0c,0x04,
+/* 25215 0x627f "承" */
+0x1f,0x00,0x00,0x01,0x79,0x0f,0x09,0x11,0x17,0x21,0x21,0x4f,0x81,0x01,0x05,0x02,
+0xe0,0x40,0x80,0x04,0x28,0xf0,0x20,0x10,0xd0,0x08,0x08,0xe4,0x02,0x00,0x00,0x00,
+/* 25216 0x6280 "技" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x15,0x18,0x30,0xd0,0x10,0x10,0x10,0x51,0x26,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 25217 0x6281 "抁" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 25218 0x6282 "抂" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x19,0x30,0xd0,0x10,0x10,0x10,0x57,0x20,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25219 0x6283 "抃" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0x20,0x00,0xfe,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,
+/* 25220 0x6284 "抄" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x11,0x15,0x1a,0x30,0xd0,0x10,0x10,0x10,0x50,0x23,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 25221 0x6285 "抅" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x18,0x31,0xd3,0x11,0x10,0x10,0x50,0x20,
+0x80,0x80,0x80,0xfe,0x02,0x42,0x42,0x82,0xa2,0x12,0xfa,0x0a,0x02,0x02,0x14,0x08,
+/* 25222 0x6286 "抆" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x51,0x26,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25223 0x6287 "抇" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfa,0x02,0x02,0x02,0x02,0x02,0xfe,0x02,0x00,
+/* 25224 0x6288 "抈" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 25225 0x6289 "抉" */
+0x10,0x10,0x10,0x13,0xf8,0x10,0x14,0x18,0x37,0xd0,0x10,0x10,0x11,0x11,0x52,0x24,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 25226 0x628a "把" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 25227 0x628b "抋" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x12,0x1a,0x32,0xd2,0x14,0x10,0x10,0x50,0x20,
+0x00,0x40,0x20,0x10,0x90,0x80,0x80,0x84,0x82,0x82,0x82,0x88,0x88,0x88,0x78,0x00,
+/* 25228 0x628c "抌" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 25229 0x628d "抍" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x11,0x11,0x52,0x24,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 25230 0x628e "抎" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x13,0x14,0x18,0x30,0xd0,0x10,0x11,0x13,0x51,0x20,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 25231 0x628f "抏" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x13,0x10,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 25232 0x6290 "抐" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 25233 0x6291 "抑" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x13,0x12,0x10,0x50,0x20,
+0x00,0x80,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xb4,0x28,0x20,0x20,0x20,0x20,
+/* 25234 0x6292 "抒" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x13,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 25235 0x6293 "抓" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x48,0x44,0x44,0x42,0x00,
+/* 25236 0x6294 "抔" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 25237 0x6295 "投" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x12,0x15,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x23,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 25238 0x6296 "抖" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x10,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x50,0x20,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 25239 0x6297 "抗" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 25240 0x6298 "折" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 25241 0x6299 "抙" */
+0x10,0x10,0x11,0x10,0xfc,0x11,0x10,0x14,0x18,0x33,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x08,0x3c,0xe0,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 25242 0x629a "抚" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x17,0x10,0x18,0x30,0xd0,0x11,0x11,0x12,0x54,0x28,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 25243 0x629b "抛" */
+0x12,0x12,0x12,0x12,0xfa,0x17,0x12,0x1a,0x32,0xd2,0x12,0x12,0x14,0x14,0x58,0x30,
+0x10,0x10,0x10,0x7c,0x14,0x94,0x94,0x94,0xa4,0xa4,0xd4,0x8a,0x82,0x82,0x7e,0x00,
+/* 25244 0x629c "抜" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x14,0x18,0x31,0xd1,0x11,0x12,0x12,0x14,0x58,0x23,
+0x40,0x40,0x40,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 25245 0x629d "抝" */
+0x20,0x20,0x21,0x21,0xfa,0x22,0x27,0x28,0x30,0xe1,0x21,0x22,0x27,0x22,0xa0,0x40,
+0x80,0x80,0x3e,0x02,0x42,0x42,0xc2,0x82,0x82,0x02,0x42,0x22,0xe2,0x22,0x0a,0x04,
+/* 25246 0x629e "択" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 25247 0x629f "抟" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x11,0x14,0x18,0x31,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfc,0x20,0x40,0xfe,0x40,0x80,0xfc,0x04,0x88,0x50,0x20,0x10,0x10,
+/* 25248 0x62a0 "抠" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 25249 0x62a1 "抡" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x14,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 25250 0x62a2 "抢" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x14,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 25251 0x62a3 "抣" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x10,0x50,0x20,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 25252 0x62a4 "护" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x40,0x20,0x20,0xfe,0x02,0x02,0x02,0xfe,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 25253 0x62a5 "报" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x04,0x04,0x14,0x08,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25254 0x62a6 "抦" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x12,0x16,0x1a,0x32,0xd2,0x13,0x12,0x12,0x52,0x22,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 25255 0x62a7 "抧" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 25256 0x62a8 "抨" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 25257 0x62a9 "抩" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd7,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 25258 0x62aa "抪" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x15,0x19,0x33,0xd5,0x11,0x11,0x11,0x11,0x50,0x20,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 25259 0x62ab "披" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25260 0x62ac "抬" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x10,0x14,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25261 0x62ad "抭" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x10,0x18,0x30,0xd0,0x10,0x10,0x11,0x11,0x52,0x24,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0xf0,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 25262 0x62ae "抮" */
+0x10,0x10,0x10,0x11,0xfa,0x14,0x10,0x18,0x33,0xd0,0x10,0x10,0x13,0x10,0x50,0x27,
+0x40,0x40,0xa0,0x10,0x08,0x26,0x40,0x80,0x10,0x20,0x40,0x88,0x10,0x20,0xc0,0x00,
+/* 25263 0x62af "抯" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x57,0x20,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 25264 0x62b0 "抰" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x33,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 25265 0x62b1 "抱" */
+0x10,0x10,0x11,0x11,0xfa,0x15,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x11,0x50,0x20,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 25266 0x62b2 "抲" */
+0x10,0x10,0x17,0x10,0xfc,0x13,0x12,0x16,0x1a,0x32,0xd3,0x12,0x10,0x10,0x50,0x20,
+0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0x48,0xc8,0x48,0x08,0x08,0x28,0x10,
+/* 25267 0x62b3 "抳" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 25268 0x62b4 "抴" */
+0x20,0x22,0x22,0x22,0xfa,0x27,0x22,0x2a,0x32,0xe2,0x22,0x22,0x22,0x22,0xa3,0x40,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 25269 0x62b5 "抵" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x13,0x1a,0x32,0xd2,0x12,0x12,0x12,0x53,0x22,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 25270 0x62b6 "抶" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x12,0x10,0x1b,0x30,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 25271 0x62b7 "抷" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x10,0x57,0x20,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 25272 0x62b8 "抸" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x13,0x14,0x18,0x30,0xd0,0x10,0x11,0x12,0x54,0x20,
+0x08,0x3c,0xc0,0x00,0x40,0x20,0xfc,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x7e,0x00,
+/* 25273 0x62b9 "抹" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x15,0x18,0x30,0xd0,0x11,0x11,0x12,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 25274 0x62ba "抺" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x10,0x13,0x18,0x30,0xd0,0x11,0x11,0x12,0x50,0x20,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 25275 0x62bb "抻" */
+0x10,0x10,0x10,0x13,0xfa,0x12,0x16,0x1b,0x32,0xd2,0x12,0x13,0x12,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0xfe,0x22,0x22,0x22,0xfe,0x22,0x20,0x20,0x20,
+/* 25276 0x62bc "押" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 25277 0x62bd "抽" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 25278 0x62be "抾" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x11,0x53,0x21,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,
+/* 25279 0x62bf "抿" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x12,0x16,0x1b,0x32,0xd2,0x12,0x12,0x12,0x53,0x22,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 25280 0x62c0 "拀" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x14,0x18,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 25281 0x62c1 "拁" */
+0x22,0x22,0x22,0x22,0xf7,0x22,0x22,0x22,0x32,0xe2,0x22,0x22,0x24,0x24,0xa9,0x50,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x80,
+/* 25282 0x62c2 "拂" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x13,0x16,0x1a,0x33,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 25283 0x62c3 "拃" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x12,0x10,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 25284 0x62c4 "拄" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x14,0x19,0x30,0xd0,0x10,0x10,0x10,0x53,0x20,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25285 0x62c5 "担" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x53,0x20,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 25286 0x62c6 "拆" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 25287 0x62c7 "拇" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x17,0x1a,0x32,0xd2,0x12,0x13,0x10,0x50,0x20,
+0x00,0xf8,0x08,0x48,0x28,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0xfe,0x08,0x50,0x20,
+/* 25288 0x62c8 "拈" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x14,0x18,0x33,0xd2,0x12,0x12,0x12,0x12,0x53,0x22,
+0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25289 0x62c9 "拉" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x14,0x19,0x31,0xd0,0x10,0x10,0x10,0x10,0x57,0x20,
+0x40,0x20,0x20,0x00,0xfe,0x00,0x04,0x04,0x04,0x88,0x88,0x88,0x90,0x10,0xfe,0x00,
+/* 25290 0x62ca "拊" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x15,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 25291 0x62cb "拋" */
+0x22,0x22,0x22,0x22,0xfa,0x27,0x22,0x2a,0x32,0xe2,0x22,0x22,0x24,0x24,0xa8,0x50,
+0x10,0x10,0x10,0x7c,0x14,0xd4,0x94,0x94,0xa4,0xa4,0xd4,0x8a,0x82,0x82,0x7e,0x00,
+/* 25292 0x62cc "拌" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x11,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 25293 0x62cd "拍" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25294 0x62ce "拎" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x14,0x10,0x1b,0x30,0xd0,0x11,0x10,0x10,0x50,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 25295 0x62cf "拏" */
+0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x00,0x00,0xfc,0x44,0x28,0x10,0x28,0xc6,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25296 0x62d0 "拐" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 25297 0x62d1 "拑" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 25298 0x62d2 "拒" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 25299 0x62d3 "拓" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 25300 0x62d4 "拔" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x14,0x18,0x31,0xd1,0x11,0x11,0x12,0x12,0x54,0x21,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25301 0x62d5 "拕" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x10,0x14,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 25302 0x62d6 "拖" */
+0x10,0x10,0x10,0x11,0xfe,0x11,0x11,0x15,0x1b,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 25303 0x62d7 "拗" */
+0x20,0x21,0x21,0x22,0xfa,0x24,0x27,0x29,0x32,0xe2,0x24,0x27,0x20,0x20,0xa0,0x41,
+0x20,0x20,0x20,0x20,0xfc,0xa4,0x24,0x24,0x24,0x24,0xa4,0xa4,0xc4,0x44,0x94,0x08,
+/* 25304 0x62d8 "拘" */
+0x10,0x10,0x11,0x11,0xfa,0x14,0x11,0x19,0x31,0xd1,0x11,0x11,0x10,0x10,0x50,0x20,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 25305 0x62d9 "拙" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x15,0x18,0x30,0xd0,0x12,0x12,0x12,0x12,0x53,0x20,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x22,0x22,0x22,0x22,0xfe,0x02,
+/* 25306 0x62da "拚" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x10,0x14,0x18,0x33,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 25307 0x62db "招" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x11,0x12,0x1c,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25308 0x62dc "拜" */
+0x04,0x1e,0xf0,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x11,0x10,0x20,0x20,0x40,0x80,
+0x00,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 25309 0x62dd "拝" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x10,0x15,0x18,0x30,0xd3,0x10,0x10,0x10,0x50,0x20,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 25310 0x62de "拞" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x57,0x20,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 25311 0x62df "拟" */
+0x10,0x10,0x10,0x12,0xfa,0x12,0x12,0x1a,0x32,0xd2,0x12,0x12,0x13,0x12,0x50,0x20,
+0x08,0x88,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x10,0x98,0x24,0x24,0x42,0x82,
+/* 25312 0x62e0 "拠" */
+0x22,0x22,0x22,0xfb,0x22,0x22,0x34,0x26,0xea,0x22,0x21,0x21,0x22,0x22,0xa4,0x48,
+0x00,0x38,0x28,0xa8,0xa8,0xa8,0xa8,0xaa,0xaa,0xaa,0x26,0x40,0x80,0x60,0x1e,0x00,
+/* 25313 0x62e1 "拡" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 25314 0x62e2 "拢" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x14,0x18,0x30,0xd1,0x11,0x11,0x12,0x12,0x54,0x28,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0x28,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 25315 0x62e3 "拣" */
+0x10,0x10,0x17,0x10,0xfc,0x13,0x11,0x12,0x1b,0x30,0xd1,0x11,0x12,0x14,0x50,0x20,
+0x40,0x40,0xfc,0x80,0x80,0xe0,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 25316 0x62e4 "拤" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x14,0x1b,0x30,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x40,0x40,0x50,0x48,0x44,0x40,0x40,0x40,
+/* 25317 0x62e5 "拥" */
+0x20,0x27,0x24,0x24,0xfc,0x27,0x24,0x2c,0x34,0xe7,0x24,0x24,0x24,0x28,0xa8,0x50,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0x54,0x08,
+/* 25318 0x62e6 "拦" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x14,0x18,0x31,0xd0,0x10,0x10,0x10,0x53,0x20,
+0x00,0x08,0x88,0x90,0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 25319 0x62e7 "拧" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x10,0x18,0x33,0xd0,0x10,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 25320 0x62e8 "拨" */
+0x10,0x10,0x12,0x12,0xfb,0x10,0x14,0x18,0x31,0xd1,0x11,0x12,0x12,0x14,0x58,0x23,
+0x40,0x48,0x44,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 25321 0x62e9 "择" */
+0x20,0x27,0x22,0x21,0xf0,0x20,0x21,0x26,0x30,0xe3,0x20,0x20,0x27,0x20,0xa0,0x40,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,
+/* 25322 0x62ea "拪" */
+0x10,0x17,0x10,0x10,0xfc,0x13,0x12,0x16,0x1a,0x32,0xd2,0x13,0x12,0x12,0x53,0x22,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 25323 0x62eb "拫" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 25324 0x62ec "括" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x10,0x14,0x18,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25325 0x62ed "拭" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x14,0x1b,0x31,0xd1,0x11,0x11,0x11,0x17,0x52,0x20,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xa0,0x20,0x10,0x10,0x10,0xca,0x0a,0x06,0x02,
+/* 25326 0x62ee "拮" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x14,0x18,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25327 0x62ef "拯" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x10,0x14,0x19,0x31,0xd2,0x14,0x10,0x10,0x57,0x20,
+0x00,0xfc,0x08,0x10,0x22,0xb2,0xb4,0xa8,0x28,0x24,0x22,0xa0,0x40,0x00,0xfe,0x00,
+/* 25328 0x62f0 "拰" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x15,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 25329 0x62f1 "拱" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x33,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 25330 0x62f2 "拲" */
+0x04,0x04,0x7f,0x04,0xff,0x08,0x30,0xc0,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x40,0x40,0xfc,0x40,0xfe,0x20,0x18,0xe6,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25331 0x62f3 "拳" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x3f,0xc1,0x1f,0x01,0x3f,0x01,0x05,0x02,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0xf0,0x08,0x06,0xe0,0x00,0xf8,0x00,0x00,0x00,
+/* 25332 0x62f4 "拴" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x11,0x14,0x18,0x30,0xd1,0x10,0x10,0x10,0x53,0x20,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25333 0x62f5 "拵" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x15,0x1b,0x35,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x78,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 25334 0x62f6 "拶" */
+0x11,0x11,0x12,0x11,0xfd,0x10,0x10,0x14,0x19,0x31,0xd2,0x14,0x10,0x10,0x50,0x23,
+0x24,0x24,0x48,0x24,0x24,0x00,0x80,0xfc,0x04,0x84,0x48,0x28,0x10,0x20,0xc0,0x00,
+/* 25335 0x62f7 "拷" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x10,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x50,0x20,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 25336 0x62f8 "拸" */
+0x10,0x10,0x10,0x11,0xfa,0x10,0x14,0x19,0x36,0xd0,0x10,0x13,0x10,0x10,0x50,0x27,
+0x40,0x40,0xfc,0x08,0x90,0x60,0x48,0x90,0x3e,0x42,0x84,0x48,0x30,0x20,0xc0,0x00,
+/* 25337 0x62f9 "拹" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x15,0x1a,0x31,0xd3,0x11,0x11,0x11,0x12,0x53,0x24,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 25338 0x62fa "拺" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x11,0x15,0x19,0x31,0xd0,0x10,0x11,0x16,0x50,0x20,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x2c,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 25339 0x62fb "拻" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x15,0x19,0x31,0xd2,0x12,0x14,0x10,0x50,0x21,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x90,0x12,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 25340 0x62fc "拼" */
+0x11,0x10,0x10,0x10,0xfd,0x10,0x10,0x14,0x18,0x33,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 25341 0x62fd "拽" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x30,0xd0,0x10,0x10,0x10,0x53,0x20,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 25342 0x62fe "拾" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x11,0x14,0x18,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25343 0x62ff "拿" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25344 0x6300 "挀" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x04,0x1e,0xe0,0x00,0x06,0x78,0x50,0x50,0x52,0x54,0x48,0x48,0x44,0x54,0x62,0x40,
+/* 25345 0x6301 "持" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x13,0x10,0x18,0x33,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 25346 0x6302 "挂" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x13,0x10,0x18,0x30,0xd1,0x10,0x10,0x10,0x53,0x20,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25347 0x6303 "挃" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x11,0x14,0x18,0x30,0xd1,0x10,0x10,0x10,0x53,0x20,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 25348 0x6304 "挄" */
+0x10,0x10,0x12,0x11,0xfd,0x10,0x17,0x10,0x18,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 25349 0x6305 "挅" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x15,0x1a,0x30,0xd7,0x10,0x10,0x11,0x12,0x54,0x20,
+0x00,0xf8,0x88,0x90,0xbc,0x04,0x14,0x48,0x40,0xfe,0x40,0xe0,0x50,0x48,0x46,0x40,
+/* 25350 0x6306 "挆" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x12,0x14,0x1b,0x30,0xd0,0x11,0x12,0x14,0x50,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x4e,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 25351 0x6307 "指" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0x04,0x38,0xc0,0x02,0x02,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 25352 0x6308 "挈" */
+0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x08,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x00,0x7c,0x24,0x24,0x24,0x44,0x54,0xf8,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25353 0x6309 "按" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x10,0x1b,0x30,0xd0,0x11,0x10,0x10,0x10,0x50,0x23,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 25354 0x630a "挊" */
+0x10,0x10,0x10,0x10,0xfc,0x13,0x10,0x10,0x1b,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x40,0x40,0x40,
+/* 25355 0x630b "挋" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x12,0x16,0x1a,0x32,0xd3,0x12,0x12,0x12,0x53,0x20,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25356 0x630c "挌" */
+0x10,0x10,0x11,0x12,0xfd,0x10,0x14,0x18,0x33,0xdc,0x13,0x12,0x12,0x12,0x53,0x22,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 25357 0x630d "挍" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x12,0x18,0x30,0xd0,0x10,0x10,0x10,0x50,0x23,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 25358 0x630e "挎" */
+0x20,0x20,0x27,0x20,0xf1,0x22,0x2d,0x20,0x37,0xe0,0x21,0x23,0x20,0x20,0xa0,0x40,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 25359 0x630f "挏" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 25360 0x6310 "挐" */
+0x10,0x10,0xfe,0x22,0x42,0x34,0x08,0x34,0xc2,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25361 0x6311 "挑" */
+0x10,0x10,0x10,0x12,0xfd,0x10,0x10,0x15,0x1a,0x34,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 25362 0x6312 "挒" */
+0x20,0x20,0x2f,0x22,0xfa,0x23,0x22,0x2c,0x36,0xe5,0x28,0x20,0x21,0x22,0xa4,0x48,
+0x02,0x02,0xc2,0x12,0x12,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x02,0x02,0x0a,0x04,
+/* 25363 0x6313 "挓" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x10,0x1b,0x30,0xd0,0x10,0x17,0x10,0x10,0x50,0x20,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x38,0xc0,0x40,0x40,0x7e,0xc0,0x40,0x42,0x42,0x3e,
+/* 25364 0x6314 "挔" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 25365 0x6315 "挕" */
+0x10,0x13,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x17,0x10,0x50,0x20,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 25366 0x6316 "挖" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x12,0x14,0x18,0x30,0xd0,0x10,0x11,0x11,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x02,0xf8,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 25367 0x6317 "挗" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x11,0x15,0x19,0x30,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 25368 0x6318 "挘" */
+0x10,0x10,0x11,0x11,0xfa,0x10,0x14,0x1b,0x30,0xd0,0x13,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x24,0x22,0x2a,0x10,0x60,0x80,0x40,0x40,0xfc,0x44,0x84,0x84,0x14,0x08,
+/* 25369 0x6319 "挙" */
+0x22,0x11,0x11,0x00,0xff,0x08,0x10,0x20,0xdf,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x08,0x08,0x10,0x20,0xfe,0x20,0x10,0xe8,0x06,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25370 0x631a "挚" */
+0x10,0xfb,0x10,0x19,0xf0,0x11,0x52,0x24,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x80,0xf0,0x90,0x90,0x94,0x54,0x0c,0xe4,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25371 0x631b "挛" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x44,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0xf0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25372 0x631c "挜" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x14,0x12,0x1a,0x32,0xd0,0x10,0x10,0x10,0x57,0x20,
+0x00,0xfc,0x90,0x90,0x90,0x92,0x92,0x94,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 25373 0x631d "挝" */
+0x24,0x22,0x22,0x20,0xf8,0x2e,0x22,0x2a,0x32,0xe2,0x22,0x22,0x22,0x25,0xa8,0x40,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,0x00,0xfe,0x00,
+/* 25374 0x631e "挞" */
+0x10,0x12,0x11,0x11,0xfc,0x10,0x13,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x54,0x20,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x24,0x44,0x42,0x82,0x00,0x80,0x7e,0x00,
+/* 25375 0x631f "挟" */
+0x10,0x10,0x10,0x11,0xfc,0x11,0x10,0x14,0x18,0x33,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 25376 0x6320 "挠" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x10,0x13,0x18,0x33,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 25377 0x6321 "挡" */
+0x10,0x12,0x11,0x11,0xfd,0x10,0x17,0x10,0x18,0x30,0xd3,0x10,0x10,0x10,0x57,0x20,
+0x40,0x44,0x44,0x44,0x48,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 25378 0x6322 "挢" */
+0x20,0x20,0x23,0x20,0xf8,0x27,0x20,0x29,0x32,0xe5,0x21,0x21,0x21,0x22,0xa2,0x44,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 25379 0x6323 "挣" */
+0x10,0x10,0x11,0x12,0xf8,0x13,0x10,0x18,0x37,0xd0,0x10,0x13,0x10,0x10,0x51,0x20,
+0x80,0x80,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x80,
+/* 25380 0x6324 "挤" */
+0x10,0x10,0x17,0x12,0xfd,0x10,0x14,0x19,0x36,0xd1,0x11,0x11,0x11,0x12,0x52,0x24,
+0x80,0x40,0xfe,0x08,0x10,0xa0,0x40,0xb0,0x0e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 25381 0x6325 "挥" */
+0x10,0x13,0x12,0x14,0xfc,0x13,0x10,0x14,0x19,0x31,0xd0,0x10,0x17,0x10,0x50,0x20,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 25382 0x6326 "挦" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x10,0x17,0x18,0x30,0xd7,0x11,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x08,0x08,0xfe,0x08,0x88,0x88,0x28,0x10,
+/* 25383 0x6327 "挧" */
+0x10,0x13,0x10,0x10,0xfa,0x11,0x15,0x18,0x30,0xd1,0x12,0x10,0x10,0x10,0x51,0x20,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 25384 0x6328 "挨" */
+0x20,0x20,0x21,0x22,0xf7,0x21,0x21,0x23,0x34,0xe0,0x2f,0x20,0x20,0x21,0xa2,0x4c,
+0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 25385 0x6329 "挩" */
+0x10,0x10,0x10,0x11,0xfa,0x15,0x11,0x19,0x31,0xd1,0x10,0x10,0x10,0x11,0x52,0x24,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 25386 0x632a "挪" */
+0x10,0x17,0x12,0x12,0xfa,0x17,0x12,0x1a,0x32,0xdf,0x12,0x12,0x12,0x14,0x55,0x28,
+0x00,0xde,0x52,0x52,0x54,0xd4,0x58,0x54,0x52,0xd2,0x52,0x5a,0x54,0x50,0x50,0x90,
+/* 25387 0x632b "挫" */
+0x20,0x20,0x22,0x22,0xf2,0x25,0x28,0x20,0x30,0xe7,0x20,0x20,0x20,0x20,0xaf,0x40,
+0x40,0x40,0x48,0x48,0x48,0x54,0xe2,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 25388 0x632c "挬" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x12,0x14,0x19,0x30,0xd0,0x13,0x10,0x10,0x50,0x20,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 25389 0x632d "挭" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x50,0x23,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 25390 0x632e "挮" */
+0x11,0x10,0x10,0x13,0xfc,0x10,0x13,0x16,0x1a,0x33,0xd0,0x10,0x11,0x12,0x54,0x20,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 25391 0x632f "振" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x12,0x17,0x1a,0x32,0xd2,0x12,0x12,0x14,0x54,0x28,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 25392 0x6330 "挰" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x1b,0x30,0xd0,0x11,0x10,0x10,0x53,0x20,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 25393 0x6331 "挱" */
+0x10,0x12,0x11,0x11,0xfc,0x12,0x12,0x10,0x18,0x31,0xd6,0x12,0x12,0x12,0x52,0x20,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 25394 0x6332 "挲" */
+0x20,0x12,0x44,0x20,0x08,0x73,0x20,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x40,0x48,0x44,0x14,0x60,0x80,0x00,0xf0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25395 0x6333 "挳" */
+0x10,0x11,0x10,0x10,0xfd,0x12,0x11,0x14,0x18,0x31,0xd0,0x10,0x10,0x10,0x53,0x20,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25396 0x6334 "挴" */
+0x11,0x11,0x11,0x12,0xfd,0x11,0x11,0x15,0x1b,0x31,0xd2,0x12,0x13,0x10,0x50,0x20,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 25397 0x6335 "挵" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x14,0x1b,0x30,0xd0,0x13,0x10,0x10,0x11,0x51,0x22,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,
+/* 25398 0x6336 "挶" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x20,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 25399 0x6337 "挷" */
+0x21,0x21,0x21,0x27,0xf9,0x21,0x27,0x29,0x31,0xe7,0x21,0x21,0x21,0x22,0xa2,0x44,
+0x00,0x1e,0x12,0xd2,0x14,0x14,0xd8,0x14,0x12,0xd2,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 25400 0x6338 "挸" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x10,0x51,0x22,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 25401 0x6339 "挹" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x13,0x12,0x1a,0x32,0xd3,0x12,0x12,0x12,0x51,0x20,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0x44,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 25402 0x633a "挺" */
+0x20,0x20,0x27,0x21,0xf9,0x22,0x22,0x2f,0x31,0xe5,0x25,0x22,0x22,0x25,0xa8,0x50,
+0x00,0x0c,0x70,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0xfe,0x00,
+/* 25403 0x633b "挻" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x15,0x1b,0x30,0xd2,0x12,0x11,0x11,0x12,0x54,0x28,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 25404 0x633c "挼" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x15,0x18,0x33,0xd0,0x11,0x13,0x10,0x10,0x51,0x26,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 25405 0x633d "挽" */
+0x10,0x10,0x11,0x12,0xfc,0x13,0x12,0x16,0x1a,0x33,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x44,0x44,0x44,0xfc,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 25406 0x633e "挾" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x11,0x15,0x19,0x32,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 25407 0x633f "挿" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x10,0x50,0x20,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0x20,
+/* 25408 0x6340 "捀" */
+0x11,0x11,0x13,0x14,0xfc,0x11,0x16,0x10,0x1b,0x30,0xd3,0x10,0x17,0x10,0x50,0x20,
+0x00,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x40,0x40,0x40,
+/* 25409 0x6341 "捁" */
+0x10,0x11,0x11,0x11,0xfd,0x12,0x10,0x13,0x18,0x30,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 25410 0x6342 "捂" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x10,0x17,0x18,0x30,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 25411 0x6343 "捃" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x14,0x19,0x30,0xd0,0x11,0x12,0x14,0x10,0x50,0x20,
+0x00,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x80,0x80,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 25412 0x6344 "捄" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x11,0x14,0x18,0x30,0xd0,0x11,0x12,0x10,0x50,0x20,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 25413 0x6345 "捅" */
+0x20,0x27,0x20,0x21,0xf8,0x27,0x24,0x2c,0x37,0xe4,0x24,0x27,0x24,0x24,0xa4,0x44,
+0x00,0xf8,0x10,0xa0,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 25414 0x6346 "捆" */
+0x20,0x27,0x24,0x24,0xfc,0x27,0x24,0x2c,0x34,0xe5,0x26,0x24,0x24,0x24,0xa7,0x44,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0xc4,0xe4,0x54,0x44,0x44,0x44,0x04,0xfc,0x04,
+/* 25415 0x6347 "捇" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x13,0x14,0x18,0x31,0xd1,0x11,0x12,0x10,0x50,0x21,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x50,0x50,0x54,0x52,0x52,0x52,0x90,0x90,0x30,
+/* 25416 0x6348 "捈" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x1b,0x30,0xd1,0x11,0x12,0x14,0x50,0x20,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 25417 0x6349 "捉" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 25418 0x634a "捊" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x10,0x1b,0x30,0xd0,0x17,0x10,0x10,0x10,0x50,0x20,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 25419 0x634b "捋" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x15,0x18,0x33,0xd0,0x11,0x10,0x10,0x10,0x50,0x20,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x50,0x20,
+/* 25420 0x634c "捌" */
+0x20,0x27,0x24,0x24,0xfc,0x27,0x22,0x2a,0x37,0xe2,0x22,0x22,0x24,0x24,0xa9,0x50,
+0x04,0xc4,0x44,0x54,0x54,0xd4,0x14,0x14,0xd4,0x54,0x54,0x54,0x44,0x44,0x54,0x88,
+/* 25421 0x634d "捍" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x19,0x30,0xd0,0x13,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 25422 0x634e "捎" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 25423 0x634f "捏" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x30,0xd1,0x10,0x10,0x10,0x53,0x20,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25424 0x6350 "捐" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x13,0x16,0x1a,0x33,0xd2,0x12,0x13,0x12,0x52,0x22,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 25425 0x6351 "捑" */
+0x10,0x10,0x10,0x12,0xfe,0x12,0x12,0x16,0x1a,0x33,0xd0,0x13,0x10,0x10,0x50,0x23,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xe0,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 25426 0x6352 "捒" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x11,0x15,0x19,0x30,0xd0,0x10,0x11,0x12,0x50,0x20,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 25427 0x6353 "捓" */
+0x20,0x27,0x20,0x24,0xf4,0x24,0x27,0x20,0x31,0xe1,0x22,0x22,0x24,0x28,0xa2,0x41,
+0x00,0xde,0x92,0x92,0x94,0x94,0xd8,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x90,0x10,
+/* 25428 0x6354 "捔" */
+0x10,0x10,0x11,0x11,0xfa,0x15,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x12,0x52,0x24,
+0x80,0x80,0xfc,0x04,0x08,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x22,0x22,0x2a,0x04,
+/* 25429 0x6355 "捕" */
+0x10,0x10,0x17,0x10,0xfc,0x13,0x12,0x16,0x1b,0x32,0xd2,0x13,0x12,0x12,0x52,0x22,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 25430 0x6356 "捖" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x10,0x14,0x1b,0x30,0xd0,0x10,0x11,0x11,0x52,0x24,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 25431 0x6357 "捗" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x13,0x14,0x18,0x30,0xd0,0x11,0x12,0x10,0x50,0x23,
+0x10,0x10,0x90,0x9e,0x90,0x90,0xfe,0x00,0x10,0x92,0x92,0x14,0x08,0x10,0x60,0x80,
+/* 25432 0x6358 "捘" */
+0x10,0x10,0x10,0x11,0xfb,0x10,0x14,0x19,0x32,0xd0,0x11,0x12,0x10,0x10,0x51,0x26,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 25433 0x6359 "捙" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x10,0x13,0x10,0x50,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 25434 0x635a "捚" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x30,0xd1,0x10,0x10,0x10,0x53,0x20,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25435 0x635b "捛" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x14,0x18,0x33,0xd2,0x12,0x12,0x12,0x53,0x22,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 25436 0x635c "捜" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x30,0xd3,0x10,0x10,0x10,0x50,0x23,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0xd8,0x06,
+/* 25437 0x635d "捝" */
+0x11,0x10,0x10,0x10,0xfd,0x11,0x11,0x15,0x19,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 25438 0x635e "捞" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x12,0x14,0x18,0x33,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x44,0x40,0xfc,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 25439 0x635f "损" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x50,0x23,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 25440 0x6360 "捠" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd7,0x10,0x10,0x11,0x52,0x24,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,0x02,
+/* 25441 0x6361 "捡" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x15,0x10,0x18,0x30,0xd2,0x11,0x11,0x10,0x57,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 25442 0x6362 "换" */
+0x10,0x10,0x10,0x11,0xfa,0x15,0x11,0x19,0x31,0xd1,0x17,0x10,0x10,0x10,0x51,0x26,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 25443 0x6363 "捣" */
+0x20,0x20,0x23,0x22,0xfa,0x22,0x22,0x2a,0x33,0xe0,0x24,0x24,0x27,0x20,0xa0,0x40,
+0x40,0x80,0xf8,0x08,0x88,0x48,0x18,0x00,0xfe,0x82,0x92,0x92,0xf2,0x02,0x14,0x08,
+/* 25444 0x6364 "捤" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x2a,0x32,0xe2,0x22,0x23,0x22,0x24,0xa4,0x48,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x18,0xe0,0x38,0xe0,0x3c,0xe0,0x22,0x22,0x1e,0x00,
+/* 25445 0x6365 "捥" */
+0x10,0x10,0x13,0x12,0xfd,0x11,0x11,0x12,0x1a,0x33,0xd4,0x10,0x11,0x11,0x52,0x24,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 25446 0x6366 "捦" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x18,0x31,0xd0,0x11,0x10,0x10,0x53,0x20,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 25447 0x6367 "捧" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x32,0xd0,0x10,0x13,0x10,0x50,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 25448 0x6368 "捨" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x1b,0x30,0xd0,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 25449 0x6369 "捩" */
+0x10,0x10,0x13,0x12,0xfa,0x13,0x16,0x1a,0x32,0xd3,0x12,0x12,0x12,0x14,0x55,0x2a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 25450 0x636a "捪" */
+0x10,0x13,0x12,0x13,0xfe,0x12,0x13,0x12,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 25451 0x636b "捫" */
+0x20,0x27,0x24,0x24,0xff,0x24,0x24,0x2f,0x34,0xe4,0x24,0x24,0x24,0x24,0xa4,0x44,
+0x00,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 25452 0x636c "捬" */
+0x20,0x20,0x27,0x24,0xfc,0x24,0x25,0x2d,0x37,0xe5,0x25,0x25,0x29,0x29,0xb1,0x41,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x08,0x7e,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 25453 0x636d "捭" */
+0x10,0x10,0x13,0x12,0xfa,0x13,0x16,0x1a,0x33,0xd0,0x11,0x17,0x10,0x10,0x50,0x20,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 25454 0x636e "据" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x16,0x1b,0x32,0xd2,0x12,0x12,0x12,0x14,0x54,0x28,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 25455 0x636f "捯" */
+0x20,0x20,0x2f,0x22,0xfa,0x24,0x27,0x29,0x31,0xe7,0x21,0x21,0x21,0x2e,0xa4,0x40,
+0x04,0x04,0xc4,0x14,0x14,0x94,0xd4,0x14,0x14,0xd4,0x14,0x14,0xc4,0x04,0x14,0x08,
+/* 25456 0x6370 "捰" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x33,0xd0,0x10,0x11,0x12,0x50,0x20,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 25457 0x6371 "捱" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x12,0x17,0x1a,0x32,0xd2,0x12,0x12,0x14,0x55,0x28,
+0x00,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 25458 0x6372 "捲" */
+0x10,0x11,0x10,0x13,0xfc,0x10,0x17,0x11,0x1a,0x35,0xd9,0x11,0x11,0x11,0x51,0x20,
+0x20,0x24,0xa8,0xfe,0x40,0x80,0xfe,0x08,0x04,0xfa,0x08,0x08,0x28,0x12,0x02,0xfe,
+/* 25459 0x6373 "捳" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x15,0x19,0x37,0xd0,0x10,0x12,0x12,0x12,0x53,0x20,
+0x08,0x1c,0xe0,0x00,0xfe,0x10,0x10,0x10,0xfe,0x00,0x20,0x22,0x22,0x22,0xfe,0x02,
+/* 25460 0x6374 "捴" */
+0x20,0x20,0x21,0x21,0xfa,0x24,0x21,0x2b,0x30,0xe0,0x20,0x22,0x22,0x22,0xa4,0x40,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 25461 0x6375 "捵" */
+0x10,0x10,0x10,0x13,0xfe,0x12,0x12,0x17,0x1a,0x32,0xd2,0x17,0x10,0x10,0x51,0x22,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 25462 0x6376 "捶" */
+0x10,0x10,0x13,0x10,0xf8,0x17,0x12,0x1a,0x37,0xd2,0x12,0x17,0x10,0x10,0x57,0x20,
+0x10,0x78,0xc0,0x40,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0x40,0xfc,0x00,
+/* 25463 0x6377 "捷" */
+0x20,0x20,0x27,0x20,0xfb,0x20,0x27,0x28,0x33,0xe0,0x22,0x22,0x22,0x25,0xa4,0x48,
+0x40,0x40,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 25464 0x6378 "捸" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x10,0x14,0x19,0x32,0xd1,0x10,0x11,0x12,0x50,0x20,
+0x20,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 25465 0x6379 "捹" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x12,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x51,0x22,
+0x20,0x20,0xfe,0x50,0xa8,0x24,0xfa,0x20,0xa8,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 25466 0x637a "捺" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x12,0x10,0x18,0x33,0xd0,0x11,0x11,0x12,0x50,0x20,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0x24,0x22,0x22,0xa0,0x40,
+/* 25467 0x637b "捻" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x11,0x14,0x18,0x30,0xd0,0x12,0x12,0x12,0x54,0x20,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 25468 0x637c "捼" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x15,0x1a,0x30,0xd3,0x10,0x11,0x10,0x10,0x50,0x21,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 25469 0x637d "捽" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x15,0x1a,0x30,0xd0,0x13,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 25470 0x637e "捾" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 25471 0x637f "捿" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x30,0xd3,0x10,0x11,0x10,0x50,0x23,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x40,0xfe,0x84,0xc8,0x30,0xcc,0x02,
+/* 25472 0x6380 "掀" */
+0x20,0x20,0x27,0x24,0xf4,0x24,0x27,0x25,0x35,0xe5,0x25,0x25,0x25,0x29,0xa9,0x50,
+0x10,0x90,0x10,0x3e,0x22,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 25473 0x6381 "掁" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x17,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 25474 0x6382 "掂" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x12,0x1a,0x32,0xd2,0x12,0x12,0x14,0x54,0x28,
+0x40,0x20,0xfe,0x00,0x20,0x20,0x3e,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 25475 0x6383 "掃" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x10,0x13,0x1a,0x30,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 25476 0x6384 "掄" */
+0x20,0x20,0x20,0x21,0xf2,0x2d,0x20,0x27,0x34,0xe4,0x27,0x24,0x24,0x24,0xa4,0x44,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 25477 0x6385 "掅" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 25478 0x6386 "掆" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x52,0x22,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 25479 0x6387 "掇" */
+0x20,0x27,0x20,0x22,0xf9,0x22,0x24,0x28,0x30,0xe7,0x20,0x22,0x21,0x22,0xa4,0x48,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 25480 0x6388 "授" */
+0x10,0x13,0x10,0x12,0xfd,0x11,0x17,0x14,0x18,0x33,0xd1,0x11,0x10,0x10,0x51,0x26,
+0x1c,0xe0,0x84,0x44,0x48,0x10,0xfe,0x02,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 25481 0x6389 "掉" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x15,0x19,0x31,0xd1,0x10,0x13,0x10,0x10,0x50,0x20,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 25482 0x638a "掊" */
+0x10,0x10,0x11,0x10,0xfd,0x10,0x10,0x13,0x18,0x30,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 25483 0x638b "掋" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x54,0x28,
+0x40,0x20,0xfe,0x00,0x1c,0xf0,0x90,0x90,0xfe,0x90,0x90,0x90,0xaa,0xca,0xa6,0x12,
+/* 25484 0x638c "掌" */
+0x11,0x09,0x3f,0x20,0x4f,0x08,0x0f,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x10,0x20,0xfc,0x04,0xe8,0x20,0xe0,0xf0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25485 0x638d "掍" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 25486 0x638e "掎" */
+0x10,0x10,0x13,0x10,0xfd,0x12,0x17,0x10,0x1b,0x32,0xd2,0x12,0x13,0x10,0x50,0x20,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 25487 0x638f "掏" */
+0x10,0x10,0x10,0x11,0xfe,0x10,0x11,0x14,0x1b,0x30,0xd1,0x11,0x11,0x10,0x50,0x20,
+0x80,0x80,0xfe,0x02,0x82,0xf2,0x42,0x42,0xfa,0x42,0x52,0x52,0xf2,0x02,0x14,0x08,
+/* 25488 0x6390 "掐" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 25489 0x6391 "掑" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x18,0x30,0xd0,0x13,0x10,0x10,0x51,0x22,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 25490 0x6392 "排" */
+0x10,0x10,0x10,0x17,0xf8,0x10,0x10,0x1b,0x30,0xd0,0x10,0x17,0x10,0x10,0x50,0x20,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 25491 0x6393 "掓" */
+0x21,0x21,0x21,0x21,0xf9,0x21,0x27,0x28,0x31,0xe1,0x25,0x25,0x29,0x21,0xa5,0x42,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 25492 0x6394 "掔" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25493 0x6395 "掕" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x10,0x15,0x1a,0x30,0xd1,0x12,0x10,0x10,0x51,0x26,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 25494 0x6396 "掖" */
+0x10,0x10,0x17,0x11,0xfd,0x12,0x12,0x16,0x1a,0x33,0xd2,0x12,0x12,0x12,0x52,0x23,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 25495 0x6397 "掗" */
+0x10,0x17,0x10,0x10,0xfc,0x13,0x12,0x16,0x1a,0x33,0xd0,0x10,0x10,0x10,0x57,0x20,
+0x00,0xfe,0x90,0x90,0x90,0x9c,0x04,0x04,0x04,0x9c,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 25496 0x6398 "掘" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x25,0x25,0x35,0xe5,0x24,0x25,0x25,0x29,0xa9,0x50,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x24,0x24,0x24,0xfc,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 25497 0x6399 "掙" */
+0x10,0x17,0x12,0x11,0xfc,0x13,0x14,0x18,0x37,0xd0,0x10,0x13,0x10,0x10,0x51,0x20,
+0x3c,0xc0,0x44,0x28,0x00,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x48,0x40,0x40,0x80,
+/* 25498 0x639a "掚" */
+0x10,0x13,0x10,0x10,0xfb,0x12,0x12,0x1b,0x32,0xd2,0x13,0x12,0x12,0x12,0x52,0x22,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 25499 0x639b "掛" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x17,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x53,0x21,
+0x88,0x88,0xe8,0x88,0x88,0x88,0xec,0x0a,0x8a,0x88,0xe8,0x88,0x88,0xe8,0x88,0x08,
+/* 25500 0x639c "掜" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x12,0x16,0x1b,0x30,0xd0,0x10,0x10,0x11,0x52,0x24,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 25501 0x639d "掝" */
+0x10,0x10,0x10,0x17,0xf8,0x10,0x17,0x1a,0x32,0xd2,0x13,0x10,0x10,0x17,0x52,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 25502 0x639e "掞" */
+0x10,0x11,0x11,0x12,0xfc,0x10,0x13,0x14,0x18,0x31,0xd1,0x12,0x10,0x10,0x51,0x26,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 25503 0x639f "掟" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x13,0x14,0x18,0x31,0xd1,0x11,0x12,0x12,0x54,0x28,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 25504 0x63a0 "掠" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x11,0x15,0x19,0x30,0xd1,0x11,0x12,0x14,0x50,0x20,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 25505 0x63a1 "採" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x15,0x18,0x33,0xd0,0x10,0x10,0x11,0x12,0x54,0x20,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 25506 0x63a2 "探" */
+0x20,0x27,0x24,0x24,0xf9,0x22,0x20,0x28,0x37,0xe0,0x20,0x21,0x22,0x2c,0xa0,0x40,
+0x00,0xfc,0x04,0xa4,0x10,0x08,0x40,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 25507 0x63a3 "掣" */
+0x24,0x3f,0x44,0xff,0x04,0x3f,0x24,0x25,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x04,0xa4,0x24,0xa4,0x24,0x84,0x94,0x88,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25508 0x63a4 "掤" */
+0x10,0x13,0x12,0x12,0xfa,0x13,0x12,0x1a,0x32,0xd3,0x12,0x12,0x12,0x12,0x55,0x28,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 25509 0x63a5 "接" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x17,0x10,0x18,0x37,0xd0,0x11,0x10,0x10,0x51,0x26,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 25510 0x63a6 "掦" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x19,0x32,0xd4,0x10,0x11,0x12,0x50,0x21,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0x80,0xfe,0x4a,0x4a,0x92,0x22,0x42,0x94,0x08,
+/* 25511 0x63a7 "控" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x11,0x1a,0x30,0xd1,0x10,0x10,0x10,0x10,0x57,0x20,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 25512 0x63a8 "推" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x15,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 25513 0x63a9 "掩" */
+0x10,0x10,0x17,0x11,0xfe,0x14,0x13,0x16,0x1a,0x33,0xd2,0x12,0x13,0x10,0x50,0x20,
+0x40,0x80,0xfe,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 25514 0x63aa "措" */
+0x10,0x10,0x10,0x13,0xf8,0x10,0x17,0x18,0x31,0xd1,0x11,0x11,0x11,0x11,0x51,0x21,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 25515 0x63ab "掫" */
+0x20,0x2f,0x24,0x24,0xf4,0x27,0x24,0x24,0x37,0xe4,0x24,0x25,0x2e,0x20,0xa0,0x40,
+0x00,0xc0,0xbc,0xa4,0xa4,0xa4,0xa4,0xa8,0xa8,0xa8,0x90,0xd0,0xa8,0xa8,0xc4,0x82,
+/* 25516 0x63ac "掬" */
+0x11,0x11,0x11,0x12,0xfc,0x11,0x14,0x18,0x33,0xd0,0x10,0x11,0x12,0x10,0x50,0x20,
+0x00,0x00,0xfc,0x04,0x44,0x54,0xe4,0x44,0xfc,0x44,0xe4,0x54,0x44,0x44,0x14,0x08,
+/* 25517 0x63ad "掭" */
+0x20,0x23,0x20,0x20,0xfb,0x20,0x21,0x2a,0x34,0xe0,0x20,0x22,0x22,0x24,0xa1,0x40,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 25518 0x63ae "掮" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x12,0x12,0x1a,0x32,0xd2,0x12,0x14,0x14,0x58,0x20,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 25519 0x63af "掯" */
+0x10,0x11,0x11,0x11,0xf9,0x17,0x10,0x1b,0x32,0xd3,0x12,0x13,0x12,0x12,0x52,0x22,
+0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 25520 0x63b0 "掰" */
+0x10,0x3a,0xe2,0x24,0x24,0xf8,0x20,0x27,0x22,0xfa,0x22,0x24,0x24,0x2a,0x51,0x80,
+0x00,0x86,0xb8,0x88,0x48,0x5e,0x28,0x88,0x88,0xbe,0x88,0x88,0x88,0x88,0x28,0x10,
+/* 25521 0x63b1 "掱" */
+0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x7a,0x10,0x7c,0x10,0xfe,0x10,0x50,0x20,
+0xf0,0x00,0x00,0xf8,0x00,0xfc,0x00,0x04,0x78,0x10,0xfc,0x10,0xfe,0x10,0x50,0x20,
+/* 25522 0x63b2 "掲" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x15,0x1a,0x31,0xd1,0x11,0x10,0x10,0x50,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x02,0x12,0xea,0x0a,0xfa,0x02,0x14,0x08,
+/* 25523 0x63b3 "掳" */
+0x20,0x20,0x20,0x23,0xfa,0x22,0x23,0x2a,0x32,0xe2,0x23,0x22,0x24,0x24,0xa9,0x42,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x40,0x40,0xfc,0x44,0x84,0x84,0x14,0x08,
+/* 25524 0x63b4 "掴" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x2a,0x32,0xe2,0x22,0x23,0x22,0x22,0xa3,0x42,
+0x00,0xfe,0x02,0x02,0xfe,0x22,0x22,0xfa,0x22,0x32,0x2a,0xfe,0x02,0x02,0xfe,0x02,
+/* 25525 0x63b5 "掵" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x17,0x1a,0x32,0xd2,0x13,0x12,0x10,0x50,0x20,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xde,0x52,0x52,0x52,0xda,0x54,0x10,0x10,0x10,
+/* 25526 0x63b6 "掶" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x17,0x1a,0x32,0xd2,0x12,0x12,0x14,0x54,0x29,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x20,0x50,0x50,0x88,0x06,
+/* 25527 0x63b7 "掷" */
+0x24,0x22,0x22,0x20,0xff,0x21,0x21,0x29,0x37,0xe1,0x21,0x21,0x22,0x22,0xa4,0x48,
+0x40,0x5e,0x92,0x12,0xd4,0x14,0x18,0x14,0xf2,0x12,0x12,0x1a,0x94,0x50,0x50,0x10,
+/* 25528 0x63b8 "掸" */
+0x11,0x10,0x10,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd0,0x10,0x13,0x10,0x50,0x20,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 25529 0x63b9 "掹" */
+0x10,0x11,0x10,0x10,0xf8,0x13,0x14,0x18,0x30,0xd1,0x11,0x11,0x11,0x11,0x57,0x20,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 25530 0x63ba "掺" */
+0x10,0x10,0x11,0x13,0xfc,0x17,0x11,0x12,0x1c,0x33,0xd0,0x10,0x13,0x10,0x50,0x27,
+0x80,0x90,0x08,0xfc,0x40,0xfe,0x10,0x48,0x86,0x10,0x20,0xc4,0x08,0x30,0xc0,0x00,
+/* 25531 0x63bb "掻" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x14,0x1b,0x30,0xd1,0x11,0x11,0x11,0x10,0x53,0x20,
+0x00,0xfc,0x84,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 25532 0x63bc "掼" */
+0x11,0x11,0x11,0x13,0xfd,0x11,0x11,0x14,0x19,0x31,0xd1,0x11,0x11,0x10,0x50,0x23,
+0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x00,0xfc,0x04,0x24,0x24,0x24,0x58,0x84,0x02,
+/* 25533 0x63bd "掽" */
+0x11,0x10,0x10,0x13,0xfc,0x10,0x10,0x14,0x1a,0x32,0xd0,0x10,0x10,0x10,0x57,0x20,
+0x08,0x90,0x00,0xfc,0x90,0x90,0x92,0x92,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 25534 0x63be "掾" */
+0x21,0x21,0x22,0x23,0xf8,0x27,0x20,0x29,0x36,0xe0,0x21,0x26,0x20,0x21,0xa6,0x40,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 25535 0x63bf "掿" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x13,0x14,0x18,0x30,0xd1,0x12,0x10,0x10,0x50,0x20,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 25536 0x63c0 "揀" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd0,0x10,0x10,0x11,0x52,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 25537 0x63c1 "揁" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x51,0x22,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 25538 0x63c2 "揂" */
+0x21,0x20,0x20,0x27,0xf8,0x20,0x23,0x2a,0x32,0xe3,0x22,0x23,0x22,0x22,0xa3,0x42,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 25539 0x63c3 "揃" */
+0x11,0x10,0x10,0x17,0xf8,0x13,0x12,0x1a,0x33,0xd2,0x12,0x13,0x12,0x12,0x52,0x22,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 25540 0x63c4 "揄" */
+0x20,0x20,0x21,0x22,0xfd,0x20,0x23,0x2a,0x32,0xe3,0x22,0x22,0x23,0x22,0xa2,0x42,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 25541 0x63c5 "揅" */
+0xfd,0x20,0x40,0x7d,0xc4,0x44,0x7d,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0xfe,0x48,0x48,0xfe,0x48,0x88,0x08,0xe8,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25542 0x63c6 "揆" */
+0x10,0x13,0x10,0x12,0xfd,0x10,0x11,0x12,0x18,0x30,0xd3,0x10,0x10,0x10,0x51,0x22,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 25543 0x63c7 "揇" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x52,0x22,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 25544 0x63c8 "揈" */
+0x11,0x11,0x11,0x12,0xfc,0x17,0x10,0x13,0x18,0x33,0xd0,0x13,0x12,0x13,0x50,0x20,
+0x00,0x00,0xfe,0x02,0x82,0xf2,0x02,0xf2,0x02,0xf2,0x02,0xf2,0x12,0xf2,0x14,0x08,
+/* 25545 0x63c9 "揉" */
+0x20,0x21,0x20,0x20,0xfb,0x20,0x20,0x29,0x32,0xe0,0x23,0x20,0x20,0x21,0xa6,0x40,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 25546 0x63ca "揊" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x14,0x1b,0x32,0xd2,0x13,0x12,0x12,0x53,0x22,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 25547 0x63cb "揋" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x33,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 25548 0x63cc "揌" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x15,0x19,0x30,0xd0,0x10,0x12,0x12,0x14,0x50,0x20,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 25549 0x63cd "揍" */
+0x20,0x20,0x27,0x20,0xfb,0x20,0x27,0x29,0x32,0xe5,0x20,0x23,0x20,0x20,0xa1,0x46,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x40,0xf8,0x40,0xa0,0x10,0x08,
+/* 25550 0x63ce "揎" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x14,0x19,0x31,0xd1,0x11,0x11,0x11,0x10,0x53,0x20,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 25551 0x63cf "描" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 25552 0x63d0 "提" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x33,0xd0,0x11,0x11,0x11,0x52,0x24,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 25553 0x63d1 "揑" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x30,0xd1,0x10,0x10,0x10,0x53,0x20,
+0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25554 0x63d2 "插" */
+0x20,0x20,0x27,0x20,0xf8,0x2f,0x20,0x29,0x36,0xe4,0x24,0x27,0x24,0x24,0xa7,0x44,
+0x08,0x3c,0xc0,0x40,0x40,0xfe,0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x04,
+/* 25555 0x63d3 "揓" */
+0x22,0x21,0x21,0x27,0xfa,0x22,0x23,0x2a,0x32,0xe2,0x22,0x22,0x24,0x24,0xa9,0x50,
+0x10,0x10,0x10,0xbe,0x28,0x48,0xaa,0xae,0xba,0xea,0xae,0xa8,0xaa,0xa2,0xa2,0x1e,
+/* 25556 0x63d4 "揔" */
+0x10,0x10,0x10,0x11,0xfa,0x10,0x15,0x1a,0x30,0xd1,0x10,0x10,0x12,0x12,0x54,0x20,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 25557 0x63d5 "揕" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x14,0x18,0x33,0xd1,0x11,0x11,0x11,0x51,0x20,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 25558 0x63d6 "揖" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x17,0x15,0x19,0x31,0xd1,0x11,0x11,0x17,0x50,0x20,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 25559 0x63d7 "揗" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x12,0x1a,0x32,0xd2,0x12,0x12,0x14,0x14,0x58,0x20,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 25560 0x63d8 "揘" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x14,0x1b,0x30,0xd0,0x11,0x10,0x10,0x53,0x20,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 25561 0x63d9 "揙" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x12,0x16,0x1b,0x33,0xd5,0x15,0x15,0x15,0x59,0x21,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0x52,0x52,0xfe,0x52,0x52,0x52,0x06,
+/* 25562 0x63da "揚" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x14,0x1b,0x31,0xd1,0x12,0x14,0x11,0x12,0x50,0x21,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 25563 0x63db "換" */
+0x10,0x10,0x11,0x12,0xfc,0x13,0x12,0x1a,0x32,0xd2,0x10,0x17,0x10,0x10,0x51,0x26,
+0x80,0x80,0xf8,0x08,0x10,0xfe,0x02,0x52,0x8a,0x22,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 25564 0x63dc "揜" */
+0x10,0x10,0x10,0x11,0xfe,0x10,0x15,0x19,0x31,0xd1,0x10,0x10,0x13,0x10,0x51,0x22,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x88,0x88,0xfe,0x88,0x08,0x08,
+/* 25565 0x63dd "揝" */
+0x10,0x10,0x11,0x11,0xfa,0x15,0x10,0x19,0x36,0xd1,0x11,0x11,0x11,0x11,0x51,0x21,
+0x88,0x88,0xec,0x2a,0x28,0x48,0x88,0x7e,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,
+/* 25566 0x63de "揞" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x17,0x10,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0x20,0xfe,0x00,0x04,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 25567 0x63df "揟" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x12,0x14,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 25568 0x63e0 "揠" */
+0x10,0x13,0x12,0x12,0xfa,0x12,0x16,0x1a,0x32,0xd3,0x12,0x12,0x12,0x12,0x52,0x23,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 25569 0x63e1 "握" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x23,0x2a,0x32,0xe3,0x22,0x22,0x25,0x24,0xa8,0x53,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 25570 0x63e2 "揢" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x15,0x1a,0x30,0xd1,0x16,0x11,0x11,0x11,0x51,0x21,
+0x40,0x20,0xfe,0x02,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 25571 0x63e3 "揣" */
+0x20,0x24,0x24,0x24,0xf7,0x20,0x2f,0x20,0x30,0xe7,0x24,0x24,0x24,0x24,0xa4,0x44,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x0c,
+/* 25572 0x63e4 "揤" */
+0x10,0x13,0x12,0x12,0xfa,0x13,0x12,0x1a,0x32,0xd3,0x12,0x12,0x12,0x12,0x53,0x20,
+0x00,0xde,0x52,0x52,0x52,0xd2,0x52,0x52,0x52,0xd2,0x1a,0x94,0x50,0xb0,0x10,0x10,
+/* 25573 0x63e5 "揥" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x17,0x14,0x18,0x33,0xd2,0x12,0x12,0x12,0x50,0x20,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x42,0x44,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 25574 0x63e6 "揦" */
+0x10,0x10,0x17,0x10,0xfc,0x13,0x16,0x1a,0x33,0xd0,0x11,0x12,0x14,0x10,0x50,0x20,
+0x82,0x82,0xf2,0x82,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xaa,0xa2,0x82,0x8a,0x84,
+/* 25575 0x63e7 "揧" */
+0x04,0x7f,0x04,0x3f,0x24,0x3f,0x15,0x24,0x44,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x04,0xc4,0x24,0xa4,0xa4,0xa4,0x04,0x94,0x28,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25576 0x63e8 "揨" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x14,0x1b,0x32,0xd1,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 25577 0x63e9 "揩" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x14,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 25578 0x63ea "揪" */
+0x20,0x21,0x27,0x21,0xf9,0x21,0x27,0x29,0x33,0xe3,0x25,0x25,0x29,0x21,0xa1,0x41,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 25579 0x63eb "揫" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x09,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x05,0x02,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0xe4,0x00,0x00,0xf8,0x00,0xfc,0x00,0x00,0x00,
+/* 25580 0x63ec "揬" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x12,0x10,0x18,0x33,0xd0,0x10,0x10,0x10,0x51,0x22,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x22,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 25581 0x63ed "揭" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x11,0x13,0x1c,0x32,0xd2,0x12,0x13,0x10,0x50,0x20,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 25582 0x63ee "揮" */
+0x10,0x13,0x12,0x10,0xfd,0x10,0x11,0x15,0x19,0x31,0xd1,0x10,0x13,0x10,0x50,0x20,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 25583 0x63ef "揯" */
+0x22,0x22,0x22,0x22,0xfb,0x22,0x26,0x2a,0x32,0xe2,0x22,0x22,0x22,0x22,0xa2,0x42,
+0x00,0xfe,0x20,0x20,0x20,0xbc,0x44,0x54,0x4c,0x84,0xa4,0x18,0x08,0x08,0xfe,0x00,
+/* 25584 0x63f0 "揰" */
+0x10,0x10,0x11,0x10,0xfb,0x10,0x15,0x19,0x31,0xd1,0x11,0x10,0x11,0x10,0x53,0x20,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25585 0x63f1 "揱" */
+0x49,0x2a,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x43,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x2c,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25586 0x63f2 "揲" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x11,0x15,0x19,0x30,0xd3,0x10,0x10,0x11,0x56,0x20,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 25587 0x63f3 "揳" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x18,0x30,0xd3,0x10,0x10,0x10,0x51,0x26,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 25588 0x63f4 "援" */
+0x20,0x27,0x22,0x21,0xf8,0x23,0x20,0x28,0x37,0xe1,0x21,0x22,0x22,0x24,0xa8,0x43,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 25589 0x63f5 "揵" */
+0x20,0x20,0x27,0x21,0xf9,0x22,0x22,0x2f,0x31,0xe5,0x25,0x22,0x22,0x25,0xa8,0x40,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 25590 0x63f6 "揶" */
+0x20,0x2f,0x24,0x24,0xf4,0x27,0x24,0x24,0x37,0xe4,0x24,0x25,0x2e,0x20,0xa0,0x40,
+0x00,0xde,0x92,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0x92,0xda,0x94,0x90,0x90,0x90,
+/* 25591 0x63f7 "揷" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x20,
+0x1c,0xe0,0x20,0x20,0xfe,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x24,0x20,0x20,
+/* 25592 0x63f8 "揸" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x12,0x11,0x19,0x31,0xd1,0x11,0x11,0x10,0x57,0x20,
+0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 25593 0x63f9 "揹" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x10,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x50,0x52,0xdc,0x50,0xd2,0x4e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 25594 0x63fa "揺" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x15,0x18,0x30,0xd3,0x10,0x11,0x11,0x11,0x51,0x20,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 25595 0x63fb "揻" */
+0x20,0x20,0x27,0x24,0xfc,0x27,0x24,0x2c,0x37,0xe5,0x25,0x24,0x25,0x2a,0xa8,0x50,
+0x14,0x12,0xfe,0x10,0x10,0xf0,0x92,0x92,0xd2,0x54,0x54,0x88,0x4a,0x1a,0x26,0x42,
+/* 25596 0x63fc "揼" */
+0x10,0x13,0x10,0x10,0xfd,0x12,0x10,0x14,0x18,0x30,0xd3,0x10,0x11,0x12,0x54,0x20,
+0x00,0xfe,0x40,0x80,0xfc,0x84,0x84,0xfc,0x20,0x22,0xb4,0xa8,0x28,0x24,0xa2,0x40,
+/* 25597 0x63fd "揽" */
+0x10,0x12,0x12,0x12,0xfa,0x10,0x15,0x19,0x31,0xd1,0x11,0x11,0x10,0x10,0x51,0x26,
+0x90,0x90,0x9e,0xa8,0xc4,0x80,0xfc,0x04,0x24,0x24,0x24,0x54,0x50,0x90,0x12,0x0e,
+/* 25598 0x63fe "揾" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x33,0xd2,0x12,0x12,0x12,0x57,0x20,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 25599 0x63ff "揿" */
+0x22,0x22,0x22,0x23,0xf4,0x24,0x27,0x2a,0x32,0xef,0x22,0x22,0x22,0x23,0xa2,0x40,
+0x10,0x10,0x10,0xbe,0x22,0x44,0x90,0x10,0x10,0x90,0x28,0x28,0xa8,0x44,0x44,0x82,
+/* 25600 0x6400 "搀" */
+0x21,0x21,0x22,0x24,0xfb,0x22,0x22,0x2b,0x30,0xe1,0x26,0x20,0x20,0x21,0xa0,0x40,
+0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfc,0xa0,0x22,0x1e,0xc0,0x30,0x80,0x60,0x10,
+/* 25601 0x6401 "搁" */
+0x22,0x21,0x25,0x24,0xf4,0x25,0x26,0x24,0x34,0xe7,0x25,0x25,0x25,0x25,0xa5,0x44,
+0x00,0x7c,0x04,0x84,0xf4,0x14,0xa4,0x44,0xa4,0x1c,0xf4,0x14,0x14,0xf4,0x14,0x08,
+/* 25602 0x6402 "搂" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x11,0x1a,0x30,0xd7,0x10,0x11,0x11,0x10,0x51,0x26,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 25603 0x6403 "搃" */
+0x11,0x10,0x10,0x13,0xfe,0x12,0x12,0x13,0x18,0x30,0xd0,0x12,0x12,0x12,0x54,0x20,
+0x08,0x88,0x90,0xfc,0x04,0x04,0x04,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 25604 0x6404 "搄" */
+0x21,0x21,0x21,0x21,0xf9,0x25,0x25,0x2d,0x35,0xe1,0x21,0x21,0x21,0x21,0xa1,0x41,
+0x00,0x3c,0x00,0x00,0xbc,0x64,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x00,0x7e,0x00,
+/* 25605 0x6405 "搅" */
+0x24,0x22,0x22,0x27,0xfc,0x28,0x23,0x2a,0x32,0xe2,0x22,0x22,0x20,0x21,0xa2,0x4c,
+0x84,0x44,0x48,0xfe,0x02,0x04,0xf8,0x08,0x48,0x48,0x48,0xa8,0xa0,0x22,0x22,0x1e,
+/* 25606 0x6406 "搆" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x31,0xd1,0x11,0x13,0x11,0x51,0x21,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 25607 0x6407 "搇" */
+0x20,0x20,0x21,0x26,0xf8,0x23,0x20,0x28,0x30,0xe7,0x20,0x21,0x23,0x25,0xa9,0x41,
+0x40,0xa0,0x18,0x86,0x40,0xf0,0x10,0xa0,0x40,0xfe,0x88,0x50,0x20,0x10,0x48,0x86,
+/* 25608 0x6408 "搈" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x11,0x14,0x18,0x31,0xd2,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 25609 0x6409 "搉" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x15,0x1b,0x35,0xd1,0x11,0x11,0x11,0x11,0x51,0x21,
+0x40,0x40,0xfe,0xa2,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 25610 0x640a "搊" */
+0x10,0x10,0x11,0x12,0xfd,0x11,0x10,0x15,0x1a,0x31,0xd2,0x15,0x11,0x10,0x51,0x22,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 25611 0x640b "搋" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x14,0x55,0x2a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 25612 0x640c "搌" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x2a,0x32,0xe2,0x23,0x22,0x22,0x24,0xa4,0x48,
+0x00,0xfc,0x04,0x04,0xfc,0x48,0x48,0xfc,0x48,0x48,0xfe,0xa4,0xa8,0x90,0xc8,0x86,
+/* 25613 0x640d "損" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x13,0x16,0x1b,0x32,0xd3,0x12,0x13,0x10,0x51,0x22,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 25614 0x640e "搎" */
+0x20,0x2f,0x21,0x21,0xfa,0x22,0x23,0x2a,0x36,0xea,0x22,0x22,0x22,0x22,0xaa,0x44,
+0x06,0x78,0x10,0x20,0x44,0x78,0x10,0x24,0x7e,0x12,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 25615 0x640f "搏" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd0,0x13,0x10,0x10,0x50,0x20,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 25616 0x6410 "搐" */
+0x20,0x20,0x27,0x20,0xf9,0x23,0x20,0x29,0x37,0xe0,0x27,0x24,0x27,0x24,0xa7,0x44,
+0x80,0x40,0xfc,0x80,0x08,0xf0,0x60,0x84,0xfe,0x02,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 25617 0x6411 "搑" */
+0x11,0x11,0x17,0x11,0xf8,0x17,0x11,0x19,0x31,0xd1,0x11,0x11,0x17,0x10,0x50,0x20,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,0x08,
+/* 25618 0x6412 "搒" */
+0x10,0x10,0x13,0x11,0xfc,0x13,0x12,0x14,0x18,0x33,0xd0,0x10,0x10,0x11,0x51,0x22,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 25619 0x6413 "搓" */
+0x11,0x10,0x10,0x13,0xfc,0x11,0x10,0x17,0x18,0x31,0xd1,0x12,0x14,0x18,0x53,0x20,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 25620 0x6414 "搔" */
+0x20,0x23,0x21,0x21,0xf8,0x20,0x21,0x2e,0x30,0xe3,0x22,0x22,0x23,0x20,0xa7,0x40,
+0x00,0xf8,0x48,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xf8,0x48,0x48,0xf8,0x44,0xfc,0x04,
+/* 25621 0x6415 "搕" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x10,0x15,0x1b,0x30,0xd3,0x12,0x12,0x12,0x57,0x20,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 25622 0x6416 "搖" */
+0x10,0x10,0x11,0x12,0xfd,0x10,0x13,0x11,0x1a,0x30,0xd3,0x10,0x11,0x11,0x51,0x20,
+0x40,0x80,0xfc,0x48,0x30,0xc0,0x00,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0xfc,0x04,
+/* 25623 0x6417 "搗" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x10,0x12,0x13,0x50,0x20,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x42,0x4a,0xfa,0x14,0x08,
+/* 25624 0x6418 "搘" */
+0x10,0x10,0x11,0x10,0xfb,0x10,0x14,0x19,0x32,0xd4,0x11,0x11,0x11,0x11,0x51,0x21,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 25625 0x6419 "搙" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x12,0x16,0x1a,0x32,0xd2,0x13,0x12,0x14,0x54,0x28,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 25626 0x641a "搚" */
+0x10,0x11,0x10,0x10,0xfd,0x13,0x11,0x15,0x1a,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x40,0xfc,0x44,0x94,0x08,0xde,0x4a,0x4a,0x94,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 25627 0x641b "搛" */
+0x11,0x10,0x10,0x17,0xf8,0x13,0x10,0x1f,0x30,0xd3,0x10,0x11,0x12,0x14,0x50,0x20,
+0x10,0xa0,0x00,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 25628 0x641c "搜" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x31,0xd0,0x10,0x10,0x10,0x50,0x23,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 25629 0x641d "搝" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x30,0xd0,0x13,0x10,0x10,0x51,0x22,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x88,0x04,0x02,
+/* 25630 0x641e "搞" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x14,0x1b,0x32,0xd2,0x12,0x12,0x12,0x52,0x22,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 25631 0x641f "搟" */
+0x21,0x21,0x21,0x27,0xf9,0x27,0x25,0x2f,0x35,0xe7,0x21,0x2f,0x21,0x21,0xa1,0x41,
+0x00,0x00,0x3e,0xc8,0x08,0xc8,0x48,0xc8,0x7e,0xc8,0x08,0xe8,0x08,0x08,0x08,0x08,
+/* 25632 0x6420 "搠" */
+0x24,0x22,0x22,0x20,0xf7,0x21,0x25,0x25,0x35,0xe7,0x21,0x21,0x22,0x22,0xa4,0x48,
+0x40,0x5e,0x92,0x12,0xd2,0x1e,0x52,0x52,0x52,0xde,0x52,0x12,0x12,0x22,0x2a,0x44,
+/* 25633 0x6421 "搡" */
+0x23,0x21,0x20,0x23,0xf8,0x27,0x24,0x2b,0x34,0xe0,0x27,0x20,0x21,0x22,0xac,0x40,
+0xf0,0x10,0xe0,0x18,0x00,0xbc,0xa4,0x18,0xa4,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 25634 0x6422 "搢" */
+0x10,0x13,0x10,0x12,0xfd,0x10,0x17,0x18,0x31,0xd1,0x11,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 25635 0x6423 "搣" */
+0x20,0x20,0x20,0x27,0xfc,0x24,0x27,0x2c,0x34,0xe5,0x26,0x24,0x25,0x29,0xaa,0x50,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xf2,0x92,0x92,0xb4,0xd4,0x88,0x4a,0x3a,0x26,0x42,
+/* 25636 0x6424 "搤" */
+0x11,0x10,0x10,0x10,0xfb,0x10,0x14,0x19,0x32,0xd1,0x11,0x11,0x11,0x11,0x57,0x20,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 25637 0x6425 "搥" */
+0x10,0x12,0x11,0x11,0xfc,0x10,0x13,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x54,0x20,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 25638 0x6426 "搦" */
+0x20,0x27,0x20,0x20,0xf7,0x24,0x24,0x27,0x30,0xe4,0x22,0x22,0x24,0x20,0xa5,0x42,
+0x00,0xbc,0x84,0x84,0xbc,0x20,0x20,0xbc,0x84,0xa4,0x94,0x94,0xa4,0x84,0x28,0x10,
+/* 25639 0x6427 "搧" */
+0x20,0x20,0x27,0x24,0xfc,0x27,0x24,0x2f,0x34,0xe6,0x25,0x24,0x2b,0x28,0xb1,0x40,
+0x80,0x40,0xfe,0x02,0x02,0xfe,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 25640 0x6428 "搨" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x1b,0x30,0xd2,0x11,0x12,0x10,0x51,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 25641 0x6429 "搩" */
+0x22,0x22,0x23,0xf4,0x2a,0x21,0x22,0x34,0xe8,0x27,0x20,0x21,0x22,0x2c,0xa0,0x40,
+0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x48,0x48,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 25642 0x642a "搪" */
+0x20,0x20,0x27,0x24,0xfd,0x24,0x27,0x2c,0x35,0xe4,0x25,0x25,0x25,0x29,0xa9,0x51,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 25643 0x642b "搫" */
+0x08,0x3e,0x22,0x2a,0x7e,0x22,0x2a,0x46,0x80,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x78,0x48,0x8e,0x00,0xf8,0x48,0x30,0xcc,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25644 0x642c "搬" */
+0x21,0x22,0x27,0x24,0xf6,0x25,0x24,0x2f,0x34,0xe4,0x26,0x25,0x24,0x24,0xa4,0x49,
+0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xc2,0x80,0xbc,0xa4,0xa4,0xa4,0x94,0x88,0x94,0xa2,
+/* 25645 0x642d "搭" */
+0x21,0x21,0x27,0x21,0xf8,0x20,0x21,0x2a,0x35,0xe0,0x20,0x23,0x22,0x22,0xa3,0x42,
+0x10,0x10,0xfc,0x10,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 25646 0x642e "搮" */
+0x10,0x13,0x10,0x10,0xfb,0x12,0x16,0x1b,0x30,0xd0,0x13,0x10,0x10,0x11,0x56,0x20,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 25647 0x642f "搯" */
+0x10,0x13,0x10,0x12,0xf9,0x11,0x14,0x1b,0x32,0xd2,0x13,0x12,0x12,0x12,0x53,0x22,
+0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 25648 0x6430 "搰" */
+0x10,0x11,0x11,0x11,0xfd,0x13,0x12,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x00,0xfc,0x04,0xe4,0x24,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 25649 0x6431 "搱" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x12,0x1b,0x32,0xd2,0x13,0x12,0x15,0x14,0x58,0x20,
+0x00,0xfc,0x04,0x04,0xfc,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x20,
+/* 25650 0x6432 "搲" */
+0x20,0x20,0x27,0x24,0xf9,0x22,0x20,0x2b,0x32,0xe2,0x22,0x22,0x22,0x24,0xa4,0x48,
+0x80,0x40,0xfc,0x04,0x10,0x08,0x3c,0xd0,0x90,0x90,0x90,0x88,0x88,0xa4,0xd4,0x92,
+/* 25651 0x6433 "搳" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x10,0x15,0x18,0x33,0xd0,0x11,0x11,0x11,0x51,0x21,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 25652 0x6434 "搴" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x17,0x21,0xdf,0x01,0x7f,0x01,0x03,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xd0,0x08,0xf6,0x00,0xf8,0x00,0x00,
+/* 25653 0x6435 "搵" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x23,0x28,0x30,0xe7,0x24,0x24,0x24,0x24,0xaf,0x40,
+0x00,0xf8,0x48,0xa8,0x18,0x08,0xf8,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 25654 0x6436 "搶" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x15,0x11,0x19,0x31,0xd1,0x11,0x12,0x12,0x54,0x20,
+0x20,0x20,0x50,0xc8,0x24,0xfe,0x04,0xfc,0x04,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 25655 0x6437 "搷" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x13,0x10,0x51,0x22,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 25656 0x6438 "搸" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x32,0xd0,0x11,0x10,0x10,0x53,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 25657 0x6439 "搹" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x14,0x1b,0x32,0xd2,0x13,0x12,0x12,0x52,0x22,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 25658 0x643a "携" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x11,0x15,0x19,0x31,0xd3,0x10,0x10,0x11,0x52,0x24,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 25659 0x643b "搻" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x04,0x78,0x10,0x7c,0x10,0xfe,0x10,0x30,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x0c,0xf0,0x10,0xfc,0x10,0xfe,0x10,0x30,
+/* 25660 0x643c "搼" */
+0x10,0x12,0x11,0x13,0xf8,0x17,0x11,0x1a,0x35,0xd8,0x13,0x10,0x17,0x10,0x51,0x20,
+0x40,0x48,0x50,0xf8,0x80,0xfc,0x10,0x28,0xc4,0x42,0xf8,0x40,0xfc,0x40,0x40,0x80,
+/* 25661 0x643d "搽" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x10,0x15,0x1a,0x31,0xd0,0x10,0x11,0x12,0x50,0x20,
+0x88,0x88,0xfe,0x88,0xa8,0x50,0x88,0x24,0x22,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 25662 0x643e "搾" */
+0x10,0x10,0x13,0x12,0xfd,0x10,0x10,0x15,0x1a,0x30,0xd0,0x10,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x8a,0x04,0x80,0xfe,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 25663 0x643f "搿" */
+0x11,0x39,0xe2,0x22,0x24,0xf8,0x23,0x20,0x20,0xfb,0x22,0x22,0x22,0x23,0x42,0x80,
+0x00,0x06,0xb8,0x88,0x48,0x5e,0x88,0x08,0x08,0xbe,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 25664 0x6440 "摀" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x11,0x15,0x19,0x31,0xd0,0x12,0x12,0x14,0x50,0x20,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 25665 0x6441 "摁" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x24,0x25,0x34,0xe7,0x20,0x20,0x25,0x25,0xa9,0x40,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0xa4,0x14,0x04,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 25666 0x6442 "摂" */
+0x10,0x13,0x11,0x11,0xfd,0x11,0x11,0x17,0x18,0x30,0xd2,0x11,0x10,0x11,0x52,0x24,
+0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0x08,0x04,0x08,0x90,0x08,0x04,0x02,
+/* 25667 0x6443 "摃" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x10,0x51,0x22,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 25668 0x6444 "摄" */
+0x10,0x13,0x11,0x11,0xfd,0x11,0x11,0x17,0x18,0x37,0xd0,0x12,0x11,0x12,0x54,0x28,
+0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 25669 0x6445 "摅" */
+0x20,0x20,0x20,0x27,0xf4,0x24,0x27,0x24,0x34,0xe4,0x24,0x24,0x25,0x29,0xa9,0x52,
+0x40,0x7c,0x40,0xfe,0x42,0x70,0xc4,0x44,0x3c,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,
+/* 25670 0x6446 "摆" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x14,0x19,0x30,0xd0,0x17,0x10,0x10,0x11,0x53,0x21,
+0x00,0xfe,0x52,0x52,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x02,
+/* 25671 0x6447 "摇" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x11,0x1a,0x30,0xd3,0x10,0x11,0x11,0x11,0x51,0x20,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 25672 0x6448 "摈" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x11,0x15,0x19,0x31,0xd1,0x17,0x10,0x10,0x51,0x22,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 25673 0x6449 "摉" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x14,0x18,0x33,0xd0,0x11,0x12,0x10,0x10,0x50,0x23,
+0x40,0x20,0xfe,0x02,0xa8,0x24,0x50,0x88,0x46,0xf8,0x08,0x88,0x50,0x20,0x40,0x80,
+/* 25674 0x644a "摊" */
+0x20,0x20,0x27,0x21,0xf1,0x29,0x25,0x25,0x32,0xe2,0x25,0x25,0x29,0x20,0xa0,0x40,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 25675 0x644b "摋" */
+0x20,0x24,0x22,0x21,0xfa,0x24,0x21,0x29,0x37,0xe1,0x25,0x25,0x29,0x21,0xa5,0x42,
+0x00,0x5c,0x94,0x14,0x94,0x54,0x26,0x00,0xdc,0x14,0x94,0x54,0x48,0x08,0x14,0x22,
+/* 25676 0x644c "摌" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x17,0x1a,0x32,0xd2,0x13,0x12,0x12,0x14,0x54,0x29,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 25677 0x644d "摍" */
+0x10,0x10,0x17,0x14,0xfd,0x11,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x52,0x22,
+0x40,0x20,0xfe,0x02,0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 25678 0x644e "摎" */
+0x20,0x27,0x20,0x24,0xfa,0x24,0x20,0x29,0x36,0xe0,0x23,0x20,0x23,0x20,0xa0,0x47,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 25679 0x644f "摏" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x32,0xd5,0x11,0x11,0x11,0x51,0x21,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0x42,0x9c,0x04,0xdc,0x04,0xfc,0x04,
+/* 25680 0x6450 "摐" */
+0x21,0x21,0x22,0xf4,0x29,0x21,0x22,0x36,0xea,0x22,0x22,0x22,0x22,0x22,0xa2,0x43,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 25681 0x6451 "摑" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x27,0x26,0x37,0xe4,0x25,0x26,0x24,0x24,0xa7,0x44,
+0x00,0xfe,0x2a,0x26,0xfe,0x22,0xaa,0xaa,0xaa,0x32,0x96,0x2e,0x46,0x82,0xfe,0x02,
+/* 25682 0x6452 "摒" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x2a,0x32,0xe2,0x22,0x23,0x24,0x24,0xa8,0x51,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x84,0x48,0xfc,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 25683 0x6453 "摓" */
+0x10,0x14,0x12,0x11,0xfc,0x10,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x12,0x55,0x28,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 25684 0x6454 "摔" */
+0x10,0x10,0x13,0x10,0xfc,0x12,0x11,0x16,0x18,0x30,0xd0,0x13,0x10,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x20,0x48,0xf2,0x24,0x52,0xf8,0x08,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 25685 0x6455 "摕" */
+0x22,0x22,0x27,0x22,0xfa,0x24,0x28,0x2f,0x34,0xe0,0x23,0x22,0x22,0x22,0xa2,0x40,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 25686 0x6456 "摖" */
+0x11,0x11,0x13,0x12,0xfd,0x12,0x11,0x1a,0x34,0xd0,0x13,0x10,0x11,0x12,0x55,0x20,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 25687 0x6457 "摗" */
+0x21,0x21,0x27,0x21,0xf9,0x27,0x25,0x2d,0x37,0xe1,0x23,0x25,0x29,0x21,0xa1,0x41,
+0x08,0x08,0xc8,0x08,0x1e,0xd2,0x64,0x40,0xc8,0x08,0x88,0x48,0x54,0x14,0x24,0x42,
+/* 25688 0x6458 "摘" */
+0x20,0x20,0x27,0x21,0xf8,0x27,0x24,0x2d,0x34,0xe5,0x25,0x25,0x25,0x24,0xa4,0x44,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xf4,0x44,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 25689 0x6459 "摙" */
+0x20,0x24,0x22,0x22,0xf8,0x20,0x26,0x2a,0x32,0xe2,0x22,0x22,0x22,0x25,0xa8,0x40,
+0x10,0x10,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 25690 0x645a "摚" */
+0x10,0x11,0x10,0x13,0xfa,0x10,0x14,0x18,0x30,0xd0,0x10,0x11,0x10,0x10,0x53,0x20,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 25691 0x645b "摛" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x11,0x15,0x18,0x33,0xd2,0x12,0x12,0x12,0x52,0x22,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 25692 0x645c "摜" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x10,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x21,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 25693 0x645d "摝" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x12,0x16,0x1b,0x32,0xd2,0x12,0x12,0x14,0x54,0x28,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 25694 0x645e "摞" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x10,0x15,0x1b,0x30,0xd1,0x13,0x10,0x11,0x52,0x24,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x80,0x10,0xe0,0x48,0x84,0xfe,0x22,0x28,0xa4,0x42,
+/* 25695 0x645f "摟" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x10,0x15,0x19,0x31,0xd0,0x13,0x10,0x11,0x50,0x23,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 25696 0x6460 "摠" */
+0x10,0x10,0x13,0x12,0xfa,0x13,0x12,0x1a,0x32,0xd3,0x10,0x10,0x15,0x15,0x59,0x20,
+0x40,0x80,0xfc,0x44,0xf4,0x14,0xa4,0x44,0xa4,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 25697 0x6461 "摡" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x24,0x27,0x34,0xe5,0x24,0x25,0x26,0x24,0xa0,0x40,
+0x00,0xbe,0x88,0x88,0xa8,0xa8,0xa8,0xbe,0x10,0x18,0x98,0xa8,0xaa,0x4a,0x46,0x80,
+/* 25698 0x6462 "摢" */
+0x10,0x10,0x10,0x13,0xfa,0x12,0x13,0x1a,0x32,0xd2,0x13,0x12,0x15,0x14,0x58,0x20,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 25699 0x6463 "摣" */
+0x10,0x10,0x10,0x13,0xfa,0x12,0x13,0x1a,0x32,0xd2,0x12,0x12,0x12,0x14,0x54,0x29,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfe,
+/* 25700 0x6464 "摤" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x12,0x18,0x32,0xd1,0x12,0x10,0x10,0x10,0x51,0x26,
+0x20,0x20,0xfe,0x20,0xaa,0x24,0xaa,0x20,0xaa,0x24,0xaa,0x50,0x50,0x88,0x04,0x02,
+/* 25701 0x6465 "摥" */
+0x11,0x11,0x12,0x15,0xf9,0x11,0x15,0x19,0x30,0xd7,0x11,0x13,0x14,0x11,0x52,0x20,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 25702 0x6466 "摦" */
+0x22,0x22,0x2f,0xf2,0x25,0x28,0x27,0x30,0xef,0x24,0x27,0x21,0x21,0x21,0xa5,0x42,
+0x00,0x0e,0x74,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x54,0x54,0x52,0x54,0x5c,0x84,
+/* 25703 0x6467 "摧" */
+0x10,0x12,0x13,0x10,0xfc,0x11,0x13,0x15,0x19,0x31,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 25704 0x6468 "摨" */
+0x10,0x13,0x12,0x13,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x15,0x54,0x28,
+0x00,0xfe,0x02,0xfe,0x10,0x54,0x38,0x54,0x82,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,
+/* 25705 0x6469 "摩" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x20,0x27,0x20,0x27,0x20,0x2f,0x40,0x41,0x80,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0x38,0xc0,0x40,0xf8,0x40,0xfe,0x40,0x40,0x80,
+/* 25706 0x646a "摪" */
+0x20,0x22,0x22,0x22,0xfa,0x23,0x20,0x28,0x37,0xe2,0x22,0x22,0x22,0x22,0xa4,0x48,
+0x90,0x90,0x9e,0xa2,0xd4,0xa8,0x94,0xa4,0xfe,0x84,0xa4,0x94,0x94,0x84,0x94,0x88,
+/* 25707 0x646b "摫" */
+0x22,0x22,0x22,0x27,0xfa,0x22,0x22,0x2f,0x32,0xe2,0x22,0x22,0x25,0x25,0xa8,0x50,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 25708 0x646c "摬" */
+0x10,0x10,0x13,0x11,0xf8,0x17,0x10,0x1b,0x32,0xd3,0x12,0x13,0x11,0x11,0x52,0x2c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 25709 0x646d "摭" */
+0x20,0x20,0x23,0x22,0xfa,0x22,0x23,0x2a,0x32,0xe2,0x22,0x22,0x25,0x25,0xaa,0x50,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 25710 0x646e "摮" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x5f,0x81,0x3f,0x01,0x7f,0x01,0x03,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x64,0xc2,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25711 0x646f "摯" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x08,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0xa2,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25712 0x6470 "摰" */
+0x08,0x3e,0x08,0x7f,0x2a,0x5d,0x08,0x3e,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x20,0x20,0xf8,0x28,0x68,0x2a,0x56,0x82,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25713 0x6471 "摱" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x10,0x17,0x1a,0x33,0xd0,0x11,0x10,0x10,0x51,0x26,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 25714 0x6472 "摲" */
+0x22,0x22,0x22,0x2f,0xf2,0x2f,0x2a,0x2f,0x3a,0xef,0x22,0x2f,0x22,0x22,0xa2,0x42,
+0x00,0x02,0x3c,0xa0,0x20,0xa0,0xbe,0xa4,0xa4,0xa4,0x24,0xa4,0x24,0x44,0x44,0x84,
+/* 25715 0x6473 "摳" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x12,0x53,0x20,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 25716 0x6474 "摴" */
+0x11,0x10,0x13,0x12,0xfd,0x10,0x11,0x14,0x19,0x30,0xd3,0x10,0x10,0x10,0x50,0x20,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,
+/* 25717 0x6475 "摵" */
+0x20,0x20,0x20,0x27,0xfc,0x24,0x24,0x2c,0x37,0xe4,0x24,0x25,0x2a,0x28,0xb1,0x40,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 25718 0x6476 "摶" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x15,0x18,0x33,0xd0,0x13,0x11,0x10,0x50,0x20,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 25719 0x6477 "摷" */
+0x11,0x12,0x11,0x10,0xfd,0x11,0x11,0x15,0x19,0x30,0xd3,0x10,0x10,0x11,0x56,0x20,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 25720 0x6478 "摸" */
+0x11,0x11,0x17,0x11,0xfc,0x13,0x12,0x17,0x1a,0x33,0xd0,0x17,0x10,0x11,0x52,0x24,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 25721 0x6479 "摹" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x10,0x27,0xc1,0x1f,0x01,0x03,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x50,0x88,0x06,0xf0,0x00,0x00,
+/* 25722 0x647a "摺" */
+0x20,0x27,0x20,0x24,0xfa,0x24,0x20,0x28,0x33,0xe2,0x22,0x23,0x22,0x22,0xa3,0x42,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 25723 0x647b "摻" */
+0x10,0x10,0x11,0x11,0xfa,0x13,0x14,0x19,0x36,0xd0,0x13,0x10,0x13,0x10,0x50,0x27,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 25724 0x647c "摼" */
+0x20,0x27,0x25,0x27,0xfc,0x27,0x25,0x2d,0x37,0xe0,0x20,0x27,0x20,0x20,0xaf,0x40,
+0x00,0xdc,0x14,0xd4,0x54,0xc8,0x08,0x14,0xe2,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 25725 0x647d "摽" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x14,0x19,0x30,0xd3,0x10,0x10,0x11,0x52,0x20,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 25726 0x647e "摾" */
+0x20,0x27,0x21,0x21,0xf9,0x27,0x24,0x2c,0x34,0xe7,0x21,0x21,0x21,0x21,0xaa,0x44,
+0x00,0x7c,0x44,0x44,0x7c,0x10,0x10,0x7c,0x54,0x54,0x54,0x7c,0x10,0x14,0xfe,0x02,
+/* 25727 0x647f "摿" */
+0x10,0x10,0x10,0x13,0xfc,0x11,0x10,0x14,0x1b,0x30,0xd1,0x11,0x11,0x11,0x51,0x21,
+0x20,0x50,0x88,0x46,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 25728 0x6480 "撀" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x9f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x68,0xc6,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25729 0x6481 "撁" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x12,0x10,0x19,0x30,0xd1,0x11,0x12,0x17,0x50,0x20,
+0x20,0xfe,0x48,0xf0,0x20,0xfe,0x42,0x90,0xf8,0x28,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 25730 0x6482 "撂" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x21,0x2b,0x35,0xe0,0x23,0x2c,0x23,0x22,0xa3,0x42,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,0xf8,0x08,0xf8,0x08,
+/* 25731 0x6483 "撃" */
+0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0xfe,0x10,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x78,0x48,0x48,0x86,0x78,0x48,0x30,0xce,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25732 0x6484 "撄" */
+0x20,0x2f,0x28,0x2a,0xfa,0x2a,0x25,0x28,0x30,0xef,0x21,0x22,0x23,0x20,0xa1,0x4e,
+0x00,0xbe,0xa2,0xaa,0xaa,0xaa,0x14,0xa2,0x80,0xfe,0x10,0x10,0xa0,0x60,0x98,0x04,
+/* 25733 0x6485 "撅" */
+0x20,0x2f,0x28,0x2a,0xf9,0x2b,0x28,0x28,0x3a,0xea,0x2b,0x28,0x28,0x29,0xa9,0x52,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 25734 0x6486 "撆" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25735 0x6487 "撇" */
+0x21,0x21,0x25,0x23,0xf9,0x27,0x25,0x2d,0x35,0xe7,0x25,0x25,0x25,0x25,0xa4,0x44,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 25736 0x6488 "撈" */
+0x20,0x22,0x22,0x24,0xf9,0x22,0x20,0x2b,0x32,0xe4,0x23,0x20,0x20,0x20,0xa1,0x42,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 25737 0x6489 "撉" */
+0x08,0x7f,0x22,0x3e,0x01,0x3e,0x04,0x7e,0x08,0x28,0x10,0x3f,0x01,0x7f,0x01,0x03,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0xf0,0x00,0x00,0xfc,0x00,0x00,
+/* 25738 0x648a "撊" */
+0x27,0x24,0x27,0x24,0xff,0x24,0x24,0x2c,0x34,0xe4,0x24,0x24,0x24,0x25,0xa4,0x44,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 25739 0x648b "撋" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x24,0x2d,0x34,0xe4,0x24,0x24,0x25,0x24,0xa4,0x44,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x44,0xe4,0x44,0x44,0xf4,0x04,0x14,0x08,
+/* 25740 0x648c "撌" */
+0x10,0x13,0x12,0x13,0xf8,0x17,0x10,0x1b,0x32,0xd3,0x12,0x13,0x12,0x13,0x51,0x22,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 25741 0x648d "撍" */
+0x20,0x27,0x21,0x25,0xf7,0x23,0x25,0x29,0x30,0xe3,0x22,0x22,0x23,0x22,0xa2,0x43,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 25742 0x648e "撎" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x12,0x15,0x18,0x31,0xd1,0x11,0x11,0x10,0x53,0x20,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 25743 0x648f "撏" */
+0x10,0x13,0x10,0x13,0xfc,0x13,0x10,0x17,0x19,0x37,0xd0,0x13,0x11,0x10,0x50,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 25744 0x6490 "撐" */
+0x11,0x10,0x13,0x12,0xfc,0x10,0x10,0x14,0x19,0x30,0xd1,0x11,0x10,0x10,0x53,0x20,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x00,0xfc,0x10,0x10,0xfe,0x50,0x90,0x10,0x30,
+/* 25745 0x6491 "撑" */
+0x11,0x10,0x13,0x12,0xfc,0x10,0x10,0x14,0x19,0x30,0xd1,0x10,0x13,0x10,0x50,0x20,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 25746 0x6492 "撒" */
+0x22,0x22,0x27,0x22,0xfa,0x27,0x20,0x2f,0x34,0xe7,0x24,0x27,0x24,0x24,0xa4,0x44,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 25747 0x6493 "撓" */
+0x10,0x10,0x11,0x10,0xfb,0x11,0x17,0x19,0x31,0xd6,0x10,0x13,0x10,0x10,0x51,0x22,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 25748 0x6494 "撔" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x14,0x1b,0x30,0xd1,0x11,0x11,0x10,0x11,0x52,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 25749 0x6495 "撕" */
+0x24,0x24,0x24,0x2f,0xf4,0x27,0x24,0x27,0x34,0xe4,0x2f,0x20,0x25,0x28,0xb0,0x40,
+0x80,0x82,0x9c,0xd0,0x90,0x90,0x9e,0x94,0x94,0x94,0xd4,0x14,0x14,0xa4,0x24,0x44,
+/* 25750 0x6496 "撖" */
+0x20,0x27,0x20,0x21,0xff,0x24,0x24,0x27,0x34,0xe7,0x24,0x24,0x27,0x2c,0xa0,0x40,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 25751 0x6497 "撗" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x10,0x15,0x19,0x31,0xd1,0x11,0x10,0x10,0x51,0x22,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 25752 0x6498 "撘" */
+0x12,0x12,0x13,0x12,0xfd,0x10,0x15,0x1a,0x35,0xd0,0x10,0x13,0x12,0x12,0x53,0x22,
+0x10,0x10,0xde,0x28,0x44,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 25753 0x6499 "撙" */
+0x21,0x20,0x27,0x20,0xfb,0x22,0x23,0x2a,0x33,0xe2,0x23,0x20,0x27,0x21,0xa0,0x40,
+0x08,0x90,0xfe,0x90,0xfc,0x94,0x1c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x08,0xa8,0x10,
+/* 25754 0x649a "撚" */
+0x21,0x21,0x21,0x22,0xfa,0x25,0x20,0x2a,0x31,0xe1,0x22,0x24,0x20,0x22,0xa2,0x44,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 25755 0x649b "撛" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x12,0x11,0x19,0x31,0xd2,0x15,0x10,0x11,0x52,0x24,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 25756 0x649c "撜" */
+0x20,0x27,0x20,0x22,0xf9,0x22,0x25,0x28,0x33,0xe2,0x22,0x23,0x22,0x21,0xaf,0x40,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 25757 0x649d "撝" */
+0x20,0x20,0x27,0x22,0xf9,0x23,0x22,0x2b,0x32,0xe3,0x24,0x26,0x2a,0x2a,0xb0,0x40,
+0x04,0x3e,0xc0,0x44,0x28,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 25758 0x649e "撞" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x11,0x15,0x19,0x31,0xd1,0x10,0x11,0x10,0x53,0x20,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25759 0x649f "撟" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x12,0x14,0x18,0x30,0xd3,0x12,0x12,0x12,0x52,0x22,
+0x1c,0xe0,0x40,0xfe,0x88,0x04,0xfa,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x06,
+/* 25760 0x64a0 "撠" */
+0x21,0x21,0x21,0x27,0xf9,0x27,0x24,0x2f,0x34,0xe7,0x21,0x2f,0x21,0x21,0xa1,0x41,
+0x10,0x14,0x12,0xd2,0x10,0xde,0x70,0xd2,0x52,0xd4,0x14,0xd8,0x0a,0x1a,0x26,0x42,
+/* 25761 0x64a1 "撡" */
+0x20,0x21,0x23,0x22,0xfc,0x27,0x20,0x28,0x33,0xec,0x20,0x22,0x22,0x24,0xa1,0x40,
+0x80,0x10,0xf8,0x10,0xa4,0xbc,0x40,0xa0,0x58,0x46,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 25762 0x64a2 "撢" */
+0x10,0x13,0x10,0x13,0xfe,0x13,0x10,0x15,0x19,0x31,0xd1,0x11,0x10,0x13,0x50,0x20,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 25763 0x64a3 "撣" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x15,0x19,0x31,0xd1,0x11,0x10,0x13,0x10,0x50,0x20,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 25764 0x64a4 "撤" */
+0x22,0x21,0x27,0x22,0xf4,0x2f,0x20,0x27,0x34,0xe7,0x24,0x27,0x24,0x24,0xa4,0x45,
+0x08,0x08,0xc8,0x10,0x9e,0xd4,0x64,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0xa4,0xc2,
+/* 25765 0x64a5 "撥" */
+0x20,0x23,0x20,0x25,0xf2,0x2c,0x27,0x20,0x37,0xe4,0x27,0x20,0x20,0x20,0xa5,0x42,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x00,0xbc,0x84,0xa8,0x90,0x28,0x44,
+/* 25766 0x64a6 "撦" */
+0x10,0x10,0x17,0x11,0xfa,0x14,0x13,0x18,0x37,0xd0,0x13,0x1d,0x11,0x11,0x51,0x21,
+0x40,0x40,0xfc,0x10,0x48,0x46,0xf8,0x50,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 25767 0x64a7 "撧" */
+0x21,0x21,0x22,0x22,0xf4,0x2f,0x21,0x22,0x34,0xef,0x20,0x20,0x2a,0x2a,0xa8,0x40,
+0x10,0x10,0x1c,0xa4,0xc8,0x3e,0x2a,0x2a,0xaa,0xbe,0xa0,0x22,0xa2,0xa2,0x1e,0x00,
+/* 25768 0x64a8 "撨" */
+0x10,0x10,0x11,0x11,0xfb,0x15,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x12,0x52,0x24,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 25769 0x64a9 "撩" */
+0x20,0x20,0x27,0x20,0xf5,0x22,0x27,0x2a,0x33,0xe2,0x23,0x20,0x22,0x24,0xa9,0x40,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 25770 0x64aa "撪" */
+0x20,0x21,0x23,0x20,0xf7,0x22,0x25,0x28,0x33,0xe2,0x23,0x22,0x23,0x20,0xa7,0x40,
+0x80,0x10,0xf8,0x80,0xfe,0x48,0xf4,0x42,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,
+/* 25771 0x64ab "撫" */
+0x11,0x11,0x13,0x16,0xfa,0x12,0x17,0x1a,0x32,0xd2,0x1f,0x10,0x12,0x12,0x54,0x20,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 25772 0x64ac "撬" */
+0x10,0x13,0x10,0x13,0xfc,0x13,0x10,0x14,0x18,0x37,0xd1,0x17,0x11,0x17,0x51,0x21,
+0x38,0xc0,0x78,0xc0,0x78,0xc4,0x3c,0x00,0xc6,0x38,0xce,0x38,0xce,0x38,0x4a,0x86,
+/* 25773 0x64ad "播" */
+0x20,0x27,0x22,0x21,0xfb,0x21,0x22,0x2c,0x33,0xe2,0x22,0x23,0x22,0x22,0xa3,0x42,
+0x78,0xc0,0x48,0x50,0xfc,0x50,0x48,0x06,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x08,
+/* 25774 0x64ae "撮" */
+0x20,0x23,0x22,0x23,0xfa,0x23,0x20,0x2f,0x34,0xe7,0x24,0x27,0x24,0x2f,0xa0,0x40,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x80,0xbc,0x94,0x94,0xd4,0x88,0x94,0xa2,
+/* 25775 0x64af "撯" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x13,0x14,0x19,0x32,0xd4,0x10,0x10,0x10,0x50,0x20,
+0x88,0x50,0xfe,0x20,0xfc,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 25776 0x64b0 "撰" */
+0x20,0x27,0x24,0x27,0xfc,0x24,0x23,0x28,0x31,0xe7,0x21,0x21,0x2f,0x21,0xa2,0x44,
+0x00,0xbc,0xa4,0xbc,0x20,0xa4,0x9c,0x00,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0x04,
+/* 25777 0x64b1 "撱" */
+0x20,0x27,0x25,0x25,0xfd,0x26,0x25,0x2d,0x35,0xe5,0x25,0x26,0x24,0x24,0xa4,0x44,
+0x20,0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 25778 0x64b2 "撲" */
+0x10,0x12,0x11,0x10,0xfb,0x10,0x14,0x1b,0x30,0xd1,0x10,0x13,0x10,0x10,0x51,0x26,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 25779 0x64b3 "撳" */
+0x22,0x22,0x25,0xf4,0x28,0x27,0x22,0x32,0xef,0x22,0x2a,0x27,0x22,0x23,0xac,0x40,
+0x10,0x10,0x10,0xbe,0x22,0x44,0x10,0x10,0x10,0x10,0xa8,0x28,0x28,0x44,0x44,0x82,
+/* 25780 0x64b4 "撴" */
+0x22,0x21,0x2f,0x20,0xf7,0x24,0x27,0x20,0x37,0xe0,0x21,0x21,0x2f,0x21,0xa5,0x42,
+0x10,0x10,0xd0,0x10,0xbe,0xa4,0xd4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 25781 0x64b5 "撵" */
+0x10,0x10,0x13,0x10,0xfb,0x10,0x11,0x1a,0x33,0xd0,0x11,0x13,0x10,0x17,0x50,0x20,
+0x88,0x88,0xde,0x88,0xde,0x88,0x54,0x22,0xfc,0x80,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 25782 0x64b6 "撶" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x10,0x17,0x18,0x30,0xd1,0x10,0x13,0x10,0x50,0x20,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 25783 0x64b7 "撷" */
+0x22,0x22,0x22,0x2f,0xf2,0x22,0x27,0x20,0x30,0xe7,0x25,0x25,0x25,0x27,0xa5,0x40,
+0x00,0xfe,0x10,0xa0,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 25784 0x64b8 "撸" */
+0x21,0x23,0x24,0x2f,0xf4,0x27,0x24,0x27,0x30,0xef,0x20,0x23,0x22,0x23,0xa2,0x43,
+0x00,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 25785 0x64b9 "撹" */
+0x12,0x11,0x11,0x13,0xfa,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x10,0x10,0x51,0x26,
+0x44,0x24,0x28,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x90,0x12,0x0e,
+/* 25786 0x64ba "撺" */
+0x20,0x20,0x27,0x25,0xfa,0x24,0x23,0x2a,0x33,0xe0,0x27,0x24,0x27,0x24,0xa0,0x40,
+0x80,0x40,0xfc,0x14,0x48,0x44,0xf8,0x48,0xf8,0x40,0xfc,0x44,0xfc,0x44,0x40,0x40,
+/* 25787 0x64bb "撻" */
+0x20,0x24,0x22,0x20,0xf8,0x20,0x26,0x2a,0x32,0xe2,0x22,0x22,0x22,0x22,0xa5,0x48,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 25788 0x64bc "撼" */
+0x20,0x20,0x27,0x24,0xf5,0x24,0x25,0x25,0x35,0xe4,0x24,0x28,0x22,0x22,0xa4,0x40,
+0x14,0x12,0xfe,0x10,0xd0,0x14,0xd4,0x58,0xca,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 25789 0x64bd "撽" */
+0x21,0x22,0x27,0x24,0xf7,0x24,0x27,0x22,0x31,0xe7,0x22,0x23,0x22,0x24,0xa5,0x48,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 25790 0x64be "撾" */
+0x10,0x12,0x11,0x11,0xfc,0x10,0x16,0x12,0x1a,0x32,0xd2,0x12,0x12,0x12,0x55,0x28,
+0x00,0x7c,0x44,0x74,0x54,0x54,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,0x00,0xfe,
+/* 25791 0x64bf "撿" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x10,0x14,0x19,0x31,0xd1,0x11,0x10,0x10,0x51,0x22,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 25792 0x64c0 "擀" */
+0x21,0x21,0x21,0x2f,0xf1,0x27,0x24,0x27,0x34,0xe7,0x21,0x2f,0x21,0x21,0xa1,0x41,
+0x08,0x08,0x14,0xd4,0x22,0xc0,0x5c,0xc8,0x48,0xc8,0x3e,0xc8,0x08,0x08,0x08,0x08,
+/* 25793 0x64c1 "擁" */
+0x20,0x20,0x27,0x20,0xfa,0x22,0x24,0x2f,0x31,0xe2,0x24,0x2f,0x21,0x22,0xa4,0x48,
+0x40,0x20,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x7e,0x40,
+/* 25794 0x64c2 "擂" */
+0x20,0x27,0x20,0x2f,0xf8,0x23,0x20,0x2b,0x30,0xe7,0x24,0x24,0x27,0x24,0xa4,0x47,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,
+/* 25795 0x64c3 "擃" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x10,0x17,0x1a,0x32,0xd2,0x13,0x15,0x15,0x55,0x29,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 25796 0x64c4 "擄" */
+0x10,0x10,0x10,0x13,0xfe,0x13,0x12,0x12,0x1a,0x32,0xd2,0x12,0x12,0x15,0x54,0x29,
+0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x20,0xfc,0x44,0x8c,
+/* 25797 0x64c5 "擅" */
+0x20,0x2f,0x20,0x27,0xfc,0x25,0x25,0x2f,0x30,0xe3,0x22,0x23,0x22,0x23,0xa0,0x4f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 25798 0x64c6 "擆" */
+0x11,0x11,0x17,0x11,0xf8,0x13,0x10,0x18,0x37,0xd0,0x11,0x13,0x15,0x19,0x51,0x21,
+0x08,0x08,0xfe,0x08,0x44,0xf4,0x48,0x50,0xfe,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 25799 0x64c7 "擇" */
+0x10,0x13,0x12,0x13,0xfc,0x11,0x14,0x1b,0x30,0xd0,0x11,0x10,0x17,0x10,0x50,0x20,
+0x00,0xfe,0x52,0xfe,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 25800 0x64c8 "擈" */
+0x10,0x12,0x11,0x10,0xfb,0x10,0x14,0x1b,0x30,0xd1,0x10,0x13,0x10,0x11,0x56,0x20,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 25801 0x64c9 "擉" */
+0x10,0x13,0x12,0x12,0xfb,0x11,0x13,0x1c,0x33,0xd2,0x12,0x13,0x10,0x17,0x50,0x20,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xfc,0x84,0xe4,0xa4,0xa4,0xe4,0x94,0xf4,0x14,0x08,
+/* 25802 0x64ca "擊" */
+0x08,0x7f,0x2a,0x3e,0x2a,0xff,0x49,0x7f,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x3c,0x24,0x24,0x42,0x3c,0xa4,0x18,0x66,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25803 0x64cb "擋" */
+0x20,0x22,0x21,0x27,0xf4,0x28,0x23,0x22,0x33,0xe0,0x27,0x24,0x27,0x24,0xa7,0x44,
+0x40,0x48,0x50,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 25804 0x64cc "擌" */
+0x22,0x22,0x23,0x25,0xf8,0x20,0x27,0x28,0x32,0xe2,0x25,0x28,0x20,0x21,0xa2,0x4c,
+0x10,0x10,0xde,0x28,0xc4,0x40,0xfe,0x40,0x48,0x48,0x54,0xa2,0xa0,0x10,0x08,0x06,
+/* 25805 0x64cd "操" */
+0x23,0x22,0x22,0x23,0xf8,0x27,0x24,0x2c,0x37,0xe0,0x2f,0x21,0x22,0x24,0xb8,0x40,
+0xf8,0x08,0x08,0xf8,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0xfe,0x60,0x50,0x48,0x46,0x40,
+/* 25806 0x64ce "擎" */
+0x24,0xff,0x24,0x7e,0x82,0x7a,0x4a,0x7a,0x04,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25807 0x64cf "擏" */
+0x22,0x22,0x27,0x22,0xfc,0x27,0x24,0x28,0x37,0xe5,0x25,0x27,0x25,0x20,0xa2,0x41,
+0x88,0x88,0xe8,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x94,0x22,
+/* 25808 0x64d0 "擐" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x17,0x18,0x33,0xd2,0x13,0x10,0x11,0x13,0x5d,0x21,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 25809 0x64d1 "擑" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x17,0x1a,0x33,0xd2,0x13,0x12,0x12,0x17,0x50,0x20,
+0x10,0xd4,0x52,0x52,0xd0,0x10,0xfe,0x50,0xd2,0x52,0xd4,0x54,0xea,0x4a,0x56,0x62,
+/* 25810 0x64d2 "擒" */
+0x20,0x20,0x21,0x22,0xfd,0x20,0x22,0x2a,0x33,0xe0,0x27,0x24,0x25,0x25,0xa4,0x44,
+0x40,0xa0,0x10,0x48,0xf6,0xa0,0x48,0xa8,0xf8,0x40,0xfc,0x84,0x24,0xf4,0x14,0x0c,
+/* 25811 0x64d3 "擓" */
+0x20,0x27,0x24,0x26,0xfd,0x24,0x24,0x2c,0x36,0xe5,0x24,0x24,0x25,0x26,0xa7,0x40,
+0x00,0xfe,0x28,0x24,0x7e,0x48,0xc8,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x40,0xfe,0x00,
+/* 25812 0x64d4 "擔" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x11,0x15,0x19,0x31,0xd1,0x11,0x11,0x12,0x52,0x24,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 25813 0x64d5 "擕" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x11,0x15,0x19,0x31,0xd3,0x12,0x12,0x12,0x52,0x22,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xde,0x52,0x52,0x72,0x02,0x06,
+/* 25814 0x64d6 "擖" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x11,0x15,0x18,0x31,0xd2,0x15,0x11,0x11,0x50,0x20,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 25815 0x64d7 "擗" */
+0x20,0x20,0x27,0x24,0xf4,0x24,0x27,0x24,0x34,0xe7,0x26,0x2a,0x2a,0x2b,0xb2,0x40,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0x7e,0x08,0x88,0xbe,0x88,0x88,0x88,0x88,0x08,
+/* 25816 0x64d8 "擘" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25817 0x64d9 "擙" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x13,0x16,0x1a,0x32,0xd0,0x13,0x10,0x10,0x50,0x23,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 25818 0x64da "據" */
+0x10,0x10,0x10,0x13,0xfe,0x12,0x13,0x16,0x1a,0x33,0xd2,0x13,0x12,0x15,0x54,0x29,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 25819 0x64db "擛" */
+0x10,0x13,0x10,0x10,0xfd,0x13,0x11,0x15,0x19,0x31,0xd0,0x13,0x10,0x10,0x53,0x20,
+0x88,0xfe,0x88,0x00,0x48,0xfe,0x48,0x78,0x00,0xfc,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 25820 0x64dc "擜" */
+0x21,0x21,0x27,0x21,0xf9,0x27,0x24,0x2e,0x35,0xe7,0x25,0x27,0x25,0x25,0xa4,0x44,
+0x08,0x08,0xcc,0x0a,0x08,0xde,0x48,0xc8,0x48,0xc8,0x54,0xd4,0x54,0x54,0x54,0xe2,
+/* 25821 0x64dd "擝" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x24,0x27,0x30,0xe0,0x23,0x22,0x22,0x22,0xaf,0x40,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xa4,0x24,0x4c,0xf8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 25822 0x64de "擞" */
+0x22,0x2a,0x27,0x22,0xff,0x22,0x27,0x2a,0x32,0xef,0x24,0x28,0x25,0x22,0xa5,0x48,
+0x10,0x90,0x10,0x20,0xbe,0x44,0xa4,0xa4,0x28,0xa8,0x90,0x90,0x28,0x28,0x44,0x82,
+/* 25823 0x64df "擟" */
+0x20,0x27,0x22,0xf4,0x2f,0x24,0x26,0x35,0xe6,0x24,0x26,0x25,0x26,0x24,0xa4,0x44,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 25824 0x64e0 "擠" */
+0x20,0x20,0x27,0x21,0xf0,0x2f,0x25,0x25,0x3b,0xe0,0x22,0x23,0x22,0x23,0xa2,0x44,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 25825 0x64e1 "擡" */
+0x20,0x2f,0x20,0x27,0xf0,0x23,0x22,0x2f,0x38,0xe7,0x21,0x23,0x20,0x27,0xa0,0x4f,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xfc,0x40,0xfe,
+/* 25826 0x64e2 "擢" */
+0x20,0x27,0x20,0x24,0xfa,0x24,0x21,0x2a,0x37,0xea,0x23,0x22,0x23,0x22,0xa3,0x42,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25827 0x64e3 "擣" */
+0x20,0x27,0x20,0x23,0xf8,0x27,0x20,0x2b,0x30,0xe7,0x20,0x27,0x20,0x27,0xa4,0x47,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 25828 0x64e4 "擤" */
+0x20,0x23,0x22,0x23,0xfa,0x23,0x20,0x2f,0x34,0xe7,0x24,0x27,0x20,0x2f,0xa1,0x42,
+0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x10,0x10,
+/* 25829 0x64e5 "擥" */
+0x00,0x7e,0x48,0x7e,0x43,0x7e,0x48,0x7e,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x00,0x40,0x7e,0x90,0x08,0xfe,0xaa,0xfe,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25830 0x64e6 "擦" */
+0x20,0x20,0x27,0x24,0xfa,0x23,0x24,0x2a,0x35,0xe2,0x24,0x2b,0x20,0x22,0xa4,0x40,
+0x80,0x40,0xfe,0x02,0x24,0xbc,0xa4,0xa8,0x10,0xe8,0x04,0xfa,0x40,0x48,0x44,0xc0,
+/* 25831 0x64e7 "擧" */
+0x0a,0x33,0x22,0x3b,0x20,0x3a,0x22,0xff,0x08,0x37,0xc1,0x1f,0x01,0x7f,0x01,0x03,
+0x00,0xb8,0x08,0xb8,0x88,0xb8,0x88,0xfe,0x20,0xd8,0x06,0xf0,0x00,0xfc,0x00,0x00,
+/* 25832 0x64e8 "擨" */
+0x20,0x20,0x2f,0x28,0xf8,0x2b,0x2a,0x2a,0x3b,0xea,0x2a,0x2a,0x2a,0x2a,0xaa,0x55,
+0x08,0x68,0x88,0xee,0x8a,0xf2,0xa4,0xc4,0x84,0xa4,0x64,0x0a,0xea,0xaa,0xaa,0x30,
+/* 25833 0x64e9 "擩" */
+0x20,0x27,0x20,0x2f,0xf8,0x23,0x20,0x2b,0x30,0xef,0x20,0x27,0x24,0x24,0xa4,0x44,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfe,0x40,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 25834 0x64ea "擪" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x27,0x20,0x27,0x20,0x5f,0x40,0x80,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0x94,0xa2,0xf8,0x40,0xfc,0x40,0xfe,0x40,0xc0,
+/* 25835 0x64eb "擫" */
+0x20,0x2f,0x28,0x2b,0xfa,0x2b,0x2a,0x2b,0x38,0xeb,0x2a,0x2b,0x2a,0x2b,0xaa,0x52,
+0x00,0xfe,0x08,0xc8,0x4c,0xca,0x48,0xde,0x08,0xc8,0x48,0xd4,0x54,0xd4,0x54,0xe2,
+/* 25836 0x64ec "擬" */
+0x24,0x25,0x26,0xf4,0x23,0x20,0x24,0x37,0xea,0x22,0x2f,0x22,0x25,0x24,0xa8,0x41,
+0x00,0x7c,0x04,0xa8,0x90,0x7c,0x14,0x94,0x50,0x50,0xdc,0x50,0x50,0xb0,0x9e,0x00,
+/* 25837 0x64ed "擭" */
+0x10,0x13,0x10,0x10,0xfd,0x13,0x11,0x15,0x19,0x31,0xd1,0x11,0x13,0x10,0x50,0x23,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 25838 0x64ee "擮" */
+0x21,0x21,0x27,0x21,0xff,0x22,0x24,0x2f,0x34,0xe7,0x24,0x27,0x24,0x27,0xa4,0x40,
+0x10,0x14,0xd2,0x10,0xfe,0x90,0x50,0xf4,0x94,0xf4,0x94,0xe8,0x8a,0xfa,0x26,0x42,
+/* 25839 0x64ef "擯" */
+0x10,0x10,0x13,0x12,0xfd,0x11,0x16,0x19,0x33,0xd1,0x11,0x11,0x11,0x11,0x50,0x21,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 25840 0x64f0 "擰" */
+0x10,0x10,0x13,0x12,0xfd,0x11,0x12,0x10,0x19,0x31,0xd3,0x10,0x11,0x10,0x50,0x20,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 25841 0x64f1 "擱" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x24,0x2d,0x36,0xe4,0x27,0x24,0x24,0x24,0xa4,0x44,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x84,0xf4,0x94,0xe4,0x1c,0xe4,0xa4,0xa4,0xe4,0x0c,
+/* 25842 0x64f2 "擲" */
+0x24,0x22,0x2f,0xf2,0x2f,0x2a,0x2c,0x3b,0xe8,0x2f,0x21,0x2f,0x22,0x24,0xa8,0x40,
+0x40,0x8e,0xea,0x8a,0xea,0xaa,0x6c,0xaa,0x2a,0xea,0x0a,0xea,0x8c,0x48,0x28,0x08,
+/* 25843 0x64f3 "擳" */
+0x11,0x11,0x11,0x12,0xfc,0x10,0x13,0x16,0x1b,0x32,0xd3,0x12,0x12,0x13,0x52,0x20,
+0x08,0x08,0xee,0x94,0x42,0x00,0xde,0x52,0xd2,0x52,0xd2,0x1a,0x94,0x50,0x10,0x10,
+/* 25844 0x64f4 "擴" */
+0x20,0x20,0x27,0x24,0xfd,0x24,0x27,0x2c,0x35,0xe5,0x25,0x25,0x25,0x24,0xa4,0x49,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 25845 0x64f5 "擵" */
+0x20,0x27,0x24,0x27,0xf4,0x25,0x26,0x24,0x35,0xe4,0x25,0x24,0x27,0x28,0xa8,0x50,
+0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x8c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 25846 0x64f6 "擶" */
+0x12,0x13,0x15,0x10,0xfd,0x10,0x17,0x10,0x1b,0x32,0xd3,0x12,0x13,0x12,0x52,0x22,
+0x10,0xde,0x28,0x84,0x08,0x90,0xfe,0x00,0xd4,0x54,0xd4,0x54,0xd4,0x44,0x54,0xc8,
+/* 25847 0x64f7 "擷" */
+0x22,0x22,0x22,0x2f,0xf2,0x22,0x27,0x20,0x30,0xe7,0x25,0x25,0x25,0x27,0xa5,0x40,
+0x00,0x7e,0x10,0xa0,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 25848 0x64f8 "擸" */
+0x11,0x12,0x11,0x10,0xfb,0x12,0x16,0x1a,0x33,0xd2,0x13,0x12,0x13,0x12,0x52,0x23,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 25849 0x64f9 "擹" */
+0x22,0x22,0x27,0x22,0xfb,0x21,0x27,0x2d,0x37,0xe1,0x27,0x21,0x2f,0x22,0xa4,0x48,
+0x90,0x90,0xd0,0x9e,0x92,0x22,0xc8,0x48,0xc8,0x08,0xc8,0x14,0xd4,0x94,0x54,0x22,
+/* 25850 0x64fa "擺" */
+0x20,0x27,0x24,0x24,0xf7,0x22,0x24,0x27,0x30,0xef,0x28,0x2f,0x28,0x2f,0xa8,0x49,
+0x00,0xfc,0xa4,0xa4,0xfc,0x20,0xa4,0xb8,0x22,0x9e,0x80,0xa4,0xb8,0xa2,0xa2,0x9e,
+/* 25851 0x64fb "擻" */
+0x21,0x27,0x25,0x2f,0xf5,0x27,0x21,0x27,0x35,0xe7,0x22,0x2f,0x24,0x26,0xa1,0x46,
+0x08,0xc8,0x48,0xf0,0x5e,0xe4,0x14,0xd4,0x54,0xd4,0x14,0xc8,0x48,0x94,0x94,0x62,
+/* 25852 0x64fc "擼" */
+0x21,0x23,0x24,0x2f,0xf4,0x27,0x24,0x27,0x35,0xe8,0x23,0x22,0x23,0x22,0xa3,0x42,
+0x00,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x24,0x92,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 25853 0x64fd "擽" */
+0x24,0x24,0x28,0x2a,0xfe,0x24,0x2a,0x2e,0x32,0xe0,0x2f,0x20,0x21,0x22,0xac,0x40,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 25854 0x64fe "擾" */
+0x27,0x20,0x23,0x22,0xf3,0x22,0x2f,0x28,0x35,0xe5,0x28,0x21,0x23,0x25,0xa0,0x4f,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xfe,0x82,0x48,0x14,0xf4,0x00,0xf8,0x08,0xf0,0x0e,
+/* 25855 0x64ff "擿" */
+0x20,0x20,0x24,0x22,0xfa,0x20,0x20,0x2e,0x32,0xe2,0x22,0x22,0x22,0x25,0xa8,0x40,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x92,0xfe,0x92,0xba,0xaa,0xba,0x86,0x00,0xfe,0x00,
+/* 25856 0x6500 "攀" */
+0x22,0x21,0xfa,0x20,0x72,0xa9,0x22,0xff,0x08,0x37,0xc1,0x1f,0x01,0x7f,0x01,0x03,
+0x88,0x08,0xbe,0x08,0x9c,0x2a,0x88,0xfe,0x20,0xd8,0x06,0xf0,0x00,0xfc,0x00,0x00,
+/* 25857 0x6501 "攁" */
+0x22,0x21,0x27,0x20,0xfb,0x20,0x27,0x29,0x33,0xe6,0x2b,0x22,0x23,0x22,0xa2,0x43,
+0x08,0x10,0xfc,0x40,0xf8,0x80,0xfc,0x48,0xfc,0x0a,0xf8,0x08,0xfa,0x34,0x8c,0x02,
+/* 25858 0x6502 "攂" */
+0x23,0x22,0x22,0x23,0xf2,0x22,0x23,0x20,0x3f,0xea,0x2a,0x2f,0x2a,0x2a,0xaf,0x48,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 25859 0x6503 "攃" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x12,0x15,0x1a,0x31,0xd2,0x11,0x10,0x11,0x52,0x20,
+0x88,0x88,0xfe,0x88,0x10,0xde,0x52,0x54,0x88,0x74,0x02,0xfc,0x20,0x24,0x22,0x60,
+/* 25860 0x6504 "攄" */
+0x20,0x20,0x20,0x27,0xfc,0x25,0x24,0x2d,0x35,0xe5,0x25,0x25,0x28,0x2a,0xb2,0x44,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x24,0xfc,0x24,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 25861 0x6505 "攅" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x12,0x11,0x19,0x31,0xd1,0x11,0x11,0x11,0x50,0x21,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 25862 0x6506 "攆" */
+0x10,0x13,0x10,0x13,0xfd,0x12,0x11,0x14,0x19,0x31,0xd1,0x11,0x11,0x10,0x53,0x20,
+0x88,0xde,0x88,0xde,0x54,0x22,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,
+/* 25863 0x6507 "攇" */
+0x20,0x2f,0x28,0x27,0xf8,0x23,0x20,0x2f,0x30,0xe7,0x24,0x27,0x20,0x25,0xa5,0x48,
+0x40,0xfe,0x42,0xfc,0x40,0xf8,0x40,0xfc,0x40,0xfc,0xa4,0xfc,0x40,0x24,0x2a,0xfa,
+/* 25864 0x6508 "攈" */
+0x10,0x13,0x12,0x13,0xfa,0x13,0x12,0x1a,0x32,0xd2,0x12,0x12,0x12,0x15,0x54,0x2b,
+0x20,0xfe,0x50,0xfe,0x52,0xfe,0x94,0xd8,0x92,0xce,0x08,0xf0,0x20,0xfc,0xa8,0x26,
+/* 25865 0x6509 "攉" */
+0x27,0x20,0x27,0x24,0xfb,0x20,0x27,0x29,0x33,0xe6,0x2b,0x22,0x23,0x22,0xa3,0x42,
+0xfc,0x40,0xfe,0x42,0x5c,0x40,0x5c,0x20,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 25866 0x650a "攊" */
+0x20,0x27,0x24,0x25,0xfc,0x27,0x24,0x2d,0x36,0xe4,0x24,0x25,0x25,0x29,0xa9,0x57,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 25867 0x650b "攋" */
+0x21,0x21,0x27,0x21,0xf9,0x27,0x25,0x2d,0x37,0xe1,0x23,0x25,0x29,0x21,0xa1,0x41,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 25868 0x650c "攌" */
+0x2f,0x28,0x2b,0x2a,0xfb,0x28,0x2b,0x28,0x39,0xe9,0x29,0x28,0x29,0x2a,0xa8,0x4f,
+0xfe,0x02,0xfa,0xaa,0xfa,0x02,0xfa,0x02,0xf2,0x12,0xf2,0xaa,0x92,0xca,0x82,0xfe,
+/* 25869 0x650d "攍" */
+0x40,0x7f,0x48,0x4f,0xe0,0x4f,0x48,0x4f,0x60,0xdc,0x57,0x5d,0x55,0x5c,0x55,0xee,
+0x80,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x80,0x9c,0xd4,0x54,0x5c,0x96,0x56,0x22,
+/* 25870 0x650e "攎" */
+0x10,0x10,0x10,0x13,0xfe,0x13,0x12,0x16,0x1a,0x32,0xd2,0x12,0x12,0x15,0x55,0x2b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 25871 0x650f "攏" */
+0x11,0x10,0x13,0x10,0xfa,0x11,0x17,0x18,0x33,0xd2,0x13,0x12,0x13,0x12,0x52,0x22,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 25872 0x6510 "攐" */
+0x10,0x17,0x14,0x13,0xfc,0x13,0x10,0x17,0x19,0x32,0xd5,0x10,0x11,0x12,0x54,0x20,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x48,0x24,0xfa,0xa4,0xa8,0x90,0xc8,0x86,
+/* 25873 0x6511 "攑" */
+0x11,0x12,0x12,0x13,0xfe,0x13,0x12,0x17,0x19,0x32,0xd5,0x10,0x17,0x10,0x50,0x20,
+0x40,0x6c,0x44,0x6c,0xa4,0xac,0xa4,0xfe,0x08,0x44,0xf2,0x40,0xfc,0x40,0x40,0x40,
+/* 25874 0x6512 "攒" */
+0x21,0x25,0x27,0x29,0xf7,0x23,0x25,0x29,0x30,0xe3,0x22,0x22,0x22,0x20,0xa1,0x46,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0x00,0xf8,0x08,0x48,0x48,0xb0,0x08,0x04,
+/* 25875 0x6513 "攓" */
+0x20,0x27,0x24,0x23,0xf8,0x23,0x20,0x2f,0x31,0xe3,0x25,0x21,0x22,0x22,0xa5,0x48,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0xfc,0x0a,0xf8,0x40,0x7c,0x40,0xfe,
+/* 25876 0x6514 "攔" */
+0x27,0x24,0x27,0x24,0xff,0x24,0x25,0x2c,0x35,0xe5,0x25,0x25,0x25,0x24,0xa5,0x44,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xf4,0x44,0xf4,0x54,0xf4,0x54,0xf4,0xe4,0x54,0x4c,
+/* 25877 0x6515 "攕" */
+0x24,0x24,0x2a,0xf0,0x2f,0x22,0x2e,0x32,0xee,0x22,0x2e,0x22,0x22,0x2f,0xa4,0x40,
+0x48,0x4c,0xaa,0x08,0xfe,0x88,0xe8,0x8a,0xea,0x8c,0xec,0x88,0xea,0x1a,0x26,0x42,
+/* 25878 0x6516 "攖" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x13,0x19,0x32,0xd0,0x17,0x10,0x11,0x10,0x50,0x23,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 25879 0x6517 "攗" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x25,0x2d,0x35,0xe5,0x25,0x24,0x27,0x28,0xa9,0x52,
+0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x14,0xd8,0x12,0x4e,0xa4,0xa8,0xfe,0xa8,0x24,0x22,
+/* 25880 0x6518 "攘" */
+0x20,0x27,0x20,0x23,0xfa,0x23,0x21,0x2f,0x31,0xe7,0x21,0x2f,0x21,0x23,0xad,0x41,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 25881 0x6519 "攙" */
+0x11,0x12,0x17,0x12,0xfb,0x12,0x13,0x1a,0x31,0xd2,0x17,0x12,0x13,0x10,0x51,0x26,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 25882 0x651a "攚" */
+0x10,0x12,0x12,0x14,0xf9,0x12,0x17,0x1a,0x30,0xd0,0x10,0x10,0x11,0x11,0x51,0x21,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xf8,0x88,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 25883 0x651b "攛" */
+0x10,0x17,0x14,0x11,0xfc,0x13,0x12,0x17,0x1a,0x33,0xd2,0x13,0x12,0x13,0x52,0x23,
+0x40,0xfe,0x92,0x08,0x80,0x1c,0x04,0x9c,0x04,0xfc,0x48,0x68,0x48,0x6a,0x46,0x62,
+/* 25884 0x651c "攜" */
+0x12,0x13,0x10,0x11,0xfb,0x15,0x11,0x19,0x31,0xd1,0x11,0x13,0x12,0x13,0x52,0x22,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 25885 0x651d "攝" */
+0x13,0x11,0x11,0x11,0xfd,0x11,0x17,0x18,0x37,0xd2,0x13,0x12,0x13,0x12,0x57,0x20,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 25886 0x651e "攞" */
+0x20,0x27,0x24,0xf4,0x27,0x22,0x22,0x34,0xef,0x22,0x24,0x2f,0x20,0x2a,0xaa,0x40,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 25887 0x651f "攟" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x24,0x2d,0x35,0xe5,0x25,0x25,0x25,0x29,0xa9,0x51,
+0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x00,0xfc,0x04,0x74,0x24,0xfc,0x74,0xac,0x24,0xfc,
+/* 25888 0x6520 "攠" */
+0x20,0x27,0x24,0x27,0xfc,0x25,0x26,0x2c,0x34,0xe7,0x24,0x25,0x24,0x2b,0xa8,0x50,
+0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 25889 0x6521 "攡" */
+0x24,0x22,0x2f,0x25,0xfa,0x2d,0x28,0x2f,0x32,0xef,0x2a,0x2a,0x2b,0x28,0xaa,0x49,
+0x18,0x14,0x90,0x3e,0xa8,0xe8,0xbe,0xa8,0x28,0xbe,0xa8,0xa8,0xa8,0xbe,0xa0,0x20,
+/* 25890 0x6522 "攢" */
+0x25,0x27,0x29,0x27,0xfb,0x25,0x29,0x2b,0x32,0xe3,0x22,0x23,0x22,0x23,0xa1,0x42,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 25891 0x6523 "攣" */
+0x21,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x00,0x1f,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x08,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 25892 0x6524 "攤" */
+0x25,0x25,0x2f,0x25,0xf7,0x22,0x2f,0x2a,0x3f,0xe2,0x2f,0x22,0x3f,0x25,0xa8,0x50,
+0x18,0x14,0x90,0x3e,0x28,0x68,0xbe,0xa8,0xa8,0x3e,0xa8,0x28,0xe8,0x3e,0xa0,0x60,
+/* 25893 0x6525 "攥" */
+0x22,0x23,0x25,0x20,0xfb,0x22,0x22,0x2b,0x30,0xe7,0x22,0x25,0x28,0x23,0xa1,0x42,
+0x10,0xde,0x28,0x84,0xfc,0xa4,0x54,0xfc,0x80,0xfe,0xa8,0xe4,0x52,0xf8,0x50,0xc8,
+/* 25894 0x6526 "攦" */
+0x2f,0x20,0x27,0x24,0xf6,0x24,0x20,0x27,0x34,0xe7,0x24,0x27,0x25,0x29,0xa9,0x51,
+0xbe,0x00,0xbc,0xa4,0xb4,0xa4,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x12,0xdc,0x12,0xce,
+/* 25895 0x6527 "攧" */
+0x22,0x22,0x2f,0x22,0xf7,0x24,0x27,0x24,0x37,0xe4,0x27,0x24,0x2f,0x25,0xa4,0x48,
+0x00,0x1e,0xc4,0x08,0x9e,0x92,0x92,0x9e,0x92,0x9e,0x92,0x92,0xde,0x00,0x8c,0x92,
+/* 25896 0x6528 "攨" */
+0x20,0x2f,0x2a,0x24,0xf3,0x22,0x22,0x22,0x34,0xe1,0x2e,0x2b,0x2a,0x2a,0xab,0x52,
+0x40,0xfe,0x0a,0x34,0xc0,0x90,0x88,0xa4,0xd0,0x8e,0x74,0x54,0xd4,0x52,0x5a,0x94,
+/* 25897 0x6529 "攩" */
+0x22,0x21,0x27,0x24,0xf9,0x21,0x27,0x2d,0x34,0xe7,0x20,0x27,0x20,0x2f,0xa2,0x44,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 25898 0x652a "攪" */
+0x22,0x24,0x26,0x24,0xf6,0x24,0x2f,0x2a,0x33,0xe2,0x23,0x22,0x23,0x20,0xa1,0x46,
+0xac,0x44,0xac,0x44,0xac,0x04,0xfe,0x0a,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 25899 0x652b "攫" */
+0x13,0x12,0x13,0x12,0xfb,0x10,0x11,0x1b,0x35,0xd1,0x11,0x10,0x11,0x10,0x50,0x27,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 25900 0x652c "攬" */
+0x27,0x25,0x27,0x24,0xff,0x25,0x27,0x28,0x33,0xe2,0x23,0x22,0x23,0x20,0xa1,0x46,
+0x90,0x1e,0xa8,0x84,0xbe,0x2a,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 25901 0x652d "攭" */
+0x21,0x22,0x23,0x20,0xf7,0x21,0x26,0x21,0x36,0xe1,0x22,0x2f,0x2a,0x2f,0xa2,0x4f,
+0xf0,0x10,0xe0,0x20,0xfc,0x88,0x50,0xa8,0x64,0xa0,0x48,0xbe,0xaa,0xbe,0x8a,0xbe,
+/* 25902 0x652e "攮" */
+0x20,0x27,0x22,0x23,0xf0,0x2f,0x2a,0x23,0x31,0xe7,0x21,0x2f,0x21,0x23,0xad,0x41,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 25903 0x652f "支" */
+0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x3f,0x10,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 25904 0x6530 "攰" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x19,0x24,0x43,0x80,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,0x00,0xfe,0x00,
+/* 25905 0x6531 "攱" */
+0x20,0x10,0x10,0xfd,0x00,0x08,0x88,0x89,0x48,0x48,0x50,0x50,0x1c,0xe0,0x41,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 25906 0x6532 "攲" */
+0x10,0x10,0xfe,0x10,0x28,0x44,0xfe,0x04,0x74,0x54,0x54,0x74,0x54,0x04,0x14,0x09,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25907 0x6533 "攳" */
+0x11,0x10,0x10,0xfe,0x11,0x10,0xfd,0x44,0x47,0x28,0x2b,0x11,0x18,0x24,0x43,0x80,
+0xfc,0x04,0xfc,0x04,0xfc,0x00,0xde,0x92,0xde,0x08,0xfe,0x08,0xa8,0x10,0xfe,0x00,
+/* 25908 0x6534 "攴" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x10,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 25909 0x6535 "攵" */
+0x04,0x04,0x04,0x0f,0x08,0x10,0x30,0x48,0x84,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 25910 0x6536 "收" */
+0x08,0x08,0x48,0x48,0x48,0x49,0x4a,0x48,0x48,0x58,0x68,0x48,0x08,0x08,0x09,0x0a,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25911 0x6537 "攷" */
+0x00,0x00,0xfe,0x20,0x20,0x21,0x42,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x29,0x12,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25912 0x6538 "攸" */
+0x08,0x08,0x08,0x10,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0x12,0x12,0x10,0x10,0x11,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25913 0x6539 "改" */
+0x00,0x00,0xfc,0x04,0x05,0x05,0x06,0x7c,0x40,0x40,0x40,0x44,0x58,0x60,0x41,0x02,
+0x40,0x40,0x80,0xfe,0x08,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25914 0x653a "攺" */
+0x00,0x00,0x7c,0x44,0x44,0x45,0x46,0x44,0x7c,0x40,0x40,0x40,0x44,0x58,0x61,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25915 0x653b "攻" */
+0x00,0x00,0x00,0xfe,0x10,0x11,0x12,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x01,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25916 0x653c "攼" */
+0x00,0x7c,0x10,0x10,0x10,0x11,0x12,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x11,0x12,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25917 0x653d "攽" */
+0x00,0x14,0x12,0x12,0x21,0x21,0x40,0xbe,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x85,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25918 0x653e "放" */
+0x20,0x10,0x00,0xfe,0x20,0x21,0x3e,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x89,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25919 0x653f "政" */
+0x00,0x00,0xff,0x08,0x08,0x08,0x48,0x4e,0x48,0x48,0x48,0x48,0x4f,0xf0,0x00,0x01,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25920 0x6540 "敀" */
+0x10,0x10,0x20,0x7c,0x44,0x45,0x46,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25921 0x6541 "敁" */
+0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x01,0x06,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 25922 0x6542 "敂" */
+0x10,0x10,0x20,0x3f,0x41,0x81,0x3d,0x25,0x25,0x25,0x3d,0x25,0x01,0x01,0x0a,0x05,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25923 0x6543 "敃" */
+0x00,0xfe,0x82,0x82,0x82,0xfe,0x90,0x90,0xff,0x90,0x90,0x88,0x89,0xa5,0xc3,0x81,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25924 0x6544 "敄" */
+0x00,0xfc,0x04,0x68,0x10,0x09,0xfe,0x12,0x34,0x30,0x50,0x50,0x90,0x10,0x51,0x22,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25925 0x6545 "故" */
+0x10,0x10,0x10,0x10,0xfe,0x11,0x12,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25926 0x6546 "敆" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 25927 0x6547 "敇" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x49,0x4d,0x4a,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x10,0x10,0x90,0x20,0x3e,0x44,0x24,0x24,0x24,0x28,0x28,0x10,0x28,0xa8,0x44,0x82,
+/* 25928 0x6548 "效" */
+0x10,0x08,0x00,0xff,0x00,0x24,0x42,0x81,0x24,0x14,0x08,0x14,0x22,0x42,0x80,0x01,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25929 0x6549 "敉" */
+0x10,0x10,0x94,0x54,0x58,0x11,0xfe,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x11,0x12,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25930 0x654a "敊" */
+0x08,0x08,0x0e,0x08,0x08,0x08,0xfe,0x00,0x08,0x08,0x4a,0x49,0x89,0x08,0x28,0x10,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25931 0x654b "敋" */
+0x20,0x20,0x3c,0x44,0xc4,0x29,0x12,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x7d,0x46,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25932 0x654c "敌" */
+0x04,0x0e,0x38,0x08,0x08,0xff,0x08,0x08,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25933 0x654d "敍" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x08,0x2a,0x29,0x49,0x88,0x28,0x10,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25934 0x654e "敎" */
+0x02,0x64,0x18,0x24,0xd2,0x11,0xfe,0x20,0xfe,0x44,0x88,0x0f,0xf8,0x08,0x29,0x12,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25935 0x654f "敏" */
+0x40,0x40,0x7f,0x80,0x7e,0x42,0x52,0x4a,0xff,0x42,0x92,0x8a,0xff,0x02,0x14,0x09,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0xa8,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25936 0x6550 "敐" */
+0x00,0x7f,0x40,0x40,0x5e,0x40,0x40,0x7f,0x50,0x51,0x5a,0x54,0x52,0x91,0x98,0x10,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25937 0x6551 "救" */
+0x10,0x14,0x12,0x10,0xfe,0x11,0x10,0x92,0x54,0x10,0x38,0x54,0x92,0x10,0x51,0x22,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25938 0x6552 "敒" */
+0x12,0x12,0x12,0x2f,0x2a,0x6a,0x6a,0xaf,0x2a,0x2a,0x2a,0x2f,0x22,0x22,0x22,0x22,
+0x10,0x10,0x10,0xa0,0xbe,0xc4,0xa4,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x28,0x44,0x82,
+/* 25939 0x6553 "敓" */
+0x00,0x28,0x24,0x42,0x80,0x7d,0x46,0x44,0x44,0x7c,0x28,0x28,0x28,0x2a,0x4d,0x8a,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25940 0x6554 "敔" */
+0x00,0xff,0x10,0x10,0x7e,0x22,0x22,0xff,0x00,0x00,0x7e,0x42,0x42,0x42,0x7e,0x42,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25941 0x6555 "敕" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x1c,0x2a,0x49,0x88,0x08,0x09,
+0x20,0x20,0xa0,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25942 0x6556 "敖" */
+0x08,0x08,0x08,0x7f,0x08,0x3e,0x08,0xff,0x10,0x1e,0x12,0x12,0x22,0x2a,0x44,0x81,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25943 0x6557 "敗" */
+0x00,0x7c,0x44,0x44,0x7d,0x45,0x46,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x45,0x82,
+0x40,0x40,0x80,0xfe,0x08,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25944 0x6558 "敘" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x08,0x2a,0x29,0x49,0x88,0x28,0x11,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25945 0x6559 "教" */
+0x08,0x08,0x7e,0x09,0x0a,0xff,0x08,0x7e,0x24,0x48,0x8f,0x78,0x08,0x08,0x28,0x11,
+0x20,0x20,0xa0,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25946 0x655a "敚" */
+0x44,0x24,0x28,0x00,0x7c,0x45,0x46,0x44,0x7c,0x28,0x28,0x28,0x2a,0x4c,0x89,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 25947 0x655b "敛" */
+0x08,0x08,0x14,0x12,0x21,0x40,0xbe,0x00,0x11,0x09,0x49,0x22,0x22,0x07,0x78,0x21,
+0x20,0x20,0x20,0x3e,0x44,0xc4,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25948 0x655c "敜" */
+0x08,0x08,0x14,0x22,0x51,0x88,0x7e,0x02,0x14,0x08,0x2a,0xa1,0xa1,0xa5,0x1c,0x00,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25949 0x655d "敝" */
+0x08,0x49,0x29,0x2a,0x08,0x7f,0x49,0x49,0x5d,0x6b,0x49,0x49,0x49,0x41,0x45,0x42,
+0x10,0x10,0x10,0x20,0x3e,0x44,0x24,0x24,0x24,0x28,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 25950 0x655e "敞" */
+0x08,0x49,0x29,0x2a,0x08,0x7f,0x41,0x41,0x5d,0x55,0x55,0x55,0x5d,0x41,0x45,0x42,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25951 0x655f "敟" */
+0x14,0x14,0x14,0x7f,0x55,0x55,0x55,0x7f,0x55,0x55,0x55,0xff,0x24,0x22,0x42,0x81,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x90,0x28,0x48,0x84,0x02,
+/* 25952 0x6560 "敠" */
+0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25953 0x6561 "敡" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x20,0x7f,0x95,0x25,0x49,0x91,0x25,0x42,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25954 0x6562 "敢" */
+0x00,0x7e,0x02,0x04,0xff,0x22,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2f,0xf2,0x42,0x02,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25955 0x6563 "散" */
+0x24,0x24,0x7e,0x24,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x42,0x4a,0x44,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25956 0x6564 "敤" */
+0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25957 0x6565 "敥" */
+0x08,0x09,0x49,0x4a,0x88,0x14,0x22,0x49,0x88,0x49,0x49,0x8a,0x14,0x22,0x41,0x80,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25958 0x6566 "敦" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x00,0x7e,0x04,0x08,0x0f,0xf8,0x08,0x28,0x11,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25959 0x6567 "敧" */
+0x08,0x08,0x7f,0x14,0x22,0x41,0xff,0x02,0x7a,0x4a,0x4a,0x7a,0x4a,0x02,0x0a,0x04,
+0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 25960 0x6568 "敨" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25961 0x6569 "敩" */
+0x51,0x29,0x2a,0x00,0xff,0x80,0x01,0x7e,0x04,0x08,0x0f,0xf8,0x08,0x08,0x28,0x10,
+0x10,0x10,0x10,0x20,0xbe,0xc4,0x24,0x24,0x24,0x28,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 25962 0x656a "敪" */
+0x00,0xf7,0x11,0x55,0x22,0x55,0x99,0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,0x01,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25963 0x656b "敫" */
+0x08,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x10,0x08,0xff,0x20,0x3e,0x22,0x42,0x4a,0x85,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25964 0x656c "敬" */
+0x22,0x22,0xff,0x22,0x40,0x7f,0x41,0x81,0x7d,0x45,0x45,0x7d,0x45,0x01,0x0a,0x04,
+0x20,0x20,0xa0,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25965 0x656d "敭" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x00,0xff,0x40,0x7f,0x95,0x25,0x49,0x91,0x2a,0x45,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25966 0x656e "敮" */
+0x02,0x0f,0x78,0x08,0x08,0xff,0x28,0x4b,0x49,0x49,0x6b,0x49,0x49,0x7f,0x41,0x00,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25967 0x656f "敯" */
+0x00,0xfe,0x82,0xfe,0x88,0xff,0x88,0xa5,0xc3,0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25968 0x6570 "数" */
+0x08,0x49,0x2a,0x08,0xff,0x2a,0x49,0x88,0x10,0xfe,0x22,0x42,0x64,0x18,0x34,0xc2,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25969 0x6571 "敱" */
+0x08,0x49,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x42,0x24,0x0f,0xf0,0x40,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25970 0x6572 "敲" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x00,0xff,0x81,0xbd,0xa5,0xbd,0x81,0x85,0x82,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25971 0x6573 "敳" */
+0x08,0x49,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x42,0x24,0x0f,0xf0,0x41,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25972 0x6574 "整" */
+0x08,0x08,0xff,0x08,0x7f,0x49,0x7f,0x2a,0x49,0x88,0x00,0x7f,0x01,0x11,0x11,0xff,
+0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,0x00,0xfc,0x00,0xf8,0x00,0xfe,
+/* 25973 0x6575 "敵" */
+0x10,0x08,0x7f,0x22,0x14,0x7f,0x41,0x49,0x7f,0x49,0x5d,0x55,0x55,0x5d,0x41,0x43,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25974 0x6576 "敶" */
+0x02,0xe2,0xbf,0xa2,0xaf,0xca,0xaf,0xaa,0xaf,0xa2,0xa7,0xca,0x92,0x82,0x82,0x82,
+0x10,0x10,0xd0,0x20,0xbe,0xc4,0xa4,0xa4,0xa4,0x28,0x28,0x90,0x68,0x28,0x44,0x82,
+/* 25975 0x6577 "敷" */
+0x0a,0x09,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x49,0x10,0xff,0x20,0x3e,0x42,0x86,
+0x20,0x20,0xa0,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x90,0x28,0x28,0x44,0x82,
+/* 25976 0x6578 "數" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0x24,0x24,0x24,0x28,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 25977 0x6579 "敹" */
+0x08,0x08,0x0f,0x08,0xff,0x81,0x06,0x78,0x49,0x2a,0xff,0x18,0x2c,0x4a,0x88,0x09,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 25978 0x657a "敺" */
+0x00,0xff,0x80,0x9f,0x91,0x91,0x9f,0x80,0xbb,0xaa,0xaa,0xaa,0xbb,0x80,0xff,0x00,
+0x10,0x90,0x1e,0x10,0x10,0xfc,0x44,0x44,0xc4,0xa8,0xa8,0x90,0x90,0x28,0xc4,0x82,
+/* 25979 0x657b "敻" */
+0x10,0x1f,0x20,0x7f,0xa3,0x24,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x28,0x07,0xf8,
+0x00,0xe0,0x20,0xf8,0x08,0x88,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x20,0xc0,0x3e,
+/* 25980 0x657c "敼" */
+0x08,0xff,0x08,0x7f,0x00,0x7f,0x41,0x7f,0x22,0xff,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x90,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0xc4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25981 0x657d "敽" */
+0x06,0x78,0x10,0xff,0x22,0x5d,0x94,0x1c,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x43,
+0x10,0x10,0x10,0x9e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25982 0x657e "敾" */
+0x22,0x14,0xff,0x08,0x7f,0x08,0xff,0x49,0x2a,0xff,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x10,0x90,0x20,0x3e,0x44,0xa4,0x24,0x24,0xa8,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 25983 0x657f "敿" */
+0x06,0x78,0x10,0xff,0x22,0x5d,0x94,0x1c,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x43,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0xa4,0x24,0x24,0x28,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 25984 0x6580 "斀" */
+0x00,0x7f,0x55,0x55,0x7f,0x20,0x7f,0x91,0x7d,0x55,0x55,0x7d,0x11,0x7d,0x05,0x02,
+0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 25985 0x6581 "斁" */
+0x00,0x7f,0x55,0x7f,0x08,0x7f,0x08,0xff,0x22,0x14,0x7f,0x08,0xff,0x08,0x08,0x09,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0xa8,0x48,0x84,0x02,
+/* 25986 0x6582 "斂" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x88,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 25987 0x6583 "斃" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x00,0xff,0x10,0x3e,0x42,0x24,0x18,0xe0,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x00,0xfe,0x80,0x98,0xe0,0x84,0x84,0x7c,
+/* 25988 0x6584 "斄" */
+0x08,0x3e,0x08,0x7f,0x2a,0x49,0x08,0x3f,0x20,0x2f,0x24,0x24,0x2a,0x51,0x46,0x98,
+0x20,0x3e,0x44,0xa8,0x10,0x28,0x44,0xfe,0x80,0xfc,0x90,0x90,0xa8,0xc4,0xb0,0x8e,
+/* 25989 0x6585 "斅" */
+0x34,0x4b,0x55,0x63,0x55,0x6b,0x55,0xff,0x80,0x7e,0x04,0x0f,0xf8,0x08,0x28,0x10,
+0x10,0x10,0x10,0x1e,0x10,0x10,0x7c,0xa4,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 25990 0x6586 "斆" */
+0x34,0x4b,0x55,0x63,0x55,0x6b,0x55,0xff,0x80,0x7e,0x04,0x0f,0xf8,0x08,0x28,0x10,
+0x10,0x10,0x10,0x20,0x3e,0x44,0x24,0xa4,0xa4,0x28,0x28,0x10,0x28,0x28,0x44,0x82,
+/* 25991 0x6587 "文" */
+0x02,0x01,0x01,0xff,0x10,0x10,0x08,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 25992 0x6588 "斈" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe0,0x0f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 25993 0x6589 "斉" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xf0,0x10,0x1f,0x10,0x10,0x1f,0x10,0x20,0x40,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x1e,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x10,
+/* 25994 0x658a "斊" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe0,0x3f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0xf8,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,
+/* 25995 0x658b "斋" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe0,0x1f,0x02,0x04,0x3f,0x24,0x24,0x24,0x20,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0xf0,0x00,0x00,0xf8,0x88,0x88,0xa8,0x10,
+/* 25996 0x658c "斌" */
+0x00,0x20,0x11,0x00,0xfc,0x0b,0x08,0x48,0x28,0x12,0x12,0x2a,0x2a,0x4a,0x87,0x02,
+0x10,0x14,0xd2,0x12,0x10,0xfe,0x10,0x90,0x90,0xd0,0x90,0x90,0x8a,0xea,0x06,0x02,
+/* 25997 0x658d "斍" */
+0x01,0x7f,0x08,0x04,0x03,0x1c,0xe0,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0xf0,
+0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x3e,
+/* 25998 0x658e "斎" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe0,0x17,0x10,0x17,0x11,0x15,0x25,0x29,0x40,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0xd0,0x10,0xd0,0x10,0x90,0x50,0x10,0x10,
+/* 25999 0x658f "斏" */
+0x00,0x20,0x11,0x01,0xfd,0x09,0x09,0x49,0x29,0x11,0x11,0x29,0x29,0x49,0x81,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 26000 0x6590 "斐" */
+0x04,0x7c,0x04,0x04,0x3c,0x04,0x04,0x7c,0x04,0x01,0xff,0x08,0x04,0x03,0x1c,0xe0,
+0x40,0x7c,0x40,0x40,0x78,0x40,0x40,0x7c,0x40,0x00,0xfe,0x20,0x40,0x80,0x70,0x0e,
+/* 26001 0x6591 "斑" */
+0x00,0x02,0xf9,0x21,0x2f,0x20,0x24,0xfa,0x22,0x21,0x21,0x3a,0xe2,0x44,0x08,0x00,
+0x00,0x00,0x3e,0x08,0xc8,0x88,0x88,0x88,0xbe,0x08,0x08,0x88,0x88,0x48,0x7e,0x00,
+/* 26002 0x6592 "斒" */
+0x00,0x20,0x11,0x01,0xfd,0x09,0x09,0x49,0x29,0x11,0x11,0x2a,0x2a,0x4a,0x84,0x00,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 26003 0x6593 "斓" */
+0x02,0x41,0x25,0x04,0xfd,0x14,0x15,0x15,0x95,0x55,0x25,0x25,0x54,0x55,0x84,0x04,
+0x00,0x7c,0x04,0x44,0xf4,0x44,0xf4,0x54,0x74,0xd4,0x54,0xf4,0xe4,0x54,0x44,0x4c,
+/* 26004 0x6594 "斔" */
+0x20,0x10,0xfe,0x05,0x69,0x11,0x29,0xd5,0x11,0x7d,0x55,0x7c,0x10,0x1c,0xe5,0x42,
+0x20,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x24,0x50,0x50,0x88,0x04,0x02,
+/* 26005 0x6595 "斕" */
+0x03,0x22,0x13,0x02,0xff,0x0a,0x0a,0x4a,0x2a,0x12,0x12,0x2a,0x2a,0x4a,0x82,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 26006 0x6596 "斖" */
+0x01,0x7f,0x08,0x07,0x18,0xe7,0x24,0x37,0x24,0xff,0x90,0x1f,0x10,0x1f,0x10,0xff,
+0x00,0xfc,0x20,0xc0,0x30,0xce,0x48,0xd8,0x48,0xfe,0x12,0xf0,0x10,0xf0,0x10,0xfe,
+/* 26007 0x6597 "斗" */
+0x00,0x04,0x02,0x02,0x10,0x08,0x08,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 26008 0x6598 "斘" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x8a,0x05,0x04,0x08,0x08,0x10,0x20,0x40,
+0x10,0x10,0x90,0x50,0x10,0x90,0x50,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 26009 0x6599 "料" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 26010 0x659a "斚" */
+0x10,0x10,0x24,0x7e,0x22,0x00,0x7f,0x44,0x82,0x10,0x08,0x00,0xff,0x00,0x00,0x00,
+0x20,0x20,0x48,0xfc,0x44,0x00,0xfe,0x42,0x44,0x40,0x40,0x7e,0xc0,0x40,0x40,0x40,
+/* 26011 0x659b "斛" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 26012 0x659c "斜" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x08,0x2a,0x29,0x49,0x88,0x28,0x10,
+0x08,0x48,0x28,0x28,0x08,0x48,0x28,0x28,0x0e,0x78,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 26013 0x659d "斝" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x44,0x82,0x10,0x08,0x00,0xff,0x00,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x42,0x44,0x40,0x40,0x7e,0xc0,0x40,0x40,0x40,
+/* 26014 0x659e "斞" */
+0x08,0x28,0x4b,0x49,0x49,0x6b,0x49,0x49,0x7f,0x49,0x08,0x14,0x12,0x21,0x41,0x80,
+0x08,0x48,0x28,0x28,0x08,0x48,0x28,0x28,0x0e,0x78,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 26015 0x659f "斟" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x00,
+0x08,0x48,0x28,0x28,0x08,0x48,0x28,0x28,0x0e,0x78,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 26016 0x65a0 "斠" */
+0x22,0x22,0xff,0x22,0x7f,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0xff,0x41,0x45,0x42,
+0x08,0x48,0xa8,0x28,0x08,0x48,0xa8,0x28,0x0e,0x78,0x08,0x08,0xc8,0x08,0x08,0x08,
+/* 26017 0x65a1 "斡" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x44,0x7c,0x45,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x88,0x04,0x12,0x90,0x50,0x10,0x90,0x1e,0xf0,0x10,0x10,0x10,0x10,
+/* 26018 0x65a2 "斢" */
+0x22,0x22,0x7f,0x22,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0x22,0x41,0x80,
+0x08,0x48,0x28,0x28,0x08,0xc8,0x28,0x28,0x0e,0x78,0x08,0x08,0x08,0x08,0x08,0x88,
+/* 26019 0x65a3 "斣" */
+0x00,0x7f,0x55,0x55,0x7f,0x20,0x7f,0x90,0x7c,0x54,0x54,0x7c,0x12,0xfe,0x02,0x01,
+0x08,0x48,0x28,0x28,0x08,0x48,0xa8,0xa8,0x8e,0xf8,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 26020 0x65a4 "斤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x10,0xf8,0x00,0x00,0x00,0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 26021 0x65a5 "斥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x11,0x10,0x10,0x20,0x20,0x40,0x80,
+0x10,0xf8,0x00,0x00,0x00,0x00,0xfe,0x40,0x40,0xc0,0x60,0x50,0x48,0x40,0x40,0x40,
+/* 26022 0x65a6 "斦" */
+0x02,0x07,0x38,0x20,0x20,0x20,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x81,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26023 0x65a7 "斧" */
+0x04,0x08,0x18,0x24,0x03,0x0c,0x30,0xc0,0x1f,0x10,0x10,0x1f,0x10,0x10,0x20,0x40,
+0x40,0x20,0x50,0x88,0x00,0xc0,0x30,0xee,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,
+/* 26024 0x65a8 "斨" */
+0x04,0x24,0x24,0x24,0x24,0x3c,0x04,0x04,0xfc,0x24,0x24,0x24,0x25,0x45,0x46,0x84,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 26025 0x65a9 "斩" */
+0x20,0x20,0x21,0xfd,0x41,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 26026 0x65aa "斪" */
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x14,0x09,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26027 0x65ab "斫" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3d,0x25,0x22,0x04,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 26028 0x65ac "斬" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x90,0x90,0x90,0x90,0x90,0x90,0x10,0x10,0x10,
+/* 26029 0x65ad "断" */
+0x04,0x04,0x55,0x4e,0x44,0x7f,0x44,0x4e,0x55,0x65,0x44,0x44,0x40,0x7f,0x00,0x01,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26030 0x65ae "斮" */
+0x24,0x24,0x7e,0x24,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x01,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26031 0x65af "斯" */
+0x22,0x22,0x7f,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0xff,0x04,0x22,0x41,0x81,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26032 0x65b0 "新" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x08,0x08,0x7f,0x08,0x2a,0x49,0x88,0x28,0x11,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26033 0x65b1 "斱" */
+0x10,0x10,0x7d,0x12,0x14,0xff,0x10,0x20,0x7e,0xa2,0x22,0x3e,0x22,0x22,0x3e,0x23,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26034 0x65b2 "斲" */
+0x00,0x77,0x55,0x55,0x77,0x14,0x14,0x77,0x41,0x41,0x77,0x14,0x14,0x1f,0xf0,0x41,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26035 0x65b3 "斳" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0x02,0xbc,0x20,0x20,0x20,0x3e,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+/* 26036 0x65b4 "斴" */
+0x08,0x49,0x2a,0xff,0x2a,0x49,0x88,0x41,0x41,0x77,0x91,0x55,0x27,0x41,0x81,0x01,
+0x00,0x02,0x3c,0xa0,0x20,0x20,0xbe,0x24,0x24,0xa4,0x24,0x24,0xa4,0x44,0x44,0x84,
+/* 26037 0x65b5 "斵" */
+0x10,0x6f,0x45,0x55,0x69,0x4b,0x10,0xff,0x14,0x77,0x41,0x77,0x14,0x17,0xf8,0x21,
+0x00,0x04,0x78,0x40,0x40,0x40,0x7e,0xc8,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 26038 0x65b6 "斶" */
+0x00,0x0d,0x71,0x41,0x41,0x40,0x7d,0x4a,0x49,0x49,0x49,0x49,0x48,0x49,0x48,0x88,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 26039 0x65b7 "斷" */
+0x08,0x50,0x5d,0x49,0x54,0x5d,0x44,0x7f,0x48,0x50,0x5d,0x49,0x54,0x5d,0x44,0x7f,
+0x82,0x9c,0x50,0xd0,0x90,0xde,0x54,0xd4,0x94,0x94,0x54,0xd4,0x94,0xd4,0x64,0xc4,
+/* 26040 0x65b8 "斸" */
+0x7f,0x40,0x7f,0x52,0x4a,0x52,0x5f,0x55,0x5f,0x64,0x5f,0x55,0x5f,0x44,0xbf,0x00,
+0xc2,0x5c,0xd0,0x50,0x90,0x5e,0xd4,0x54,0xd4,0x54,0x54,0x54,0x54,0x54,0x64,0x84,
+/* 26041 0x65b9 "方" */
+0x02,0x01,0x01,0xff,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 26042 0x65ba "斺" */
+0x20,0x10,0x00,0xfe,0x20,0x21,0x3e,0x24,0x24,0x24,0x24,0x24,0x44,0x55,0x89,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 26043 0x65bb "斻" */
+0x20,0x10,0x00,0xfe,0x21,0x22,0x3c,0x24,0x24,0x24,0x24,0x24,0x44,0x55,0x89,0x02,
+0x80,0x80,0x80,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 26044 0x65bc "於" */
+0x20,0x10,0x00,0xfe,0x20,0x20,0x3d,0x26,0x24,0x24,0x24,0x24,0x44,0x54,0x88,0x00,
+0x20,0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x60,0x10,0x00,0xc0,0x20,0x10,0x08,0x00,
+/* 26045 0x65bd "施" */
+0x20,0x10,0x10,0x01,0xfe,0x21,0x21,0x3d,0x27,0x25,0x25,0x25,0x25,0x45,0x54,0x88,
+0x80,0x80,0xfe,0x20,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x2a,0x22,0x02,0xfe,0x00,
+/* 26046 0x65be "斾" */
+0x20,0x10,0x00,0xfe,0x21,0x22,0x3c,0x25,0x25,0x25,0x25,0x25,0x45,0x55,0x88,0x00,
+0x80,0x80,0x80,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26047 0x65bf "斿" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x25,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x00,0x00,0xfc,0x04,0x08,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 26048 0x65c0 "旀" */
+0x20,0x10,0x00,0xfe,0x21,0x20,0x3c,0x24,0x24,0x24,0x25,0x25,0x46,0x54,0x88,0x00,
+0x20,0x20,0x48,0x84,0xfe,0x02,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 26049 0x65c1 "旁" */
+0x02,0x01,0x3f,0x08,0x04,0x7f,0x42,0x81,0x3f,0x04,0x04,0x07,0x08,0x08,0x10,0x20,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x02,0x04,0xf8,0x00,0x00,0xf0,0x10,0x10,0x50,0x20,
+/* 26050 0x65c2 "旂" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x80,0x80,0xfe,0x00,0x0c,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 26051 0x65c3 "旃" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x24,0x25,0x24,0x24,0x45,0x55,0x8a,
+0x80,0x80,0xfe,0x00,0x00,0xfc,0x84,0xa4,0x94,0x84,0xfe,0x84,0x84,0x04,0x14,0x08,
+/* 26052 0x65c4 "旄" */
+0x20,0x10,0x10,0x01,0xfe,0x21,0x20,0x3c,0x25,0x24,0x24,0x27,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x00,0x1c,0xe0,0x20,0x3c,0xe0,0x20,0x3e,0xe0,0x20,0x22,0x22,0x1e,
+/* 26053 0x65c5 "旅" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x00,0x0c,0xf0,0x90,0x90,0x92,0x94,0x88,0x88,0x84,0xa4,0xc2,0x80,
+/* 26054 0x65c6 "旆" */
+0x20,0x10,0x10,0x01,0xfe,0x21,0x20,0x3c,0x25,0x25,0x25,0x25,0x25,0x45,0x54,0x88,
+0x80,0x80,0xfe,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26055 0x65c7 "旇" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x80,0x80,0xfe,0x00,0x10,0x10,0xfe,0x92,0x90,0xfc,0xa4,0xa4,0xa8,0x10,0x28,0x46,
+/* 26056 0x65c8 "旈" */
+0x20,0x10,0x01,0xfe,0x20,0x20,0x3d,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x89,0x02,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 26057 0x65c9 "旉" */
+0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x00,0xff,0x08,0x0f,0x10,0x20,0xc0,
+0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x80,0xfe,0x00,0xf8,0x08,0x28,0x10,
+/* 26058 0x65ca "旊" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x00,0x00,0xfc,0x40,0x40,0x78,0x48,0xa8,0x98,0x88,0xaa,0xca,0x8e,
+/* 26059 0x65cb "旋" */
+0x20,0x10,0x10,0x01,0xfe,0x21,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x80,0x80,0xfe,0x00,0x00,0xfc,0x24,0x24,0xa0,0xa0,0xbc,0xa0,0xa0,0x60,0x3e,0x00,
+/* 26060 0x65cc "旌" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x25,0x24,0x24,0x24,0x24,0x44,0x55,0x88,
+0x80,0x80,0xfe,0x10,0x10,0x90,0xfe,0x90,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 26061 0x65cd "旍" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3d,0x26,0x24,0x25,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x20,0x20,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x88,0x50,0x20,0x10,
+/* 26062 0x65ce "旎" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x80,0x80,0xfe,0x00,0x00,0xfc,0x84,0x84,0xfc,0x80,0xa4,0xa8,0xb0,0x22,0x22,0x1e,
+/* 26063 0x65cf "族" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x20,0x3c,0x25,0x24,0x27,0x24,0x24,0x44,0x54,0x89,
+0x80,0x80,0xfe,0x00,0x80,0x80,0xfc,0xa0,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x06,
+/* 26064 0x65d0 "旐" */
+0x21,0x11,0x11,0x02,0xfc,0x20,0x22,0x3d,0x24,0x24,0x25,0x26,0x24,0x44,0x54,0x89,
+0x00,0x00,0xfe,0x00,0x50,0x50,0x54,0x58,0x50,0xd8,0x54,0x52,0x50,0x50,0x92,0x0e,
+/* 26065 0x65d1 "旑" */
+0x20,0x10,0x11,0x00,0xfc,0x21,0x23,0x3c,0x25,0x25,0x25,0x25,0x25,0x44,0x54,0x88,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 26066 0x65d2 "旒" */
+0x21,0x11,0x11,0x02,0xfc,0x21,0x20,0x3c,0x25,0x24,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x00,0x00,0xfe,0x40,0x20,0xfe,0x40,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xaa,0x2a,0x26,
+/* 26067 0x65d3 "旓" */
+0x21,0x11,0x11,0x02,0xfd,0x20,0x20,0x3d,0x25,0x25,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0x00,0xfe,0x20,0x24,0xa8,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 26068 0x65d4 "旔" */
+0x40,0x20,0x00,0xf7,0x41,0x41,0x72,0x52,0x57,0x51,0x51,0x55,0x52,0x53,0xb4,0x08,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 26069 0x65d5 "旕" */
+0x10,0x08,0xff,0x20,0x3e,0x22,0x22,0x42,0x4a,0x84,0x00,0x7c,0x44,0x44,0x7c,0x44,
+0x10,0x10,0x28,0x44,0x82,0x10,0x08,0x20,0x10,0x08,0x00,0x88,0xb0,0xc4,0x84,0x7c,
+/* 26070 0x65d6 "旖" */
+0x21,0x11,0x11,0x02,0xfc,0x21,0x20,0x3c,0x27,0x24,0x25,0x25,0x25,0x44,0x54,0x88,
+0x00,0x00,0xfe,0x00,0x20,0xfc,0x50,0x88,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x28,0x10,
+/* 26071 0x65d7 "旗" */
+0x21,0x11,0x11,0x02,0xfc,0x21,0x20,0x3c,0x24,0x24,0x24,0x24,0x27,0x44,0x54,0x89,
+0x00,0x00,0xfe,0x00,0x88,0xfc,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x50,0x88,0x04,
+/* 26072 0x65d8 "旘" */
+0x21,0x10,0x13,0x00,0xfa,0x21,0x27,0x38,0x2b,0x2a,0x2a,0x2b,0x2a,0x4a,0x4b,0x98,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 26073 0x65d9 "旙" */
+0x20,0x13,0x11,0x00,0xfd,0x20,0x21,0x3e,0x25,0x25,0x25,0x25,0x25,0x45,0x55,0x89,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 26074 0x65da "旚" */
+0x21,0x11,0x12,0x01,0xfc,0x21,0x21,0x3d,0x24,0x25,0x24,0x27,0x24,0x44,0x55,0x8a,
+0x00,0xfe,0x00,0xfe,0x50,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0x64,
+/* 26075 0x65db "旛" */
+0x21,0x11,0x11,0x02,0xfc,0x23,0x21,0x3c,0x27,0x25,0x26,0x25,0x25,0x45,0x55,0x89,
+0x00,0x00,0xfe,0x00,0x1c,0xe0,0x24,0xa8,0xfe,0x24,0x02,0xfc,0x24,0xfc,0x24,0xfc,
+/* 26076 0x65dc "旜" */
+0x21,0x11,0x12,0x04,0xfc,0x21,0x21,0x3d,0x25,0x25,0x24,0x24,0x24,0x44,0x54,0x89,
+0x00,0xfe,0x20,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 26077 0x65dd "旝" */
+0x20,0x10,0x11,0x02,0xfc,0x21,0x21,0x3d,0x25,0x25,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0xfe,0x30,0x48,0xb4,0x02,0xfe,0xaa,0x72,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,
+/* 26078 0x65de "旞" */
+0x20,0x10,0x10,0x01,0xfe,0x20,0x22,0x3d,0x24,0x27,0x25,0x25,0x25,0x45,0x56,0x8c,
+0x80,0x80,0xfe,0x00,0x44,0x28,0xfe,0x20,0x54,0x28,0x5c,0x2a,0x4a,0x28,0x90,0x7e,
+/* 26079 0x65df "旟" */
+0x21,0x11,0x01,0xfe,0x25,0x22,0x3a,0x2b,0x2a,0x2a,0x2b,0x2a,0x4f,0x68,0x91,0x02,
+0x00,0x00,0xfe,0x00,0x40,0x4c,0x64,0x4c,0x64,0xa4,0xac,0xa4,0xfe,0x90,0x08,0x04,
+/* 26080 0x65e0 "无" */
+0x00,0x3f,0x02,0x02,0x02,0x02,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0xf0,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x7c,0x00,
+/* 26081 0x65e1 "旡" */
+0x00,0x3f,0x02,0x02,0x42,0x42,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x00,0xf0,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x7c,0x00,
+/* 26082 0x65e2 "既" */
+0x00,0x7d,0x44,0x44,0x7d,0x45,0x45,0x7c,0x40,0x48,0x44,0x4a,0x52,0x60,0x41,0x02,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x30,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 26083 0x65e3 "旣" */
+0x10,0x21,0x7c,0x44,0x7d,0x45,0x7d,0x00,0x40,0x40,0x7c,0x40,0x40,0x4c,0x71,0x02,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x30,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 26084 0x65e4 "旤" */
+0x00,0x7d,0x44,0x44,0x75,0x55,0x55,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x8b,0x86,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x30,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 26085 0x65e5 "日" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 26086 0x65e6 "旦" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0xff,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0xfe,0x00,
+/* 26087 0x65e7 "旧" */
+0x20,0x23,0x22,0x22,0x22,0x22,0x22,0x23,0x22,0x22,0x22,0x22,0x22,0x23,0x22,0x20,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 26088 0x65e8 "旨" */
+0x20,0x20,0x23,0x3c,0x20,0x20,0x1f,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x70,0x80,0x08,0x08,0x08,0xf8,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26089 0x65e9 "早" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 26090 0x65ea "旪" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x47,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26091 0x65eb "旫" */
+0x00,0x00,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x02,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 26092 0x65ec "旬" */
+0x08,0x08,0x0f,0x10,0x10,0x2f,0x48,0x88,0x0f,0x08,0x08,0x0f,0x08,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xc4,0x44,0x44,0xc4,0x44,0x44,0xc4,0x44,0x04,0x28,0x10,
+/* 26093 0x65ed "旭" */
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x8a,0x02,0x02,0xfe,0x00,
+/* 26094 0x65ee "旮" */
+0x02,0x02,0x3f,0x04,0x08,0x30,0xc0,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xe0,0x20,0x22,0x22,0x1e,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26095 0x65ef "旯" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x02,0x7f,0x04,0x04,0x08,0x10,0x60,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,
+/* 26096 0x65f0 "旰" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26097 0x65f1 "旱" */
+0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 26098 0x65f2 "旲" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 26099 0x65f3 "旳" */
+0x00,0x00,0x7c,0x44,0x45,0x46,0x44,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 26100 0x65f4 "旴" */
+0x00,0x01,0x7c,0x44,0x44,0x44,0x47,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26101 0x65f5 "旵" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 26102 0x65f6 "时" */
+0x00,0x00,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x28,0x10,
+/* 26103 0x65f7 "旷" */
+0x00,0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 26104 0x65f8 "旸" */
+0x00,0x01,0x7c,0x44,0x44,0x44,0x45,0x7c,0x44,0x44,0x45,0x45,0x7e,0x44,0x00,0x01,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 26105 0x65f9 "旹" */
+0x01,0x21,0x21,0x21,0x3f,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x08,0x08,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26106 0x65fa "旺" */
+0x00,0x07,0x78,0x48,0x48,0x48,0x78,0x4b,0x48,0x48,0x48,0x78,0x48,0x00,0x0f,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 26107 0x65fb "旻" */
+0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x01,0x7f,0x08,0x04,0x03,0x04,0x18,0xe0,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x20,0x40,0x80,0x40,0x30,0x0e,
+/* 26108 0x65fc "旼" */
+0x00,0x00,0x7c,0x47,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x01,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 26109 0x65fd "旽" */
+0x00,0x00,0x78,0x4b,0x48,0x49,0x49,0x79,0x49,0x49,0x48,0x48,0x78,0x48,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 26110 0x65fe "旾" */
+0x01,0x01,0xff,0x01,0x21,0x3f,0x01,0x01,0x00,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x08,0xf8,0x02,0x02,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 26111 0x65ff "旿" */
+0x00,0x00,0x7c,0x45,0x45,0x46,0x44,0x7c,0x47,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26112 0x6600 "昀" */
+0x00,0x00,0x7c,0x44,0x45,0x46,0x44,0x7c,0x44,0x44,0x44,0x44,0x7d,0x44,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 26113 0x6601 "昁" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x49,0x79,0x49,0x49,0x49,0x49,0x79,0x48,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 26114 0x6602 "昂" */
+0x3f,0x20,0x3f,0x20,0x3f,0x00,0x0c,0x70,0x40,0x40,0x40,0x4c,0x70,0x40,0x00,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,
+/* 26115 0x6603 "昃" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x20,0x21,0x21,0x22,0x44,0x48,0x90,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 26116 0x6604 "昄" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x09,
+0x08,0x3c,0xc0,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 26117 0x6605 "昅" */
+0x00,0x03,0x78,0x48,0x48,0x48,0x48,0x78,0x49,0x49,0x49,0x49,0x7a,0x4a,0x04,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 26118 0x6606 "昆" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x00,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x80,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 26119 0x6607 "昇" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x07,0x78,0x08,0x08,0xff,0x08,0x10,0x10,0x20,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 26120 0x6608 "昈" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x01,0x02,
+0x20,0x10,0x10,0xfe,0x82,0x82,0x82,0xfe,0x82,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 26121 0x6609 "昉" */
+0x00,0x00,0x7c,0x47,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 26122 0x660a "昊" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 26123 0x660b "昋" */
+0x3f,0x01,0x02,0xff,0x04,0x08,0x30,0xc0,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26124 0x660c "昌" */
+0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 26125 0x660d "昍" */
+0x00,0x01,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,0x00,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 26126 0x660e "明" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,0x01,0x02,0x04,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 26127 0x660f "昏" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x28,0x30,0x20,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,
+0x78,0x80,0x80,0x80,0xfc,0x40,0x22,0x1a,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 26128 0x6610 "昐" */
+0x00,0x00,0x7c,0x44,0x45,0x45,0x46,0x7d,0x44,0x44,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 26129 0x6611 "昑" */
+0x00,0x00,0x7c,0x44,0x44,0x45,0x46,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 26130 0x6612 "昒" */
+0x01,0x01,0x79,0x49,0x4a,0x4c,0x48,0x79,0x49,0x4a,0x4c,0x48,0x79,0x4a,0x04,0x00,
+0x00,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 26131 0x6613 "易" */
+0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x04,0x08,0x1f,0x22,0x42,0x04,0x08,0x11,0x02,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 26132 0x6614 "昔" */
+0x04,0x04,0x3f,0x04,0x04,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26133 0x6615 "昕" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x01,0x02,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 26134 0x6616 "昖" */
+0x00,0x00,0x78,0x48,0x48,0x49,0x49,0x7a,0x4c,0x48,0x48,0x48,0x79,0x4b,0x01,0x00,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x40,0x40,0x88,0x84,0x04,0xfe,0x02,0x00,
+/* 26135 0x6617 "昗" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x01,0x7f,0x00,0x04,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x00,0x40,0x20,0x10,0x08,
+/* 26136 0x6618 "昘" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x01,0xff,0x04,0x07,0x04,0x08,0x10,0x20,0x40,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0x10,0xa0,0x40,
+/* 26137 0x6619 "昙" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x00,0x00,0xff,0x04,0x08,0x10,0x3f,0x10,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0x10,0xf8,0x08,
+/* 26138 0x661a "昚" */
+0x01,0x01,0xff,0x01,0x22,0x14,0x08,0x30,0xdf,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x00,0x88,0x50,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26139 0x661b "昛" */
+0x00,0x01,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 26140 0x661c "昜" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,0x08,0x1f,0x22,0x44,0x08,0x11,0x22,0x04,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf8,0x48,0x48,0x88,0x08,0x28,0x10,
+/* 26141 0x661d "昝" */
+0x10,0x10,0x3e,0x22,0x54,0x08,0x17,0x20,0xdf,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x50,0x48,0x44,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26142 0x661e "昞" */
+0x00,0x03,0x78,0x48,0x48,0x4b,0x7a,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,0x02,0x02,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 26143 0x661f "星" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x11,0x1f,0x21,0x41,0x1f,0x01,0x01,0x7f,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xf0,0x00,0x00,0xfc,0x00,
+/* 26144 0x6620 "映" */
+0x00,0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x49,0x4b,0x48,0x78,0x48,0x00,0x01,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 26145 0x6621 "昡" */
+0x00,0x00,0x7c,0x45,0x44,0x44,0x44,0x7c,0x45,0x44,0x44,0x44,0x7c,0x45,0x00,0x00,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 26146 0x6622 "昢" */
+0x00,0x00,0x7d,0x45,0x45,0x45,0x45,0x7c,0x44,0x45,0x45,0x45,0x7d,0x45,0x01,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 26147 0x6623 "昣" */
+0x00,0x00,0x7c,0x44,0x45,0x46,0x44,0x7c,0x45,0x44,0x44,0x44,0x7d,0x44,0x00,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 26148 0x6624 "昤" */
+0x00,0x00,0x7c,0x44,0x44,0x45,0x46,0x7c,0x45,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 26149 0x6625 "春" */
+0x01,0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x10,0x2f,0xc8,0x08,0x0f,0x08,0x08,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x10,0xe8,0x26,0x20,0xe0,0x20,0x20,0xe0,
+/* 26150 0x6626 "昦" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x04,0x08,0x34,0xc4,0x04,0x04,0x08,0x10,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x20,0x58,0x46,0x40,0x40,0x40,0x40,
+/* 26151 0x6627 "昧" */
+0x00,0x00,0x78,0x49,0x48,0x48,0x48,0x7b,0x48,0x48,0x48,0x49,0x79,0x4a,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 26152 0x6628 "昨" */
+0x01,0x01,0x79,0x49,0x4a,0x4a,0x4c,0x78,0x48,0x48,0x48,0x48,0x78,0x48,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 26153 0x6629 "昩" */
+0x00,0x00,0x78,0x4f,0x48,0x48,0x48,0x7b,0x48,0x48,0x49,0x4a,0x7c,0x48,0x00,0x00,
+0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,0x40,
+/* 26154 0x662a "昪" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,0x3f,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0xf8,0x28,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 26155 0x662b "昫" */
+0x00,0x00,0x79,0x49,0x4a,0x4c,0x49,0x79,0x49,0x49,0x49,0x49,0x78,0x48,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 26156 0x662c "昬" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x2c,0x30,0x20,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xf8,0x08,0xf8,0x80,0xfc,0x40,0x24,0x14,0x0c,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26157 0x662d "昭" */
+0x00,0x03,0x78,0x48,0x48,0x49,0x49,0x7a,0x4c,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26158 0x662e "昮" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x00,0x7d,0x10,0x10,0x10,0x1c,0xe1,0x42,0x04,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 26159 0x662f "是" */
+0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0xff,0x01,0x11,0x11,0x11,0x29,0x45,0x83,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,
+/* 26160 0x6630 "昰" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x00,0x7f,0x01,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 26161 0x6631 "昱" */
+0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x01,0x01,0x7f,0x00,0x10,0x08,0x04,0xff,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0x00,0xfc,0x00,0x10,0x20,0x40,0xfe,
+/* 26162 0x6632 "昲" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x7b,0x4a,0x4a,0x4b,0x48,0x78,0x49,0x01,0x02,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 26163 0x6633 "昳" */
+0x00,0x00,0x7a,0x4a,0x4b,0x4a,0x4c,0x78,0x4f,0x48,0x48,0x48,0x79,0x4a,0x04,0x08,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 26164 0x6634 "昴" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x0c,0x70,0x44,0x44,0x5c,0x64,0x48,0x10,0x60,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xfc,0x84,0x84,0x84,0x94,0x88,0x80,0x80,
+/* 26165 0x6635 "昵" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 26166 0x6636 "昶" */
+0x08,0x04,0x02,0x3c,0x04,0x04,0x75,0x16,0x16,0x15,0x25,0x24,0x44,0x84,0x14,0x08,
+0x00,0x00,0x7c,0x44,0x44,0xc4,0x7c,0x44,0x44,0x44,0x7c,0x80,0x40,0x30,0x0e,0x00,
+/* 26167 0x6637 "昷" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 26168 0x6638 "昸" */
+0x00,0x00,0x7c,0x44,0x45,0x46,0x44,0x7c,0x44,0x47,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 26169 0x6639 "昹" */
+0x00,0x00,0x78,0x49,0x48,0x48,0x7b,0x48,0x48,0x48,0x49,0x79,0x4a,0x04,0x00,0x00,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 26170 0x663a "昺" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x01,0x3f,0x21,0x22,0x24,0x28,0x20,0x20,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x08,0x88,0x48,0x28,0x08,0x18,
+/* 26171 0x663b "昻" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,
+/* 26172 0x663c "昼" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x20,0x2f,0x48,0x8f,0x08,0x0f,0x00,0x7f,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x40,0x20,0x10,0xe8,0x26,0xe0,0x20,0xe0,0x00,0xfc,0x00,
+/* 26173 0x663d "昽" */
+0x00,0x00,0x78,0x48,0x4b,0x48,0x48,0x78,0x48,0x49,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0x28,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 26174 0x663e "显" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x04,0x44,0x24,0x14,0x14,0x04,0xff,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x00,
+/* 26175 0x663f "昿" */
+0x00,0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,0x08,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 26176 0x6640 "晀" */
+0x00,0x00,0x78,0x4a,0x49,0x48,0x48,0x79,0x4a,0x4c,0x48,0x48,0x79,0x49,0x02,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 26177 0x6641 "晁" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x24,0x14,0x0c,0x14,0x64,0x08,0x10,0x60,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x48,0x50,0x60,0x50,0x48,0x42,0x42,0x3e,
+/* 26178 0x6642 "時" */
+0x00,0x00,0x7c,0x45,0x44,0x44,0x47,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 26179 0x6643 "晃" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x11,0x09,0x01,0xff,0x04,0x04,0x08,0x10,0x60,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x10,0x20,0x00,0xfe,0x40,0x40,0x42,0x42,0x3e,
+/* 26180 0x6644 "晄" */
+0x00,0x00,0x7a,0x49,0x49,0x48,0x4f,0x78,0x48,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 26181 0x6645 "晅" */
+0x00,0x03,0x78,0x48,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x78,0x48,0x03,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 26182 0x6646 "晆" */
+0x00,0x00,0x7d,0x44,0x44,0x44,0x47,0x7c,0x44,0x44,0x45,0x44,0x7c,0x44,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26183 0x6647 "晇" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x7a,0x48,0x4b,0x48,0x48,0x79,0x48,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 26184 0x6648 "晈" */
+0x00,0x00,0x7c,0x47,0x44,0x44,0x45,0x7e,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 26185 0x6649 "晉" */
+0x00,0x7f,0x08,0x10,0x24,0x7e,0x02,0x00,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xfc,0x10,0x20,0x48,0xfc,0x04,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26186 0x664a "晊" */
+0x00,0x03,0x78,0x48,0x49,0x4a,0x4b,0x78,0x48,0x48,0x4b,0x48,0x78,0x48,0x07,0x00,
+0x00,0xfe,0x40,0x80,0x10,0x08,0xfc,0x44,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 26187 0x664b "晋" */
+0x00,0x7f,0x04,0x24,0x14,0x04,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x40,0x48,0x50,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26188 0x664c "晌" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 26189 0x664d "晍" */
+0x00,0x01,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 26190 0x664e "晎" */
+0x01,0x01,0x79,0x49,0x4b,0x49,0x79,0x49,0x49,0x4f,0x48,0x79,0x49,0x02,0x04,0x08,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 26191 0x664f "晏" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x7f,0x42,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 26192 0x6650 "晐" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x79,0x48,0x48,0x48,0x4b,0x78,0x48,0x00,0x03,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 26193 0x6651 "晑" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x04,0x3f,0x20,0x27,0x24,0x24,0x27,0x20,0x20,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xf8,0x08,0xc8,0x48,0x48,0xc8,0x28,0x10,
+/* 26194 0x6652 "晒" */
+0x00,0x07,0x78,0x48,0x48,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x4b,0x7a,0x4a,0x03,0x02,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 26195 0x6653 "晓" */
+0x00,0x00,0x78,0x4b,0x48,0x48,0x48,0x7b,0x48,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 26196 0x6654 "晔" */
+0x00,0x00,0x79,0x49,0x4b,0x4d,0x49,0x79,0x49,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26197 0x6655 "晕" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x42,0x9f,0x04,0x09,0x1f,0x01,0x7f,0x01,0x01,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0x00,0xf0,0x00,0xfc,0x00,0x00,
+/* 26198 0x6656 "晖" */
+0x00,0x03,0x7a,0x4c,0x48,0x4b,0x48,0x78,0x49,0x49,0x48,0x48,0x7b,0x48,0x00,0x00,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 26199 0x6657 "晗" */
+0x00,0x00,0x78,0x49,0x4a,0x4c,0x49,0x78,0x48,0x48,0x4b,0x4a,0x7a,0x4a,0x03,0x02,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf0,0x10,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 26200 0x6658 "晘" */
+0x00,0x01,0x7d,0x45,0x45,0x45,0x44,0x7c,0x45,0x44,0x44,0x47,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 26201 0x6659 "晙" */
+0x00,0x00,0x78,0x49,0x4b,0x48,0x48,0x79,0x4a,0x48,0x49,0x4a,0x78,0x48,0x01,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 26202 0x665a "晚" */
+0x00,0x00,0x79,0x4a,0x4c,0x4b,0x4a,0x7a,0x4a,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x44,0x44,0x44,0xfc,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 26203 0x665b "晛" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x4b,0x79,0x49,0x02,0x04,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 26204 0x665c "晜" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x7f,0x01,0x3f,0x21,0x3f,0x03,0x05,0x19,0x61,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x14,0x08,0x00,
+/* 26205 0x665d "晝" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x00,0xff,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 26206 0x665e "晞" */
+0x01,0x00,0x78,0x48,0x4b,0x48,0x7b,0x48,0x49,0x4b,0x4d,0x79,0x49,0x01,0x00,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26207 0x665f "晟" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x2a,0x44,0x41,0x86,
+0xf0,0x10,0xf0,0x10,0xf0,0x88,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 26208 0x6660 "晠" */
+0x00,0x00,0x78,0x48,0x4b,0x4a,0x7a,0x4a,0x4b,0x4a,0x4a,0x7a,0x4a,0x05,0x04,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 26209 0x6661 "晡" */
+0x00,0x00,0x7b,0x48,0x48,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x02,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 26210 0x6662 "晢" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26211 0x6663 "晣" */
+0x01,0x01,0x79,0x49,0x4f,0x49,0x79,0x49,0x49,0x4f,0x49,0x79,0x49,0x01,0x05,0x02,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 26212 0x6664 "晤" */
+0x00,0x03,0x78,0x48,0x49,0x48,0x48,0x7b,0x48,0x48,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26213 0x6665 "晥" */
+0x00,0x00,0x7b,0x4a,0x4c,0x49,0x78,0x48,0x4b,0x48,0x48,0x78,0x49,0x01,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 26214 0x6666 "晦" */
+0x01,0x01,0x79,0x4a,0x4d,0x49,0x49,0x79,0x4f,0x49,0x4a,0x4a,0x7b,0x48,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 26215 0x6667 "晧" */
+0x00,0x01,0x79,0x49,0x49,0x4a,0x78,0x4b,0x48,0x48,0x49,0x79,0x49,0x01,0x01,0x01,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26216 0x6668 "晨" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x29,0x28,0x48,0x4a,0x8c,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x08,0x90,0x60,0x18,0x06,
+/* 26217 0x6669 "晩" */
+0x00,0x00,0x79,0x4a,0x4c,0x4b,0x4a,0x7a,0x4a,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x44,0x44,0x44,0xfc,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 26218 0x666a "晪" */
+0x00,0x00,0x78,0x4b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4a,0x4f,0x78,0x48,0x01,0x02,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 26219 0x666b "晫" */
+0x00,0x00,0x78,0x48,0x4b,0x4a,0x4b,0x7a,0x4b,0x4a,0x48,0x4f,0x78,0x48,0x00,0x00,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 26220 0x666c "晬" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x49,0x7a,0x48,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26221 0x666d "晭" */
+0x00,0x03,0x7a,0x4a,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x04,
+0x00,0xfe,0x22,0x22,0xfa,0x22,0x22,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 26222 0x666e "普" */
+0x08,0x04,0x7f,0x04,0x24,0x14,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x40,0xfc,0x40,0x48,0x50,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26223 0x666f "景" */
+0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x01,0x21,0x45,0x02,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0x08,0x04,0x00,
+/* 26224 0x6670 "晰" */
+0x02,0x02,0xf2,0x92,0x9f,0x92,0x92,0xf6,0x97,0x9a,0x9a,0x92,0xf2,0x92,0x02,0x02,
+0x00,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0xc8,0x48,0x48,0x48,0x48,0x48,0x88,
+/* 26225 0x6671 "晱" */
+0x00,0x01,0x79,0x4a,0x48,0x48,0x7b,0x48,0x48,0x49,0x49,0x7a,0x48,0x00,0x01,0x06,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 26226 0x6672 "晲" */
+0x00,0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4b,0x48,0x48,0x78,0x48,0x01,0x02,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 26227 0x6673 "晳" */
+0x08,0x08,0x7e,0x18,0x2c,0x2a,0x48,0x88,0x09,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 26228 0x6674 "晴" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x78,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 26229 0x6675 "晵" */
+0x10,0x08,0x3e,0x22,0x23,0x3e,0x20,0x41,0x9f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x88,0x50,0x20,0x58,0x86,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26230 0x6676 "晶" */
+0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+0xe0,0x20,0x20,0xe0,0x20,0x20,0xe0,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 26231 0x6677 "晷" */
+0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x22,0x54,0x08,0x37,0xc0,0x1f,0x10,0x10,0x1f,
+0xf0,0x10,0xf0,0x10,0xf0,0x40,0x60,0x50,0x48,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,
+/* 26232 0x6678 "晸" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x04,0x04,0x27,0x24,0x24,0x24,0x2f,0xf0,0x40,
+0xf0,0x10,0xf0,0x10,0xf0,0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 26233 0x6679 "晹" */
+0x01,0x01,0x79,0x49,0x49,0x49,0x78,0x49,0x49,0x4a,0x4c,0x78,0x49,0x02,0x00,0x01,
+0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x4a,0x4a,0x92,0x12,0x22,0x4a,0x84,
+/* 26234 0x667a "智" */
+0x20,0x3e,0x48,0x08,0xff,0x14,0x22,0x40,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26235 0x667b "晻" */
+0x00,0x00,0x7b,0x49,0x4a,0x4c,0x4b,0x7a,0x4a,0x4b,0x4a,0x4a,0x7b,0x48,0x00,0x00,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 26236 0x667c "晼" */
+0x00,0x00,0xf7,0x94,0x9a,0x92,0x93,0xf4,0x94,0x96,0x99,0x91,0xf2,0x92,0x04,0x08,
+0x80,0x40,0xfe,0x02,0x04,0x00,0xbc,0xa4,0xa4,0xa4,0x34,0x28,0x22,0x22,0x22,0x1e,
+/* 26237 0x667d "晽" */
+0x01,0x01,0xf1,0x91,0x97,0x91,0x91,0xf3,0x93,0x95,0x95,0x99,0xf1,0x91,0x01,0x01,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 26238 0x667e "晾" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x49,0x79,0x49,0x49,0x48,0x48,0x79,0x4a,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 26239 0x667f "晿" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 26240 0x6680 "暀" */
+0x00,0x00,0x79,0x4a,0x4c,0x48,0x49,0x7b,0x4d,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x90,0x88,0x00,0x7e,0x90,0x90,0x10,0x10,0x7e,0x10,0x10,0x10,0x10,0x10,0x7e,0x00,
+/* 26241 0x6681 "暁" */
+0x00,0x00,0x79,0x48,0x48,0x48,0x7b,0x48,0x48,0x4b,0x48,0x78,0x49,0x01,0x02,0x04,
+0x20,0x20,0xfc,0x20,0xa8,0x88,0xfe,0x88,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 26242 0x6682 "暂" */
+0x10,0xfe,0x20,0x48,0x7e,0x08,0x0e,0xf9,0x4a,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0xf8,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 26243 0x6683 "暃" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x7c,0x04,0x04,0x7c,0x04,0x04,0xfc,0x04,0x04,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x7c,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,
+/* 26244 0x6684 "暄" */
+0x00,0x00,0x7b,0x4a,0x4c,0x49,0x48,0x79,0x49,0x49,0x49,0x49,0x79,0x48,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 26245 0x6685 "暅" */
+0x01,0x01,0xf1,0x91,0x91,0x95,0x95,0xf5,0x95,0x91,0x91,0x91,0xf1,0x91,0x01,0x01,
+0x00,0x3c,0x00,0x00,0xbc,0x64,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x00,0x7e,0x00,
+/* 26246 0x6686 "暆" */
+0x02,0x01,0xf1,0x97,0x92,0x92,0x93,0xf2,0x92,0x92,0x92,0x92,0xf4,0x94,0x09,0x10,
+0x10,0x10,0x10,0xbe,0x28,0x48,0xaa,0xae,0xba,0xea,0xae,0xa8,0xaa,0xa2,0xa2,0x1e,
+/* 26247 0x6687 "暇" */
+0x00,0x07,0xf4,0x94,0x94,0x97,0x94,0xf4,0x97,0x94,0x94,0x97,0xf4,0x94,0x04,0x04,
+0x00,0xbc,0x84,0x84,0x84,0xbc,0x00,0x00,0xbc,0x24,0x24,0xa8,0x10,0x28,0x44,0x82,
+/* 26248 0x6688 "暈" */
+0x1f,0x10,0x1f,0x10,0x7f,0x41,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0xf0,0x10,0xf0,0x10,0xfc,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 26249 0x6689 "暉" */
+0x00,0x03,0x7a,0x48,0x4b,0x48,0x79,0x49,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 26250 0x668a "暊" */
+0x00,0x03,0x7c,0x44,0x45,0x45,0x45,0x7d,0x45,0x45,0x45,0x45,0x7d,0x44,0x00,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 26251 0x668b "暋" */
+0x00,0x7f,0x41,0x7f,0x48,0x7f,0x48,0x45,0x53,0x61,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26252 0x668c "暌" */
+0x00,0x03,0x78,0x4a,0x49,0x48,0x49,0x7a,0x48,0x48,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 26253 0x668d "暍" */
+0x00,0x01,0x7d,0x45,0x45,0x45,0x44,0x7d,0x46,0x45,0x45,0x45,0x7d,0x44,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 26254 0x668e "暎" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x49,0x79,0x49,0x49,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 26255 0x668f "暏" */
+0x00,0x00,0x7b,0x48,0x48,0x4f,0x48,0x78,0x49,0x4b,0x4d,0x49,0x79,0x49,0x01,0x01,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 26256 0x6690 "暐" */
+0x00,0x00,0x79,0x48,0x4b,0x48,0x49,0x79,0x49,0x48,0x4b,0x48,0x7a,0x4b,0x00,0x00,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 26257 0x6691 "暑" */
+0x1f,0x10,0x1f,0x10,0x1f,0x02,0x1f,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,0x08,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26258 0x6692 "暒" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x78,0x49,0x49,0x4a,0x48,0x79,0x48,0x00,0x03,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 26259 0x6693 "暓" */
+0x00,0x7f,0x12,0x0c,0xff,0x19,0x2a,0x48,0xa8,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x88,0x48,0x48,0x50,0x20,0x50,0x8c,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26260 0x6694 "暔" */
+0x00,0x00,0x7b,0x48,0x48,0x4b,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x02,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 26261 0x6695 "暕" */
+0x00,0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x49,0x49,0x48,0x78,0x48,0x01,0x02,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 26262 0x6696 "暖" */
+0x00,0x07,0x7a,0x49,0x48,0x4b,0x78,0x48,0x4f,0x49,0x49,0x7a,0x4a,0x04,0x08,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 26263 0x6697 "暗" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4f,0x78,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 26264 0x6698 "暘" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x78,0x4b,0x49,0x49,0x4a,0x7c,0x49,0x02,0x00,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 26265 0x6699 "暙" */
+0x00,0x00,0xf7,0x90,0x93,0x90,0x97,0xf1,0x92,0x95,0x91,0x91,0xf1,0x91,0x01,0x01,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 26266 0x669a "暚" */
+0x00,0x00,0x7b,0x48,0x4a,0x49,0x79,0x4a,0x48,0x4b,0x48,0x79,0x49,0x01,0x01,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 26267 0x669b "暛" */
+0x01,0x00,0x78,0x4b,0x48,0x49,0x48,0x7b,0x48,0x49,0x49,0x4a,0x7c,0x48,0x03,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26268 0x669c "暜" */
+0x20,0x10,0xfe,0x00,0x44,0x24,0x28,0x0e,0xf0,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x10,0xfe,0x00,0x44,0x24,0x28,0xfe,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26269 0x669d "暝" */
+0x00,0x03,0x7a,0x48,0x49,0x49,0x49,0x79,0x49,0x48,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 26270 0x669e "暞" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x48,0x4b,0x78,0x48,0x01,0x02,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 26271 0x669f "暟" */
+0x00,0x01,0x79,0x49,0x49,0x48,0x7b,0x48,0x49,0x49,0x49,0x79,0x48,0x00,0x03,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 26272 0x66a0 "暠" */
+0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x0c,
+/* 26273 0x66a1 "暡" */
+0x00,0x00,0x79,0x4a,0x4c,0x49,0x78,0x48,0x4b,0x48,0x4a,0x79,0x4a,0x00,0x01,0x00,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 26274 0x66a2 "暢" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x7c,0x57,0x55,0x55,0x7e,0x54,0x11,0x12,0x10,0x11,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 26275 0x66a3 "暣" */
+0x01,0x01,0x79,0x4a,0x4d,0x48,0x7b,0x48,0x4a,0x49,0x4f,0x78,0x49,0x06,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 26276 0x66a4 "暤" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x79,0x48,0x4b,0x48,0x49,0x7a,0x4d,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,
+/* 26277 0x66a5 "暥" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x78,0x4b,0x4a,0x48,0x4b,0x78,0x49,0x00,0x00,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x02,0x40,0xfe,0x88,0x90,0x60,0x98,0x04,
+/* 26278 0x66a6 "暦" */
+0x00,0x3f,0x22,0x22,0x3f,0x27,0x2a,0x32,0x22,0x20,0x27,0x24,0x27,0x44,0x47,0x84,
+0x00,0xfe,0x10,0x10,0xbe,0x18,0xb4,0x52,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 26279 0x66a7 "暧" */
+0x00,0x03,0x78,0x4a,0x49,0x4b,0x7a,0x48,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,0x01,
+0x0e,0xf0,0x44,0x24,0x08,0xfe,0x42,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 26280 0x66a8 "暨" */
+0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,0x00,
+0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 26281 0x66a9 "暩" */
+0x01,0x01,0x7b,0x4a,0x4d,0x4a,0x79,0x4a,0x4c,0x48,0x4b,0x78,0x49,0x02,0x05,0x00,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 26282 0x66aa "暪" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x78,0x4b,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x02,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 26283 0x66ab "暫" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x1f,0x10,0x1f,0x10,0x1f,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0xf0,0x10,0xf0,0x10,0xf0,
+/* 26284 0x66ac "暬" */
+0x08,0x3e,0x08,0x7f,0x22,0x49,0x3e,0x08,0x7e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26285 0x66ad "暭" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x78,0x49,0x48,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 26286 0x66ae "暮" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x10,0x2f,0xc8,0x0f,0x08,0x0f,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xe8,0x26,0xe0,0x20,0xe0,
+/* 26287 0x66af "暯" */
+0x00,0x00,0x7b,0x48,0x48,0x49,0x79,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 26288 0x66b0 "暰" */
+0x01,0x01,0xf2,0x94,0x99,0x91,0x92,0xf6,0x9a,0x92,0x92,0x92,0xf2,0x92,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 26289 0x66b1 "暱" */
+0x00,0x03,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x03,0x00,
+0x00,0xfe,0x48,0x48,0xfe,0x48,0x20,0xfe,0x40,0xfc,0x44,0x44,0x7c,0x00,0xfe,0x00,
+/* 26290 0x66b2 "暲" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 26291 0x66b3 "暳" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x78,0x48,0x4b,0x48,0x48,0x79,0x48,0x00,0x03,0x00,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26292 0x66b4 "暴" */
+0x1f,0x10,0x1f,0x10,0x1f,0x08,0x7f,0x08,0xff,0x08,0x31,0xc9,0x05,0x09,0x15,0x22,
+0xf0,0x10,0xf0,0x10,0xf0,0x20,0xfc,0x20,0xfe,0x20,0x18,0x26,0x40,0x20,0x10,0x08,
+/* 26293 0x66b5 "暵" */
+0x00,0x00,0x7b,0x48,0x48,0x48,0x79,0x49,0x49,0x48,0x49,0x78,0x4b,0x00,0x00,0x03,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,
+/* 26294 0x66b6 "暶" */
+0x02,0x01,0xf1,0x97,0x92,0x92,0x93,0xf2,0x92,0x92,0x92,0x92,0xf4,0x95,0x08,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 26295 0x66b7 "暷" */
+0x00,0x03,0x78,0x49,0x49,0x49,0x79,0x49,0x48,0x4b,0x48,0x7b,0x49,0x00,0x00,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 26296 0x66b8 "暸" */
+0x00,0x00,0xf7,0x90,0x95,0x92,0x97,0xfa,0x93,0x92,0x93,0x90,0xf2,0x94,0x09,0x00,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 26297 0x66b9 "暹" */
+0x07,0x44,0x27,0x24,0x07,0x02,0xe7,0x2c,0x37,0x24,0x27,0x24,0x27,0x54,0x8f,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x00,0xfe,0x00,
+/* 26298 0x66ba "暺" */
+0x00,0x03,0x7a,0x4a,0x4b,0x48,0x79,0x49,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 26299 0x66bb "暻" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x78,0x4b,0x48,0x49,0x49,0x79,0x48,0x01,0x02,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 26300 0x66bc "暼" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26301 0x66bd "暽" */
+0x00,0x01,0x78,0x4b,0x48,0x49,0x4a,0x79,0x49,0x49,0x4a,0x4d,0x78,0x49,0x02,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 26302 0x66be "暾" */
+0x02,0x01,0xf7,0x90,0x97,0x94,0x97,0xf0,0x97,0x90,0x91,0x91,0xf7,0x91,0x05,0x02,
+0x08,0x08,0xc8,0x10,0x9e,0x94,0xa4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 26303 0x66bf "暿" */
+0x00,0x03,0x78,0x49,0x48,0x49,0x79,0x49,0x48,0x4b,0x48,0x79,0x49,0x01,0x01,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 26304 0x66c0 "曀" */
+0x00,0x03,0x78,0x49,0x48,0x4b,0x7a,0x49,0x48,0x49,0x49,0x79,0x49,0x00,0x03,0x00,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 26305 0x66c1 "曁" */
+0x10,0x7e,0x42,0x7e,0x42,0x7e,0x40,0x7c,0x41,0x5f,0x70,0x1f,0x10,0x1f,0x00,0xff,
+0x00,0xfc,0x10,0x90,0xfe,0x30,0x50,0x92,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 26306 0x66c2 "曂" */
+0x00,0x00,0x79,0x48,0x48,0x4b,0x78,0x49,0x49,0x49,0x49,0x79,0x48,0x00,0x01,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 26307 0x66c3 "曃" */
+0x00,0x02,0x79,0x48,0x48,0x48,0x4b,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x02,0x04,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x92,0x54,0x38,0x54,0x92,0x30,0x00,0xfe,0x00,
+/* 26308 0x66c4 "曄" */
+0x00,0x03,0x78,0x48,0x49,0x48,0x48,0x7b,0x48,0x48,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 26309 0x66c5 "曅" */
+0x1f,0x10,0x1f,0x10,0x1f,0x04,0x7f,0x04,0x3f,0x09,0x7f,0x09,0x3f,0x01,0x7f,0x01,
+0xf0,0x10,0xf0,0x10,0xf0,0x40,0xfc,0x40,0xf8,0x20,0xfc,0x20,0xf8,0x00,0xfc,0x00,
+/* 26310 0x66c6 "曆" */
+0x3f,0x20,0x21,0x2e,0x22,0x3f,0x27,0x2a,0x32,0x22,0x27,0x24,0x47,0x44,0x87,0x04,
+0xfe,0x00,0x8c,0x70,0x10,0xbe,0x18,0xb4,0x52,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 26311 0x66c7 "曇" */
+0x1f,0x10,0x1f,0x10,0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3f,0x00,0xff,0x10,0x3f,0x00,
+0xf0,0x10,0xf0,0x10,0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x00,0xfe,0x10,0xf8,0x08,
+/* 26312 0x66c8 "曈" */
+0x00,0x01,0x78,0x48,0x4b,0x48,0x79,0x49,0x49,0x49,0x49,0x78,0x49,0x00,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 26313 0x66c9 "曉" */
+0x00,0x00,0x79,0x48,0x4b,0x49,0x7b,0x49,0x49,0x4e,0x48,0x7b,0x48,0x00,0x01,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 26314 0x66ca "曊" */
+0x00,0x07,0x78,0x4b,0x4a,0x4b,0x79,0x4b,0x4d,0x49,0x49,0x79,0x49,0x01,0x00,0x01,
+0x90,0xfc,0x94,0xfc,0x90,0xfe,0x12,0xfa,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,
+/* 26315 0x66cb "曋" */
+0x00,0x03,0x78,0x4b,0x4a,0x4b,0x78,0x49,0x49,0x49,0x49,0x79,0x48,0x03,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 26316 0x66cc "曌" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x02,0x01,0x7f,0x48,0x10,0x2f,0x01,0x01,0x7f,0x00,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xa8,0x10,0xfc,0x24,0x10,0xe8,0x00,0x00,0xfc,0x00,
+/* 26317 0x66cd "曍" */
+0x00,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x48,0x49,0x48,0x79,0x48,0x03,0x00,0x00,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,
+/* 26318 0x66ce "曎" */
+0x00,0x01,0x79,0x49,0x48,0x49,0x78,0x4b,0x48,0x48,0x49,0x78,0x4b,0x00,0x00,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 26319 0x66cf "曏" */
+0x1f,0x10,0x1f,0x10,0x1f,0x21,0x27,0x54,0x97,0xe4,0x24,0x57,0x95,0xf4,0x25,0x46,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xde,0x52,0xd4,0x58,0x54,0xd2,0x12,0x9a,0x54,0x10,
+/* 26320 0x66d0 "曐" */
+0x0f,0x08,0x0f,0x08,0x0f,0x7c,0x44,0x7c,0x44,0x7d,0x11,0x1f,0x21,0x5f,0x01,0xff,
+0xe0,0x20,0xe0,0x20,0xe0,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xf8,0x00,0xf0,0x00,0xfe,
+/* 26321 0x66d1 "曑" */
+0x1f,0x10,0x1f,0x10,0x7f,0x44,0x7c,0x44,0x7d,0x06,0x19,0xe6,0x01,0x0e,0x00,0x1f,
+0xf0,0x10,0xf0,0x10,0xfc,0x44,0x7c,0x44,0x7c,0xc0,0x30,0x4e,0x80,0x20,0xc0,0x00,
+/* 26322 0x66d2 "曒" */
+0x01,0x02,0xf7,0x94,0x97,0x94,0x97,0xf2,0x91,0x97,0x92,0x93,0xf2,0x94,0x05,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 26323 0x66d3 "曓" */
+0x3f,0x20,0x3f,0x20,0x3f,0x11,0x1f,0x41,0x7f,0x02,0xff,0x09,0x3f,0xc5,0x0b,0x11,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xf0,0x04,0xfc,0x00,0xfe,0x20,0xf8,0x46,0xa0,0x10,
+/* 26324 0x66d4 "曔" */
+0x02,0x02,0xf7,0x92,0x94,0x97,0x94,0xf8,0x97,0x95,0x95,0x97,0xf5,0x90,0x02,0x01,
+0x88,0x88,0xe8,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x94,0x22,
+/* 26325 0x66d5 "曕" */
+0x01,0x01,0x7a,0x4f,0x4a,0x4b,0x7b,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x04,0x08,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 26326 0x66d6 "曖" */
+0x00,0x03,0xf0,0x92,0x91,0x97,0x94,0xf2,0x92,0x94,0x90,0x90,0xf1,0x92,0x00,0x07,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 26327 0x66d7 "曗" */
+0x00,0x02,0x79,0x48,0x4b,0x48,0x78,0x4b,0x48,0x49,0x48,0x7b,0x48,0x01,0x06,0x00,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 26328 0x66d8 "曘" */
+0x00,0x01,0x78,0x4b,0x4a,0x49,0x78,0x49,0x48,0x4b,0x48,0x79,0x49,0x01,0x01,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 26329 0x66d9 "曙" */
+0x00,0x03,0x7a,0x4a,0x4b,0x48,0x49,0x78,0x4b,0x48,0x48,0x49,0x7a,0x48,0x00,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x24,0xfc,0x28,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 26330 0x66da "曚" */
+0x01,0x07,0xf1,0x97,0x94,0x93,0x90,0xf7,0x90,0x91,0x96,0x91,0xf6,0x91,0x06,0x00,
+0x10,0xfc,0x10,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x44,0xa8,0x70,0xa8,0x26,0xa0,0x40,
+/* 26331 0x66db "曛" */
+0x00,0x07,0xf0,0x9f,0x90,0x97,0x95,0xf4,0x97,0x90,0x97,0x90,0xff,0x90,0x05,0x08,
+0x3c,0xc0,0x40,0xfe,0x40,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0x00,0x24,0x92,
+/* 26332 0x66dc "曜" */
+0x00,0x07,0xf0,0x94,0x92,0x94,0x91,0xf2,0x97,0x9a,0x93,0x92,0xf3,0x92,0x03,0x02,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 26333 0x66dd "曝" */
+0x03,0x02,0xf3,0x92,0x93,0x91,0x97,0xf1,0x9f,0x91,0x92,0x95,0xf0,0x91,0x02,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfc,0x10,0xfe,0x10,0x48,0x54,0xe0,0x50,0x48,0xc0,
+/* 26334 0x66de "曞" */
+0x00,0x03,0x7a,0x4b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x7b,0x4b,0x05,0x05,0x09,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 26335 0x66df "曟" */
+0x1f,0x10,0x1f,0x10,0x7f,0x44,0x7c,0x44,0x7f,0x20,0x2f,0x20,0x3f,0x24,0x44,0x86,
+0xf0,0x10,0xf0,0x10,0xfc,0x44,0x7c,0x44,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,
+/* 26336 0x66e0 "曠" */
+0x00,0x00,0xf7,0x94,0x95,0x94,0x97,0xf4,0x95,0x95,0x95,0x95,0xf5,0x94,0x04,0x09,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 26337 0x66e1 "曡" */
+0x0f,0x08,0x0f,0x08,0x0f,0x7c,0x44,0x7c,0x44,0xff,0x90,0x1f,0x10,0x1f,0x10,0xff,
+0xe0,0x20,0xe0,0x20,0xe0,0x7c,0x44,0x7c,0x44,0xfe,0x12,0xf0,0x10,0xf0,0x10,0xfe,
+/* 26338 0x66e2 "曢" */
+0x00,0x00,0x7b,0x4a,0x49,0x48,0x7a,0x49,0x4a,0x48,0x48,0x78,0x48,0x01,0x02,0x00,
+0x40,0x20,0xfe,0x22,0xfc,0x50,0x8a,0xfc,0x8a,0xf8,0x88,0xf8,0x20,0x24,0xa2,0x40,
+/* 26339 0x66e3 "曣" */
+0x01,0x01,0xf7,0x91,0x91,0x92,0x92,0xf6,0x92,0x92,0x96,0x9a,0xf0,0x92,0x02,0x04,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 26340 0x66e4 "曤" */
+0x07,0x00,0xf7,0x94,0x9b,0x90,0x97,0xf1,0x93,0x96,0x9b,0x92,0xf3,0x92,0x03,0x02,
+0xfc,0x40,0xfe,0x42,0x5c,0x40,0x5c,0x20,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 26341 0x66e5 "曥" */
+0x00,0x00,0x78,0x4b,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x05,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 26342 0x66e6 "曦" */
+0x01,0x07,0xf0,0x93,0x90,0x97,0x90,0xf3,0x91,0x97,0x93,0x95,0xf3,0x90,0x02,0x01,
+0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xd4,0x12,0xfe,0x50,0x34,0x8c,0x8a,0x96,0x02,
+/* 26343 0x66e7 "曧" */
+0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x55,0x7f,0x49,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x14,0x12,0xfe,0x02,
+/* 26344 0x66e8 "曨" */
+0x02,0x01,0xf7,0x90,0x94,0x92,0x97,0xf0,0x97,0x94,0x97,0x94,0xf7,0x94,0x04,0x04,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 26345 0x66e9 "曩" */
+0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x22,0x3e,0x04,0x3f,0x04,0xff,0x04,0x1c,0x67,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x88,0xf8,0x40,0xf8,0x40,0xfe,0x90,0x60,0x1c,
+/* 26346 0x66ea "曪" */
+0x00,0x03,0xf2,0x92,0x93,0x91,0x91,0xf2,0x97,0x91,0x92,0x97,0xf0,0x95,0x05,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x08,0x54,0x5e,0xb4,0x1e,0x54,0xde,0x14,0x54,0x5e,0x10,
+/* 26347 0x66eb "曫" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 26348 0x66ec "曬" */
+0x0f,0x00,0xf7,0x94,0x96,0x94,0x90,0xf7,0x94,0x97,0x94,0x97,0xf5,0x99,0x09,0x11,
+0xbe,0x00,0xbc,0xa4,0xb4,0xa4,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x12,0xdc,0x12,0xce,
+/* 26349 0x66ed "曭" */
+0x02,0x01,0xf7,0x94,0x91,0x91,0x97,0xf5,0x94,0x97,0x90,0x97,0xf0,0x9f,0x02,0x04,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 26350 0x66ee "曮" */
+0x07,0x04,0xf7,0x90,0x97,0x94,0x95,0xf4,0x97,0x95,0x95,0x95,0xf5,0x95,0x0b,0x10,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 26351 0x66ef "曯" */
+0x03,0x02,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,0x05,0x00,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 26352 0x66f0 "曰" */
+0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x7f,0x40,0x40,0x40,0x40,0x7f,0x40,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xe4,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,
+/* 26353 0x66f1 "曱" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,0x01,0x01,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 26354 0x66f2 "曲" */
+0x04,0x04,0x04,0x04,0x7f,0x44,0x44,0x44,0x44,0x7f,0x44,0x44,0x44,0x44,0x7f,0x40,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 26355 0x66f3 "曳" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x00,0x00,0x01,0x0e,0xf0,
+0x00,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0xa0,0x42,0xa2,0x1a,0x06,
+/* 26356 0x66f4 "更" */
+0x00,0xff,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x11,0x0a,0x06,0x19,0xe0,
+0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0x00,0xc0,0x3e,
+/* 26357 0x66f5 "曵" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x00,0x00,0x01,0x0e,0xf0,
+0x20,0x10,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0xa0,0x42,0xa2,0x1a,0x06,
+/* 26358 0x66f6 "曶" */
+0x08,0x08,0x1f,0x22,0x44,0x08,0x11,0x22,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xf8,0x48,0x48,0x88,0x28,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26359 0x66f7 "曷" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x08,0x1f,0x21,0x52,0x94,0x10,0x1f,0x00,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x00,0xfc,0x04,0x84,0x44,0x04,0x84,0x28,0x10,
+/* 26360 0x66f8 "書" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x3f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 26361 0x66f9 "曹" */
+0x04,0x04,0xff,0x04,0x3f,0x24,0x3f,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x40,0xfe,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26362 0x66fa "曺" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26363 0x66fb "曻" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x10,0x10,0x3e,0x42,0xa4,0x14,0x08,0x10,0x20,0x40,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0x10,0x10,0xfc,0x10,0x90,0x90,0xfe,0x10,0x10,0x10,
+/* 26364 0x66fc "曼" */
+0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x44,0x7f,0x00,0x3f,0x08,0x07,0x18,0xe0,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x44,0xfc,0x00,0xf0,0x20,0xc0,0x30,0x0e,
+/* 26365 0x66fd "曽" */
+0x08,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26366 0x66fe "曾" */
+0x08,0x04,0x3f,0x21,0x29,0x25,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x40,0xf8,0x08,0x28,0x48,0xf8,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26367 0x66ff "替" */
+0x08,0x08,0x7e,0x08,0xfe,0x14,0x22,0x41,0x9f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26368 0x6700 "最" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,0x22,0x3e,0x22,0x3e,0x22,0x2f,0xf2,0x42,0x03,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf8,0x88,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 26369 0x6701 "朁" */
+0x3e,0x08,0x48,0x7e,0x14,0x24,0x46,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x7c,0x10,0x90,0xfc,0x28,0x4a,0x86,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26370 0x6702 "朂" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,0x22,0x3e,0x22,0x3e,0x22,0x2f,0xf2,0x42,0x02,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x54,0x88,
+/* 26371 0x6703 "會" */
+0x01,0x02,0x0c,0x37,0xc0,0x3f,0x29,0x25,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x80,0x60,0xd8,0x06,0xf8,0x28,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 26372 0x6704 "朄" */
+0x10,0x10,0x13,0x7c,0x55,0x55,0x7d,0x55,0x55,0x55,0x7c,0x54,0x10,0x11,0x12,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 26373 0x6705 "朅" */
+0x10,0x11,0x11,0x7d,0x11,0x11,0x10,0xfd,0x12,0x11,0x21,0x29,0x45,0xfc,0x44,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 26374 0x6706 "朆" */
+0x44,0x24,0x28,0xfe,0x92,0xd7,0xba,0x92,0xfe,0x00,0x7d,0x44,0x7c,0x44,0x7c,0x44,
+0x40,0x40,0x40,0x7e,0xaa,0x2a,0x2a,0x4a,0x4a,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 26375 0x6707 "朇" */
+0x10,0x28,0x44,0xba,0x00,0xfe,0x92,0xd6,0x92,0xfe,0x00,0x7d,0x44,0x7c,0x44,0x7c,
+0x10,0x20,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x28,0x48,0xfe,0x08,0x08,0x08,0x08,
+/* 26376 0x6708 "月" */
+0x00,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x0f,0x08,0x08,0x10,0x10,0x20,0x40,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 26377 0x6709 "有" */
+0x02,0x02,0xff,0x04,0x04,0x0f,0x08,0x18,0x2f,0x48,0x88,0x0f,0x08,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 26378 0x670a "朊" */
+0x00,0x78,0x49,0x48,0x48,0x78,0x4b,0x48,0x48,0x78,0x48,0x48,0x48,0x49,0x49,0x9a,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,
+/* 26379 0x670b "朋" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x42,0x4a,0x85,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x84,0x94,0x08,
+/* 26380 0x670c "朌" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x26,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 26381 0x670d "服" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x42,0x4a,0x84,
+0x00,0xfc,0x84,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0xa8,0xc4,0x82,
+/* 26382 0x670e "朎" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 26383 0x670f "朏" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x24,0x24,0x3d,0x25,0x25,0x25,0x45,0x55,0x88,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 26384 0x6710 "朐" */
+0x00,0x3c,0x25,0x25,0x26,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x44,0x54,0x88,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 26385 0x6711 "朑" */
+0x00,0x7a,0x4a,0x4a,0x4a,0x7f,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x98,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 26386 0x6712 "朒" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x54,0x8c,0x24,0x24,0x54,0x8c,0x04,0x04,0x14,0x08,
+/* 26387 0x6713 "朓" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x44,0x55,0x8a,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 26388 0x6714 "朔" */
+0x42,0x22,0x24,0xff,0x08,0x08,0x49,0x49,0x49,0x7f,0x09,0x10,0x10,0x20,0x41,0x82,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x84,0x84,0x14,0x08,
+/* 26389 0x6715 "朕" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x27,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26390 0x6716 "朖" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 26391 0x6717 "朗" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x48,0x44,0x5a,0x62,0x41,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x84,0x84,0x14,0x08,
+/* 26392 0x6718 "朘" */
+0x00,0x78,0x48,0x49,0x4b,0x78,0x48,0x49,0x4a,0x78,0x49,0x4a,0x48,0x48,0x49,0x9e,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 26393 0x6719 "朙" */
+0x00,0xfe,0x82,0xaa,0xa6,0xc6,0x82,0xba,0xaa,0xaa,0xaa,0xaa,0xfe,0x82,0x01,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x84,0x84,0x14,0x08,
+/* 26394 0x671a "朚" */
+0x02,0x01,0xff,0x10,0x10,0x1f,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x02,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x14,0x08,
+/* 26395 0x671b "望" */
+0x10,0x08,0xff,0x20,0x20,0x26,0x38,0x20,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0x08,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 26396 0x671c "朜" */
+0x00,0x3c,0x27,0x24,0x25,0x3d,0x25,0x24,0x25,0x3c,0x24,0x27,0x24,0x44,0x54,0x88,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 26397 0x671d "朝" */
+0x08,0x08,0xff,0x08,0x7f,0x41,0x7f,0x41,0x7f,0x49,0x08,0xff,0x08,0x08,0x08,0x09,
+0x00,0x3e,0xa2,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0xa2,0x42,0x42,0x8a,0x04,
+/* 26398 0x671e "朞" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x10,0x2f,0xc8,0x0f,0x08,0x0f,0x08,0x08,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0xe8,0x26,0xe0,0x20,0xe0,0x20,0x60,
+/* 26399 0x671f "期" */
+0x22,0x22,0x7f,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0xff,0x04,0x22,0x41,0x82,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x84,0x84,0x14,0x08,
+/* 26400 0x6720 "朠" */
+0x00,0x78,0x4b,0x48,0x48,0x78,0x49,0x49,0x49,0x79,0x4b,0x48,0x48,0x48,0x49,0x9a,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 26401 0x6721 "朡" */
+0x00,0x78,0x4a,0x4a,0x4a,0x7a,0x4a,0x4b,0x48,0x79,0x4a,0x48,0x49,0x48,0x48,0x9b,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 26402 0x6722 "朢" */
+0x00,0x7f,0x48,0x7e,0x42,0x7e,0x48,0x7f,0x00,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x54,0x88,0xfc,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 26403 0x6723 "朣" */
+0x00,0x3d,0x24,0x24,0x27,0x3c,0x25,0x25,0x25,0x3d,0x25,0x24,0x25,0x44,0x57,0x88,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 26404 0x6724 "朤" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x4a,0x85,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x4a,0x85,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0x08,
+/* 26405 0x6725 "朥" */
+0x00,0x7a,0x4a,0x4c,0x49,0x7a,0x48,0x4b,0x4a,0x7c,0x4b,0x48,0x48,0x48,0x49,0x9a,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 26406 0x6726 "朦" */
+0x00,0x7b,0x48,0x4b,0x4a,0x79,0x48,0x4b,0x48,0x78,0x4b,0x48,0x4b,0x48,0x4b,0x98,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 26407 0x6727 "朧" */
+0x01,0x78,0x4b,0x48,0x4a,0x79,0x4b,0x48,0x4b,0x7a,0x4b,0x4a,0x4b,0x4a,0x4a,0x9a,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 26408 0x6728 "木" */
+0x01,0x01,0x01,0x01,0x7f,0x03,0x05,0x05,0x09,0x11,0x21,0x41,0x81,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0xfc,0x80,0x40,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,0x00,
+/* 26409 0x6729 "朩" */
+0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x09,0x09,0x11,0x11,0x21,0x41,0x81,0x05,0x02,
+0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0x00,
+/* 26410 0x672a "未" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 26411 0x672b "末" */
+0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 26412 0x672c "本" */
+0x01,0x01,0x01,0x01,0x7f,0x03,0x05,0x05,0x09,0x11,0x21,0x4f,0x81,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0xfc,0x80,0x40,0x40,0x20,0x10,0x08,0xe4,0x02,0x00,0x00,0x00,
+/* 26413 0x672d "札" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 26414 0x672e "朮" */
+0x01,0x01,0x01,0x01,0xff,0x01,0x09,0x09,0x09,0x09,0x11,0x11,0x21,0x41,0x81,0x01,
+0x00,0x20,0x10,0x00,0xfe,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1e,0x00,0x00,
+/* 26415 0x672f "术" */
+0x01,0x01,0x01,0x01,0x7f,0x03,0x05,0x05,0x09,0x11,0x21,0x41,0x81,0x01,0x01,0x01,
+0x00,0x20,0x10,0x10,0xfc,0x80,0x40,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00,0x00,
+/* 26416 0x6730 "朰" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x3f,0x00,0x00,0x03,0x1c,0x20,0x1f,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0xf8,0x10,0x60,0x80,0x04,0x04,0xfc,0x00,
+/* 26417 0x6731 "朱" */
+0x01,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 26418 0x6732 "朲" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 26419 0x6733 "朳" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x12,0x12,0x14,0x18,0x10,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 26420 0x6734 "朴" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 26421 0x6735 "朵" */
+0x00,0x0f,0x08,0x08,0x08,0x10,0x20,0xc1,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x1e,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 26422 0x6736 "朶" */
+0x00,0x3f,0x08,0x08,0x08,0x10,0x10,0x20,0x41,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x10,0x20,0x3c,0x04,0x04,0x14,0x08,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26423 0x6737 "朷" */
+0x08,0x08,0x09,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x09,0x09,0x0a,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 26424 0x6738 "朸" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 26425 0x6739 "朹" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 26426 0x673a "机" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 26427 0x673b "朻" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0xb4,0xc4,0x84,0x04,0x04,0x04,0x04,
+/* 26428 0x673c "朼" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 26429 0x673d "朽" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x31,0x39,0x54,0x50,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x40,0x40,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 26430 0x673e "朾" */
+0x08,0x08,0x0b,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26431 0x673f "朿" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x23,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x28,0x90,0x40,0x20,0x18,0x06,0x00,
+/* 26432 0x6740 "杀" */
+0x00,0x18,0x06,0x01,0x06,0x18,0x61,0x01,0xff,0x01,0x11,0x11,0x21,0x21,0x45,0x02,
+0x08,0x10,0x60,0x80,0x60,0x18,0x04,0x00,0xfe,0x00,0x20,0x10,0x08,0x04,0x04,0x00,
+/* 26433 0x6741 "杁" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x0a,
+0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x48,0x88,0x88,0x84,0x04,0x02,
+/* 26434 0x6742 "杂" */
+0x02,0x02,0x3f,0x04,0x04,0x08,0x11,0x61,0x01,0xff,0x01,0x09,0x11,0x21,0x45,0x02,
+0x00,0x00,0xe0,0x20,0x22,0x22,0x1e,0x00,0x00,0xfe,0x00,0x20,0x10,0x08,0x04,0x00,
+/* 26435 0x6743 "权" */
+0x10,0x13,0x11,0x11,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x04,0x04,0x04,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 26436 0x6744 "杄" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26437 0x6745 "杅" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26438 0x6746 "杆" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26439 0x6747 "杇" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 26440 0x6748 "杈" */
+0x10,0x13,0x11,0x11,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x04,0x44,0x24,0xa8,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 26441 0x6749 "杉" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x20,0xc0,
+/* 26442 0x674a "杊" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 26443 0x674b "杋" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 26444 0x674c "杌" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 26445 0x674d "杍" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26446 0x674e "李" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x0f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 26447 0x674f "杏" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 26448 0x6750 "材" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x18,0x28,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 26449 0x6751 "村" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 26450 0x6752 "杒" */
+0x10,0x10,0x11,0x10,0xfc,0x11,0x39,0x35,0x52,0x50,0x90,0x10,0x11,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 26451 0x6753 "杓" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x39,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 26452 0x6754 "杔" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x38,0x34,0x53,0x50,0x90,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 26453 0x6755 "杕" */
+0x08,0x08,0x08,0x08,0xfe,0x09,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x0a,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26454 0x6756 "杖" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x39,0x55,0x54,0x90,0x10,0x10,0x10,0x11,0x16,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 26455 0x6757 "杗" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x1f,0x01,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 26456 0x6758 "杘" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x21,0x22,0x24,0x28,0x50,0x40,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x80,0x80,0xfe,0xc0,0xa0,0x90,0x88,0x86,0x80,0x80,
+/* 26457 0x6759 "杙" */
+0x08,0x08,0x08,0x08,0xfe,0x09,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x48,0x44,0x44,0x40,0x5e,0xe0,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 26458 0x675a "杚" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x10,0x10,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 26459 0x675b "杛" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x38,0x55,0x55,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 26460 0x675c "杜" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x17,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26461 0x675d "杝" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x3b,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 26462 0x675e "杞" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 26463 0x675f "束" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x23,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x88,0x40,0x20,0x18,0x06,0x00,
+/* 26464 0x6760 "杠" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x13,0x10,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26465 0x6761 "条" */
+0x04,0x04,0x0f,0x18,0x64,0x03,0x1d,0xe1,0x01,0x7f,0x01,0x09,0x11,0x21,0x45,0x02,
+0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0x00,0xfc,0x00,0x20,0x10,0x08,0x04,0x00,
+/* 26466 0x6762 "杢" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x00,0x3f,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 26467 0x6763 "杣" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 26468 0x6764 "杤" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x91,0x11,0x12,0x12,0x14,0x18,
+0x00,0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 26469 0x6765 "来" */
+0x01,0x01,0x01,0x7f,0x01,0x11,0x09,0x09,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x20,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 26470 0x6766 "杦" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x31,0x3a,0x54,0x50,0x90,0x10,0x10,0x11,0x12,0x14,
+0x80,0x80,0x80,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 26471 0x6767 "杧" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 26472 0x6768 "杨" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x31,0x38,0x54,0x54,0x91,0x11,0x12,0x14,0x10,0x11,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 26473 0x6769 "杩" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x54,0x54,0x90,0x13,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 26474 0x676a "杪" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x31,0x39,0x56,0x54,0x90,0x10,0x10,0x10,0x10,0x13,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 26475 0x676b "杫" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x0b,0x08,
+0x10,0x10,0x10,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 26476 0x676c "杬" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 26477 0x676d "杭" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 26478 0x676e "杮" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 26479 0x676f "杯" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x38,0x34,0x51,0x52,0x94,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,
+/* 26480 0x6770 "杰" */
+0x01,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,0x00,0x24,0x22,0x42,0x80,
+0x00,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0x88,0x44,0x44,0x04,
+/* 26481 0x6771 "東" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x23,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x88,0x40,0x20,0x18,0x06,0x00,
+/* 26482 0x6772 "杲" */
+0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 26483 0x6773 "杳" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 26484 0x6774 "杴" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x0a,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26485 0x6775 "杵" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x30,0x38,0x57,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26486 0x6776 "杶" */
+0x10,0x10,0x10,0x13,0xfc,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 26487 0x6777 "杷" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 26488 0x6778 "杸" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x32,0x39,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x13,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 26489 0x6779 "杹" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x35,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0xa0,0xa0,0xa0,0x24,0x24,0x28,0x30,0x20,0x60,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 26490 0x677a "杺" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x3a,0x56,0x52,0x92,0x14,0x10,0x10,0x10,0x10,
+0x00,0x40,0x20,0x10,0x90,0x80,0x80,0x84,0x82,0x82,0x82,0x88,0x88,0x88,0x78,0x00,
+/* 26491 0x677b "杻" */
+0x08,0x09,0x08,0x08,0xfe,0x08,0x18,0x1d,0x2a,0x2a,0x48,0x88,0x08,0x08,0x0b,0x08,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 26492 0x677c "杼" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26493 0x677d "杽" */
+0x10,0x10,0x11,0x10,0xfc,0x11,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26494 0x677e "松" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x31,0x3a,0x54,0x54,0x90,0x10,0x11,0x13,0x11,0x10,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x40,0x40,0x88,0x84,0x04,0xfe,0x02,0x00,
+/* 26495 0x677f "板" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 26496 0x6780 "枀" */
+0x04,0x04,0x08,0x10,0x22,0xc4,0x08,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0x20,0x10,0x08,0x46,0x20,0xf0,0x10,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26497 0x6781 "极" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x30,0x38,0x55,0x55,0x91,0x11,0x12,0x12,0x14,0x11,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 26498 0x6782 "枂" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x0a,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 26499 0x6783 "枃" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 26500 0x6784 "构" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x32,0x38,0x54,0x54,0x91,0x11,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x44,0x44,0x84,0xa4,0x14,0xf4,0x14,0x04,0x28,0x10,
+/* 26501 0x6785 "枅" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x50,0x90,0x10,0x10,0x11,0x11,0x12,
+0x00,0xfc,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 26502 0x6786 "枆" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x31,0x38,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 26503 0x6787 "枇" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 26504 0x6788 "枈" */
+0x20,0x20,0x3e,0x20,0x20,0x26,0x38,0x21,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x80,0x84,0x98,0xe0,0x84,0x84,0x7c,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 26505 0x6789 "枉" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x55,0x50,0x90,0x10,0x10,0x10,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26506 0x678a "枊" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x10,
+0x00,0x40,0x9e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x5a,0x94,0x10,0x10,0x10,0x10,
+/* 26507 0x678b "枋" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 26508 0x678c "枌" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x3a,0x35,0x50,0x50,0x90,0x10,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 26509 0x678d "枍" */
+0x10,0x10,0x11,0x11,0xfa,0x14,0x33,0x38,0x55,0x51,0x90,0x10,0x10,0x10,0x10,0x10,
+0x90,0x90,0x08,0x08,0x04,0x02,0xfc,0x80,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 26510 0x678e "枎" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x57,0x54,0x90,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26511 0x678f "枏" */
+0x10,0x11,0x11,0x11,0xfd,0x13,0x31,0x39,0x55,0x53,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xf8,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 26512 0x6790 "析" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 26513 0x6791 "枑" */
+0x10,0x17,0x10,0x10,0xfc,0x10,0x39,0x35,0x51,0x52,0x93,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x80,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x10,0x10,0x10,0xfe,0x00,
+/* 26514 0x6792 "枒" */
+0x08,0x09,0x08,0x08,0xfe,0x08,0x19,0x1d,0x2a,0x2a,0x48,0x88,0x09,0x0a,0x08,0x08,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 26515 0x6793 "枓" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x49,0x88,0x08,0x08,0x08,0x08,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 26516 0x6794 "枔" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x32,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 26517 0x6795 "枕" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x30,0x38,0x54,0x50,0x90,0x11,0x11,0x12,0x14,0x18,
+0x40,0x40,0x40,0xfc,0x44,0x48,0x40,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 26518 0x6796 "枖" */
+0x08,0x08,0x09,0x08,0xfe,0x08,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x0a,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26519 0x6797 "林" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x50,0x91,0x12,0x14,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 26520 0x6798 "枘" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 26521 0x6799 "枙" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x12,0x14,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 26522 0x679a "枚" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x32,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x11,0x12,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 26523 0x679b "枛" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x48,0x44,0x44,0x42,0x00,
+/* 26524 0x679c "果" */
+0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x11,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26525 0x679d "枝" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x10,0x10,0x10,0x11,0x16,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 26526 0x679e "枞" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x52,0x92,0x12,0x14,0x14,0x18,0x11,
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xa8,0x68,0x28,0x44,0x44,0x84,0x02,
+/* 26527 0x679f "枟" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x11,0x13,0x11,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 26528 0x67a0 "枠" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x31,0x3a,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0xf8,0x48,0x88,0x8a,0x0a,0x26,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26529 0x67a1 "枡" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 26530 0x67a2 "枢" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x13,0x12,0x13,0x10,
+0x00,0xfc,0x00,0x08,0x88,0x50,0x50,0x20,0x20,0x50,0x50,0x88,0x08,0x00,0xfe,0x00,
+/* 26531 0x67a3 "枣" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x23,0x25,0x09,0x30,0xc6,0x01,0x00,0x0e,0x01,0x00,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0x88,0x48,0x20,0x18,0x06,0x80,0x40,0x00,0x80,0x40,
+/* 26532 0x67a4 "枤" */
+0x08,0x08,0x08,0x08,0xfe,0x09,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x0a,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26533 0x67a5 "枥" */
+0x20,0x23,0x22,0x22,0xfa,0x22,0x22,0x72,0x6a,0xa2,0xa2,0x22,0x24,0x24,0x29,0x32,
+0x00,0xfe,0x00,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 26534 0x67a6 "枦" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x40,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 26535 0x67a7 "枧" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 26536 0x67a8 "枨" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x80,0x84,0x84,0x88,0x90,0xa0,0x80,0xfe,0xa0,0x90,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 26537 0x67a9 "枩" */
+0x01,0x01,0x7f,0x05,0x09,0x31,0xc5,0x04,0x08,0x11,0x21,0xc2,0x04,0x08,0x1f,0x00,
+0x00,0x00,0xfc,0x20,0x10,0x08,0x44,0x40,0x20,0x10,0x08,0x06,0x40,0x20,0xf0,0x10,
+/* 26538 0x67aa "枪" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x34,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 26539 0x67ab "枫" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x72,0x6a,0xa2,0xa2,0x23,0x24,0x24,0x28,0x30,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 26540 0x67ac "枬" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x39,0x35,0x53,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xf8,0x08,0x08,0x48,0x28,0x28,0x08,0xfe,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 26541 0x67ad "枭" */
+0x01,0x02,0x1f,0x10,0x12,0x11,0x10,0x1f,0x01,0x01,0x7f,0x03,0x05,0x19,0xe1,0x01,
+0x00,0x00,0xf0,0x10,0x10,0x50,0x20,0xfc,0x04,0x04,0xf4,0x88,0x40,0x30,0x0e,0x00,
+/* 26542 0x67ae "枮" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 26543 0x67af "枯" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26544 0x67b0 "枰" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x30,0x38,0x57,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 26545 0x67b1 "枱" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 26546 0x67b2 "枲" */
+0x04,0x08,0x10,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0x10,0xf8,0x08,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26547 0x67b3 "枳" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 26548 0x67b4 "枴" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x57,0x54,0x90,0x10,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 26549 0x67b5 "枵" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x3b,0x54,0x55,0x91,0x10,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0xfe,0x80,0x00,0xf8,0x08,0x08,0x08,0x50,0x20,
+/* 26550 0x67b6 "架" */
+0x08,0x08,0x7f,0x09,0x11,0x11,0x25,0x42,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26551 0x67b7 "枷" */
+0x22,0x22,0x22,0xfa,0x27,0x22,0x72,0x6a,0xaa,0xa2,0x22,0x22,0x24,0x24,0x29,0x30,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x80,
+/* 26552 0x67b8 "枸" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 26553 0x67b9 "枹" */
+0x10,0x10,0x11,0x11,0xfa,0x15,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 26554 0x67ba "枺" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 26555 0x67bb "枻" */
+0x10,0x11,0x11,0x11,0xfd,0x13,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 26556 0x67bc "枼" */
+0x12,0x12,0xff,0x12,0x12,0x13,0x10,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x20,0xe0,0x00,0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26557 0x67bd "枽" */
+0x01,0x01,0x7f,0x01,0x10,0xff,0x10,0x10,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfc,0x00,0x10,0xfe,0x10,0x10,0xf0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26558 0x67be "枾" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0x20,
+/* 26559 0x67bf "枿" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x38,0x34,0x50,0x57,0x90,0x10,0x11,0x11,0x12,0x14,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xa8,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 26560 0x67c0 "柀" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 26561 0x67c1 "柁" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 26562 0x67c2 "柂" */
+0x10,0x10,0x10,0x11,0xfa,0x11,0x31,0x39,0x57,0x51,0x91,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 26563 0x67c3 "柃" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x32,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 26564 0x67c4 "柄" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 26565 0x67c5 "柅" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 26566 0x67c6 "柆" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x13,0x10,
+0x40,0x20,0x20,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 26567 0x67c7 "柇" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x55,0x91,0x12,0x14,0x18,0x10,0x10,
+0x38,0xc0,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 26568 0x67c8 "柈" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x31,0x38,0x54,0x54,0x93,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26569 0x67c9 "柉" */
+0x08,0x08,0x09,0x08,0xfe,0x08,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x09,0x0a,0x08,
+0x04,0x1e,0xe0,0x00,0x20,0x10,0xfe,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x3e,0x00,
+/* 26570 0x67ca "柊" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x54,0x53,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 26571 0x67cb "柋" */
+0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x11,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x90,0x88,0x80,0x9e,0xe0,0x80,0x44,0x34,0x0c,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26572 0x67cc "柌" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 26573 0x67cd "柍" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x53,0x90,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 26574 0x67ce "柎" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x35,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 26575 0x67cf "柏" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26576 0x67d0 "某" */
+0x08,0x08,0xff,0x08,0x08,0x0f,0x08,0x08,0x0f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x20,0xe0,0x20,0x20,0xe0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26577 0x67d1 "柑" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 26578 0x67d2 "柒" */
+0x20,0x10,0x00,0x47,0x20,0x08,0x10,0x60,0x21,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x80,0x80,0x9c,0xe0,0x80,0x84,0x84,0x7c,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26579 0x67d3 "染" */
+0x20,0x10,0x03,0x40,0x21,0x09,0x12,0x64,0x29,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x80,0x80,0xf0,0x90,0x10,0x12,0x12,0x0e,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26580 0x67d4 "柔" */
+0x00,0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26581 0x67d5 "柕" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x91,0x12,0x14,0x10,0x10,0x10,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x62,0xa4,0xa0,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26582 0x67d6 "柖" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x31,0x3a,0x54,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26583 0x67d7 "柗" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x34,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x10,0x90,0x90,0x08,0x08,0x04,0x02,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 26584 0x67d8 "柘" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x55,0x52,0x94,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 26585 0x67d9 "柙" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 26586 0x67da "柚" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 26587 0x67db "柛" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 26588 0x67dc "柜" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 26589 0x67dd "柝" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 26590 0x67de "柞" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x32,0x38,0x54,0x50,0x90,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 26591 0x67df "柟" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x93,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 26592 0x67e0 "柠" */
+0x20,0x20,0x20,0x23,0xfa,0x24,0x20,0x70,0x6b,0xa0,0xa0,0x20,0x20,0x20,0x20,0x20,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 26593 0x67e1 "柡" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x30,0x38,0x57,0x50,0x90,0x11,0x11,0x12,0x14,0x10,
+0x00,0xfc,0x00,0x00,0xfe,0x00,0x20,0x22,0xb2,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 26594 0x67e2 "柢" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x12,0x13,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 26595 0x67e3 "柣" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x32,0x38,0x57,0x54,0x90,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26596 0x67e4 "柤" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 26597 0x67e5 "查" */
+0x01,0x01,0xff,0x05,0x09,0x11,0x3f,0xd0,0x10,0x1f,0x10,0x10,0x1f,0x00,0xff,0x00,
+0x00,0x00,0xfe,0x40,0x20,0x10,0xf8,0x16,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x00,
+/* 26598 0x67e6 "柦" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,0x08,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 26599 0x67e7 "柧" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 26600 0x67e8 "柨" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x39,0x35,0x53,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26601 0x67e9 "柩" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x57,0x52,0x92,0x12,0x13,0x12,0x13,0x10,
+0x00,0xfc,0x00,0x40,0x40,0x78,0x88,0x90,0x10,0x20,0x50,0x88,0x04,0x00,0xfe,0x00,
+/* 26602 0x67ea "柪" */
+0x10,0x10,0x10,0x11,0xfd,0x12,0x33,0x38,0x55,0x51,0x92,0x13,0x10,0x10,0x10,0x10,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 26603 0x67eb "柫" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x33,0x3a,0x56,0x53,0x90,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 26604 0x67ec "柬" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x29,0x25,0x3f,0x23,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x28,0x48,0xf8,0x88,0x40,0x20,0x18,0x06,0x00,
+/* 26605 0x67ed "柭" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x30,0x38,0x55,0x51,0x91,0x11,0x12,0x12,0x14,0x11,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 26606 0x67ee "柮" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 26607 0x67ef "柯" */
+0x10,0x10,0x17,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x93,0x12,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0x48,0xc8,0x48,0x08,0x08,0x28,0x10,
+/* 26608 0x67f0 "柰" */
+0x01,0x01,0x7f,0x05,0x09,0x31,0xcf,0x00,0x00,0x7f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x00,0xfc,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 26609 0x67f1 "柱" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x13,0x10,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26610 0x67f2 "柲" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x3a,0x56,0x52,0x94,0x10,0x11,0x12,0x14,0x10,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 26611 0x67f3 "柳" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x93,0x12,0x10,0x10,0x11,0x12,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 26612 0x67f4 "柴" */
+0x08,0x08,0x28,0x2e,0x28,0x28,0x2e,0xf0,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x7c,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26613 0x67f5 "柵" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x3b,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 26614 0x67f6 "柶" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x13,0x12,0x10,
+0x00,0x00,0xfe,0x52,0x52,0x52,0x52,0x52,0x52,0x8e,0x82,0x02,0x02,0xfe,0x02,0x00,
+/* 26615 0x67f7 "柷" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x54,0x90,0x10,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 26616 0x67f8 "柸" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x38,0x55,0x52,0x90,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 26617 0x67f9 "柹" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x54,0x54,0x90,0x11,0x16,0x10,0x10,0x10,
+0x20,0x20,0x2e,0xf0,0x20,0x20,0x20,0xfe,0x22,0x62,0xa2,0x2a,0x24,0x20,0x20,0x20,
+/* 26618 0x67fa "柺" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 26619 0x67fb "査" */
+0x01,0x01,0x7f,0x05,0x09,0x31,0xc1,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 26620 0x67fc "柼" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x30,0x38,0x54,0x50,0x90,0x11,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 26621 0x67fd "柽" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x30,0x38,0x57,0x50,0x91,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x26,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26622 0x67fe "柾" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x17,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26623 0x67ff "柿" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x40,0x20,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26624 0x6800 "栀" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 26625 0x6801 "栁" */
+0x21,0x21,0x21,0x21,0xfa,0x22,0x22,0x75,0x68,0xa0,0xa1,0x21,0x22,0x24,0x28,0x20,
+0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x1a,0x14,0x10,0x10,0x10,0x10,
+/* 26626 0x6802 "栂" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x3b,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 26627 0x6803 "栃" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+/* 26628 0x6804 "栄" */
+0x22,0x11,0x11,0x00,0x7f,0x40,0x81,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x08,0x08,0x10,0x20,0xfe,0x02,0x04,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 26629 0x6805 "栅" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x3b,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0xd4,0x24,0x4c,
+/* 26630 0x6806 "栆" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x21,0x3f,0x02,0x04,0x08,0x33,0xc0,0x06,0x01,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x80,0x40,0x20,0x18,0xc6,0x00,0x80,0x40,
+/* 26631 0x6807 "标" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x30,0x38,0x55,0x55,0x92,0x12,0x14,0x10,0x10,0x10,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 26632 0x6808 "栈" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x39,0x54,0x50,0x90,0x10,0x10,0x10,0x13,0x10,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 26633 0x6809 "栉" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfe,0x42,0x42,0x42,0x42,0x4a,0x44,0x40,0x40,0x40,
+/* 26634 0x680a "栊" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x30,0x38,0x54,0x51,0x91,0x11,0x12,0x12,0x14,0x18,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0x28,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 26635 0x680b "栋" */
+0x10,0x10,0x10,0x17,0xf8,0x11,0x31,0x3a,0x57,0x50,0x91,0x11,0x12,0x14,0x10,0x10,
+0x40,0x40,0x40,0xfe,0x80,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 26636 0x680c "栌" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,
+/* 26637 0x680d "栍" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x32,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26638 0x680e "栎" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3b,0x54,0x54,0x91,0x11,0x12,0x14,0x10,0x10,
+0x08,0x3c,0xc0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 26639 0x680f "栏" */
+0x10,0x11,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x13,0x10,
+0x00,0x08,0x88,0x90,0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 26640 0x6810 "栐" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x33,0x38,0x54,0x54,0x91,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 26641 0x6811 "树" */
+0x20,0x20,0x27,0x20,0xf8,0x24,0x22,0x72,0x69,0xa1,0xa2,0x22,0x24,0x28,0x20,0x20,
+0x04,0x04,0x84,0x84,0xbe,0x84,0x84,0xa4,0x14,0x14,0x84,0x84,0x84,0x04,0x14,0x08,
+/* 26642 0x6812 "栒" */
+0x10,0x10,0x11,0x11,0xfe,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x10,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 26643 0x6813 "栓" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x31,0x38,0x54,0x50,0x91,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26644 0x6814 "栔" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x09,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26645 0x6815 "栕" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26646 0x6816 "栖" */
+0x10,0x17,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 26647 0x6817 "栗" */
+0x00,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26648 0x6818 "栘" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x55,0x54,0x90,0x11,0x10,0x10,0x10,0x11,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 26649 0x6819 "栙" */
+0x20,0x20,0x20,0x21,0xfa,0x20,0x21,0x76,0x68,0xa1,0xa0,0x22,0x23,0x20,0x20,0x20,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 26650 0x681a "栚" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x11,0x12,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 26651 0x681b "栛" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x31,0x3a,0x55,0x53,0x91,0x11,0x11,0x12,0x13,0x14,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 26652 0x681c "栜" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x11,0x16,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x2c,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 26653 0x681d "栝" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26654 0x681e "栞" */
+0x00,0x7e,0x08,0x08,0xfe,0x08,0x10,0x20,0x41,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26655 0x681f "栟" */
+0x11,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x53,0x90,0x10,0x11,0x11,0x12,0x14,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 26656 0x6820 "栠" */
+0x08,0x13,0x30,0x50,0x97,0x10,0x10,0x13,0x00,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x38,0xc0,0x40,0x40,0xfc,0x40,0x40,0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26657 0x6821 "校" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x31,0x3a,0x54,0x50,0x90,0x10,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 26658 0x6822 "栢" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26659 0x6823 "栣" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x35,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 26660 0x6824 "栤" */
+0x20,0x24,0x22,0x22,0xf8,0x21,0x20,0x72,0x6a,0xa4,0xa5,0x29,0x2a,0x20,0x20,0x20,
+0x20,0x20,0x20,0x20,0x32,0xb2,0xb4,0xa8,0xa8,0xa8,0x24,0x24,0x22,0x20,0xa0,0x40,
+/* 26661 0x6825 "栥" */
+0x01,0x41,0x21,0x0a,0x14,0xe0,0x21,0x26,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfc,0x44,0x48,0xa0,0x10,0x08,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26662 0x6826 "栦" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x32,0x3a,0x54,0x50,0x90,0x10,0x10,0x11,0x11,0x12,
+0x82,0x92,0x92,0x92,0x92,0x92,0xda,0xb6,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 26663 0x6827 "栧" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 26664 0x6828 "栨" */
+0x10,0x10,0x12,0x11,0xfd,0x10,0x38,0x34,0x50,0x53,0x91,0x11,0x11,0x11,0x10,0x10,
+0x10,0x10,0x10,0x3e,0x22,0x44,0x10,0x90,0x90,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 26665 0x6829 "栩" */
+0x10,0x13,0x10,0x10,0xfe,0x11,0x31,0x38,0x54,0x51,0x92,0x10,0x10,0x10,0x11,0x10,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 26666 0x682a "株" */
+0x10,0x11,0x11,0x11,0xfd,0x12,0x30,0x3b,0x54,0x54,0x90,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 26667 0x682b "栫" */
+0x10,0x10,0x10,0x17,0xf8,0x10,0x31,0x39,0x57,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 26668 0x682c "栬" */
+0x10,0x10,0x10,0x11,0xfa,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x10,0x10,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 26669 0x682d "栭" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 26670 0x682e "栮" */
+0x10,0x13,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x17,0x10,0x10,0x10,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 26671 0x682f "栯" */
+0x10,0x10,0x17,0x10,0xfd,0x13,0x35,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 26672 0x6830 "栰" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x35,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0xa8,0xa4,0xa4,0x20,0x2e,0xf0,0x20,0x24,0x24,0x24,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 26673 0x6831 "栱" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x53,0x90,0x10,0x10,0x11,0x12,0x14,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 26674 0x6832 "栲" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x38,0x55,0x52,0x94,0x10,0x10,0x10,0x10,0x10,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 26675 0x6833 "栳" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x33,0x38,0x54,0x55,0x92,0x14,0x10,0x10,0x10,0x10,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 26676 0x6834 "栴" */
+0x10,0x10,0x10,0x11,0xfa,0x10,0x30,0x38,0x54,0x50,0x93,0x10,0x10,0x11,0x11,0x12,
+0x80,0x80,0xfe,0x00,0x00,0xfc,0x84,0xa4,0x94,0x84,0xfe,0x84,0x84,0x04,0x14,0x08,
+/* 26677 0x6835 "栵" */
+0x10,0x10,0x17,0x11,0xf9,0x11,0x31,0x3a,0x57,0x52,0x94,0x10,0x10,0x11,0x12,0x14,
+0x02,0x02,0xe2,0x0a,0x0a,0xea,0x2a,0x2a,0x2a,0xaa,0x4a,0x4a,0x82,0x02,0x0a,0x04,
+/* 26678 0x6836 "栶" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x33,0x3a,0x56,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfc,0x04,0x44,0x44,0x44,0xfc,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0xfc,0x04,
+/* 26679 0x6837 "样" */
+0x11,0x10,0x10,0x10,0xfb,0x10,0x30,0x39,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26680 0x6838 "核" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x13,0x10,0x10,0x10,0x13,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 26681 0x6839 "根" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 26682 0x683a "栺" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0x04,0x38,0xc0,0x02,0x02,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26683 0x683b "栻" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x30,0x3b,0x55,0x51,0x91,0x11,0x11,0x17,0x12,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xa0,0x20,0x10,0x10,0x10,0xca,0x0a,0x06,0x02,
+/* 26684 0x683c "格" */
+0x10,0x10,0x10,0x11,0xfb,0x14,0x30,0x38,0x55,0x52,0x95,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 26685 0x683d "栽" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x08,0xff,0x18,0x2c,0x2a,0x49,0x88,0x08,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 26686 0x683e "栾" */
+0x02,0x01,0xff,0x04,0x14,0x14,0x24,0x44,0x00,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x44,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26687 0x683f "栿" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x90,0x94,0x92,0x12,0x10,0x7e,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 26688 0x6840 "桀" */
+0x10,0x10,0x3e,0x42,0xa4,0x14,0x08,0x10,0x20,0x41,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x10,0x10,0xfc,0x10,0x90,0x90,0xfe,0x10,0x10,0x10,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26689 0x6841 "桁" */
+0x10,0x10,0x11,0x12,0xfc,0x10,0x31,0x3b,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 26690 0x6842 "桂" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x91,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26691 0x6843 "桃" */
+0x10,0x10,0x10,0x12,0xfd,0x10,0x30,0x39,0x56,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 26692 0x6844 "桄" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 26693 0x6845 "桅" */
+0x10,0x10,0x10,0x11,0xfe,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 26694 0x6846 "框" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x00,0xfe,0x00,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 26695 0x6847 "桇" */
+0x10,0x10,0xfe,0x22,0x42,0x34,0x08,0x34,0xc3,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26696 0x6848 "案" */
+0x01,0x7f,0x40,0x04,0xff,0x08,0x1e,0x03,0x3c,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x04,0x00,0xfe,0x20,0x40,0xc0,0x38,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26697 0x6849 "桉" */
+0x10,0x10,0x10,0x13,0xfe,0x14,0x30,0x3b,0x54,0x54,0x91,0x10,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 26698 0x684a "桊" */
+0x01,0x11,0x09,0x3f,0x02,0x02,0x7f,0x08,0x11,0x21,0xdf,0x03,0x05,0x19,0x61,0x01,
+0x00,0x10,0x20,0xf8,0x00,0x00,0xfc,0x20,0x10,0x08,0xf6,0x00,0xc0,0x30,0x08,0x00,
+/* 26699 0x684b "桋" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 26700 0x684c "桌" */
+0x01,0x01,0x01,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26701 0x684d "桍" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x32,0x38,0x57,0x54,0x90,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 26702 0x684e "桎" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x33,0x38,0x54,0x54,0x93,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 26703 0x684f "桏" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x90,0x17,0x12,0x10,0x10,0x10,
+0x00,0x1e,0xf2,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0xf2,0x1a,0x14,0x10,0x10,0x10,
+/* 26704 0x6850 "桐" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 26705 0x6851 "桑" */
+0x1f,0x06,0x01,0x0e,0x00,0x7c,0x24,0x18,0x66,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0xe0,0x40,0x80,0x40,0x00,0xf8,0x48,0x30,0xcc,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 26706 0x6852 "桒" */
+0x01,0x01,0x7f,0x01,0x09,0x08,0xff,0x08,0x09,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfc,0x00,0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26707 0x6853 "桓" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 26708 0x6854 "桔" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x31,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26709 0x6855 "桕" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x10,
+0x00,0x40,0x9c,0x04,0x04,0x04,0x04,0xdc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 26710 0x6856 "桖" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x13,0x10,
+0x20,0x20,0x40,0x80,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 26711 0x6857 "桗" */
+0x10,0x13,0x10,0x10,0xfc,0x11,0x39,0x36,0x50,0x57,0x90,0x10,0x11,0x12,0x14,0x10,
+0x00,0xf8,0x88,0x90,0xbc,0x04,0x14,0x48,0x40,0xfe,0x40,0xe0,0x50,0x48,0x46,0x40,
+/* 26712 0x6858 "桘" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x80,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26713 0x6859 "桙" */
+0x10,0x10,0x10,0x11,0xfb,0x10,0x31,0x39,0x55,0x52,0x90,0x17,0x10,0x10,0x10,0x10,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 26714 0x685a "桚" */
+0x11,0x11,0x12,0x11,0xfd,0x10,0x30,0x38,0x55,0x51,0x92,0x14,0x10,0x10,0x10,0x13,
+0x24,0x24,0x48,0x24,0x24,0x00,0x80,0xfc,0x04,0x84,0x48,0x28,0x10,0x20,0xc0,0x00,
+/* 26715 0x685b "桛" */
+0x08,0x08,0x08,0x08,0xfe,0x09,0x18,0x1c,0x2b,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x20,0x20,0x20,
+/* 26716 0x685c "桜" */
+0x10,0x10,0x12,0x11,0xfd,0x10,0x30,0x38,0x57,0x54,0x91,0x11,0x10,0x10,0x11,0x16,
+0x40,0x24,0x24,0x08,0x08,0x10,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 26717 0x685d "桝" */
+0x22,0x22,0x22,0x23,0xfa,0x22,0x24,0x74,0x6a,0xa1,0xa1,0x21,0x22,0x22,0x24,0x28,
+0x08,0x08,0x08,0x88,0xbe,0x88,0xa8,0xa8,0xa8,0x28,0x3e,0x08,0x08,0x08,0x08,0x08,
+/* 26718 0x685e "桞" */
+0x21,0x21,0x21,0x21,0xfa,0x22,0x22,0x75,0x68,0xa0,0xa1,0x21,0x22,0x24,0x28,0x20,
+0x00,0x00,0x1e,0xd2,0x54,0x54,0x58,0x54,0x92,0x92,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 26719 0x685f "桟" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x3b,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x17,0x10,
+0x50,0x48,0x7e,0xc0,0x40,0x7c,0xc0,0x40,0x7e,0xc0,0x44,0x28,0x32,0xca,0x06,0x02,
+/* 26720 0x6860 "桠" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x32,0x39,0x55,0x55,0x90,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0x4a,0x4a,0x4c,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 26721 0x6861 "桡" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x3b,0x54,0x53,0x90,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 26722 0x6862 "桢" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x10,0x11,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 26723 0x6863 "档" */
+0x10,0x11,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x50,0x91,0x10,0x10,0x10,0x13,0x10,
+0x20,0x24,0xa4,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26724 0x6864 "桤" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x31,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 26725 0x6865 "桥" */
+0x20,0x20,0x23,0x20,0xf8,0x27,0x20,0x71,0x6a,0xa5,0xa1,0x21,0x21,0x22,0x22,0x24,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 26726 0x6866 "桦" */
+0x10,0x10,0x11,0x11,0xfb,0x15,0x31,0x39,0x55,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26727 0x6867 "桧" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x11,0x13,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 26728 0x6868 "桨" */
+0x08,0x48,0x28,0x09,0x1a,0x28,0x48,0x89,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x60,0x80,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 26729 0x6869 "桩" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 26730 0x686a "桪" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x30,0x3b,0x54,0x50,0x97,0x11,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x08,0x08,0xfe,0x08,0x88,0x88,0x28,0x10,
+/* 26731 0x686b "桫" */
+0x20,0x22,0x21,0x21,0xf4,0x22,0x22,0x70,0x68,0xa1,0xa6,0x22,0x22,0x22,0x22,0x20,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 26732 0x686c "桬" */
+0x10,0x08,0x40,0x24,0x09,0x72,0x10,0x10,0x07,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xa8,0xa4,0x22,0x28,0x30,0xc0,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26733 0x686d "桭" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 26734 0x686e "桮" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26735 0x686f "桯" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x57,0x54,0x90,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 26736 0x6870 "桰" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3b,0x56,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0x90,0x0a,0x06,0xfa,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 26737 0x6871 "桱" */
+0x10,0x13,0x10,0x11,0xfa,0x14,0x32,0x39,0x54,0x53,0x90,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 26738 0x6872 "桲" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x3a,0x34,0x51,0x50,0x90,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 26739 0x6873 "桳" */
+0x10,0x10,0x11,0x13,0xfc,0x10,0x33,0x38,0x54,0x51,0x92,0x11,0x10,0x10,0x10,0x10,
+0x40,0x80,0x04,0xfe,0x22,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,0x20,
+/* 26740 0x6874 "桴" */
+0x10,0x10,0x11,0x10,0xfd,0x10,0x30,0x39,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 26741 0x6875 "桵" */
+0x20,0x20,0x23,0x20,0xfa,0x21,0x21,0x70,0x6b,0xa0,0xa1,0x23,0x20,0x20,0x21,0x26,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 26742 0x6876 "桶" */
+0x20,0x27,0x20,0x21,0xf8,0x27,0x24,0x74,0x6f,0xa4,0xa4,0x27,0x24,0x24,0x24,0x24,
+0x00,0xf8,0x10,0xa0,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 26743 0x6877 "桷" */
+0x10,0x10,0x10,0x11,0xfa,0x15,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x14,0x08,
+/* 26744 0x6878 "桸" */
+0x11,0x10,0x10,0x10,0xfb,0x10,0x33,0x38,0x55,0x53,0x95,0x11,0x11,0x11,0x10,0x10,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26745 0x6879 "桹" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 26746 0x687a "桺" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x93,0x10,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x50,0x50,0x50,0xde,0x52,0x52,0x52,0x52,0xde,0x50,0x90,0x90,0x10,0x10,
+/* 26747 0x687b "桻" */
+0x21,0x21,0x23,0x24,0xf8,0x21,0x26,0x70,0x6b,0xa0,0xa3,0x20,0x27,0x20,0x20,0x20,
+0x00,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x40,0x40,0x40,
+/* 26748 0x687c "桼" */
+0x01,0x01,0x7f,0x09,0x11,0x21,0xc2,0x04,0x09,0x31,0xcb,0x05,0x19,0x61,0x05,0x02,
+0x00,0x00,0xfc,0x20,0x10,0x08,0x84,0x40,0x20,0x18,0x26,0xc0,0x30,0x08,0x00,0x00,
+/* 26749 0x687d "桽" */
+0x01,0x01,0x7f,0x05,0x19,0xe1,0x08,0x09,0x15,0x23,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfc,0x40,0x30,0x0e,0x20,0x20,0x50,0x88,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 26750 0x687e "桾" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x30,0x39,0x54,0x50,0x91,0x12,0x14,0x10,0x10,0x10,
+0x00,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x80,0x80,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 26751 0x687f "桿" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x55,0x54,0x90,0x13,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 26752 0x6880 "梀" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x11,0x12,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 26753 0x6881 "梁" */
+0x00,0x23,0x10,0x82,0x52,0x24,0xe1,0x22,0x25,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x90,0x94,0x92,0x92,0x10,0x50,0x20,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26754 0x6882 "梂" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x31,0x38,0x54,0x54,0x90,0x11,0x12,0x10,0x10,0x10,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 26755 0x6883 "梃" */
+0x20,0x20,0x27,0x21,0xf9,0x22,0x32,0x6f,0x61,0xa5,0xa5,0x22,0x22,0x25,0x28,0x30,
+0x00,0x0c,0x70,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0xfe,0x00,
+/* 26756 0x6884 "梄" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x8c,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26757 0x6885 "梅" */
+0x11,0x11,0x11,0x12,0xfd,0x11,0x39,0x35,0x57,0x51,0x92,0x12,0x13,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 26758 0x6886 "梆" */
+0x21,0x21,0x21,0x2f,0xf1,0x21,0x27,0x71,0x69,0xaf,0xa1,0x21,0x22,0x22,0x24,0x28,
+0x00,0x1e,0x12,0xd2,0x14,0x14,0xd8,0x14,0x12,0xd2,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 26759 0x6887 "梇" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x30,0x3b,0x54,0x50,0x93,0x10,0x10,0x11,0x11,0x12,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,
+/* 26760 0x6888 "梈" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x54,0x53,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x08,0x30,0x20,0x20,0xa0,0x40,
+/* 26761 0x6889 "梉" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x57,0x51,0x91,0x11,0x11,0x11,0x12,0x14,
+0x48,0x48,0x48,0x48,0x48,0xc8,0x7e,0x48,0xc8,0x48,0x48,0x48,0x48,0x48,0x5c,0x40,
+/* 26762 0x688a "梊" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26763 0x688b "梋" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x33,0x3a,0x56,0x53,0x92,0x12,0x13,0x12,0x12,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 26764 0x688c "梌" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x57,0x54,0x91,0x11,0x12,0x14,0x10,0x10,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 26765 0x688d "梍" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x17,0x10,0x10,0x10,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x40,0x40,0x7e,0xc0,0x42,0x42,0x3e,
+/* 26766 0x688e "梎" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0x0c,0xf0,0x00,0x02,0x02,0xfe,0x00,
+/* 26767 0x688f "梏" */
+0x10,0x11,0x11,0x11,0xfd,0x12,0x30,0x3b,0x54,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26768 0x6890 "梐" */
+0x12,0x12,0x12,0x13,0xfe,0x12,0x32,0x3b,0x54,0x50,0x93,0x10,0x10,0x10,0x17,0x10,
+0x20,0x24,0x28,0xb0,0x20,0x22,0xa2,0x1e,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 26769 0x6891 "梑" */
+0x20,0x28,0x25,0x22,0xf5,0x29,0x21,0x71,0x6b,0xa5,0xa9,0x21,0x21,0x21,0x2a,0x25,
+0x10,0x90,0x10,0x12,0x52,0x54,0x58,0x90,0x10,0x28,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 26770 0x6892 "梒" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x54,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26771 0x6893 "梓" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x91,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 26772 0x6894 "梔" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0xfe,0x00,0x7c,0x54,0x54,0x54,0x54,0x7c,0x40,0x42,0x42,0x3e,
+/* 26773 0x6895 "梕" */
+0x10,0x13,0x10,0x11,0xfd,0x12,0x38,0x35,0x52,0x50,0x90,0x12,0x12,0x12,0x14,0x10,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 26774 0x6896 "梖" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x09,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x48,0x44,0x82,0x02,
+/* 26775 0x6897 "梗" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x10,0x13,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 26776 0x6898 "梘" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 26777 0x6899 "梙" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x30,0x38,0x57,0x52,0x92,0x13,0x12,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0xfe,0x22,0x20,0x20,0x20,
+/* 26778 0x689a "梚" */
+0x10,0x10,0x11,0x12,0xfc,0x13,0x32,0x3a,0x56,0x53,0x90,0x10,0x11,0x11,0x12,0x14,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x44,0x44,0x44,0xfc,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 26779 0x689b "梛" */
+0x20,0x2f,0x22,0x22,0xfa,0x27,0x32,0x6a,0x62,0xaf,0xa2,0x22,0x22,0x24,0x25,0x28,
+0x00,0xde,0x52,0x52,0x54,0xd4,0x58,0x54,0x52,0xd2,0x52,0x5a,0x54,0x50,0x50,0x90,
+/* 26780 0x689c "梜" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x39,0x35,0x51,0x52,0x90,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 26781 0x689d "條" */
+0x08,0x08,0x10,0x10,0x35,0x54,0x94,0x17,0x14,0x15,0x14,0x14,0x15,0x12,0x10,0x10,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 26782 0x689e "梞" */
+0x10,0x11,0x10,0x10,0xfd,0x11,0x31,0x39,0x54,0x54,0x90,0x10,0x12,0x12,0x14,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x04,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 26783 0x689f "梟" */
+0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3f,0x05,0x19,0xe1,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x04,0xf4,0x48,0x30,0x0e,0x00,
+/* 26784 0x68a0 "梠" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x53,0x92,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 26785 0x68a1 "梡" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x38,0x34,0x53,0x50,0x90,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 26786 0x68a2 "梢" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 26787 0x68a3 "梣" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x30,0x38,0x55,0x52,0x90,0x11,0x10,0x10,0x10,0x10,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x10,0x10,0x20,
+/* 26788 0x68a4 "梤" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x30,0x38,0x55,0x52,0x90,0x10,0x10,0x10,0x11,0x12,
+0x20,0x24,0x24,0x24,0xfc,0x00,0x88,0x88,0x04,0xfa,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 26789 0x68a5 "梥" */
+0x02,0x01,0x7f,0x48,0x92,0x24,0x08,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x22,0x14,0x48,0x20,0xf0,0x10,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26790 0x68a6 "梦" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x04,0x07,0x08,0x14,0x22,0x01,0x02,0x0c,0x70,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x26,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 26791 0x68a7 "梧" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x30,0x3b,0x54,0x50,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26792 0x68a8 "梨" */
+0x03,0x3c,0x04,0x7f,0x0c,0x16,0x25,0x44,0x05,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x08,0x08,0x48,0x48,0x48,0x48,0x08,0x28,0x10,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26793 0x68a9 "梩" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x54,0x91,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 26794 0x68aa "梪" */
+0x10,0x13,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x54,0x91,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x88,0x90,0x00,0xfe,0x00,
+/* 26795 0x68ab "梫" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x38,0x37,0x52,0x51,0x90,0x10,0x10,0x10,0x10,0x13,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 26796 0x68ac "梬" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x38,0x57,0x54,0x91,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 26797 0x68ad "梭" */
+0x10,0x10,0x10,0x11,0xfb,0x10,0x30,0x39,0x56,0x50,0x91,0x12,0x10,0x10,0x11,0x16,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 26798 0x68ae "梮" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,0x10,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 26799 0x68af "梯" */
+0x11,0x10,0x10,0x11,0xfc,0x10,0x31,0x39,0x55,0x51,0x90,0x10,0x11,0x12,0x14,0x10,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 26800 0x68b0 "械" */
+0x10,0x10,0x10,0x10,0xfb,0x10,0x31,0x39,0x57,0x51,0x91,0x11,0x12,0x12,0x14,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x50,0x54,0xf4,0x54,0x54,0x48,0x4a,0x5a,0x26,0x42,
+/* 26801 0x68b1 "梱" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x56,0x52,0x93,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 26802 0x68b2 "梲" */
+0x10,0x10,0x10,0x11,0xfa,0x15,0x31,0x39,0x55,0x51,0x90,0x10,0x10,0x11,0x12,0x14,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 26803 0x68b3 "梳" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x33,0x38,0x55,0x51,0x91,0x11,0x12,0x12,0x14,0x18,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 26804 0x68b4 "梴" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x3b,0x54,0x52,0x92,0x11,0x11,0x12,0x14,0x18,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 26805 0x68b5 "梵" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x00,0x0f,0x08,0x08,0x0a,0x09,0x11,0x20,0x40,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x26,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 26806 0x68b6 "梶" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x18,0xe0,0x38,0xe0,0x3c,0xe0,0x22,0x22,0x1e,0x00,
+/* 26807 0x68b7 "梷" */
+0x10,0x10,0x1e,0x10,0x7e,0x42,0x42,0x7e,0x01,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x04,0x48,0x28,0x10,0x28,0xc4,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26808 0x68b8 "梸" */
+0x20,0x21,0x27,0x21,0xf9,0x21,0x27,0x71,0x6b,0xa3,0xa5,0x25,0x29,0x21,0x21,0x21,
+0x84,0xc4,0x04,0x14,0x14,0x14,0xd4,0x14,0x14,0x94,0x54,0x04,0x04,0x04,0x14,0x08,
+/* 26809 0x68b9 "梹" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x97,0x10,0x10,0x11,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,0x02,
+/* 26810 0x68ba "梺" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x26,0x00,0xfe,0x00,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 26811 0x68bb "梻" */
+0x22,0x22,0x22,0x25,0xf4,0x2c,0x35,0x75,0x6d,0xa5,0xa4,0x24,0x24,0x24,0x24,0x25,
+0x50,0x50,0x50,0xfc,0x54,0x54,0xfc,0x50,0x50,0xfe,0x52,0x52,0x5a,0x94,0x90,0x10,
+/* 26812 0x68bc "梼" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x54,0x54,0x91,0x11,0x12,0x14,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 26813 0x68bd "梽" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x12,0x12,0x12,0x14,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 26814 0x68be "梾" */
+0x10,0x10,0x10,0x13,0xfc,0x11,0x30,0x38,0x55,0x54,0x90,0x10,0x11,0x12,0x14,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x24,0xa4,0xa8,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 26815 0x68bf "梿" */
+0x10,0x12,0x11,0x11,0xfc,0x10,0x37,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x14,0x10,
+0x10,0x10,0x10,0x7e,0x20,0x28,0x48,0x7e,0x08,0x08,0xfe,0x08,0x08,0x88,0x7e,0x00,
+/* 26816 0x68c0 "检" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x35,0x38,0x54,0x50,0x92,0x11,0x11,0x10,0x17,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 26817 0x68c1 "棁" */
+0x11,0x10,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x11,0x12,0x14,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 26818 0x68c2 "棂" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x30,0x3b,0x54,0x51,0x91,0x12,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 26819 0x68c3 "棃" */
+0x0c,0x70,0x11,0xfd,0x12,0x38,0x54,0x91,0x10,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x80,0xfc,0x24,0x24,0x24,0x44,0x84,0x28,0x10,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26820 0x68c4 "棄" */
+0x02,0x01,0x7f,0x10,0x3f,0x01,0x11,0xff,0x11,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x00,0xfc,0x10,0xf8,0x08,0x10,0xfe,0x10,0xf0,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 26821 0x68c5 "棅" */
+0x20,0x23,0x20,0x27,0xf8,0x23,0x20,0x77,0x68,0xa3,0xa0,0x21,0x22,0x2c,0x20,0x20,
+0x78,0xc0,0x40,0xfc,0x40,0xf8,0x48,0xfe,0x48,0xf8,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 26822 0x68c6 "棆" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 26823 0x68c7 "棇" */
+0x10,0x10,0x11,0x11,0xfa,0x14,0x31,0x3b,0x54,0x50,0x90,0x12,0x12,0x12,0x14,0x10,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 26824 0x68c8 "棈" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 26825 0x68c9 "棉" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x53,0x92,0x12,0x12,0x12,0x10,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 26826 0x68ca "棊" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x11,0x21,0xdf,0x03,0x05,0x19,0x61,0x01,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0x08,0xf6,0x00,0xc0,0x30,0x08,0x00,
+/* 26827 0x68cb "棋" */
+0x11,0x11,0x13,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x17,0x10,0x10,0x11,0x12,
+0x08,0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 26828 0x68cc "棌" */
+0x20,0x20,0x23,0x20,0xfa,0x21,0x21,0x70,0x6b,0xa0,0xa0,0x20,0x21,0x22,0x24,0x20,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 26829 0x68cd "棍" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 26830 0x68ce "棎" */
+0x10,0x13,0x12,0x12,0xfc,0x11,0x30,0x38,0x57,0x54,0x90,0x10,0x11,0x16,0x10,0x10,
+0x00,0xfe,0x02,0x52,0x88,0x04,0x20,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 26831 0x68cf "棏" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x39,0x54,0x53,0x90,0x11,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x08,0xfe,0x08,0x08,0x88,0x08,0x28,0x10,
+/* 26832 0x68d0 "棐" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x05,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26833 0x68d1 "棑" */
+0x10,0x10,0x10,0x17,0xf8,0x10,0x30,0x3b,0x54,0x50,0x90,0x17,0x10,0x10,0x10,0x10,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 26834 0x68d2 "棒" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x52,0x90,0x10,0x13,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 26835 0x68d3 "棓" */
+0x10,0x10,0x11,0x10,0xfd,0x10,0x30,0x3b,0x54,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0x40,0xfc,0x00,0x08,0x88,0x90,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26836 0x68d4 "棔" */
+0x10,0x13,0x12,0x13,0xfe,0x12,0x33,0x3a,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26837 0x68d5 "棕" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x30,0x38,0x57,0x54,0x91,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 26838 0x68d6 "棖" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x3b,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 26839 0x68d7 "棗" */
+0x01,0x7f,0x01,0x3f,0x23,0x0d,0x30,0x01,0x7f,0x01,0x3f,0x21,0x23,0x05,0x19,0xe1,
+0x00,0xfc,0x00,0xf8,0x88,0x60,0x10,0x00,0xfc,0x00,0xf8,0x08,0x88,0x60,0x18,0x06,
+/* 26840 0x68d8 "棘" */
+0x10,0x10,0xfd,0x10,0x10,0x7c,0x54,0x54,0x54,0x5c,0x10,0x38,0x54,0x95,0x10,0x10,
+0x20,0x20,0xfc,0x20,0x20,0xf8,0xa8,0xa8,0xa8,0xb8,0x20,0x70,0xa8,0x26,0x20,0x20,
+/* 26841 0x68d9 "棙" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x56,0x53,0x92,0x12,0x12,0x14,0x15,0x1a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 26842 0x68da "棚" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x56,0x53,0x92,0x12,0x12,0x12,0x15,0x18,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 26843 0x68db "棛" */
+0x10,0x10,0x13,0x10,0xfd,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 26844 0x68dc "棜" */
+0x21,0x20,0x20,0x27,0xfa,0x22,0x22,0x73,0x6a,0xa2,0xa2,0x22,0x22,0x24,0x25,0x28,
+0x08,0x88,0x08,0xd4,0x14,0x22,0x00,0xc8,0x44,0x44,0x40,0x50,0x48,0x44,0x44,0x80,
+/* 26845 0x68dd "棝" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 26846 0x68de "棞" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3b,0x56,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x02,0x1a,0xe2,0x22,0x22,0xfe,0x22,0x72,0xaa,0x26,0x22,0x22,0xfe,0x02,
+/* 26847 0x68df "棟" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x11,0x16,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 26848 0x68e0 "棠" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26849 0x68e1 "棡" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 26850 0x68e2 "棢" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x57,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 26851 0x68e3 "棣" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x38,0x34,0x51,0x52,0x91,0x10,0x11,0x12,0x10,0x10,
+0x20,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 26852 0x68e4 "棤" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x37,0x38,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26853 0x68e5 "棥" */
+0x20,0x24,0x22,0x21,0xf9,0x22,0x24,0x70,0x68,0xa2,0xa1,0x21,0x22,0x22,0x24,0x28,
+0x88,0x88,0x88,0x08,0x3e,0x88,0x98,0x1c,0xac,0xaa,0x48,0x08,0x88,0x88,0x88,0x08,
+/* 26854 0x68e6 "棦" */
+0x10,0x10,0x11,0x12,0xfc,0x13,0x30,0x38,0x57,0x54,0x90,0x13,0x10,0x10,0x11,0x10,
+0x80,0x80,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x80,
+/* 26855 0x68e7 "棧" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x30,0x39,0x54,0x54,0x91,0x10,0x10,0x10,0x10,0x11,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 26856 0x68e8 "棨" */
+0x10,0x08,0x3e,0x22,0x22,0x3e,0x22,0x40,0x81,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0x3e,0x44,0x84,0x28,0x10,0x28,0x44,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26857 0x68e9 "棩" */
+0x10,0x12,0x12,0x12,0xfb,0x12,0x32,0x3b,0x56,0x52,0x93,0x12,0x12,0x12,0x14,0x18,
+0x50,0x52,0x52,0x52,0xde,0x02,0x02,0xfe,0x02,0x02,0xde,0x52,0x52,0x52,0x52,0x02,
+/* 26858 0x68ea "棪" */
+0x10,0x11,0x11,0x12,0xfc,0x10,0x33,0x38,0x54,0x55,0x91,0x12,0x10,0x10,0x11,0x16,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 26859 0x68eb "棫" */
+0x10,0x10,0x10,0x17,0xf8,0x10,0x33,0x3a,0x56,0x52,0x93,0x10,0x10,0x17,0x12,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 26860 0x68ec "棬" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x33,0x38,0x55,0x52,0x94,0x10,0x10,0x10,0x10,0x10,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 26861 0x68ed "棭" */
+0x20,0x20,0x27,0x21,0xf9,0x22,0x22,0x76,0x6a,0xa3,0xa2,0x22,0x22,0x22,0x22,0x23,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 26862 0x68ee "森" */
+0x01,0x01,0x7f,0x05,0x09,0x31,0xc1,0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x08,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0x20,
+/* 26863 0x68ef "棯" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x31,0x38,0x54,0x54,0x90,0x12,0x12,0x12,0x14,0x10,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 26864 0x68f0 "棰" */
+0x20,0x20,0x23,0x20,0xf8,0x27,0x22,0x72,0x6f,0xa2,0xa2,0x27,0x20,0x20,0x27,0x20,
+0x10,0x78,0xc0,0x40,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0x40,0xfc,0x00,
+/* 26865 0x68f1 "棱" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x39,0x56,0x54,0x91,0x12,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 26866 0x68f2 "棲" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x50,0x93,0x10,0x11,0x10,0x10,0x13,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x40,0xfe,0x84,0xc8,0x30,0xcc,0x02,
+/* 26867 0x68f3 "棳" */
+0x10,0x13,0x10,0x11,0xfc,0x11,0x3a,0x34,0x50,0x53,0x90,0x11,0x10,0x11,0x12,0x14,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 26868 0x68f4 "棴" */
+0x20,0x27,0x24,0x24,0xfc,0x27,0x24,0x74,0x6c,0xa7,0xa4,0x24,0x24,0x24,0x24,0x29,
+0x00,0xbe,0xa2,0xa2,0xaa,0xa4,0xa0,0xbe,0xaa,0xaa,0xaa,0xaa,0xa4,0xa4,0xaa,0xb0,
+/* 26869 0x68f5 "棵" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x53,0x90,0x10,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 26870 0x68f6 "棶" */
+0x10,0x10,0x10,0x17,0xf8,0x12,0x32,0x3a,0x55,0x50,0x91,0x11,0x12,0x14,0x18,0x10,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 26871 0x68f7 "棷" */
+0x20,0x2f,0x24,0x24,0xf4,0x27,0x24,0x74,0x6f,0xa4,0xa4,0x25,0x2e,0x20,0x20,0x20,
+0x00,0xc0,0xbc,0xa4,0xa4,0xa4,0xa4,0xa8,0xa8,0xa8,0x90,0xd0,0xa8,0xa8,0xc4,0x82,
+/* 26872 0x68f8 "棸" */
+0x00,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0x7c,0x04,0x28,0x10,0xa8,0x44,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26873 0x68f9 "棹" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x13,0x10,0x10,0x10,0x10,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 26874 0x68fa "棺" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 26875 0x68fb "棻" */
+0x08,0xff,0x08,0x04,0x08,0x37,0xc2,0x04,0x18,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0xfe,0x20,0x60,0x10,0xe8,0x24,0xa0,0x40,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26876 0x68fc "棼" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x24,0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,
+/* 26877 0x68fd "棽" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x02,0x0e,0x31,0xc1,0x1f,0x00,0x00,0x00,0x01,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x24,0x80,0x60,0x18,0x06,0xe0,0x20,0x40,0x80,0x00,
+/* 26878 0x68fe "棾" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x00,0x7f,0x40,0x8f,0x08,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x26,0x00,0xfe,0x02,0xe4,0x20,0x20,0x22,0x22,0x1e,
+/* 26879 0x68ff "棿" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x57,0x54,0x90,0x10,0x10,0x11,0x12,0x14,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 26880 0x6900 "椀" */
+0x10,0x10,0x13,0x12,0xfd,0x11,0x31,0x3a,0x56,0x53,0x94,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 26881 0x6901 "椁" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x38,0x55,0x54,0x90,0x13,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 26882 0x6902 "椂" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x30,0x3b,0x54,0x52,0x91,0x10,0x11,0x12,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 26883 0x6903 "椃" */
+0x10,0x10,0x10,0x10,0xfb,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x14,0x14,0x19,0x12,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 26884 0x6904 "椄" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x37,0x38,0x54,0x57,0x90,0x11,0x10,0x10,0x11,0x16,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 26885 0x6905 "椅" */
+0x20,0x20,0x23,0x20,0xf9,0x22,0x27,0x70,0x6b,0xa2,0xa2,0x22,0x23,0x20,0x20,0x20,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 26886 0x6906 "椆" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 26887 0x6907 "椇" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x17,0x10,0x10,0x11,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 26888 0x6908 "椈" */
+0x11,0x11,0x11,0x12,0xfc,0x14,0x32,0x38,0x57,0x50,0x91,0x12,0x14,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x04,0x84,0x94,0xa4,0x84,0xfc,0x84,0xc4,0xa4,0x94,0x84,0xa8,0x10,
+/* 26889 0x6909 "椉" */
+0x02,0x01,0xff,0x10,0x3e,0x42,0x14,0x18,0xe0,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfe,0x10,0xfc,0x10,0x90,0xfe,0x10,0x10,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26890 0x690a "椊" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x31,0x3a,0x54,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 26891 0x690b "椋" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x39,0x55,0x54,0x91,0x11,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 26892 0x690c "椌" */
+0x10,0x10,0x10,0x13,0xfa,0x14,0x31,0x3a,0x54,0x51,0x90,0x10,0x10,0x10,0x17,0x10,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 26893 0x690d "植" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfe,0x00,
+/* 26894 0x690e "椎" */
+0x10,0x10,0x10,0x11,0xfd,0x13,0x35,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0xa0,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 26895 0x690f "椏" */
+0x10,0x17,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x53,0x90,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x90,0x90,0x90,0x9c,0x04,0x04,0x04,0x9c,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 26896 0x6910 "椐" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 26897 0x6911 "椑" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x91,0x13,0x10,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 26898 0x6912 "椒" */
+0x21,0x21,0x21,0x21,0xf9,0x21,0x27,0x70,0x69,0xa1,0xa5,0x25,0x29,0x21,0x25,0x22,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 26899 0x6913 "椓" */
+0x10,0x13,0x10,0x10,0xfd,0x12,0x30,0x3a,0x55,0x52,0x90,0x10,0x11,0x12,0x10,0x10,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 26900 0x6914 "椔" */
+0x10,0x10,0x11,0x12,0xfd,0x10,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 26901 0x6915 "椕" */
+0x20,0x20,0x22,0x22,0xfa,0x24,0x20,0x77,0x6a,0xa2,0xa2,0x22,0x22,0x24,0x24,0x29,
+0x08,0x88,0x88,0x88,0xbe,0x48,0x18,0x9c,0xac,0xaa,0xc8,0x88,0x88,0x88,0x88,0x88,
+/* 26902 0x6916 "椖" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x20,0x10,0xfe,0x20,0x20,0x3c,0x24,0x44,0x54,0x88,
+/* 26903 0x6917 "椗" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x33,0x38,0x54,0x55,0x91,0x11,0x12,0x12,0x14,0x18,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 26904 0x6918 "椘" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x02,0x01,0x7f,0x00,0x01,0x0e,0x30,0x48,0x87,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x24,0x00,0x00,0xf8,0x60,0x80,0x00,0x00,0x00,0xfe,
+/* 26905 0x6919 "椙" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26906 0x691a "椚" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x04,
+/* 26907 0x691b "椛" */
+0x11,0x11,0x17,0x11,0xfd,0x10,0x38,0x34,0x51,0x53,0x95,0x11,0x11,0x11,0x11,0x11,
+0x08,0x08,0xfe,0x08,0x08,0x00,0x90,0x92,0x14,0x18,0x10,0x32,0x52,0x12,0x0e,0x00,
+/* 26908 0x691c "検" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x55,0x55,0x91,0x11,0x10,0x10,0x11,0x12,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfc,0x24,0x24,0xfc,0x50,0x88,0x04,0x02,
+/* 26909 0x691d "椝" */
+0x10,0x11,0x7d,0x11,0x11,0xfc,0x10,0x29,0x46,0x81,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x04,0x24,0x24,0x50,0x90,0x12,0x0e,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26910 0x691e "椞" */
+0x08,0x08,0x7e,0x18,0x2c,0x2a,0x48,0x88,0x09,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26911 0x691f "椟" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x38,0x54,0x55,0x90,0x13,0x10,0x10,0x10,0x13,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x10,0x90,0xfe,0x28,0x44,0x82,0x02,
+/* 26912 0x6920 "椠" */
+0x10,0xfe,0x20,0x48,0x7e,0x08,0x0e,0xf9,0x4a,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26913 0x6921 "椡" */
+0x10,0x10,0x17,0x11,0xfd,0x12,0x33,0x38,0x54,0x53,0x90,0x10,0x10,0x17,0x12,0x10,
+0x02,0x02,0xe2,0x0a,0x0a,0x4a,0xea,0x8a,0x8a,0xea,0x8a,0x8a,0xe2,0x02,0x0a,0x04,
+/* 26914 0x6922 "椢" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x02,0x02,0xfe,0x22,0x22,0xfa,0x22,0x32,0x2a,0xfe,0x02,0x02,0xfe,0x02,
+/* 26915 0x6923 "椣" */
+0x10,0x10,0x10,0x13,0xfe,0x12,0x32,0x3b,0x56,0x52,0x92,0x17,0x10,0x10,0x11,0x12,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 26916 0x6924 "椤" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x30,0x38,0x54,0x51,0x92,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfe,0x52,0x52,0x52,0xfe,0x20,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0x00,
+/* 26917 0x6925 "椥" */
+0x11,0x11,0x11,0x13,0xfa,0x14,0x30,0x38,0x57,0x50,0x90,0x11,0x11,0x12,0x14,0x18,
+0x00,0x00,0x00,0xde,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x52,0x5e,0x20,0x20,0x00,
+/* 26918 0x6926 "椦" */
+0x10,0x11,0x10,0x10,0xfd,0x10,0x33,0x38,0x55,0x52,0x95,0x10,0x10,0x10,0x11,0x12,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x44,0x42,0xf8,0x48,0x88,0x88,0x28,0x10,
+/* 26919 0x6927 "椧" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x3b,0x56,0x52,0x92,0x13,0x12,0x10,0x10,0x10,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xde,0x52,0x52,0x52,0xda,0x54,0x10,0x10,0x10,
+/* 26920 0x6928 "椨" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x57,0x52,0x92,0x12,0x12,0x12,0x14,0x10,
+0x40,0x20,0xfe,0x00,0x44,0x44,0x84,0xbe,0x84,0xa4,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 26921 0x6929 "椩" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x19,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x20,0x50,0x50,0x88,0x06,
+/* 26922 0x692a "椪" */
+0x10,0x10,0x10,0x11,0xfc,0x10,0x30,0x3a,0x55,0x55,0x90,0x10,0x10,0x10,0x13,0x10,
+0x84,0x48,0x00,0xfe,0x48,0x48,0x48,0x48,0x4a,0x4c,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 26923 0x692b "椫" */
+0x11,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x13,0x10,0x10,0x10,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 26924 0x692c "椬" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x17,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 26925 0x692d "椭" */
+0x20,0x27,0x24,0x25,0xfd,0x26,0x25,0x74,0x6c,0xa4,0xa6,0x25,0x24,0x24,0x24,0x24,
+0x10,0x90,0x90,0x7e,0x20,0x20,0x7c,0xa4,0xa4,0xbc,0xa4,0x3c,0x24,0x24,0x24,0x2c,
+/* 26926 0x692e "椮" */
+0x10,0x10,0x10,0x11,0xfc,0x13,0x30,0x39,0x56,0x51,0x90,0x10,0x11,0x10,0x10,0x13,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x62,0x84,0x18,0x60,0x80,
+/* 26927 0x692f "椯" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x33,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 26928 0x6930 "椰" */
+0x20,0x2f,0x24,0x24,0xf4,0x27,0x24,0x74,0x6f,0xa4,0xa4,0x25,0x2e,0x20,0x20,0x20,
+0x00,0xde,0x92,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0x92,0xda,0x94,0x90,0x90,0x90,
+/* 26929 0x6931 "椱" */
+0x11,0x11,0x11,0x12,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x11,0x12,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 26930 0x6932 "椲" */
+0x10,0x10,0x11,0x10,0xfb,0x10,0x31,0x39,0x55,0x50,0x93,0x10,0x12,0x13,0x10,0x10,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 26931 0x6933 "椳" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x53,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 26932 0x6934 "椴" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x17,0x11,0x11,0x11,
+0x20,0xdc,0x14,0x14,0x14,0xd4,0x26,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 26933 0x6935 "椵" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x57,0x52,0x92,0x13,0x12,0x12,0x12,0x12,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 26934 0x6936 "椶" */
+0x10,0x10,0x12,0x12,0xfe,0x12,0x32,0x3b,0x54,0x51,0x92,0x10,0x11,0x10,0x10,0x17,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 26935 0x6937 "椷" */
+0x20,0x20,0x20,0x27,0xfc,0x24,0x25,0x74,0x6c,0xa5,0xa5,0x25,0x25,0x24,0x28,0x30,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 26936 0x6938 "椸" */
+0x22,0x21,0x21,0x27,0xfa,0x22,0x23,0x72,0x6a,0xa2,0xa2,0x22,0x24,0x24,0x29,0x30,
+0x10,0x10,0x10,0xbe,0x28,0x48,0xaa,0xae,0xba,0xea,0xae,0xa8,0xaa,0xa2,0xa2,0x1e,
+/* 26937 0x6939 "椹" */
+0x11,0x11,0x17,0x11,0xfd,0x11,0x39,0x35,0x51,0x57,0x92,0x12,0x13,0x12,0x13,0x10,
+0x10,0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,0x90,0x08,0x00,0xfc,0x00,
+/* 26938 0x693a "椺" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x2a,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x23,0x22,0x22,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 26939 0x693b "椻" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x53,0x92,0x12,0x12,0x12,0x12,0x13,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 26940 0x693c "椼" */
+0x10,0x10,0x11,0x12,0xfc,0x10,0x31,0x3b,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0x8e,0x20,0x10,0xc0,0xae,0x04,0x14,0x24,0x64,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 26941 0x693d "椽" */
+0x21,0x21,0x22,0x23,0xf8,0x27,0x20,0x71,0x6e,0xa0,0xa1,0x26,0x20,0x21,0x26,0x20,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 26942 0x693e "椾" */
+0x11,0x10,0x10,0x17,0xf8,0x13,0x32,0x3a,0x57,0x52,0x92,0x13,0x12,0x12,0x12,0x12,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 26943 0x693f "椿" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x52,0x90,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 26944 0x6940 "楀" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x54,0x53,0x92,0x12,0x12,0x12,0x12,0x12,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 26945 0x6941 "楁" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x31,0x3a,0x54,0x51,0x96,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 26946 0x6942 "楂" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x32,0x39,0x55,0x51,0x91,0x11,0x11,0x10,0x13,0x10,
+0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 26947 0x6943 "楃" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x33,0x3a,0x56,0x53,0x92,0x12,0x15,0x14,0x18,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 26948 0x6944 "楄" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x57,0x53,0x95,0x15,0x15,0x15,0x19,0x11,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0x52,0x52,0xfe,0x52,0x52,0x52,0x06,
+/* 26949 0x6945 "楅" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 26950 0x6946 "楆" */
+0x10,0x13,0x10,0x10,0xfb,0x12,0x32,0x3b,0x54,0x50,0x97,0x10,0x11,0x10,0x10,0x13,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 26951 0x6947 "楇" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x3b,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 26952 0x6948 "楈" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x3a,0x34,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 26953 0x6949 "楉" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x91,0x12,0x10,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 26954 0x694a "楊" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x3b,0x55,0x51,0x92,0x14,0x11,0x12,0x10,0x11,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 26955 0x694b "楋" */
+0x10,0x10,0x17,0x10,0xfc,0x13,0x32,0x3a,0x57,0x50,0x91,0x12,0x14,0x10,0x10,0x10,
+0x82,0x82,0xf2,0x82,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xaa,0xa2,0x82,0x8a,0x84,
+/* 26956 0x694c "楌" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x19,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x10,0x20,0xc8,0x10,0x24,0xc8,0x10,0x60,0x80,
+/* 26957 0x694d "楍" */
+0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,
+/* 26958 0x694e "楎" */
+0x10,0x13,0x12,0x10,0xfd,0x10,0x31,0x39,0x55,0x55,0x91,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 26959 0x694f "楏" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x31,0x38,0x54,0x53,0x90,0x10,0x11,0x10,0x10,0x13,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 26960 0x6950 "楐" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x51,0x92,0x10,0x10,0x10,0x11,0x12,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,
+/* 26961 0x6951 "楑" */
+0x10,0x13,0x10,0x12,0xfd,0x10,0x31,0x3a,0x54,0x50,0x93,0x10,0x10,0x10,0x11,0x12,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 26962 0x6952 "楒" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x54,0x90,0x12,0x12,0x14,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 26963 0x6953 "楓" */
+0x20,0x27,0x24,0x24,0xfd,0x24,0x25,0x75,0x6d,0xa5,0xa4,0x24,0x25,0x24,0x28,0x30,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 26964 0x6954 "楔" */
+0x21,0x21,0x27,0x21,0xfb,0x21,0x27,0x71,0x69,0xa0,0xa7,0x20,0x20,0x21,0x22,0x2c,
+0x00,0x3c,0xd4,0x14,0x94,0x14,0xd4,0x24,0x4c,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 26965 0x6955 "楕" */
+0x10,0x10,0x13,0x10,0xfd,0x12,0x35,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 26966 0x6956 "楖" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x56,0x53,0x92,0x12,0x12,0x12,0x13,0x10,
+0x00,0xde,0x52,0x52,0x52,0xd2,0x52,0x52,0x52,0xd2,0x1a,0x94,0x50,0xb0,0x10,0x10,
+/* 26967 0x6957 "楗" */
+0x20,0x20,0x20,0x2e,0xfb,0x22,0x24,0x74,0x6e,0xa2,0xa2,0x2b,0x24,0x26,0x29,0x30,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfe,0x00,
+/* 26968 0x6958 "楘" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x99,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0x7e,0x84,0x28,0x10,0x28,0x44,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 26969 0x6959 "楙" */
+0x20,0x27,0x20,0x22,0xf9,0x21,0x27,0x71,0x6b,0xa3,0xa5,0x25,0x29,0x21,0x25,0x22,
+0x08,0x88,0x88,0x88,0x3e,0x08,0xd8,0x5c,0x2c,0x2a,0x48,0x08,0x08,0x08,0x08,0x08,
+/* 26970 0x695a "楚" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x00,0x7f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x24,0x00,0xfc,0x04,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 26971 0x695b "楛" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 26972 0x695c "楜" */
+0x21,0x21,0x21,0x27,0xf9,0x21,0x21,0x77,0x6c,0xa4,0xa4,0x27,0x24,0x20,0x20,0x20,
+0x00,0x1e,0x12,0xd2,0x12,0x1e,0x12,0xd2,0x52,0x5e,0x52,0xd2,0x52,0x22,0x2a,0x44,
+/* 26973 0x695d "楝" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x10,0x11,0x12,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 26974 0x695e "楞" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x30,0x38,0x57,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x94,0x94,0x94,0xfc,0x80,0x40,0xfe,0x80,0xf8,0x88,0x08,0x08,0x28,0x10,
+/* 26975 0x695f "楟" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x39,0x34,0x53,0x52,0x91,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 26976 0x6960 "楠" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 26977 0x6961 "楡" */
+0x11,0x10,0x11,0x12,0xfd,0x10,0x33,0x3a,0x56,0x53,0x92,0x12,0x13,0x12,0x12,0x12,
+0xc0,0xa0,0x10,0x08,0xf6,0x00,0xca,0x4a,0x54,0xd4,0x68,0x54,0xd4,0x4a,0x4a,0xc0,
+/* 26978 0x6962 "楢" */
+0x11,0x10,0x10,0x17,0xf8,0x10,0x33,0x3a,0x56,0x53,0x92,0x13,0x12,0x12,0x13,0x12,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 26979 0x6963 "楣" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x14,0x18,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 26980 0x6964 "楤" */
+0x10,0x10,0x10,0x11,0xfa,0x10,0x31,0x3a,0x54,0x51,0x90,0x10,0x12,0x12,0x14,0x10,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 26981 0x6965 "楥" */
+0x10,0x17,0x12,0x11,0xfc,0x13,0x30,0x38,0x57,0x55,0x91,0x12,0x12,0x14,0x18,0x13,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 26982 0x6966 "楦" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 26983 0x6967 "楧" */
+0x21,0x21,0x27,0x21,0xf9,0x20,0x23,0x72,0x6a,0xa2,0xa7,0x20,0x20,0x21,0x22,0x24,
+0x10,0x10,0xfc,0x10,0x50,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 26984 0x6968 "楨" */
+0x10,0x10,0x10,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x11,0x12,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 26985 0x6969 "楩" */
+0x21,0x21,0x21,0x22,0xfa,0x22,0x26,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x22,0x22,
+0x00,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x90,0x50,0x20,0x58,0x86,
+/* 26986 0x696a "楪" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x31,0x39,0x55,0x54,0x93,0x10,0x10,0x11,0x16,0x10,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 26987 0x696b "楫" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x37,0x39,0x55,0x55,0x91,0x11,0x11,0x17,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 26988 0x696c "楬" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x38,0x35,0x52,0x51,0x91,0x11,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 26989 0x696d "業" */
+0x04,0x24,0x14,0xff,0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x48,0x50,0xfe,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 26990 0x696e "楮" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x38,0x54,0x51,0x92,0x10,0x10,0x10,0x10,0x10,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 26991 0x696f "楯" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x72,0x6a,0xa2,0xa2,0x22,0x24,0x24,0x28,0x20,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 26992 0x6970 "楰" */
+0x10,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x24,0x50,0x50,0x88,0x04,0x02,
+/* 26993 0x6971 "楱" */
+0x20,0x20,0x27,0x20,0xfb,0x20,0x27,0x71,0x6a,0xa5,0xa0,0x23,0x20,0x20,0x21,0x26,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x40,0xf8,0x40,0xa0,0x10,0x08,
+/* 26994 0x6972 "楲" */
+0x20,0x20,0x27,0x24,0xfc,0x27,0x24,0x74,0x6f,0xa5,0xa5,0x24,0x25,0x2a,0x28,0x30,
+0x14,0x12,0xfe,0x10,0x10,0xf0,0x92,0x92,0xd2,0x54,0x54,0x88,0x4a,0x1a,0x26,0x42,
+/* 26995 0x6973 "楳" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x54,0x54,0x93,0x10,0x10,0x11,0x12,0x10,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 26996 0x6974 "楴" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x33,0x3a,0x54,0x55,0x91,0x11,0x11,0x11,0x10,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 26997 0x6975 "極" */
+0x10,0x13,0x10,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x93,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x08,0x10,0x20,0xae,0xa2,0xaa,0xa4,0xa4,0xaa,0x32,0xa0,0x40,0xfe,0x00,
+/* 26998 0x6976 "楶" */
+0x41,0x21,0x0a,0x10,0xe0,0x21,0x26,0x1f,0x10,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0xfc,0x44,0x48,0xa0,0x10,0x08,0xf4,0x10,0xf0,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 26999 0x6977 "楷" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 27000 0x6978 "楸" */
+0x20,0x21,0x27,0x21,0xf9,0x21,0x27,0x71,0x6b,0xa3,0xa5,0x25,0x29,0x21,0x21,0x21,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 27001 0x6979 "楹" */
+0x10,0x13,0x11,0x11,0xfd,0x12,0x32,0x3a,0x54,0x51,0x93,0x12,0x12,0x12,0x17,0x10,
+0x00,0xf8,0x08,0x10,0x1c,0xe4,0xa4,0x54,0xa8,0x00,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 27002 0x697a "楺" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x38,0x35,0x52,0x50,0x91,0x10,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27003 0x697b "楻" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x39,0x34,0x53,0x50,0x90,0x11,0x10,0x10,0x13,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 27004 0x697c "楼" */
+0x20,0x21,0x20,0x20,0xfb,0x20,0x21,0x72,0x68,0xa7,0xa0,0x21,0x21,0x20,0x21,0x26,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 27005 0x697d "楽" */
+0x01,0x42,0x27,0x14,0x04,0x17,0x24,0xc4,0x07,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x04,0xc8,0x50,0x40,0xd0,0x48,0x44,0xc0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27006 0x697e "楾" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x53,0x90,0x11,0x11,0x12,0x14,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 27007 0x697f "楿" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x3a,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 27008 0x6980 "榀" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x38,0x54,0x53,0x92,0x12,0x12,0x12,0x13,0x12,
+0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,0x00,0xde,0x52,0x52,0x52,0x52,0xde,0x52,
+/* 27009 0x6981 "榁" */
+0x10,0x10,0x11,0x11,0xfe,0x11,0x30,0x38,0x55,0x54,0x90,0x11,0x10,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 27010 0x6982 "概" */
+0x20,0x27,0x24,0x24,0xff,0x24,0x24,0x77,0x6c,0xa5,0xa4,0x25,0x26,0x24,0x20,0x20,
+0x00,0xbe,0x88,0x88,0xa8,0xa8,0xa8,0xbe,0x10,0x18,0x98,0xa8,0xaa,0x4a,0x46,0x80,
+/* 27011 0x6983 "榃" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x26,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 27012 0x6984 "榄" */
+0x10,0x12,0x12,0x12,0xfe,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x11,0x16,
+0x90,0x90,0x9e,0xa8,0xc4,0x80,0xfc,0x04,0x24,0x24,0x24,0x54,0x50,0x90,0x12,0x0e,
+/* 27013 0x6985 "榅" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x53,0x92,0x12,0x12,0x12,0x17,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 27014 0x6986 "榆" */
+0x10,0x10,0x11,0x12,0xfd,0x10,0x33,0x3a,0x56,0x53,0x92,0x12,0x13,0x12,0x12,0x12,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 27015 0x6987 "榇" */
+0x10,0x10,0x11,0x10,0xfc,0x10,0x33,0x38,0x54,0x55,0x90,0x10,0x11,0x12,0x10,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 27016 0x6988 "榈" */
+0x11,0x10,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xbc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x04,0xf4,0x94,0x94,0xf4,0x04,0x14,0x08,
+/* 27017 0x6989 "榉" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x3a,0x54,0x50,0x90,0x13,0x10,0x10,0x10,0x10,
+0x44,0x24,0x88,0x10,0xfe,0x88,0x24,0x22,0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 27018 0x698a "榊" */
+0x12,0x11,0x11,0x10,0xfb,0x10,0x30,0x39,0x55,0x53,0x95,0x11,0x11,0x11,0x11,0x11,
+0x08,0x08,0x08,0x3e,0xaa,0xaa,0xbe,0x2a,0xaa,0x6a,0x3e,0x2a,0x08,0x08,0x08,0x08,
+/* 27019 0x698b "榋" */
+0x10,0x11,0x10,0x10,0xfc,0x11,0x30,0x38,0x57,0x54,0x90,0x13,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xde,0x42,0x42,0xde,0x42,0x42,0xde,0x42,
+/* 27020 0x698c "榌" */
+0x10,0x13,0x10,0x10,0xfb,0x11,0x31,0x39,0x57,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfa,0x0c,0x4a,0x88,0x2a,0x26,0x22,0xf8,0x2a,0x2c,0x2a,0x28,0x2a,0x26,0x22,
+/* 27021 0x698d "榍" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x24,0x24,0x28,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x54,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x8a,0x84,
+/* 27022 0x698e "榎" */
+0x13,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x11,0x12,0x10,0x11,0x16,
+0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 27023 0x698f "榏" */
+0x11,0x10,0x10,0x10,0xfb,0x10,0x30,0x39,0x56,0x51,0x91,0x11,0x11,0x11,0x17,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 27024 0x6990 "榐" */
+0x10,0x13,0x12,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x93,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x04,0x04,0xfc,0x48,0x48,0xfc,0x48,0x48,0xfe,0xa4,0xa8,0x90,0xc8,0x86,
+/* 27025 0x6991 "榑" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x13,0x10,0x10,0x10,0x10,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 27026 0x6992 "榒" */
+0x10,0x13,0x10,0x10,0xfb,0x12,0x32,0x3b,0x54,0x52,0x91,0x11,0x12,0x10,0x12,0x11,
+0x00,0xde,0x42,0x42,0xde,0x10,0x10,0xde,0x42,0x52,0x4a,0x4a,0x52,0x42,0x94,0x08,
+/* 27027 0x6993 "榓" */
+0x20,0x20,0x20,0x22,0xfa,0x24,0x21,0x76,0x68,0xa3,0xa2,0x22,0x22,0x22,0x27,0x20,
+0x40,0x28,0x90,0xa4,0xc2,0x8a,0x88,0x78,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 27028 0x6994 "榔" */
+0x11,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x57,0x52,0x92,0x12,0x12,0x13,0x12,0x10,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 27029 0x6995 "榕" */
+0x10,0x10,0x13,0x12,0xfc,0x10,0x31,0x38,0x54,0x51,0x92,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 27030 0x6996 "榖" */
+0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0xbe,0x00,0x08,0x7e,0x18,0x2c,0x4a,0x88,0x09,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27031 0x6997 "榗" */
+0x10,0x13,0x10,0x12,0xfd,0x10,0x37,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 27032 0x6998 "榘" */
+0x20,0x20,0x3e,0x48,0x88,0x7e,0x14,0x22,0x40,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x80,0xf8,0x88,0xf8,0x80,0xfc,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27033 0x6999 "榙" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x38,0x35,0x52,0x50,0x90,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 27034 0x699a "榚" */
+0x11,0x10,0x10,0x10,0xfb,0x10,0x30,0x39,0x54,0x50,0x93,0x10,0x12,0x12,0x14,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 27035 0x699b "榛" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x3b,0x34,0x51,0x52,0x90,0x11,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 27036 0x699c "榜" */
+0x10,0x10,0x13,0x11,0xfc,0x13,0x32,0x3c,0x54,0x53,0x90,0x10,0x10,0x11,0x11,0x12,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 27037 0x699d "榝" */
+0x20,0x24,0x22,0x21,0xfa,0x24,0x21,0x71,0x6f,0xa1,0xa5,0x25,0x29,0x21,0x25,0x22,
+0x00,0x5c,0x94,0x14,0x94,0x54,0x26,0x00,0xdc,0x14,0x94,0x54,0x48,0x08,0x14,0x22,
+/* 27038 0x699e "榞" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 27039 0x699f "榟" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x30,0x38,0x57,0x50,0x90,0x11,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x42,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 27040 0x69a0 "榠" */
+0x10,0x13,0x12,0x10,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x13,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 27041 0x69a1 "榡" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x54,0x55,0x90,0x13,0x10,0x11,0x12,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 27042 0x69a2 "榢" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x30,0x38,0x57,0x54,0x90,0x13,0x10,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 27043 0x69a3 "榣" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x31,0x3a,0x54,0x53,0x90,0x11,0x11,0x11,0x11,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 27044 0x69a4 "榤" */
+0x22,0x22,0x23,0x24,0xfa,0x21,0x22,0x74,0x68,0xa7,0xa0,0x21,0x22,0x2c,0x20,0x20,
+0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x48,0x48,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 27045 0x69a5 "榥" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x39,0x54,0x50,0x93,0x10,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 27046 0x69a6 "榦" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x46,0x7c,0x45,0x7c,0x10,0xfe,0x10,0x11,0x12,0x10,
+0x20,0x20,0x50,0x50,0x88,0x04,0x22,0x20,0xfc,0x60,0x70,0xa8,0xa4,0x24,0x20,0x20,
+/* 27047 0x69a7 "榧" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x28,0x28,0xee,0x28,0x28,0xee,0x28,0x28,0xee,0x28,0x28,0x28,0xfe,0x00,
+/* 27048 0x69a8 "榨" */
+0x10,0x10,0x13,0x12,0xfd,0x10,0x30,0x39,0x56,0x50,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x8a,0x04,0x80,0xfe,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 27049 0x69a9 "榩" */
+0x10,0x10,0x10,0x13,0xfe,0x12,0x33,0x3a,0x56,0x52,0x93,0x12,0x12,0x14,0x14,0x19,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x40,0x20,0xfe,0x88,0x50,0x20,0x58,0x86,
+/* 27050 0x69aa "榪" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x50,0x92,0x12,0x12,0x12,0x10,0x10,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 27051 0x69ab "榫" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x13,0x10,0x10,0x10,0x10,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 27052 0x69ac "榬" */
+0x10,0x10,0x11,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x90,0x10,0x11,0x16,0x10,0x10,
+0x20,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x52,0x94,0x88,0xa4,0xc2,0x80,
+/* 27053 0x69ad "榭" */
+0x20,0x21,0x23,0x22,0xfb,0x22,0x33,0x6a,0x62,0xa7,0xa0,0x21,0x22,0x24,0x21,0x20,
+0x84,0x04,0xc4,0x44,0xde,0x44,0xc4,0x64,0x54,0xd4,0xc4,0x44,0x44,0x44,0x54,0x88,
+/* 27054 0x69ae "榮" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x81,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 27055 0x69af "榯" */
+0x20,0x20,0x27,0x25,0xfd,0x25,0x25,0x77,0x6d,0xa5,0xa5,0x25,0x27,0x20,0x20,0x20,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 27056 0x69b0 "榰" */
+0x10,0x10,0x11,0x10,0xfb,0x10,0x30,0x39,0x56,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 27057 0x69b1 "榱" */
+0x20,0x20,0x27,0x20,0xfb,0x22,0x2f,0x72,0x6b,0xa0,0xa1,0x23,0x25,0x29,0x21,0x21,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xfe,0x08,0xf8,0xa4,0x28,0x10,0x10,0x48,0x86,0x00,
+/* 27058 0x69b2 "榲" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x23,0x70,0x68,0xa7,0xa4,0x24,0x24,0x24,0x2f,0x20,
+0x00,0xf8,0x48,0xa8,0x18,0x08,0xf8,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 27059 0x69b3 "榳" */
+0x20,0x20,0x23,0x22,0xfa,0x22,0x22,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x24,0x24,0x29,
+0x40,0x20,0xfe,0x02,0xec,0x24,0x44,0x44,0xee,0x24,0xa4,0xa4,0x4e,0x60,0x9e,0x00,
+/* 27060 0x69b4 "榴" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x33,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 27061 0x69b5 "榵" */
+0x11,0x11,0x17,0x11,0xf8,0x17,0x31,0x39,0x55,0x51,0x91,0x11,0x17,0x10,0x10,0x10,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,0x08,
+/* 27062 0x69b6 "榶" */
+0x10,0x10,0x13,0x12,0xfa,0x12,0x33,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x20,0x10,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 27063 0x69b7 "榷" */
+0x10,0x10,0x17,0x15,0xfd,0x13,0x36,0x3a,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x80,0x80,0xfe,0x22,0x10,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 27064 0x69b8 "榸" */
+0x11,0x11,0x11,0x11,0xf9,0x17,0x31,0x39,0x55,0x51,0x91,0x11,0x17,0x12,0x10,0x10,
+0x00,0x3e,0x2a,0x2a,0x3e,0xaa,0x2a,0x3e,0x08,0x08,0x3e,0x88,0x08,0x08,0x7e,0x00,
+/* 27065 0x69b9 "榹" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x15,0x1a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 27066 0x69ba "榺" */
+0x00,0x3d,0x24,0x24,0x25,0x3c,0x27,0x24,0x25,0x3e,0x25,0x24,0x24,0x45,0x56,0x88,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x70,0xa8,0x24,0x24,0x20,
+/* 27067 0x69bb "榻" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x38,0x34,0x53,0x50,0x92,0x11,0x12,0x10,0x11,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 27068 0x69bc "榼" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x39,0x57,0x54,0x93,0x12,0x12,0x12,0x17,0x10,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 27069 0x69bd "榽" */
+0x10,0x17,0x12,0x11,0xfc,0x11,0x33,0x38,0x55,0x53,0x90,0x10,0x17,0x10,0x11,0x16,
+0x3c,0xc0,0x44,0x28,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x40,0xfc,0xa0,0x10,0x0e,
+/* 27070 0x69be "榾" */
+0x10,0x11,0x11,0x11,0xfd,0x13,0x32,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0xe4,0x24,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 27071 0x69bf "榿" */
+0x10,0x11,0x11,0x11,0xfd,0x10,0x33,0x38,0x55,0x55,0x91,0x11,0x10,0x10,0x13,0x10,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 27072 0x69c0 "槀" */
+0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x01,0xff,0x09,0x71,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xec,0x00,0xfe,0x20,0x1c,
+/* 27073 0x69c1 "槁" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x38,0x57,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 27074 0x69c2 "槂" */
+0x20,0x2f,0x21,0x21,0xfa,0x22,0x33,0x6a,0x66,0xaa,0xa2,0x22,0x22,0x22,0x2a,0x24,
+0x06,0x78,0x10,0x20,0x44,0x78,0x10,0x24,0x7e,0x12,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 27075 0x69c3 "槃" */
+0x10,0x3e,0x22,0x2a,0xfe,0x23,0x2a,0x42,0x4a,0x84,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27076 0x69c4 "槄" */
+0x10,0x13,0x10,0x12,0xfd,0x11,0x30,0x3b,0x56,0x52,0x93,0x12,0x12,0x12,0x13,0x12,
+0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 27077 0x69c5 "槅" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 27078 0x69c6 "槆" */
+0x11,0x11,0x17,0x11,0xfa,0x13,0x34,0x3b,0x56,0x53,0x92,0x13,0x12,0x10,0x10,0x10,
+0x10,0x10,0xfe,0x10,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 27079 0x69c7 "槇" */
+0x11,0x11,0x11,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x18,0xe0,0x02,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x88,0x04,
+/* 27080 0x69c8 "槈" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x13,0x12,0x14,0x14,0x18,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 27081 0x69c9 "槉" */
+0x10,0x10,0x11,0x11,0xf9,0x15,0x33,0x39,0x55,0x53,0x95,0x11,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x00,0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 27082 0x69ca "槊" */
+0x22,0x14,0xff,0x08,0x49,0x49,0x7f,0x08,0x10,0x21,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x94,0x08,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27083 0x69cb "構" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x55,0x91,0x11,0x13,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 27084 0x69cc "槌" */
+0x10,0x12,0x11,0x11,0xfc,0x10,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x14,0x10,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 27085 0x69cd "槍" */
+0x10,0x10,0x10,0x10,0xfd,0x13,0x35,0x39,0x55,0x51,0x91,0x11,0x12,0x12,0x14,0x10,
+0x20,0x20,0x50,0xc8,0x24,0xfe,0x04,0xfc,0x04,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 27086 0x69ce "槎" */
+0x11,0x10,0x10,0x13,0xfc,0x11,0x30,0x3b,0x54,0x55,0x91,0x12,0x14,0x18,0x13,0x10,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 27087 0x69cf "槏" */
+0x10,0x10,0x10,0x13,0xfc,0x11,0x30,0x3b,0x54,0x55,0x90,0x10,0x11,0x12,0x10,0x10,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 27088 0x69d0 "槐" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x11,0x11,0x12,0x14,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xb0,0xa4,0x3c,0x22,0x22,0x1e,
+/* 27089 0x69d1 "槑" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfd,0x30,0x38,0x54,0x51,0x92,0x10,0x10,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 27090 0x69d2 "槒" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x30,0x38,0x55,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x40,0x88,0xf0,0x20,0x44,0xfe,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 27091 0x69d3 "槓" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x10,0x11,0x12,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 27092 0x69d4 "槔" */
+0x10,0x10,0x13,0x12,0xfb,0x12,0x33,0x38,0x57,0x51,0x92,0x14,0x1b,0x10,0x10,0x10,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xfc,0x10,0x48,0x44,0xfa,0x40,0x40,0x40,
+/* 27093 0x69d5 "槕" */
+0x10,0x10,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x50,0x93,0x10,0x10,0x11,0x12,0x10,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27094 0x69d6 "槖" */
+0x01,0x7f,0x01,0x1f,0x00,0x7f,0x40,0xbf,0x08,0x1f,0x68,0x0f,0x01,0xff,0x09,0x71,
+0x00,0xfc,0x00,0xf0,0x00,0xfe,0x02,0xf4,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x1c,
+/* 27095 0x69d7 "槗" */
+0x10,0x10,0x17,0x10,0xfd,0x12,0x34,0x38,0x57,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x40,0x40,0xfe,0x80,0xf8,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 27096 0x69d8 "様" */
+0x11,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x54,0x90,0x10,0x11,0x16,0x10,0x10,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,
+/* 27097 0x69d9 "槙" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x13,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 27098 0x69da "槚" */
+0x10,0x13,0x10,0x13,0xfe,0x12,0x33,0x38,0x55,0x55,0x91,0x11,0x11,0x10,0x10,0x13,
+0x00,0xfe,0x50,0xfe,0x52,0x52,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 27099 0x69db "槛" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x17,0x10,
+0x48,0x48,0x4e,0x50,0x68,0x44,0x44,0x40,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 27100 0x69dc "槜" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x31,0x39,0x55,0x51,0x93,0x10,0x10,0x11,0x12,0x14,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 27101 0x69dd "槝" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x10,0x12,0x13,0x10,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x42,0x4a,0xfa,0x14,0x08,
+/* 27102 0x69de "槞" */
+0x10,0x10,0x17,0x11,0xf8,0x17,0x30,0x3b,0x56,0x53,0x92,0x13,0x12,0x10,0x10,0x10,
+0x80,0x40,0xfc,0x10,0xa0,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x4a,0x42,0x3e,0x00,
+/* 27103 0x69df "槟" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x31,0x39,0x55,0x51,0x91,0x17,0x10,0x10,0x11,0x12,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 27104 0x69e0 "槠" */
+0x20,0x24,0x22,0x22,0xf8,0x21,0x2e,0x72,0x6a,0xa3,0xa2,0x22,0x22,0x23,0x22,0x20,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0xc4,0x44,0x7c,0x44,
+/* 27105 0x69e1 "槡" */
+0x11,0x10,0x10,0x11,0xfc,0x13,0x32,0x39,0x56,0x50,0x93,0x10,0x10,0x11,0x16,0x10,
+0xf8,0x88,0x70,0x8c,0x00,0xde,0x52,0x8c,0x52,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27106 0x69e2 "槢" */
+0x10,0x13,0x10,0x12,0xfd,0x12,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 27107 0x69e3 "槣" */
+0x10,0x10,0x13,0x12,0xfc,0x11,0x30,0x38,0x57,0x54,0x91,0x11,0x11,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x20,0xfc,0x50,0x88,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x28,0x10,
+/* 27108 0x69e4 "槤" */
+0x10,0x10,0x12,0x11,0xfd,0x10,0x30,0x3b,0x55,0x51,0x91,0x11,0x11,0x12,0x14,0x10,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 27109 0x69e5 "槥" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x38,0x34,0x53,0x50,0x90,0x11,0x10,0x10,0x13,0x10,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 27110 0x69e6 "槦" */
+0x20,0x27,0x24,0x25,0xfc,0x27,0x24,0x75,0x6c,0xa5,0xa5,0x25,0x25,0x29,0x29,0x31,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 27111 0x69e7 "槧" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x01,0x7f,0x05,0x19,0xe1,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0xfc,0x40,0x30,0x0e,
+/* 27112 0x69e8 "槨" */
+0x22,0x21,0x27,0x20,0xf7,0x24,0x27,0x70,0x6f,0xa0,0xa1,0x21,0x27,0x21,0x25,0x22,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 27113 0x69e9 "槩" */
+0x00,0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x65,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0x0e,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27114 0x69ea "槪" */
+0x21,0x22,0x27,0x24,0xfc,0x27,0x24,0x74,0x6f,0xa0,0xa4,0x27,0x24,0x24,0x23,0x20,
+0x00,0x3e,0x88,0x88,0xa8,0xa8,0xbe,0x88,0x88,0x10,0x98,0x18,0x28,0xaa,0xca,0x86,
+/* 27115 0x69eb "槫" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x39,0x54,0x53,0x90,0x13,0x11,0x10,0x10,0x10,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 27116 0x69ec "槬" */
+0x22,0x22,0x2f,0x22,0xf5,0x28,0x27,0x70,0x6f,0xa4,0xa7,0x21,0x21,0x21,0x25,0x22,
+0x00,0x0e,0x74,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x54,0x54,0x52,0x54,0x5c,0x84,
+/* 27117 0x69ed "槭" */
+0x20,0x20,0x20,0x27,0xfc,0x24,0x24,0x74,0x6f,0xa4,0xa4,0x25,0x2a,0x28,0x31,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x90,0xd2,0x92,0xf2,0x94,0x94,0xc8,0xaa,0x9a,0xa6,0x42,
+/* 27118 0x69ee "槮" */
+0x10,0x10,0x11,0x11,0xfa,0x13,0x30,0x39,0x56,0x50,0x93,0x10,0x13,0x10,0x10,0x17,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 27119 0x69ef "槯" */
+0x10,0x12,0x13,0x10,0xfc,0x11,0x3b,0x35,0x51,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 27120 0x69f0 "槰" */
+0x20,0x24,0x22,0x21,0xf8,0x20,0x26,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 27121 0x69f1 "槱" */
+0x10,0x11,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x11,0x11,0x12,
+0x00,0xfe,0x48,0x48,0xfe,0x4a,0x4a,0x8e,0x02,0xfe,0x02,0xfe,0x00,0x54,0x2a,0x2a,
+/* 27122 0x69f2 "槲" */
+0x22,0x22,0x27,0x24,0xf9,0x27,0x25,0x75,0x6f,0xa5,0xa5,0x27,0x25,0x25,0x24,0x28,
+0x04,0x04,0x84,0x94,0x0c,0xc4,0x64,0x54,0xc4,0x46,0x7c,0xc4,0x44,0x44,0x44,0xc4,
+/* 27123 0x69f3 "槳" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x85,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27124 0x69f4 "槴" */
+0x10,0x10,0x13,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x93,0x13,0x15,0x15,0x19,0x10,
+0x40,0x20,0xfc,0x04,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x02,0x02,0xfe,
+/* 27125 0x69f5 "槵" */
+0x10,0x10,0x11,0x11,0xfd,0x10,0x33,0x3a,0x57,0x50,0x90,0x10,0x12,0x12,0x14,0x10,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x20,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 27126 0x69f6 "槶" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x27,0x76,0x6f,0xa4,0xa5,0x26,0x24,0x24,0x27,0x24,
+0x00,0xfe,0x2a,0x26,0xfe,0x22,0xaa,0xaa,0xaa,0x32,0x96,0x2e,0x46,0x82,0xfe,0x02,
+/* 27127 0x69f7 "槷" */
+0x08,0x3e,0x08,0x7f,0x22,0x49,0x3e,0x08,0x7e,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27128 0x69f8 "槸" */
+0x21,0x21,0x27,0x21,0xf9,0x27,0x20,0x72,0x6d,0xa1,0xa7,0x21,0x21,0x21,0x27,0x22,
+0x10,0x10,0xd0,0x10,0x3c,0xd4,0x14,0xb4,0x54,0x1c,0xd4,0x14,0x14,0xe4,0x26,0x42,
+/* 27129 0x69f9 "槹" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x38,0x55,0x54,0x91,0x10,0x13,0x10,0x10,0x10,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 27130 0x69fa "槺" */
+0x20,0x20,0x27,0x24,0xfd,0x24,0x27,0x74,0x6d,0xa4,0xa5,0x24,0x29,0x2a,0x30,0x20,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x62,0xb4,0x28,0x26,0xa0,0x40,
+/* 27131 0x69fb "槻" */
+0x22,0x22,0x22,0x27,0xfa,0x22,0x22,0x77,0x6a,0xa2,0xa2,0x22,0x25,0x25,0x28,0x30,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 27132 0x69fc "槼" */
+0x11,0x7d,0x11,0x11,0xfd,0x11,0x29,0x24,0x41,0x86,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x12,0x0e,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27133 0x69fd "槽" */
+0x10,0x10,0x17,0x10,0xfb,0x12,0x33,0x3a,0x57,0x50,0x91,0x11,0x11,0x11,0x11,0x11,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 27134 0x69fe "槾" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x3b,0x56,0x53,0x90,0x11,0x10,0x10,0x11,0x16,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 27135 0x69ff "槿" */
+0x10,0x10,0x17,0x10,0xfc,0x10,0x31,0x39,0x55,0x50,0x93,0x10,0x11,0x10,0x17,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 27136 0x6a00 "樀" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 27137 0x6a01 "樁" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x52,0x95,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0x42,0x9c,0x04,0xdc,0x04,0xfc,0x04,
+/* 27138 0x6a02 "樂" */
+0x21,0x22,0x47,0x94,0xe4,0x47,0x94,0xf4,0x17,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x04,0x04,0xc8,0x52,0x5c,0xc8,0x52,0x5e,0xc2,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27139 0x6a03 "樃" */
+0x11,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x57,0x52,0x92,0x12,0x12,0x13,0x12,0x10,
+0x00,0x9e,0xd2,0x52,0x52,0xde,0x52,0x52,0xd2,0x1e,0x92,0x52,0xd2,0x52,0x2a,0x44,
+/* 27140 0x6a04 "樄" */
+0x20,0x27,0x25,0x25,0xfd,0x26,0x25,0x75,0x6d,0xa5,0xa5,0x26,0x24,0x24,0x24,0x24,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 27141 0x6a05 "樅" */
+0x21,0x21,0x22,0x24,0xf9,0x21,0x22,0x76,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x22,0x23,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 27142 0x6a06 "樆" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x54,0x53,0x92,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 27143 0x6a07 "樇" */
+0x21,0x21,0x21,0x22,0xfa,0x26,0x2a,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x22,0x22,
+0x20,0x3c,0x44,0xa8,0x10,0xa8,0xc6,0xbc,0xa4,0xbc,0xa4,0xbc,0x24,0x24,0x24,0x2c,
+/* 27144 0x6a08 "樈" */
+0x20,0x20,0x23,0x21,0xf8,0x27,0x20,0x73,0x6a,0xa3,0xa2,0x23,0x21,0x21,0x22,0x2c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 27145 0x6a09 "樉" */
+0x10,0x10,0x13,0x10,0xfa,0x11,0x32,0x38,0x56,0x51,0x92,0x10,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfe,0x20,0xaa,0x24,0xaa,0x20,0xaa,0x24,0xaa,0x50,0x50,0x88,0x04,0x02,
+/* 27146 0x6a0a "樊" */
+0x24,0x22,0xf9,0x22,0x64,0x72,0xa9,0x22,0x25,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x48,0x88,0x3e,0x88,0x58,0x9c,0x2a,0x88,0x48,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 27147 0x6a0b "樋" */
+0x20,0x24,0x22,0x22,0xf8,0x20,0x2e,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x25,0x28,0x20,
+0xfe,0x04,0x28,0x10,0xfe,0x92,0x92,0xfe,0x92,0xfe,0x92,0x92,0x96,0x00,0xfe,0x00,
+/* 27148 0x6a0c "樌" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27149 0x6a0d "樍" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27150 0x6a0e "樎" */
+0x10,0x10,0x13,0x12,0xf8,0x10,0x31,0x3b,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x10,0xfe,0x02,0x80,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 27151 0x6a0f "樏" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x30,0x38,0x55,0x54,0x90,0x13,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 27152 0x6a10 "樐" */
+0x10,0x10,0x10,0x10,0xfc,0x13,0x32,0x3b,0x56,0x52,0x93,0x12,0x12,0x13,0x13,0x12,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x02,0x26,0x8a,0x52,0x26,0x52,0x8a,0x26,0xfe,0x02,
+/* 27153 0x6a11 "樑" */
+0x22,0x21,0x24,0x22,0xf8,0x21,0x22,0x70,0x68,0xa7,0xa0,0x21,0x22,0x2c,0x20,0x20,
+0x78,0x28,0x6c,0xaa,0x2a,0x48,0x98,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 27154 0x6a12 "樒" */
+0x10,0x10,0x13,0x12,0xfc,0x12,0x3a,0x34,0x50,0x53,0x90,0x11,0x11,0x11,0x11,0x10,
+0x40,0x20,0xfe,0x42,0x28,0x94,0xaa,0xca,0xf8,0x00,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 27155 0x6a13 "樓" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x30,0x39,0x55,0x55,0x90,0x13,0x10,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 27156 0x6a14 "樔" */
+0x11,0x12,0x11,0x10,0xfd,0x11,0x31,0x39,0x55,0x50,0x93,0x10,0x10,0x11,0x16,0x10,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27157 0x6a15 "樕" */
+0x21,0x21,0x27,0x21,0xf9,0x27,0x25,0x75,0x6f,0xa1,0xa3,0x25,0x29,0x21,0x21,0x21,
+0x08,0x08,0xc8,0x08,0x1e,0xd2,0x64,0x40,0xc8,0x08,0x88,0x48,0x54,0x14,0x24,0x42,
+/* 27158 0x6a16 "樖" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x00,0x13,0xfc,0x11,0x39,0x55,0x90,0x10,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x18,
+/* 27159 0x6a17 "樗" */
+0x11,0x10,0x13,0x12,0xfd,0x10,0x31,0x38,0x55,0x50,0x93,0x10,0x10,0x10,0x10,0x10,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,
+/* 27160 0x6a18 "樘" */
+0x10,0x11,0x10,0x13,0xfe,0x10,0x30,0x38,0x54,0x54,0x90,0x11,0x10,0x10,0x13,0x10,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 27161 0x6a19 "標" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x38,0x55,0x54,0x93,0x10,0x10,0x11,0x12,0x10,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 27162 0x6a1a "樚" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x57,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 27163 0x6a1b "樛" */
+0x20,0x27,0x20,0x24,0xfa,0x24,0x20,0x71,0x6e,0xa0,0xa3,0x20,0x23,0x20,0x20,0x27,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 27164 0x6a1c "樜" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x33,0x3a,0x56,0x52,0x92,0x12,0x15,0x15,0x1a,0x10,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 27165 0x6a1d "樝" */
+0x10,0x10,0x10,0x13,0xfe,0x12,0x33,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x19,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfe,
+/* 27166 0x6a1e "樞" */
+0x10,0x13,0x12,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x13,0x10,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 27167 0x6a1f "樟" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x10,0x13,0x10,0x10,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 27168 0x6a20 "樠" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x3b,0x56,0x53,0x92,0x13,0x12,0x12,0x12,0x12,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 27169 0x6a21 "模" */
+0x11,0x11,0x17,0x11,0xfc,0x13,0x32,0x3b,0x56,0x53,0x90,0x17,0x10,0x11,0x12,0x14,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 27170 0x6a22 "樢" */
+0x10,0x10,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x10,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 27171 0x6a23 "樣" */
+0x11,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x54,0x54,0x90,0x13,0x10,0x11,0x16,0x10,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x20,0x10,0xe0,0x22,0xb4,0xa8,0x24,0xa2,0x40,
+/* 27172 0x6a24 "樤" */
+0x21,0x21,0x21,0x22,0xf2,0x26,0x2a,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x22,0x22,
+0x10,0x1e,0x22,0x54,0x08,0x94,0xe2,0x88,0x88,0xbe,0x88,0xac,0x2a,0x4a,0x28,0x10,
+/* 27173 0x6a25 "樥" */
+0x10,0x13,0x10,0x10,0xfd,0x12,0x30,0x3b,0x54,0x55,0x90,0x11,0x10,0x13,0x10,0x10,
+0x88,0xfe,0x88,0x80,0xf8,0x88,0x70,0x8e,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 27174 0x6a26 "樦" */
+0x12,0x12,0x13,0x15,0xf8,0x10,0x30,0x3b,0x54,0x50,0x91,0x10,0x10,0x10,0x13,0x10,
+0x10,0x10,0xde,0x28,0x84,0x20,0x10,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 27175 0x6a27 "樧" */
+0x20,0x24,0x22,0x21,0xfa,0x24,0x20,0x71,0x69,0xa7,0xa1,0x23,0x25,0x29,0x21,0x21,
+0x00,0x5c,0x94,0x14,0x94,0x14,0xa6,0x40,0x1c,0xd4,0x14,0x94,0x48,0x08,0x14,0x22,
+/* 27176 0x6a28 "樨" */
+0x20,0x23,0x22,0x23,0xfa,0x22,0x22,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x25,0x24,0x28,
+0x00,0xfe,0x02,0xfe,0x10,0x54,0x38,0x54,0x82,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,
+/* 27177 0x6a29 "権" */
+0x10,0x10,0x11,0x12,0xfc,0x13,0x38,0x35,0x53,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xfe,0x20,0x40,0xfe,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 27178 0x6a2a "横" */
+0x11,0x11,0x13,0xfd,0x11,0x17,0x30,0x3b,0x56,0x53,0x92,0x13,0x10,0x11,0x12,0x14,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0x10,0x08,0x04,
+/* 27179 0x6a2b "樫" */
+0x20,0x27,0x25,0x27,0xfc,0x27,0x25,0x75,0x6f,0xa0,0xa0,0x27,0x20,0x20,0x2f,0x20,
+0x00,0xdc,0x14,0xd4,0x54,0xc8,0x08,0x14,0xe2,0x00,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 27180 0x6a2c "樬" */
+0x10,0x10,0x13,0x12,0xfe,0x13,0x32,0x3a,0x56,0x53,0x90,0x10,0x15,0x15,0x19,0x10,
+0x40,0x80,0xfc,0x44,0xf4,0x14,0xa4,0x44,0xa4,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 27181 0x6a2d "樭" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x30,0x38,0x57,0x50,0x91,0x12,0x10,0x10,0x13,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x24,0xfa,0x20,0x20,0xfe,0x00,
+/* 27182 0x6a2e "樮" */
+0x10,0x13,0x10,0x10,0xfb,0x12,0x32,0x3b,0x54,0x51,0x91,0x12,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 27183 0x6a2f "樯" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 27184 0x6a30 "樰" */
+0x10,0x11,0x10,0x13,0xfe,0x11,0x30,0x39,0x54,0x55,0x90,0x11,0x10,0x10,0x11,0x10,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 27185 0x6a31 "樱" */
+0x20,0x2f,0x28,0x2a,0xfa,0x2a,0x25,0x78,0x68,0xaf,0xa1,0x22,0x23,0x20,0x21,0x2e,
+0x00,0xbe,0xa2,0xaa,0xaa,0xaa,0x14,0xa2,0x80,0xfe,0x10,0x10,0xa0,0x60,0x98,0x04,
+/* 27186 0x6a32 "樲" */
+0x10,0x17,0x10,0x13,0xfc,0x13,0x30,0x3b,0x56,0x53,0x92,0x13,0x12,0x13,0x11,0x12,
+0x14,0xfe,0x10,0xd0,0x10,0xd0,0x10,0xd0,0x50,0xd0,0x50,0xc8,0x4a,0xca,0x86,0x42,
+/* 27187 0x6a33 "樳" */
+0x10,0x13,0x10,0x13,0xfc,0x13,0x30,0x3b,0x55,0x57,0x90,0x13,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 27188 0x6a34 "樴" */
+0x11,0x10,0x13,0x10,0xfa,0x11,0x37,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x10,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 27189 0x6a35 "樵" */
+0x10,0x10,0x11,0x11,0xfb,0x15,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 27190 0x6a36 "樶" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x38,0x37,0x52,0x53,0x92,0x13,0x12,0x17,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0xdc,0x54,0xd4,0x68,0xc8,0x54,0x62,
+/* 27191 0x6a37 "樷" */
+0x08,0x08,0x7e,0x18,0x2c,0x4a,0x88,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x27,0xfa,0x02,
+0x20,0x20,0xfc,0x30,0x68,0xa4,0x20,0x7c,0x44,0x44,0x28,0x28,0x10,0xa8,0x44,0x82,
+/* 27192 0x6a38 "樸" */
+0x10,0x12,0x11,0x10,0xfb,0x10,0x30,0x3b,0x54,0x51,0x90,0x13,0x10,0x10,0x11,0x16,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 27193 0x6a39 "樹" */
+0x21,0x21,0x2f,0x21,0xf9,0x27,0x20,0x77,0x6c,0xa4,0xa7,0x24,0x22,0x20,0x2f,0x24,
+0x04,0x04,0xe4,0x04,0x3e,0xc4,0x04,0xe4,0x54,0x54,0xc4,0x44,0x84,0xe4,0x14,0x08,
+/* 27194 0x6a3a "樺" */
+0x10,0x13,0x10,0x10,0xfd,0x10,0x30,0x3b,0x54,0x54,0x91,0x10,0x13,0x10,0x10,0x10,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 27195 0x6a3b "樻" */
+0x10,0x11,0x11,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27196 0x6a3c "樼" */
+0x27,0x24,0x27,0x24,0xfd,0x24,0x27,0x74,0x6c,0xa7,0xa4,0x25,0x29,0x2f,0x31,0x23,
+0xfc,0x04,0xfc,0x00,0xf8,0x10,0xfe,0x20,0x60,0x9c,0x84,0x08,0xde,0x08,0x08,0x18,
+/* 27197 0x6a3d "樽" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x13,0x11,0x10,0x10,0x10,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 27198 0x6a3e "樾" */
+0x21,0x21,0x21,0x27,0xf9,0x21,0x2f,0x71,0x69,0xa5,0xa5,0x25,0x27,0x25,0x24,0x28,
+0x14,0x12,0x12,0x90,0x7e,0x50,0xd4,0x54,0x54,0x48,0xea,0x56,0x22,0x00,0xfe,0x00,
+/* 27199 0x6a3f "樿" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x10,0x13,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 27200 0x6a40 "橀" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x30,0x38,0x55,0x52,0x91,0x11,0x11,0x11,0x13,0x10,
+0x40,0x20,0xfe,0x40,0x84,0xfe,0xa8,0xaa,0x26,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 27201 0x6a41 "橁" */
+0x11,0x11,0x11,0x12,0xfc,0x11,0x31,0x3a,0x55,0x51,0x91,0x11,0x11,0x11,0x10,0x10,
+0x10,0x10,0xde,0xa8,0x44,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x14,0x28,0x10,
+/* 27202 0x6a42 "橂" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x13,0x10,0x10,0x11,0x12,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 27203 0x6a43 "橃" */
+0x10,0x13,0x10,0x15,0xfa,0x14,0x33,0x38,0x54,0x53,0x92,0x13,0x10,0x10,0x12,0x11,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 27204 0x6a44 "橄" */
+0x20,0x27,0x20,0x21,0xff,0x24,0x24,0x77,0x6c,0xa7,0xa4,0x24,0x27,0x2c,0x20,0x20,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 27205 0x6a45 "橅" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x33,0x39,0x55,0x51,0x97,0x10,0x11,0x11,0x12,0x10,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 27206 0x6a46 "橆" */
+0x20,0x3f,0x52,0x92,0x7f,0x12,0x12,0xff,0x08,0x08,0x7e,0x18,0x2c,0x4a,0x89,0x08,
+0x00,0xfc,0x90,0x90,0xfc,0x90,0x90,0xfe,0x20,0x20,0xfc,0x20,0x70,0xa8,0x24,0x20,
+/* 27207 0x6a47 "橇" */
+0x10,0x13,0x10,0x13,0xfc,0x13,0x38,0x34,0x50,0x57,0x91,0x17,0x11,0x17,0x11,0x11,
+0x38,0xc0,0x78,0xc0,0x78,0xc4,0x3c,0x00,0xc6,0x38,0xce,0x38,0xce,0x38,0x4a,0x86,
+/* 27208 0x6a48 "橈" */
+0x10,0x10,0x11,0x10,0xfb,0x11,0x33,0x39,0x55,0x56,0x90,0x13,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 27209 0x6a49 "橉" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x32,0x39,0x55,0x51,0x92,0x15,0x10,0x11,0x12,0x14,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 27210 0x6a4a "橊" */
+0x10,0x13,0x10,0x13,0xfa,0x12,0x33,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x50,0xde,0x52,0x52,0xde,0x50,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 27211 0x6a4b "橋" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x32,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,0x11,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 27212 0x6a4c "橌" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x13,0x12,0x12,
+0xde,0x52,0xde,0x52,0xde,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 27213 0x6a4d "橍" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x22,0x72,0x22,0x22,0xfa,0x02,0x0a,0x04,
+/* 27214 0x6a4e "橎" */
+0x10,0x13,0x11,0x10,0xfb,0x10,0x31,0x3a,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 27215 0x6a4f "橏" */
+0x10,0x10,0x13,0x10,0xfd,0x10,0x33,0x39,0x54,0x53,0x90,0x11,0x11,0x11,0x11,0x11,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 27216 0x6a50 "橐" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x80,0x3f,0x04,0x1f,0x68,0x0f,0x01,0xff,0x09,0x71,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x02,0xf8,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x1c,
+/* 27217 0x6a51 "橑" */
+0x20,0x20,0x27,0xf8,0x25,0x22,0x77,0x6a,0xab,0xa2,0x23,0x20,0x22,0x24,0x29,0x20,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 27218 0x6a52 "橒" */
+0x10,0x11,0x10,0x13,0xfe,0x11,0x30,0x39,0x54,0x55,0x90,0x13,0x10,0x10,0x11,0x10,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x40,0x88,0xfc,0x84,
+/* 27219 0x6a53 "橓" */
+0x20,0x27,0x20,0xfa,0x21,0x27,0x74,0x6a,0xaa,0xa3,0x24,0x2a,0x21,0x22,0x24,0x28,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x02,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 27220 0x6a54 "橔" */
+0x22,0x21,0x2f,0x20,0xf7,0x24,0x27,0x70,0x6f,0xa0,0xa1,0x21,0x2f,0x21,0x25,0x22,
+0x10,0x10,0xd0,0x10,0xbe,0xa4,0xd4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 27221 0x6a55 "橕" */
+0x11,0x10,0x13,0x12,0xfc,0x10,0x30,0x38,0x55,0x54,0x91,0x11,0x10,0x10,0x13,0x10,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x00,0xfc,0x10,0x10,0xfe,0x50,0x90,0x10,0x30,
+/* 27222 0x6a56 "橖" */
+0x10,0x11,0x10,0x13,0xfe,0x10,0x30,0x38,0x54,0x50,0x93,0x10,0x10,0x11,0x12,0x10,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27223 0x6a57 "橗" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x32,0x3a,0x57,0x52,0x92,0x13,0x12,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x22,0x2a,0x44,
+/* 27224 0x6a58 "橘" */
+0x10,0x13,0x10,0x10,0xfb,0x10,0x30,0x3b,0x54,0x53,0x92,0x12,0x13,0x12,0x12,0x12,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 27225 0x6a59 "橙" */
+0x10,0x17,0x10,0x12,0xf9,0x12,0x35,0x38,0x57,0x52,0x92,0x13,0x12,0x11,0x1f,0x10,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 27226 0x6a5a "橚" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x30,0x3a,0x57,0x52,0x93,0x12,0x13,0x12,0x12,0x14,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 27227 0x6a5b "橛" */
+0x20,0x2f,0x28,0x2a,0xf9,0x2b,0x28,0x78,0x6a,0xaa,0xab,0x28,0x28,0x29,0x29,0x32,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 27228 0x6a5c "橜" */
+0x3f,0x28,0x25,0x3f,0x22,0x2a,0x2f,0x22,0x24,0x28,0x3f,0x21,0x22,0x44,0x58,0x80,
+0xfe,0x90,0x10,0xde,0x22,0x88,0x88,0x94,0x22,0x80,0xfe,0xc0,0xa0,0x98,0x86,0x80,
+/* 27229 0x6a5d "橝" */
+0x10,0x13,0x10,0x13,0xfe,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x10,0x13,0x10,0x10,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 27230 0x6a5e "橞" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x31,0x39,0x55,0x50,0x93,0x10,0x10,0x12,0x12,0x14,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 27231 0x6a5f "機" */
+0x11,0x11,0x12,0x13,0xf9,0x12,0x33,0x39,0x57,0x51,0x91,0x11,0x12,0x12,0x12,0x14,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 27232 0x6a60 "橠" */
+0x10,0x13,0x10,0x10,0xfb,0x10,0x33,0x38,0x55,0x50,0x90,0x13,0x10,0x11,0x16,0x10,
+0x20,0xfe,0x40,0xf8,0x48,0x30,0xd0,0x3c,0xc4,0x48,0x30,0xc4,0xa8,0x90,0xa8,0xc6,
+/* 27233 0x6a61 "橡" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x39,0x34,0x50,0x53,0x90,0x13,0x10,0x10,0x13,0x10,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 27234 0x6a62 "橢" */
+0x20,0x27,0x25,0x25,0xfd,0x26,0x25,0x75,0x6d,0xa5,0xa5,0x26,0x24,0x24,0x24,0x24,
+0x20,0x20,0xfe,0x40,0x7c,0x90,0x7e,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 27235 0x6a63 "橣" */
+0x20,0x20,0x2f,0x28,0xf5,0x25,0x28,0x70,0x6f,0xa4,0xa7,0x24,0x27,0x24,0x24,0x24,
+0x80,0x40,0xfe,0x82,0x48,0x14,0xf4,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x54,0x08,
+/* 27236 0x6a64 "橤" */
+0x01,0x24,0x24,0x43,0x00,0x24,0x12,0xa0,0xa4,0x1c,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x88,0x24,0xe4,0x00,0x24,0x12,0xa0,0xa4,0x1c,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27237 0x6a65 "橥" */
+0x28,0x11,0x28,0x4b,0x98,0x29,0x4e,0x88,0x28,0x10,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x22,0xfc,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27238 0x6a66 "橦" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x10,0x11,0x10,0x13,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 27239 0x6a67 "橧" */
+0x11,0x10,0x10,0x13,0xfe,0x12,0x32,0x3a,0x57,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 27240 0x6a68 "橨" */
+0x10,0x11,0x10,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x10,0x11,0x12,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 27241 0x6a69 "橩" */
+0x10,0x12,0x12,0x14,0xf9,0x12,0x33,0x3a,0x54,0x50,0x90,0x10,0x10,0x11,0x12,0x14,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0x00,0xf8,0x88,0x88,0x8a,0x0a,0x06,0x00,
+/* 27242 0x6a6a "橪" */
+0x11,0x11,0x11,0x12,0xfa,0x15,0x30,0x3a,0x55,0x51,0x92,0x14,0x10,0x12,0x12,0x14,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 27243 0x6a6b "橫" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x33,0x38,0x55,0x55,0x91,0x11,0x11,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0xf8,0x00,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x04,0x02,
+/* 27244 0x6a6c "橬" */
+0x10,0x13,0x10,0x12,0xfb,0x11,0x32,0x3c,0x55,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 27245 0x6a6d "橭" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x30,0x39,0x54,0x50,0x93,0x10,0x11,0x10,0x10,0x10,
+0x20,0xfe,0x20,0xfc,0x04,0xfc,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x20,
+/* 27246 0x6a6e "橮" */
+0x10,0x13,0x12,0x12,0xfe,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x40,0xbe,0x92,0x52,0xaa,0x24,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27247 0x6a6f "橯" */
+0x20,0x22,0x22,0x24,0xf9,0x22,0x20,0x73,0x6a,0xa4,0xa3,0x20,0x20,0x20,0x21,0x22,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 27248 0x6a70 "橰" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x31,0x39,0x54,0x55,0x90,0x11,0x10,0x13,0x10,0x10,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,
+/* 27249 0x6a71 "橱" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x25,0x75,0x6d,0xa5,0xa4,0x25,0x24,0x24,0x2b,0x20,
+0x00,0xfe,0x00,0x04,0xe4,0x04,0xde,0x44,0x44,0xd4,0x0c,0x44,0x84,0xe4,0x14,0x08,
+/* 27250 0x6a72 "橲" */
+0x10,0x13,0x10,0x11,0xfc,0x11,0x39,0x35,0x50,0x53,0x90,0x11,0x11,0x11,0x11,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 27251 0x6a73 "橳" */
+0x20,0x27,0x25,0x25,0xfd,0x27,0x25,0x75,0x6d,0xa7,0xa5,0x25,0x25,0x25,0x2b,0x20,
+0x10,0x54,0x38,0x10,0x7c,0x10,0xfe,0x28,0x24,0x52,0xfc,0x14,0x24,0x24,0x54,0x88,
+/* 27252 0x6a74 "橴" */
+0x10,0x10,0x12,0x12,0xfa,0x17,0x30,0x39,0x54,0x50,0x93,0x10,0x11,0x12,0x14,0x10,
+0x90,0x92,0xd4,0x9a,0xd2,0x4e,0x88,0xf0,0x20,0x44,0xfe,0x22,0x28,0x24,0xa2,0x40,
+/* 27253 0x6a75 "橵" */
+0x22,0x22,0x27,0x22,0xfa,0x27,0x20,0x77,0x6c,0xa7,0xa4,0x27,0x24,0x24,0x24,0x24,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 27254 0x6a76 "橶" */
+0x21,0x21,0x21,0x27,0xf9,0x27,0x24,0x77,0x6c,0xa7,0xa1,0x2f,0x21,0x21,0x21,0x21,
+0x10,0x14,0x12,0xd2,0x10,0xde,0x70,0xd2,0x52,0xd4,0x14,0xd8,0x0a,0x1a,0x26,0x42,
+/* 27255 0x6a77 "橷" */
+0x20,0x22,0x22,0x2e,0xf2,0x22,0x22,0x76,0x6a,0xa0,0xa1,0x21,0x21,0x22,0x24,0x28,
+0x40,0x88,0xea,0xaa,0xac,0xe8,0xaa,0xaa,0xe6,0x00,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 27256 0x6a78 "橸" */
+0x10,0x10,0x10,0x10,0xfc,0x10,0x30,0x38,0x57,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,
+/* 27257 0x6a79 "橹" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x39,0x35,0x50,0x53,0x90,0x11,0x11,0x11,0x11,0x11,
+0x80,0xf8,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,
+/* 27258 0x6a7a "橺" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 27259 0x6a7b "橻" */
+0x20,0x23,0x20,0x20,0xfb,0x20,0x20,0x77,0x68,0xa7,0xa2,0x22,0x27,0x22,0x22,0x2f,
+0x00,0xf8,0x48,0x48,0xf8,0x88,0x88,0xfc,0x00,0xbc,0x94,0x94,0xbc,0x94,0xd4,0x3e,
+/* 27260 0x6a7c "橼" */
+0x22,0x22,0x24,0x25,0xf9,0x2e,0x22,0x74,0x68,0xaf,0xa0,0x20,0x23,0x2c,0x20,0x20,
+0x20,0x3c,0x44,0x78,0x08,0xfe,0x20,0xd2,0x1a,0x2c,0xcc,0x1a,0x2a,0xc8,0x28,0x10,
+/* 27261 0x6a7d "橽" */
+0x10,0x12,0x11,0x10,0xfc,0x10,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x12,0x14,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 27262 0x6a7e "橾" */
+0x11,0x11,0x11,0x11,0xfc,0x13,0x32,0x3a,0x57,0x50,0x93,0x10,0x10,0x11,0x16,0x10,
+0xfc,0x04,0x04,0xfc,0x00,0xde,0x52,0x52,0xde,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27263 0x6a7f "橿" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x3b,0x54,0x55,0x91,0x11,0x11,0x11,0x10,0x13,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 27264 0x6a80 "檀" */
+0x20,0x2f,0x20,0x27,0xfc,0x25,0x25,0x77,0x68,0xa3,0xa2,0x23,0x22,0x23,0x20,0x2f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 27265 0x6a81 "檁" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x10,0x13,0x10,0x13,
+0x20,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x08,0xf0,0x20,0xfe,0xa8,0x26,
+/* 27266 0x6a82 "檂" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x30,0x3b,0x56,0x52,0x92,0x13,0x15,0x15,0x15,0x19,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 27267 0x6a83 "檃" */
+0x00,0x7b,0x49,0x53,0x60,0x53,0x48,0x4b,0x68,0x53,0x40,0x43,0x01,0xff,0x09,0x71,
+0x1e,0xe4,0x28,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x1c,
+/* 27268 0x6a84 "檄" */
+0x21,0x22,0x27,0x24,0xff,0x24,0x27,0x72,0x69,0xa7,0xa2,0x23,0x22,0x24,0x25,0x28,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 27269 0x6a85 "檅" */
+0x10,0x11,0x11,0x13,0xfc,0x10,0x33,0x3a,0x57,0x52,0x92,0x12,0x13,0x14,0x18,0x13,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 27270 0x6a86 "檆" */
+0x21,0x21,0x21,0x25,0xf5,0x29,0x22,0x74,0x69,0xa1,0xa5,0x25,0x29,0x22,0x24,0x28,
+0x08,0x08,0x48,0x48,0x8e,0x08,0x88,0x48,0x3e,0x62,0xa2,0x22,0x22,0xa2,0x7e,0x22,
+/* 27271 0x6a87 "檇" */
+0x10,0x10,0x11,0x13,0xfd,0x11,0x31,0x39,0x55,0x51,0x93,0x12,0x12,0x12,0x12,0x12,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xde,0x52,0x52,0x72,0x02,0x06,
+/* 27272 0x6a88 "檈" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x37,0x38,0x57,0x52,0x93,0x10,0x11,0x13,0x1d,0x11,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 27273 0x6a89 "檉" */
+0x10,0x17,0x12,0x13,0xfe,0x13,0x3a,0x37,0x50,0x53,0x90,0x11,0x10,0x10,0x13,0x10,
+0x00,0xe0,0x5e,0xd2,0x52,0xd2,0x72,0xde,0x40,0xfe,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 27274 0x6a8a "檊" */
+0x21,0x21,0x21,0x2f,0xf1,0x27,0x24,0x77,0x6c,0xa7,0xa1,0x2f,0x21,0x21,0x21,0x21,
+0x08,0x08,0x14,0xd4,0x22,0xc0,0x5c,0xc8,0x48,0xc8,0x3e,0xc8,0x08,0x08,0x08,0x08,
+/* 27275 0x6a8b "檋" */
+0x10,0x13,0x10,0x13,0xfc,0x11,0x32,0x38,0x55,0x55,0x91,0x11,0x11,0x10,0x13,0x10,
+0x88,0xfe,0x88,0xfe,0x88,0x24,0xfa,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,
+/* 27276 0x6a8c "檌" */
+0x20,0x23,0x22,0x22,0xfb,0x20,0x20,0x77,0x68,0xa0,0xa3,0x20,0x20,0x27,0x20,0x20,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0x90,0x9e,0x90,0x90,0x9c,0x90,0x90,0x9e,0x90,0x90,
+/* 27277 0x6a8d "檍" */
+0x10,0x10,0x11,0x10,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x10,0x12,0x12,0x14,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 27278 0x6a8e "檎" */
+0x10,0x10,0x10,0x11,0xfe,0x10,0x31,0x39,0x55,0x50,0x93,0x12,0x12,0x12,0x12,0x12,
+0x20,0x50,0x88,0x24,0xfa,0x50,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x06,
+/* 27279 0x6a8f "檏" */
+0x10,0x12,0x11,0x10,0xfb,0x10,0x30,0x3b,0x54,0x51,0x90,0x13,0x10,0x11,0x16,0x10,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 27280 0x6a90 "檐" */
+0x11,0x11,0x12,0x17,0xfa,0x13,0x33,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x14,0x18,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 27281 0x6a91 "檑" */
+0x10,0x11,0x10,0x13,0xfa,0x11,0x30,0x39,0x54,0x51,0x91,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,
+/* 27282 0x6a92 "檒" */
+0x08,0x08,0x7e,0x18,0x2c,0x4a,0x9f,0x10,0x17,0x11,0x17,0x15,0x27,0x21,0x4f,0x80,
+0x20,0x20,0xfc,0x30,0x68,0xa6,0xf0,0xd0,0x10,0x10,0xd0,0x50,0xca,0x2a,0xe6,0x22,
+/* 27283 0x6a93 "檓" */
+0x21,0x26,0x24,0x24,0xf6,0x24,0x24,0x77,0x68,0xa0,0xa7,0x21,0x21,0x21,0x27,0x22,
+0x00,0xdc,0x54,0x54,0xd4,0x54,0x66,0xc0,0x1c,0x14,0xd4,0x14,0x08,0xc8,0x14,0x22,
+/* 27284 0x6a94 "檔" */
+0x10,0x11,0x10,0x13,0xfe,0x10,0x30,0x38,0x54,0x54,0x91,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 27285 0x6a95 "檕" */
+0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x49,0x7f,0x01,0xff,0x09,0x71,
+0x00,0x78,0x48,0x48,0x86,0x00,0x78,0x48,0x28,0x90,0x28,0x44,0x00,0xfe,0x20,0x1c,
+/* 27286 0x6a96 "檖" */
+0x10,0x12,0x11,0x10,0xfc,0x10,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x12,0x14,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 27287 0x6a97 "檗" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27288 0x6a98 "檘" */
+0x20,0x20,0x27,0x24,0xfc,0x24,0x27,0x74,0x6c,0xa7,0xa6,0x2a,0x2a,0x2b,0x32,0x20,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0x7e,0x08,0x88,0xbe,0x88,0x88,0x88,0x88,0x08,
+/* 27289 0x6a99 "檙" */
+0x21,0x21,0x21,0x25,0xf5,0x25,0x25,0x74,0x6f,0xa0,0xa0,0x2f,0x24,0x24,0x24,0x28,
+0xf8,0x08,0xf8,0x0a,0xfa,0x0a,0xfa,0x02,0x9e,0x90,0x90,0x9e,0x92,0x92,0x92,0x92,
+/* 27290 0x6a9a "檚" */
+0x21,0x21,0x27,0x21,0xfb,0x25,0x29,0x70,0x6f,0xa0,0xa2,0x22,0x22,0x25,0x28,0x30,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xfc,0x44,0x40,0x78,0x40,0x40,0xfe,0x00,
+/* 27291 0x6a9b "檛" */
+0x20,0x22,0x21,0x21,0xf8,0x20,0x26,0x72,0x6a,0xa2,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x00,0x7c,0x44,0x74,0x54,0x54,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,0x00,0xfe,
+/* 27292 0x6a9c "檜" */
+0x20,0x20,0x23,0x2d,0xf0,0x27,0x25,0x74,0x6f,0xa0,0xa3,0x22,0x23,0x22,0x23,0x22,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 27293 0x6a9d "檝" */
+0x10,0x13,0x12,0x12,0xfb,0x10,0x37,0x3a,0x57,0x52,0x93,0x12,0x12,0x17,0x10,0x10,
+0x10,0xd4,0x52,0x52,0xd0,0x10,0xfe,0x50,0xd2,0x52,0xd4,0x54,0xea,0x4a,0x56,0x62,
+/* 27294 0x6a9e "檞" */
+0x22,0x23,0x24,0x29,0xf7,0x25,0x25,0x77,0x6d,0xa5,0xa7,0x25,0x25,0x25,0x24,0x28,
+0x00,0x9e,0x8a,0x0a,0xd2,0x66,0x40,0xd4,0x5e,0x64,0xc4,0x44,0x5e,0x44,0x44,0xc4,
+/* 27295 0x6a9f "檟" */
+0x10,0x13,0x10,0x13,0xfe,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27296 0x6aa0 "檠" */
+0x24,0xff,0x24,0x7e,0x82,0x7a,0x4a,0x7a,0x04,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0x3e,0x44,0x84,0x28,0x10,0x28,0x44,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 27297 0x6aa1 "檡" */
+0x10,0x11,0x11,0x11,0xfc,0x11,0x30,0x3b,0x54,0x54,0x91,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 27298 0x6aa2 "檢" */
+0x10,0x10,0x10,0x10,0xfd,0x12,0x30,0x38,0x55,0x55,0x91,0x11,0x10,0x10,0x11,0x12,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 27299 0x6aa3 "檣" */
+0x20,0x20,0x27,0x22,0xfa,0x25,0x2f,0x70,0x6b,0xa2,0xa2,0x22,0x22,0x22,0x23,0x22,
+0x40,0x40,0xfc,0x48,0x48,0x54,0xfe,0x00,0xf8,0x08,0xe8,0xa8,0xe8,0x08,0xf8,0x08,
+/* 27300 0x6aa4 "檤" */
+0x10,0x10,0x12,0x11,0xfd,0x10,0x30,0x3b,0x55,0x51,0x91,0x11,0x11,0x12,0x14,0x10,
+0x44,0x28,0x00,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 27301 0x6aa5 "檥" */
+0x11,0x10,0x13,0x10,0xfd,0x10,0x3b,0x34,0x51,0x50,0x93,0x10,0x10,0x13,0x10,0x11,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 27302 0x6aa6 "檦" */
+0x20,0x2f,0x22,0x2f,0xfa,0x2a,0x2f,0x70,0x6b,0xa0,0xaf,0x21,0x25,0x25,0x29,0x23,
+0x02,0xe2,0x82,0xea,0xaa,0xaa,0xea,0x0a,0xca,0x0a,0xea,0x0a,0x42,0x22,0x2a,0x04,
+/* 27303 0x6aa7 "檧" */
+0x10,0x13,0x10,0x11,0xfb,0x15,0x30,0x3b,0x54,0x50,0x93,0x10,0x10,0x12,0x12,0x14,
+0x88,0xfe,0x88,0x00,0xfc,0x54,0xd4,0x24,0x54,0x94,0x48,0x20,0xa4,0x8a,0x8a,0x78,
+/* 27304 0x6aa8 "檨" */
+0x11,0x10,0x13,0x10,0xfd,0x10,0x33,0x38,0x56,0x51,0x90,0x11,0x16,0x12,0x12,0x10,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x00,0x20,0x3e,0x42,0x14,0x10,0x28,0x44,0x82,
+/* 27305 0x6aa9 "檩" */
+0x10,0x13,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x11,0x10,0x13,0x11,0x12,
+0x20,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x00,0xfc,0x00,0xfe,0x24,0x62,
+/* 27306 0x6aaa "檪" */
+0x10,0x10,0x10,0x12,0xfd,0x10,0x31,0x3a,0x54,0x50,0x93,0x10,0x10,0x11,0x16,0x10,
+0x20,0x40,0xf8,0x8a,0x8c,0xf8,0x8c,0x8a,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27307 0x6aab "檫" */
+0x20,0x20,0x27,0x24,0xfa,0x23,0x34,0x6a,0x65,0xa2,0xa4,0x2b,0x20,0x22,0x24,0x20,
+0x80,0x40,0xfe,0x02,0x24,0xbc,0xa4,0xa8,0x10,0xe8,0x04,0xfa,0x40,0x48,0x44,0xc0,
+/* 27308 0x6aac "檬" */
+0x21,0x27,0x21,0x27,0xf4,0x23,0x20,0x77,0x68,0xa1,0xa6,0x21,0x26,0x21,0x26,0x20,
+0x10,0xfc,0x10,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x44,0xa8,0x70,0xa8,0x26,0xa0,0x40,
+/* 27309 0x6aad "檭" */
+0x22,0x22,0x25,0x24,0xf8,0x27,0x22,0x72,0x6f,0xa2,0xaa,0x27,0x22,0x23,0x2c,0x20,
+0x00,0x7c,0x44,0xc4,0x7c,0x44,0x44,0x7c,0x52,0x52,0x54,0x48,0x48,0x54,0x62,0x40,
+/* 27310 0x6aae "檮" */
+0x20,0x27,0x20,0x23,0xf8,0x27,0x20,0x73,0x68,0xa7,0xa0,0x27,0x20,0x27,0x24,0x27,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 27311 0x6aaf "檯" */
+0x20,0x2f,0x20,0x27,0xf8,0x23,0x32,0x6f,0x68,0xa7,0xa1,0x23,0x20,0x27,0x20,0x2f,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xfe,0x02,0xfc,0x10,0xf8,0x40,0xfc,0x40,0xfe,
+/* 27312 0x6ab0 "檰" */
+0x21,0x21,0x22,0x22,0xf4,0x27,0x21,0x72,0x6c,0xa7,0xa0,0x20,0x25,0x25,0x24,0x20,
+0x08,0x10,0x3e,0x22,0xbe,0x22,0x3e,0x08,0xbe,0xaa,0x2a,0xaa,0x6a,0x2e,0x08,0x08,
+/* 27313 0x6ab1 "檱" */
+0x11,0x11,0x12,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x13,0x10,0x11,0x12,
+0x08,0xee,0x94,0x42,0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x04,0x02,
+/* 27314 0x6ab2 "檲" */
+0x13,0x12,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x93,0x12,0x13,0x12,0x12,0x13,
+0xfe,0x22,0xfe,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x26,0xfe,0x0a,0xfe,0x8a,0x5a,0xfe,
+/* 27315 0x6ab3 "檳" */
+0x20,0x20,0x27,0x24,0xfb,0x21,0x22,0x77,0x6a,0xa7,0xaa,0x23,0x22,0x23,0x21,0x22,
+0x80,0x40,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 27316 0x6ab4 "檴" */
+0x10,0x13,0x10,0x10,0xfd,0x13,0x31,0x39,0x55,0x51,0x91,0x11,0x13,0x10,0x10,0x13,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 27317 0x6ab5 "檵" */
+0x10,0x12,0x12,0x12,0xfe,0x12,0x32,0x3b,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x13,
+0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,
+/* 27318 0x6ab6 "檶" */
+0x10,0x10,0x13,0x10,0xfc,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x13,
+0x20,0x20,0xfe,0x50,0x88,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xee,0xaa,0xee,0x00,0xfe,
+/* 27319 0x6ab7 "檷" */
+0x20,0x27,0x22,0x24,0xff,0x24,0x26,0x75,0x6e,0xa4,0xa6,0x25,0x26,0x24,0x24,0x24,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 27320 0x6ab8 "檸" */
+0x10,0x10,0x13,0x12,0xfd,0x11,0x32,0x38,0x55,0x51,0x93,0x10,0x11,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 27321 0x6ab9 "檹" */
+0x24,0x22,0x22,0x2f,0xf4,0x24,0x27,0x75,0x6d,0xa5,0xa5,0x25,0x29,0x29,0x33,0x20,
+0x20,0x20,0x3e,0x40,0x90,0x7e,0x24,0x42,0xfe,0x04,0x74,0x54,0x74,0x04,0x14,0x08,
+/* 27322 0x6aba "檺" */
+0x20,0x27,0x20,0x21,0xf9,0x21,0x20,0x77,0x6c,0xa3,0xa1,0x26,0x21,0x26,0x21,0x26,
+0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x80,0x44,0xb8,0x68,0xa6,0x60,
+/* 27323 0x6abb "檻" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x32,0x3b,0x54,0x51,0x91,0x11,0x11,0x11,0x17,0x10,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 27324 0x6abc "檼" */
+0x20,0x27,0x22,0x21,0xfb,0x20,0x27,0x70,0x6b,0xa0,0xa3,0x20,0x23,0x25,0x25,0x28,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 27325 0x6abd "檽" */
+0x10,0x11,0x10,0x13,0xfa,0x11,0x30,0x39,0x54,0x53,0x90,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 27326 0x6abe "檾" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x88,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x08,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x24,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0x20,
+/* 27327 0x6abf "檿" */
+0x3f,0x28,0x2f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x20,0x4f,0x41,0x86,0x18,
+0xfe,0x94,0x92,0x90,0xfe,0x10,0x90,0xa8,0xa4,0xc4,0x80,0x40,0xfe,0x60,0x58,0x46,
+/* 27328 0x6ac0 "櫀" */
+0x11,0x17,0x11,0x11,0xfd,0x11,0x39,0x37,0x51,0x52,0x95,0x10,0x13,0x10,0x12,0x14,
+0x08,0xfe,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x08,0x94,0xe2,0x48,0xfc,0x40,0x48,0xc4,
+/* 27329 0x6ac1 "櫁" */
+0x10,0x10,0x13,0x12,0xfc,0x12,0x3a,0x34,0x53,0x50,0x91,0x11,0x11,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x42,0x28,0x94,0xaa,0xca,0x78,0x20,0xfc,0x24,0xfc,0x22,0xfe,0x02,
+/* 27330 0x6ac2 "櫂" */
+0x20,0x27,0x20,0x24,0xf2,0x24,0x21,0x72,0x6f,0xaa,0xa3,0x22,0x23,0x22,0x23,0x22,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 27331 0x6ac3 "櫃" */
+0x27,0x24,0x25,0x25,0xfd,0x24,0x27,0x75,0x6d,0xa5,0xa5,0x25,0x25,0x24,0x25,0x27,
+0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0xfe,
+/* 27332 0x6ac4 "櫄" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x31,0x39,0x55,0x54,0x91,0x10,0x13,0x10,0x11,0x12,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 27333 0x6ac5 "櫅" */
+0x20,0x20,0x27,0x21,0xf0,0x2f,0x25,0x75,0x6b,0xa0,0xa2,0x23,0x22,0x23,0x22,0x24,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 27334 0x6ac6 "櫆" */
+0x21,0x22,0x27,0x25,0xfd,0x27,0x25,0x75,0x6f,0xa1,0xa2,0x22,0x24,0x24,0x28,0x20,
+0x04,0x14,0xcc,0x44,0x54,0xcc,0x46,0x5c,0xc4,0x04,0xa4,0xd4,0xf0,0x82,0x7e,0x00,
+/* 27335 0x6ac7 "櫇" */
+0x20,0x20,0x20,0x27,0xfc,0x24,0x24,0x77,0x6e,0xa5,0xa5,0x24,0x28,0x29,0x31,0x22,
+0x80,0x9e,0x84,0xe8,0xbe,0x92,0x92,0xde,0x52,0x5e,0x52,0x92,0x9e,0x40,0x4c,0x52,
+/* 27336 0x6ac8 "櫈" */
+0x20,0x27,0x20,0x25,0xf2,0x24,0x23,0x72,0x6b,0xa1,0xa7,0x20,0x21,0x21,0x22,0x24,
+0x24,0xa8,0x92,0x14,0xe8,0x04,0xfa,0x08,0xf8,0x10,0xfc,0x00,0xf0,0x10,0x12,0x0e,
+/* 27337 0x6ac9 "櫉" */
+0x20,0x27,0x24,0x24,0xf7,0x24,0x25,0x74,0x6d,0xa5,0xa5,0x25,0x28,0x28,0x33,0x20,
+0x00,0xfe,0x84,0x84,0xe4,0x9e,0xc4,0x04,0xd4,0x4c,0xc4,0x44,0x84,0xc4,0x14,0x08,
+/* 27338 0x6aca "櫊" */
+0x20,0x27,0x24,0x27,0xfc,0x27,0x24,0x75,0x6e,0xa4,0xa7,0x24,0x24,0x24,0x24,0x24,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x84,0xf4,0x94,0xe4,0x1c,0xe4,0xa4,0xa4,0xe4,0x0c,
+/* 27339 0x6acb "櫋" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x39,0x34,0x53,0x52,0x91,0x13,0x10,0x10,0x11,0x12,
+0x40,0xfc,0x24,0x94,0x4c,0x24,0xfc,0x20,0xfe,0x8a,0x24,0xfe,0x80,0xfc,0x04,0x0c,
+/* 27340 0x6acc "櫌" */
+0x23,0x20,0x21,0x21,0xf9,0x21,0x27,0x74,0x6a,0xa2,0xa4,0x20,0x21,0x22,0x20,0x23,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 27341 0x6acd "櫍" */
+0x10,0x13,0x12,0x13,0xfe,0x12,0x34,0x3b,0x56,0x53,0x92,0x13,0x12,0x13,0x11,0x12,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 27342 0x6ace "櫎" */
+0x20,0x20,0x27,0x24,0xfd,0x24,0x27,0x74,0x6d,0xa5,0xa5,0x25,0x25,0x24,0x24,0x29,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 27343 0x6acf "櫏" */
+0x20,0x20,0x24,0x22,0xfa,0x20,0x20,0x71,0x6e,0xa2,0xa3,0x22,0x22,0x22,0x25,0x28,
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x10,0xfe,0x44,0xfe,0x44,0x7c,0x42,0x3e,0x00,0xfe,
+/* 27344 0x6ad0 "櫐" */
+0x1f,0x11,0x1f,0x11,0x1f,0x00,0x3e,0x2a,0x3e,0x2a,0x3e,0x01,0x7f,0x05,0x19,0xe1,
+0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x40,0x30,0x0e,
+/* 27345 0x6ad1 "櫑" */
+0x23,0x22,0x22,0x23,0xfa,0x22,0x23,0x70,0x6f,0xaa,0xaa,0x2f,0x2a,0x2a,0x2f,0x28,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 27346 0x6ad2 "櫒" */
+0x10,0x10,0x13,0x10,0xfd,0x11,0x3a,0x35,0x52,0x51,0x92,0x11,0x10,0x11,0x12,0x10,
+0x88,0x88,0xfe,0x88,0x10,0xde,0x52,0x54,0x88,0x74,0x02,0xfc,0x20,0x24,0x22,0x60,
+/* 27347 0x6ad3 "櫓" */
+0x10,0x11,0x12,0x15,0xfd,0x11,0x39,0x35,0x51,0x52,0x91,0x11,0x11,0x11,0x11,0x11,
+0x80,0xf8,0x08,0xfc,0x24,0xfc,0x24,0xfc,0x54,0x2a,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 27348 0x6ad4 "櫔" */
+0x10,0x13,0x12,0x13,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x13,0x13,0x15,0x15,0x19,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 27349 0x6ad5 "櫕" */
+0x10,0x11,0x10,0x13,0xfc,0x11,0x32,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27350 0x6ad6 "櫖" */
+0x20,0x20,0x20,0x27,0xfc,0x25,0x24,0x75,0x6d,0xa5,0xa5,0x25,0x28,0x2a,0x32,0x24,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x24,0xfc,0x24,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 27351 0x6ad7 "櫗" */
+0x11,0x17,0x11,0x10,0xfb,0x12,0x32,0x3b,0x54,0x53,0x92,0x13,0x12,0x12,0x14,0x18,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 27352 0x6ad8 "櫘" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x30,0x3b,0x54,0x51,0x90,0x13,0x10,0x12,0x12,0x14,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 27353 0x6ad9 "櫙" */
+0x10,0x10,0x17,0x10,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x13,
+0x88,0x88,0xfe,0x88,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x00,0xfe,
+/* 27354 0x6ada "櫚" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x02,0xfa,0x8a,0xfa,0x02,0x06,
+/* 27355 0x6adb "櫛" */
+0x11,0x11,0x11,0x12,0xfc,0x10,0x33,0x3a,0x57,0x52,0x93,0x12,0x12,0x13,0x12,0x10,
+0x08,0x08,0xee,0x94,0x42,0x00,0xde,0x52,0xd2,0x52,0xd2,0x1a,0x94,0x50,0x10,0x10,
+/* 27356 0x6adc "櫜" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x88,0x1f,0x32,0x4c,0x37,0xc1,0x7f,0x05,0x19,0xe1,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x42,0x60,0x50,0x48,0xfe,0x00,0xfc,0x40,0x30,0x0e,
+/* 27357 0x6add "櫝" */
+0x10,0x13,0x10,0x11,0xfc,0x13,0x32,0x3b,0x55,0x55,0x91,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27358 0x6ade "櫞" */
+0x21,0x21,0x21,0x22,0xfa,0x24,0x2f,0x71,0x6a,0xa4,0xaf,0x20,0x20,0x2a,0x2a,0x28,
+0x20,0x3c,0x44,0x78,0x88,0xfe,0x20,0x52,0x1a,0xac,0xcc,0x9a,0x2a,0xc8,0xa8,0x10,
+/* 27359 0x6adf "櫟" */
+0x24,0x24,0x28,0x2a,0xfe,0x24,0x2a,0x7e,0x6a,0xa0,0xaf,0x20,0x21,0x22,0x2c,0x20,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 27360 0x6ae0 "櫠" */
+0x20,0x27,0x24,0x27,0xfd,0x24,0x25,0x77,0x6c,0xa5,0xa5,0x25,0x28,0x28,0x31,0x20,
+0x20,0xfe,0x10,0xd4,0x4a,0x84,0x02,0xdc,0x54,0xe6,0x00,0xdc,0x44,0x54,0x48,0x94,
+/* 27361 0x6ae1 "櫡" */
+0x22,0x22,0x23,0x25,0xf8,0x20,0x23,0x70,0x6f,0xa0,0xa3,0x2d,0x21,0x21,0x21,0x21,
+0x10,0x10,0xde,0x28,0x84,0x44,0xf8,0x50,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 27362 0x6ae2 "櫢" */
+0x21,0x27,0x25,0x2f,0xf5,0x27,0x21,0x77,0x6d,0xa7,0xa2,0x2f,0x24,0x26,0x21,0x26,
+0x08,0xc8,0x48,0xf0,0x5e,0xe4,0x14,0xd4,0x54,0xd4,0x14,0xc8,0x48,0x94,0x94,0x62,
+/* 27363 0x6ae3 "櫣" */
+0x11,0x17,0x11,0x14,0xfa,0x12,0x30,0x38,0x56,0x52,0x92,0x12,0x12,0x12,0x15,0x18,
+0x08,0xfe,0x08,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0xfe,
+/* 27364 0x6ae4 "櫤" */
+0x12,0x13,0x15,0x10,0xfd,0x10,0x37,0x38,0x57,0x52,0x93,0x12,0x13,0x12,0x12,0x12,
+0x10,0xde,0x28,0x84,0x08,0x90,0xfe,0x00,0xd4,0x54,0xd4,0x54,0xd4,0x44,0x54,0xc8,
+/* 27365 0x6ae5 "櫥" */
+0x10,0x10,0x13,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x14,0x15,0x18,
+0x40,0x20,0xfe,0x44,0xf4,0x44,0xee,0x04,0xf4,0xac,0xe4,0x14,0xa4,0x74,0x94,0x08,
+/* 27366 0x6ae6 "櫦" */
+0x10,0x13,0x12,0x13,0xfe,0x13,0x32,0x3b,0x56,0x53,0x92,0x12,0x12,0x15,0x14,0x19,
+0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfe,0x92,0x48,0x3a,0x40,0xfc,0x48,0x30,0xce,
+/* 27367 0x6ae7 "櫧" */
+0x24,0x22,0x20,0x27,0xf8,0x27,0x20,0x77,0x68,0xa7,0xa5,0x25,0x25,0x27,0x25,0x20,
+0x10,0x10,0x7a,0x12,0x14,0x7e,0x08,0x10,0x3c,0x64,0xa4,0x3c,0x24,0x24,0x3c,0x24,
+/* 27368 0x6ae8 "櫨" */
+0x10,0x10,0x10,0x13,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x15,0x15,0x1b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 27369 0x6ae9 "櫩" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x32,0x3a,0x57,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0xde,0x52,0xde,0x52,0xde,0x42,0x7a,0x8a,0x12,0xda,0x8a,0xda,0x8a,0xfa,0x0a,0x04,
+/* 27370 0x6aea "櫪" */
+0x20,0x27,0x24,0x25,0xfc,0x27,0x24,0x75,0x6e,0xa4,0xa4,0x25,0x25,0x29,0x29,0x37,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 27371 0x6aeb "櫫" */
+0x00,0x7f,0x10,0x28,0x4d,0x16,0x24,0x4e,0x15,0x64,0x0c,0x01,0x7f,0x05,0x19,0xe1,
+0x20,0x24,0xfc,0x28,0xfe,0x20,0x7c,0xc4,0x7c,0x44,0x7c,0x00,0xfc,0x40,0x30,0x0e,
+/* 27372 0x6aec "櫬" */
+0x22,0x21,0x27,0x20,0xf4,0x23,0x27,0x71,0x69,0xa7,0xa1,0x25,0x25,0x29,0x25,0x22,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xa4,0x3c,0x24,0xa4,0x3c,0x90,0x58,0x68,0x2a,0x46,
+/* 27373 0x6aed "櫭" */
+0x2f,0x29,0x2f,0x29,0xff,0x2a,0x2b,0x7d,0x68,0xa7,0xa4,0x27,0x24,0x27,0x20,0x2f,
+0x7e,0x10,0x50,0x50,0x7e,0x28,0x28,0x4a,0x86,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 27374 0x6aee "櫮" */
+0x10,0x13,0x10,0x13,0xfe,0x12,0x33,0x38,0x57,0x50,0x93,0x12,0x12,0x13,0x10,0x13,
+0x00,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,
+/* 27375 0x6aef "櫯" */
+0x22,0x22,0x27,0x24,0xf9,0x27,0x25,0x75,0x6f,0xa5,0xa5,0x27,0x20,0x2a,0x2a,0x20,
+0x06,0x38,0x88,0x88,0x08,0xde,0x48,0x48,0xdc,0x5a,0x68,0xe8,0x08,0xa8,0xa8,0x08,
+/* 27376 0x6af0 "櫰" */
+0x20,0x20,0x2f,0x20,0xf7,0x24,0x27,0x72,0x69,0xa2,0xa4,0x20,0x21,0x23,0x2d,0x21,
+0x80,0x40,0xfe,0x00,0xfc,0xa4,0xfc,0x48,0x50,0x08,0x44,0xa8,0x10,0x08,0x46,0x80,
+/* 27377 0x6af1 "櫱" */
+0x52,0x7e,0x28,0x7e,0xa2,0x3e,0x20,0x3e,0x22,0x3e,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27378 0x6af2 "櫲" */
+0x20,0x2f,0x21,0x25,0xfa,0x21,0x2f,0x72,0x6b,0xa2,0xa2,0x22,0x22,0x22,0x2a,0x24,
+0x20,0x3c,0x44,0xbe,0x2a,0x2a,0xbe,0x90,0x2a,0x5a,0x2c,0x5c,0x2a,0x48,0x28,0x10,
+/* 27379 0x6af3 "櫳" */
+0x22,0x21,0x27,0x20,0xf4,0x22,0x27,0x70,0x6f,0xa4,0xa7,0x24,0x27,0x24,0x24,0x24,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 27380 0x6af4 "櫴" */
+0x21,0x21,0x27,0x21,0xf9,0x27,0x25,0x75,0x6f,0xa1,0xa3,0x25,0x29,0x21,0x21,0x21,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 27381 0x6af5 "櫵" */
+0x10,0x10,0x13,0x10,0xfc,0x11,0x31,0x3b,0x55,0x51,0x91,0x11,0x11,0x12,0x12,0x14,
+0x88,0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,
+/* 27382 0x6af6 "櫶" */
+0x10,0x13,0x12,0x11,0xfc,0x10,0x30,0x39,0x54,0x55,0x91,0x11,0x10,0x12,0x12,0x14,
+0x20,0xfe,0x22,0xfc,0x20,0xf8,0x20,0xfc,0x20,0xfc,0x54,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 27383 0x6af7 "櫷" */
+0x20,0x27,0x24,0x27,0xf8,0x26,0x22,0x77,0x6a,0xa6,0xa0,0x26,0x22,0x27,0x22,0x26,
+0x80,0xfc,0x04,0xbc,0xa0,0xbe,0xa2,0xb6,0xaa,0xaa,0xb6,0xa2,0xbe,0xa0,0xa2,0x7e,
+/* 27384 0x6af8 "櫸" */
+0x21,0x22,0x22,0x23,0xfa,0x23,0x22,0x77,0x69,0xa2,0xa5,0x20,0x27,0x20,0x20,0x20,
+0x40,0x6c,0x44,0x6c,0xa4,0xac,0xa4,0xfe,0x08,0x44,0xf2,0x40,0xfc,0x40,0x40,0x40,
+/* 27385 0x6af9 "櫹" */
+0x21,0x27,0x21,0x23,0xf8,0x27,0x20,0x73,0x6d,0xa7,0xa4,0x27,0x24,0x27,0x25,0x29,
+0x10,0xfe,0x50,0xf8,0x48,0xfe,0x48,0xf8,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,
+/* 27386 0x6afa "櫺" */
+0x20,0x27,0x20,0x2f,0xf8,0x23,0x20,0x73,0x68,0xa0,0xae,0x2a,0x2a,0x2a,0x2e,0x2a,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0x00,0xee,0xaa,0xaa,0xaa,0xee,0xaa,
+/* 27387 0x6afb "櫻" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x33,0x39,0x56,0x50,0x97,0x10,0x11,0x10,0x10,0x13,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 27388 0x6afc "櫼" */
+0x21,0x21,0x22,0xf8,0x27,0x21,0x73,0x69,0xab,0xa1,0x23,0x21,0x21,0x23,0x20,0x20,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 27389 0x6afd "櫽" */
+0x00,0x7b,0x49,0x53,0x60,0x53,0x48,0x49,0x68,0x52,0x44,0x01,0x7f,0x05,0x19,0xe1,
+0x18,0xe0,0x50,0xf8,0x40,0xf8,0x08,0xf8,0x40,0x94,0xf4,0x00,0xfc,0x40,0x30,0x0e,
+/* 27390 0x6afe "櫾" */
+0x21,0x2e,0x20,0x2a,0xf5,0x24,0x27,0x7a,0x6a,0xaf,0xa2,0x2a,0x2a,0x2b,0x2e,0x20,
+0x82,0x3c,0x88,0x90,0x22,0x3c,0x88,0x12,0x3e,0x88,0x08,0xac,0xaa,0xca,0xa8,0x90,
+/* 27391 0x6aff "櫿" */
+0x10,0x12,0x12,0x14,0xf9,0x12,0x33,0x3a,0x54,0x50,0x90,0x10,0x11,0x11,0x11,0x11,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xf8,0x88,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 27392 0x6b00 "欀" */
+0x20,0x27,0x20,0x23,0xfa,0x23,0x21,0x77,0x69,0xa7,0xa1,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 27393 0x6b01 "欁" */
+0x22,0x2f,0x2a,0x2f,0xfa,0x2f,0x30,0x6f,0x68,0xab,0xa8,0x2f,0x2a,0x2a,0x2b,0x32,
+0x88,0xe8,0xa8,0xe8,0xbe,0xe8,0x08,0xdc,0x1a,0xe8,0x28,0xc8,0xa8,0x48,0x28,0x28,
+/* 27394 0x6b02 "欂" */
+0x10,0x13,0x10,0x14,0xfa,0x10,0x34,0x3a,0x56,0x50,0x91,0x12,0x16,0x12,0x12,0x12,
+0x88,0xfe,0x88,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x2c,
+/* 27395 0x6b03 "欃" */
+0x11,0x12,0x17,0x12,0xfb,0x12,0x33,0x3a,0x55,0x52,0x97,0x12,0x13,0x10,0x11,0x16,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 27396 0x6b04 "欄" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x12,0x12,0x12,0x12,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 27397 0x6b05 "欅" */
+0x21,0x22,0x22,0x23,0xfa,0x23,0x22,0x77,0x69,0xa2,0xa4,0x23,0x20,0x27,0x20,0x20,
+0x40,0x6c,0x44,0x6c,0xa4,0xac,0xa4,0xfe,0x08,0xf4,0x42,0xf8,0x40,0xfc,0x40,0xc0,
+/* 27398 0x6b06 "欆" */
+0x21,0x22,0x23,0x26,0xfb,0x22,0x23,0x72,0x6b,0xa2,0xa7,0x21,0x20,0x20,0x21,0x26,
+0x08,0x94,0xde,0xb4,0xde,0x94,0xde,0x94,0xde,0x10,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 27399 0x6b07 "欇" */
+0x13,0x11,0x11,0x11,0xfd,0x11,0x37,0x38,0x57,0x52,0x93,0x12,0x13,0x12,0x17,0x10,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 27400 0x6b08 "欈" */
+0x12,0x13,0x10,0x11,0xfb,0x15,0x31,0x39,0x55,0x51,0x91,0x13,0x12,0x13,0x12,0x12,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 27401 0x6b09 "欉" */
+0x24,0x22,0x2f,0x21,0xf7,0x20,0x23,0x70,0x6f,0xa4,0xa7,0x24,0x27,0x24,0x2f,0x20,
+0x92,0x94,0xfe,0x10,0xfc,0x40,0xf8,0x40,0xfe,0x80,0xbc,0x94,0x94,0xc8,0x94,0xa2,
+/* 27402 0x6b0a "權" */
+0x10,0x13,0x10,0x13,0xfe,0x13,0x30,0x38,0x55,0x51,0x93,0x15,0x11,0x11,0x11,0x11,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 27403 0x6b0b "欋" */
+0x13,0x12,0x13,0x12,0xfb,0x12,0x33,0x38,0x55,0x51,0x93,0x15,0x11,0x11,0x11,0x11,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 27404 0x6b0c "欌" */
+0x20,0x20,0x27,0x20,0xf8,0x21,0x25,0x77,0x69,0xa1,0xaf,0x25,0x25,0x29,0x22,0x24,
+0x90,0x90,0xfe,0x94,0x0a,0xfe,0x08,0xe8,0x4a,0xea,0x2a,0xea,0x4c,0xea,0x16,0x62,
+/* 27405 0x6b0d "欍" */
+0x21,0x27,0x21,0x23,0xfa,0x27,0x2a,0x73,0x6a,0xa3,0xa0,0x23,0x22,0x23,0x22,0x23,
+0x08,0xfe,0x28,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x80,0x1c,0x04,0x9c,0x04,0xfc,
+/* 27406 0x6b0e "欎" */
+0x22,0xf9,0x22,0x72,0xa9,0x22,0xff,0x80,0x3e,0x22,0x3e,0x22,0x3e,0x28,0x24,0x3a,
+0x88,0x3e,0x88,0x9c,0x2a,0x88,0xfe,0x02,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 27407 0x6b0f "欏" */
+0x20,0x27,0x24,0x24,0xf7,0x22,0x22,0x74,0x6f,0xa2,0xa4,0x2f,0x20,0x2a,0x2a,0x20,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 27408 0x6b10 "欐" */
+0x13,0x10,0x13,0x12,0xfb,0x12,0x30,0x3b,0x56,0x53,0x92,0x13,0x12,0x12,0x12,0x14,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 27409 0x6b11 "欑" */
+0x25,0x27,0x29,0x27,0xfb,0x25,0x29,0x73,0x6a,0xa3,0xa2,0x23,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 27410 0x6b12 "欒" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 27411 0x6b13 "欓" */
+0x22,0x21,0x27,0x24,0xf9,0x21,0x27,0x75,0x6c,0xa7,0xa0,0x27,0x20,0x2f,0x22,0x24,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 27412 0x6b14 "欔" */
+0x13,0x12,0x13,0x12,0xfb,0x10,0x31,0x3b,0x55,0x51,0x91,0x10,0x11,0x10,0x10,0x17,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 27413 0x6b15 "欕" */
+0x27,0x24,0x27,0x20,0xf7,0x24,0x25,0x74,0x6f,0xa5,0xa5,0x25,0x25,0x25,0x2b,0x30,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 27414 0x6b16 "欖" */
+0x27,0x25,0x27,0x24,0xf7,0x25,0x27,0x70,0x6b,0xa2,0xa3,0x22,0x23,0x20,0x21,0x26,
+0x90,0x1e,0xa8,0x84,0xbe,0x2a,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 27415 0x6b17 "欗" */
+0x10,0x13,0x10,0x13,0xfe,0x13,0x32,0x3b,0x56,0x53,0x92,0x12,0x12,0x12,0x12,0x12,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0xaa,0xfa,0x22,0x72,0xaa,0x24,
+/* 27416 0x6b18 "欘" */
+0x13,0x12,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x53,0x92,0x12,0x14,0x14,0x19,0x10,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 27417 0x6b19 "欙" */
+0x27,0x24,0x27,0x24,0xff,0x2a,0x2f,0x7a,0x6f,0xa2,0xa7,0x20,0x2f,0x20,0x25,0x28,
+0xfc,0x44,0xfc,0x44,0xfe,0xaa,0xbe,0xaa,0xbe,0x20,0xc0,0x84,0xfe,0x42,0x48,0x84,
+/* 27418 0x6b1a "欚" */
+0x21,0x22,0x23,0x20,0xf7,0x21,0x26,0x71,0x6e,0xa1,0xa2,0x2f,0x2a,0x2f,0x22,0x2f,
+0xf0,0x10,0xe0,0x20,0xfc,0x88,0x50,0xa8,0x64,0xa0,0x48,0xbe,0xaa,0xbe,0x8a,0xbe,
+/* 27419 0x6b1b "欛" */
+0x23,0x20,0x27,0x24,0xf9,0x22,0x27,0x72,0x6b,0xa1,0xa7,0x25,0x27,0x21,0x2f,0x21,
+0xfe,0x20,0xfe,0x22,0xac,0x80,0xde,0x92,0x92,0x1e,0xd2,0x52,0xde,0x12,0xd2,0x26,
+/* 27420 0x6b1c "欜" */
+0x20,0x27,0x22,0x23,0xf0,0x2f,0x2a,0x73,0x69,0xa7,0xa1,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 27421 0x6b1d "欝" */
+0x22,0xf9,0x22,0x72,0xa9,0x22,0x7f,0x44,0x7f,0x22,0x3e,0x22,0x3e,0x28,0x24,0x3a,
+0x88,0x3e,0x88,0x9c,0x2a,0x88,0xfc,0x44,0xfc,0x08,0xfe,0x48,0x28,0x08,0x28,0x10,
+/* 27422 0x6b1e "欞" */
+0x27,0x20,0x2f,0x28,0xfb,0x20,0x23,0x70,0x6e,0xaa,0xae,0x20,0x2f,0x22,0x25,0x2f,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xee,0xaa,0xee,0x00,0xfe,0x48,0x54,0xfe,
+/* 27423 0x6b1f "欟" */
+0x22,0x27,0x22,0x27,0xfd,0x27,0x31,0x6c,0x67,0xad,0xb7,0x25,0x27,0x25,0x27,0x24,
+0x80,0xde,0x92,0xd2,0x5e,0xd2,0x12,0x9e,0xd2,0x12,0xde,0x08,0xcc,0x14,0xd4,0x22,
+/* 27424 0x6b20 "欠" */
+0x08,0x08,0x08,0x0f,0x10,0x11,0x21,0x41,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0xfc,0x04,0x08,0x10,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 27425 0x6b21 "次" */
+0x00,0x40,0x20,0x20,0x01,0x09,0x0a,0x14,0x10,0xe0,0x20,0x21,0x21,0x22,0x24,0x08,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27426 0x6b22 "欢" */
+0x00,0x00,0xfc,0x04,0x05,0x49,0x2a,0x14,0x10,0x28,0x24,0x45,0x81,0x02,0x04,0x08,
+0x80,0x80,0x80,0xfc,0x04,0x08,0x40,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27427 0x6b23 "欣" */
+0x02,0x07,0x38,0x20,0x20,0x20,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x81,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27428 0x6b24 "欤" */
+0x20,0x20,0x20,0x3f,0x20,0x40,0x40,0x7e,0x02,0x02,0x1a,0xe2,0x42,0x02,0x14,0x09,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27429 0x6b25 "欥" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x45,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27430 0x6b26 "欦" */
+0x08,0x08,0x14,0x14,0x22,0x52,0x89,0x08,0x00,0x7e,0x02,0x04,0x04,0x08,0x09,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27431 0x6b27 "欧" */
+0x00,0x7e,0x40,0x44,0x64,0x54,0x49,0x48,0x54,0x54,0x64,0x40,0x40,0x7e,0x01,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27432 0x6b28 "欨" */
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x15,0x0a,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27433 0x6b29 "欩" */
+0x00,0x7f,0x11,0x11,0x21,0x25,0x42,0x80,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x00,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27434 0x6b2a "欪" */
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x9e,0xf2,0x00,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27435 0x6b2b "欫" */
+0x20,0x20,0x3f,0x48,0x88,0x08,0x7f,0x08,0x08,0x2e,0x28,0x28,0x2f,0xf0,0x40,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27436 0x6b2c "欬" */
+0x10,0x08,0x08,0xff,0x08,0x10,0x22,0x7c,0x09,0x12,0x24,0xc8,0x14,0x22,0xc0,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27437 0x6b2d "欭" */
+0x00,0xfe,0x82,0x92,0x92,0x92,0xfe,0x92,0x92,0xaa,0xa6,0xc2,0x82,0xfe,0x82,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27438 0x6b2e "欮" */
+0x42,0x22,0x24,0xff,0x08,0x08,0x49,0x49,0x49,0x7f,0x09,0x10,0x10,0x20,0x40,0x81,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27439 0x6b2f "欯" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7d,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27440 0x6b30 "欰" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0xa8,0x44,0x44,0x82,
+/* 27441 0x6b31 "欱" */
+0x10,0x10,0x28,0x24,0x42,0x80,0x7d,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27442 0x6b32 "欲" */
+0x14,0x12,0x21,0x49,0x08,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27443 0x6b33 "欳" */
+0x08,0x08,0x0f,0x08,0x08,0x7f,0x55,0x55,0x55,0x7f,0x55,0x55,0x55,0x51,0x45,0x42,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27444 0x6b34 "欴" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x43,0x42,0x7e,0x40,0x48,0x44,0x4a,0x52,0x61,0x42,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27445 0x6b35 "欵" */
+0x40,0x4c,0x70,0x44,0x44,0x3c,0x41,0x7c,0x90,0x10,0xfe,0x10,0x28,0x24,0x45,0x82,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27446 0x6b36 "欶" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x49,0x49,0x7f,0x08,0x1c,0x2a,0x49,0x88,0x08,0x09,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27447 0x6b37 "欷" */
+0x42,0x24,0x18,0x24,0x52,0x10,0xff,0x20,0x28,0x7e,0xaa,0x2a,0x2a,0x2e,0x08,0x09,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27448 0x6b38 "欸" */
+0x10,0x10,0x20,0x44,0xfe,0x02,0x40,0x7c,0x90,0x10,0xfe,0x10,0x10,0x28,0x44,0x85,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27449 0x6b39 "欹" */
+0x08,0x08,0x7f,0x14,0x22,0x41,0xff,0x02,0x7a,0x4a,0x4a,0x7a,0x4a,0x02,0x0a,0x04,
+0x20,0x20,0x20,0x3e,0x22,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 27450 0x6b3a "欺" */
+0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0xff,0x24,0x22,0x42,0x81,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0xa8,0x48,0x44,0x84,0x02,
+/* 27451 0x6b3b "欻" */
+0x10,0x52,0x54,0x90,0x28,0x44,0x83,0x10,0x10,0x52,0x54,0x90,0x28,0x24,0x43,0x82,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27452 0x6b3c "欼" */
+0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27453 0x6b3d "欽" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x11,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27454 0x6b3e "款" */
+0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x7e,0x00,0xff,0x08,0x4a,0x49,0x89,0x28,0x11,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27455 0x6b3f "欿" */
+0x10,0x10,0x3e,0x22,0x44,0x80,0x10,0x66,0x42,0x42,0x66,0x42,0x42,0x7e,0x42,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27456 0x6b40 "歀" */
+0x08,0x08,0x7f,0x1c,0x2a,0x49,0x00,0x7e,0x00,0xff,0x08,0x4a,0x49,0x89,0x28,0x11,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27457 0x6b41 "歁" */
+0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0x22,0xff,0x40,0x54,0x62,0x40,0x7e,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27458 0x6b42 "歂" */
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0x86,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27459 0x6b43 "歃" */
+0x02,0x0f,0x78,0x08,0x08,0xff,0x28,0x4b,0x49,0x49,0x6b,0x49,0x49,0x7f,0x41,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27460 0x6b44 "歄" */
+0x00,0x3e,0x22,0x22,0x3a,0x2a,0x2a,0x7f,0x41,0x5d,0x55,0x55,0x5d,0x41,0x45,0x42,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27461 0x6b45 "歅" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xab,0xfe,0x10,0x10,0xfe,0x10,0x10,0x1e,0xf1,0x42,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27462 0x6b46 "歆" */
+0x10,0x08,0xff,0x00,0x42,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x43,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27463 0x6b47 "歇" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x20,0x7f,0x89,0x49,0x55,0x41,0x7d,0x01,0x0a,0x04,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27464 0x6b48 "歈" */
+0x10,0x28,0x44,0x82,0x7d,0x00,0xf1,0x95,0x95,0xf5,0x95,0x95,0xf5,0x91,0x95,0xb2,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27465 0x6b49 "歉" */
+0x22,0x14,0xff,0x14,0x14,0x7f,0x15,0xff,0x15,0x7f,0x14,0x36,0x55,0x94,0x14,0x14,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x90,0x10,0x10,0x28,0x28,0x28,0xc4,0x44,0x82,
+/* 27466 0x6b4a "歊" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x00,0xff,0x81,0xbd,0xa5,0xbd,0x81,0x85,0x82,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27467 0x6b4b "歋" */
+0x03,0x7c,0x47,0x44,0x5f,0x55,0x56,0x5c,0x55,0x53,0x50,0x57,0x55,0x55,0xa9,0x01,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27468 0x6b4c "歌" */
+0x00,0xff,0x02,0x7a,0x4a,0x7a,0x00,0xff,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27469 0x6b4d "歍" */
+0x10,0x20,0x7f,0x41,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x00,0x05,0x02,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0xd0,0x10,0x90,0xa8,0xa8,0xa8,0xc4,0x44,0x82,
+/* 27470 0x6b4e "歎" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x14,0x22,0x41,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 27471 0x6b4f "歏" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27472 0x6b50 "歐" */
+0x00,0xff,0x80,0x9f,0x91,0x91,0x9f,0x80,0xbb,0xaa,0xaa,0xaa,0xbb,0x80,0xff,0x00,
+0x20,0xa0,0x20,0x7e,0x42,0x84,0x10,0x10,0x90,0x90,0xa8,0xa8,0xa8,0x44,0xc4,0x82,
+/* 27473 0x6b51 "歑" */
+0x04,0x07,0x04,0x3f,0x24,0x27,0x3c,0x23,0x20,0x2f,0x32,0x2a,0x5f,0x42,0x8a,0x04,
+0x10,0x90,0x10,0xde,0x52,0x24,0x88,0x88,0x88,0x08,0x48,0x94,0xd4,0x14,0x14,0x22,
+/* 27474 0x6b52 "歒" */
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x82,0x92,0xfe,0x92,0xba,0xaa,0xaa,0xba,0x82,0x86,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27475 0x6b53 "歓" */
+0x20,0x20,0x3f,0x48,0x88,0x7f,0x14,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x20,
+0x20,0x20,0x20,0x3e,0x22,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 27476 0x6b54 "歔" */
+0x10,0x1e,0x10,0x7f,0x51,0x5c,0x72,0x4e,0x40,0x4a,0x6a,0x5b,0x4a,0x8f,0x78,0x00,
+0x20,0x20,0x20,0x3e,0x22,0x44,0x50,0x90,0x10,0x10,0x90,0x28,0x28,0x44,0x44,0x82,
+/* 27477 0x6b55 "歕" */
+0x08,0x7f,0x08,0x22,0xff,0x22,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,0x80,
+0x20,0x20,0x20,0x3e,0xa2,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 27478 0x6b56 "歖" */
+0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27479 0x6b57 "歗" */
+0x04,0x3f,0x04,0x7f,0x04,0x3f,0x04,0x55,0x75,0x44,0x7f,0x44,0x75,0x55,0x55,0x84,
+0x10,0x90,0x90,0xde,0x92,0xa4,0x08,0x48,0xc8,0x48,0xc8,0x54,0xd4,0x54,0x54,0x62,
+/* 27480 0x6b58 "歘" */
+0x08,0x29,0x29,0x4a,0x14,0x22,0x41,0x00,0x22,0x2a,0xb7,0x62,0x22,0x52,0x45,0x88,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x90,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27481 0x6b59 "歙" */
+0x08,0x14,0x22,0x5d,0x80,0x3e,0x22,0x3e,0x00,0x77,0x11,0x55,0x33,0x55,0x11,0x33,
+0x20,0x20,0x20,0x3e,0xa2,0x44,0x50,0x90,0x10,0x10,0x10,0x28,0x28,0x44,0x44,0x82,
+/* 27482 0x6b5a "歚" */
+0x11,0x0a,0x7f,0x04,0x3f,0x04,0x7f,0x24,0x15,0x7f,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x10,0x10,0xd0,0x1e,0x92,0x24,0xc8,0x88,0x08,0xc8,0x08,0x94,0x94,0x94,0x94,0xa2,
+/* 27483 0x6b5b "歛" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x88,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27484 0x6b5c "歜" */
+0x00,0x7f,0x55,0x55,0x7f,0x20,0x7f,0x91,0x7d,0x55,0x55,0x7d,0x11,0x7d,0x05,0x02,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27485 0x6b5d "歝" */
+0x00,0x7f,0x55,0x7f,0x08,0x7f,0x08,0xff,0x22,0x14,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x90,0x10,0x10,0x28,0x28,0xa8,0x44,0x44,0x82,
+/* 27486 0x6b5e "歞" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x55,0x77,0x22,0x55,0x77,0x00,0x55,0x55,0x00,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27487 0x6b5f "歟" */
+0x28,0x4b,0x4d,0x49,0x6b,0x4d,0x55,0x77,0x55,0x55,0xff,0x00,0x22,0x21,0x41,0x80,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0xa8,0x28,0x28,0x44,0x44,0x82,
+/* 27488 0x6b60 "歠" */
+0x77,0x55,0x22,0x55,0xf7,0x55,0x22,0x55,0xff,0x14,0x7f,0x55,0x63,0x5d,0x41,0x7f,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x90,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27489 0x6b61 "歡" */
+0x22,0x22,0xff,0x22,0x77,0x55,0x77,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x20,0x20,0xa0,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 27490 0x6b62 "止" */
+0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 27491 0x6b63 "正" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 27492 0x6b64 "此" */
+0x04,0x04,0x04,0x24,0x24,0x27,0x24,0x24,0x24,0x24,0x24,0x24,0x2f,0xf0,0x40,0x00,
+0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 27493 0x6b65 "步" */
+0x01,0x01,0x11,0x11,0x11,0x11,0xff,0x01,0x01,0x11,0x11,0x21,0x40,0x03,0x1c,0xe0,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x08,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 27494 0x6b66 "武" */
+0x00,0x00,0x3f,0x00,0x00,0xff,0x00,0x04,0x04,0x27,0x24,0x24,0x24,0x27,0xf8,0x40,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x8a,0x06,0x02,
+/* 27495 0x6b67 "歧" */
+0x08,0x08,0x08,0x0b,0x48,0x4e,0x48,0x49,0x48,0x48,0x48,0x4e,0x58,0xe0,0x01,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 27496 0x6b68 "歨" */
+0x01,0x01,0x11,0x11,0x11,0x11,0xff,0x00,0x01,0x11,0x11,0x11,0x11,0x29,0x47,0x80,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 27497 0x6b69 "歩" */
+0x01,0x01,0x11,0x11,0x11,0x11,0xff,0x01,0x01,0x11,0x11,0x21,0x40,0x03,0x1c,0xe0,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x10,0x08,0x14,0x24,0xc0,0x00,0x00,0x00,
+/* 27498 0x6b6a "歪" */
+0x00,0x7f,0x01,0x03,0x05,0x19,0x61,0x00,0x7f,0x01,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x60,0x18,0x04,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 27499 0x6b6b "歫" */
+0x08,0x08,0x08,0x08,0x48,0x4e,0x48,0x48,0x48,0x48,0x48,0x4e,0x58,0xe0,0x00,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 27500 0x6b6c "歬" */
+0x01,0x11,0x11,0x11,0xff,0x01,0x02,0x1f,0x10,0x12,0x11,0xff,0x12,0x21,0x40,0x80,
+0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 27501 0x6b6d "歭" */
+0x10,0x10,0x10,0x11,0x50,0x5c,0x53,0x50,0x50,0x51,0x50,0x5c,0x70,0xc0,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 27502 0x6b6e "歮" */
+0x01,0x01,0x11,0x11,0x11,0xff,0x00,0x08,0x08,0x48,0x4e,0x48,0x48,0x4e,0xf1,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x10,0x10,0x90,0x9c,0x90,0x90,0x90,0xfe,0x00,
+/* 27503 0x6b6f "歯" */
+0x01,0x01,0x11,0x11,0x11,0xff,0x00,0x29,0x25,0x2f,0x23,0x25,0x29,0x20,0x3f,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x28,0x48,0xe8,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 27504 0x6b70 "歰" */
+0x00,0x7e,0x12,0x52,0x93,0x22,0x2a,0x44,0x08,0x08,0x4e,0x48,0x48,0x4e,0xf1,0x00,
+0x00,0xfc,0x24,0xa4,0x24,0x44,0x54,0x88,0x10,0x10,0x9c,0x90,0x90,0x90,0xfe,0x00,
+/* 27505 0x6b71 "歱" */
+0x10,0x10,0x11,0x10,0x53,0x5c,0x51,0x51,0x51,0x51,0x51,0x5c,0x71,0xc0,0x03,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 27506 0x6b72 "歲" */
+0x00,0x08,0x08,0x08,0x7f,0x00,0x00,0x3f,0x20,0x2f,0x22,0x2a,0x2a,0x51,0x46,0x98,
+0x80,0xfc,0x80,0x80,0xfe,0x28,0x24,0xfe,0x20,0xa4,0x24,0x18,0x90,0x2a,0x46,0x82,
+/* 27507 0x6b73 "歳" */
+0x00,0x08,0x08,0x08,0x7f,0x00,0x00,0x3f,0x20,0x2f,0x22,0x2b,0x2a,0x52,0x4a,0x84,
+0x80,0xfc,0x80,0x80,0xfe,0x28,0x24,0xfe,0x20,0xa4,0x24,0x18,0x92,0xaa,0x46,0x82,
+/* 27508 0x6b74 "歴" */
+0x3f,0x22,0x22,0x3f,0x26,0x27,0x2a,0x32,0x22,0x22,0x20,0x22,0x42,0x42,0x9f,0x00,
+0xfe,0x10,0x10,0xbe,0x10,0x38,0xd4,0x92,0x10,0x50,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 27509 0x6b75 "歵" */
+0x10,0x11,0x10,0x11,0x50,0x5d,0x50,0x51,0x51,0x51,0x51,0x5d,0x71,0xc1,0x00,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27510 0x6b76 "歶" */
+0x08,0x2f,0x28,0x2f,0xf0,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x21,0x2f,0x24,0x20,
+0x44,0x78,0x42,0x3e,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x48,0xe8,0x28,0x18,
+/* 27511 0x6b77 "歷" */
+0x3f,0x20,0x23,0x3c,0x24,0x3f,0x24,0x2e,0x35,0x24,0x20,0x24,0x44,0x44,0xbf,0x00,
+0xfe,0x00,0x0c,0x70,0x10,0x7e,0x10,0x38,0x54,0x92,0x80,0xf8,0x80,0x80,0xfe,0x00,
+/* 27512 0x6b78 "歸" */
+0x10,0x7d,0x44,0x7c,0x40,0x7d,0x44,0x7f,0x12,0x10,0x5d,0x51,0x51,0x5d,0xe1,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 27513 0x6b79 "歹" */
+0x00,0xff,0x02,0x02,0x04,0x07,0x08,0x10,0x24,0x42,0x01,0x00,0x01,0x02,0x0c,0x70,
+0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 27514 0x6b7a "歺" */
+0x00,0x00,0x00,0x08,0x08,0x0f,0x10,0x14,0x22,0x41,0x01,0x00,0x01,0x02,0x0c,0x70,
+0x80,0x80,0xfe,0x80,0x80,0xf8,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 27515 0x6b7b "死" */
+0x00,0xff,0x10,0x10,0x10,0x1e,0x22,0x22,0x52,0x8c,0x04,0x08,0x08,0x10,0x20,0x40,
+0x00,0xfc,0x80,0x80,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 27516 0x6b7c "歼" */
+0x00,0x00,0xfd,0x20,0x20,0x3c,0x44,0x47,0x64,0x94,0x08,0x08,0x10,0x20,0x40,0x80,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 27517 0x6b7d "歽" */
+0x00,0x00,0xfd,0x21,0x21,0x3d,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x22,0x42,0x84,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27518 0x6b7e "歾" */
+0x00,0x00,0xfc,0x20,0x21,0x3e,0x44,0x44,0x64,0x95,0x0a,0x08,0x10,0x20,0x41,0x80,
+0x80,0x80,0x80,0xfc,0x54,0x54,0x54,0x94,0x94,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 27519 0x6b7f "歿" */
+0x00,0x00,0xfc,0x21,0x21,0x3e,0x44,0x47,0x65,0x94,0x08,0x08,0x10,0x20,0x41,0x86,
+0x80,0x80,0xfc,0x04,0x04,0x28,0x10,0xfc,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 27520 0x6b80 "殀" */
+0x00,0x00,0xfd,0x20,0x20,0x3c,0x45,0x44,0x64,0x94,0x08,0x08,0x10,0x20,0x41,0x82,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27521 0x6b81 "殁" */
+0x00,0x00,0xfc,0x20,0x20,0x3d,0x46,0x45,0x64,0x94,0x08,0x08,0x10,0x20,0x40,0x83,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 27522 0x6b82 "殂" */
+0x00,0x01,0xfd,0x21,0x21,0x3d,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x21,0x47,0x80,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 27523 0x6b83 "殃" */
+0x00,0x00,0xfc,0x21,0x21,0x3d,0x45,0x45,0x65,0x97,0x08,0x08,0x10,0x20,0x41,0x82,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 27524 0x6b84 "殄" */
+0x00,0x00,0xfc,0x20,0x21,0x3e,0x44,0x44,0x65,0x94,0x08,0x08,0x11,0x20,0x40,0x83,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 27525 0x6b85 "殅" */
+0x00,0x00,0xfd,0x21,0x21,0x3d,0x46,0x44,0x64,0x95,0x08,0x08,0x10,0x20,0x43,0x80,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 27526 0x6b86 "殆" */
+0x00,0xfc,0x20,0x20,0x20,0x3c,0x45,0x44,0x64,0x94,0x08,0x08,0x10,0x20,0x40,0x80,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 27527 0x6b87 "殇" */
+0x00,0x00,0xfc,0x21,0x22,0x3c,0x44,0x44,0x65,0x94,0x08,0x09,0x12,0x24,0x40,0x81,
+0x80,0x80,0xfe,0x00,0xf8,0x10,0x20,0x40,0xfc,0x94,0x94,0x24,0x24,0x44,0xa8,0x10,
+/* 27528 0x6b88 "殈" */
+0x00,0x00,0xfc,0x20,0x21,0x3d,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x21,0x43,0x80,
+0x20,0x20,0x40,0x80,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 27529 0x6b89 "殉" */
+0x00,0xfe,0x21,0x21,0x22,0x3d,0x45,0x45,0xa5,0x19,0x09,0x11,0x11,0x20,0x40,0x80,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 27530 0x6b8a "殊" */
+0x00,0x01,0xfd,0x21,0x21,0x3e,0x44,0x47,0x64,0x94,0x08,0x09,0x11,0x22,0x40,0x80,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 27531 0x6b8b "残" */
+0x00,0x00,0xfc,0x20,0x21,0x3c,0x44,0x47,0x64,0x94,0x08,0x08,0x10,0x20,0x43,0x80,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 27532 0x6b8c "殌" */
+0x00,0x03,0xf8,0x21,0x22,0x3c,0x4a,0x49,0x68,0x9b,0x08,0x10,0x10,0x20,0x47,0x80,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27533 0x6b8d "殍" */
+0x00,0x00,0xfd,0x20,0x21,0x3c,0x44,0x45,0x64,0x94,0x0b,0x08,0x10,0x20,0x40,0x80,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 27534 0x6b8e "殎" */
+0x00,0x00,0xfc,0x23,0x20,0x3c,0x45,0x45,0x65,0x96,0x08,0x08,0x10,0x20,0x41,0x82,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 27535 0x6b8f "殏" */
+0x00,0x00,0xfc,0x20,0x23,0x3c,0x45,0x44,0x64,0x94,0x08,0x09,0x12,0x20,0x40,0x80,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 27536 0x6b90 "殐" */
+0x00,0x00,0xfd,0x20,0x20,0x3d,0x45,0x45,0x65,0x94,0x08,0x08,0x11,0x22,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 27537 0x6b91 "殑" */
+0x00,0xfc,0x23,0x20,0x20,0x3d,0x45,0x45,0x65,0x95,0x08,0x08,0x10,0x20,0x41,0x82,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 27538 0x6b92 "殒" */
+0x00,0x00,0xfc,0x20,0x20,0x3c,0x45,0x45,0x65,0x95,0x09,0x09,0x10,0x20,0x40,0x83,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 27539 0x6b93 "殓" */
+0x00,0x00,0xfc,0x20,0x20,0x3d,0x46,0x44,0x64,0x94,0x09,0x08,0x10,0x20,0x43,0x80,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x44,0x24,0x24,0xa8,0x88,0x10,0xfe,0x00,
+/* 27540 0x6b94 "殔" */
+0x00,0x00,0xf9,0x20,0x20,0x3b,0x48,0x48,0x69,0x9a,0x09,0x10,0x11,0x22,0x40,0x80,
+0x20,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 27541 0x6b95 "殕" */
+0x00,0x00,0xfd,0x20,0x21,0x3c,0x44,0x47,0x64,0x94,0x09,0x09,0x11,0x21,0x41,0x81,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 27542 0x6b96 "殖" */
+0x00,0xfc,0x23,0x20,0x20,0x3d,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x21,0x47,0x80,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfe,0x00,
+/* 27543 0x6b97 "殗" */
+0x00,0x00,0xfb,0x21,0x22,0x3c,0x4b,0x4a,0x6a,0x9b,0x0a,0x12,0x13,0x20,0x40,0x80,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 27544 0x6b98 "殘" */
+0x00,0x00,0xfc,0x23,0x20,0x3c,0x44,0x47,0x64,0x94,0x0b,0x08,0x10,0x20,0x40,0x83,
+0x90,0x88,0xbc,0xc0,0x50,0x24,0xd4,0x2c,0x90,0xbc,0xc0,0x48,0x50,0x24,0xd4,0x0c,
+/* 27545 0x6b99 "殙" */
+0x00,0x03,0xfa,0x23,0x22,0x3a,0x4b,0x4a,0x69,0x99,0x09,0x11,0x11,0x21,0x41,0x81,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 27546 0x6b9a "殚" */
+0x01,0x00,0xfc,0x21,0x21,0x3d,0x45,0x45,0x65,0x95,0x08,0x08,0x13,0x20,0x40,0x80,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 27547 0x6b9b "殛" */
+0x00,0x03,0xf8,0x20,0x20,0x3b,0x4a,0x4a,0x6a,0x9a,0x0b,0x10,0x10,0x20,0x47,0x80,
+0x00,0xfc,0x08,0x10,0x20,0xae,0xa2,0xaa,0xa4,0xa4,0xaa,0x32,0xa0,0x40,0xfe,0x00,
+/* 27548 0x6b9c "殜" */
+0x00,0x01,0xfd,0x23,0x21,0x3d,0x45,0x45,0x65,0x94,0x0b,0x08,0x10,0x21,0x46,0x80,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 27549 0x6b9d "殝" */
+0x00,0x00,0xfb,0x20,0x21,0x38,0x4b,0x48,0x69,0x9a,0x08,0x11,0x10,0x20,0x43,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 27550 0x6b9e "殞" */
+0x00,0x01,0xf9,0x21,0x21,0x38,0x4b,0x4a,0x6b,0x9a,0x0b,0x12,0x13,0x20,0x41,0x82,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 27551 0x6b9f "殟" */
+0x00,0x01,0xfd,0x21,0x21,0x3d,0x45,0x45,0x64,0x97,0x0a,0x0a,0x12,0x22,0x47,0x80,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 27552 0x6ba0 "殠" */
+0x00,0x00,0xfd,0x21,0x21,0x3d,0x45,0x45,0x65,0x94,0x08,0x0b,0x10,0x20,0x41,0x86,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x88,0x04,0x02,
+/* 27553 0x6ba1 "殡" */
+0x00,0x00,0xfb,0x22,0x24,0x39,0x49,0x49,0x69,0x99,0x09,0x17,0x10,0x20,0x41,0x82,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 27554 0x6ba2 "殢" */
+0x01,0x01,0xfb,0x21,0x21,0x3a,0x4c,0x4b,0x6a,0x98,0x09,0x11,0x11,0x21,0x41,0x80,
+0x54,0x54,0xfe,0x54,0x54,0x72,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x24,0x2c,0x20,
+/* 27555 0x6ba3 "殣" */
+0x00,0xfc,0x23,0x20,0x20,0x3c,0x45,0x45,0x65,0x94,0x0b,0x08,0x11,0x20,0x43,0x80,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 27556 0x6ba4 "殤" */
+0x00,0x00,0xfd,0x22,0x20,0x3c,0x44,0x44,0x64,0x97,0x08,0x09,0x12,0x20,0x41,0x80,
+0x80,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x52,0x92,0x2a,0x44,
+/* 27557 0x6ba5 "殥" */
+0x00,0xfc,0x23,0x22,0x20,0x3d,0x44,0x45,0x65,0x95,0x09,0x09,0x10,0x20,0x41,0x82,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 27558 0x6ba6 "殦" */
+0x00,0x00,0xfd,0x21,0x21,0x3d,0x45,0x45,0x65,0x95,0x09,0x08,0x12,0x22,0x42,0x80,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 27559 0x6ba7 "殧" */
+0x02,0x01,0xfb,0x20,0x20,0x3b,0x4a,0x4a,0x6b,0x99,0x0b,0x13,0x15,0x21,0x45,0x82,
+0x14,0x12,0xd2,0x10,0x3e,0xd0,0x50,0x50,0xd0,0x28,0xa8,0x68,0x28,0x2a,0x2a,0x46,
+/* 27560 0x6ba8 "殨" */
+0x00,0x01,0xfd,0x21,0x20,0x3f,0x44,0x45,0x65,0x95,0x09,0x09,0x11,0x21,0x40,0x81,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27561 0x6ba9 "殩" */
+0x00,0x00,0xfa,0x23,0x24,0x3a,0x4b,0x4c,0x6a,0x99,0x0f,0x10,0x11,0x22,0x4c,0x80,
+0x80,0xdc,0x84,0xd4,0x48,0x94,0x24,0x40,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 27562 0x6baa "殪" */
+0x00,0x03,0xf8,0x21,0x20,0x3b,0x4a,0x49,0x68,0x99,0x09,0x11,0x11,0x20,0x43,0x80,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 27563 0x6bab "殫" */
+0x00,0x03,0xfa,0x22,0x23,0x38,0x49,0x49,0x69,0x99,0x09,0x10,0x13,0x20,0x40,0x80,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 27564 0x6bac "殬" */
+0x00,0x01,0xfd,0x21,0x20,0x3d,0x44,0x47,0x64,0x94,0x09,0x08,0x13,0x20,0x40,0x80,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 27565 0x6bad "殭" */
+0x00,0x03,0xfc,0x21,0x21,0x3d,0x45,0x47,0x64,0x95,0x09,0x09,0x11,0x21,0x40,0x83,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 27566 0x6bae "殮" */
+0x00,0x00,0xfc,0x20,0x21,0x3e,0x44,0x44,0x65,0x95,0x09,0x09,0x10,0x20,0x41,0x82,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 27567 0x6baf "殯" */
+0x00,0x00,0xfb,0x22,0x21,0x39,0x4a,0x49,0x6b,0x99,0x09,0x11,0x11,0x21,0x40,0x81,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27568 0x6bb0 "殰" */
+0x00,0x03,0xf8,0x21,0x20,0x3b,0x4a,0x4b,0x69,0x99,0x09,0x11,0x11,0x21,0x40,0x81,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 27569 0x6bb1 "殱" */
+0x00,0x00,0xfb,0x20,0x20,0x3b,0x49,0x4b,0x69,0x9b,0x09,0x13,0x11,0x21,0x47,0x80,
+0x88,0x8c,0xea,0x88,0x88,0xfe,0x48,0x6a,0x4a,0x6a,0x4c,0x6c,0x4a,0x6a,0x96,0x22,
+/* 27570 0x6bb2 "殲" */
+0x01,0x01,0xfa,0x20,0x27,0x39,0x4b,0x49,0x6b,0x99,0x0b,0x11,0x11,0x23,0x40,0x80,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 27571 0x6bb3 "殳" */
+0x00,0x0f,0x08,0x08,0x08,0x10,0x20,0xc0,0x3f,0x10,0x08,0x04,0x03,0x0c,0x30,0xc0,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x1e,0x00,0xf0,0x10,0x20,0x40,0x80,0x60,0x18,0x06,
+/* 27572 0x6bb4 "殴" */
+0x00,0x7e,0x40,0x44,0x64,0x54,0x49,0x48,0x55,0x54,0x64,0x40,0x40,0x7e,0x00,0x03,
+0x00,0xf8,0x88,0x88,0x88,0x86,0x00,0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 27573 0x6bb5 "段" */
+0x06,0x38,0x20,0x20,0x20,0x3c,0x21,0x20,0x3d,0x20,0x20,0x2c,0xf0,0x20,0x20,0x23,
+0x00,0xf8,0x88,0x88,0x88,0x86,0x00,0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 27574 0x6bb6 "殶" */
+0x10,0x08,0x00,0x7f,0x08,0x08,0x08,0x7e,0x08,0x08,0x08,0x08,0x0f,0xf0,0x40,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27575 0x6bb7 "殷" */
+0x06,0x38,0x20,0x3e,0x22,0x3e,0x22,0x3e,0x20,0x3e,0x22,0x22,0x42,0x4a,0x84,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27576 0x6bb8 "殸" */
+0x08,0x08,0x7f,0x08,0x08,0x3e,0x00,0x3e,0x2a,0x2a,0x3e,0x20,0x20,0x40,0x40,0x81,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27577 0x6bb9 "殹" */
+0x00,0x7f,0x48,0x48,0x5f,0x64,0x44,0x44,0x7f,0x44,0x4a,0x51,0x60,0x40,0x7e,0x01,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27578 0x6bba "殺" */
+0x04,0x44,0x28,0x10,0x28,0x44,0x92,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x21,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27579 0x6bbb "殻" */
+0x08,0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0x82,0x3c,0x24,0x24,0x25,0x26,0x44,0x81,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27580 0x6bbc "殼" */
+0x08,0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0xbe,0x00,0x3c,0x24,0x25,0x26,0x44,0x81,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27581 0x6bbd "殽" */
+0x42,0x24,0x18,0x24,0x52,0x10,0xff,0x20,0x3e,0x62,0xbe,0x22,0x3e,0x22,0x2a,0x25,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27582 0x6bbe "殾" */
+0x10,0x10,0x7d,0x12,0x14,0xff,0x10,0x20,0x7e,0xa2,0x22,0x3e,0x22,0x22,0x3e,0x23,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27583 0x6bbf "殿" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x2a,0x2a,0x3f,0x2a,0x2a,0x3f,0x20,0x4a,0x91,0x21,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27584 0x6bc0 "毀" */
+0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x10,0x10,0xfe,0x10,0x10,0x1e,0xf0,0x41,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27585 0x6bc1 "毁" */
+0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x00,0x00,0xfe,0x10,0x10,0x1e,0xf0,0x41,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27586 0x6bc2 "毂" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x10,0x7c,0x20,0x50,0x7c,0x10,0xfe,0x10,0x11,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27587 0x6bc3 "毃" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x85,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27588 0x6bc4 "毄" */
+0x10,0x7e,0x10,0x7e,0x52,0x7e,0x52,0x7e,0x10,0xff,0x10,0x7e,0x42,0x42,0x7e,0x43,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27589 0x6bc5 "毅" */
+0x10,0x08,0x7f,0x22,0x14,0xff,0x10,0x29,0xce,0x14,0x26,0xcd,0x15,0x24,0xd4,0x09,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 27590 0x6bc6 "毆" */
+0x00,0xff,0x80,0x9f,0x91,0x91,0x9f,0x80,0xbb,0xaa,0xaa,0xaa,0xbb,0x80,0xff,0x00,
+0x00,0xb8,0x28,0x28,0x28,0x46,0x00,0x7c,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0xc4,0x82,
+/* 27591 0x6bc7 "毇" */
+0x10,0x67,0x41,0x77,0x41,0x41,0x7f,0x08,0x49,0x2a,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x00,0x38,0x28,0x28,0x28,0x46,0x00,0x7c,0x24,0x24,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 27592 0x6bc8 "毈" */
+0x20,0xce,0x8a,0xaa,0xaa,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0xa8,0x2b,0x48,0x48,0x88,
+0x40,0x9c,0x94,0x94,0xd4,0x94,0xa6,0xc0,0x9c,0x94,0x94,0xd4,0x88,0x88,0x94,0xa2,
+/* 27593 0x6bc9 "毉" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x00,0x7f,0x11,0x11,0x29,0x45,0xff,0x00,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x00,0xfc,0x10,0x10,0x28,0x44,0xfe,0x00,
+/* 27594 0x6bca "毊" */
+0x08,0xff,0x08,0x3e,0x2a,0x3e,0x40,0x9f,0x02,0xff,0x08,0x3f,0xd0,0x13,0x12,0x13,
+0x78,0x48,0x86,0x78,0x48,0x30,0x48,0xf4,0x00,0xfe,0x20,0xf8,0x16,0x90,0x90,0xb0,
+/* 27595 0x6bcb "毋" */
+0x00,0x1f,0x11,0x11,0x11,0x11,0xff,0x21,0x22,0x22,0x22,0x3f,0x04,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0xa0,0x40,
+/* 27596 0x6bcc "毌" */
+0x00,0x1f,0x11,0x11,0x11,0x11,0x11,0xff,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,
+/* 27597 0x6bcd "母" */
+0x00,0x1f,0x10,0x12,0x11,0x11,0xff,0x20,0x22,0x21,0x21,0x3f,0x00,0x00,0x00,0x00,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0xa0,0x40,
+/* 27598 0x6bce "毎" */
+0x10,0x1f,0x20,0x20,0x5f,0x91,0x11,0x11,0xff,0x22,0x22,0x22,0x3f,0x00,0x00,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0xfc,0x10,0xa0,0x40,
+/* 27599 0x6bcf "每" */
+0x10,0x1f,0x20,0x20,0x5f,0x90,0x12,0x11,0xff,0x20,0x22,0x21,0x3f,0x00,0x00,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0xfc,0x10,0xa0,0x40,
+/* 27600 0x6bd0 "毐" */
+0x01,0x01,0xff,0x01,0x3f,0x00,0x1f,0x11,0x11,0xff,0x21,0x22,0x3f,0x04,0x08,0x10,
+0x00,0x00,0xfe,0x00,0xf8,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xfc,0x10,0x50,0x20,
+/* 27601 0x6bd1 "毑" */
+0x00,0x3e,0x22,0x32,0x2a,0x22,0x22,0xff,0x42,0x52,0x4a,0x42,0x7f,0x02,0x14,0x08,
+0x10,0x50,0x50,0x5c,0x74,0xd4,0x54,0x54,0x54,0x5c,0x50,0x50,0x42,0x42,0x3e,0x00,
+/* 27602 0x6bd2 "毒" */
+0x01,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x1f,0x12,0x11,0xff,0x22,0x21,0x3f,0x00,0x00,
+0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xfc,0x10,0x60,
+/* 27603 0x6bd3 "毓" */
+0x40,0x40,0x7d,0x80,0x7c,0x44,0x65,0x54,0xfe,0x44,0xa4,0x94,0xfe,0x05,0x29,0x12,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x26,0x00,
+/* 27604 0x6bd4 "比" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x20,0x26,0x38,0x20,0x00,
+0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 27605 0x6bd5 "毕" */
+0x20,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,0x21,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x80,0x88,0xb0,0xc0,0x80,0x84,0x84,0x7c,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 27606 0x6bd6 "毖" */
+0x20,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,0x01,0x00,0x48,0x48,0x89,0x0e,0x18,0xe7,
+0x80,0x88,0xb0,0xc0,0x80,0x84,0x84,0x7c,0x00,0x90,0xa4,0x42,0x82,0x10,0x10,0xf0,
+/* 27607 0x6bd7 "毗" */
+0x00,0x01,0x7d,0x55,0x55,0x55,0x55,0x7d,0x55,0x55,0x55,0x55,0x7d,0x45,0x01,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 27608 0x6bd8 "毘" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x80,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 27609 0x6bd9 "毙" */
+0x41,0x41,0x7d,0x41,0x4d,0x70,0x00,0xff,0x10,0x10,0x3e,0x42,0x14,0x08,0x30,0xc0,
+0x00,0x18,0xe0,0x04,0x04,0xfc,0x00,0xfe,0x80,0x88,0x90,0xe0,0x80,0x84,0x84,0x7c,
+/* 27610 0x6bda "毚" */
+0x1f,0x20,0x7f,0xa0,0x3f,0x20,0x3c,0x20,0x1f,0x20,0x7f,0xa2,0x3f,0x05,0x19,0xe0,
+0xc0,0x80,0xe0,0x20,0xe0,0x88,0xf4,0x84,0xfc,0x40,0xf0,0x10,0xf0,0x44,0x24,0xfc,
+/* 27611 0x6bdb "毛" */
+0x00,0x01,0x7e,0x02,0x02,0x03,0x3e,0x02,0x02,0x03,0xfe,0x02,0x02,0x02,0x02,0x01,
+0x10,0xf8,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xfc,0x00,0x00,0x04,0x04,0x04,0xfc,
+/* 27612 0x6bdc "毜" */
+0x08,0x1c,0x70,0x10,0x10,0x1c,0x71,0x11,0x12,0x1c,0xf0,0x10,0x10,0x10,0x0f,0x00,
+0x20,0x20,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0x20,0xa2,0x42,0x02,0xfe,0x00,
+/* 27613 0x6bdd "毝" */
+0x08,0x1c,0x70,0x11,0x10,0x1c,0x70,0x11,0x10,0x1c,0xf0,0x11,0x10,0x10,0x0f,0x00,
+0x04,0x08,0x30,0xc0,0x04,0x08,0x30,0xc0,0x04,0x08,0x30,0xc2,0x02,0x02,0xfe,0x00,
+/* 27614 0x6bde "毞" */
+0x20,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x80,0x88,0xb0,0xc0,0x84,0x84,0x7c,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 27615 0x6bdf "毟" */
+0x01,0x11,0x11,0x21,0x41,0x01,0x0e,0xf0,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x00,0x10,0x08,0x24,0x44,0x80,0x00,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 27616 0x6be0 "毠" */
+0x08,0x08,0x7f,0x09,0x11,0x11,0x25,0x42,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 27617 0x6be1 "毡" */
+0x08,0x1c,0x70,0x10,0x10,0x1c,0x70,0x11,0x11,0x1d,0xf1,0x11,0x11,0x10,0x0f,0x00,
+0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0xfa,0x0a,0x02,0xfe,0x00,
+/* 27618 0x6be2 "毢" */
+0x10,0x3b,0xe0,0x20,0x23,0x3a,0xe2,0x22,0x22,0x3b,0xe2,0x23,0x22,0x20,0x20,0x1f,
+0x00,0xf8,0xa0,0xa0,0xf8,0xa8,0xa8,0xa8,0xb8,0x08,0x08,0xf8,0x0a,0x02,0x02,0xfe,
+/* 27619 0x6be3 "毣" */
+0x00,0x7e,0x22,0x12,0x06,0x1a,0x62,0x00,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x00,0xfc,0x44,0x24,0x0c,0x34,0xc4,0x00,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 27620 0x6be4 "毤" */
+0x28,0x24,0x42,0x92,0x10,0x20,0x44,0xfe,0x02,0x24,0x24,0x24,0x24,0x44,0x43,0x80,
+0x18,0xe0,0x20,0x38,0xe0,0x20,0x3c,0xe0,0x22,0x22,0x1e,0x00,0x02,0x02,0xfe,0x00,
+/* 27621 0x6be5 "毥" */
+0x11,0x39,0xe1,0x22,0x24,0x3b,0xe2,0x23,0x22,0x3a,0xe3,0x20,0x20,0x20,0x20,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0xe4,0x24,0x24,0xe4,0x04,0x2a,0x12,0x02,0xfe,
+/* 27622 0x6be6 "毦" */
+0x00,0xff,0x44,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x4f,0xf4,0x04,0x04,0x04,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 27623 0x6be7 "毧" */
+0x10,0x38,0xe0,0x2f,0x20,0x3a,0xe2,0x2f,0x22,0x3a,0xe2,0x24,0x28,0x21,0x20,0x1f,
+0x50,0x48,0x40,0xfc,0x40,0x48,0x48,0x50,0x50,0x20,0x28,0x68,0x9a,0x0a,0x02,0xfe,
+/* 27624 0x6be8 "毨" */
+0x08,0x1c,0x70,0x11,0x10,0x1d,0x70,0x10,0x10,0x1c,0xf1,0x12,0x10,0x10,0x0f,0x00,
+0x20,0xa0,0xfc,0x20,0x20,0xfe,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,0x02,0xfe,0x00,
+/* 27625 0x6be9 "毩" */
+0x08,0x1c,0x71,0x10,0x10,0x1c,0x73,0x10,0x10,0x1c,0xf1,0x12,0x10,0x10,0x0f,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x02,0xfe,0x00,
+/* 27626 0x6bea "毪" */
+0x10,0x38,0xe0,0x21,0x23,0x38,0xe1,0x21,0x21,0x3a,0xe7,0x20,0x20,0x20,0x20,0x1f,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x20,0x22,0x22,0x22,0xfe,
+/* 27627 0x6beb "毫" */
+0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x81,0x3e,0x03,0x3e,0x03,0x7e,0x01,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0xf0,0x00,0xfa,0x02,0xfe,
+/* 27628 0x6bec "毬" */
+0x08,0x1c,0x70,0x13,0x10,0x1d,0x70,0x10,0x10,0x1d,0xf2,0x10,0x10,0x10,0x0f,0x00,
+0x20,0x28,0x24,0xfe,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,0x02,0xfe,0x00,
+/* 27629 0x6bed "毭" */
+0x00,0xff,0x00,0x00,0x7e,0x42,0x42,0x42,0x7e,0x00,0x42,0x22,0x24,0x0f,0xf0,0x40,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 27630 0x6bee "毮" */
+0x10,0x10,0x11,0x11,0xfa,0x10,0x14,0x1b,0x30,0xd3,0x10,0x13,0x10,0x17,0x50,0x20,
+0x20,0x20,0x24,0x22,0x2a,0x10,0x60,0x80,0x3c,0xc0,0x7c,0xc0,0x7c,0xc2,0x42,0x3e,
+/* 27631 0x6bef "毯" */
+0x10,0x3a,0xe2,0x24,0x20,0x39,0xe6,0x20,0x20,0x3a,0xe2,0x24,0x20,0x21,0x22,0x1f,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa2,0x12,0x0a,0xfe,
+/* 27632 0x6bf0 "毰" */
+0x08,0x1c,0x71,0x10,0x10,0x1c,0x73,0x10,0x10,0x1c,0xf0,0x10,0x10,0x10,0x0f,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x00,0xf8,0x88,0x88,0x8a,0xfa,0x02,0xfe,0x00,
+/* 27633 0x6bf1 "毱" */
+0x11,0x39,0xe1,0x22,0x24,0x3c,0xe2,0x27,0x20,0x39,0xe2,0x24,0x20,0x20,0x20,0x1f,
+0x00,0x00,0xfc,0x04,0x84,0x94,0xa4,0xfc,0x84,0xc4,0xa4,0x94,0xaa,0x92,0x02,0xfe,
+/* 27634 0x6bf2 "毲" */
+0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 27635 0x6bf3 "毳" */
+0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,0x00,0x18,0x71,0x1c,0x71,0x1c,0x71,0x14,0x18,
+0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,0x00,0x30,0xc0,0x78,0xc0,0x78,0xc4,0x44,0x3c,
+/* 27636 0x6bf4 "毴" */
+0x10,0x38,0xe0,0x27,0x20,0x38,0xe3,0x20,0x20,0x38,0xe7,0x20,0x20,0x20,0x20,0x1f,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x92,0x92,0x02,0xfe,
+/* 27637 0x6bf5 "毵" */
+0x08,0x10,0x24,0x7e,0x10,0xff,0x24,0x42,0x89,0x30,0xc4,0x08,0x32,0xc4,0x38,0xc0,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 27638 0x6bf6 "毶" */
+0x08,0x1c,0x71,0x10,0x13,0x1c,0x71,0x12,0x10,0x1c,0xf0,0x10,0x11,0x10,0x0f,0x00,
+0x40,0x88,0xfc,0x24,0xfe,0x88,0x34,0xc2,0x18,0xe0,0x0c,0x30,0xc0,0x02,0xfe,0x00,
+/* 27639 0x6bf7 "毷" */
+0x00,0x7f,0x41,0x5d,0x41,0x5d,0x41,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x22,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 27640 0x6bf8 "毸" */
+0x08,0x1d,0x71,0x11,0x11,0x1d,0x70,0x10,0x11,0x1d,0xf2,0x10,0x10,0x10,0x0f,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x14,0x52,0x42,0x48,0x3a,0x02,0x02,0xfe,0x00,
+/* 27641 0x6bf9 "毹" */
+0x08,0x14,0x22,0x41,0xbe,0x00,0x78,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x48,0x4a,0x59,
+0x04,0x0e,0x70,0x10,0x90,0x1c,0xf0,0x90,0x90,0x9e,0xf0,0x90,0x92,0x92,0x92,0x0e,
+/* 27642 0x6bfa "毺" */
+0x10,0x38,0xe0,0x21,0x26,0x38,0xe3,0x22,0x23,0x3a,0xe3,0x22,0x22,0x22,0x20,0x1f,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xc4,0x54,0xd4,0x54,0xd4,0x44,0x56,0xca,0x02,0xfe,
+/* 27643 0x6bfb "毻" */
+0x10,0x10,0xfe,0x20,0x7e,0x88,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x4a,0x44,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 27644 0x6bfc "毼" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x20,0x7f,0x91,0x51,0x69,0x41,0x7d,0x01,0x0a,0x04,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 27645 0x6bfd "毽" */
+0x10,0x38,0xe7,0x21,0x22,0x3a,0xe7,0x21,0x21,0x39,0xe6,0x22,0x25,0x28,0x20,0x1f,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x12,0xfe,0x02,0xfe,
+/* 27646 0x6bfe "毾" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x00,0xf7,0x10,0x94,0x52,0x31,0xd6,0x10,0x52,0x21,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x90,0x90,0x9e,0xf0,0x90,0x92,0x92,0x92,0x0e,
+/* 27647 0x6bff "毿" */
+0x10,0x22,0x7f,0x42,0x94,0xf7,0x08,0x36,0xc9,0x30,0xc4,0x19,0x62,0x0c,0x30,0xc0,
+0x04,0x0e,0x70,0x10,0x90,0x9c,0x70,0x10,0x10,0x9e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 27648 0x6c00 "氀" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x04,0x0e,0x70,0x90,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 27649 0x6c01 "氁" */
+0x11,0x39,0xe7,0x21,0x23,0x3a,0xe3,0x22,0x23,0x38,0xe7,0x20,0x21,0x22,0x20,0x1f,
+0x10,0x10,0xfc,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x12,0x0a,0x02,0xfe,
+/* 27650 0x6c02 "氂" */
+0x08,0x3e,0x08,0x7f,0x1c,0x2a,0x49,0x3f,0x20,0x20,0x2f,0x20,0x27,0x40,0x4f,0x80,
+0x20,0x7e,0xa4,0x28,0x10,0x28,0x44,0xfe,0x00,0x78,0x80,0xf0,0x80,0xfa,0x82,0x7e,
+/* 27651 0x6c03 "氃" */
+0x10,0x08,0x7f,0x22,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 27652 0x6c04 "氄" */
+0x7e,0x14,0x08,0xff,0x29,0x4a,0xa8,0x10,0x7f,0x55,0x63,0x5d,0x55,0x5d,0x41,0x43,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0x70,0x10,0x12,0x12,0x12,0x0e,
+/* 27653 0x6c05 "氅" */
+0x08,0x49,0x2a,0x7f,0x41,0x5d,0x55,0x5d,0x42,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0x28,0xf6,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 27654 0x6c06 "氆" */
+0x11,0x38,0xe3,0x20,0x22,0x39,0xe0,0x27,0x20,0x39,0xe1,0x21,0x21,0x21,0x20,0x1f,
+0x08,0x90,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0xf8,0x0a,0xfa,0x02,0xfe,
+/* 27655 0x6c07 "氇" */
+0x11,0x3b,0xe4,0x2b,0x22,0x3b,0xe2,0x27,0x20,0x3b,0xe2,0x23,0x22,0x23,0x20,0x1f,
+0x00,0xf0,0x10,0xf8,0x48,0xf8,0x48,0xfc,0x00,0xf8,0x08,0xf8,0x0a,0xfa,0x02,0xfe,
+/* 27656 0x6c08 "氈" */
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x22,0x22,0x22,0x1e,0x00,
+/* 27657 0x6c09 "氉" */
+0x00,0x7f,0x41,0x7f,0x00,0xf7,0x94,0xf7,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x04,0x0e,0x70,0x10,0x10,0x9c,0xf0,0x90,0x10,0x1e,0x70,0x10,0x12,0x12,0x92,0x0e,
+/* 27658 0x6c0a "氊" */
+0x10,0x3b,0xe0,0x23,0x22,0x3a,0xe2,0x23,0x21,0x39,0xe1,0x21,0x20,0x27,0x20,0x1f,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x08,0xf8,0x08,0xf8,0x02,0xfe,0x02,0xfe,
+/* 27659 0x6c0b "氋" */
+0x24,0xff,0x24,0xff,0x81,0x7e,0x00,0xff,0x10,0x28,0xd5,0x2e,0xd5,0x24,0xd4,0x08,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x9e,0x70,0x10,0x12,0x92,0x12,0x0e,
+/* 27660 0x6c0c "氌" */
+0x10,0x39,0xe2,0x25,0x21,0x39,0xe1,0x21,0x21,0x3a,0xe0,0x20,0x20,0x20,0x20,0x1f,
+0x80,0xf8,0x08,0xfc,0x24,0xfc,0x24,0xfc,0x54,0xfa,0x88,0xf8,0x8a,0xfa,0x02,0xfe,
+/* 27661 0x6c0d "氍" */
+0x77,0x55,0x77,0x55,0x77,0x55,0x77,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x20,
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x90,0x1e,0x70,0x10,0x12,0x12,0x92,0x0e,
+/* 27662 0x6c0e "氎" */
+0x3f,0x24,0x3f,0x24,0x7f,0x55,0x7f,0x55,0x7f,0x04,0x7f,0x48,0x1f,0x2a,0x04,0x7f,
+0x84,0x8e,0xf0,0x90,0xd0,0x5c,0xf0,0x50,0xd0,0x1e,0xf0,0x50,0x12,0x12,0x12,0xce,
+/* 27663 0x6c0f "氏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x28,0x30,0x20,
+0x10,0xf8,0x80,0x80,0x80,0x80,0xfe,0x80,0x80,0x40,0x40,0x22,0x12,0x0a,0x06,0x02,
+/* 27664 0x6c10 "氐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x21,0x28,0x30,0x20,
+0x10,0xf8,0x80,0x80,0x80,0x80,0xfe,0x80,0x80,0x40,0x40,0x22,0x12,0x8a,0x46,0x42,
+/* 27665 0x6c11 "民" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x24,0x28,0x30,0x20,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x80,0x80,0xfc,0x80,0x40,0x40,0x24,0x14,0x0c,0x04,
+/* 27666 0x6c12 "氒" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x28,0x31,0x21,0x01,0xff,0x01,0x01,0x01,0x01,
+0xf0,0x00,0x00,0x00,0xfc,0x80,0x40,0x24,0x14,0x0c,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 27667 0x6c13 "氓" */
+0x20,0x13,0x12,0x02,0xfa,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x7a,0x02,0x03,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 27668 0x6c14 "气" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x0a,0x0a,0x06,0x02,
+/* 27669 0x6c15 "氕" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x0a,0x0a,0x06,0x02,
+/* 27670 0x6c16 "氖" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x3f,0x11,0x12,0x17,0x20,0x20,0x42,0x81,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x10,0xd0,0x4a,0x4a,0x86,0x02,
+/* 27671 0x6c17 "気" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x00,0x30,0x0d,0x02,0x05,0x18,0x60,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x10,0x10,0x0a,0x8a,0x46,0x02,
+/* 27672 0x6c18 "氘" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x00,0x11,0x11,0x11,0x21,0x21,0x41,0x81,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x0a,0x0a,0x06,0x02,
+/* 27673 0x6c19 "氙" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x04,0x04,0x44,0x44,0x44,0x7f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x50,0x50,0x4a,0xca,0x46,0x02,
+/* 27674 0x6c1a "氚" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x00,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x80,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x8a,0x8a,0x86,0x82,
+/* 27675 0x6c1b "氛" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x12,0x21,0x40,0xbf,0x11,0x11,0x11,0x25,0x42,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0x10,0x90,0x50,0x12,0x0a,0x0a,0x06,0x02,
+/* 27676 0x6c1c "氜" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 27677 0x6c1d "氝" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x04,0x04,0x7f,0x44,0x4a,0x51,0x60,0x41,0x40,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0xd0,0x50,0x50,0x4a,0x4a,0x46,0x82,
+/* 27678 0x6c1e "氞" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x7f,0x04,0x7f,0x44,0x4a,0x51,0x60,0x41,0x40,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0xd0,0x50,0x52,0x4a,0x4a,0x46,0x82,
+/* 27679 0x6c1f "氟" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x12,0x7f,0x12,0x7f,0x52,0x7f,0x12,0x13,0x22,0x42,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x90,0x10,0xd2,0x4a,0x4a,0x86,0x02,
+/* 27680 0x6c20 "氠" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x04,0x7f,0x44,0x7f,0x44,0x7f,0x44,0x04,0x04,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0xd0,0x50,0xd0,0x52,0xca,0x4a,0x06,0x02,
+/* 27681 0x6c21 "氡" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x10,0x1f,0x20,0x51,0x0e,0x31,0xcc,0x03,0x1c,0x03,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x10,0x10,0x92,0x6a,0x0a,0x06,0x02,
+/* 27682 0x6c22 "氢" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x3f,0x03,0x0c,0x70,0x1f,0x02,0x02,0x7f,0x00,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0xd0,0x30,0xd2,0x0a,0x0a,0xf6,0x02,
+/* 27683 0x6c23 "氣" */
+0x10,0x10,0x3f,0x20,0x4f,0x80,0x3f,0x04,0x24,0x15,0x7f,0x0e,0x15,0x24,0x44,0x04,
+0x00,0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x10,0xd0,0x10,0x0a,0x8a,0x46,0x02,
+/* 27684 0x6c24 "氤" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x7f,0x44,0x44,0x5f,0x44,0x4a,0x51,0x7f,0x40,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x50,0x50,0x50,0x52,0x4a,0x4a,0xc6,0x42,
+/* 27685 0x6c25 "氥" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x7f,0x0a,0x3f,0x2a,0x2a,0x33,0x20,0x3f,0x20,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 27686 0x6c26 "氦" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x7f,0x08,0x11,0x3e,0x04,0x19,0x62,0x0d,0x30,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0x10,0x10,0x92,0x0a,0x0a,0x06,0x82,
+/* 27687 0x6c27 "氧" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x11,0x0a,0x7f,0x04,0x3f,0x04,0xff,0x04,0x04,0x04,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x10,0xd0,0x10,0x90,0x12,0xea,0x0a,0x06,0x02,
+/* 27688 0x6c28 "氨" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x7f,0x40,0x08,0xff,0x11,0x32,0x0c,0x1b,0x60,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x50,0x10,0xd0,0x12,0x0a,0x0a,0x06,0x82,
+/* 27689 0x6c29 "氩" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x7f,0x12,0x12,0x92,0x53,0x52,0x12,0xff,0x00,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x10,0x50,0x90,0x12,0x0a,0x0a,0xc6,0x02,
+/* 27690 0x6c2a "氪" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x7f,0x04,0x3f,0x20,0x3f,0x0a,0x12,0x22,0x41,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0x90,0x90,0x92,0x0a,0x4a,0x46,0xc2,
+/* 27691 0x6c2b "氫" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x7f,0x24,0x49,0x24,0x7f,0x04,0x04,0xff,0x00,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x90,0x10,0x90,0xd2,0x0a,0x0a,0xe6,0x02,
+/* 27692 0x6c2c "氬" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0xff,0x12,0x73,0x40,0x40,0x73,0x12,0x12,0xff,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0x90,0x90,0x92,0x8a,0x0a,0x06,0xe2,
+/* 27693 0x6c2d "氭" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x7f,0x04,0x3f,0x24,0x3f,0x24,0x3f,0x15,0x24,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0x90,0x90,0x92,0x8a,0x8a,0x06,0x82,
+/* 27694 0x6c2e "氮" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x24,0x0b,0x10,0x60,0x04,0x24,0x0b,0x10,0x60,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x10,0x90,0x50,0x12,0x8a,0x0a,0x86,0x42,
+/* 27695 0x6c2f "氯" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x7f,0x00,0x3f,0x00,0xff,0x24,0x15,0x24,0x4c,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0xf2,0x8a,0x0a,0x86,0x42,
+/* 27696 0x6c30 "氰" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x04,0x7f,0x04,0x3f,0x04,0xff,0x20,0x3f,0x20,0x21,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x10,0x90,0x10,0xf2,0x8a,0x8a,0x86,0x82,
+/* 27697 0x6c31 "氱" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x10,0x1f,0x10,0x3f,0x10,0x3f,0x4a,0x12,0x25,0x08,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x90,0x90,0x90,0xf0,0x10,0xd2,0x4a,0x4a,0x46,0x82,
+/* 27698 0x6c32 "氲" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x7f,0x4a,0xff,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x92,0x0a,0xca,0x46,0xe2,
+/* 27699 0x6c33 "氳" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x00,0x3f,0x24,0x2a,0x3f,0x00,0x7f,0x4a,0x4a,0xff,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x12,0xca,0x4a,0x46,0xe2,
+/* 27700 0x6c34 "水" */
+0x01,0x01,0x01,0x01,0x01,0x7d,0x05,0x09,0x09,0x11,0x11,0x21,0x41,0x81,0x05,0x02,
+0x00,0x00,0x00,0x08,0x08,0x90,0xa0,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0x00,
+/* 27701 0x6c35 "氵" */
+0x00,0x20,0x10,0x10,0x80,0x40,0x48,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 27702 0x6c36 "氶" */
+0x00,0x3f,0x00,0x00,0x00,0x01,0x7d,0x05,0x05,0x09,0x09,0x11,0x21,0xc1,0x05,0x02,
+0x00,0xf0,0x20,0x40,0x84,0x08,0x90,0xa0,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 27703 0x6c37 "氷" */
+0x01,0x01,0x11,0x09,0x09,0x01,0x7d,0x05,0x09,0x09,0x11,0x21,0xc1,0x01,0x05,0x02,
+0x00,0x00,0x00,0x08,0x08,0x90,0xa0,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0x00,
+/* 27704 0x6c38 "永" */
+0x02,0x01,0x00,0x1f,0x01,0x01,0x7d,0x05,0x05,0x09,0x09,0x11,0x21,0xc1,0x05,0x02,
+0x00,0x00,0x80,0x00,0x04,0x08,0x90,0xa0,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 27705 0x6c39 "氹" */
+0x00,0x00,0xf8,0x08,0x0f,0x09,0x11,0x12,0x22,0x24,0x48,0x41,0x40,0x40,0x3f,0x00,
+0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x44,0x40,0x82,0x02,0xfe,0x00,
+/* 27706 0x6c3a "氺" */
+0x01,0x01,0x01,0x41,0x21,0x11,0x11,0x01,0x05,0x09,0x11,0xe1,0x41,0x01,0x05,0x02,
+0x00,0x00,0x00,0x08,0x08,0x10,0x20,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,0x00,
+/* 27707 0x6c3b "氻" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x10,0x10,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x80,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 27708 0x6c3c "氼" */
+0x01,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,0x01,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0x00,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 27709 0x6c3d "氽" */
+0x01,0x02,0x04,0x08,0x31,0xc1,0x01,0x3d,0x05,0x09,0x09,0x11,0x21,0xc1,0x05,0x02,
+0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x84,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 27710 0x6c3e "氾" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x21,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 27711 0x6c3f "氿" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x49,0x09,0x11,0x11,0xe1,0x22,0x22,0x24,0x28,0x10,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 27712 0x6c40 "汀" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x48,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 27713 0x6c41 "汁" */
+0x00,0x20,0x10,0x10,0x80,0x40,0x47,0x10,0x10,0x20,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 27714 0x6c42 "求" */
+0x01,0x01,0x01,0x7f,0x01,0x21,0x11,0x09,0x03,0x05,0x09,0x11,0x61,0x01,0x05,0x02,
+0x20,0x10,0x00,0xfc,0x00,0x08,0x10,0xa0,0x40,0x20,0x10,0x08,0x06,0x00,0x00,0x00,
+/* 27715 0x6c43 "汃" */
+0x00,0x20,0x11,0x11,0x81,0x41,0x49,0x09,0x11,0x11,0xe1,0x22,0x22,0x24,0x28,0x10,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 27716 0x6c44 "汄" */
+0x00,0x20,0x10,0x10,0x80,0x40,0x48,0x08,0x10,0x10,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27717 0x6c45 "汅" */
+0x00,0x27,0x10,0x10,0x81,0x41,0x4a,0x0b,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0xfe,0x80,0x80,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 27718 0x6c46 "汆" */
+0x06,0x01,0x02,0x0c,0x31,0xc1,0x01,0x3d,0x05,0x09,0x09,0x11,0x21,0xc1,0x05,0x02,
+0x00,0x00,0x80,0x60,0x18,0x06,0x00,0x84,0x88,0x50,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 27719 0x6c47 "汇" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x23,0x00,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 27720 0x6c48 "汈" */
+0x00,0x27,0x10,0x10,0x80,0x40,0x48,0x08,0x10,0x11,0xe6,0x20,0x20,0x20,0x20,0x00,
+0x00,0xfc,0x04,0x04,0x04,0x14,0x24,0x44,0x84,0x04,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 27721 0x6c49 "汉" */
+0x00,0x27,0x12,0x12,0x82,0x41,0x49,0x09,0x10,0x10,0xe0,0x20,0x20,0x21,0x22,0x0c,
+0x00,0xf8,0x08,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 27722 0x6c4a "汊" */
+0x00,0x27,0x12,0x12,0x82,0x41,0x49,0x09,0x10,0x10,0xe0,0x20,0x20,0x21,0x22,0x0c,
+0x00,0xf8,0x08,0x88,0x48,0x50,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 27723 0x6c4b "汋" */
+0x00,0x20,0x11,0x11,0x82,0x42,0x54,0x19,0x10,0x20,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 27724 0x6c4c "汌" */
+0x02,0x22,0x12,0x12,0x82,0x42,0x42,0x12,0x12,0x22,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,
+/* 27725 0x6c4d "汍" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x0a,0x11,0x10,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x50,0x52,0x0a,0x0a,0x06,0x02,
+/* 27726 0x6c4e "汎" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x52,0x12,0x12,0x22,0xe2,0x22,0x24,0x24,0x28,0x10,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 27727 0x6c4f "汏" */
+0x00,0x20,0x10,0x10,0x80,0x47,0x48,0x08,0x10,0x10,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27728 0x6c50 "汐" */
+0x00,0x20,0x10,0x10,0x81,0x41,0x42,0x14,0x10,0x20,0xe0,0x20,0x20,0x20,0x21,0x06,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x84,0x48,0x28,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 27729 0x6c51 "汑" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x48,0x08,0x17,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 27730 0x6c52 "汒" */
+0x00,0x20,0x10,0x10,0x87,0x41,0x49,0x09,0x11,0x11,0xe1,0x21,0x21,0x21,0x21,0x00,
+0x40,0x20,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 27731 0x6c53 "汓" */
+0x00,0x23,0x10,0x10,0x80,0x40,0x48,0x0f,0x10,0x10,0xe0,0x20,0x20,0x20,0x21,0x00,
+0x00,0xf8,0x08,0x10,0x20,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 27732 0x6c54 "汔" */
+0x00,0x20,0x11,0x11,0x82,0x44,0x41,0x10,0x10,0x20,0xe0,0x21,0x22,0x22,0x21,0x00,
+0x80,0x80,0x00,0xfe,0x00,0x00,0xf8,0x08,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 27733 0x6c55 "汕" */
+0x00,0x20,0x10,0x10,0x84,0x44,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x27,0x20,0x00,
+0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,0x00,
+/* 27734 0x6c56 "汖" */
+0x01,0x01,0x21,0x21,0x21,0x3f,0x00,0x01,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,
+0x00,0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,
+/* 27735 0x6c57 "汗" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x48,0x08,0x17,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 27736 0x6c58 "汘" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x48,0x0f,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 27737 0x6c59 "汙" */
+0x00,0x21,0x10,0x10,0x80,0x40,0x48,0x0b,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 27738 0x6c5a "汚" */
+0x00,0x23,0x10,0x10,0x80,0x47,0x48,0x08,0x11,0x11,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0xf8,0x40,0x40,0x40,0xfe,0x80,0x80,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 27739 0x6c5b "汛" */
+0x00,0x27,0x11,0x11,0x81,0x41,0x41,0x17,0x11,0x21,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xd0,0x10,0x10,0x10,0x12,0x0a,0x0a,0x06,0x02,
+/* 27740 0x6c5c "汜" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x22,0x21,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 27741 0x6c5d "汝" */
+0x00,0x20,0x10,0x10,0x8f,0x41,0x41,0x12,0x12,0x26,0xe1,0x20,0x20,0x21,0x22,0x0c,
+0x80,0x80,0x80,0x80,0xfe,0x08,0x08,0x08,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x04,
+/* 27742 0x6c5e "汞" */
+0x00,0x3f,0x01,0x01,0x01,0xff,0x00,0x01,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,
+0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,
+/* 27743 0x6c5f "江" */
+0x00,0x20,0x17,0x10,0x80,0x40,0x48,0x08,0x10,0x10,0xe0,0x20,0x20,0x2f,0x20,0x00,
+0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,0x00,
+/* 27744 0x6c60 "池" */
+0x00,0x20,0x12,0x12,0x82,0x42,0x53,0x1e,0x12,0x22,0xe2,0x22,0x22,0x22,0x21,0x00,
+0x40,0x40,0x40,0x58,0x68,0xc8,0x48,0x48,0x48,0x48,0x58,0x42,0x02,0x02,0xfe,0x00,
+/* 27745 0x6c61 "污" */
+0x00,0x23,0x10,0x10,0x80,0x47,0x40,0x10,0x11,0x21,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0xf8,0x00,0x00,0x00,0xfe,0x80,0x80,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 27746 0x6c62 "汢" */
+0x00,0x20,0x10,0x10,0x80,0x40,0x47,0x10,0x10,0x20,0xe0,0x20,0x20,0x20,0x2f,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27747 0x6c63 "汣" */
+0x00,0x20,0x10,0x10,0x81,0x41,0x49,0x0a,0x10,0x10,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x80,0x80,0x80,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 27748 0x6c64 "汤" */
+0x00,0x23,0x10,0x10,0x80,0x41,0x43,0x11,0x11,0x21,0xe2,0x22,0x24,0x28,0x21,0x02,
+0x00,0xf0,0x20,0x40,0x80,0x00,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 27749 0x6c65 "汥" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x40,0x17,0x12,0x22,0xe1,0x20,0x20,0x20,0x23,0x0c,
+0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x04,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 27750 0x6c66 "汦" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x06,0x02,
+/* 27751 0x6c67 "汧" */
+0x00,0x27,0x11,0x11,0x81,0x41,0x49,0x0f,0x11,0x11,0xe1,0x21,0x21,0x21,0x22,0x04,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27752 0x6c68 "汨" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x23,0x22,0x00,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 27753 0x6c69 "汩" */
+0x00,0x20,0x17,0x14,0x84,0x44,0x44,0x17,0x14,0x24,0xe4,0x24,0x24,0x27,0x24,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 27754 0x6c6a "汪" */
+0x00,0x27,0x10,0x10,0x80,0x40,0x40,0x13,0x10,0x20,0xe0,0x20,0x20,0x20,0x2f,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27755 0x6c6b "汫" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x41,0x11,0x11,0x2f,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27756 0x6c6c "汬" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x10,0x20,0x41,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 27757 0x6c6d "汭" */
+0x00,0x20,0x10,0x10,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 27758 0x6c6e "汮" */
+0x01,0x41,0x21,0x22,0x02,0x85,0x48,0x40,0x10,0x20,0xe0,0x23,0x21,0x20,0x20,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x84,0x84,0x14,0x24,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 27759 0x6c6f "汯" */
+0x00,0x40,0x20,0x2f,0x00,0x80,0x41,0x51,0x11,0x22,0xe2,0x24,0x24,0x29,0x20,0x00,
+0x80,0x80,0x80,0xfe,0x80,0x80,0x20,0x20,0x20,0x40,0x40,0x88,0x88,0xfc,0x84,0x04,
+/* 27760 0x6c70 "汰" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x10,0x10,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x88,0x48,0x44,0x02,
+/* 27761 0x6c71 "汱" */
+0x00,0x20,0x10,0x10,0x80,0x47,0x48,0x08,0x10,0x10,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27762 0x6c72 "汲" */
+0x00,0x27,0x11,0x11,0x81,0x41,0x49,0x09,0x11,0x12,0xe2,0x22,0x24,0x24,0x28,0x03,
+0x00,0xf8,0x08,0x10,0x10,0x20,0x3c,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 27763 0x6c73 "汳" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x09,
+0x08,0x3c,0xc0,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 27764 0x6c74 "汴" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x10,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x80,0x40,0x40,0x00,0xfe,0x80,0x80,0xc0,0xa0,0x90,0x88,0x88,0x80,0x80,0x80,0x80,
+/* 27765 0x6c75 "汵" */
+0x00,0x20,0x10,0x10,0x81,0x42,0x4c,0x08,0x10,0x13,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x88,0x46,0x40,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,
+/* 27766 0x6c76 "汶" */
+0x00,0x20,0x10,0x17,0x81,0x41,0x49,0x09,0x11,0x10,0xe0,0x20,0x20,0x21,0x22,0x0c,
+0x80,0x40,0x40,0xfc,0x10,0x10,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 27767 0x6c77 "汷" */
+0x00,0x20,0x10,0x10,0x81,0x41,0x4a,0x0d,0x11,0x10,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x80,0x80,0x80,0x80,0xf8,0x08,0x08,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 27768 0x6c78 "汸" */
+0x00,0x20,0x10,0x17,0x81,0x41,0x49,0x09,0x11,0x11,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x40,0x40,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 27769 0x6c79 "汹" */
+0x00,0x20,0x11,0x10,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe3,0x22,0x22,0x23,0x20,0x00,
+0x00,0x08,0x08,0x88,0x52,0x52,0x22,0x22,0x52,0x92,0x0a,0x0a,0x02,0xfe,0x02,0x00,
+/* 27770 0x6c7a "決" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x48,0x08,0x17,0x10,0xe1,0x21,0x22,0x24,0x28,0x10,
+0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x88,0xfe,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 27771 0x6c7b "汻" */
+0x00,0x20,0x10,0x11,0x81,0x41,0x4a,0x08,0x10,0x17,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 27772 0x6c7c "汼" */
+0x00,0x20,0x11,0x11,0x81,0x42,0x42,0x14,0x10,0x27,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 27773 0x6c7d "汽" */
+0x01,0x21,0x11,0x12,0x84,0x41,0x48,0x08,0x13,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 27774 0x6c7e "汾" */
+0x00,0x21,0x11,0x12,0x82,0x44,0x58,0x13,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x10,0x10,0x10,0x08,0x08,0x04,0x02,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 27775 0x6c7f "汿" */
+0x00,0x23,0x10,0x11,0x80,0x40,0x47,0x10,0x10,0x20,0xe0,0x20,0x20,0x20,0x21,0x00,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xfe,0x42,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 27776 0x6c80 "沀" */
+0x08,0x08,0x08,0x09,0x09,0xea,0x2c,0x2a,0x29,0x49,0x48,0x88,0x08,0x08,0x28,0x10,
+0x00,0x7c,0x04,0x28,0x10,0x08,0xfe,0x12,0x14,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 27777 0x6c81 "沁" */
+0x00,0x20,0x10,0x10,0x81,0x41,0x41,0x15,0x15,0x25,0xe5,0x29,0x21,0x21,0x20,0x00,
+0x00,0x80,0x40,0x20,0x20,0x00,0x00,0x04,0x02,0x02,0x02,0x08,0x08,0x08,0xf8,0x00,
+/* 27778 0x6c82 "沂" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x43,0x12,0x12,0x22,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x08,0x3c,0xc0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27779 0x6c83 "沃" */
+0x00,0x20,0x17,0x10,0x80,0x40,0x40,0x17,0x10,0x20,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27780 0x6c84 "沄" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x47,0x10,0x10,0x20,0xe0,0x21,0x22,0x27,0x22,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 27781 0x6c85 "沅" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x47,0x11,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 27782 0x6c86 "沆" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x49,0x09,0x11,0x11,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 27783 0x6c87 "沇" */
+0x00,0x20,0x11,0x11,0x82,0x47,0x40,0x11,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x80,0x00,0x10,0x08,0xfc,0x04,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 27784 0x6c88 "沈" */
+0x00,0x20,0x10,0x17,0x84,0x48,0x40,0x10,0x10,0x20,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x40,0x40,0xfe,0x44,0x48,0x40,0xa0,0xa0,0xa0,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 27785 0x6c89 "沉" */
+0x00,0x20,0x13,0x12,0x84,0x40,0x41,0x11,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x00,0x00,0xfe,0x02,0x04,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 27786 0x6c8a "沊" */
+0x10,0x10,0x10,0x7e,0x53,0x94,0x10,0x11,0x29,0x2a,0x2c,0x28,0x28,0x48,0x47,0x80,
+0x20,0x20,0x20,0x24,0xa8,0xb0,0xa8,0x24,0x22,0x22,0x20,0xa2,0x42,0x02,0xfe,0x00,
+/* 27787 0x6c8b "沋" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x10,0x10,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 27788 0x6c8c "沌" */
+0x00,0x20,0x10,0x17,0x80,0x42,0x4a,0x0a,0x12,0x13,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 27789 0x6c8d "沍" */
+0x00,0x27,0x10,0x10,0x80,0x40,0x49,0x09,0x11,0x12,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x10,0x10,0x10,0xfe,0x00,
+/* 27790 0x6c8e "沎" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x56,0x1a,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x20,0x20,0x20,0x24,0x24,0x28,0x30,0x20,0x60,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 27791 0x6c8f "沏" */
+0x00,0x22,0x12,0x12,0x82,0x42,0x53,0x1e,0x12,0x22,0xe2,0x23,0x22,0x20,0x20,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0xa4,0x24,0x24,0x24,0xa4,0x24,0x44,0x44,0x94,0x08,
+/* 27792 0x6c90 "沐" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x11,0x11,0xe2,0x24,0x28,0x20,0x20,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 27793 0x6c91 "沑" */
+0x00,0x23,0x10,0x10,0x80,0x40,0x48,0x0b,0x11,0x11,0xe1,0x21,0x21,0x21,0x2f,0x00,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 27794 0x6c92 "沒" */
+0x00,0x20,0x10,0x11,0x81,0x42,0x48,0x0b,0x11,0x10,0xe0,0x20,0x20,0x20,0x21,0x06,
+0x80,0x80,0xfc,0x04,0x04,0x28,0x10,0xfc,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 27795 0x6c93 "沓" */
+0x01,0x01,0x7d,0x05,0x09,0x31,0xc5,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x08,0x10,0xa0,0x60,0x18,0x06,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 27796 0x6c94 "沔" */
+0x00,0x27,0x10,0x10,0x82,0x42,0x4a,0x0a,0x12,0x13,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 27797 0x6c95 "沕" */
+0x01,0x21,0x11,0x11,0x82,0x44,0x40,0x11,0x11,0x22,0xe4,0x20,0x21,0x22,0x24,0x00,
+0x00,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x04,0x04,0x28,0x10,
+/* 27798 0x6c96 "沖" */
+0x00,0x20,0x10,0x10,0x87,0x44,0x44,0x14,0x14,0x24,0xe7,0x24,0x20,0x20,0x20,0x00,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x40,
+/* 27799 0x6c97 "沗" */
+0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x18,0xe1,0x11,0x0b,0x05,0x19,0x61,0x05,0x02,
+0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x30,0x0e,0x10,0x20,0xc0,0x30,0x08,0x00,0x00,
+/* 27800 0x6c98 "沘" */
+0x00,0x22,0x12,0x12,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe2,0x22,0x22,0x23,0x22,0x00,
+0x20,0x20,0x20,0x22,0x22,0x24,0xa8,0x30,0x20,0x20,0x20,0x22,0xa2,0x22,0x1e,0x00,
+/* 27801 0x6c99 "沙" */
+0x00,0x20,0x10,0x11,0x81,0x42,0x42,0x14,0x10,0x20,0xe0,0x20,0x20,0x20,0x21,0x06,
+0x40,0x40,0x40,0x48,0x44,0x42,0x42,0x48,0x48,0x48,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 27802 0x6c9a "沚" */
+0x00,0x20,0x10,0x10,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27803 0x6c9b "沛" */
+0x00,0x40,0x20,0x2f,0x00,0x80,0x47,0x54,0x14,0x24,0xe4,0x24,0x24,0x20,0x20,0x00,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 27804 0x6c9c "沜" */
+0x00,0x22,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x10,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 27805 0x6c9d "沝" */
+0x08,0x08,0x08,0x0a,0x0a,0xed,0x28,0x2c,0x2a,0x2a,0x49,0x49,0x8a,0x08,0x28,0x10,
+0x20,0x20,0x20,0x20,0x32,0xb2,0xb4,0xa8,0xa8,0xa8,0x24,0x24,0x22,0x20,0xa0,0x40,
+/* 27806 0x6c9e "沞" */
+0x00,0x4f,0x20,0x20,0x00,0x87,0x44,0x54,0x14,0x24,0xe4,0x24,0x24,0x20,0x20,0x00,
+0x00,0xfe,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 27807 0x6c9f "沟" */
+0x01,0x21,0x11,0x11,0x82,0x44,0x40,0x11,0x11,0x22,0xe7,0x22,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x84,0x84,0x04,0x44,0x24,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 27808 0x6ca0 "沠" */
+0x00,0x20,0x17,0x14,0x84,0x44,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x28,0x28,0x10,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0x88,0x84,0x84,0x82,0x00,
+/* 27809 0x6ca1 "没" */
+0x00,0x21,0x11,0x11,0x81,0x42,0x54,0x18,0x13,0x22,0xe1,0x21,0x20,0x20,0x21,0x0e,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x0e,0x00,0xf8,0x08,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 27810 0x6ca2 "沢" */
+0x00,0x21,0x11,0x11,0x81,0x41,0x49,0x09,0x11,0x11,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 27811 0x6ca3 "沣" */
+0x00,0x20,0x10,0x13,0x80,0x40,0x48,0x09,0x10,0x10,0xe0,0x27,0x20,0x20,0x20,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 27812 0x6ca4 "沤" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x23,0x22,0x23,0x00,
+0x00,0xfc,0x00,0x08,0x88,0x50,0x50,0x20,0x20,0x50,0x50,0x88,0x08,0x00,0xfe,0x00,
+/* 27813 0x6ca5 "沥" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x29,0x12,
+0x00,0xfe,0x00,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 27814 0x6ca6 "沦" */
+0x00,0x20,0x10,0x10,0x81,0x42,0x44,0x11,0x11,0x21,0xe1,0x21,0x21,0x21,0x20,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 27815 0x6ca7 "沧" */
+0x00,0x40,0x20,0x21,0x02,0x84,0x4b,0x42,0x12,0x22,0xe2,0x22,0x22,0x22,0x21,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x04,0xf2,0x10,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 27816 0x6ca8 "沨" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x23,0x24,0x24,0x28,0x10,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 27817 0x6ca9 "沩" */
+0x00,0x22,0x11,0x11,0x80,0x47,0x40,0x10,0x10,0x20,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x40,0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x84,0xa4,0x94,0x14,0x04,0x04,0x28,0x10,
+/* 27818 0x6caa "沪" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x42,0x13,0x12,0x22,0xe2,0x22,0x24,0x24,0x28,0x10,
+0x80,0x40,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 27819 0x6cab "沫" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x48,0x0b,0x10,0x10,0xe1,0x22,0x24,0x28,0x20,0x00,
+0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,0x40,
+/* 27820 0x6cac "沬" */
+0x00,0x20,0x10,0x13,0x80,0x40,0x48,0x0f,0x10,0x11,0xe1,0x22,0x24,0x28,0x20,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 27821 0x6cad "沭" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x40,0x10,0x11,0x21,0xe2,0x24,0x28,0x20,0x20,0x00,
+0x40,0x50,0x48,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 27822 0x6cae "沮" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 27823 0x6caf "沯" */
+0x01,0x01,0x7d,0x05,0x09,0x31,0xc5,0x02,0x7f,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0x08,0x10,0xa0,0x60,0x18,0x06,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 27824 0x6cb0 "沰" */
+0x00,0x20,0x17,0x10,0x80,0x40,0x48,0x09,0x13,0x15,0xe9,0x21,0x21,0x21,0x21,0x01,
+0x00,0x00,0xfe,0x40,0x40,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27825 0x6cb1 "沱" */
+0x00,0x20,0x10,0x17,0x84,0x48,0x42,0x12,0x12,0x22,0xe3,0x22,0x22,0x22,0x21,0x00,
+0x80,0x40,0x40,0xfc,0x04,0x08,0x00,0x10,0x20,0x40,0x80,0x04,0x04,0x04,0xfc,0x00,
+/* 27826 0x6cb2 "沲" */
+0x01,0x21,0x13,0x12,0x84,0x48,0x42,0x12,0x13,0x2e,0xe2,0x22,0x22,0x22,0x21,0x00,
+0x00,0x00,0xfc,0x00,0x40,0x40,0x78,0xc8,0x48,0x48,0x48,0x5a,0x42,0x02,0xfe,0x00,
+/* 27827 0x6cb3 "河" */
+0x00,0x20,0x17,0x10,0x80,0x43,0x42,0x12,0x12,0x22,0xe3,0x22,0x20,0x20,0x20,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0x48,0xc8,0x48,0x08,0x08,0x28,0x10,
+/* 27828 0x6cb4 "沴" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x40,0x10,0x13,0x20,0xe0,0x20,0x23,0x20,0x20,0x07,
+0x40,0x40,0xa0,0x10,0x08,0x26,0x40,0x80,0x10,0x20,0x40,0x88,0x10,0x20,0xc0,0x00,
+/* 27829 0x6cb5 "沵" */
+0x00,0x20,0x10,0x11,0x81,0x42,0x54,0x10,0x11,0x21,0xe2,0x22,0x24,0x20,0x20,0x00,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 27830 0x6cb6 "沶" */
+0x00,0x23,0x10,0x10,0x80,0x40,0x4f,0x10,0x10,0x22,0xe2,0x24,0x24,0x28,0x21,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x40,0x40,0x48,0x44,0x44,0x42,0x42,0x40,0x80,
+/* 27831 0x6cb7 "沷" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x49,0x09,0x11,0x12,0xe2,0x24,0x24,0x28,0x20,0x03,
+0x90,0x88,0x88,0x80,0xfe,0x80,0x00,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 27832 0x6cb8 "沸" */
+0x01,0x21,0x11,0x17,0x81,0x41,0x47,0x15,0x15,0x27,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x20,0x20,0x20,0xf8,0x28,0x28,0xf8,0x20,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 27833 0x6cb9 "油" */
+0x00,0x20,0x10,0x10,0x87,0x44,0x44,0x14,0x14,0x27,0xe4,0x24,0x24,0x24,0x27,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 27834 0x6cba "沺" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x44,0x17,0x14,0x24,0xe4,0x24,0x24,0x27,0x24,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,0x00,
+/* 27835 0x6cbb "治" */
+0x00,0x20,0x10,0x11,0x82,0x47,0x40,0x10,0x13,0x22,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27836 0x6cbc "沼" */
+0x00,0x27,0x10,0x10,0x80,0x41,0x41,0x12,0x14,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 27837 0x6cbd "沽" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x13,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27838 0x6cbe "沾" */
+0x00,0x20,0x10,0x10,0x80,0x40,0x48,0x08,0x13,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 27839 0x6cbf "沿" */
+0x00,0x21,0x11,0x11,0x81,0x41,0x42,0x14,0x10,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x0e,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27840 0x6cc0 "泀" */
+0x00,0x23,0x10,0x10,0x87,0x40,0x48,0x0b,0x12,0x12,0xe2,0x23,0x20,0x20,0x20,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 27841 0x6cc1 "況" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x47,0x11,0x11,0x21,0xe1,0x22,0x22,0x24,0x28,0x10,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 27842 0x6cc2 "泂" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 27843 0x6cc3 "泃" */
+0x01,0x21,0x12,0x13,0x84,0x48,0x43,0x12,0x12,0x22,0xe2,0x23,0x22,0x20,0x20,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 27844 0x6cc4 "泄" */
+0x00,0x22,0x12,0x12,0x82,0x4f,0x42,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x23,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 27845 0x6cc5 "泅" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x44,0x14,0x14,0x24,0xe4,0x25,0x26,0x24,0x27,0x04,
+0x00,0xfc,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0xfc,0x04,
+/* 27846 0x6cc6 "泆" */
+0x00,0x20,0x12,0x12,0x83,0x42,0x44,0x10,0x17,0x20,0xe0,0x20,0x21,0x22,0x24,0x08,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 27847 0x6cc7 "泇" */
+0x02,0x22,0x12,0x12,0x87,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x29,0x10,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x80,
+/* 27848 0x6cc8 "泈" */
+0x00,0x20,0x10,0x11,0x83,0x44,0x40,0x10,0x13,0x2c,0xe0,0x20,0x20,0x21,0x20,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xc0,0x20,0x10,0x80,0x60,0x10,
+/* 27849 0x6cc9 "泉" */
+0x01,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 27850 0x6cca "泊" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4a,0x0a,0x13,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 27851 0x6ccb "泋" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x41,0x11,0x11,0x2f,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x50,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27852 0x6ccc "泌" */
+0x00,0x20,0x10,0x10,0x81,0x41,0x41,0x15,0x15,0x25,0xe5,0x29,0x21,0x23,0x24,0x08,
+0x00,0x80,0x40,0x28,0x28,0x08,0x10,0x14,0x22,0x22,0x42,0x88,0x08,0x08,0xf8,0x00,
+/* 27853 0x6ccd "泍" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x48,0x08,0x11,0x11,0xe2,0x25,0x28,0x20,0x20,0x00,
+0x40,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0xf4,0x42,0x40,0x40,0x40,
+/* 27854 0x6cce "泎" */
+0x01,0x21,0x11,0x11,0x82,0x42,0x44,0x10,0x10,0x20,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 27855 0x6ccf "泏" */
+0x00,0x20,0x12,0x12,0x82,0x42,0x4b,0x08,0x10,0x10,0xe4,0x24,0x24,0x24,0x27,0x00,
+0x40,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x40,0x44,0x44,0x44,0x44,0xfc,0x04,
+/* 27856 0x6cd0 "泐" */
+0x00,0x47,0x24,0x25,0x05,0x86,0x45,0x54,0x14,0x24,0xe6,0x25,0x24,0x24,0x24,0x04,
+0x10,0x90,0x90,0x10,0x7e,0x12,0x12,0x92,0x92,0x92,0x92,0x12,0x22,0x22,0x4a,0x84,
+/* 27857 0x6cd1 "泑" */
+0x02,0x42,0x22,0x24,0x05,0x89,0x4e,0x42,0x14,0x24,0xe9,0x2f,0x21,0x20,0x20,0x01,
+0x20,0x20,0x20,0x20,0x7c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 27858 0x6cd2 "泒" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 27859 0x6cd3 "泓" */
+0x00,0x27,0x10,0x10,0x80,0x47,0x44,0x14,0x14,0x27,0xe0,0x20,0x20,0x20,0x25,0x02,
+0x08,0x88,0x88,0x88,0x88,0x88,0x08,0x10,0x10,0x90,0x94,0xa4,0xa2,0xbe,0x02,0x00,
+/* 27860 0x6cd4 "泔" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x41,0x11,0x11,0x21,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27861 0x6cd5 "法" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x40,0x10,0x1f,0x20,0xe0,0x21,0x22,0x24,0x2f,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0x80,0x00,0x10,0x08,0xfc,0x04,
+/* 27862 0x6cd6 "泖" */
+0x00,0x21,0x16,0x14,0x84,0x44,0x44,0x14,0x14,0x25,0xe6,0x24,0x21,0x21,0x22,0x04,
+0x00,0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xb4,0xa8,0x20,0x20,0x20,0x20,
+/* 27863 0x6cd7 "泗" */
+0x00,0x20,0x17,0x14,0x84,0x44,0x44,0x14,0x14,0x25,0xe5,0x26,0x24,0x24,0x27,0x04,
+0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x1c,0x04,0x04,0x04,0xfc,0x04,
+/* 27864 0x6cd8 "泘" */
+0x00,0x20,0x17,0x10,0x84,0x42,0x42,0x10,0x17,0x20,0xe0,0x20,0x20,0x20,0x21,0x00,
+0x10,0x78,0xc0,0x40,0x44,0x44,0x48,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 27865 0x6cd9 "泙" */
+0x00,0x23,0x10,0x10,0x82,0x41,0x49,0x08,0x17,0x10,0xe0,0x20,0x20,0x20,0x20,0x00,
+0x00,0xf8,0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 27866 0x6cda "泚" */
+0x01,0x21,0x11,0x15,0x85,0x45,0x45,0x15,0x15,0x25,0xe5,0x25,0x25,0x2e,0x24,0x00,
+0x20,0x20,0x20,0x24,0x24,0xe8,0x30,0x20,0x20,0x20,0x20,0x22,0xe2,0x22,0x1e,0x00,
+/* 27867 0x6cdb "泛" */
+0x00,0x20,0x17,0x10,0x80,0x40,0x47,0x10,0x10,0x20,0xe0,0x21,0x22,0x25,0x28,0x00,
+0x10,0x78,0x80,0x00,0x80,0x40,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0xfc,0x00,
+/* 27868 0x6cdc "泜" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 27869 0x6cdd "泝" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x08,0x3c,0xc0,0x00,0x00,0x00,0xfe,0x10,0x10,0x70,0x10,0x18,0x14,0x10,0x10,0x10,
+/* 27870 0x6cde "泞" */
+0x00,0x20,0x10,0x17,0x84,0x48,0x40,0x10,0x17,0x20,0xe0,0x20,0x20,0x20,0x21,0x00,
+0x80,0x40,0x40,0xfc,0x04,0x08,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 27871 0x6cdf "泟" */
+0x00,0x27,0x10,0x10,0x80,0x40,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x78,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27872 0x6ce0 "泠" */
+0x00,0x20,0x10,0x10,0x81,0x42,0x44,0x10,0x13,0x20,0xe0,0x21,0x20,0x20,0x20,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 27873 0x6ce1 "泡" */
+0x01,0x21,0x11,0x12,0x82,0x47,0x4a,0x12,0x12,0x23,0xe2,0x22,0x22,0x22,0x21,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x14,0x08,0x02,0x02,0xfe,0x00,
+/* 27874 0x6ce2 "波" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x09,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 27875 0x6ce3 "泣" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x40,0x12,0x12,0x21,0xe1,0x21,0x21,0x20,0x2f,0x00,
+0x80,0x40,0x40,0x00,0xfc,0x00,0x08,0x08,0x08,0x10,0x10,0x10,0x20,0x20,0xfe,0x00,
+/* 27876 0x6ce4 "泤" */
+0x00,0x21,0x10,0x14,0x84,0x44,0x44,0x14,0x14,0x24,0xe4,0x25,0x26,0x24,0x20,0x01,
+0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x10,0x10,0x10,0x28,0x24,0x44,0x82,0x02,
+/* 27877 0x6ce5 "泥" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x28,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 27878 0x6ce6 "泦" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x13,0x12,0xe2,0x22,0x24,0x24,0x29,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x88,0x8a,0x0a,0x06,
+/* 27879 0x6ce7 "泧" */
+0x00,0x20,0x10,0x10,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x23,0x22,0x20,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 27880 0x6ce8 "注" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x40,0x10,0x13,0x20,0xe0,0x20,0x20,0x20,0x2f,0x00,
+0x80,0x40,0x00,0xfc,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27881 0x6ce9 "泩" */
+0x00,0x22,0x12,0x12,0x83,0x44,0x54,0x18,0x10,0x23,0xe0,0x20,0x20,0x20,0x2f,0x00,
+0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27882 0x6cea "泪" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 27883 0x6ceb "泫" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x41,0x12,0x17,0x20,0xe0,0x21,0x22,0x27,0x22,0x00,
+0x80,0x40,0x40,0xfe,0x40,0x80,0x08,0x10,0xe0,0x40,0x80,0x08,0x04,0xfe,0x02,0x00,
+/* 27884 0x6cec "泬" */
+0x00,0x20,0x10,0x13,0x82,0x44,0x40,0x10,0x10,0x20,0xe0,0x21,0x21,0x21,0x22,0x04,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 27885 0x6ced "泭" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x4a,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x28,0x10,
+/* 27886 0x6cee "泮" */
+0x00,0x20,0x12,0x11,0x81,0x40,0x4b,0x08,0x10,0x10,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x40,0x40,0x48,0x48,0x50,0x40,0xf8,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,
+/* 27887 0x6cef "泯" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x13,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x8a,0x06,0x02,
+/* 27888 0x6cf0 "泰" */
+0x01,0x01,0x7f,0x01,0x3f,0x02,0xff,0x04,0x09,0x31,0xcb,0x05,0x19,0x61,0x05,0x02,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x18,0x26,0xc0,0x30,0x08,0x00,0x00,
+/* 27889 0x6cf1 "泱" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4a,0x0a,0x12,0x17,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 27890 0x6cf2 "泲" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4a,0x0b,0x10,0x10,0xe1,0x22,0x2c,0x20,0x20,0x00,
+0x40,0x40,0x5c,0xe0,0x40,0x40,0x40,0xfc,0x44,0xc4,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 27891 0x6cf3 "泳" */
+0x00,0x20,0x10,0x13,0x80,0x40,0x4f,0x11,0x11,0x21,0xe2,0x24,0x28,0x30,0x21,0x00,
+0x80,0x40,0x20,0xc0,0x44,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x40,0x80,
+/* 27892 0x6cf4 "泴" */
+0x01,0x01,0x7d,0x05,0x09,0x31,0xc5,0x02,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x08,0x10,0xa0,0x60,0x18,0x06,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 27893 0x6cf5 "泵" */
+0x00,0xff,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x01,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 27894 0x6cf6 "泶" */
+0x22,0x11,0x11,0x00,0x7f,0x40,0x80,0x01,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,
+0x08,0x08,0x10,0x20,0xfe,0x02,0x04,0x00,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,
+/* 27895 0x6cf7 "泷" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x49,0x09,0x11,0x12,0xe2,0x22,0x24,0x24,0x29,0x10,
+0x20,0x10,0x10,0x00,0xfe,0x40,0x40,0x48,0x48,0x50,0x50,0x62,0x42,0xc2,0x3e,0x00,
+/* 27896 0x6cf8 "泸" */
+0x00,0x20,0x10,0x10,0x80,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x40,0x40,0x7e,0x40,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,
+/* 27897 0x6cf9 "泹" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe2,0x23,0x20,0x20,0x2f,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 27898 0x6cfa "泺" */
+0x00,0x20,0x17,0x14,0x84,0x44,0x44,0x17,0x10,0x20,0xe2,0x22,0x24,0x28,0x21,0x00,
+0x08,0x3c,0xc0,0x00,0x40,0x40,0x40,0xfe,0x40,0x40,0x48,0x44,0x42,0x42,0x40,0x80,
+/* 27899 0x6cfb "泻" */
+0x00,0x27,0x14,0x19,0x81,0x41,0x49,0x0a,0x13,0x10,0xe0,0x27,0x20,0x20,0x20,0x00,
+0x00,0xfe,0x02,0x04,0x00,0xfc,0x00,0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 27900 0x6cfc "泼" */
+0x00,0x20,0x12,0x12,0x83,0x40,0x48,0x08,0x11,0x11,0xe1,0x22,0x22,0x24,0x28,0x03,
+0x40,0x48,0x44,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 27901 0x6cfd "泽" */
+0x00,0x27,0x12,0x11,0x80,0x40,0x41,0x16,0x10,0x23,0xe0,0x20,0x27,0x20,0x20,0x00,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,
+/* 27902 0x6cfe "泾" */
+0x00,0x27,0x10,0x10,0x80,0x40,0x41,0x16,0x10,0x23,0xe0,0x20,0x20,0x20,0x27,0x00,
+0x00,0xf8,0x10,0x20,0x60,0x98,0x04,0x02,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 27903 0x6cff "泿" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 27904 0x6d00 "洀" */
+0x00,0x21,0x13,0x12,0x82,0x42,0x42,0x1f,0x12,0x22,0xe2,0x22,0x22,0x22,0x24,0x08,
+0x80,0x00,0xf8,0x08,0x88,0x48,0x48,0xfe,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 27905 0x6d01 "洁" */
+0x00,0x40,0x20,0x2f,0x00,0x80,0x47,0x50,0x10,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27906 0x6d02 "洂" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x48,0x0a,0x12,0x12,0xe4,0x20,0x21,0x21,0x22,0x04,
+0x40,0x20,0x20,0xfe,0x90,0x90,0x90,0x94,0x92,0x92,0x92,0x90,0x10,0x10,0x50,0x20,
+/* 27907 0x6d03 "洃" */
+0x00,0x20,0x10,0x17,0x81,0x41,0x4a,0x0a,0x14,0x15,0xea,0x20,0x20,0x21,0x22,0x04,
+0x80,0x80,0x80,0xfe,0x00,0x20,0x20,0xa4,0xa4,0x28,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 27908 0x6d04 "洄" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x24,0x27,0x04,
+0x00,0xfe,0x02,0x02,0xf2,0x92,0x92,0x92,0x92,0x92,0xf2,0x92,0x02,0x02,0xfe,0x02,
+/* 27909 0x6d05 "洅" */
+0x00,0x27,0x10,0x10,0x83,0x42,0x4a,0x0b,0x12,0x12,0xef,0x22,0x22,0x22,0x22,0x02,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfe,0x08,0x08,0x08,0x28,0x10,
+/* 27910 0x6d06 "洆" */
+0x00,0x23,0x10,0x10,0x80,0x47,0x41,0x11,0x12,0x22,0xe4,0x29,0x20,0x20,0x2f,0x00,
+0x00,0xf8,0x10,0x20,0x44,0x64,0x68,0x50,0x50,0x48,0x44,0x42,0x80,0x00,0xfe,0x00,
+/* 27911 0x6d07 "洇" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x47,0x14,0x14,0x24,0xe4,0x25,0x26,0x24,0x27,0x04,
+0x00,0xfc,0x04,0x44,0x44,0x44,0xfc,0x44,0x44,0xa4,0x94,0x14,0x04,0x04,0xfc,0x04,
+/* 27912 0x6d08 "洈" */
+0x01,0x21,0x13,0x12,0x84,0x4b,0x42,0x12,0x12,0x22,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x00,0x00,0xf8,0x08,0x10,0xfe,0x00,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 27913 0x6d09 "洉" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x28,0x00,
+0x08,0x3c,0xc0,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 27914 0x6d0a "洊" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x49,0x09,0x13,0x15,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 27915 0x6d0b "洋" */
+0x02,0x21,0x11,0x10,0x87,0x40,0x40,0x13,0x10,0x20,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 27916 0x6d0c "洌" */
+0x00,0x40,0x2f,0x22,0x02,0x83,0x42,0x54,0x16,0x25,0xe8,0x20,0x21,0x22,0x24,0x08,
+0x02,0x02,0xc2,0x12,0x12,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x02,0x02,0x0a,0x04,
+/* 27917 0x6d0d "洍" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x24,0x27,0x00,
+0x00,0xfe,0x20,0x20,0x20,0xf8,0x88,0x88,0x88,0x88,0xf8,0x20,0x20,0x20,0xfe,0x00,
+/* 27918 0x6d0e "洎" */
+0x00,0x20,0x13,0x12,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x40,0x80,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 27919 0x6d0f "洏" */
+0x00,0x2f,0x10,0x10,0x80,0x47,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x24,0x24,0x04,
+0x00,0xfe,0x40,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x14,0x08,
+/* 27920 0x6d10 "洐" */
+0x00,0x20,0x11,0x12,0x84,0x40,0x49,0x0b,0x15,0x11,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 27921 0x6d11 "洑" */
+0x01,0x41,0x21,0x22,0x02,0x86,0x4a,0x42,0x12,0x22,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x20,0x28,0x24,0x24,0x20,0x20,0xfc,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 27922 0x6d12 "洒" */
+0x00,0x2f,0x10,0x10,0x87,0x44,0x44,0x14,0x14,0x24,0xe5,0x26,0x24,0x24,0x27,0x04,
+0x00,0xfe,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x1c,0x04,0x04,0x04,0xfc,0x04,
+/* 27923 0x6d13 "洓" */
+0x00,0x20,0x17,0x10,0x80,0x43,0x4a,0x0a,0x12,0x12,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x48,0x48,0x48,0x58,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 27924 0x6d14 "洔" */
+0x00,0x20,0x10,0x13,0x80,0x40,0x47,0x10,0x10,0x27,0xe0,0x22,0x21,0x21,0x20,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 27925 0x6d15 "洕" */
+0x00,0x21,0x11,0x12,0x84,0x4b,0x42,0x12,0x13,0x22,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x10,0x10,0x08,0x08,0x04,0xfa,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 27926 0x6d16 "洖" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x40,0x17,0x10,0x20,0xef,0x20,0x20,0x21,0x22,0x0c,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 27927 0x6d17 "洗" */
+0x00,0x22,0x12,0x13,0x84,0x48,0x40,0x17,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 27928 0x6d18 "洘" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x48,0x09,0x13,0x14,0xe9,0x21,0x20,0x20,0x20,0x00,
+0x80,0x88,0xe8,0x90,0xa0,0xfe,0x80,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 27929 0x6d19 "洙" */
+0x00,0x22,0x12,0x13,0x84,0x40,0x40,0x17,0x10,0x21,0xe1,0x22,0x24,0x28,0x20,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 27930 0x6d1a "洚" */
+0x01,0x21,0x11,0x13,0x84,0x40,0x51,0x16,0x10,0x23,0xe0,0x24,0x27,0x20,0x20,0x00,
+0x00,0x00,0xf8,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,
+/* 27931 0x6d1b "洛" */
+0x00,0x20,0x11,0x12,0x85,0x40,0x40,0x10,0x13,0x2c,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 27932 0x6d1c "洜" */
+0x08,0x1f,0x28,0x07,0x18,0xe0,0x1f,0x10,0x1f,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 27933 0x6d1d "洝" */
+0x00,0x20,0x10,0x17,0x84,0x48,0x40,0x17,0x11,0x21,0xe2,0x21,0x20,0x20,0x21,0x06,
+0x80,0x40,0x40,0xfc,0x04,0x88,0x80,0xfc,0x10,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,
+/* 27934 0x6d1e "洞" */
+0x00,0x27,0x14,0x14,0x85,0x44,0x44,0x15,0x15,0x25,0xe5,0x25,0x24,0x24,0x24,0x04,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x04,0x14,0x08,
+/* 27935 0x6d1f "洟" */
+0x00,0x20,0x17,0x10,0x87,0x40,0x43,0x12,0x14,0x27,0xe0,0x20,0x20,0x21,0x22,0x0c,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x40,0x40,0xfe,0x42,0xaa,0xa4,0x10,0x08,0x06,
+/* 27936 0x6d20 "洠" */
+0x00,0x20,0x10,0x11,0x83,0x40,0x49,0x09,0x11,0x12,0xe0,0x27,0x20,0x20,0x20,0x00,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 27937 0x6d21 "洡" */
+0x00,0x20,0x17,0x10,0x80,0x43,0x48,0x08,0x17,0x10,0xe1,0x21,0x22,0x24,0x28,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 27938 0x6d22 "洢" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x4a,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x00,0x7c,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x7c,0x24,0x20,0x20,0x20,0x40,0x80,
+/* 27939 0x6d23 "洣" */
+0x00,0x20,0x12,0x11,0x81,0x40,0x47,0x10,0x10,0x21,0xe1,0x22,0x24,0x28,0x20,0x00,
+0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 27940 0x6d24 "洤" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x43,0x10,0x10,0x20,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 27941 0x6d25 "津" */
+0x00,0x20,0x13,0x10,0x87,0x40,0x4b,0x08,0x10,0x13,0xe0,0x20,0x27,0x20,0x20,0x00,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,
+/* 27942 0x6d26 "洦" */
+0x00,0x27,0x10,0x10,0x80,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 27943 0x6d27 "洧" */
+0x00,0x20,0x17,0x10,0x81,0x41,0x43,0x15,0x19,0x21,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 27944 0x6d28 "洨" */
+0x00,0x20,0x10,0x17,0x80,0x41,0x42,0x14,0x11,0x21,0xe0,0x20,0x20,0x21,0x22,0x0c,
+0x80,0x40,0x40,0xfc,0x00,0x10,0x08,0x04,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 27945 0x6d29 "洩" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x47,0x14,0x14,0x27,0xe0,0x20,0x20,0x20,0x21,0x0e,
+0x40,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x28,0x12,0x32,0x4a,0x86,0x02,
+/* 27946 0x6d2a "洪" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x41,0x11,0x11,0x2f,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x10,0x08,0x08,0x04,0x04,
+/* 27947 0x6d2b "洫" */
+0x00,0x20,0x10,0x11,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x40,0x40,0x80,0x00,0xfc,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 27948 0x6d2c "洬" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x14,0x15,0x25,0xe6,0x24,0x24,0x28,0x29,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x88,0x88,0xe8,0x28,0x28,0xa8,0x4a,0x4a,0x8a,0x06,0x02,
+/* 27949 0x6d2d "洭" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x23,0x22,0x22,0x23,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 27950 0x6d2e "洮" */
+0x00,0x20,0x10,0x14,0x82,0x40,0x40,0x11,0x12,0x24,0xe0,0x20,0x21,0x21,0x22,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 27951 0x6d2f "洯" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x09,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x00,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 27952 0x6d30 "洰" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe3,0x22,0x22,0x22,0x23,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 27953 0x6d31 "洱" */
+0x00,0x27,0x12,0x12,0x83,0x42,0x42,0x13,0x12,0x22,0xe2,0x23,0x2e,0x20,0x20,0x00,
+0x00,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,
+/* 27954 0x6d32 "洲" */
+0x01,0x21,0x11,0x11,0x81,0x41,0x45,0x15,0x19,0x21,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0xb4,0x6c,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 27955 0x6d33 "洳" */
+0x01,0x21,0x11,0x11,0x87,0x42,0x42,0x12,0x12,0x24,0xe2,0x21,0x22,0x22,0x24,0x08,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x12,0x92,0x5e,0x52,0x00,
+/* 27956 0x6d34 "洴" */
+0x02,0x21,0x11,0x10,0x87,0x41,0x41,0x11,0x11,0x2f,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x08,0x08,0x10,0x00,0xfc,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27957 0x6d35 "洵" */
+0x00,0x20,0x11,0x11,0x82,0x44,0x43,0x12,0x12,0x23,0xe2,0x22,0x23,0x20,0x20,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 27958 0x6d36 "洶" */
+0x02,0x22,0x12,0x13,0x84,0x44,0x4a,0x11,0x14,0x25,0xe6,0x24,0x27,0x20,0x20,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x24,0x44,0x94,0x54,0x34,0x14,0xf4,0x04,0x28,0x10,
+/* 27959 0x6d37 "洷" */
+0x00,0x27,0x10,0x10,0x81,0x42,0x47,0x10,0x10,0x20,0xe7,0x20,0x20,0x20,0x2f,0x00,
+0x00,0xfe,0x40,0x80,0x10,0x08,0xfc,0x44,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 27960 0x6d38 "洸" */
+0x00,0x20,0x14,0x12,0x82,0x40,0x4f,0x11,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x88,0x88,0x90,0xa0,0x80,0xfc,0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x1c,0x00,
+/* 27961 0x6d39 "洹" */
+0x00,0x27,0x10,0x10,0x83,0x42,0x42,0x13,0x12,0x22,0xe3,0x22,0x20,0x20,0x2f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x00,0xfe,0x00,
+/* 27962 0x6d3a "洺" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x40,0x10,0x11,0x23,0xed,0x21,0x21,0x21,0x21,0x01,
+0x80,0x80,0xfc,0x04,0x88,0x50,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 27963 0x6d3b "活" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x40,0x10,0x10,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x10,0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27964 0x6d3c "洼" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x47,0x10,0x10,0x20,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x40,0x40,0xf8,0x40,0x40,0x40,0xfc,0x00,0x40,0x40,0xf8,0x40,0x40,0x40,0xfc,0x00,
+/* 27965 0x6d3d "洽" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x43,0x10,0x10,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 27966 0x6d3e "派" */
+0x00,0x20,0x17,0x14,0x84,0x45,0x45,0x15,0x15,0x25,0xe5,0x25,0x25,0x29,0x29,0x11,
+0x08,0x3c,0xc0,0x00,0x1c,0xe0,0x20,0x22,0x24,0x28,0x10,0x10,0x08,0x44,0x82,0x00,
+/* 27967 0x6d3f "洿" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x4d,0x10,0x17,0x20,0xe1,0x23,0x20,0x20,0x20,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 27968 0x6d40 "浀" */
+0x00,0x20,0x10,0x10,0x83,0x42,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x50,0x50,0x50,0x50,0xfe,0x52,0x52,0x52,0x52,0xfe,0x52,0x52,0x52,0x52,0xfe,0x02,
+/* 27969 0x6d41 "流" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x47,0x10,0x10,0x22,0xe2,0x22,0x22,0x22,0x24,0x08,
+0x80,0x40,0xfe,0x80,0x10,0x08,0xfc,0x04,0x00,0x48,0x48,0x48,0x48,0x4a,0x4a,0x46,
+/* 27970 0x6d42 "浂" */
+0x02,0x21,0x11,0x10,0x83,0x40,0x48,0x08,0x17,0x10,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x08,0x08,0x10,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 27971 0x6d43 "浃" */
+0x00,0x20,0x10,0x17,0x80,0x42,0x51,0x10,0x1f,0x20,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x50,0x40,0xfe,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 27972 0x6d44 "浄" */
+0x01,0x21,0x13,0x12,0x84,0x4b,0x40,0x10,0x17,0x20,0xe0,0x23,0x20,0x20,0x21,0x00,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x80,
+/* 27973 0x6d45 "浅" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x40,0x17,0x10,0x20,0xe0,0x20,0x20,0x21,0x26,0x00,
+0xa0,0x90,0x80,0xb8,0xc0,0x80,0xbc,0xc0,0x88,0x90,0x60,0x44,0xa4,0x14,0x0c,0x04,
+/* 27974 0x6d46 "浆" */
+0x08,0x48,0x28,0x09,0x1a,0x28,0x48,0x89,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x60,0x80,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,
+/* 27975 0x6d47 "浇" */
+0x00,0x20,0x10,0x13,0x80,0x40,0x48,0x0b,0x10,0x17,0xe0,0x20,0x21,0x21,0x22,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 27976 0x6d48 "浈" */
+0x00,0x20,0x10,0x10,0x80,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x20,0x21,0x22,0x04,
+0x40,0x40,0x7e,0x40,0x40,0xf8,0x08,0x48,0x48,0x48,0x48,0x48,0xa0,0x10,0x08,0x04,
+/* 27977 0x6d49 "浉" */
+0x01,0x21,0x11,0x15,0x85,0x45,0x45,0x15,0x15,0x25,0xe5,0x21,0x22,0x22,0x24,0x08,
+0x00,0xfe,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,
+/* 27978 0x6d4a "浊" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x44,0x14,0x17,0x24,0xe0,0x20,0x20,0x2f,0x24,0x00,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x40,0x48,0x44,0xfe,0x02,0x00,
+/* 27979 0x6d4b "测" */
+0x00,0x27,0x14,0x14,0x85,0x45,0x45,0x15,0x15,0x25,0xe5,0x21,0x22,0x22,0x24,0x08,
+0x04,0xc4,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x04,0x84,0x44,0x14,0x08,
+/* 27980 0x6d4c "浌" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x4b,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x20,0x28,0x24,0x24,0x20,0x3e,0xe0,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 27981 0x6d4d "浍" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x41,0x10,0x10,0x27,0xe0,0x20,0x21,0x22,0x27,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x00,0x00,0xfc,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 27982 0x6d4e "济" */
+0x00,0x20,0x17,0x12,0x81,0x40,0x40,0x11,0x16,0x21,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x80,0x40,0xfe,0x08,0x10,0xa0,0x40,0xb0,0x0e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 27983 0x6d4f "浏" */
+0x02,0x41,0x21,0x2f,0x00,0x84,0x42,0x52,0x11,0x21,0xe2,0x22,0x24,0x28,0x30,0x00,
+0x04,0x04,0x04,0xe4,0x94,0x94,0x94,0x94,0x14,0x14,0x94,0x94,0x44,0x44,0x14,0x08,
+/* 27984 0x6d50 "浐" */
+0x00,0x20,0x13,0x10,0x81,0x40,0x4b,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 27985 0x6d51 "浑" */
+0x00,0x23,0x12,0x14,0x80,0x43,0x48,0x08,0x11,0x11,0xe0,0x20,0x27,0x20,0x20,0x00,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 27986 0x6d52 "浒" */
+0x00,0x44,0x22,0x22,0x00,0x80,0x4e,0x52,0x12,0x22,0xe2,0x22,0x23,0x22,0x20,0x00,
+0x40,0x40,0x40,0x7c,0x50,0x90,0x10,0x10,0xfe,0x10,0x10,0x90,0x10,0x10,0x10,0x10,
+/* 27987 0x6d53 "浓" */
+0x00,0x20,0x10,0x17,0x84,0x48,0x41,0x11,0x13,0x25,0xe9,0x21,0x21,0x21,0x21,0x01,
+0x40,0x40,0x40,0xfc,0x84,0x88,0x40,0x44,0x48,0x30,0x20,0x10,0x08,0x44,0x82,0x00,
+/* 27988 0x6d54 "浔" */
+0x00,0x27,0x10,0x10,0x83,0x40,0x40,0x17,0x10,0x20,0xef,0x22,0x21,0x21,0x20,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 27989 0x6d55 "浕" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x12,0x14,0xe4,0x28,0x21,0x20,0x20,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x20,0x20,0x10,0x08,0xc6,0x20,0x00,0xc0,0x30,0x08,0x00,
+/* 27990 0x6d56 "浖" */
+0x00,0x20,0x17,0x10,0x84,0x42,0x42,0x10,0x17,0x20,0xe2,0x21,0x21,0x20,0x20,0x00,
+0x10,0x78,0x80,0x88,0x48,0x50,0x00,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 27991 0x6d57 "浗" */
+0x00,0x20,0x10,0x10,0x87,0x40,0x4a,0x09,0x11,0x10,0xe1,0x22,0x24,0x20,0x21,0x00,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x44,0x64,0x68,0xd0,0x50,0x48,0x44,0x42,0x40,0x80,
+/* 27992 0x6d58 "浘" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x23,0x22,0x24,0x24,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x18,0xe0,0x38,0xe0,0x3c,0xe0,0x22,0x22,0x1e,0x00,
+/* 27993 0x6d59 "浙" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x52,0x13,0x2e,0xe2,0x22,0x22,0x22,0x2a,0x05,
+0x08,0x1c,0x60,0x40,0xc0,0x40,0x7e,0xc8,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 27994 0x6d5a "浚" */
+0x00,0x20,0x11,0x12,0x87,0x40,0x41,0x12,0x14,0x21,0xe3,0x24,0x20,0x20,0x23,0x0c,
+0x80,0x80,0x10,0x08,0xfc,0x04,0x10,0x88,0x84,0xf0,0x10,0xa0,0x40,0xa0,0x10,0x0c,
+/* 27995 0x6d5b "浛" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x41,0x10,0x10,0x20,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf0,0x10,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 27996 0x6d5c "浜" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x42,0x12,0x12,0x22,0xef,0x20,0x21,0x22,0x24,0x08,
+0x10,0x38,0xc0,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,0x20,0x10,0x08,0x04,
+/* 27997 0x6d5d "浝" */
+0x01,0x21,0x11,0x17,0x81,0x41,0x49,0x09,0x11,0x12,0xe2,0x22,0x24,0x24,0x29,0x10,
+0x10,0x08,0x00,0xfe,0x48,0x50,0x64,0x48,0x50,0x64,0x48,0x52,0x62,0x42,0xbe,0x00,
+/* 27998 0x6d5e "浞" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x43,0x10,0x10,0x22,0xe2,0x22,0x22,0x25,0x28,0x10,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x00,
+/* 27999 0x6d5f "浟" */
+0x02,0x22,0x12,0x14,0x85,0x4d,0x4d,0x15,0x15,0x25,0xe5,0x25,0x24,0x24,0x24,0x04,
+0x10,0x10,0x10,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 28000 0x6d60 "浠" */
+0x02,0x21,0x10,0x11,0x82,0x40,0x4f,0x11,0x12,0x27,0xea,0x22,0x22,0x22,0x20,0x00,
+0x08,0x10,0xe0,0x10,0x08,0x80,0xfe,0x40,0x40,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 28001 0x6d61 "浡" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x54,0x18,0x11,0x20,0xe0,0x2f,0x20,0x20,0x21,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x02,0x04,0xf0,0x10,0x20,0xfe,0x40,0x40,0x40,0x80,
+/* 28002 0x6d62 "浢" */
+0x00,0x27,0x10,0x10,0x83,0x42,0x4a,0x0a,0x12,0x13,0xe0,0x22,0x21,0x21,0x2f,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x08,0x08,0x10,0xfe,0x00,
+/* 28003 0x6d63 "浣" */
+0x00,0x20,0x17,0x14,0x88,0x43,0x40,0x10,0x17,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x40,0xfc,0x04,0x08,0xf0,0x00,0x00,0xfc,0x20,0x20,0x20,0x24,0x24,0x1c,0x00,
+/* 28004 0x6d64 "浤" */
+0x00,0x20,0x13,0x12,0x84,0x40,0x4b,0x08,0x10,0x10,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x90,0x90,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 28005 0x6d65 "浥" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x47,0x14,0x14,0x24,0xe7,0x24,0x24,0x24,0x23,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0x44,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 28006 0x6d66 "浦" */
+0x00,0x40,0x2f,0x20,0x00,0x87,0x44,0x54,0x17,0x24,0xe4,0x27,0x24,0x24,0x24,0x04,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 28007 0x6d67 "浧" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x48,0x08,0x17,0x10,0xe0,0x23,0x20,0x20,0x2f,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 28008 0x6d68 "浨" */
+0x00,0x20,0x17,0x14,0x88,0x40,0x40,0x17,0x10,0x21,0xe1,0x22,0x24,0x28,0x20,0x00,
+0x80,0x40,0xfe,0x02,0x44,0x40,0x40,0xfc,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 28009 0x6d69 "浩" */
+0x00,0x22,0x12,0x13,0x84,0x48,0x40,0x17,0x10,0x20,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 28010 0x6d6a "浪" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x13,0x12,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x80,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x44,0x28,0x10,0x88,0x06,0x00,
+/* 28011 0x6d6b "浫" */
+0x00,0x47,0x24,0x29,0x02,0x84,0x43,0x50,0x10,0x20,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x00,0xfe,0x02,0x14,0x08,0x04,0xf8,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,
+/* 28012 0x6d6c "浬" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x10,0x20,0xe7,0x20,0x20,0x20,0x2f,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 28013 0x6d6d "浭" */
+0x00,0x2f,0x10,0x17,0x84,0x44,0x47,0x14,0x14,0x27,0xe2,0x21,0x20,0x21,0x22,0x0c,
+0x00,0xfe,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x40,0x40,0x80,0x40,0x30,0x0e,
+/* 28014 0x6d6e "浮" */
+0x00,0x20,0x13,0x10,0x82,0x41,0x48,0x0b,0x10,0x10,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 28015 0x6d6f "浯" */
+0x00,0x27,0x10,0x10,0x83,0x40,0x40,0x17,0x10,0x20,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x40,0x40,0xf8,0x88,0x88,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 28016 0x6d70 "浰" */
+0x00,0x21,0x17,0x11,0x81,0x41,0x4f,0x11,0x13,0x23,0xe5,0x25,0x29,0x21,0x21,0x01,
+0x84,0xc4,0x04,0x14,0x14,0x14,0xd4,0x14,0x14,0x94,0x54,0x04,0x04,0x04,0x14,0x08,
+/* 28017 0x6d71 "浱" */
+0x00,0x23,0x12,0x12,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 28018 0x6d72 "浲" */
+0x01,0x21,0x13,0x14,0x80,0x41,0x46,0x10,0x13,0x20,0xe3,0x20,0x27,0x20,0x20,0x00,
+0x00,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x40,0x40,0x40,
+/* 28019 0x6d73 "浳" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x88,0x84,0xbe,0xc0,0x32,0x0e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 28020 0x6d74 "浴" */
+0x01,0x21,0x12,0x14,0x80,0x40,0x41,0x12,0x14,0x23,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x10,0x08,0x04,0x44,0x40,0xa0,0x10,0x08,0x06,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 28021 0x6d75 "浵" */
+0x00,0x27,0x14,0x14,0x86,0x45,0x44,0x14,0x1f,0x24,0xe4,0x24,0x24,0x24,0x28,0x11,
+0x02,0x82,0x84,0x88,0x90,0x82,0x82,0x84,0xc8,0x90,0x82,0x82,0x84,0x88,0x90,0xa0,
+/* 28022 0x6d76 "浶" */
+0x00,0x20,0x13,0x12,0x84,0x41,0x49,0x09,0x12,0x10,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x40,0x20,0xfe,0x02,0x24,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 28023 0x6d77 "海" */
+0x01,0x21,0x11,0x12,0x85,0x41,0x49,0x09,0x17,0x11,0xe2,0x22,0x23,0x20,0x20,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 28024 0x6d78 "浸" */
+0x00,0x23,0x10,0x11,0x80,0x43,0x40,0x17,0x14,0x23,0xe1,0x21,0x20,0x20,0x21,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf0,0x10,0x10,0xa0,0x40,0xb0,0x0e,
+/* 28025 0x6d79 "浹" */
+0x00,0x20,0x10,0x17,0x80,0x42,0x42,0x12,0x15,0x28,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x40,0x40,0x40,0xfe,0x40,0x48,0x48,0x48,0x54,0xa2,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 28026 0x6d7a "浺" */
+0x01,0x21,0x11,0x11,0x81,0x45,0x45,0x15,0x19,0x21,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x08,0x08,0x08,0x3e,0xaa,0x6a,0x2a,0x2a,0x2a,0x3e,0x2a,0x08,0x08,0x08,0x08,0x08,
+/* 28027 0x6d7b "浻" */
+0x00,0x27,0x14,0x14,0x85,0x46,0x54,0x15,0x15,0x25,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x00,0xfc,0x04,0xa4,0x14,0x0c,0x04,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0x14,0x08,
+/* 28028 0x6d7c "浼" */
+0x01,0x21,0x11,0x12,0x82,0x47,0x4a,0x12,0x12,0x23,0xe2,0x20,0x21,0x22,0x24,0x08,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0x44,0xfc,0xa4,0xa0,0x20,0x22,0x22,0x1e,
+/* 28029 0x6d7d "浽" */
+0x00,0x20,0x13,0x10,0x82,0x41,0x49,0x08,0x13,0x10,0xe1,0x23,0x20,0x20,0x21,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 28030 0x6d7e "浾" */
+0x00,0x20,0x13,0x10,0x80,0x40,0x47,0x10,0x12,0x22,0xe4,0x29,0x21,0x22,0x24,0x08,
+0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x90,0x94,0x92,0x92,0x12,0x10,0x10,0x50,0x20,
+/* 28031 0x6d7f "浿" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x12,0x12,0xe3,0x20,0x21,0x21,0x22,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x10,0x08,0x04,0x04,
+/* 28032 0x6d80 "涀" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x42,0x13,0x12,0x22,0xe3,0x21,0x21,0x22,0x24,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 28033 0x6d81 "涁" */
+0x01,0x21,0x11,0x11,0x8f,0x41,0x43,0x13,0x15,0x25,0xe9,0x21,0x21,0x21,0x21,0x01,
+0x02,0x02,0x04,0x08,0xd0,0x02,0x02,0x84,0x48,0x50,0x02,0x02,0x04,0x08,0x10,0x60,
+/* 28034 0x6d82 "涂" */
+0x00,0x20,0x10,0x11,0x82,0x45,0x40,0x10,0x17,0x20,0xe2,0x22,0x24,0x28,0x21,0x00,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 28035 0x6d83 "涃" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x44,0x14,0x14,0x25,0xe6,0x24,0x24,0x24,0x27,0x04,
+0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0xc4,0xe4,0x54,0x44,0x44,0x44,0x04,0xfc,0x04,
+/* 28036 0x6d84 "涄" */
+0x00,0x20,0x17,0x14,0x87,0x44,0x47,0x10,0x1f,0x21,0xe2,0x23,0x20,0x20,0x20,0x00,
+0x40,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 28037 0x6d85 "涅" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x10,0x20,0xe7,0x20,0x20,0x20,0x2f,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 28038 0x6d86 "涆" */
+0x00,0x20,0x17,0x14,0x84,0x44,0x44,0x17,0x14,0x24,0xe4,0x24,0x27,0x24,0x20,0x00,
+0x00,0x3e,0x88,0x88,0x88,0x88,0x88,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,
+/* 28039 0x6d87 "涇" */
+0x00,0x23,0x10,0x11,0x82,0x44,0x52,0x11,0x10,0x23,0xe0,0x20,0x20,0x20,0x27,0x00,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 28040 0x6d88 "消" */
+0x00,0x22,0x11,0x11,0x80,0x43,0x4a,0x0a,0x13,0x12,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x40,0x48,0x48,0x50,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 28041 0x6d89 "涉" */
+0x00,0x20,0x11,0x11,0x81,0x41,0x47,0x10,0x10,0x21,0xe1,0x22,0x24,0x20,0x20,0x07,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x24,0x24,0x28,0x10,0x20,0xc0,0x00,
+/* 28042 0x6d8a "涊" */
+0x00,0x23,0x10,0x11,0x81,0x42,0x48,0x09,0x12,0x10,0xe0,0x22,0x22,0x22,0x24,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 28043 0x6d8b "涋" */
+0x00,0x20,0x13,0x12,0x84,0x40,0x40,0x10,0x17,0x20,0xe0,0x20,0x21,0x21,0x22,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x50,0x48,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 28044 0x6d8c "涌" */
+0x00,0x27,0x10,0x11,0x80,0x47,0x44,0x14,0x17,0x24,0xe4,0x27,0x24,0x24,0x24,0x04,
+0x00,0xf8,0x10,0xa0,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 28045 0x6d8d "涍" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x40,0x10,0x13,0x21,0xe2,0x25,0x28,0x20,0x20,0x00,
+0x40,0x44,0xf4,0x48,0x48,0xfe,0x20,0x40,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 28046 0x6d8e "涎" */
+0x00,0x20,0x17,0x11,0x81,0x42,0x42,0x17,0x11,0x25,0xe5,0x22,0x22,0x25,0x28,0x10,
+0x08,0x1c,0x70,0x10,0x10,0x50,0x5c,0x50,0x50,0x50,0x50,0x7c,0x00,0x00,0xfe,0x00,
+/* 28047 0x6d8f "涏" */
+0x00,0x20,0x17,0x11,0x81,0x42,0x42,0x17,0x11,0x25,0xe5,0x22,0x22,0x25,0x28,0x10,
+0x00,0x0c,0x70,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,0xfe,0x00,
+/* 28048 0x6d90 "涐" */
+0x01,0x43,0x2e,0x22,0x02,0x9f,0x42,0x52,0x12,0x23,0xe2,0x2e,0x22,0x22,0x2a,0x04,
+0x20,0xa8,0x24,0x24,0x20,0xfe,0x20,0x24,0xa4,0x28,0x28,0x10,0x32,0x4a,0x86,0x02,
+/* 28049 0x6d91 "涑" */
+0x00,0x40,0x2f,0x20,0x00,0x87,0x44,0x54,0x17,0x20,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 28050 0x6d92 "涒" */
+0x00,0x23,0x10,0x10,0x87,0x40,0x48,0x0b,0x11,0x11,0xe3,0x25,0x29,0x21,0x21,0x01,
+0x00,0xf8,0x88,0x88,0xfe,0x88,0x88,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 28051 0x6d93 "涓" */
+0x00,0x21,0x11,0x11,0x81,0x40,0x4b,0x0a,0x12,0x13,0xe2,0x22,0x23,0x22,0x22,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 28052 0x6d94 "涔" */
+0x00,0x22,0x12,0x12,0x83,0x40,0x48,0x09,0x12,0x14,0xe0,0x23,0x20,0x20,0x20,0x00,
+0x40,0x48,0x48,0x48,0xf8,0x40,0xa0,0x10,0x88,0x46,0x40,0xf0,0x10,0x20,0x20,0x40,
+/* 28053 0x6d95 "涕" */
+0x02,0x21,0x11,0x17,0x80,0x40,0x47,0x14,0x14,0x27,0xe0,0x21,0x22,0x24,0x28,0x00,
+0x10,0x10,0x20,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0xc4,0x44,0x54,0x48,0x40,0x40,
+/* 28054 0x6d96 "涖" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x56,0x1a,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x20,0x10,0x10,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 28055 0x6d97 "涗" */
+0x00,0x20,0x10,0x11,0x82,0x45,0x41,0x11,0x11,0x21,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 28056 0x6d98 "涘" */
+0x00,0x20,0x11,0x12,0x87,0x41,0x41,0x13,0x14,0x20,0xef,0x20,0x20,0x21,0x22,0x0c,
+0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 28057 0x6d99 "涙" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x24,0x25,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 28058 0x6d9a "涚" */
+0x02,0x21,0x11,0x10,0x83,0x42,0x4a,0x0a,0x13,0x10,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x08,0x08,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 28059 0x6d9b "涛" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x11,0x21,0xe2,0x22,0x24,0x28,0x20,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x90,0x10,0xfe,0x10,0x90,0x50,0x10,0x50,0x20,
+/* 28060 0x6d9c "涜" */
+0x00,0x20,0x13,0x10,0x81,0x40,0x4b,0x0a,0x14,0x10,0xe0,0x20,0x20,0x21,0x21,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0x04,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 28061 0x6d9d "涝" */
+0x01,0x21,0x17,0x11,0x80,0x47,0x54,0x18,0x10,0x27,0xe0,0x21,0x21,0x22,0x24,0x08,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x02,0x84,0x80,0xfc,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 28062 0x6d9e "涞" */
+0x00,0x20,0x10,0x17,0x80,0x42,0x41,0x11,0x17,0x20,0xe1,0x21,0x22,0x24,0x28,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x50,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 28063 0x6d9f "涟" */
+0x00,0x24,0x12,0x12,0x80,0x40,0x4e,0x12,0x12,0x22,0xe3,0x22,0x22,0x25,0x28,0x00,
+0x20,0x20,0x20,0xfe,0x40,0x50,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 28064 0x6da0 "涠" */
+0x00,0x27,0x14,0x14,0x85,0x44,0x44,0x14,0x15,0x24,0xe4,0x24,0x24,0x24,0x27,0x04,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0xe4,0x44,0xf4,0x54,0x54,0x74,0x44,0x44,0xfc,0x04,
+/* 28065 0x6da1 "涡" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x40,0x10,0x17,0x24,0xe4,0x25,0x26,0x24,0x24,0x04,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x40,0x40,0xfc,0x44,0xa4,0x14,0x14,0x04,0x14,0x08,
+/* 28066 0x6da2 "涢" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x40,0x17,0x14,0x24,0xe4,0x24,0x24,0x21,0x26,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x44,0x44,0x44,0xb4,0x08,0x04,0x02,
+/* 28067 0x6da3 "涣" */
+0x01,0x21,0x11,0x12,0x84,0x4b,0x42,0x12,0x12,0x22,0xef,0x20,0x20,0x21,0x22,0x0c,
+0x00,0x00,0xf0,0x10,0x20,0xf8,0x48,0x48,0x48,0x48,0xfe,0xa0,0xa0,0x10,0x08,0x06,
+/* 28068 0x6da4 "涤" */
+0x00,0x20,0x11,0x13,0x84,0x40,0x41,0x16,0x10,0x27,0xe0,0x22,0x22,0x24,0x21,0x00,
+0x80,0x80,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xfc,0x40,0x48,0x44,0x44,0x40,0x80,
+/* 28069 0x6da5 "涥" */
+0x00,0x40,0x2f,0x20,0x03,0x82,0x42,0x53,0x10,0x23,0xe0,0x20,0x20,0x20,0x21,0x00,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x10,0x60,0x40,0x40,0x40,0x80,
+/* 28070 0x6da6 "润" */
+0x02,0x21,0x15,0x14,0x85,0x44,0x44,0x14,0x15,0x24,0xe4,0x24,0x25,0x24,0x24,0x04,
+0x00,0x7c,0x04,0x04,0xf4,0x44,0x44,0x44,0xf4,0x44,0x44,0x44,0xf4,0x04,0x14,0x08,
+/* 28071 0x6da7 "涧" */
+0x02,0x21,0x15,0x14,0x84,0x45,0x45,0x15,0x15,0x25,0xe5,0x25,0x24,0x24,0x24,0x04,
+0x00,0x7c,0x04,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x14,0xf4,0x04,0x04,0x14,0x08,
+/* 28072 0x6da8 "涨" */
+0x00,0x4f,0x21,0x21,0x01,0x8f,0x48,0x58,0x18,0x2f,0xe1,0x21,0x21,0x21,0x2a,0x04,
+0x40,0x44,0x44,0x48,0x48,0x50,0x40,0xfe,0x50,0x50,0x48,0x48,0x44,0x44,0x62,0x40,
+/* 28073 0x6da9 "涩" */
+0x00,0x23,0x10,0x12,0x82,0x44,0x40,0x11,0x12,0x20,0xe1,0x21,0x21,0x21,0x27,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x20,0x20,0x3c,0x20,0x20,0x20,0xfe,0x00,
+/* 28074 0x6daa "涪" */
+0x00,0x20,0x13,0x10,0x82,0x41,0x41,0x17,0x10,0x20,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x80,0x40,0xfc,0x00,0x08,0x08,0x10,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 28075 0x6dab "涫" */
+0x00,0x40,0x27,0x24,0x08,0x83,0x42,0x52,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x80,0x40,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 28076 0x6dac "涬" */
+0x00,0x20,0x17,0x10,0x80,0x4f,0x41,0x10,0x17,0x20,0xe0,0x2f,0x20,0x20,0x20,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0xa0,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 28077 0x6dad "涭" */
+0x00,0x23,0x10,0x12,0x81,0x41,0x57,0x14,0x10,0x23,0xe1,0x21,0x20,0x20,0x21,0x06,
+0x1c,0xe0,0x84,0x44,0x48,0x10,0xfe,0x02,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 28078 0x6dae "涮" */
+0x00,0x47,0x24,0x24,0x07,0x84,0x44,0x54,0x17,0x26,0xe6,0x2a,0x2a,0x32,0x20,0x00,
+0x02,0xe2,0x22,0x2a,0xea,0x8a,0x8a,0x8a,0xea,0xaa,0xaa,0xaa,0xa2,0xe2,0x8a,0x84,
+/* 28079 0x6daf "涯" */
+0x00,0x27,0x14,0x14,0x85,0x44,0x44,0x17,0x14,0x24,0xe4,0x25,0x24,0x28,0x2b,0x10,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 28080 0x6db0 "涰" */
+0x00,0x27,0x10,0x12,0x81,0x42,0x54,0x18,0x10,0x27,0xe0,0x22,0x21,0x22,0x24,0x08,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 28081 0x6db1 "涱" */
+0x00,0x21,0x11,0x11,0x81,0x41,0x51,0x1f,0x12,0x22,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x80,0x48,0x50,0x20,0x10,0x88,0x06,0x00,
+/* 28082 0x6db2 "液" */
+0x00,0x20,0x17,0x11,0x81,0x42,0x42,0x16,0x12,0x23,0xe2,0x22,0x22,0x22,0x22,0x03,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 28083 0x6db3 "涳" */
+0x00,0x20,0x10,0x13,0x82,0x44,0x41,0x12,0x10,0x21,0xe0,0x20,0x20,0x20,0x27,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28084 0x6db4 "涴" */
+0x00,0x40,0x27,0x24,0x0a,0x82,0x43,0x54,0x14,0x26,0xe9,0x21,0x22,0x22,0x24,0x08,
+0x80,0x40,0xfe,0x02,0x04,0x00,0xbc,0xa4,0xa4,0xa4,0x34,0x28,0x22,0x22,0x22,0x1e,
+/* 28085 0x6db5 "涵" */
+0x00,0x23,0x10,0x10,0x84,0x45,0x44,0x14,0x14,0x25,0xe6,0x25,0x24,0x24,0x27,0x00,
+0x00,0xf8,0x10,0x20,0x44,0x54,0xe4,0x44,0xe4,0x54,0x4c,0x44,0x84,0x04,0xfc,0x04,
+/* 28086 0x6db6 "涶" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x42,0x12,0x1f,0x22,0xe2,0x27,0x20,0x20,0x27,0x00,
+0x10,0x78,0xc0,0x40,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0x40,0xfc,0x00,
+/* 28087 0x6db7 "涷" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x4b,0x0a,0x13,0x10,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 28088 0x6db8 "涸" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x15,0x15,0x25,0xe5,0x25,0x25,0x24,0x27,0x04,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xf4,0x14,0x14,0x14,0xf4,0x14,0x04,0xfc,0x04,
+/* 28089 0x6db9 "涹" */
+0x00,0x23,0x10,0x10,0x87,0x41,0x42,0x14,0x10,0x27,0xe1,0x22,0x21,0x20,0x20,0x03,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x86,0x80,0xfc,0x10,0x10,0xa0,0x60,0x90,0x08,
+/* 28090 0x6dba "涺" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 28091 0x6dbb "涻" */
+0x00,0x20,0x10,0x11,0x82,0x45,0x40,0x10,0x17,0x20,0xe0,0x23,0x22,0x22,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 28092 0x6dbc "涼" */
+0x00,0x20,0x17,0x10,0x80,0x43,0x4a,0x0a,0x13,0x10,0xe2,0x22,0x24,0x28,0x21,0x00,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 28093 0x6dbd "涽" */
+0x00,0x23,0x12,0x13,0x82,0x42,0x4b,0x0a,0x11,0x11,0xe1,0x21,0x21,0x21,0x21,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28094 0x6dbe "涾" */
+0x00,0x20,0x17,0x11,0x81,0x42,0x45,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x40,0x44,0x68,0x50,0x50,0x48,0x44,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28095 0x6dbf "涿" */
+0x00,0x4f,0x20,0x21,0x02,0x84,0x4a,0x41,0x12,0x24,0xe8,0x21,0x22,0x24,0x20,0x00,
+0x00,0xfe,0x80,0x84,0x44,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x24,0x22,0x20,0xa0,0x40,
+/* 28096 0x6dc0 "淀" */
+0x00,0x20,0x13,0x12,0x84,0x40,0x43,0x10,0x10,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 28097 0x6dc1 "淁" */
+0x00,0x20,0x13,0x10,0x81,0x40,0x47,0x10,0x10,0x27,0xe0,0x21,0x20,0x20,0x21,0x06,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 28098 0x6dc2 "淂" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x48,0x0b,0x10,0x17,0xe0,0x22,0x21,0x20,0x20,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 28099 0x6dc3 "淃" */
+0x00,0x22,0x11,0x17,0x80,0x41,0x4f,0x12,0x14,0x2b,0xf2,0x22,0x22,0x22,0x22,0x01,
+0x40,0x48,0x50,0xfc,0x80,0x00,0xfe,0x10,0x08,0xf4,0x12,0x10,0x50,0x24,0x04,0xfc,
+/* 28100 0x6dc4 "淄" */
+0x01,0x21,0x12,0x14,0x82,0x41,0x41,0x10,0x17,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x24,0x24,0x48,0x90,0x48,0x24,0x24,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 28101 0x6dc5 "淅" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x56,0x17,0x2a,0xea,0x32,0x22,0x22,0x22,0x02,
+0x00,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0xc8,0x48,0x48,0x48,0x48,0x48,0x88,
+/* 28102 0x6dc6 "淆" */
+0x02,0x21,0x10,0x13,0x8c,0x40,0x4f,0x11,0x13,0x26,0xeb,0x22,0x23,0x22,0x22,0x02,
+0x10,0x20,0xc0,0x30,0x88,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 28103 0x6dc7 "淇" */
+0x01,0x21,0x17,0x11,0x81,0x41,0x49,0x09,0x11,0x11,0xe1,0x27,0x20,0x20,0x21,0x02,
+0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 28104 0x6dc8 "淈" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 28105 0x6dc9 "淉" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x10,0x17,0xe0,0x21,0x22,0x24,0x20,0x00,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 28106 0x6dca "淊" */
+0x01,0x21,0x11,0x12,0x84,0x48,0x41,0x16,0x14,0x24,0xe7,0x24,0x24,0x24,0x27,0x04,
+0x00,0x00,0xf8,0x08,0x10,0x20,0x80,0x3c,0x04,0x04,0xbc,0x04,0x04,0x04,0xfc,0x04,
+/* 28107 0x6dcb "淋" */
+0x01,0x21,0x11,0x11,0x87,0x41,0x41,0x13,0x13,0x25,0xe5,0x29,0x21,0x21,0x21,0x01,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 28108 0x6dcc "淌" */
+0x00,0x22,0x11,0x11,0x80,0x47,0x44,0x14,0x15,0x25,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x40,0x48,0x48,0x50,0x40,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 28109 0x6dcd "淍" */
+0x00,0x27,0x14,0x14,0x85,0x44,0x44,0x17,0x14,0x25,0xe5,0x25,0x25,0x24,0x24,0x08,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 28110 0x6dce "淎" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x11,0x12,0x24,0xe1,0x20,0x27,0x20,0x20,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x48,0x46,0xf0,0x40,0xfc,0x40,0x40,0x40,
+/* 28111 0x6dcf "淏" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x48,0x0b,0x10,0x10,0xe7,0x20,0x20,0x21,0x22,0x04,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfc,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 28112 0x6dd0 "淐" */
+0x03,0x22,0x12,0x13,0x82,0x42,0x43,0x10,0x17,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28113 0x6dd1 "淑" */
+0x01,0x21,0x11,0x11,0x81,0x41,0x47,0x10,0x11,0x21,0xe5,0x25,0x29,0x21,0x25,0x02,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 28114 0x6dd2 "淒" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x13,0x20,0xe7,0x21,0x23,0x20,0x21,0x06,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x80,0xfe,0x08,0x90,0x60,0x98,0x04,
+/* 28115 0x6dd3 "淓" */
+0x02,0x42,0x2f,0x22,0x02,0x80,0x4f,0x41,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x08,0x08,0xfe,0x08,0x88,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 28116 0x6dd4 "淔" */
+0x00,0x20,0x17,0x10,0x80,0x43,0x4a,0x0b,0x12,0x13,0xe2,0x23,0x22,0x22,0x2f,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 28117 0x6dd5 "淕" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x41,0x12,0x14,0x20,0xe3,0x20,0x20,0x20,0x27,0x00,
+0x40,0x40,0xf8,0x40,0x40,0xfc,0x10,0x08,0x44,0x40,0xf8,0x40,0x40,0x40,0xfc,0x00,
+/* 28118 0x6dd6 "淖" */
+0x00,0x20,0x10,0x10,0x83,0x42,0x4b,0x0a,0x13,0x12,0xe0,0x27,0x20,0x20,0x20,0x00,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 28119 0x6dd7 "淗" */
+0x01,0x21,0x11,0x12,0x84,0x44,0x42,0x10,0x17,0x20,0xe1,0x22,0x24,0x20,0x20,0x00,
+0x00,0x00,0xfc,0x04,0x84,0x94,0xa4,0x84,0xfc,0x84,0xc4,0xa4,0x94,0x84,0xa8,0x10,
+/* 28120 0x6dd8 "淘" */
+0x01,0x21,0x11,0x12,0x85,0x41,0x42,0x10,0x17,0x20,0xe2,0x22,0x23,0x20,0x20,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x84,0x84,0xf4,0x84,0xa4,0xa4,0xe4,0x04,0x28,0x10,
+/* 28121 0x6dd9 "淙" */
+0x00,0x40,0x27,0x24,0x08,0x83,0x40,0x50,0x17,0x20,0xe2,0x22,0x24,0x28,0x21,0x00,
+0x80,0x40,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 28122 0x6dda "淚" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x12,0x13,0xe2,0x22,0x22,0x24,0x25,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 28123 0x6ddb "淛" */
+0x01,0x21,0x15,0x17,0x89,0x41,0x4f,0x11,0x17,0x25,0xe5,0x25,0x25,0x25,0x21,0x01,
+0x04,0x04,0x04,0xd4,0x14,0x14,0xf4,0x14,0xd4,0x54,0x54,0x54,0x44,0xc4,0x14,0x08,
+/* 28124 0x6ddc "淜" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x44,0x14,0x14,0x27,0xe4,0x24,0x24,0x24,0x2a,0x11,
+0x00,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0x4c,
+/* 28125 0x6ddd "淝" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x44,0x14,0x14,0x27,0xe4,0x24,0x24,0x28,0x2a,0x11,
+0x00,0xbe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xbe,0xa0,0xa0,0xa0,0xa2,0xa2,0xa2,0x1e,
+/* 28126 0x6dde "淞" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x56,0x17,0x2a,0xea,0x32,0x22,0x22,0x22,0x02,
+0x08,0x28,0x28,0x28,0xa4,0x44,0x54,0x92,0x10,0xa0,0x20,0x28,0x44,0xfc,0x44,0x00,
+/* 28127 0x6ddf "淟" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x27,0x20,0x20,0x21,0x02,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 28128 0x6de0 "淠" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x10,0x20,0xef,0x22,0x22,0x22,0x24,0x08,
+0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfe,0x08,0x08,0x08,0x08,0x08,
+/* 28129 0x6de1 "淡" */
+0x00,0x22,0x12,0x14,0x80,0x41,0x46,0x10,0x10,0x22,0xe2,0x24,0x20,0x21,0x22,0x0c,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 28130 0x6de2 "淢" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x4b,0x0a,0x12,0x12,0xe3,0x20,0x20,0x27,0x22,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 28131 0x6de3 "淣" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x13,0x10,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 28132 0x6de4 "淤" */
+0x02,0x41,0x20,0x2f,0x04,0x84,0x44,0x57,0x14,0x24,0xe4,0x24,0x24,0x28,0x2a,0x11,
+0x10,0x10,0x10,0xa8,0x28,0x44,0x02,0x90,0x88,0x88,0x80,0xa0,0x90,0x88,0x88,0x00,
+/* 28133 0x6de5 "淥" */
+0x00,0x20,0x10,0x11,0x81,0x40,0x48,0x0b,0x10,0x12,0xe1,0x20,0x21,0x22,0x20,0x00,
+0x80,0xf8,0x88,0x08,0xf0,0x10,0x10,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 28134 0x6de6 "淦" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x41,0x10,0x10,0x23,0xe0,0x22,0x21,0x21,0x2f,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x40,0x40,0xf8,0x40,0x48,0x48,0x50,0xfe,0x00,
+/* 28135 0x6de7 "淧" */
+0x00,0x20,0x13,0x12,0x84,0x40,0x48,0x08,0x10,0x12,0xe2,0x24,0x21,0x22,0x24,0x00,
+0x40,0x20,0xfe,0x02,0x44,0x20,0x28,0x88,0x90,0xa4,0xc2,0x82,0x88,0x88,0x78,0x00,
+/* 28136 0x6de8 "淨" */
+0x00,0x27,0x12,0x11,0x80,0x43,0x48,0x08,0x17,0x10,0xe0,0x23,0x20,0x20,0x21,0x00,
+0x3c,0xc0,0x44,0x28,0x00,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x48,0x40,0x40,0x80,
+/* 28137 0x6de9 "淩" */
+0x00,0x20,0x17,0x10,0x80,0x4f,0x42,0x14,0x18,0x21,0xe2,0x25,0x20,0x20,0x21,0x0e,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x08,0x84,0x82,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 28138 0x6dea "淪" */
+0x00,0x20,0x10,0x11,0x82,0x4d,0x40,0x17,0x14,0x24,0xe7,0x24,0x24,0x24,0x24,0x04,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x14,0x08,
+/* 28139 0x6deb "淫" */
+0x00,0x20,0x17,0x10,0x84,0x42,0x42,0x10,0x17,0x20,0xe0,0x2f,0x20,0x20,0x27,0x00,
+0x08,0x3c,0xc0,0x84,0x44,0x48,0x10,0x3c,0xc0,0x40,0x40,0xfe,0x40,0x40,0xfc,0x00,
+/* 28140 0x6dec "淬" */
+0x00,0x20,0x17,0x10,0x81,0x41,0x42,0x14,0x10,0x20,0xe7,0x20,0x20,0x20,0x20,0x00,
+0x80,0x40,0xfc,0x00,0x10,0x10,0xa8,0x44,0x00,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 28141 0x6ded "淭" */
+0x00,0x20,0x17,0x14,0x84,0x47,0x44,0x14,0x17,0x24,0xe9,0x29,0x32,0x24,0x28,0x00,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 28142 0x6dee "淮" */
+0x01,0x21,0x11,0x13,0x82,0x46,0x4b,0x12,0x12,0x23,0xe2,0x22,0x22,0x23,0x22,0x02,
+0x40,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 28143 0x6def "淯" */
+0x00,0x20,0x17,0x11,0x82,0x47,0x40,0x13,0x12,0x23,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x80,0x40,0xfe,0x00,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 28144 0x6df0 "淰" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x40,0x13,0x10,0x20,0xe0,0x21,0x25,0x25,0x29,0x00,
+0x40,0x40,0xa0,0x10,0x88,0x46,0x00,0xf0,0x10,0x20,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 28145 0x6df1 "深" */
+0x00,0x27,0x14,0x14,0x81,0x42,0x40,0x10,0x17,0x20,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x00,0xfc,0x04,0xa4,0x10,0x08,0x40,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 28146 0x6df2 "淲" */
+0x00,0x20,0x10,0x10,0x83,0x42,0x4a,0x0b,0x12,0x12,0xe2,0x22,0x24,0x24,0x29,0x12,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 28147 0x6df3 "淳" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x4b,0x08,0x13,0x10,0xe0,0x27,0x20,0x20,0x21,0x00,
+0x80,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x10,0x20,0xfc,0x40,0x40,0x40,0x80,
+/* 28148 0x6df4 "淴" */
+0x01,0x21,0x13,0x14,0x88,0x41,0x42,0x14,0x11,0x22,0xe0,0x21,0x25,0x25,0x28,0x00,
+0x00,0x00,0xfc,0x94,0x94,0x24,0x44,0x84,0x28,0x10,0x40,0x24,0x2a,0x0a,0xf8,0x00,
+/* 28149 0x6df5 "淵" */
+0x00,0x24,0x14,0x14,0x87,0x44,0x44,0x17,0x14,0x24,0xe7,0x24,0x24,0x24,0x28,0x10,
+0xa0,0xa4,0xa4,0xa4,0xbc,0x04,0x04,0xfc,0x04,0x04,0xbc,0xa4,0xa4,0xa4,0xa4,0x04,
+/* 28150 0x6df6 "淶" */
+0x00,0x20,0x10,0x17,0x80,0x42,0x42,0x12,0x15,0x20,0xe1,0x21,0x22,0x24,0x28,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 28151 0x6df7 "混" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x10,0x24,0xe4,0x27,0x24,0x24,0x25,0x06,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x20,0x22,0xac,0x30,0x22,0xa2,0x1e,
+/* 28152 0x6df8 "淸" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x48,0x48,0xf8,0x08,0x08,0x28,0x10,
+/* 28153 0x6df9 "淹" */
+0x00,0x20,0x17,0x11,0x82,0x44,0x43,0x12,0x12,0x23,0xe2,0x22,0x23,0x20,0x20,0x00,
+0x40,0x80,0xfe,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 28154 0x6dfa "淺" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x51,0x1e,0x10,0x20,0xe0,0x27,0x20,0x20,0x21,0x0e,
+0xa0,0x90,0xbc,0xc8,0x50,0x64,0x94,0x0c,0xa0,0x90,0xbc,0xc8,0x50,0x64,0x94,0x0c,
+/* 28155 0x6dfb "添" */
+0x00,0x23,0x10,0x10,0x87,0x40,0x41,0x12,0x14,0x20,0xe0,0x22,0x22,0x24,0x21,0x00,
+0x00,0xfc,0x40,0x40,0xfe,0xa0,0x10,0x08,0x46,0x40,0x48,0x64,0x52,0x52,0x40,0x80,
+/* 28156 0x6dfc "淼" */
+0x01,0x01,0x7d,0x05,0x09,0x31,0xc5,0x02,0x08,0x0a,0x6a,0x2c,0x2a,0x4a,0xa9,0x10,
+0x00,0x08,0x10,0xa0,0x60,0x18,0x06,0x00,0x10,0x14,0xd4,0x58,0x54,0x94,0x52,0x20,
+/* 28157 0x6dfd "淽" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x48,0x09,0x11,0x11,0xe1,0x21,0x21,0x21,0x2f,0x00,
+0x08,0x08,0xfe,0x08,0x08,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28158 0x6dfe "淾" */
+0x01,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,0x00,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0x00,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,0x00,0x08,0x90,0x60,0x20,0x18,0x06,
+/* 28159 0x6dff "淿" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x4b,0x08,0x10,0x17,0xe4,0x24,0x24,0x24,0x20,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x40,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 28160 0x6e00 "渀" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x45,0x10,0x11,0x21,0xe7,0x21,0x21,0x21,0x22,0x04,
+0x40,0x40,0xfe,0xa0,0x50,0x48,0xf6,0x40,0x50,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 28161 0x6e01 "渁" */
+0x00,0x47,0x21,0x21,0x02,0x84,0x49,0x40,0x10,0x20,0xe7,0x21,0x22,0x24,0x29,0x00,
+0x40,0x44,0x68,0x50,0x48,0x44,0x40,0x80,0x00,0x40,0x44,0x68,0x50,0x48,0x46,0x80,
+/* 28162 0x6e02 "渂" */
+0x03,0x22,0x12,0x13,0x82,0x42,0x4b,0x08,0x10,0x17,0xe1,0x21,0x20,0x20,0x21,0x0e,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0x40,0xfc,0x10,0x10,0xa0,0x40,0xb0,0x0e,
+/* 28163 0x6e03 "渃" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x47,0x10,0x11,0x23,0xe5,0x29,0x21,0x21,0x21,0x01,
+0x08,0x08,0xfe,0x08,0x48,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 28164 0x6e04 "渄" */
+0x00,0x20,0x10,0x17,0x80,0x40,0x48,0x0b,0x10,0x10,0xe0,0x27,0x20,0x20,0x20,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 28165 0x6e05 "清" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x13,0x22,0xe3,0x22,0x23,0x22,0x22,0x02,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 28166 0x6e06 "渆" */
+0x08,0x44,0x20,0x2f,0x04,0x84,0x44,0x54,0x1f,0x24,0xe4,0x24,0x24,0x28,0x28,0x10,
+0x44,0x84,0x04,0xd4,0x94,0x94,0x94,0x94,0xf4,0x94,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 28167 0x6e07 "渇" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x49,0x0b,0x14,0x12,0xe3,0x22,0x21,0x20,0x20,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x24,0xd4,0x14,0xf4,0x04,0x28,0x10,
+/* 28168 0x6e08 "済" */
+0x00,0x20,0x17,0x11,0x80,0x40,0x41,0x16,0x11,0x21,0xe1,0x21,0x21,0x21,0x22,0x04,
+0x40,0x20,0xfe,0x08,0x90,0x60,0x98,0x06,0x08,0xf8,0x08,0xf8,0x08,0x08,0x08,0x08,
+/* 28169 0x6e09 "渉" */
+0x00,0x20,0x11,0x11,0x81,0x41,0x47,0x10,0x10,0x21,0xe1,0x22,0x24,0x20,0x20,0x07,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x28,0x24,0x22,0x2a,0x10,0x20,0xc0,0x00,
+/* 28170 0x6e0a "渊" */
+0x04,0x24,0x16,0x15,0x85,0x44,0x47,0x14,0x14,0x24,0xe5,0x25,0x26,0x28,0x28,0x10,
+0x44,0x44,0x54,0x54,0x64,0x44,0xfc,0x44,0xc4,0xe4,0x54,0x54,0x44,0x44,0x44,0x44,
+/* 28171 0x6e0b "渋" */
+0x00,0x20,0x11,0x11,0x81,0x41,0x47,0x10,0x10,0x22,0xe1,0x20,0x21,0x22,0x24,0x00,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x00,0x04,0x08,0x90,0x08,0x04,0x02,0x00,
+/* 28172 0x6e0c "渌" */
+0x00,0x23,0x10,0x10,0x83,0x40,0x40,0x17,0x10,0x24,0xe2,0x21,0x22,0x24,0x21,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x40,0x44,0xe8,0x50,0x48,0x46,0x40,0x80,
+/* 28173 0x6e0d "渍" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x13,0x22,0xe2,0x22,0x22,0x20,0x21,0x06,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x48,0x48,0x48,0xa0,0x10,0x08,
+/* 28174 0x6e0e "渎" */
+0x00,0x20,0x13,0x10,0x80,0x47,0x40,0x11,0x10,0x22,0xe1,0x27,0x20,0x20,0x21,0x06,
+0x40,0x40,0xf8,0x40,0x40,0xfc,0x04,0x28,0xa0,0x20,0x20,0xfc,0x50,0x88,0x04,0x04,
+/* 28175 0x6e0f "渏" */
+0x00,0x20,0x13,0x10,0x81,0x42,0x57,0x10,0x13,0x22,0xe2,0x22,0x23,0x20,0x20,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 28176 0x6e10 "渐" */
+0x01,0x41,0x21,0x2f,0x02,0x82,0x45,0x57,0x11,0x21,0xe1,0x2f,0x25,0x21,0x21,0x01,
+0x00,0x02,0x1c,0xd0,0x10,0x10,0x1e,0xd4,0x14,0x14,0xd4,0x14,0x14,0x24,0x24,0x44,
+/* 28177 0x6e11 "渑" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x47,0x14,0x14,0x27,0xe4,0x24,0x27,0x20,0x20,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x42,0x42,0x3e,
+/* 28178 0x6e12 "渒" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x13,0x10,0xe1,0x27,0x20,0x20,0x20,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 28179 0x6e13 "渓" */
+0x00,0x27,0x10,0x14,0x82,0x42,0x48,0x08,0x13,0x10,0xe0,0x27,0x20,0x21,0x22,0x0c,
+0x3c,0xc0,0x84,0x44,0x48,0x10,0x40,0x40,0xf8,0x40,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 28180 0x6e14 "渔" */
+0x01,0x41,0x23,0x22,0x04,0x8f,0x54,0x54,0x17,0x24,0xe4,0x27,0x20,0x20,0x2f,0x00,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfe,0x00,
+/* 28181 0x6e15 "渕" */
+0x04,0x22,0x12,0x17,0x81,0x41,0x51,0x1f,0x11,0x21,0xe2,0x22,0x24,0x24,0x28,0x00,
+0x44,0x44,0x84,0xd4,0x14,0x14,0x14,0xf4,0x14,0x14,0x94,0x54,0x44,0x44,0x14,0x08,
+/* 28182 0x6e16 "渖" */
+0x00,0x20,0x17,0x14,0x80,0x43,0x42,0x12,0x13,0x22,0xe2,0x23,0x22,0x20,0x20,0x00,
+0x80,0x40,0xfc,0x44,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x48,0x40,0x40,0x40,
+/* 28183 0x6e17 "渗" */
+0x00,0x20,0x11,0x13,0x80,0x47,0x41,0x12,0x1c,0x23,0xe0,0x20,0x23,0x20,0x20,0x07,
+0x80,0x90,0x08,0xfc,0x40,0xfe,0x10,0x48,0x86,0x10,0x20,0xc4,0x08,0x30,0xc0,0x00,
+/* 28184 0x6e18 "渘" */
+0x00,0x23,0x10,0x10,0x87,0x40,0x41,0x12,0x14,0x20,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0x20,0x60,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 28185 0x6e19 "渙" */
+0x01,0x21,0x13,0x14,0x88,0x47,0x44,0x14,0x15,0x24,0xe0,0x2f,0x20,0x21,0x22,0x0c,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x04,0xa4,0x14,0x44,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 28186 0x6e1a "渚" */
+0x00,0x20,0x17,0x10,0x80,0x4f,0x40,0x11,0x13,0x26,0xea,0x23,0x22,0x22,0x23,0x02,
+0x80,0x88,0xe8,0x90,0xa0,0xfe,0x80,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28187 0x6e1b "減" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x45,0x14,0x14,0x25,0xe5,0x25,0x25,0x24,0x28,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 28188 0x6e1c "渜" */
+0x00,0x27,0x10,0x10,0x87,0x44,0x44,0x14,0x14,0x24,0xe0,0x2f,0x20,0x21,0x22,0x0c,
+0x00,0xfc,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0x84,0x4c,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 28189 0x6e1d "渝" */
+0x00,0x20,0x11,0x12,0x85,0x48,0x47,0x14,0x14,0x27,0xe4,0x24,0x27,0x24,0x25,0x04,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0x88,
+/* 28190 0x6e1e "渞" */
+0x02,0x21,0x17,0x10,0x80,0x43,0x4a,0x0a,0x13,0x12,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x08,0x10,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28191 0x6e1f "渟" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x43,0x10,0x1f,0x28,0xe3,0x20,0x20,0x20,0x21,0x00,
+0x80,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x40,0x40,0x40,0x40,0x80,
+/* 28192 0x6e20 "渠" */
+0x23,0x12,0x83,0x4a,0x0a,0x13,0xe2,0x23,0x21,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 28193 0x6e21 "渡" */
+0x00,0x20,0x17,0x14,0x84,0x47,0x44,0x14,0x14,0x25,0xe4,0x24,0x24,0x28,0x28,0x13,
+0x40,0x20,0xfe,0x88,0x88,0xfe,0x88,0xf8,0x00,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 28194 0x6e22 "渢" */
+0x40,0x2f,0x28,0x88,0x4b,0x48,0x08,0x2b,0x2a,0x4a,0xcb,0x48,0x48,0x50,0x57,0x20,
+0x00,0xf8,0x08,0x68,0x88,0x88,0x88,0xe8,0xa8,0xa8,0xe8,0x8a,0xaa,0xea,0x26,0x02,
+/* 28195 0x6e23 "渣" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x44,0x13,0x12,0x23,0xe2,0x23,0x22,0x20,0x2f,0x00,
+0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 28196 0x6e24 "渤" */
+0x02,0x82,0x5f,0x02,0x82,0x5f,0x50,0x20,0x2f,0x41,0xc2,0x43,0x5e,0x42,0x4a,0x04,
+0x10,0x10,0xd0,0x10,0x3e,0xd2,0x52,0x92,0x12,0x12,0x12,0x92,0x22,0x22,0x4a,0x84,
+/* 28197 0x6e25 "渥" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4b,0x0a,0x12,0x13,0xe2,0x22,0x25,0x24,0x28,0x13,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,
+/* 28198 0x6e26 "渦" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x42,0x17,0x14,0x25,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 28199 0x6e27 "渧" */
+0x00,0x20,0x13,0x10,0x81,0x40,0x47,0x14,0x18,0x23,0xe2,0x22,0x22,0x22,0x20,0x00,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x42,0x44,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 28200 0x6e28 "渨" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x10,0x17,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 28201 0x6e29 "温" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x42,0x13,0x10,0x27,0xe4,0x24,0x24,0x24,0x2f,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 28202 0x6e2a "渪" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x4a,0x0b,0x10,0x17,0xe4,0x24,0x25,0x24,0x24,0x04,
+0x08,0x3c,0xc0,0x40,0xf8,0x48,0x48,0xf8,0x40,0xfc,0x44,0x54,0xf4,0x04,0x14,0x08,
+/* 28203 0x6e2b "渫" */
+0x00,0x22,0x12,0x17,0x82,0x42,0x42,0x12,0x13,0x20,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x90,0x90,0x90,0xfe,0x90,0x90,0xf0,0x00,0xfc,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 28204 0x6e2c "測" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x14,0x24,0xe7,0x20,0x22,0x22,0x24,0x08,
+0x02,0xc2,0x42,0x52,0xd2,0x52,0x52,0xd2,0x52,0x52,0xd2,0x02,0x82,0x42,0x4a,0x04,
+/* 28205 0x6e2d "渭" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x40,0x13,0x12,0x23,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 28206 0x6e2e "渮" */
+0x01,0x21,0x17,0x11,0x80,0x47,0x40,0x10,0x13,0x22,0xe2,0x23,0x22,0x20,0x20,0x00,
+0x10,0x10,0xfe,0x10,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0xc8,0x48,0x08,0x28,0x10,
+/* 28207 0x6e2f "港" */
+0x01,0x21,0x17,0x11,0x81,0x4f,0x41,0x12,0x17,0x2a,0xe2,0x23,0x22,0x22,0x21,0x00,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0xf4,0x12,0x10,0xf0,0x04,0x04,0xfc,0x00,
+/* 28208 0x6e30 "渰" */
+0x00,0x20,0x11,0x12,0x8d,0x40,0x43,0x12,0x12,0x23,0xe1,0x21,0x27,0x21,0x22,0x04,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xf8,0x08,0x08,0xf8,0x10,0x10,0xfc,0x10,0x10,0x10,
+/* 28209 0x6e31 "渱" */
+0x01,0x21,0x11,0x17,0x85,0x45,0x45,0x15,0x17,0x25,0xe1,0x21,0x21,0x2e,0x24,0x00,
+0x00,0x00,0x3e,0xc8,0x48,0x48,0x48,0x48,0xc8,0x08,0x08,0x48,0xc8,0x48,0x3e,0x00,
+/* 28210 0x6e32 "渲" */
+0x00,0x40,0x27,0x24,0x08,0x83,0x40,0x53,0x12,0x23,0xe2,0x23,0x22,0x20,0x27,0x00,
+0x80,0x40,0xfc,0x04,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfc,0x00,
+/* 28211 0x6e33 "渳" */
+0x00,0x27,0x11,0x11,0x81,0x47,0x44,0x14,0x14,0x27,0xe1,0x21,0x21,0x21,0x2a,0x04,
+0x00,0x7e,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x26,0x7c,0x04,0x04,0x04,0x04,
+/* 28212 0x6e34 "渴" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x49,0x0b,0x14,0x12,0xe2,0x22,0x23,0x20,0x20,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 28213 0x6e35 "渵" */
+0x02,0x42,0x2f,0x22,0x02,0x80,0x47,0x54,0x14,0x24,0xe7,0x24,0x24,0x24,0x27,0x04,
+0x08,0x08,0xfe,0x08,0x08,0x00,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x04,
+/* 28214 0x6e36 "渶" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x43,0x12,0x12,0x22,0xef,0x20,0x20,0x21,0x22,0x04,
+0x10,0x10,0xfc,0x10,0x50,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 28215 0x6e37 "渷" */
+0x00,0x20,0x17,0x11,0x82,0x44,0x43,0x12,0x12,0x23,0xe1,0x21,0x21,0x22,0x24,0x08,
+0x80,0x40,0xfc,0x10,0x08,0x04,0xf8,0x08,0x08,0xf8,0x10,0x10,0x12,0x12,0x0e,0x00,
+/* 28216 0x6e38 "游" */
+0x02,0x21,0x11,0x17,0x82,0x42,0x43,0x12,0x12,0x22,0xe2,0x22,0x24,0x24,0x29,0x10,
+0x10,0x10,0x10,0xbe,0x20,0x40,0xbc,0x84,0x88,0x88,0xbe,0x88,0x88,0x88,0xa8,0x10,
+/* 28217 0x6e39 "渹" */
+0x02,0x22,0x13,0x14,0x88,0x47,0x40,0x17,0x10,0x27,0xe0,0x27,0x24,0x27,0x20,0x00,
+0x00,0x00,0xfe,0x02,0x82,0xfa,0x02,0xf2,0x02,0xf2,0x02,0xf2,0x12,0xf2,0x14,0x08,
+/* 28218 0x6e3a "渺" */
+0x40,0x20,0x2f,0x89,0x49,0x4f,0x09,0x29,0x2f,0x49,0xc9,0x4f,0x49,0x40,0x40,0x01,
+0x10,0x10,0x10,0x10,0x14,0x52,0x52,0x92,0x10,0x14,0x04,0x08,0x10,0x20,0x40,0x80,
+/* 28219 0x6e3b "渻" */
+0x00,0x20,0x12,0x12,0x84,0x40,0x49,0x0e,0x13,0x12,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x40,0x40,0x48,0x44,0x54,0x60,0x80,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 28220 0x6e3c "渼" */
+0x02,0x21,0x17,0x10,0x80,0x43,0x48,0x08,0x17,0x10,0xe0,0x27,0x20,0x21,0x22,0x0c,
+0x08,0x10,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 28221 0x6e3d "渽" */
+0x01,0x21,0x17,0x11,0x81,0x4f,0x40,0x10,0x17,0x24,0xe4,0x24,0x27,0x24,0x20,0x00,
+0x28,0x24,0xa4,0x20,0x20,0xfe,0x20,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 28222 0x6e3e "渾" */
+0x00,0x27,0x14,0x10,0x87,0x40,0x4b,0x0a,0x13,0x12,0xe3,0x20,0x27,0x20,0x20,0x00,
+0x00,0xfc,0x44,0x40,0xfe,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 28223 0x6e3f "渿" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x4c,0x13,0x10,0x20,0xe7,0x20,0x22,0x24,0x29,0x00,
+0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf8,0x00,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 28224 0x6e40 "湀" */
+0x00,0x27,0x10,0x14,0x83,0x41,0x42,0x15,0x10,0x20,0xe7,0x20,0x20,0x21,0x22,0x04,
+0x20,0xa8,0xb0,0xa4,0x18,0x10,0x08,0xf4,0x40,0x40,0xfc,0x40,0xa0,0x10,0x08,0x04,
+/* 28225 0x6e41 "湁" */
+0x02,0x22,0x12,0x12,0x8f,0x42,0x42,0x13,0x12,0x2e,0xe2,0x22,0x22,0x22,0x2a,0x04,
+0x10,0x10,0x28,0x28,0x44,0x82,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 28226 0x6e42 "湂" */
+0x00,0x27,0x14,0x14,0x87,0x40,0x43,0x10,0x1f,0x21,0xe2,0x23,0x20,0x20,0x20,0x00,
+0x00,0xbc,0xa4,0xa4,0xbc,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 28227 0x6e43 "湃" */
+0x01,0x43,0x2e,0x22,0x02,0x8f,0x42,0x52,0x12,0x2f,0xe2,0x22,0x22,0x22,0x24,0x08,
+0x00,0xbc,0x10,0x10,0x3c,0x90,0x10,0x3c,0x10,0x90,0x7e,0x10,0x10,0x10,0x10,0x10,
+/* 28228 0x6e44 "湄" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x28,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 28229 0x6e45 "湅" */
+0x00,0x40,0x2f,0x20,0x07,0x84,0x45,0x54,0x14,0x27,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0x54,0xe4,0x44,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 28230 0x6e46 "湆" */
+0x00,0x20,0x17,0x10,0x82,0x41,0x4f,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x80,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28231 0x6e47 "湇" */
+0x00,0x20,0x17,0x12,0x81,0x4f,0x40,0x13,0x12,0x23,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x80,0x40,0xfc,0x08,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 28232 0x6e48 "湈" */
+0x02,0x42,0x2f,0x22,0x02,0x83,0x42,0x52,0x13,0x20,0xef,0x20,0x21,0x22,0x2c,0x00,
+0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 28233 0x6e49 "湉" */
+0x02,0x42,0x22,0x22,0x03,0x8a,0x4a,0x4a,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x08,0x1c,0x70,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 28234 0x6e4a "湊" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x11,0x12,0x25,0xe0,0x23,0x20,0x20,0x21,0x06,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x40,0xf8,0x40,0xa0,0x10,0x08,
+/* 28235 0x6e4b "湋" */
+0x00,0x20,0x13,0x11,0x87,0x40,0x4b,0x0a,0x13,0x10,0xe7,0x20,0x24,0x27,0x20,0x00,
+0x80,0x80,0xf8,0x08,0xfe,0x00,0xf8,0x08,0xf8,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,
+/* 28236 0x6e4c "湌" */
+0x00,0x20,0x10,0x11,0x82,0x44,0x4b,0x0a,0x13,0x12,0xe3,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x28,0x90,0x08,0x04,
+/* 28237 0x6e4d "湍" */
+0x00,0x24,0x14,0x14,0x87,0x40,0x4f,0x10,0x10,0x27,0xe4,0x24,0x24,0x24,0x24,0x04,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x0c,
+/* 28238 0x6e4e "湎" */
+0x00,0x27,0x10,0x10,0x87,0x44,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x24,0x27,0x04,
+0x00,0xfe,0x40,0x80,0xfe,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x92,0x92,0xfe,0x02,
+/* 28239 0x6e4f "湏" */
+0x00,0x27,0x10,0x10,0x83,0x42,0x4a,0x0b,0x12,0x13,0xe2,0x22,0x23,0x20,0x21,0x02,
+0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x08,0x04,
+/* 28240 0x6e50 "湐" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x57,0x16,0x2a,0xea,0x32,0x22,0x22,0x22,0x02,
+0x10,0x10,0x20,0x7c,0xc4,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 28241 0x6e51 "湑" */
+0x00,0x27,0x10,0x12,0x82,0x42,0x55,0x18,0x13,0x22,0xe3,0x22,0x23,0x22,0x22,0x02,
+0x00,0xfc,0x44,0x40,0x78,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 28242 0x6e52 "湒" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x4f,0x12,0x13,0x22,0xe3,0x22,0x22,0x2f,0x20,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x7e,0x88,0x08,0x08,
+/* 28243 0x6e53 "湓" */
+0x00,0x21,0x11,0x12,0x85,0x40,0x41,0x12,0x14,0x23,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x10,0x10,0x08,0x04,0xfa,0x88,0x08,0x28,0x10,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 28244 0x6e54 "湔" */
+0x02,0x41,0x21,0x2f,0x00,0x87,0x44,0x54,0x17,0x24,0xe4,0x27,0x24,0x24,0x25,0x04,
+0x08,0x08,0x10,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0x88,
+/* 28245 0x6e55 "湕" */
+0x00,0x20,0x17,0x11,0x81,0x42,0x42,0x17,0x11,0x25,0xe5,0x22,0x22,0x25,0x28,0x00,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 28246 0x6e56 "湖" */
+0x01,0x21,0x11,0x17,0x81,0x41,0x41,0x17,0x14,0x24,0xe4,0x27,0x24,0x20,0x20,0x00,
+0x00,0x1e,0x12,0xd2,0x12,0x1e,0x12,0xd2,0x52,0x5e,0x52,0xd2,0x52,0x22,0x2a,0x44,
+/* 28247 0x6e57 "湗" */
+0x01,0x21,0x11,0x17,0x81,0x41,0x47,0x10,0x11,0x21,0xe7,0x21,0x21,0x21,0x2e,0x04,
+0x04,0x04,0x04,0xc4,0x3e,0x04,0xc4,0x24,0x14,0x14,0xc4,0x04,0x04,0xc4,0x14,0x08,
+/* 28248 0x6e58 "湘" */
+0x02,0x42,0x22,0x22,0x0f,0x82,0x42,0x57,0x16,0x2a,0xf2,0x22,0x22,0x22,0x22,0x02,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0xc4,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 28249 0x6e59 "湙" */
+0x00,0x20,0x17,0x10,0x82,0x44,0x41,0x12,0x14,0x20,0xe7,0x20,0x20,0x21,0x22,0x0c,
+0x80,0x40,0xfe,0x90,0x98,0x94,0x14,0x30,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 28250 0x6e5a "湚" */
+0x00,0x24,0x15,0x15,0x84,0x44,0x45,0x14,0x15,0x25,0xe5,0x25,0x25,0x29,0x29,0x11,
+0x40,0x88,0x28,0xe8,0x48,0xa8,0xe8,0x08,0xe8,0x28,0xe8,0x28,0xea,0x2a,0x2a,0x66,
+/* 28251 0x6e5b "湛" */
+0x01,0x21,0x17,0x11,0x81,0x41,0x49,0x09,0x11,0x17,0xe2,0x22,0x23,0x22,0x23,0x00,
+0x08,0x08,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x50,0x88,0x04,0x00,0xfc,0x00,
+/* 28252 0x6e5c "湜" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0b,0x10,0x17,0xe0,0x22,0x22,0x22,0x25,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x40,0x40,0x78,0x40,0x40,0xfe,
+/* 28253 0x6e5d "湝" */
+0x02,0x22,0x13,0x12,0x82,0x43,0x4a,0x08,0x13,0x12,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x20,0x24,0xa8,0x30,0xa2,0x22,0x5e,0x80,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28254 0x6e5e "湞" */
+0x00,0x20,0x10,0x10,0x87,0x44,0x44,0x17,0x14,0x27,0xe4,0x24,0x27,0x21,0x22,0x04,
+0x40,0x7e,0x40,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x10,0x08,0x04,
+/* 28255 0x6e5f "湟" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x4b,0x08,0x17,0x10,0xe0,0x23,0x20,0x20,0x27,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,
+/* 28256 0x6e60 "湠" */
+0x00,0x24,0x14,0x14,0x87,0x41,0x41,0x17,0x11,0x22,0xe2,0x22,0x25,0x24,0x28,0x01,
+0x40,0x44,0x44,0x44,0xfc,0x00,0x00,0xfe,0x20,0x20,0xa4,0xa8,0x50,0x50,0x88,0x06,
+/* 28257 0x6e61 "湡" */
+0x03,0x22,0x12,0x13,0x82,0x42,0x4b,0x08,0x10,0x17,0xe4,0x24,0x25,0x24,0x24,0x04,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0x44,0x54,0xf4,0x14,0x04,0x0c,
+/* 28258 0x6e62 "湢" */
+0x00,0x27,0x10,0x13,0x82,0x42,0x43,0x10,0x17,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 28259 0x6e63 "湣" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x4a,0x0a,0x13,0x10,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 28260 0x6e64 "湤" */
+0x02,0x21,0x11,0x17,0x82,0x42,0x4b,0x0a,0x12,0x12,0xe2,0x22,0x24,0x24,0x29,0x10,
+0x10,0x10,0x10,0xbe,0x28,0x48,0xaa,0xae,0xba,0xea,0xae,0xa8,0xaa,0xa2,0xa2,0x1e,
+/* 28261 0x6e65 "湥" */
+0x00,0x20,0x17,0x14,0x81,0x42,0x44,0x10,0x10,0x27,0xe0,0x20,0x20,0x21,0x22,0x04,
+0x80,0x40,0xfc,0x04,0x10,0x08,0x44,0x50,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 28262 0x6e66 "湦" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x48,0x0a,0x13,0x14,0xe0,0x23,0x20,0x20,0x27,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 28263 0x6e67 "湧" */
+0x00,0x27,0x11,0x10,0x87,0x44,0x47,0x14,0x17,0x24,0xe0,0x27,0x20,0x21,0x22,0x04,
+0x00,0xf8,0x10,0xa0,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x80,0xfc,0x84,0x04,0x28,0x10,
+/* 28264 0x6e68 "湨" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x4a,0x0b,0x10,0x10,0xe7,0x20,0x20,0x21,0x22,0x0c,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x50,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 28265 0x6e69 "湩" */
+0x00,0x20,0x17,0x10,0x8f,0x40,0x47,0x14,0x17,0x24,0xe7,0x20,0x27,0x20,0x2f,0x00,
+0x08,0x3c,0xc0,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfc,0x40,0xfe,0x00,
+/* 28266 0x6e6a "湪" */
+0x01,0x21,0x12,0x13,0x80,0x47,0x40,0x11,0x16,0x20,0xe1,0x26,0x20,0x21,0x26,0x00,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 28267 0x6e6b "湫" */
+0x43,0x2e,0x22,0x82,0x42,0x4f,0x02,0x26,0x27,0x4a,0xca,0x52,0x42,0x42,0x42,0x03,
+0x90,0x10,0x10,0x12,0x52,0xd4,0x58,0x90,0x10,0xa8,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 28268 0x6e6c "湬" */
+0x06,0x38,0x08,0x7e,0x08,0x1c,0x2a,0x48,0x09,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x10,0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 28269 0x6e6d "湭" */
+0x01,0x20,0x10,0x17,0x80,0x40,0x4b,0x0a,0x12,0x13,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28270 0x6e6e "湮" */
+0x00,0x27,0x10,0x10,0x87,0x44,0x44,0x14,0x17,0x20,0xe0,0x27,0x20,0x20,0x2f,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 28271 0x6e6f "湯" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x50,0x1f,0x12,0x23,0xe4,0x29,0x22,0x24,0x21,0x02,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 28272 0x6e70 "湰" */
+0x00,0x21,0x12,0x15,0x80,0x43,0x4c,0x13,0x10,0x22,0xe3,0x24,0x23,0x20,0x2f,0x00,
+0x80,0xf8,0x08,0x10,0xe0,0x18,0x06,0xf8,0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,
+/* 28273 0x6e71 "湱" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x17,0x20,0xe1,0x23,0x2d,0x21,0x21,0x01,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfc,0x40,0xfc,0x80,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 28274 0x6e72 "湲" */
+0x00,0x27,0x12,0x11,0x80,0x43,0x48,0x08,0x17,0x11,0xe1,0x22,0x22,0x24,0x28,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 28275 0x6e73 "湳" */
+0x00,0x40,0x2f,0x20,0x00,0x87,0x45,0x54,0x15,0x24,0xe4,0x25,0x24,0x24,0x24,0x04,
+0x40,0x40,0xfe,0x40,0x40,0xfc,0x14,0xa4,0xf4,0x44,0x44,0xf4,0x44,0x44,0x54,0x08,
+/* 28276 0x6e74 "湴" */
+0x01,0x20,0x10,0x13,0x80,0x40,0x40,0x14,0x12,0x22,0xe0,0x20,0x20,0x20,0x27,0x00,
+0x08,0x90,0x00,0xfc,0x90,0x90,0x92,0x92,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 28277 0x6e75 "湵" */
+0x02,0x21,0x17,0x10,0x83,0x40,0x47,0x11,0x11,0x23,0xe4,0x28,0x20,0x20,0x23,0x0c,
+0x08,0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0x00,0xf8,0x10,0x20,0x40,0xa0,0x18,0x06,
+/* 28278 0x6e76 "湶" */
+0x00,0x21,0x13,0x12,0x83,0x42,0x43,0x10,0x10,0x27,0xe1,0x21,0x22,0x24,0x29,0x00,
+0x80,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x40,0x64,0x68,0x50,0x48,0x44,0x42,0x80,
+/* 28279 0x6e77 "湷" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x11,0x12,0x27,0xea,0x22,0x23,0x22,0x22,0x03,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x10,0x08,0xfc,0x0a,0x08,0xf8,0x08,0x08,0xf8,
+/* 28280 0x6e78 "湸" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x43,0x10,0x17,0x24,0xe9,0x21,0x21,0x22,0x24,0x08,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf4,0x10,0x10,0x12,0x12,0x0e,
+/* 28281 0x6e79 "湹" */
+0x00,0x27,0x14,0x15,0x85,0x45,0x45,0x15,0x15,0x25,0xe4,0x24,0x25,0x28,0x28,0x13,
+0x00,0xfe,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 28282 0x6e7a "湺" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x4a,0x12,0x12,0x22,0xe2,0x22,0x22,0x23,0x22,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 28283 0x6e7b "湻" */
+0x00,0x20,0x17,0x10,0x81,0x41,0x49,0x08,0x13,0x12,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28284 0x6e7c "湼" */
+0x01,0x26,0x14,0x14,0x87,0x44,0x44,0x17,0x10,0x20,0xe7,0x20,0x20,0x20,0x2f,0x00,
+0x00,0x1c,0x04,0x04,0x1c,0x04,0x04,0xfc,0x00,0x00,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 28285 0x6e7d "湽" */
+0x02,0x42,0x24,0x2f,0x04,0x82,0x42,0x50,0x17,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x48,0x48,0x90,0xfe,0x90,0x48,0x48,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 28286 0x6e7e "湾" */
+0x01,0x20,0x1f,0x11,0x85,0x49,0x40,0x17,0x10,0x27,0xe4,0x27,0x20,0x20,0x20,0x00,
+0x00,0x80,0xfc,0x20,0x28,0x24,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 28287 0x6e7f "湿" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x11,0x21,0xe9,0x25,0x23,0x21,0x2f,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x24,0x28,0x30,0x20,0xfe,0x00,
+/* 28288 0x6e80 "満" */
+0x01,0x41,0x2f,0x21,0x00,0x87,0x40,0x50,0x17,0x24,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x10,0x10,0xfe,0x10,0x00,0xfc,0x40,0x40,0xfc,0x44,0x54,0x54,0xf4,0x04,0x14,0x08,
+/* 28289 0x6e81 "溁" */
+0x00,0x20,0x13,0x10,0x80,0x43,0x42,0x14,0x10,0x23,0xe0,0x20,0x20,0x21,0x22,0x00,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x24,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,
+/* 28290 0x6e82 "溂" */
+0x01,0x21,0x17,0x11,0x81,0x47,0x45,0x15,0x17,0x21,0xe3,0x25,0x29,0x21,0x21,0x01,
+0x02,0x02,0xc2,0x12,0x12,0xd2,0x52,0x52,0xd2,0x12,0x92,0x42,0x22,0x02,0x0a,0x04,
+/* 28291 0x6e83 "溃" */
+0x00,0x20,0x13,0x12,0x83,0x40,0x4f,0x10,0x13,0x22,0xe2,0x22,0x22,0x20,0x21,0x06,
+0x40,0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x48,0x48,0x48,0xa0,0x10,0x08,
+/* 28292 0x6e84 "溄" */
+0x00,0x24,0x14,0x17,0x80,0x41,0x42,0x15,0x10,0x23,0xec,0x23,0x20,0x2f,0x20,0x00,
+0x40,0x44,0x44,0xfc,0x80,0xf8,0x08,0x10,0xe0,0x18,0x46,0xf8,0x40,0xfe,0x40,0x40,
+/* 28293 0x6e85 "溅" */
+0x00,0x4f,0x28,0x28,0x0a,0x8a,0x4a,0x5a,0x1a,0x2a,0xea,0x22,0x25,0x24,0x28,0x10,
+0x10,0x94,0x92,0x90,0x9e,0xf0,0x90,0x9e,0xf0,0x94,0x94,0x08,0x0a,0x9a,0x26,0x42,
+/* 28294 0x6e86 "溆" */
+0x42,0x22,0x25,0x84,0x48,0x57,0x02,0x22,0x2f,0x42,0xcb,0x4a,0x52,0x42,0x4a,0x04,
+0x00,0x00,0x7c,0xa4,0x24,0x24,0x24,0x28,0xa8,0x28,0x10,0x90,0xa8,0x28,0x44,0x82,
+/* 28295 0x6e87 "溇" */
+0x00,0x22,0x11,0x10,0x87,0x41,0x42,0x14,0x10,0x2f,0xe1,0x22,0x23,0x20,0x23,0x0c,
+0x40,0x48,0x50,0x40,0xfc,0x50,0x48,0x04,0x80,0xfe,0x10,0x10,0x20,0xc0,0x30,0x08,
+/* 28296 0x6e88 "溈" */
+0x00,0x22,0x11,0x17,0x80,0x40,0x48,0x09,0x11,0x13,0xe2,0x24,0x2a,0x22,0x24,0x00,
+0x40,0x40,0x40,0xf8,0x88,0x90,0xfc,0x04,0x08,0xfe,0x02,0x2a,0xaa,0x82,0x14,0x08,
+/* 28297 0x6e89 "溉" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x14,0x25,0xe4,0x25,0x26,0x24,0x20,0x00,
+0x00,0xbe,0x88,0x88,0xa8,0xa8,0xa8,0xbe,0x10,0x18,0x98,0xa8,0xaa,0x4a,0x46,0x80,
+/* 28298 0x6e8a "溊" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x44,0x14,0x17,0x24,0xe4,0x27,0x24,0x24,0x24,0x04,
+0x00,0xbc,0x84,0x84,0x84,0xbc,0x00,0x00,0xbc,0x24,0x24,0xa8,0x10,0x28,0x44,0x82,
+/* 28299 0x6e8b "溋" */
+0x00,0x23,0x11,0x11,0x81,0x42,0x42,0x12,0x14,0x21,0xe3,0x22,0x22,0x22,0x27,0x00,
+0x00,0xf8,0x08,0x10,0x1c,0xe4,0xa4,0x54,0xa8,0x00,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 28300 0x6e8c "溌" */
+0x00,0x23,0x10,0x14,0x82,0x41,0x42,0x15,0x10,0x20,0xe7,0x20,0x21,0x21,0x22,0x04,
+0x10,0xd4,0x58,0x52,0x8c,0x08,0x04,0xfa,0x90,0x90,0xfe,0x90,0x10,0x12,0x12,0x0e,
+/* 28301 0x6e8d "溍" */
+0x00,0x27,0x10,0x14,0x82,0x40,0x4f,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x00,0xfc,0xa0,0xa4,0xa8,0xa0,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28302 0x6e8e "溎" */
+0x02,0x22,0x12,0x12,0x8f,0x42,0x42,0x17,0x16,0x2a,0xea,0x32,0x22,0x22,0x22,0x02,
+0x10,0x10,0x7c,0x10,0x90,0x10,0xfe,0x00,0x90,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 28303 0x6e8f "溏" */
+0x00,0x20,0x17,0x14,0x85,0x44,0x47,0x14,0x15,0x24,0xe5,0x25,0x25,0x29,0x29,0x11,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 28304 0x6e90 "源" */
+0x00,0x27,0x14,0x14,0x85,0x45,0x45,0x15,0x15,0x25,0xe4,0x24,0x29,0x2a,0x30,0x00,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 28305 0x6e91 "溑" */
+0x00,0x22,0x11,0x10,0x83,0x42,0x4a,0x0b,0x12,0x13,0xe2,0x22,0x23,0x20,0x21,0x02,
+0x40,0x44,0x48,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x08,0x04,
+/* 28306 0x6e92 "溒" */
+0x00,0x20,0x13,0x10,0x87,0x40,0x4b,0x0a,0x12,0x13,0xe0,0x21,0x23,0x2d,0x21,0x01,
+0x40,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x08,0xf8,0xa4,0x28,0x10,0x48,0x86,0x00,
+/* 28307 0x6e93 "溓" */
+0x01,0x20,0x10,0x17,0x80,0x43,0x40,0x17,0x10,0x23,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x10,0xa0,0x00,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 28308 0x6e94 "溔" */
+0x02,0x21,0x11,0x10,0x87,0x40,0x48,0x0b,0x10,0x10,0xe7,0x20,0x25,0x24,0x28,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,0x48,0xa4,0xa4,0x00,
+/* 28309 0x6e95 "溕" */
+0x00,0x47,0x24,0x29,0x00,0x83,0x40,0x51,0x16,0x20,0xe1,0x26,0x20,0x21,0x26,0x00,
+0x00,0xfe,0x02,0xf4,0x00,0xf8,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 28310 0x6e96 "準" */
+0x21,0x11,0x83,0x52,0x17,0x2a,0xe3,0x22,0x23,0x22,0x01,0xff,0x01,0x01,0x01,0x01,
+0x40,0x20,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 28311 0x6e97 "溗" */
+0x00,0x23,0x10,0x17,0x81,0x41,0x47,0x11,0x13,0x25,0xe0,0x21,0x22,0x24,0x28,0x00,
+0x38,0xc0,0x40,0xfc,0x50,0x54,0x58,0x54,0x54,0x4c,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 28312 0x6e98 "溘" */
+0x00,0x20,0x13,0x10,0x80,0x4f,0x40,0x11,0x13,0x20,0xe7,0x24,0x24,0x24,0x2f,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x80,0x10,0xf8,0x08,0xfc,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 28313 0x6e99 "溙" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x11,0x12,0x24,0xe2,0x21,0x22,0x24,0x21,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x48,0x46,0x48,0x50,0x48,0x44,0x40,0x80,
+/* 28314 0x6e9a "溚" */
+0x01,0x21,0x17,0x11,0x80,0x40,0x49,0x0a,0x15,0x10,0xe0,0x23,0x22,0x22,0x23,0x02,
+0x10,0x10,0xfc,0x10,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 28315 0x6e9b "溛" */
+0x00,0x20,0x17,0x14,0x81,0x42,0x48,0x0b,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x80,0x40,0xfc,0x04,0x10,0x08,0x3c,0xd0,0x90,0x90,0x90,0x88,0x88,0xa4,0xd4,0x92,
+/* 28316 0x6e9c "溜" */
+0x00,0x27,0x14,0x15,0x84,0x45,0x46,0x10,0x17,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x80,0x7c,0x24,0x24,0xa4,0x54,0x48,0x80,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 28317 0x6e9d "溝" */
+0x01,0x21,0x17,0x11,0x83,0x41,0x4f,0x10,0x13,0x22,0xe3,0x22,0x2f,0x22,0x22,0x02,
+0x10,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfe,0x04,0x14,0x08,
+/* 28318 0x6e9e "溞" */
+0x00,0x23,0x11,0x11,0x80,0x40,0x41,0x16,0x10,0x23,0xe2,0x22,0x23,0x20,0x27,0x00,
+0x00,0xf8,0x48,0x10,0xa0,0x40,0xb0,0x4e,0x40,0xf8,0x48,0x48,0xf8,0x44,0xfc,0x04,
+/* 28319 0x6e9f "溟" */
+0x00,0x27,0x14,0x10,0x83,0x42,0x4b,0x0a,0x13,0x10,0xe0,0x27,0x20,0x21,0x22,0x04,
+0x00,0xfc,0x04,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x40,0xfc,0x00,0x10,0x08,0x04,
+/* 28320 0x6ea0 "溠" */
+0x01,0x20,0x10,0x13,0x80,0x41,0x48,0x0b,0x10,0x11,0xe1,0x22,0x24,0x28,0x23,0x00,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 28321 0x6ea1 "溡" */
+0x00,0x20,0x17,0x15,0x85,0x45,0x45,0x17,0x15,0x25,0xe5,0x25,0x27,0x20,0x20,0x00,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 28322 0x6ea2 "溢" */
+0x02,0x21,0x11,0x10,0x87,0x40,0x41,0x12,0x14,0x23,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 28323 0x6ea3 "溣" */
+0x02,0x42,0x22,0x24,0x05,0x8e,0x54,0x55,0x15,0x25,0xe5,0x25,0x25,0x25,0x25,0x05,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 28324 0x6ea4 "溤" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x4a,0x0a,0x13,0x10,0xe5,0x25,0x25,0x24,0x20,0x00,
+0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x04,0x54,0x54,0x54,0x04,0x28,0x10,
+/* 28325 0x6ea5 "溥" */
+0x00,0x40,0x2f,0x20,0x07,0x84,0x47,0x54,0x17,0x24,0xe0,0x2f,0x22,0x21,0x21,0x00,
+0x50,0x48,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x08,0xfe,0x08,0x08,0x28,0x10,
+/* 28326 0x6ea6 "溦" */
+0x01,0x25,0x15,0x15,0x87,0x40,0x40,0x1f,0x10,0x27,0xe4,0x24,0x24,0x24,0x28,0x10,
+0x08,0x48,0x48,0x50,0xde,0x24,0x14,0xd4,0x14,0x94,0x94,0xa8,0xc8,0x94,0x14,0x22,
+/* 28327 0x6ea7 "溧" */
+0x00,0x27,0x10,0x10,0x87,0x44,0x44,0x17,0x10,0x20,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 28328 0x6ea8 "溨" */
+0x01,0x21,0x17,0x11,0x81,0x4f,0x40,0x11,0x17,0x21,0xe3,0x25,0x29,0x21,0x21,0x01,
+0x10,0x14,0xd2,0x10,0x10,0xfe,0x10,0x14,0xd4,0x14,0x94,0x48,0x0a,0x1a,0x26,0x42,
+/* 28329 0x6ea9 "溩" */
+0x00,0x21,0x13,0x12,0x82,0x43,0x4a,0x0b,0x12,0x13,0xe0,0x25,0x25,0x28,0x20,0x00,
+0x80,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 28330 0x6eaa "溪" */
+0x00,0x27,0x12,0x11,0x80,0x41,0x43,0x10,0x11,0x23,0xe0,0x20,0x27,0x20,0x21,0x06,
+0x3c,0xc0,0x44,0x28,0x80,0x10,0xe0,0x40,0x88,0xfc,0x44,0x40,0xfc,0xa0,0x10,0x0e,
+/* 28331 0x6eab "溫" */
+0x40,0x23,0x22,0x0a,0x8a,0x53,0x53,0x22,0x20,0xc7,0x44,0x44,0x44,0x44,0x4f,0x00,
+0x00,0xf8,0x48,0x48,0xa8,0x08,0xf8,0x08,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 28332 0x6eac "溬" */
+0x02,0x21,0x17,0x10,0x80,0x43,0x48,0x08,0x17,0x10,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x08,0x10,0xfc,0x40,0x40,0xf8,0x40,0x80,0xfc,0xa0,0x28,0x34,0x3c,0x22,0x22,0x1e,
+/* 28333 0x6ead "溭" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x41,0x12,0x14,0x21,0xe2,0x25,0x20,0x20,0x21,0x0e,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x10,0x08,0x84,0xf8,0x08,0x08,0x90,0x60,0x98,0x06,
+/* 28334 0x6eae "溮" */
+0x02,0x24,0x17,0x15,0x85,0x45,0x47,0x14,0x14,0x27,0xe5,0x25,0x25,0x27,0x25,0x00,
+0x00,0xfe,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,0x10,
+/* 28335 0x6eaf "溯" */
+0x04,0x42,0x22,0x20,0x07,0x81,0x45,0x55,0x15,0x27,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x40,0x5e,0x92,0x12,0xd2,0x1e,0x52,0x52,0x52,0xde,0x52,0x12,0x12,0x22,0x2a,0x44,
+/* 28336 0x6eb0 "溰" */
+0x00,0x22,0x12,0x12,0x83,0x40,0x47,0x10,0x13,0x22,0xe2,0x23,0x21,0x20,0x27,0x00,
+0x40,0x48,0x48,0x48,0xf8,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x10,0xa0,0xfe,0x00,
+/* 28337 0x6eb1 "溱" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x11,0x12,0x25,0xe0,0x23,0x20,0x21,0x26,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x68,0xc6,0x40,0xf8,0xe0,0x58,0x44,0x40,
+/* 28338 0x6eb2 "溲" */
+0x00,0x21,0x16,0x14,0x84,0x47,0x44,0x14,0x17,0x20,0xe7,0x21,0x20,0x20,0x23,0x1c,
+0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x40,0xf8,0x10,0xa0,0x60,0x98,0x06,
+/* 28339 0x6eb3 "溳" */
+0x00,0x21,0x11,0x11,0x81,0x40,0x4b,0x0a,0x13,0x12,0xe3,0x22,0x23,0x20,0x21,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x08,0x04,
+/* 28340 0x6eb4 "溴" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x43,0x12,0x13,0x20,0xe0,0x27,0x20,0x21,0x22,0x0c,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x50,0x48,0xfe,0xa0,0x10,0x08,0x06,
+/* 28341 0x6eb5 "溵" */
+0x00,0x21,0x16,0x14,0x87,0x44,0x47,0x14,0x17,0x24,0xe7,0x24,0x24,0x28,0x2a,0x11,
+0x00,0xb8,0x28,0x28,0xa8,0xa8,0xce,0x80,0xb8,0x28,0xa8,0xa8,0x90,0x90,0xa8,0x46,
+/* 28342 0x6eb6 "溶" */
+0x00,0x20,0x13,0x12,0x84,0x41,0x4a,0x08,0x11,0x12,0xe5,0x21,0x21,0x21,0x21,0x01,
+0x40,0x20,0xfe,0x02,0x94,0x08,0x64,0x90,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x08,
+/* 28343 0x6eb7 "溷" */
+0x00,0x27,0x14,0x15,0x84,0x44,0x45,0x14,0x14,0x25,0xe4,0x24,0x25,0x24,0x27,0x04,
+0x00,0xfe,0x02,0xfa,0x42,0xc2,0x2a,0x6a,0xb2,0x2a,0x6a,0xaa,0x22,0x42,0xfe,0x02,
+/* 28344 0x6eb8 "溸" */
+0x00,0x20,0x17,0x10,0x83,0x40,0x47,0x10,0x11,0x23,0xe0,0x27,0x20,0x22,0x25,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x10,0xe0,0x48,0xfc,0x44,0x48,0x44,0x80,
+/* 28345 0x6eb9 "溹" */
+0x00,0x20,0x17,0x10,0x8f,0x48,0x41,0x13,0x10,0x20,0xe7,0x20,0x22,0x24,0x29,0x00,
+0x40,0x40,0xfc,0x40,0xfe,0x82,0x10,0xe0,0x40,0x88,0xfc,0x44,0x48,0x44,0x42,0x80,
+/* 28346 0x6eba "溺" */
+0x00,0x27,0x10,0x10,0x87,0x44,0x44,0x17,0x10,0x24,0xe2,0x22,0x24,0x20,0x25,0x02,
+0x00,0xbc,0x84,0x84,0xbc,0x20,0x20,0xbc,0x84,0xa4,0x94,0x94,0xa4,0x84,0x28,0x10,
+/* 28347 0x6ebb "溻" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x40,0x17,0x10,0x24,0xe2,0x21,0x26,0x20,0x22,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0x8c,0xb4,0x84,0x94,0x08,
+/* 28348 0x6ebc "溼" */
+0x00,0x2f,0x12,0x12,0x84,0x47,0x42,0x14,0x17,0x20,0xe0,0x27,0x20,0x20,0x2f,0x00,
+0x00,0xfe,0x10,0x10,0xa4,0x38,0x10,0xa4,0xbc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 28349 0x6ebd "溽" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x23,0x22,0x24,0x24,0x08,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 28350 0x6ebe "溾" */
+0x00,0x21,0x17,0x14,0x84,0x47,0x44,0x14,0x17,0x20,0xe1,0x21,0x22,0x22,0x24,0x08,
+0x80,0x00,0xfc,0x44,0x44,0xfc,0x44,0x84,0xfc,0xc8,0x50,0x68,0x7c,0x42,0x42,0x3e,
+/* 28351 0x6ebf "溿" */
+0x00,0x80,0x5f,0x15,0x95,0x55,0x55,0x1f,0x35,0x55,0xd5,0x55,0x5f,0x51,0x40,0x00,
+0x10,0x94,0x54,0x54,0x58,0x10,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 28352 0x6ec0 "滀" */
+0x00,0x20,0x17,0x10,0x81,0x43,0x48,0x09,0x17,0x10,0xe7,0x24,0x27,0x24,0x27,0x04,
+0x80,0x40,0xfc,0x80,0x08,0xf0,0x60,0x84,0xfe,0x02,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 28353 0x6ec1 "滁" */
+0x40,0x2f,0x29,0x8a,0x4a,0x4c,0x0a,0x29,0x29,0x49,0xcd,0x4a,0x48,0x49,0x48,0x08,
+0x10,0x10,0x28,0x28,0x44,0xba,0x10,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x20,
+/* 28354 0x6ec2 "滂" */
+0x00,0x40,0x27,0x22,0x01,0x8f,0x48,0x50,0x17,0x21,0xe1,0x21,0x21,0x22,0x22,0x04,
+0x80,0x40,0xfc,0x10,0x20,0xfe,0x82,0x44,0xfc,0x00,0x00,0xf8,0x08,0x08,0x28,0x10,
+/* 28355 0x6ec3 "滃" */
+0x01,0x21,0x12,0x14,0x89,0x43,0x40,0x10,0x17,0x20,0xe4,0x22,0x24,0x20,0x22,0x01,
+0x20,0x10,0x08,0x86,0x10,0xf8,0x08,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x94,0x08,
+/* 28356 0x6ec4 "滄" */
+0x00,0x20,0x10,0x11,0x82,0x47,0x4a,0x13,0x12,0x23,0xe2,0x23,0x25,0x25,0x29,0x01,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 28357 0x6ec5 "滅" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x47,0x14,0x14,0x25,0xe6,0x24,0x25,0x29,0x2a,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xf2,0x92,0x92,0xb4,0xd4,0x88,0x4a,0x3a,0x26,0x42,
+/* 28358 0x6ec6 "滆" */
+0x00,0x2f,0x10,0x13,0x82,0x42,0x43,0x10,0x17,0x25,0xe4,0x27,0x24,0x24,0x24,0x04,
+0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x14,0xa4,0xfc,0x44,0x44,0x54,0x08,
+/* 28359 0x6ec7 "滇" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x43,0x12,0x13,0x22,0xe3,0x22,0x2f,0x21,0x22,0x04,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 28360 0x6ec8 "滈" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x43,0x10,0x17,0x24,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0x14,0x08,
+/* 28361 0x6ec9 "滉" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x48,0x0a,0x11,0x10,0xe7,0x21,0x21,0x22,0x24,0x08,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x48,0x50,0x40,0xfc,0x20,0x20,0x24,0x24,0x1c,
+/* 28362 0x6eca "滊" */
+0x01,0x21,0x11,0x12,0x85,0x40,0x4b,0x08,0x12,0x11,0xe7,0x20,0x21,0x26,0x20,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 28363 0x6ecb "滋" */
+0x01,0x20,0x10,0x17,0x81,0x41,0x42,0x12,0x14,0x27,0xe1,0x22,0x22,0x24,0x27,0x00,
+0x08,0x88,0x90,0xfe,0x08,0x08,0x10,0x94,0xa4,0x38,0x08,0x10,0x10,0xa4,0xbc,0x84,
+/* 28364 0x6ecc "滌" */
+0x44,0x24,0x24,0x88,0x4a,0x4a,0x1a,0x2a,0x2a,0x4a,0xca,0x4a,0x48,0x49,0x48,0x08,
+0x20,0x20,0x7c,0x44,0xa8,0x10,0x28,0xd6,0x10,0xfe,0x10,0x54,0x92,0x12,0x50,0x20,
+/* 28365 0x6ecd "滍" */
+0x00,0x22,0x12,0x13,0x80,0x4f,0x40,0x10,0x13,0x22,0xe2,0x23,0x20,0x20,0x27,0x02,
+0x40,0x44,0x44,0xfc,0x40,0xfe,0x00,0x40,0xfc,0x44,0x44,0xfc,0x40,0x44,0xfe,0x02,
+/* 28366 0x6ece "滎" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x81,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 28367 0x6ecf "滏" */
+0x01,0x42,0x25,0x20,0x00,0x83,0x4c,0x53,0x10,0x20,0xe7,0x20,0x22,0x21,0x2f,0x00,
+0x10,0x08,0x14,0xa0,0xe0,0x18,0x06,0xf8,0x40,0x40,0xfc,0x40,0x48,0x50,0xfe,0x00,
+/* 28368 0x6ed0 "滐" */
+0x02,0x22,0x13,0x14,0x8a,0x41,0x42,0x14,0x18,0x27,0xe0,0x21,0x22,0x2c,0x20,0x00,
+0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x48,0x48,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 28369 0x6ed1 "滑" */
+0x00,0x23,0x12,0x13,0x82,0x4f,0x48,0x13,0x12,0x23,0xe2,0x23,0x22,0x22,0x22,0x02,
+0x00,0xf8,0x08,0xc8,0x48,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 28370 0x6ed2 "滒" */
+0x00,0x27,0x10,0x13,0x82,0x42,0x43,0x10,0x1f,0x20,0xe3,0x22,0x22,0x23,0x20,0x00,
+0x00,0xfc,0x08,0xc8,0x48,0x48,0xc8,0x00,0xfe,0x08,0xc8,0x48,0x48,0xc8,0x28,0x10,
+/* 28371 0x6ed3 "滓" */
+0x00,0x20,0x17,0x14,0x80,0x43,0x41,0x10,0x17,0x20,0xe0,0x23,0x20,0x20,0x20,0x00,
+0x80,0x40,0xfc,0x84,0x40,0xf8,0x10,0xa0,0xfc,0x40,0x40,0xf8,0x40,0x40,0x40,0x40,
+/* 28372 0x6ed4 "滔" */
+0x00,0x4f,0x20,0x24,0x02,0x82,0x41,0x56,0x14,0x24,0xe7,0x24,0x24,0x24,0x27,0x04,
+0x3e,0xc0,0x84,0x44,0x48,0x10,0x00,0x1c,0x04,0x04,0x1c,0x04,0x04,0x04,0xfc,0x04,
+/* 28373 0x6ed5 "滕" */
+0x00,0x79,0x48,0x49,0x48,0x78,0x4b,0x48,0x49,0x7a,0x4d,0x48,0x49,0x4a,0x48,0x98,
+0x20,0x24,0xa8,0xfc,0x20,0x40,0xfe,0x88,0x24,0x22,0x24,0xa8,0x24,0x22,0xa0,0x40,
+/* 28374 0x6ed6 "滖" */
+0x00,0x20,0x17,0x10,0x83,0x42,0x4f,0x12,0x13,0x20,0xe1,0x23,0x25,0x29,0x21,0x01,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xfe,0x08,0xf8,0xa4,0x28,0x10,0x10,0x48,0x86,0x00,
+/* 28375 0x6ed7 "滗" */
+0x02,0x22,0x13,0x15,0x88,0x40,0x47,0x10,0x10,0x27,0xe0,0x20,0x2f,0x20,0x20,0x00,
+0x10,0x10,0xde,0x28,0x84,0x78,0x80,0x80,0xf8,0x80,0x80,0xf8,0x84,0x84,0x84,0x7c,
+/* 28376 0x6ed8 "滘" */
+0x00,0x47,0x24,0x29,0x02,0x85,0x40,0x50,0x17,0x20,0xe0,0x23,0x22,0x22,0x23,0x02,
+0x00,0xfe,0x02,0x14,0x08,0xf4,0x40,0x40,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 28377 0x6ed9 "滙" */
+0x00,0x27,0x14,0x14,0x85,0x46,0x44,0x14,0x14,0x24,0xe4,0x24,0x24,0x24,0x27,0x00,
+0x00,0xfe,0x50,0x88,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,0x00,0xfe,0x00,
+/* 28378 0x6eda "滚" */
+0x00,0x20,0x17,0x11,0x82,0x44,0x41,0x13,0x10,0x20,0xe1,0x23,0x25,0x29,0x21,0x01,
+0x80,0x40,0xfc,0x10,0x48,0x84,0x20,0xf0,0x10,0x88,0x50,0x20,0x10,0x48,0x86,0x00,
+/* 28379 0x6edb "滛" */
+0x00,0x20,0x17,0x12,0x81,0x41,0x42,0x13,0x14,0x20,0xef,0x20,0x24,0x24,0x27,0x00,
+0x04,0x3e,0xc0,0x44,0x24,0x28,0x00,0xfc,0x40,0x40,0xfe,0x40,0x44,0x44,0xfc,0x04,
+/* 28380 0x6edc "滜" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x4b,0x08,0x17,0x11,0xe2,0x24,0x2b,0x20,0x20,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xfc,0x10,0x48,0x44,0xfa,0x40,0x40,0x40,
+/* 28381 0x6edd "滝" */
+0x00,0x20,0x17,0x11,0x80,0x47,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x20,0x20,0x00,
+0x80,0x40,0xfc,0x10,0xa0,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x4a,0x42,0x3e,0x00,
+/* 28382 0x6ede "滞" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x47,0x14,0x18,0x23,0xe2,0x22,0x22,0x22,0x20,0x00,
+0x50,0x50,0xfc,0x50,0x50,0x00,0xfe,0x42,0x44,0xf8,0x48,0x48,0x48,0x58,0x40,0x40,
+/* 28383 0x6edf "滟" */
+0x04,0x84,0x44,0x1f,0x84,0x44,0x44,0x1e,0x24,0x44,0xc4,0x5f,0x44,0x44,0x44,0x04,
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x54,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 28384 0x6ee0 "滠" */
+0x00,0x23,0x11,0x11,0x81,0x41,0x41,0x17,0x10,0x27,0xe0,0x22,0x21,0x22,0x24,0x08,
+0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 28385 0x6ee1 "满" */
+0x01,0x21,0x17,0x11,0x80,0x47,0x40,0x10,0x17,0x24,0xe4,0x25,0x26,0x24,0x24,0x04,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x90,0x90,0xfe,0x92,0x92,0x6a,0x46,0x02,0x0a,0x04,
+/* 28386 0x6ee2 "滢" */
+0x01,0x21,0x17,0x11,0x80,0x4f,0x48,0x10,0x17,0x20,0xe0,0x23,0x20,0x20,0x2f,0x00,
+0x10,0x10,0xfe,0x10,0x00,0xfe,0x02,0x00,0xfc,0x40,0x40,0xf8,0x50,0x48,0xfe,0x00,
+/* 28387 0x6ee3 "滣" */
+0x00,0x23,0x12,0x12,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 28388 0x6ee4 "滤" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x47,0x14,0x14,0x24,0xe4,0x24,0x25,0x29,0x29,0x12,
+0x40,0x7c,0x40,0xfe,0x42,0x70,0xc4,0x44,0x3c,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,
+/* 28389 0x6ee5 "滥" */
+0x00,0x24,0x14,0x14,0x84,0x44,0x44,0x10,0x10,0x27,0xe4,0x24,0x24,0x24,0x2f,0x00,
+0x90,0x90,0x9e,0x90,0xa8,0xa4,0xc4,0x80,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 28390 0x6ee6 "滦" */
+0x00,0x40,0x2f,0x20,0x02,0x82,0x44,0x50,0x10,0x27,0xe0,0x21,0x22,0x24,0x28,0x00,
+0x80,0x40,0xfe,0xa0,0xa8,0xa4,0xa4,0x40,0x40,0xfe,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 28391 0x6ee7 "滧" */
+0x44,0x22,0x22,0x8f,0x40,0x45,0x04,0x28,0x31,0x45,0xc2,0x42,0x45,0x49,0x50,0x00,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0xa4,0xa4,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 28392 0x6ee8 "滨" */
+0x00,0x20,0x17,0x14,0x88,0x43,0x4a,0x0a,0x13,0x12,0xe2,0x2f,0x20,0x21,0x22,0x04,
+0x80,0x40,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x10,0x08,0x04,
+/* 28393 0x6ee9 "滩" */
+0x00,0x40,0x2e,0x22,0x03,0x92,0x4a,0x5a,0x14,0x24,0xea,0x2a,0x32,0x20,0x20,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 28394 0x6eea "滪" */
+0x00,0x4f,0x20,0x25,0x02,0x81,0x4f,0x52,0x12,0x22,0xe2,0x22,0x22,0x22,0x2a,0x04,
+0x00,0xbe,0x88,0x10,0x3e,0x22,0xaa,0xaa,0x2a,0x2a,0x2a,0x2a,0x10,0x14,0x22,0x42,
+/* 28395 0x6eeb "滫" */
+0x44,0x24,0x24,0x88,0x4b,0x5a,0x1a,0x2b,0x2a,0x4a,0xca,0x4a,0x4a,0x48,0x48,0x08,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x88,0x98,
+/* 28396 0x6eec "滬" */
+0x00,0x20,0x13,0x12,0x83,0x42,0x4a,0x0a,0x12,0x12,0xe3,0x23,0x25,0x25,0x29,0x00,
+0x40,0x20,0xfc,0x04,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x02,0x02,0xfe,
+/* 28397 0x6eed "滭" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x52,0x12,0x17,0x22,0xe2,0x27,0x20,0x2f,0x20,0x00,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0xfe,0x40,0x40,
+/* 28398 0x6eee "滮" */
+0x42,0x23,0x22,0x8f,0x4a,0x4b,0x0e,0x29,0x28,0x4b,0xca,0x4a,0x4a,0x4c,0x54,0x08,
+0x00,0xc2,0x02,0xe4,0x28,0x92,0x42,0xc4,0x08,0x92,0x82,0x84,0x8a,0x92,0x7e,0x00,
+/* 28399 0x6eef "滯" */
+0x02,0x22,0x17,0x12,0x82,0x44,0x48,0x17,0x14,0x20,0xe3,0x22,0x22,0x22,0x22,0x00,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 28400 0x6ef0 "滰" */
+0x00,0x20,0x13,0x11,0x80,0x47,0x40,0x13,0x12,0x23,0xe2,0x23,0x21,0x21,0x22,0x0c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 28401 0x6ef1 "滱" */
+0x40,0x20,0x2f,0x88,0x50,0x4f,0x00,0x20,0x2f,0x45,0xc5,0x45,0x49,0x49,0x51,0x20,
+0x80,0x40,0xfe,0x02,0x04,0x90,0x1c,0x10,0x90,0x7c,0x04,0x28,0x10,0x2a,0x42,0xfe,
+/* 28402 0x6ef2 "滲" */
+0x00,0x21,0x13,0x12,0x84,0x4f,0x40,0x10,0x13,0x2c,0xe1,0x26,0x21,0x26,0x21,0x0e,
+0x80,0x10,0xf8,0x10,0xa4,0xbe,0x42,0xa0,0x18,0x46,0x90,0x64,0x88,0x30,0xc0,0x00,
+/* 28403 0x6ef3 "滳" */
+0x00,0x20,0x17,0x11,0x80,0x47,0x44,0x15,0x16,0x25,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0xa4,0x14,0x0c,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 28404 0x6ef4 "滴" */
+0x00,0x20,0x17,0x11,0x80,0x47,0x44,0x15,0x14,0x25,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xf4,0x44,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 28405 0x6ef5 "滵" */
+0x00,0x40,0x27,0x24,0x08,0x80,0x45,0x55,0x18,0x23,0xe0,0x24,0x24,0x24,0x27,0x00,
+0x80,0x40,0xfe,0x02,0x94,0x50,0x24,0x4a,0xfa,0x00,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 28406 0x6ef6 "滶" */
+0x01,0x21,0x11,0x17,0x81,0x47,0x51,0x1f,0x12,0x23,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 28407 0x6ef7 "滷" */
+0x00,0x20,0x10,0x10,0x80,0x47,0x44,0x16,0x15,0x24,0xe6,0x24,0x25,0x26,0x27,0x04,
+0x40,0x40,0x7e,0x40,0x40,0xfc,0x04,0x4c,0x14,0xa4,0x4c,0xa4,0x14,0x4c,0xfc,0x04,
+/* 28408 0x6ef8 "滸" */
+0x02,0x41,0x21,0x2f,0x00,0x87,0x40,0x57,0x10,0x27,0xe4,0x24,0x24,0x27,0x24,0x00,
+0x10,0x10,0x10,0xde,0x28,0x88,0x08,0x88,0x3e,0x88,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 28409 0x6ef9 "滹" */
+0x00,0x20,0x10,0x17,0x84,0x44,0x45,0x14,0x14,0x24,0xe5,0x24,0x27,0x28,0x28,0x10,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 28410 0x6efa "滺" */
+0x02,0x42,0x24,0x25,0x0d,0x95,0x45,0x54,0x14,0x20,0xe1,0x25,0x25,0x25,0x28,0x00,
+0x20,0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0x80,0x40,0x24,0x22,0x0a,0x0a,0xf8,0x00,
+/* 28411 0x6efb "滻" */
+0x00,0x20,0x13,0x10,0x81,0x40,0x4b,0x0a,0x12,0x12,0xe3,0x22,0x22,0x24,0x24,0x09,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 28412 0x6efc "滼" */
+0x01,0x21,0x17,0x11,0x83,0x45,0x49,0x10,0x13,0x22,0xe2,0x22,0x22,0x22,0x24,0x08,
+0x10,0x10,0xbe,0x10,0xb8,0x54,0x12,0x00,0xf0,0x10,0x90,0x50,0x52,0x12,0x0e,0x00,
+/* 28413 0x6efd "滽" */
+0x00,0x27,0x14,0x15,0x84,0x47,0x44,0x15,0x14,0x25,0xe5,0x25,0x25,0x29,0x29,0x11,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 28414 0x6efe "滾" */
+0x00,0x20,0x17,0x11,0x82,0x45,0x41,0x11,0x11,0x20,0xe1,0x23,0x25,0x29,0x21,0x01,
+0x80,0x40,0xfc,0x10,0x08,0xf4,0x10,0x10,0xf0,0x88,0x50,0x20,0x10,0x48,0x86,0x00,
+/* 28415 0x6eff "滿" */
+0x01,0x21,0x17,0x11,0x81,0x41,0x40,0x17,0x14,0x26,0xe5,0x26,0x24,0x24,0x24,0x04,
+0x10,0x10,0xfc,0x10,0x10,0xf0,0x40,0xfc,0x44,0x64,0x54,0xec,0x44,0x44,0x54,0x48,
+/* 28416 0x6f00 "漀" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x80,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0x08,0x90,0x60,0x20,0x18,0x06,
+/* 28417 0x6f01 "漁" */
+0x01,0x21,0x13,0x12,0x84,0x4f,0x54,0x14,0x17,0x24,0xe4,0x27,0x20,0x25,0x24,0x08,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x00,0x24,0x92,0x92,
+/* 28418 0x6f02 "漂" */
+0x00,0x4f,0x20,0x27,0x04,0x84,0x47,0x50,0x17,0x20,0xef,0x20,0x22,0x24,0x29,0x00,
+0x00,0xfe,0xa0,0xfc,0xa4,0xa4,0xfc,0x00,0xfc,0x00,0xfe,0x40,0x48,0x44,0x42,0x80,
+/* 28419 0x6f03 "漃" */
+0x00,0x40,0x2f,0x28,0x12,0x83,0x42,0x52,0x1f,0x20,0xe2,0x2b,0x32,0x22,0x2a,0x04,
+0x80,0x40,0xfe,0x02,0x04,0xbc,0x24,0x24,0xa4,0x28,0x28,0x10,0x90,0x28,0x44,0x82,
+/* 28420 0x6f04 "漄" */
+0x00,0x22,0x12,0x13,0x80,0x43,0x4a,0x0b,0x12,0x13,0xe2,0x22,0x25,0x24,0x2b,0x00,
+0x20,0x22,0x22,0xfe,0x00,0xfe,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfc,0x20,0xfe,0x00,
+/* 28421 0x6f05 "漅" */
+0x02,0x24,0x12,0x10,0x83,0x42,0x4b,0x0a,0x13,0x10,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x48,0x90,0x48,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 28422 0x6f06 "漆" */
+0x00,0x20,0x17,0x10,0x81,0x46,0x40,0x11,0x12,0x2c,0xe2,0x21,0x22,0x24,0x21,0x00,
+0x40,0x40,0xfc,0xe0,0x58,0x44,0xa0,0x10,0x48,0x46,0x48,0x50,0x48,0x44,0x40,0x80,
+/* 28423 0x6f07 "漇" */
+0x02,0x42,0x24,0x29,0x01,0x82,0x46,0x5a,0x12,0x22,0xe2,0x22,0x22,0x22,0x23,0x02,
+0x10,0x10,0x50,0x5c,0x50,0x50,0xfe,0x00,0x10,0x50,0x5c,0x50,0xb0,0x90,0x0e,0x00,
+/* 28424 0x6f08 "漈" */
+0x01,0x21,0x13,0x12,0x85,0x42,0x41,0x12,0x14,0x20,0xe3,0x20,0x21,0x22,0x25,0x00,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 28425 0x6f09 "漉" */
+0x00,0x20,0x17,0x14,0x84,0x47,0x44,0x14,0x17,0x24,0xe5,0x25,0x25,0x29,0x29,0x11,
+0x80,0x40,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x00,0x24,0xa8,0x30,0x24,0xa4,0x1c,
+/* 28426 0x6f0a "漊" */
+0x00,0x43,0x22,0x2f,0x02,0x83,0x40,0x53,0x12,0x23,0xe0,0x2f,0x21,0x20,0x23,0x0c,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x48,0xf8,0x80,0xfe,0x10,0xe0,0x18,0x04,
+/* 28427 0x6f0b "漋" */
+0x00,0x4f,0x29,0x2a,0x0a,0x8c,0x4a,0x49,0x19,0x29,0xed,0x2a,0x28,0x28,0x28,0x08,
+0x20,0x3c,0x44,0xa8,0x10,0x28,0xc6,0x38,0x10,0x50,0x7e,0x90,0x7c,0x10,0xfe,0x00,
+/* 28428 0x6f0c "漌" */
+0x01,0x41,0x2f,0x21,0x01,0x80,0x47,0x54,0x17,0x20,0xef,0x20,0x27,0x20,0x2f,0x00,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x40,0xfc,0x40,0xfe,0x00,
+/* 28429 0x6f0d "漍" */
+0x00,0x4f,0x28,0x28,0x0f,0x88,0x4b,0x4a,0x1b,0x28,0xe9,0x2e,0x28,0x28,0x2f,0x08,
+0x00,0xfe,0x2a,0x26,0xfe,0x22,0xaa,0xaa,0xaa,0x32,0x96,0x2e,0x46,0x82,0xfe,0x02,
+/* 28430 0x6f0e "漎" */
+0x01,0x41,0x22,0x24,0x09,0x81,0x42,0x56,0x1a,0x22,0xe2,0x22,0x22,0x22,0x22,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 28431 0x6f0f "漏" */
+0x00,0x47,0x24,0x24,0x07,0x84,0x47,0x54,0x17,0x26,0xe6,0x2a,0x2a,0x32,0x22,0x02,
+0x00,0xfe,0x02,0x02,0xfe,0x00,0xfe,0x20,0xfe,0x22,0xaa,0x22,0xaa,0x22,0x2a,0x04,
+/* 28432 0x6f10 "漐" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x09,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 28433 0x6f11 "漑" */
+0x01,0x42,0x27,0x24,0x04,0x87,0x44,0x54,0x17,0x20,0xe4,0x27,0x24,0x24,0x23,0x00,
+0x00,0x3e,0x88,0x88,0xa8,0xa8,0xbe,0x88,0x88,0x10,0x98,0x18,0x28,0xaa,0xca,0x86,
+/* 28434 0x6f12 "漒" */
+0x00,0x27,0x11,0x11,0x81,0x47,0x44,0x14,0x14,0x27,0xe1,0x21,0x21,0x21,0x2a,0x04,
+0x00,0x7c,0x44,0x44,0x7c,0x10,0x10,0x7c,0x54,0x54,0x54,0x7c,0x10,0x14,0xfe,0x02,
+/* 28435 0x6f13 "漓" */
+0x00,0x20,0x17,0x10,0x82,0x42,0x42,0x13,0x10,0x27,0xe4,0x25,0x25,0x24,0x24,0x04,
+0x80,0x40,0xfe,0x00,0xa8,0x48,0xa8,0xf8,0x40,0xfc,0x84,0x24,0xf4,0x14,0x04,0x0c,
+/* 28436 0x6f14 "演" */
+0x00,0x20,0x17,0x14,0x80,0x43,0x40,0x13,0x12,0x23,0xe2,0x23,0x20,0x21,0x22,0x04,
+0x80,0x40,0xfc,0x04,0x00,0xf8,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0x10,0x08,0x04,
+/* 28437 0x6f15 "漕" */
+0x00,0x20,0x17,0x10,0x87,0x44,0x47,0x14,0x17,0x20,0xe3,0x22,0x23,0x22,0x23,0x02,
+0xa0,0xa0,0xfe,0xa0,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 28438 0x6f16 "漖" */
+0x02,0x22,0x17,0x12,0x82,0x4f,0x41,0x12,0x1f,0x24,0xe9,0x21,0x2f,0x21,0x25,0x02,
+0x08,0x48,0x48,0x90,0x9e,0xe4,0x14,0x14,0xd4,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 28439 0x6f17 "漗" */
+0x00,0x20,0x13,0x12,0x82,0x43,0x4a,0x0a,0x12,0x13,0xe0,0x20,0x25,0x25,0x29,0x00,
+0x40,0x80,0xfc,0x44,0xf4,0x14,0xa4,0x44,0xa4,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 28440 0x6f18 "漘" */
+0x07,0x24,0x15,0x14,0x87,0x45,0x45,0x15,0x14,0x25,0xe5,0x25,0x25,0x29,0x29,0x11,
+0xfe,0x00,0xfc,0x00,0xfe,0x14,0x48,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 28441 0x6f19 "漙" */
+0x00,0x4f,0x20,0x27,0x04,0x87,0x44,0x57,0x10,0x2f,0xe0,0x2f,0x22,0x21,0x21,0x00,
+0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x42,0xfe,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 28442 0x6f1a "漚" */
+0x00,0x27,0x14,0x14,0x84,0x44,0x44,0x14,0x15,0x25,0xe5,0x25,0x25,0x24,0x27,0x00,
+0x00,0xfc,0x00,0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0x54,0xdc,0x00,0xfe,0x00,
+/* 28443 0x6f1b "漛" */
+0x00,0x22,0x11,0x17,0x80,0x40,0x4f,0x11,0x12,0x24,0xea,0x21,0x22,0x24,0x21,0x00,
+0x40,0x48,0x50,0xfc,0x40,0x80,0xfe,0x10,0x48,0x46,0x48,0x50,0x48,0x44,0x40,0x80,
+/* 28444 0x6f1c "漜" */
+0x01,0x21,0x17,0x11,0x83,0x45,0x49,0x11,0x10,0x20,0xe7,0x20,0x20,0x20,0x2f,0x00,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x10,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 28445 0x6f1d "漝" */
+0x00,0x27,0x10,0x14,0x82,0x44,0x40,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x84,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28446 0x6f1e "漞" */
+0x00,0x27,0x10,0x12,0x81,0x43,0x4a,0x0b,0x12,0x13,0xe2,0x23,0x20,0x21,0x22,0x0c,
+0x0e,0xf0,0x44,0x24,0x08,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x10,0x12,0x0e,
+/* 28447 0x6f1f "漟" */
+0x00,0x44,0x22,0x2f,0x08,0x83,0x42,0x52,0x13,0x20,0xe0,0x27,0x20,0x20,0x2f,0x00,
+0x40,0x44,0x48,0xfe,0x02,0xf8,0x08,0x08,0xf8,0x40,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 28448 0x6f20 "漠" */
+0x01,0x21,0x17,0x11,0x80,0x43,0x4a,0x0b,0x12,0x13,0xe0,0x27,0x20,0x21,0x22,0x0c,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 28449 0x6f21 "漡" */
+0x01,0x21,0x12,0x15,0x81,0x41,0x49,0x09,0x10,0x17,0xe1,0x23,0x24,0x21,0x22,0x00,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 28450 0x6f22 "漢" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x4b,0x0a,0x13,0x10,0xe7,0x20,0x2f,0x20,0x21,0x06,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0xa0,0x10,0x0c,
+/* 28451 0x6f23 "漣" */
+0x00,0x48,0x25,0x24,0x01,0x81,0x4d,0x55,0x15,0x24,0xe5,0x24,0x24,0x2a,0x31,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 28452 0x6f24 "漤" */
+0x01,0x41,0x27,0x21,0x03,0x85,0x49,0x40,0x10,0x2f,0xe1,0x22,0x21,0x20,0x23,0x0c,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x80,0x80,0xfc,0x10,0x10,0x20,0xc0,0x30,0x08,
+/* 28453 0x6f25 "漥" */
+0x00,0x40,0x2f,0x29,0x02,0x84,0x43,0x50,0x10,0x2f,0xe0,0x20,0x23,0x20,0x20,0x0f,
+0x80,0x40,0xfe,0x12,0x48,0x44,0xf8,0x40,0x40,0xfe,0x00,0x40,0xf8,0x40,0x40,0xfe,
+/* 28454 0x6f26 "漦" */
+0x08,0x3e,0x08,0x7f,0x2a,0x49,0x08,0x3f,0x20,0x20,0x2e,0x22,0x24,0x48,0x52,0x81,
+0x20,0x3e,0x44,0xa8,0x10,0x28,0x44,0xfe,0x00,0x88,0xd0,0xa0,0x90,0x88,0x86,0x00,
+/* 28455 0x6f27 "漧" */
+0x01,0x41,0x21,0x2f,0x01,0x87,0x44,0x57,0x14,0x27,0xe1,0x2f,0x21,0x21,0x21,0x01,
+0x10,0x10,0x10,0xde,0x20,0xc0,0x5c,0xc4,0x48,0xc8,0x10,0xd0,0x22,0x22,0x1e,0x00,
+/* 28456 0x6f28 "漨" */
+0x00,0x24,0x12,0x11,0x80,0x40,0x46,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x25,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 28457 0x6f29 "漩" */
+0x04,0x42,0x22,0x2f,0x04,0x84,0x47,0x55,0x15,0x25,0xe5,0x25,0x29,0x2b,0x30,0x21,
+0x20,0x20,0x20,0x7e,0x80,0x00,0x7c,0x14,0x10,0x50,0x5c,0x50,0x50,0x50,0xbe,0x00,
+/* 28458 0x6f2a "漪" */
+0x00,0x49,0x25,0x22,0x06,0x8a,0x43,0x52,0x16,0x2a,0xe2,0x22,0x22,0x22,0x2a,0x04,
+0x20,0x20,0xfc,0x20,0x50,0x88,0xfe,0x08,0xe8,0xa8,0xa8,0xe8,0xa8,0x08,0x28,0x10,
+/* 28459 0x6f2b "漫" */
+0x03,0x22,0x13,0x12,0x83,0x40,0x47,0x14,0x14,0x27,0xe0,0x23,0x21,0x20,0x23,0x0c,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 28460 0x6f2c "漬" */
+0x00,0x27,0x10,0x13,0x80,0x47,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 28461 0x6f2d "漭" */
+0x01,0x21,0x17,0x11,0x80,0x47,0x40,0x11,0x12,0x25,0xe1,0x27,0x21,0x21,0x22,0x04,
+0x10,0x10,0xfc,0x10,0x48,0xfc,0xa0,0x10,0x08,0x14,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 28462 0x6f2e "漮" */
+0x00,0x20,0x17,0x14,0x85,0x44,0x47,0x14,0x15,0x24,0xe5,0x24,0x29,0x2a,0x30,0x00,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x62,0xb4,0x28,0x26,0xa0,0x40,
+/* 28463 0x6f2f "漯" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x41,0x12,0x17,0x20,0xe3,0x2f,0x20,0x22,0x25,0x08,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x10,0xe0,0xc8,0x04,0xfe,0x42,0x48,0x44,0x82,
+/* 28464 0x6f30 "漰" */
+0x00,0x24,0x14,0x17,0x80,0x47,0x44,0x14,0x17,0x24,0xe4,0x27,0x24,0x24,0x2a,0x11,
+0x40,0x44,0x44,0xfc,0x00,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xb4,0x48,
+/* 28465 0x6f31 "漱" */
+0x01,0x21,0x17,0x11,0x81,0x47,0x45,0x15,0x17,0x21,0xe3,0x25,0x29,0x21,0x21,0x01,
+0x08,0x08,0xc8,0x08,0x1e,0xd2,0x64,0x40,0xc8,0x08,0x88,0x48,0x54,0x14,0x24,0x42,
+/* 28466 0x6f32 "漲" */
+0x00,0x4f,0x21,0x21,0x01,0x8f,0x48,0x48,0x18,0x2f,0xe1,0x21,0x21,0x21,0x2a,0x04,
+0x00,0x3e,0x20,0x3c,0x20,0x3c,0x20,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x62,0x40,
+/* 28467 0x6f33 "漳" */
+0x00,0x27,0x11,0x10,0x8f,0x40,0x43,0x12,0x13,0x22,0xe3,0x20,0x2f,0x20,0x20,0x00,
+0x40,0xfc,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 28468 0x6f34 "漴" */
+0x00,0x24,0x14,0x17,0x80,0x40,0x47,0x14,0x1b,0x20,0xe7,0x20,0x22,0x24,0x29,0x00,
+0x40,0x44,0x44,0xfc,0x80,0x40,0xfe,0x02,0xf4,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 28469 0x6f35 "漵" */
+0x01,0x21,0x12,0x12,0x84,0x4b,0x41,0x11,0x17,0x21,0xe5,0x25,0x29,0x21,0x25,0x02,
+0x08,0x08,0x88,0x50,0x1e,0x94,0x24,0x14,0xd4,0x14,0x94,0x48,0x48,0x14,0x24,0x42,
+/* 28470 0x6f36 "漶" */
+0x00,0x20,0x13,0x12,0x83,0x40,0x47,0x14,0x17,0x20,0xe0,0x20,0x25,0x25,0x28,0x00,
+0x40,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0xfc,0x40,0x80,0x48,0x44,0x14,0xf0,0x00,
+/* 28471 0x6f37 "漷" */
+0x02,0x21,0x17,0x10,0x87,0x44,0x47,0x10,0x17,0x20,0xe1,0x21,0x27,0x21,0x25,0x02,
+0x00,0x1e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x92,0x12,0xda,0x14,0x10,0x10,0x10,
+/* 28472 0x6f38 "漸" */
+0x02,0x42,0x22,0x2f,0x02,0x8f,0x4a,0x4f,0x1a,0x2f,0xe2,0x2f,0x22,0x22,0x22,0x02,
+0x00,0x02,0x3c,0xa0,0x20,0xa0,0xbe,0xa4,0xa4,0xa4,0x24,0xa4,0x24,0x44,0x44,0x84,
+/* 28473 0x6f39 "漹" */
+0x00,0x27,0x10,0x12,0x82,0x4f,0x41,0x11,0x12,0x23,0xe0,0x25,0x25,0x28,0x20,0x00,
+0x00,0xfc,0x40,0x78,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 28474 0x6f3a "漺" */
+0x00,0x20,0x17,0x10,0x85,0x42,0x45,0x10,0x15,0x22,0xe5,0x20,0x20,0x21,0x22,0x0c,
+0x40,0x40,0xfc,0x40,0x54,0x48,0x54,0x40,0x54,0x48,0x54,0xa0,0xa0,0x10,0x08,0x06,
+/* 28475 0x6f3b "漻" */
+0x00,0x27,0x10,0x14,0x82,0x44,0x40,0x11,0x16,0x20,0xe3,0x20,0x23,0x20,0x20,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 28476 0x6f3c "漼" */
+0x00,0x24,0x17,0x11,0x81,0x43,0x52,0x16,0x1b,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x40,0x44,0xfc,0x20,0x10,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 28477 0x6f3d "漽" */
+0x00,0x27,0x14,0x17,0x84,0x44,0x44,0x14,0x15,0x24,0xe4,0x25,0x24,0x2b,0x28,0x10,
+0x00,0xfc,0x04,0xfc,0x20,0xa8,0x70,0xa8,0x04,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,
+/* 28478 0x6f3e "漾" */
+0x02,0x21,0x17,0x10,0x83,0x40,0x47,0x10,0x10,0x21,0xe0,0x27,0x21,0x22,0x2d,0x00,
+0x08,0x10,0xfc,0x40,0xf8,0x40,0xfc,0x40,0x20,0xc0,0x44,0x68,0x50,0x48,0x46,0x80,
+/* 28479 0x6f3f "漿" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x85,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 28480 0x6f40 "潀" */
+0x00,0x27,0x14,0x14,0x87,0x40,0x40,0x17,0x12,0x22,0xe2,0x25,0x25,0x28,0x20,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x00,0x1c,0xe0,0x48,0x48,0x48,0x54,0x54,0x62,0x40,0x40,
+/* 28481 0x6f41 "潁" */
+0x20,0x24,0x38,0x22,0x22,0x1e,0x00,0x08,0x0a,0xec,0x28,0x2c,0x4a,0x4a,0xa8,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 28482 0x6f42 "潂" */
+0x00,0x24,0x14,0x17,0x80,0x42,0x41,0x17,0x11,0x21,0xe5,0x23,0x21,0x21,0x2f,0x00,
+0x40,0x44,0x44,0xfc,0x00,0x08,0x10,0xfc,0x10,0x10,0x14,0x18,0x10,0x10,0xfe,0x00,
+/* 28483 0x6f43 "潃" */
+0x02,0x44,0x28,0x30,0x03,0x84,0x4c,0x57,0x14,0x24,0xe4,0x24,0x24,0x24,0x24,0x04,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0xf8,0x88,0xf8,0x88,0xf8,0x88,0x88,0x98,
+/* 28484 0x6f44 "潄" */
+0x01,0x21,0x17,0x11,0x81,0x47,0x45,0x15,0x17,0x21,0xe3,0x25,0x29,0x21,0x21,0x01,
+0x08,0x08,0xc8,0x10,0x1e,0xe4,0x54,0x54,0xd4,0x14,0x94,0x48,0x48,0x14,0x14,0x22,
+/* 28485 0x6f45 "潅" */
+0x01,0x21,0x13,0x14,0x80,0x4f,0x41,0x12,0x17,0x2a,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x00,0x00,0xfc,0x40,0x80,0xfe,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 28486 0x6f46 "潆" */
+0x01,0x4f,0x21,0x20,0x0f,0x88,0x51,0x43,0x10,0x20,0xe7,0x20,0x22,0x24,0x29,0x00,
+0x10,0xfe,0x10,0x00,0xfe,0x82,0x14,0xe0,0x40,0x88,0xfc,0x44,0x50,0x48,0x44,0x80,
+/* 28487 0x6f47 "潇" */
+0x01,0x41,0x2f,0x21,0x00,0x87,0x40,0x5f,0x10,0x27,0xe0,0x25,0x25,0x26,0x28,0x10,
+0x10,0x10,0xfe,0x10,0x40,0xfc,0x44,0xfe,0x44,0xfc,0x40,0x64,0x54,0x54,0x44,0x44,
+/* 28488 0x6f48 "潈" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x40,0x11,0x16,0x20,0xe1,0x26,0x20,0x21,0x26,0x00,
+0x00,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 28489 0x6f49 "潉" */
+0x00,0x24,0x14,0x17,0x80,0x47,0x44,0x17,0x14,0x27,0xe0,0x24,0x27,0x24,0x25,0x06,
+0x40,0x44,0x44,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x24,0xa8,0x32,0xa2,0x1e,
+/* 28490 0x6f4a "潊" */
+0x42,0x22,0x25,0x84,0x48,0x57,0x02,0x22,0x2f,0x42,0xcb,0x4a,0x52,0x42,0x4a,0x04,
+0x10,0x10,0x10,0x9e,0x10,0x10,0x7c,0x24,0xa4,0x24,0x28,0xa8,0x90,0x28,0x44,0x82,
+/* 28491 0x6f4b "潋" */
+0x42,0x22,0x25,0x84,0x48,0x57,0x00,0x24,0x32,0x4a,0xc8,0x41,0x43,0x5c,0x40,0x00,
+0x10,0x10,0x10,0xa0,0x3e,0x44,0x24,0xa4,0xa4,0xa8,0xa8,0x10,0xa8,0x28,0x44,0x82,
+/* 28492 0x6f4c "潌" */
+0x00,0x20,0x17,0x15,0x82,0x47,0x40,0x11,0x13,0x20,0xe0,0x23,0x20,0x20,0x2f,0x00,
+0x80,0x40,0xfc,0x14,0x08,0xfc,0x80,0x10,0xf8,0x48,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 28493 0x6f4d "潍" */
+0x04,0x84,0x44,0x08,0x8b,0x5e,0x44,0x04,0x28,0x5e,0xc8,0x40,0x46,0x58,0x40,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 28494 0x6f4e "潎" */
+0x01,0x21,0x15,0x13,0x81,0x47,0x45,0x15,0x15,0x27,0xe5,0x25,0x25,0x25,0x24,0x04,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 28495 0x6f4f "潏" */
+0x00,0x27,0x10,0x10,0x87,0x40,0x41,0x16,0x10,0x27,0xe4,0x25,0x26,0x24,0x24,0x04,
+0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0xa0,0x40,0xfc,0xa4,0x14,0xec,0xa4,0xe4,0x0c,
+/* 28496 0x6f50 "潐" */
+0x01,0x21,0x13,0x12,0x86,0x4b,0x42,0x12,0x13,0x22,0xe2,0x23,0x22,0x25,0x24,0x08,
+0x40,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x24,0x92,0x92,
+/* 28497 0x6f51 "潑" */
+0x00,0x23,0x10,0x15,0x82,0x4c,0x47,0x10,0x17,0x24,0xe7,0x20,0x20,0x20,0x25,0x02,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x00,0xbc,0x84,0xa8,0x90,0x28,0x44,
+/* 28498 0x6f52 "潒" */
+0x01,0x41,0x22,0x27,0x0a,0x82,0x43,0x50,0x11,0x26,0xe1,0x26,0x20,0x21,0x26,0x00,
+0x00,0xf0,0x10,0xfc,0x24,0x44,0xfc,0x80,0x44,0xa8,0x30,0x68,0xa8,0x24,0xa2,0x40,
+/* 28499 0x6f53 "潓" */
+0x00,0x40,0x2f,0x20,0x07,0x84,0x47,0x54,0x17,0x20,0xef,0x20,0x20,0x25,0x25,0x08,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0xfe,0x42,0x24,0x22,0x0a,0xf8,
+/* 28500 0x6f54 "潔" */
+0x01,0x27,0x11,0x13,0x81,0x47,0x41,0x10,0x11,0x23,0xe0,0x27,0x20,0x22,0x25,0x00,
+0x00,0xbc,0x14,0x94,0x14,0xa4,0x4c,0x80,0x10,0xe0,0x48,0xfc,0x44,0x48,0x44,0x80,
+/* 28501 0x6f55 "潕" */
+0x01,0x21,0x13,0x16,0x8a,0x42,0x47,0x12,0x12,0x22,0xef,0x20,0x22,0x22,0x24,0x00,
+0x00,0x00,0xfc,0xa8,0xa8,0xa8,0xfc,0xa8,0xa8,0xa8,0xfe,0x00,0xa8,0x54,0x54,0x00,
+/* 28502 0x6f56 "潖" */
+0x00,0x4f,0x22,0x27,0x02,0x8f,0x40,0x57,0x14,0x24,0xe7,0x24,0x24,0x24,0x23,0x00,
+0x00,0xbe,0x08,0xbc,0x08,0xbe,0x00,0xfc,0x44,0x44,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 28503 0x6f57 "潗" */
+0x01,0x21,0x13,0x16,0x8b,0x42,0x43,0x12,0x13,0x22,0xe0,0x2f,0x21,0x22,0x2c,0x00,
+0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x40,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 28504 0x6f58 "潘" */
+0x00,0x27,0x12,0x11,0x87,0x41,0x42,0x14,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x78,0xc0,0x48,0x50,0xfc,0x50,0x48,0x06,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x08,
+/* 28505 0x6f59 "潙" */
+0x00,0x20,0x17,0x12,0x81,0x43,0x4a,0x0b,0x12,0x13,0xe4,0x26,0x2a,0x2a,0x30,0x00,
+0x04,0x3e,0xc0,0x44,0x28,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 28506 0x6f5a "潚" */
+0x00,0x23,0x10,0x17,0x80,0x43,0x40,0x15,0x17,0x24,0xe7,0x24,0x27,0x25,0x25,0x08,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 28507 0x6f5b "潛" */
+0x00,0x27,0x11,0x15,0x87,0x43,0x55,0x19,0x10,0x23,0xe2,0x22,0x23,0x22,0x22,0x03,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 28508 0x6f5c "潜" */
+0x01,0x41,0x27,0x21,0x0f,0x81,0x42,0x54,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x10,0x10,0xbc,0x10,0xfe,0x10,0xa8,0x44,0xfa,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28509 0x6f5d "潝" */
+0x00,0x20,0x11,0x16,0x80,0x43,0x4a,0x0b,0x10,0x17,0xe0,0x24,0x22,0x24,0x22,0x01,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 28510 0x6f5e "潞" */
+0x00,0x27,0x14,0x14,0x84,0x47,0x41,0x11,0x11,0x25,0xe5,0x25,0x25,0x25,0x2e,0x00,
+0x10,0x90,0xbc,0xa4,0xc4,0xa8,0x10,0x28,0x46,0xc0,0x3c,0x24,0x24,0xa4,0x3c,0x24,
+/* 28511 0x6f5f "潟" */
+0x01,0x26,0x14,0x14,0x87,0x44,0x44,0x17,0x12,0x27,0xe8,0x25,0x25,0x28,0x20,0x00,
+0x00,0x38,0x08,0x08,0x38,0x08,0x08,0xf8,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 28512 0x6f60 "潠" */
+0x00,0x27,0x14,0x17,0x84,0x44,0x43,0x10,0x11,0x27,0xe1,0x21,0x2f,0x21,0x22,0x04,
+0x00,0xbc,0xa4,0xbc,0x20,0xa4,0x9c,0x00,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0x04,
+/* 28513 0x6f61 "潡" */
+0x02,0x41,0x2f,0x20,0x07,0x84,0x47,0x50,0x17,0x20,0xe1,0x21,0x2f,0x21,0x25,0x02,
+0x10,0x10,0xd0,0x10,0xbe,0xa4,0xd4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x14,0x22,
+/* 28514 0x6f62 "潢" */
+0x01,0x21,0x17,0x11,0x81,0x4f,0x40,0x17,0x14,0x27,0xe4,0x27,0x20,0x21,0x22,0x04,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x10,0x08,0x04,
+/* 28515 0x6f63 "潣" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x44,0x14,0x15,0x24,0xe4,0x24,0x24,0x25,0x24,0x04,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x84,0x44,0xf4,0x24,0xa4,0x44,0xa4,0x04,0x14,0x08,
+/* 28516 0x6f64 "潤" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x44,0x15,0x14,0x24,0xe4,0x24,0x25,0x24,0x24,0x04,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x44,0xe4,0x44,0x44,0xf4,0x04,0x14,0x08,
+/* 28517 0x6f65 "潥" */
+0x00,0x27,0x10,0x10,0x87,0x44,0x44,0x17,0x12,0x21,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 28518 0x6f66 "潦" */
+0x00,0x20,0x17,0x10,0x85,0x42,0x47,0x1a,0x13,0x22,0xe3,0x20,0x22,0x24,0x29,0x00,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 28519 0x6f67 "潧" */
+0x02,0x21,0x10,0x17,0x84,0x45,0x44,0x14,0x17,0x20,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x08,0x10,0x00,0xfc,0x44,0x54,0xe4,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 28520 0x6f68 "潨" */
+0x00,0x21,0x17,0x14,0x84,0x4f,0x40,0x10,0x17,0x21,0xe2,0x24,0x21,0x22,0x2c,0x00,
+0x80,0x00,0xfc,0xa4,0xa4,0xfe,0x00,0x3c,0xc0,0x44,0x44,0xe8,0x50,0x48,0x46,0x40,
+/* 28521 0x6f69 "潩" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x41,0x11,0x17,0x21,0xe1,0x2f,0x20,0x21,0x22,0x04,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0x10,0x08,0x04,
+/* 28522 0x6f6a "潪" */
+0x02,0x43,0x25,0x21,0x0f,0x82,0x42,0x54,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x00,0xde,0x12,0x12,0xd2,0x92,0x5e,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28523 0x6f6b "潫" */
+0x00,0x22,0x11,0x13,0x80,0x47,0x41,0x12,0x15,0x21,0xe0,0x23,0x20,0x22,0x24,0x00,
+0x40,0x48,0x50,0xf8,0x80,0xfc,0x10,0x88,0x16,0xe0,0x48,0xfc,0x44,0x48,0x44,0xc0,
+/* 28524 0x6f6c "潬" */
+0x00,0x27,0x14,0x14,0x87,0x40,0x4b,0x0a,0x13,0x12,0xe3,0x20,0x27,0x20,0x20,0x00,
+0x00,0xbc,0xa4,0xa4,0xbc,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0x40,0x40,
+/* 28525 0x6f6d "潭" */
+0x00,0x27,0x10,0x17,0x84,0x47,0x40,0x13,0x12,0x23,0xe2,0x23,0x20,0x27,0x20,0x00,
+0x00,0xfc,0xa0,0xfc,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0x40,0x40,
+/* 28526 0x6f6e "潮" */
+0x01,0x41,0x27,0x21,0x01,0x87,0x44,0x57,0x14,0x27,0xe1,0x21,0x2f,0x21,0x21,0x01,
+0x00,0x1e,0xd2,0x12,0x12,0xde,0x52,0xd2,0x52,0xde,0x12,0x12,0xd2,0x22,0x2a,0x44,
+/* 28527 0x6f6f "潯" */
+0x00,0x23,0x10,0x13,0x80,0x43,0x48,0x0b,0x11,0x17,0xe0,0x23,0x21,0x20,0x20,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 28528 0x6f70 "潰" */
+0x00,0x23,0x12,0x13,0x80,0x47,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 28529 0x6f71 "潱" */
+0x00,0x27,0x10,0x13,0x80,0x47,0x44,0x13,0x10,0x23,0xe2,0x23,0x22,0x21,0x27,0x00,
+0x40,0xfc,0x40,0xf8,0x00,0xfc,0x04,0xf8,0x00,0xf8,0x08,0xf8,0x08,0x10,0xfc,0x00,
+/* 28530 0x6f72 "潲" */
+0x01,0x4e,0x22,0x22,0x02,0x8f,0x42,0x53,0x16,0x26,0xea,0x22,0x22,0x22,0x22,0x02,
+0x10,0x10,0x54,0x38,0x10,0x7c,0x44,0x44,0xfc,0x44,0x44,0x7c,0x44,0x44,0x54,0x48,
+/* 28531 0x6f73 "潳" */
+0x00,0x23,0x12,0x12,0x83,0x42,0x4a,0x0a,0x13,0x12,0xe2,0x23,0x22,0x24,0x24,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x22,0xfc,0x28,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 28532 0x6f74 "潴" */
+0x00,0x49,0x25,0x22,0x06,0x8b,0x42,0x52,0x16,0x2b,0xe2,0x22,0x22,0x22,0x2a,0x04,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 28533 0x6f75 "潵" */
+0x02,0x22,0x17,0x12,0x82,0x4f,0x40,0x17,0x14,0x27,0xe4,0x27,0x24,0x24,0x24,0x04,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 28534 0x6f76 "潶" */
+0x00,0x27,0x14,0x15,0x84,0x44,0x47,0x10,0x17,0x20,0xe0,0x2f,0x20,0x25,0x24,0x08,
+0x00,0xfc,0x44,0x54,0xe4,0x44,0xfc,0x40,0xfc,0x40,0x40,0xfe,0x00,0x24,0x92,0x92,
+/* 28535 0x6f77 "潷" */
+0x02,0x23,0x15,0x10,0x80,0x43,0x40,0x17,0x10,0x23,0xe0,0x23,0x20,0x27,0x20,0x00,
+0x10,0xde,0x28,0x84,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,
+/* 28536 0x6f78 "潸" */
+0x04,0x84,0x5f,0x04,0x95,0x55,0x65,0x00,0x2f,0x48,0xcf,0x48,0x4f,0x48,0x48,0x08,
+0x20,0x20,0xfc,0x20,0x68,0xaa,0x26,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 28537 0x6f79 "潹" */
+0x00,0x20,0x17,0x10,0x81,0x46,0x40,0x11,0x11,0x27,0xe1,0x23,0x25,0x29,0x21,0x01,
+0x40,0x40,0xfc,0xe0,0x50,0x4c,0x40,0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x10,0x10,
+/* 28538 0x6f7a "潺" */
+0x07,0x24,0x17,0x14,0x85,0x44,0x47,0x14,0x14,0x27,0xe4,0x25,0x29,0x2f,0x31,0x03,
+0xfc,0x04,0xfc,0x00,0xf8,0x10,0xfe,0x20,0x60,0x9c,0x84,0x08,0xde,0x08,0x08,0x18,
+/* 28539 0x6f7b "潻" */
+0x00,0x23,0x10,0x17,0x81,0x42,0x44,0x11,0x12,0x2c,0xe2,0x21,0x22,0x24,0x21,0x00,
+0x38,0xc0,0x40,0xfc,0x50,0x48,0xa4,0x10,0x48,0x46,0x48,0x50,0x48,0x44,0x40,0x80,
+/* 28540 0x6f7c "潼" */
+0x00,0x23,0x11,0x10,0x87,0x40,0x4b,0x0a,0x13,0x12,0xe3,0x20,0x23,0x20,0x27,0x00,
+0x40,0xf8,0x10,0xa0,0xfc,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xf8,0x40,0xfe,0x00,
+/* 28541 0x6f7d "潽" */
+0x02,0x21,0x17,0x10,0x84,0x42,0x4f,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x08,0x10,0xfc,0xa0,0xa4,0xa8,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28542 0x6f7e "潾" */
+0x00,0x22,0x11,0x17,0x81,0x42,0x44,0x12,0x12,0x23,0xe4,0x2a,0x21,0x22,0x24,0x08,
+0x40,0x48,0x50,0xfc,0x50,0x48,0x44,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 28543 0x6f7f "潿" */
+0x00,0x27,0x14,0x15,0x84,0x47,0x44,0x15,0x15,0x25,0xe4,0x24,0x25,0x25,0x24,0x07,
+0x00,0xfc,0x44,0xf4,0x94,0xfc,0x04,0xf4,0x14,0xf4,0x44,0xf4,0x44,0xfc,0x44,0xfc,
+/* 28544 0x6f80 "澀" */
+0x00,0x4f,0x22,0x26,0x0a,0x84,0x45,0x58,0x11,0x21,0xe5,0x25,0x25,0x25,0x2e,0x00,
+0x00,0xbc,0x94,0xb4,0xd4,0xa4,0xac,0x40,0x08,0x08,0xa8,0x2c,0x28,0xa8,0x7e,0x00,
+/* 28545 0x6f81 "澁" */
+0x40,0x20,0x22,0x82,0x42,0x4f,0x00,0x22,0x22,0x42,0xcb,0x4a,0x4a,0x4b,0x5e,0x00,
+0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,0x08,0x08,0x28,0xae,0x28,0x28,0xa8,0x7e,0x00,
+/* 28546 0x6f82 "澂" */
+0x01,0x25,0x15,0x15,0x87,0x40,0x47,0x10,0x17,0x21,0xe7,0x21,0x21,0x2f,0x20,0x00,
+0x08,0x48,0x48,0x50,0xde,0x14,0xe4,0x14,0xd4,0x14,0xd4,0x08,0x08,0xd4,0x24,0x42,
+/* 28547 0x6f83 "澃" */
+0x0b,0x10,0x61,0x09,0x11,0x61,0x05,0x09,0x31,0xc0,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x0c,0x90,0x60,0x20,0x18,0x06,
+/* 28548 0x6f84 "澄" */
+0x00,0x27,0x10,0x12,0x81,0x42,0x55,0x18,0x13,0x22,0xe2,0x23,0x22,0x21,0x2f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 28549 0x6f85 "澅" */
+0x00,0x23,0x10,0x17,0x80,0x43,0x40,0x17,0x10,0x23,0xe2,0x23,0x22,0x23,0x20,0x07,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfe,
+/* 28550 0x6f86 "澆" */
+0x00,0x40,0x27,0x20,0x0f,0x81,0x47,0x51,0x11,0x26,0xe0,0x2f,0x21,0x21,0x22,0x0c,
+0x40,0x40,0xfc,0x40,0xfe,0x10,0xbc,0x10,0x90,0x3e,0x00,0xfe,0x20,0x22,0x22,0x1e,
+/* 28551 0x6f87 "澇" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x40,0x57,0x14,0x28,0xe7,0x20,0x20,0x21,0x22,0x04,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0x00,0xfc,0x84,0x88,0xf8,0x88,0x88,0x08,0x28,0x10,
+/* 28552 0x6f88 "澈" */
+0x02,0x21,0x17,0x12,0x84,0x4f,0x40,0x17,0x14,0x27,0xe4,0x27,0x24,0x24,0x24,0x05,
+0x08,0x08,0xc8,0x10,0x9e,0xd4,0x64,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0xa4,0xc2,
+/* 28553 0x6f89 "澉" */
+0x00,0x47,0x20,0x21,0x0f,0x84,0x44,0x57,0x14,0x27,0xe4,0x24,0x27,0x2c,0x20,0x00,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 28554 0x6f8a "澊" */
+0x01,0x20,0x17,0x10,0x83,0x42,0x4b,0x0a,0x13,0x12,0xe3,0x20,0x27,0x21,0x20,0x00,
+0x08,0x90,0xfe,0x90,0xfc,0x94,0x1c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x08,0xa8,0x10,
+/* 28555 0x6f8b "澋" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x40,0x17,0x10,0x23,0xe2,0x23,0x20,0x22,0x24,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x40,0x48,0x44,0xc0,
+/* 28556 0x6f8c "澌" */
+0x04,0x44,0x24,0x2f,0x04,0x87,0x44,0x57,0x14,0x24,0xef,0x20,0x25,0x28,0x30,0x00,
+0x80,0x82,0x9c,0xd0,0x90,0x90,0x9e,0x94,0x94,0x94,0xd4,0x14,0x14,0xa4,0x24,0x44,
+/* 28557 0x6f8d "澍" */
+0x01,0x41,0x2f,0x21,0x01,0x87,0x40,0x57,0x14,0x24,0xe7,0x24,0x22,0x20,0x2f,0x04,
+0x04,0x04,0xe4,0x04,0x3e,0xc4,0x04,0xe4,0x54,0x54,0xc4,0x44,0x84,0xe4,0x14,0x08,
+/* 28558 0x6f8e "澎" */
+0x01,0x41,0x2f,0x21,0x01,0x87,0x40,0x57,0x14,0x24,0xe7,0x24,0x22,0x20,0x2f,0x04,
+0x04,0x04,0xe8,0x10,0x00,0xc4,0x04,0xc8,0x50,0x42,0xc2,0x44,0x84,0xe8,0x10,0x20,
+/* 28559 0x6f8f "澏" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x47,0x14,0x14,0x27,0xe0,0x24,0x24,0x24,0x27,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0x44,0x44,0x44,0xfc,0x04,
+/* 28560 0x6f90 "澐" */
+0x00,0x47,0x20,0x2f,0x08,0x83,0x40,0x53,0x10,0x27,0xe0,0x2f,0x21,0x22,0x27,0x02,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfc,0x00,0xfe,0x00,0x08,0xfc,0x04,
+/* 28561 0x6f91 "澑" */
+0x00,0x27,0x10,0x17,0x84,0x44,0x47,0x10,0x17,0x24,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x00,0xfe,0xa0,0xbc,0xa4,0xa4,0xbc,0xa0,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 28562 0x6f92 "澒" */
+0x00,0x20,0x10,0x17,0x82,0x42,0x42,0x12,0x12,0x22,0xe3,0x2e,0x20,0x20,0x20,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0xc4,0x44,0x7c,0x28,0x44,0x82,
+/* 28563 0x6f93 "澓" */
+0x01,0x21,0x12,0x14,0x89,0x41,0x42,0x16,0x1a,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x3c,0x44,0xa8,0x10,0x28,0xc6,
+/* 28564 0x6f94 "澔" */
+0x01,0x21,0x12,0x17,0x84,0x44,0x44,0x14,0x17,0x24,0xe4,0x24,0x24,0x27,0x24,0x00,
+0x08,0x28,0x28,0xbe,0xa8,0xc8,0x88,0xfe,0x80,0x80,0xbe,0xa2,0xa2,0xa2,0xbe,0x22,
+/* 28565 0x6f95 "澕" */
+0x01,0x2f,0x11,0x10,0x87,0x41,0x51,0x1f,0x11,0x21,0xe7,0x20,0x2f,0x20,0x20,0x00,
+0x10,0xfe,0x10,0x00,0xfc,0x50,0x50,0xfe,0x50,0x50,0xfc,0x40,0xfe,0x40,0x40,0x40,
+/* 28566 0x6f96 "澖" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x44,0x14,0x15,0x24,0xe4,0x25,0x26,0x24,0x24,0x04,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0x44,0xf4,0x44,0xe4,0x54,0x4c,0x44,0x54,0x08,
+/* 28567 0x6f97 "澗" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x44,0x15,0x15,0x25,0xe5,0x25,0x25,0x24,0x24,0x04,
+0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x14,0x04,0x14,0x08,
+/* 28568 0x6f98 "澘" */
+0x01,0x21,0x17,0x11,0x83,0x45,0x49,0x10,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28569 0x6f99 "澙" */
+0x00,0x20,0x17,0x14,0x87,0x44,0x47,0x12,0x13,0x24,0xe7,0x20,0x25,0x24,0x28,0x00,
+0x00,0x80,0x3c,0x04,0xbc,0x04,0xfc,0x00,0xfc,0x00,0xfe,0x02,0x52,0xaa,0xaa,0x04,
+/* 28570 0x6f9a "澚" */
+0x01,0x27,0x14,0x15,0x84,0x47,0x44,0x15,0x10,0x2f,0xe2,0x23,0x20,0x20,0x20,0x00,
+0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x00,0xfe,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 28571 0x6f9b "澛" */
+0x01,0x43,0x24,0x2f,0x14,0x87,0x44,0x57,0x10,0x2f,0xe0,0x23,0x22,0x23,0x22,0x03,
+0x00,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 28572 0x6f9c "澜" */
+0x02,0x21,0x15,0x14,0x85,0x44,0x45,0x15,0x15,0x25,0xe5,0x25,0x24,0x25,0x24,0x04,
+0x00,0x7c,0x04,0x44,0xf4,0x44,0xf4,0x54,0x74,0xd4,0x54,0xf4,0xe4,0x54,0x44,0x4c,
+/* 28573 0x6f9d "澝" */
+0x00,0x40,0x2f,0x28,0x05,0x85,0x48,0x40,0x17,0x24,0xe7,0x24,0x27,0x24,0x24,0x04,
+0x80,0x40,0xfe,0x82,0x48,0x14,0xf4,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x54,0x08,
+/* 28574 0x6f9e "澞" */
+0x00,0x20,0x10,0x17,0x84,0x45,0x44,0x15,0x15,0x25,0xe4,0x25,0x24,0x2b,0x28,0x13,
+0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0x08,0xf8,0x00,0xfe,0x20,0xfe,0x88,0x06,
+/* 28575 0x6f9f "澟" */
+0x00,0x4f,0x20,0x27,0x04,0x85,0x45,0x55,0x14,0x27,0xe0,0x23,0x20,0x2f,0x21,0x0e,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 28576 0x6fa0 "澠" */
+0x00,0x27,0x14,0x14,0x87,0x40,0x47,0x14,0x14,0x27,0xe4,0x24,0x27,0x24,0x20,0x00,
+0x00,0xfc,0xa4,0xa4,0xbc,0xa0,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa2,0xa2,0x7e,
+/* 28577 0x6fa1 "澡" */
+0x03,0x42,0x22,0x23,0x00,0x87,0x44,0x54,0x17,0x20,0xef,0x21,0x22,0x24,0x38,0x00,
+0xf8,0x08,0x08,0xf8,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0xfe,0x60,0x50,0x48,0x46,0x40,
+/* 28578 0x6fa2 "澢" */
+0x00,0x22,0x11,0x17,0x84,0x48,0x43,0x12,0x13,0x20,0xe7,0x24,0x27,0x24,0x27,0x04,
+0x40,0x48,0x50,0xfe,0x02,0x04,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 28579 0x6fa3 "澣" */
+0x01,0x41,0x21,0x2f,0x01,0x87,0x44,0x57,0x14,0x27,0xe1,0x2f,0x21,0x21,0x21,0x01,
+0x08,0x08,0x14,0xd4,0x22,0xc0,0x5c,0xc8,0x48,0xc8,0x3e,0xc8,0x08,0x08,0x08,0x08,
+/* 28580 0x6fa4 "澤" */
+0x00,0x27,0x14,0x17,0x80,0x43,0x40,0x17,0x11,0x20,0xe3,0x20,0x2f,0x20,0x20,0x00,
+0x00,0xfc,0xa4,0xfc,0x40,0xf8,0x40,0xfc,0x10,0xa0,0xf8,0x40,0xfe,0x40,0x40,0x40,
+/* 28581 0x6fa5 "澥" */
+0x44,0x27,0x29,0x92,0x4f,0x4a,0x0a,0x2f,0x2a,0x4a,0xcf,0x4a,0x4a,0x4a,0x48,0x11,
+0x00,0x3c,0x14,0x14,0xa4,0xcc,0x80,0xa8,0xbe,0xc8,0x88,0x88,0xbe,0x88,0x88,0x88,
+/* 28582 0x6fa6 "澦" */
+0x00,0x4f,0x20,0x25,0x02,0x81,0x4f,0x52,0x12,0x22,0xe2,0x22,0x22,0x22,0x2a,0x04,
+0x00,0xbe,0x88,0x10,0x3e,0x22,0xa2,0xbe,0x22,0x3e,0x22,0x22,0x3e,0x00,0x14,0x22,
+/* 28583 0x6fa7 "澧" */
+0x00,0x20,0x17,0x14,0x87,0x44,0x47,0x10,0x17,0x20,0xe3,0x22,0x23,0x21,0x20,0x0f,
+0xa0,0xa0,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x10,0xa0,0xfe,
+/* 28584 0x6fa8 "澨" */
+0x02,0x22,0x13,0x15,0x88,0x40,0x47,0x10,0x12,0x22,0xe2,0x25,0x28,0x20,0x2f,0x00,
+0x10,0x10,0xde,0x28,0x84,0x00,0xfc,0x40,0x48,0x48,0x48,0x54,0xe2,0x40,0xfe,0x00,
+/* 28585 0x6fa9 "澩" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x41,0x81,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 28586 0x6faa "澪" */
+0x00,0x47,0x20,0x2f,0x08,0x83,0x40,0x53,0x10,0x23,0xec,0x23,0x20,0x23,0x20,0x00,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0xa0,0x98,0x46,0xf0,0x10,0x20,0xc0,0x20,
+/* 28587 0x6fab "澫" */
+0x01,0x21,0x17,0x11,0x83,0x42,0x4b,0x0a,0x13,0x10,0xe7,0x24,0x24,0x25,0x24,0x04,
+0x10,0x10,0xfc,0x10,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xf4,0x14,0x0c,
+/* 28588 0x6fac "澬" */
+0x04,0x22,0x10,0x11,0x86,0x42,0x48,0x0b,0x12,0x13,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x40,0x7c,0x84,0x28,0x20,0x50,0x8c,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 28589 0x6fad "澭" */
+0x00,0x20,0x17,0x10,0x82,0x42,0x44,0x17,0x11,0x22,0xe4,0x2f,0x21,0x22,0x24,0x08,
+0x40,0x20,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x7e,0x40,
+/* 28590 0x6fae "澮" */
+0x00,0x40,0x23,0x2d,0x00,0x87,0x45,0x54,0x17,0x20,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 28591 0x6faf "澯" */
+0x00,0x40,0x22,0x23,0x04,0x8a,0x43,0x4c,0x12,0x21,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x80,0xdc,0x84,0xd4,0x48,0x94,0x24,0x40,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 28592 0x6fb0 "澰" */
+0x00,0x20,0x10,0x11,0x82,0x45,0x40,0x17,0x14,0x24,0xe7,0x22,0x22,0x25,0x29,0x10,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0xbc,0xa4,0xa4,0xbc,0x10,0x10,0x28,0x44,0x82,
+/* 28593 0x6fb1 "澱" */
+0x40,0x2f,0x28,0x88,0x4f,0x4a,0x0a,0x2f,0x2a,0x4a,0xcf,0x48,0x52,0x52,0x64,0x08,
+0x00,0xdc,0x54,0x54,0xd4,0x94,0xa6,0xc0,0x9c,0x94,0xd4,0x14,0x88,0x48,0x54,0x22,
+/* 28594 0x6fb2 "澲" */
+0x00,0x24,0x12,0x10,0x87,0x41,0x40,0x17,0x10,0x23,0xe0,0x27,0x21,0x22,0x2c,0x00,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0x50,0x48,0x46,0x40,
+/* 28595 0x6fb3 "澳" */
+0x00,0x21,0x17,0x14,0x85,0x44,0x47,0x14,0x15,0x24,0xe0,0x2f,0x20,0x21,0x22,0x0c,
+0x80,0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x04,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 28596 0x6fb4 "澴" */
+0x00,0x23,0x12,0x12,0x83,0x40,0x47,0x10,0x13,0x22,0xe3,0x20,0x21,0x23,0x2d,0x01,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 28597 0x6fb5 "澵" */
+0x02,0x21,0x17,0x10,0x84,0x42,0x47,0x11,0x11,0x27,0xe1,0x25,0x25,0x29,0x25,0x02,
+0x00,0x02,0xdc,0x10,0x50,0x90,0xde,0x14,0x14,0xd4,0x14,0x94,0x54,0x24,0x24,0x44,
+/* 28598 0x6fb6 "澶" */
+0x00,0x4f,0x20,0x27,0x04,0x85,0x45,0x57,0x10,0x23,0xe2,0x23,0x22,0x23,0x20,0x0f,
+0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 28599 0x6fb7 "澷" */
+0x03,0x22,0x13,0x12,0x83,0x40,0x47,0x14,0x17,0x20,0xe7,0x21,0x21,0x21,0x22,0x04,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xfc,0x40,0xfe,0x00,0xf8,0x08,0x28,0x10,
+/* 28600 0x6fb8 "澸" */
+0x00,0x20,0x17,0x14,0x85,0x44,0x45,0x15,0x15,0x24,0xe4,0x28,0x22,0x22,0x24,0x00,
+0x14,0x12,0xfe,0x10,0xd0,0x14,0xd4,0x58,0xca,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 28601 0x6fb9 "澹" */
+0x02,0x43,0x24,0x27,0x0d,0x96,0x47,0x54,0x15,0x24,0xe5,0x24,0x25,0x29,0x29,0x11,
+0x00,0xf8,0x10,0xfe,0x48,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x04,
+/* 28602 0x6fba "澺" */
+0x00,0x20,0x13,0x11,0x80,0x47,0x40,0x13,0x12,0x23,0xe2,0x23,0x20,0x25,0x25,0x08,
+0x80,0x40,0xfc,0x08,0x90,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x24,0x0a,0xfa,
+/* 28603 0x6fbb "澻" */
+0x00,0x24,0x12,0x10,0x80,0x40,0x46,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x25,0x08,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 28604 0x6fbc "澼" */
+0x00,0x20,0x17,0x14,0x84,0x44,0x47,0x14,0x14,0x27,0xe6,0x2a,0x2a,0x2b,0x32,0x00,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0x7e,0x08,0x88,0xbe,0x88,0x88,0x88,0x88,0x08,
+/* 28605 0x6fbd "澽" */
+0x00,0x20,0x10,0x13,0x82,0x42,0x4b,0x0a,0x12,0x13,0xe2,0x23,0x22,0x25,0x24,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 28606 0x6fbe "澾" */
+0x00,0x24,0x12,0x10,0x80,0x40,0x46,0x12,0x12,0x22,0xe2,0x22,0x22,0x22,0x25,0x08,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 28607 0x6fbf "澿" */
+0x01,0x21,0x17,0x11,0x83,0x45,0x49,0x10,0x13,0x20,0xe7,0x20,0x22,0x24,0x29,0x00,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 28608 0x6fc0 "激" */
+0x02,0x44,0x2f,0x28,0x0f,0x88,0x4f,0x54,0x12,0x2f,0xe4,0x27,0x24,0x28,0x2a,0x11,
+0x10,0x10,0x90,0x90,0xbe,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x88,0x88,0x94,0x94,0x22,
+/* 28609 0x6fc1 "濁" */
+0x00,0x27,0x14,0x14,0x87,0x42,0x53,0x14,0x1b,0x22,0xe3,0x20,0x20,0x27,0x22,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xfe,0x42,0xfa,0x4a,0xfa,0x52,0x7a,0x8a,0x14,0x08,
+/* 28610 0x6fc2 "濂" */
+0x00,0x27,0x15,0x14,0x87,0x44,0x45,0x14,0x17,0x24,0xe5,0x24,0x24,0x29,0x2a,0x10,
+0x20,0xfe,0x08,0x90,0xfc,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 28611 0x6fc3 "濃" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x48,0x0b,0x12,0x12,0xe2,0x23,0x25,0x25,0x25,0x09,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 28612 0x6fc4 "濄" */
+0x00,0x44,0x22,0x22,0x00,0x80,0x4d,0x45,0x15,0x25,0xe5,0x25,0x25,0x25,0x2a,0x11,
+0x00,0xf8,0x88,0xe8,0xa8,0xa8,0xfc,0x04,0x74,0x54,0x74,0x04,0x14,0x08,0x00,0xfe,
+/* 28613 0x6fc5 "濅" */
+0x00,0x4f,0x28,0x23,0x00,0x83,0x40,0x57,0x14,0x23,0xe2,0x20,0x27,0x21,0x20,0x0f,
+0x40,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xfc,0x44,0xf8,0x48,0x40,0xf8,0x10,0xe0,0x1e,
+/* 28614 0x6fc6 "濆" */
+0x00,0x27,0x10,0x11,0x8f,0x41,0x43,0x12,0x13,0x22,0xe3,0x22,0x23,0x21,0x22,0x04,
+0x40,0xfc,0x40,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0x04,
+/* 28615 0x6fc7 "濇" */
+0x00,0x20,0x17,0x12,0x82,0x45,0x4f,0x10,0x17,0x24,0xe5,0x25,0x25,0x24,0x27,0x04,
+0x40,0x40,0xfc,0x48,0x48,0x54,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x04,
+/* 28616 0x6fc8 "濈" */
+0x03,0x22,0x12,0x13,0x80,0x4f,0x42,0x13,0x12,0x23,0xe2,0x22,0x2f,0x24,0x20,0x00,
+0xd4,0x52,0x52,0xd0,0x10,0xfe,0x50,0xd4,0x54,0xd4,0x54,0xf8,0x4a,0x4a,0x56,0x62,
+/* 28617 0x6fc9 "濉" */
+0x00,0x40,0x2f,0x29,0x09,0x8f,0x49,0x59,0x1f,0x29,0xe9,0x29,0x2f,0x29,0x20,0x00,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 28618 0x6fca "濊" */
+0x00,0x21,0x11,0x17,0x80,0x40,0x4b,0x0a,0x13,0x12,0xe2,0x22,0x23,0x24,0x28,0x03,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 28619 0x6fcb "濋" */
+0x01,0x21,0x17,0x11,0x83,0x45,0x49,0x10,0x17,0x20,0xe2,0x22,0x22,0x25,0x28,0x10,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xfc,0x44,0x40,0x78,0x40,0x40,0xfe,0x00,
+/* 28620 0x6fcc "濌" */
+0x1c,0x70,0x11,0xfc,0x10,0x7d,0x56,0x7c,0x55,0x7d,0x11,0x7d,0x11,0x1f,0xf1,0x41,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28621 0x6fcd "濍" */
+0x01,0x4f,0x21,0x22,0x03,0x84,0x4b,0x41,0x12,0x24,0xe1,0x20,0x20,0x25,0x25,0x08,
+0x10,0xfe,0x10,0x00,0xfc,0xa4,0xa4,0x64,0x54,0x94,0x08,0x40,0x24,0x22,0x0a,0xf8,
+/* 28622 0x6fce "濎" */
+0x01,0x21,0x11,0x15,0x85,0x45,0x45,0x14,0x17,0x20,0xe0,0x2f,0x24,0x24,0x24,0x08,
+0xf8,0x08,0xf8,0x0a,0xfa,0x0a,0xfa,0x02,0x9e,0x90,0x90,0x9e,0x92,0x92,0x92,0x92,
+/* 28623 0x6fcf "濏" */
+0x00,0x27,0x11,0x11,0x87,0x41,0x41,0x17,0x10,0x20,0xe0,0x25,0x25,0x29,0x23,0x0c,
+0x00,0xbe,0x08,0x08,0xbe,0x08,0x08,0xbe,0x00,0x80,0x44,0x12,0x22,0xc0,0x04,0xfc,
+/* 28624 0x6fd0 "濐" */
+0x03,0x22,0x13,0x12,0x83,0x40,0x4b,0x08,0x17,0x10,0xe1,0x27,0x21,0x21,0x21,0x01,
+0xfc,0x04,0xfc,0x04,0xfc,0x44,0xf8,0x50,0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 28625 0x6fd1 "濑" */
+0x02,0x42,0x2f,0x22,0x02,0x8f,0x4a,0x5a,0x1f,0x22,0xe7,0x2a,0x32,0x22,0x22,0x02,
+0x10,0x10,0x9c,0x24,0x48,0xbe,0xa2,0xaa,0xaa,0x2a,0x2a,0xaa,0x88,0x14,0x22,0x42,
+/* 28626 0x6fd2 "濒" */
+0x42,0x22,0x2a,0x8b,0x4a,0x4a,0x1f,0x20,0x22,0x4a,0xca,0x4b,0x51,0x42,0x44,0x18,
+0x00,0x7e,0x10,0xa0,0x7c,0x44,0xd4,0x54,0x54,0xd4,0xd4,0x54,0x20,0x28,0x44,0x82,
+/* 28627 0x6fd3 "濓" */
+0x00,0x27,0x11,0x10,0x87,0x44,0x47,0x14,0x17,0x24,0xe7,0x24,0x25,0x2a,0x2c,0x10,
+0x40,0xfc,0x10,0xa0,0xfe,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,
+/* 28628 0x6fd4 "濔" */
+0x00,0x27,0x12,0x14,0x8f,0x44,0x46,0x15,0x16,0x24,0xe6,0x25,0x26,0x24,0x24,0x04,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 28629 0x6fd5 "濕" */
+0x00,0x27,0x14,0x17,0x84,0x47,0x42,0x14,0x17,0x22,0xe4,0x27,0x20,0x25,0x24,0x08,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x10,0xa4,0x38,0x10,0xa4,0xbc,0x00,0x48,0xa4,0xa4,
+/* 28630 0x6fd6 "濖" */
+0x00,0x27,0x14,0x14,0x87,0x40,0x43,0x10,0x17,0x20,0xe1,0x23,0x25,0x21,0x21,0x01,
+0x00,0xfc,0xa4,0xa4,0xfc,0x48,0xf8,0x50,0xfe,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 28631 0x6fd7 "濗" */
+0x01,0x2f,0x11,0x13,0x82,0x43,0x42,0x13,0x10,0x2f,0xe2,0x27,0x2a,0x22,0x22,0x00,
+0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xfe,0x48,0xfc,0x4a,0x48,0x58,0x40,
+/* 28632 0x6fd8 "濘" */
+0x00,0x20,0x17,0x14,0x82,0x42,0x44,0x10,0x13,0x22,0xef,0x20,0x27,0x20,0x21,0x00,
+0x80,0x40,0xfc,0x44,0xa8,0x94,0x74,0x00,0xf8,0xa8,0xfe,0x00,0xfc,0x40,0x40,0x80,
+/* 28633 0x6fd9 "濙" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x4f,0x48,0x10,0x22,0xe2,0x24,0x20,0x21,0x22,0x0c,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0xfe,0x02,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 28634 0x6fda "濚" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x40,0x57,0x14,0x20,0xe7,0x20,0x21,0x22,0x2c,0x00,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0x00,0xfc,0x44,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 28635 0x6fdb "濛" */
+0x01,0x27,0x11,0x17,0x84,0x43,0x40,0x17,0x10,0x21,0xe6,0x21,0x26,0x21,0x26,0x00,
+0x10,0xfc,0x10,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x44,0xa8,0x70,0xa8,0x26,0xa0,0x40,
+/* 28636 0x6fdc "濜" */
+0x00,0x23,0x10,0x17,0x80,0x43,0x40,0x17,0x10,0x22,0xe4,0x23,0x22,0x22,0x2f,0x00,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 28637 0x6fdd "濝" */
+0x01,0x27,0x11,0x11,0x81,0x41,0x41,0x17,0x11,0x22,0xe5,0x20,0x23,0x20,0x22,0x04,
+0x08,0xfe,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x08,0x94,0xe2,0x48,0xfc,0x40,0x48,0xc4,
+/* 28638 0x6fde "濞" */
+0x00,0x23,0x12,0x13,0x82,0x43,0x40,0x17,0x14,0x27,0xe4,0x27,0x20,0x2f,0x21,0x02,
+0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x10,0x10,
+/* 28639 0x6fdf "濟" */
+0x00,0x20,0x17,0x11,0x80,0x4f,0x45,0x15,0x1b,0x20,0xe2,0x23,0x22,0x23,0x22,0x04,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 28640 0x6fe0 "濠" */
+0x00,0x27,0x10,0x11,0x81,0x41,0x40,0x17,0x14,0x23,0xe1,0x26,0x21,0x26,0x21,0x0e,
+0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf8,0x80,0x44,0xb8,0x68,0xa6,0x60,
+/* 28641 0x6fe1 "濡" */
+0x00,0x47,0x20,0x2f,0x08,0x83,0x40,0x53,0x10,0x2f,0xe0,0x27,0x24,0x24,0x24,0x04,
+0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfe,0x40,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 28642 0x6fe2 "濢" */
+0x07,0x20,0x14,0x12,0x84,0x40,0x47,0x11,0x11,0x22,0xe4,0x20,0x2f,0x20,0x20,0x00,
+0xbc,0x84,0xa4,0x94,0xa4,0x40,0xfc,0x10,0x10,0xa8,0x44,0x40,0xfe,0x40,0x40,0x40,
+/* 28643 0x6fe3 "濣" */
+0x42,0x22,0x22,0x9f,0x42,0x4f,0x08,0x2f,0x28,0x4f,0xc2,0x5f,0x42,0x42,0x42,0x02,
+0x10,0x10,0x28,0xa8,0x44,0x8a,0xa8,0x98,0xc8,0xa8,0x0e,0xb8,0x08,0x08,0x08,0x08,
+/* 28644 0x6fe4 "濤" */
+0x00,0x27,0x10,0x13,0x80,0x47,0x40,0x13,0x10,0x27,0xe0,0x27,0x20,0x27,0x24,0x07,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 28645 0x6fe5 "濥" */
+0x00,0x41,0x26,0x20,0x01,0x8f,0x48,0x47,0x10,0x27,0xe4,0x27,0x24,0x27,0x22,0x04,
+0x80,0xf8,0x90,0x60,0xa0,0xfe,0x02,0xfc,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x08,0x04,
+/* 28646 0x6fe6 "濦" */
+0x00,0x27,0x12,0x11,0x83,0x40,0x47,0x10,0x13,0x20,0xe3,0x20,0x23,0x25,0x25,0x08,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 28647 0x6fe7 "濧" */
+0x02,0x42,0x2a,0x26,0x02,0x8f,0x40,0x54,0x12,0x2f,0xe1,0x27,0x21,0x21,0x2e,0x00,
+0x84,0x84,0xa4,0xc4,0x9e,0xe4,0x04,0x54,0x8c,0xe4,0x04,0xc4,0x04,0xc4,0x14,0x08,
+/* 28648 0x6fe8 "濨" */
+0x02,0x21,0x17,0x12,0x82,0x44,0x47,0x12,0x14,0x27,0xe0,0x21,0x25,0x25,0x28,0x00,
+0x10,0x20,0xfc,0x10,0x10,0xa4,0x38,0x10,0xa4,0xbc,0x80,0x48,0x54,0x14,0xf0,0x00,
+/* 28649 0x6fe9 "濩" */
+0x01,0x27,0x11,0x12,0x87,0x4a,0x43,0x12,0x13,0x22,0xe3,0x22,0x27,0x21,0x20,0x0f,
+0x08,0xfe,0x48,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x10,0xe0,0x1e,
+/* 28650 0x6fea "濪" */
+0x02,0x42,0x2f,0x22,0x0f,0x82,0x4f,0x50,0x1f,0x28,0xef,0x28,0x2f,0x28,0x2a,0x09,
+0x10,0x10,0x9c,0x24,0xc8,0x3e,0xaa,0x2a,0xaa,0xbe,0xa0,0xa0,0xa2,0xa2,0xa2,0x1e,
+/* 28651 0x6feb "濫" */
+0x00,0x27,0x15,0x17,0x84,0x47,0x45,0x17,0x10,0x23,0xe2,0x22,0x22,0x22,0x2f,0x00,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 28652 0x6fec "濬" */
+0x00,0x20,0x10,0x17,0x84,0x43,0x42,0x14,0x11,0x23,0xe6,0x2b,0x22,0x23,0x22,0x03,
+0x40,0x7c,0x40,0xfe,0x02,0xfc,0x48,0xa4,0x10,0xf8,0x0c,0xfa,0x08,0xf8,0x08,0xf8,
+/* 28653 0x6fed "濭" */
+0x01,0x27,0x11,0x10,0x83,0x40,0x47,0x10,0x11,0x23,0xe0,0x23,0x22,0x22,0x2f,0x00,
+0x10,0xfc,0x10,0x40,0xf8,0x40,0xfc,0x80,0x10,0xf8,0x00,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 28654 0x6fee "濮" */
+0x01,0x21,0x11,0x12,0x82,0x46,0x56,0x1a,0x12,0x22,0xe2,0x22,0x22,0x22,0x22,0x02,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 28655 0x6fef "濯" */
+0x00,0x27,0x10,0x14,0x82,0x44,0x41,0x12,0x17,0x2a,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x20,0x10,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 28656 0x6ff0 "濰" */
+0x42,0x22,0x24,0x85,0x49,0x5f,0x02,0x24,0x29,0x5f,0xc1,0x40,0x55,0x55,0x50,0x00,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 28657 0x6ff1 "濱" */
+0x00,0x40,0x27,0x24,0x0b,0x81,0x42,0x57,0x12,0x27,0xea,0x23,0x22,0x23,0x21,0x02,
+0x80,0x40,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 28658 0x6ff2 "濲" */
+0x02,0x42,0x2f,0x22,0x07,0x80,0x4f,0x48,0x17,0x20,0xe2,0x2f,0x27,0x2a,0x32,0x02,
+0x00,0x1c,0x94,0x14,0x14,0x26,0x80,0xbc,0x14,0x14,0x14,0x88,0x08,0x94,0x24,0x42,
+/* 28659 0x6ff3 "濳" */
+0x01,0x45,0x27,0x29,0x07,0x83,0x45,0x59,0x13,0x22,0xe2,0x23,0x22,0x22,0x23,0x02,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 28660 0x6ff4 "濴" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x4f,0x48,0x10,0x27,0xe1,0x21,0x22,0x24,0x29,0x00,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0xfe,0x42,0x40,0x64,0x68,0x50,0x48,0x44,0x42,0x80,
+/* 28661 0x6ff5 "濵" */
+0x00,0x27,0x14,0x13,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x24,0x24,0x08,
+0x20,0xfe,0x02,0xfc,0x24,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 28662 0x6ff6 "濶" */
+0x07,0x24,0x17,0x14,0x87,0x44,0x44,0x15,0x14,0x27,0xe4,0x25,0x25,0x25,0x24,0x04,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0x34,0xc4,0x44,0xfc,0x44,0xf4,0x14,0xf4,0x14,0x08,
+/* 28663 0x6ff7 "濷" */
+0x01,0x79,0x09,0x35,0xc2,0x01,0x47,0x21,0x81,0x40,0x17,0x16,0xe5,0x26,0x24,0x24,
+0x08,0x90,0x60,0x18,0x06,0x10,0xfc,0x10,0xf0,0x40,0xfc,0x64,0x54,0xec,0x44,0x4c,
+/* 28664 0x6ff8 "濸" */
+0x01,0x2f,0x11,0x10,0x81,0x4e,0x43,0x12,0x13,0x22,0xe3,0x22,0x25,0x25,0x29,0x01,
+0x10,0xfe,0x10,0x40,0xb0,0x4e,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 28665 0x6ff9 "濹" */
+0x00,0x27,0x14,0x16,0x85,0x47,0x40,0x17,0x10,0x2f,0xe5,0x28,0x20,0x27,0x20,0x0f,
+0x00,0xfc,0x44,0x4c,0x54,0xfc,0x40,0xfc,0x40,0xfe,0x24,0x92,0x40,0xfc,0x40,0xfe,
+/* 28666 0x6ffa "濺" */
+0x00,0x27,0x14,0x14,0x87,0x44,0x44,0x17,0x14,0x24,0xe7,0x20,0x25,0x24,0x28,0x00,
+0x14,0x92,0x9e,0xf0,0x94,0x8a,0x96,0xe2,0x94,0x92,0x9e,0x70,0x14,0x8a,0x96,0x62,
+/* 28667 0x6ffb "濻" */
+0x00,0x27,0x15,0x15,0x85,0x46,0x45,0x15,0x15,0x25,0xe5,0x26,0x24,0x24,0x24,0x04,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,
+/* 28668 0x6ffc "濼" */
+0x04,0x44,0x28,0x2a,0x0e,0x84,0x4a,0x4e,0x12,0x20,0xef,0x20,0x21,0x22,0x2c,0x00,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 28669 0x6ffd "濽" */
+0x02,0x4f,0x22,0x2f,0x02,0x85,0x48,0x57,0x14,0x27,0xe4,0x27,0x24,0x27,0x21,0x02,
+0x08,0xbe,0x08,0xbe,0x08,0x14,0xa2,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x10,0x08,
+/* 28670 0x6ffe "濾" */
+0x00,0x20,0x10,0x17,0x84,0x45,0x44,0x15,0x15,0x25,0xe5,0x25,0x28,0x2a,0x32,0x04,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x24,0xfc,0x24,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 28671 0x6fff "濿" */
+0x00,0x27,0x14,0x17,0x84,0x45,0x45,0x15,0x15,0x25,0xe4,0x27,0x26,0x2a,0x2a,0x12,
+0x00,0xfe,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x2a,0xfa,0x0a,0x06,
+/* 28672 0x7000 "瀀" */
+0x07,0x40,0x23,0x22,0x03,0x82,0x4f,0x58,0x15,0x25,0xe8,0x21,0x23,0x25,0x20,0x0f,
+0xfc,0x80,0xf8,0x08,0xf8,0x08,0xfe,0x82,0x48,0x14,0xf4,0x00,0xf8,0x08,0xf0,0x0e,
+/* 28673 0x7001 "瀁" */
+0x02,0x21,0x17,0x10,0x83,0x40,0x47,0x11,0x13,0x26,0xeb,0x22,0x23,0x22,0x22,0x03,
+0x08,0x10,0xfc,0x40,0xf8,0x80,0xfc,0x48,0xfc,0x0a,0xf8,0x08,0xfa,0x34,0x8c,0x02,
+/* 28674 0x7002 "瀂" */
+0x01,0x43,0x24,0x2f,0x14,0x87,0x44,0x57,0x15,0x28,0xe3,0x22,0x23,0x22,0x23,0x02,
+0x00,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x24,0x92,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 28675 0x7003 "瀃" */
+0x40,0x2f,0x29,0x89,0x4f,0x49,0x09,0x2f,0x29,0x49,0xcf,0x40,0x4a,0x49,0x49,0x11,
+0x00,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x20,0x7e,0xaa,0x2a,0x4a,0x92,0x22,0x4a,0x04,
+/* 28676 0x7004 "瀄" */
+0x02,0x22,0x13,0x15,0x80,0x40,0x47,0x14,0x17,0x24,0xe7,0x24,0x25,0x26,0x24,0x00,
+0x10,0x10,0xde,0x28,0x84,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0x34,0x28,0xa0,0x20,0x20,
+/* 28677 0x7005 "瀅" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x4f,0x48,0x13,0x20,0xe0,0x23,0x20,0x20,0x2f,0x00,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0xfe,0x02,0xf8,0x40,0x40,0xf8,0x50,0x48,0xfe,0x00,
+/* 28678 0x7006 "瀆" */
+0x00,0x4f,0x20,0x27,0x00,0x87,0x44,0x57,0x12,0x23,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x40,0xfe,0x40,0xfc,0x00,0xfc,0xa4,0xfc,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 28679 0x7007 "瀇" */
+0x00,0x20,0x17,0x14,0x85,0x44,0x47,0x14,0x15,0x25,0xe5,0x25,0x29,0x28,0x31,0x02,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x04,0x02,
+/* 28680 0x7008 "瀈" */
+0x07,0x24,0x12,0x14,0x8f,0x48,0x47,0x10,0x13,0x22,0xe3,0x22,0x23,0x20,0x27,0x00,
+0xbc,0xa4,0x94,0xa4,0xfe,0x42,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,
+/* 28681 0x7009 "瀉" */
+0x00,0x4f,0x28,0x23,0x02,0x83,0x42,0x53,0x12,0x27,0xe8,0x25,0x25,0x28,0x20,0x00,
+0x40,0xfe,0x82,0x38,0x08,0xb8,0x08,0xf8,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 28682 0x700a "瀊" */
+0x01,0x23,0x12,0x13,0x82,0x47,0x42,0x13,0x12,0x24,0xe0,0x23,0x22,0x22,0x27,0x00,
+0x00,0xdc,0x54,0x66,0x40,0xdc,0x54,0x48,0x54,0xa2,0x00,0xfc,0x94,0x94,0xfe,0x00,
+/* 28683 0x700b "瀋" */
+0x00,0x47,0x24,0x28,0x07,0x82,0x41,0x57,0x12,0x24,0xeb,0x22,0x23,0x22,0x23,0x02,
+0x40,0xfc,0x04,0x38,0xc0,0x48,0x50,0xfc,0x48,0x04,0xfa,0x48,0xf8,0x48,0xf8,0x08,
+/* 28684 0x700c "瀌" */
+0x00,0x20,0x17,0x14,0x87,0x44,0x47,0x14,0x15,0x25,0xe5,0x25,0x25,0x28,0x2a,0x14,
+0x80,0x40,0xfc,0xa0,0xfc,0xa4,0xfc,0x00,0x24,0xa8,0x30,0xa4,0x1c,0x00,0xa4,0x52,
+/* 28685 0x700d "瀍" */
+0x00,0x27,0x14,0x15,0x85,0x45,0x45,0x15,0x14,0x25,0xe4,0x27,0x25,0x2a,0x28,0x13,
+0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x24,0xfa,0x20,0xfe,
+/* 28686 0x700e "瀎" */
+0x01,0x27,0x11,0x10,0x83,0x42,0x4a,0x0b,0x10,0x13,0xe2,0x23,0x22,0x22,0x24,0x08,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 28687 0x700f "瀏" */
+0x02,0x25,0x14,0x16,0x85,0x46,0x41,0x12,0x14,0x2b,0xe1,0x27,0x21,0x25,0x21,0x0e,
+0x02,0xe2,0xa2,0xaa,0x2a,0x6a,0x0a,0x8a,0x4a,0xaa,0x0a,0xca,0x22,0x42,0xea,0x04,
+/* 28688 0x7010 "瀐" */
+0x01,0x21,0x17,0x11,0x81,0x4f,0x42,0x16,0x12,0x26,0xe2,0x26,0x22,0x22,0x2f,0x00,
+0x14,0x12,0xd2,0x10,0x10,0xfe,0x90,0xd2,0x92,0xd2,0x94,0xd4,0x8a,0xca,0x16,0x22,
+/* 28689 0x7011 "瀑" */
+0x03,0x22,0x13,0x12,0x83,0x41,0x47,0x11,0x1f,0x21,0xe2,0x25,0x20,0x21,0x22,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfc,0x10,0xfe,0x10,0x48,0x54,0xe0,0x50,0x48,0xc0,
+/* 28690 0x7012 "瀒" */
+0x00,0x4f,0x22,0x25,0x08,0x81,0x42,0x4d,0x10,0x27,0xe4,0x25,0x25,0x25,0x24,0x07,
+0x40,0xfe,0x48,0x54,0xe2,0x50,0x48,0xf6,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,
+/* 28691 0x7013 "瀓" */
+0x02,0x42,0x26,0x2b,0x00,0x82,0x45,0x5c,0x15,0x24,0xe4,0x25,0x24,0x24,0x25,0x04,
+0x88,0xa8,0xa8,0xf0,0x1e,0x24,0xd4,0x14,0xd4,0x94,0x94,0xc8,0x88,0x94,0xd4,0x22,
+/* 28692 0x7014 "瀔" */
+0x02,0x9f,0x42,0x0f,0x80,0x5f,0x50,0x0f,0x20,0x4f,0xc2,0x5f,0x47,0x4a,0x52,0x02,
+0x00,0xdc,0x14,0x94,0x14,0xd4,0x66,0x80,0x1c,0x94,0x14,0xd4,0x08,0x88,0x54,0x22,
+/* 28693 0x7015 "瀕" */
+0x01,0x21,0x15,0x15,0x85,0x45,0x4f,0x10,0x11,0x25,0xe5,0x25,0x28,0x21,0x22,0x0c,
+0x00,0x3e,0x08,0xd0,0x3e,0x22,0xe2,0x3e,0x22,0x7e,0x62,0xa2,0xbe,0x00,0x14,0x22,
+/* 28694 0x7016 "瀖" */
+0x07,0x20,0x17,0x14,0x8b,0x40,0x47,0x11,0x13,0x26,0xeb,0x22,0x23,0x22,0x23,0x02,
+0xfc,0x40,0xfe,0x42,0x5c,0x40,0x5c,0x20,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 28695 0x7017 "瀗" */
+0x00,0x4f,0x28,0x27,0x00,0x83,0x40,0x57,0x10,0x27,0xe4,0x27,0x20,0x25,0x25,0x08,
+0x40,0xfe,0x42,0xfc,0x40,0xf8,0x40,0xfc,0x40,0xfc,0xa4,0xfc,0x40,0x24,0x2a,0xfa,
+/* 28696 0x7018 "瀘" */
+0x00,0x20,0x10,0x13,0x82,0x43,0x4a,0x0a,0x12,0x12,0xe2,0x22,0x22,0x25,0x25,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 28697 0x7019 "瀙" */
+0x44,0x22,0x2f,0x80,0x48,0x45,0x0f,0x22,0x22,0x4f,0xc2,0x4b,0x4a,0x52,0x4a,0x04,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xa4,0x3c,0x24,0xa4,0x3c,0x10,0x98,0xa8,0x2a,0x46,
+/* 28698 0x701a "瀚" */
+0x04,0x84,0x44,0x1f,0x84,0x5f,0x51,0x1f,0x31,0x5f,0xc4,0x5f,0x44,0x44,0x44,0x04,
+0x10,0x10,0x28,0x44,0x82,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0xaa,0x44,
+/* 28699 0x701b "瀛" */
+0x00,0xbf,0x48,0x0f,0x80,0x4f,0x48,0x0f,0x20,0x5c,0xd7,0x5d,0x55,0x5c,0x55,0x2e,
+0x80,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x80,0x9c,0xd4,0x54,0x5c,0x96,0x56,0x22,
+/* 28700 0x701c "瀜" */
+0x00,0x4f,0x20,0x27,0x05,0x85,0x47,0x50,0x1f,0x2d,0xea,0x2f,0x2a,0x2a,0x2a,0x09,
+0x08,0x88,0x08,0x08,0x3e,0x2a,0x2a,0x2a,0xaa,0xbe,0xa8,0x88,0x8a,0x8e,0xba,0x90,
+/* 28701 0x701d "瀝" */
+0x00,0x27,0x14,0x15,0x84,0x47,0x44,0x15,0x16,0x24,0xe4,0x25,0x25,0x29,0x29,0x17,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 28702 0x701e "瀞" */
+0x02,0x42,0x2f,0x22,0x0f,0x82,0x4f,0x50,0x1f,0x28,0xef,0x28,0x2f,0x28,0x2a,0x09,
+0x20,0x20,0xb8,0x48,0x90,0x7c,0x94,0x14,0xfe,0x94,0x94,0xfc,0x94,0x90,0x90,0x30,
+/* 28703 0x701f "瀟" */
+0x01,0x27,0x11,0x13,0x80,0x47,0x40,0x13,0x15,0x27,0xe4,0x27,0x24,0x27,0x25,0x09,
+0x10,0xfe,0x50,0xf8,0x48,0xfe,0x48,0xf8,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,
+/* 28704 0x7020 "瀠" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x47,0x54,0x11,0x23,0xe0,0x27,0x20,0x22,0x25,0x00,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0xfc,0x84,0x10,0xe0,0x48,0xfc,0x44,0x48,0x44,0x80,
+/* 28705 0x7021 "瀡" */
+0x00,0x4e,0x2b,0x2a,0x0a,0x8c,0x4a,0x4b,0x1a,0x2a,0xea,0x2c,0x28,0x28,0x29,0x0a,
+0x10,0x7e,0x20,0xbc,0xc8,0xbe,0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xac,0x40,0x3e,
+/* 28706 0x7022 "瀢" */
+0x00,0x49,0x25,0x21,0x00,0x83,0x4d,0x45,0x15,0x25,0xe5,0x25,0x24,0x25,0x2b,0x10,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0xfe,0x00,
+/* 28707 0x7023 "瀣" */
+0x01,0x41,0x25,0x27,0x04,0x8a,0x41,0x52,0x17,0x20,0xe3,0x20,0x27,0x20,0x2f,0x00,
+0x00,0xbc,0x24,0xa8,0x90,0xa8,0x46,0xa0,0xbc,0xa0,0xb8,0xa0,0xbc,0xa0,0xfe,0x00,
+/* 28708 0x7024 "瀤" */
+0x00,0x40,0x2f,0x20,0x07,0x84,0x47,0x52,0x11,0x22,0xe4,0x20,0x21,0x23,0x2d,0x01,
+0x80,0x40,0xfe,0x00,0xfc,0xa4,0xfc,0x48,0x50,0x08,0x44,0xa8,0x10,0x08,0x46,0x80,
+/* 28709 0x7025 "瀥" */
+0x07,0x24,0x12,0x14,0x80,0x47,0x40,0x11,0x11,0x21,0xe0,0x27,0x24,0x24,0x24,0x04,
+0xbc,0xa4,0x94,0xa4,0x40,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0xa4,0xec,
+/* 28710 0x7026 "瀦" */
+0x00,0x9f,0x42,0x04,0x8c,0x52,0x47,0x0a,0x33,0x46,0xca,0x52,0x42,0x42,0x4a,0x04,
+0x10,0x90,0x7a,0x12,0x14,0xfe,0x08,0x10,0x3c,0xe4,0xa4,0x3c,0x24,0x24,0x3c,0x24,
+/* 28711 0x7027 "瀧" */
+0x02,0x21,0x17,0x10,0x84,0x42,0x47,0x10,0x17,0x24,0xe7,0x24,0x27,0x24,0x24,0x04,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 28712 0x7028 "瀨" */
+0x01,0x21,0x17,0x11,0x81,0x47,0x45,0x15,0x17,0x21,0xe3,0x25,0x29,0x21,0x21,0x01,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 28713 0x7029 "瀩" */
+0x01,0x4e,0x22,0x3f,0x02,0x87,0x4a,0x52,0x10,0x27,0xe5,0x25,0x25,0x29,0x29,0x10,
+0x80,0x3e,0x08,0x90,0x3e,0x22,0xa2,0x7e,0x22,0x3e,0x22,0x22,0x7e,0x80,0x14,0x22,
+/* 28714 0x702a "瀪" */
+0x20,0x7f,0xaa,0x7f,0x2a,0x3f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3d,0x09,0x73,
+0x20,0x3e,0x44,0xa8,0x10,0x28,0x44,0xf0,0x10,0xf0,0x10,0xf0,0x84,0x48,0x30,0x0e,
+/* 28715 0x702b "瀫" */
+0x02,0x9f,0x42,0x0f,0x80,0x5f,0x50,0x0f,0x24,0x48,0xcf,0x42,0x5f,0x4a,0x52,0x06,
+0x00,0xdc,0x14,0x94,0x14,0xd4,0x66,0x80,0x1c,0x94,0x14,0x94,0xc8,0x88,0x54,0x22,
+/* 28716 0x702c "瀬" */
+0x42,0x22,0x2f,0x82,0x42,0x4f,0x0a,0x2a,0x2f,0x42,0xc7,0x46,0x4a,0x52,0x42,0x02,
+0x00,0x3e,0x88,0x10,0x3e,0xa2,0xa2,0xbe,0xa2,0x3e,0x22,0xa2,0xbe,0x00,0x14,0x22,
+/* 28717 0x702d "瀭" */
+0x04,0x84,0x44,0x1f,0x84,0x5f,0x55,0x1f,0x35,0x5f,0xc4,0x5f,0x44,0x44,0x44,0x04,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xe2,0xaa,0xaa,0xea,0xaa,0xaa,0xe2,0xaa,0xa4,
+/* 28718 0x702e "瀮" */
+0x07,0x40,0x2f,0x28,0x03,0x80,0x43,0x50,0x11,0x2f,0xe1,0x23,0x25,0x29,0x21,0x01,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0x10,0xbe,0x10,0xb8,0x54,0x12,0x10,0x10,
+/* 28719 0x702f "瀯" */
+0x00,0x22,0x12,0x14,0x81,0x42,0x47,0x14,0x11,0x21,0xe1,0x20,0x23,0x22,0x23,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x02,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 28720 0x7030 "瀰" */
+0x40,0x2e,0x22,0x82,0x42,0x4e,0x08,0x28,0x28,0x4e,0xc2,0x42,0x42,0x42,0x4a,0x04,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 28721 0x7031 "瀱" */
+0x40,0x2f,0x29,0x8f,0x40,0x4f,0x08,0x2a,0x28,0x49,0xca,0x48,0x4a,0x50,0x51,0x22,
+0x00,0xfe,0x12,0xfe,0x00,0xfe,0x80,0xa2,0x8a,0x4a,0x2a,0x8a,0xaa,0x82,0x4a,0x24,
+/* 28722 0x7032 "瀲" */
+0x02,0x82,0x45,0x08,0x90,0x6f,0x40,0x00,0x3d,0x55,0xd5,0x5d,0x48,0x48,0x55,0x22,
+0x08,0x08,0x08,0x90,0x5e,0xa4,0x14,0x14,0xd4,0x54,0x54,0xc8,0x88,0x94,0x54,0x22,
+/* 28723 0x7033 "瀳" */
+0x01,0x27,0x11,0x10,0x87,0x44,0x47,0x14,0x17,0x25,0xe5,0x25,0x25,0x28,0x35,0x00,
+0x10,0xfe,0x10,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x00,0xfc,0x00,0xfc,0x04,0x54,0x08,
+/* 28724 0x7034 "瀴" */
+0x07,0x24,0x17,0x14,0x87,0x44,0x47,0x13,0x14,0x20,0xef,0x21,0x23,0x20,0x21,0x06,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x18,0xa4,0x80,0xfc,0x10,0x20,0xc0,0xb0,0x08,
+/* 28725 0x7035 "瀵" */
+0x02,0x21,0x17,0x11,0x86,0x43,0x42,0x13,0x12,0x23,0xe1,0x27,0x21,0x2f,0x22,0x04,
+0x48,0x50,0xfc,0x50,0x4c,0xf8,0x48,0xf8,0x48,0xf8,0x10,0xfc,0x10,0xfe,0x08,0x04,
+/* 28726 0x7036 "瀶" */
+0x00,0x4f,0x2a,0x2a,0x0a,0x8f,0x49,0x49,0x19,0x2f,0xea,0x2a,0x2a,0x2a,0x2f,0x00,
+0x40,0x40,0x7e,0x80,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0xaa,
+/* 28727 0x7037 "瀷" */
+0x00,0x27,0x14,0x12,0x84,0x43,0x42,0x13,0x12,0x23,0xe1,0x27,0x21,0x2f,0x22,0x04,
+0x00,0xbc,0xa4,0x94,0xa4,0xf8,0x48,0xf8,0x48,0xf8,0x10,0xfc,0x10,0xfe,0x08,0x04,
+/* 28728 0x7038 "瀸" */
+0x04,0x44,0x2a,0x20,0x0f,0x82,0x4e,0x52,0x1e,0x22,0xee,0x22,0x22,0x2f,0x24,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x88,0xe8,0x8a,0xea,0x8c,0xec,0x88,0xea,0x1a,0x26,0x42,
+/* 28729 0x7039 "瀹" */
+0x40,0x20,0x21,0x82,0x4d,0x40,0x0e,0x2a,0x2e,0x40,0xcf,0x49,0x4f,0x49,0x49,0x08,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xee,0xaa,0xee,0x00,0xfe,0x22,0xfe,0x22,0x2a,0x04,
+/* 28730 0x703a "瀺" */
+0x01,0x22,0x17,0x12,0x83,0x42,0x4b,0x0a,0x11,0x12,0xe7,0x22,0x23,0x20,0x21,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 28731 0x703b "瀻" */
+0x01,0x47,0x21,0x2f,0x00,0x87,0x45,0x57,0x15,0x27,0xe2,0x27,0x22,0x2f,0x22,0x04,
+0x14,0xd2,0x10,0xfe,0x10,0xd0,0x52,0xd2,0x52,0xd4,0x94,0xc8,0x8a,0xfa,0xa6,0x42,
+/* 28732 0x703c "瀼" */
+0x00,0x27,0x10,0x13,0x82,0x43,0x41,0x17,0x11,0x27,0xe1,0x2f,0x21,0x23,0x2d,0x01,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 28733 0x703d "瀽" */
+0x00,0x27,0x14,0x13,0x80,0x43,0x40,0x17,0x11,0x23,0xe5,0x21,0x22,0x22,0x25,0x08,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0xfc,0x0a,0xf8,0x40,0x7c,0x40,0xfe,
+/* 28734 0x703e "瀾" */
+0x07,0x24,0x17,0x14,0x87,0x44,0x45,0x14,0x15,0x25,0xe5,0x25,0x25,0x24,0x25,0x04,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xf4,0x44,0xf4,0x54,0xf4,0x54,0xf4,0xe4,0x54,0x4c,
+/* 28735 0x703f "瀿" */
+0x02,0x43,0x24,0x2f,0x05,0x8f,0x45,0x57,0x11,0x22,0xe7,0x20,0x27,0x20,0x23,0x04,
+0x10,0xd0,0x1e,0xe4,0x54,0xf4,0x48,0xd4,0xb2,0x20,0xc0,0x88,0xfc,0x44,0x50,0x88,
+/* 28736 0x7040 "灀" */
+0x07,0x40,0x2f,0x28,0x03,0x80,0x43,0x50,0x12,0x2f,0xe2,0x27,0x2a,0x32,0x22,0x02,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0x7c,0xc4,0x7c,0x44,0xfc,0x44,0x7c,0x44,
+/* 28737 0x7041 "灁" */
+0x4f,0x28,0x2f,0x88,0x4f,0x48,0x09,0x29,0x29,0x49,0xc9,0x48,0x4f,0x49,0x4a,0x0c,
+0xbe,0xa2,0xbe,0xa2,0xbe,0x42,0xf2,0x12,0xf2,0x12,0xf2,0x46,0x6a,0x52,0x4a,0xc6,
+/* 28738 0x7042 "灂" */
+0x00,0x27,0x12,0x11,0x87,0x44,0x47,0x10,0x17,0x24,0xe7,0x24,0x27,0x25,0x25,0x06,
+0x3c,0xc0,0x44,0x28,0xfc,0xa4,0xfc,0x08,0x88,0xfe,0x88,0xa8,0x98,0x08,0xa8,0x90,
+/* 28739 0x7043 "灃" */
+0x01,0x23,0x15,0x17,0x85,0x47,0x45,0x17,0x10,0x27,0xe0,0x23,0x22,0x23,0x21,0x0f,
+0x50,0xf8,0x54,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x10,0xfe,
+/* 28740 0x7044 "灄" */
+0x03,0x21,0x11,0x11,0x81,0x41,0x47,0x10,0x17,0x22,0xe3,0x22,0x23,0x22,0x27,0x00,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 28741 0x7045 "灅" */
+0x07,0x44,0x27,0x24,0x07,0x80,0x4f,0x5a,0x1f,0x2a,0xef,0x20,0x20,0x27,0x20,0x0f,
+0xfc,0x44,0xfc,0x44,0xfc,0x00,0xbe,0xaa,0xbe,0xaa,0xbe,0x40,0x40,0xfc,0x40,0xfe,
+/* 28742 0x7046 "灆" */
+0x00,0x27,0x10,0x13,0x82,0x43,0x4a,0x0b,0x12,0x13,0xe0,0x23,0x22,0x22,0x27,0x00,
+0x90,0xfe,0x90,0xe8,0x88,0xce,0x50,0xd4,0xa2,0xe2,0x00,0xfc,0x94,0x94,0xfe,0x00,
+/* 28743 0x7047 "灇" */
+0x04,0x42,0x2f,0x21,0x07,0x80,0x43,0x50,0x1f,0x24,0xe7,0x24,0x27,0x24,0x2f,0x00,
+0x92,0x94,0xfe,0x10,0xfc,0x40,0xf8,0x40,0xfe,0x80,0xbc,0x94,0x94,0xc8,0x94,0xa2,
+/* 28744 0x7048 "灈" */
+0x07,0x24,0x17,0x14,0x87,0x44,0x47,0x11,0x13,0x22,0xe7,0x2a,0x23,0x22,0x23,0x02,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 28745 0x7049 "灉" */
+0x0a,0x95,0x54,0x0a,0x9f,0x51,0x5f,0x00,0x3f,0x55,0xd5,0x5f,0x50,0x50,0x4f,0x00,
+0x98,0x14,0x90,0x3e,0x28,0x68,0x3e,0x28,0x28,0x3e,0x28,0x28,0xa8,0xbe,0xa0,0x20,
+/* 28746 0x704a "灊" */
+0x0f,0x45,0x2f,0x23,0x05,0x89,0x47,0x50,0x13,0x22,0xe3,0x20,0x27,0x24,0x25,0x04,
+0xbe,0x28,0xbe,0x08,0x9a,0x26,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xf4,0x4c,
+/* 28747 0x704b "灋" */
+0x00,0x4f,0x29,0x2f,0x09,0x8f,0x49,0x4b,0x18,0x2a,0xe8,0x2b,0x28,0x2f,0x29,0x13,
+0x40,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfe,0x02,0xaa,0x44,0xf8,0x40,0xfc,0x10,0xf8,
+/* 28748 0x704c "灌" */
+0x01,0x4f,0x21,0x27,0x04,0x87,0x41,0x51,0x13,0x22,0xe7,0x2a,0x23,0x22,0x23,0x02,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 28749 0x704d "灍" */
+0x0f,0x48,0x2f,0x28,0x0f,0x8c,0x4a,0x4f,0x19,0x2d,0xef,0x29,0x29,0x2a,0x2c,0x08,
+0xbe,0xa2,0xbe,0xa2,0xbe,0x42,0x92,0xde,0x26,0x5a,0xd2,0x12,0x2a,0x46,0x0a,0x04,
+/* 28750 0x704e "灎" */
+0x05,0x9f,0x55,0x1f,0x95,0x5f,0x40,0x1f,0x20,0x4f,0xc8,0x4f,0x48,0x45,0x43,0x1c,
+0x08,0xc8,0x5c,0xc8,0x48,0xfe,0x08,0xd0,0x14,0xbe,0x80,0xbe,0xaa,0x2a,0xaa,0x7e,
+/* 28751 0x704f "灏" */
+0x40,0x2f,0x28,0x8f,0x48,0x4f,0x02,0x3f,0x20,0x4f,0xc8,0x4f,0x42,0x4a,0x52,0x06,
+0x00,0xbe,0x88,0x90,0xbe,0xa2,0x22,0xea,0x2a,0xaa,0xaa,0xaa,0x08,0x94,0x52,0x22,
+/* 28752 0x7050 "灐" */
+0x01,0x45,0x25,0x29,0x02,0x84,0x4f,0x48,0x10,0x23,0xed,0x20,0x27,0x22,0x21,0x0f,
+0x10,0x54,0xb8,0x10,0xa8,0x44,0xfe,0x42,0xa0,0x18,0xf6,0x40,0xfc,0x48,0x50,0xfe,
+/* 28753 0x7051 "灑" */
+0x0f,0x40,0x27,0x24,0x06,0x84,0x40,0x57,0x14,0x27,0xe4,0x27,0x25,0x29,0x29,0x11,
+0xbe,0x00,0xbc,0xa4,0xb4,0xa4,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x12,0xdc,0x12,0xce,
+/* 28754 0x7052 "灒" */
+0x05,0x47,0x29,0x27,0x03,0x85,0x49,0x53,0x12,0x23,0xe2,0x23,0x22,0x23,0x21,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 28755 0x7053 "灓" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x08,0x90,0x60,0x20,0x18,0x06,
+/* 28756 0x7054 "灔" */
+0x05,0x9f,0x55,0x1f,0x95,0x5f,0x40,0x1f,0x20,0x4f,0xc8,0x4f,0x48,0x45,0x43,0x1c,
+0x10,0xd0,0x5c,0xe4,0x48,0xfe,0x2a,0xea,0x2a,0xbe,0xa0,0xa0,0xa2,0x22,0xa2,0x1e,
+/* 28757 0x7055 "灕" */
+0x04,0x82,0x5f,0x05,0x92,0x55,0x50,0x1f,0x22,0x5f,0xd4,0x55,0x57,0x50,0x51,0x10,
+0x0c,0x0a,0xc8,0x1e,0x54,0x74,0x5e,0xd4,0x14,0xde,0x54,0x54,0x54,0x5e,0x50,0x90,
+/* 28758 0x7056 "灖" */
+0x00,0x27,0x14,0x17,0x84,0x45,0x46,0x14,0x14,0x27,0xe4,0x25,0x24,0x2b,0x28,0x10,
+0x20,0xfe,0x88,0xde,0x88,0xdc,0xaa,0x88,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 28759 0x7057 "灗" */
+0x08,0x88,0x48,0x3e,0x2a,0x2a,0xaa,0x6a,0x3e,0x28,0x08,0x4a,0x8e,0x3a,0x10,0x00,
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,
+/* 28760 0x7058 "灘" */
+0x45,0x25,0x2f,0x85,0x47,0x42,0x0f,0x2a,0x2f,0x42,0xcf,0x42,0x5f,0x45,0x48,0x10,
+0x18,0x14,0x90,0x3e,0x28,0x68,0xbe,0xa8,0xa8,0x3e,0xa8,0x28,0xe8,0x3e,0xa0,0x60,
+/* 28761 0x7059 "灙" */
+0x02,0x21,0x17,0x14,0x81,0x41,0x47,0x15,0x14,0x27,0xe0,0x27,0x20,0x2f,0x22,0x04,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 28762 0x705a "灚" */
+0x02,0x44,0x26,0x24,0x06,0x84,0x4f,0x4a,0x13,0x22,0xe3,0x22,0x23,0x20,0x21,0x06,
+0xac,0x44,0xac,0x44,0xac,0x04,0xfe,0x0a,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 28763 0x705b "灛" */
+0x4f,0x29,0x2f,0x89,0x4f,0x4b,0x0a,0x2b,0x29,0x49,0xc9,0x49,0x49,0x48,0x4b,0x08,
+0x1e,0x12,0x1e,0x12,0x1e,0xba,0xaa,0xba,0xf2,0x52,0xf2,0x52,0xf2,0x42,0xfa,0x46,
+/* 28764 0x705c "灜" */
+0x00,0xbf,0x48,0x0f,0x80,0x4f,0x48,0x0f,0x20,0x5d,0xd5,0x5d,0x55,0x5d,0x54,0x2d,
+0x80,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0xdc,0x54,0xd4,0x5c,0xd6,0x96,0x62,
+/* 28765 0x705d "灝" */
+0x40,0x2f,0x28,0x8f,0x48,0x4f,0x02,0x3f,0x20,0x4f,0xc8,0x4f,0x42,0x4a,0x52,0x06,
+0x00,0xbe,0x88,0x90,0xbe,0xa2,0x22,0xfe,0x22,0xbe,0xa2,0xa2,0x3e,0x80,0x54,0x22,
+/* 28766 0x705e "灞" */
+0x47,0x20,0x2f,0x88,0x43,0x45,0x0f,0x25,0x27,0x42,0xcf,0x4a,0x4f,0x42,0x5f,0x02,
+0xfc,0x40,0xfe,0x42,0x58,0x00,0xbc,0x24,0x24,0x3c,0xa4,0xa4,0xbc,0x24,0xa4,0x4c,
+/* 28767 0x705f "灟" */
+0x07,0x24,0x17,0x15,0x84,0x45,0x45,0x15,0x15,0x26,0xe5,0x25,0x29,0x28,0x33,0x00,
+0xfc,0x04,0xfc,0x24,0xa8,0x24,0xfc,0x54,0xfc,0x44,0xf4,0x54,0xf4,0x44,0xf4,0x08,
+/* 28768 0x7060 "灠" */
+0x07,0x25,0x17,0x14,0x87,0x45,0x47,0x10,0x13,0x22,0xe3,0x22,0x23,0x20,0x21,0x06,
+0x90,0x1e,0xa8,0x84,0xbe,0x2a,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 28769 0x7061 "灡" */
+0x01,0x27,0x11,0x17,0x84,0x47,0x44,0x17,0x14,0x27,0xe5,0x25,0x24,0x24,0x25,0x04,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xfc,0x54,0xf4,0x44,0xe4,0x54,0x48,
+/* 28770 0x7062 "灢" */
+0x00,0x27,0x12,0x13,0x80,0x4f,0x4a,0x13,0x11,0x27,0xe1,0x2f,0x21,0x23,0x2d,0x01,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 28771 0x7063 "灣" */
+0x44,0x28,0x2e,0x84,0x4a,0x4e,0x00,0x2a,0x20,0x47,0xc0,0x47,0x44,0x47,0x40,0x00,
+0x44,0xe8,0x0e,0xe4,0x0a,0xee,0xa0,0xea,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x38,
+/* 28772 0x7064 "灤" */
+0x44,0x24,0x2a,0x8e,0x44,0x4a,0x0e,0x20,0x2a,0x4a,0xc0,0x4f,0x41,0x42,0x4c,0x00,
+0x44,0xe4,0x0a,0xee,0x04,0xea,0x0e,0xe0,0xaa,0xea,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 28773 0x7065 "灥" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x09,0x13,0x7c,0x44,0x7c,0x44,0x7c,0x92,0x54,0xb2,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x92,0x54,0xb2,
+/* 28774 0x7066 "灦" */
+0x00,0x9f,0x50,0x1f,0x90,0x5f,0x48,0x15,0x3d,0x48,0xd5,0x5d,0x40,0x55,0x55,0x00,
+0x00,0xde,0x44,0xc8,0x5e,0xd2,0x92,0x5e,0xd2,0x9e,0x52,0xd2,0x1e,0x40,0x4c,0x12,
+/* 28775 0x7067 "灧" */
+0x42,0x2a,0x2f,0x8a,0x4f,0x4a,0x0f,0x20,0x3f,0x40,0xcf,0x48,0x4f,0x48,0x45,0x1f,
+0x10,0x90,0x9c,0xa4,0xc8,0xbe,0xaa,0x2a,0xea,0x3e,0xa0,0xa0,0xa2,0xa2,0x22,0x9e,
+/* 28776 0x7068 "灨" */
+0x04,0x9f,0x49,0x06,0x9f,0x40,0x4f,0x08,0x2f,0x48,0xcf,0x42,0x5f,0x42,0x42,0x02,
+0x10,0x9c,0x34,0x08,0xb6,0x1c,0x88,0xbe,0x80,0xbe,0xa2,0x3e,0xa2,0x3e,0x14,0x22,
+/* 28777 0x7069 "灩" */
+0x42,0x2a,0x2f,0x8a,0x4f,0x4a,0x0f,0x20,0x3f,0x40,0xcf,0x48,0x4f,0x48,0x45,0x1f,
+0x08,0x88,0x9c,0x88,0x88,0xbe,0x88,0x10,0xd4,0x3e,0x80,0xbe,0xaa,0xaa,0x2a,0xfe,
+/* 28778 0x706a "灪" */
+0x42,0x22,0x2f,0x82,0x47,0x4a,0x02,0x2f,0x29,0x54,0xc5,0x47,0x42,0x43,0x42,0x03,
+0x88,0xe8,0x5e,0xec,0x5a,0xe8,0x08,0xfe,0x42,0x94,0x58,0xf2,0x04,0xe8,0x02,0xe4,
+/* 28779 0x706b "火" */
+0x01,0x01,0x01,0x11,0x11,0x11,0x21,0x21,0x42,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x00,0x00,0x08,0x08,0x10,0x20,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 28780 0x706c "灬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x22,0x42,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x44,0x44,0x04,
+/* 28781 0x706d "灭" */
+0x00,0xff,0x01,0x01,0x11,0x11,0x11,0x21,0x42,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0xfe,0x00,0x00,0x08,0x08,0x10,0x20,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 28782 0x706e "灮" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xe0,0x04,0x04,0x04,0x04,0x08,0x10,0x20,0xc0,0x00,
+0x00,0x08,0x08,0x90,0x40,0x30,0x0e,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 28783 0x706f "灯" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 28784 0x7070 "灰" */
+0x04,0x04,0x04,0xff,0x04,0x08,0x08,0x08,0x12,0x12,0x24,0x20,0x40,0x81,0x02,0x0c,
+0x00,0x00,0x00,0xfe,0x00,0x40,0x40,0x48,0x48,0x50,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 28785 0x7071 "灱" */
+0x10,0x10,0x11,0x10,0x54,0x58,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x45,0x42,0x84,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 28786 0x7072 "灲" */
+0x08,0x08,0x08,0x09,0x49,0x4a,0x4c,0x88,0x08,0x08,0x14,0x12,0x21,0x21,0x40,0x80,
+0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x14,0x08,
+/* 28787 0x7073 "灳" */
+0x08,0x08,0x08,0x1f,0x10,0x22,0x42,0x92,0x12,0x22,0x05,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x44,0x44,0x84,0x04,0x04,0x84,0x44,0x04,0x28,0x10,
+/* 28788 0x7074 "灴" */
+0x10,0x10,0x11,0x10,0x54,0x58,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x43,0x80,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28789 0x7075 "灵" */
+0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0x3f,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28790 0x7076 "灶" */
+0x10,0x10,0x10,0x10,0x54,0x58,0x51,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x43,0x80,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28791 0x7077 "灷" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xe0,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x00,0x08,0x08,0x90,0x40,0x30,0x0e,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 28792 0x7078 "灸" */
+0x04,0x04,0x0f,0x10,0x20,0x03,0x0c,0x70,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xe0,0x40,0x80,0x60,0x18,0x04,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28793 0x7079 "灹" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x50,0x90,0x17,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 28794 0x707a "灺" */
+0x10,0x10,0x10,0x11,0x55,0x59,0x51,0x93,0x11,0x11,0x11,0x29,0x25,0x45,0x40,0x80,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 28795 0x707b "灻" */
+0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28796 0x707c "灼" */
+0x10,0x10,0x10,0x10,0x55,0x5a,0x50,0x91,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 28797 0x707d "災" */
+0x11,0x11,0x22,0x44,0x22,0x11,0x11,0x00,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x10,0x10,0x20,0x40,0x20,0x10,0x10,0x00,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28798 0x707e "灾" */
+0x02,0x01,0x7f,0x40,0x81,0x01,0x11,0x11,0x11,0x21,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x08,0x08,0x10,0x20,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 28799 0x707f "灿" */
+0x10,0x10,0x10,0x10,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x40,0x80,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 28800 0x7080 "炀" */
+0x10,0x11,0x10,0x14,0x58,0x50,0x51,0x90,0x10,0x10,0x11,0x29,0x26,0x44,0x40,0x81,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 28801 0x7081 "炁" */
+0x00,0x7f,0x02,0x42,0x42,0x7f,0x04,0x08,0x10,0x20,0xc0,0x00,0x24,0x22,0x42,0x80,
+0x00,0xf8,0x00,0x00,0x00,0xfc,0x80,0x80,0x84,0x84,0x7c,0x00,0x88,0x44,0x44,0x04,
+/* 28802 0x7082 "炂" */
+0x10,0x10,0x10,0x14,0x58,0x51,0x51,0x92,0x14,0x10,0x10,0x28,0x25,0x43,0x41,0x80,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x40,0x40,0x88,0x84,0x04,0xfe,0x02,0x00,
+/* 28803 0x7083 "炃" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 28804 0x7084 "炄" */
+0x10,0x13,0x10,0x14,0x58,0x50,0x50,0x97,0x11,0x11,0x11,0x29,0x25,0x41,0x47,0x80,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 28805 0x7085 "炅" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x08,0x10,0x80,0x40,0x20,0x18,0x06,
+/* 28806 0x7086 "炆" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x86,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 28807 0x7087 "炇" */
+0x10,0x10,0x10,0x14,0x58,0x51,0x52,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x82,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 28808 0x7088 "炈" */
+0x10,0x10,0x10,0x14,0x58,0x51,0x52,0x91,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x83,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 28809 0x7089 "炉" */
+0x10,0x10,0x10,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x26,0x42,0x44,0x88,
+0x80,0x40,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 28810 0x708a "炊" */
+0x10,0x10,0x10,0x12,0x52,0x54,0x59,0x90,0x10,0x10,0x28,0x28,0x24,0x44,0x41,0x82,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 28811 0x708b "炋" */
+0x10,0x10,0x11,0x10,0x54,0x58,0x50,0x90,0x10,0x11,0x12,0x28,0x24,0x44,0x40,0x80,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 28812 0x708c "炌" */
+0x10,0x10,0x10,0x14,0x58,0x51,0x52,0x90,0x10,0x10,0x10,0x28,0x24,0x45,0x41,0x82,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 28813 0x708d "炍" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 28814 0x708e "炎" */
+0x01,0x11,0x11,0x21,0x02,0x04,0x18,0x60,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x08,0x10,0x20,0xc0,0x30,0x08,0x04,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28815 0x708f "炏" */
+0x10,0x10,0x10,0x14,0x59,0x51,0x51,0x92,0x10,0x10,0x10,0x28,0x25,0x41,0x42,0x84,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 28816 0x7090 "炐" */
+0x10,0x10,0x10,0x11,0x54,0x58,0x50,0x91,0x10,0x10,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 28817 0x7091 "炑" */
+0x10,0x10,0x10,0x14,0x5b,0x50,0x50,0x90,0x10,0x10,0x11,0x2a,0x24,0x44,0x40,0x80,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 28818 0x7092 "炒" */
+0x10,0x10,0x10,0x10,0x54,0x58,0x51,0x91,0x12,0x10,0x10,0x28,0x24,0x44,0x40,0x83,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 28819 0x7093 "炓" */
+0x10,0x11,0x10,0x10,0x54,0x59,0x50,0x90,0x10,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 28820 0x7094 "炔" */
+0x10,0x10,0x10,0x17,0x58,0x50,0x50,0x90,0x17,0x10,0x10,0x28,0x25,0x41,0x42,0x84,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 28821 0x7095 "炕" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x46,0x42,0x84,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 28822 0x7096 "炖" */
+0x10,0x10,0x10,0x11,0x54,0x59,0x51,0x91,0x11,0x11,0x10,0x28,0x24,0x44,0x40,0x80,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 28823 0x7097 "炗" */
+0x08,0x08,0xff,0x08,0x08,0x08,0x0f,0x08,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x20,0xe0,0x20,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28824 0x7098 "炘" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 28825 0x7099 "炙" */
+0x02,0x04,0x0f,0x12,0x69,0x04,0x03,0x0c,0x71,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xf8,0x10,0x20,0xc0,0x00,0x00,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28826 0x709a "炚" */
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x20,0x20,0x20,0x24,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 28827 0x709b "炛" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xe0,0x08,0x08,0x10,0x30,0x51,0x96,0x10,0x10,0x10,
+0x00,0x08,0x08,0x90,0x40,0x30,0x0e,0x80,0x88,0x90,0xe0,0x80,0x84,0x84,0x7c,0x00,
+/* 28828 0x709c "炜" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x51,0x90,0x10,0x13,0x10,0x28,0x24,0x44,0x40,0x80,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x42,0x42,0x4a,0x44,0x40,0x40,
+/* 28829 0x709d "炝" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x54,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x40,0x80,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,0x00,
+/* 28830 0x709e "炞" */
+0x10,0x10,0x10,0x14,0x5b,0x50,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x40,0x20,0x20,0x00,0xfe,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,
+/* 28831 0x709f "炟" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x24,0x40,0x43,0x80,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 28832 0x70a0 "炠" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x28,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 28833 0x70a1 "炡" */
+0x10,0x10,0x13,0x14,0x58,0x50,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x41,0x47,0x80,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28834 0x70a2 "炢" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x90,0x10,0x10,0x11,0x2a,0x24,0x44,0x40,0x80,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 28835 0x70a3 "炣" */
+0x10,0x10,0x13,0x10,0x54,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x24,0x44,0x40,0x80,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 28836 0x70a4 "炤" */
+0x10,0x13,0x10,0x10,0x54,0x59,0x51,0x92,0x14,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 28837 0x70a5 "炥" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x53,0x92,0x12,0x13,0x10,0x28,0x25,0x45,0x42,0x84,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 28838 0x70a6 "炦" */
+0x10,0x10,0x10,0x14,0x5b,0x50,0x50,0x90,0x11,0x11,0x11,0x29,0x26,0x42,0x44,0x81,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 28839 0x70a7 "炧" */
+0x10,0x10,0x10,0x15,0x5a,0x51,0x51,0x91,0x13,0x11,0x11,0x29,0x25,0x45,0x40,0x80,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 28840 0x70a8 "炨" */
+0x10,0x10,0x10,0x15,0x59,0x52,0x50,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 28841 0x70a9 "炩" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x54,0x90,0x13,0x10,0x10,0x29,0x24,0x44,0x40,0x80,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 28842 0x70aa "炪" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x90,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 28843 0x70ab "炫" */
+0x10,0x10,0x10,0x15,0x58,0x50,0x50,0x90,0x11,0x10,0x10,0x28,0x24,0x45,0x40,0x80,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 28844 0x70ac "炬" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 28845 0x70ad "炭" */
+0x01,0x21,0x21,0x3f,0x08,0x08,0xff,0x10,0x10,0x14,0x24,0x29,0x41,0x82,0x0c,0x30,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfe,0x80,0x88,0x88,0x90,0x40,0x40,0x20,0x18,0x06,
+/* 28846 0x70ae "炮" */
+0x10,0x10,0x11,0x15,0x5a,0x55,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x40,0x80,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 28847 0x70af "炯" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfe,0x02,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x04,
+/* 28848 0x70b0 "炰" */
+0x08,0x08,0x1f,0x20,0x5f,0x10,0x10,0x1f,0x10,0x10,0x10,0x0f,0x00,0x48,0x44,0x84,
+0x00,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x50,0x24,0x04,0xfc,0x00,0x88,0x44,0x44,
+/* 28849 0x70b1 "炱" */
+0x02,0x04,0x08,0x10,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0x00,0x20,0x10,0xf8,0x08,0xf0,0x10,0x10,0xf0,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 28850 0x70b2 "炲" */
+0x10,0x10,0x10,0x10,0x55,0x5b,0x50,0x90,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 28851 0x70b3 "炳" */
+0x10,0x13,0x10,0x14,0x58,0x53,0x52,0x92,0x12,0x12,0x12,0x2b,0x26,0x42,0x42,0x82,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 28852 0x70b4 "炴" */
+0x10,0x10,0x10,0x11,0x55,0x59,0x51,0x91,0x11,0x13,0x10,0x28,0x24,0x44,0x41,0x82,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 28853 0x70b5 "炵" */
+0x10,0x10,0x10,0x10,0x55,0x5a,0x50,0x90,0x10,0x13,0x10,0x28,0x24,0x44,0x40,0x80,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 28854 0x70b6 "炶" */
+0x10,0x10,0x10,0x10,0x54,0x58,0x50,0x90,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 28855 0x70b7 "炷" */
+0x10,0x10,0x10,0x15,0x58,0x50,0x50,0x90,0x11,0x10,0x10,0x28,0x24,0x40,0x43,0x80,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28856 0x70b8 "炸" */
+0x11,0x11,0x11,0x15,0x5a,0x52,0x54,0x90,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 28857 0x70b9 "点" */
+0x02,0x02,0x02,0x03,0x02,0x02,0x3f,0x20,0x20,0x20,0x3f,0x00,0x24,0x22,0x42,0x80,
+0x00,0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x88,0x44,0x44,0x04,
+/* 28858 0x70ba "為" */
+0x02,0x12,0x0a,0x7f,0x04,0x04,0x0f,0x08,0x10,0x1f,0x20,0x2a,0x4a,0x90,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x20,0x40,0xf8,0x08,0x10,0xfc,0x04,0xa4,0xa4,0x04,0x28,0x10,
+/* 28859 0x70bb "炻" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x50,0x90,0x11,0x12,0x14,0x28,0x24,0x44,0x40,0x80,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 28860 0x70bc "炼" */
+0x10,0x10,0x17,0x10,0x54,0x5b,0x51,0x92,0x13,0x10,0x11,0x29,0x26,0x44,0x40,0x80,
+0x40,0x40,0xfc,0x80,0x80,0xe0,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 28861 0x70bd "炽" */
+0x10,0x10,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x28,0x24,0x45,0x42,0x84,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 28862 0x70be "炾" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x90,0x10,0x10,0x10,0x28,0x24,0x45,0x42,0x84,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 28863 0x70bf "炿" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x17,0x11,0x29,0x25,0x41,0x42,0x84,
+0x20,0x40,0xf8,0x08,0x08,0x48,0x28,0x28,0x08,0xfe,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 28864 0x70c0 "烀" */
+0x10,0x10,0x13,0x10,0x55,0x58,0x50,0x90,0x13,0x10,0x10,0x28,0x24,0x44,0x40,0x80,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 28865 0x70c1 "烁" */
+0x10,0x10,0x11,0x11,0x55,0x59,0x51,0x91,0x10,0x10,0x10,0x28,0x25,0x46,0x40,0x80,
+0x08,0x1c,0xe0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 28866 0x70c2 "烂" */
+0x10,0x11,0x10,0x14,0x58,0x53,0x50,0x90,0x10,0x11,0x10,0x28,0x24,0x40,0x43,0x80,
+0x00,0x08,0x88,0x90,0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 28867 0x70c3 "烃" */
+0x10,0x11,0x10,0x10,0x54,0x58,0x50,0x93,0x10,0x11,0x10,0x28,0x24,0x44,0x43,0x80,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28868 0x70c4 "烄" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x51,0x92,0x10,0x10,0x10,0x28,0x24,0x44,0x40,0x83,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 28869 0x70c5 "烅" */
+0x10,0x10,0x10,0x14,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x41,0x43,0x80,
+0x20,0x20,0x40,0x80,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 28870 0x70c6 "烆" */
+0x10,0x10,0x11,0x12,0x54,0x58,0x51,0x93,0x15,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 28871 0x70c7 "烇" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x51,0x90,0x10,0x10,0x11,0x28,0x24,0x44,0x43,0x80,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 28872 0x70c8 "烈" */
+0x00,0x7f,0x08,0x08,0x1f,0x21,0x51,0x0a,0x04,0x08,0x30,0xc0,0x24,0x22,0x42,0x80,
+0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,0x00,0x88,0x44,0x44,0x04,
+/* 28873 0x70c9 "烉" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x20,0x22,0x24,0x28,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x88,0x48,0x28,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 28874 0x70ca "烊" */
+0x11,0x10,0x10,0x14,0x5b,0x50,0x50,0x91,0x10,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 28875 0x70cb "烋" */
+0x08,0x08,0x10,0x37,0x50,0x91,0x11,0x12,0x14,0x18,0x10,0x00,0x24,0x22,0x42,0x80,
+0x40,0x40,0x40,0xfc,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x00,0x88,0x44,0x44,0x04,
+/* 28876 0x70cc "烌" */
+0x10,0x10,0x10,0x15,0x59,0x53,0x55,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 28877 0x70cd "烍" */
+0x10,0x11,0x11,0x11,0x55,0x5a,0x50,0x93,0x10,0x10,0x10,0x28,0x25,0x45,0x42,0x84,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 28878 0x70ce "烎" */
+0x00,0x3f,0x08,0x08,0xff,0x08,0x10,0x20,0x41,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28879 0x70cf "烏" */
+0x02,0x04,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x09,0x24,0x24,0x40,0x00,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x00,0xfc,0x04,0x24,0x94,0x94,0x28,0x10,
+/* 28880 0x70d0 "烐" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x93,0x11,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x20,0x40,0xf8,0x08,0x48,0x28,0x28,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 28881 0x70d1 "烑" */
+0x10,0x10,0x10,0x14,0x5a,0x50,0x50,0x91,0x12,0x14,0x10,0x28,0x25,0x41,0x42,0x84,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 28882 0x70d2 "烒" */
+0x10,0x10,0x10,0x14,0x5b,0x50,0x50,0x93,0x11,0x11,0x11,0x29,0x25,0x47,0x42,0x80,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xa0,0x20,0x10,0x10,0x10,0xca,0x0a,0x06,0x02,
+/* 28883 0x70d3 "烓" */
+0x10,0x10,0x11,0x14,0x58,0x50,0x53,0x90,0x10,0x10,0x11,0x28,0x24,0x40,0x43,0x80,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 28884 0x70d4 "烔" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 28885 0x70d5 "烕" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x2f,0x22,0x22,0x2a,0x32,0x25,0x24,0x48,0x50,0x80,
+0x28,0x24,0x20,0xfe,0x20,0x20,0xa4,0x24,0x64,0xa8,0x28,0x10,0x92,0xaa,0x46,0x82,
+/* 28886 0x70d6 "烖" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x29,0x29,0x2a,0x48,0x14,0x12,0x22,0x40,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 28887 0x70d7 "烗" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x50,0x91,0x10,0x10,0x10,0x2b,0x24,0x44,0x40,0x83,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 28888 0x70d8 "烘" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x90,0x10,0x13,0x10,0x28,0x24,0x45,0x42,0x84,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 28889 0x70d9 "烙" */
+0x10,0x10,0x10,0x15,0x5b,0x54,0x50,0x90,0x11,0x12,0x15,0x29,0x25,0x45,0x41,0x81,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 28890 0x70da "烚" */
+0x10,0x10,0x10,0x10,0x55,0x5a,0x51,0x90,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 28891 0x70db "烛" */
+0x10,0x10,0x10,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x28,0x24,0x45,0x40,0x80,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x82,0x00,
+/* 28892 0x70dc "烜" */
+0x10,0x13,0x10,0x14,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x24,0x40,0x43,0x80,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 28893 0x70dd "烝" */
+0x00,0x1f,0x00,0x00,0x7d,0x05,0x09,0x11,0x21,0x45,0x82,0x1f,0x00,0x48,0x44,0x84,
+0x00,0xe0,0x40,0x80,0x04,0x88,0x50,0x20,0x18,0x06,0x00,0xf0,0x00,0x88,0x44,0x44,
+/* 28894 0x70de "烞" */
+0x10,0x10,0x10,0x14,0x5b,0x50,0x51,0x91,0x12,0x12,0x14,0x28,0x24,0x44,0x40,0x80,
+0x88,0x88,0x88,0x88,0xe8,0x88,0x8c,0xca,0xaa,0x88,0x88,0x88,0x88,0x88,0x88,0x88,
+/* 28895 0x70df "烟" */
+0x10,0x13,0x12,0x16,0x5a,0x52,0x53,0x92,0x12,0x12,0x12,0x2a,0x27,0x42,0x43,0x82,
+0x00,0xfe,0x02,0x22,0x22,0x22,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0xfe,0x02,
+/* 28896 0x70e0 "烠" */
+0x10,0x10,0x17,0x10,0x55,0x59,0x53,0x95,0x19,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 28897 0x70e1 "烡" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xe4,0x04,0x3f,0x04,0x04,0xff,0x00,0x08,0x10,0x20,
+0x00,0x08,0x08,0x90,0x40,0x30,0x4e,0x40,0xf8,0x40,0x40,0xfe,0x00,0x20,0x10,0x08,
+/* 28898 0x70e2 "烢" */
+0x10,0x10,0x13,0x12,0x54,0x58,0x53,0x90,0x10,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x02,0x00,0x38,0xc0,0x40,0x40,0x7c,0xc0,0x40,0x42,0x42,0x3e,0x00,
+/* 28899 0x70e3 "烣" */
+0x10,0x10,0x10,0x13,0x54,0x58,0x50,0x91,0x11,0x11,0x12,0x2a,0x24,0x44,0x40,0x81,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x90,0x12,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 28900 0x70e4 "烤" */
+0x10,0x10,0x11,0x10,0x54,0x5b,0x50,0x90,0x11,0x12,0x14,0x28,0x24,0x44,0x40,0x80,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 28901 0x70e5 "烥" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 28902 0x70e6 "烦" */
+0x10,0x13,0x10,0x10,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x24,0x44,0x41,0x82,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x04,
+/* 28903 0x70e7 "烧" */
+0x20,0x20,0x20,0x23,0xa8,0xb0,0xa0,0xa3,0x20,0x27,0x20,0x20,0x51,0x49,0x42,0x84,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 28904 0x70e8 "烨" */
+0x10,0x10,0x11,0x15,0x5b,0x55,0x51,0x91,0x11,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 28905 0x70e9 "烩" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x50,0x90,0x10,0x13,0x10,0x28,0x24,0x41,0x43,0x81,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 28906 0x70ea "烪" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x90,0x13,0x10,0x10,0x28,0x24,0x44,0x41,0x82,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 28907 0x70eb "烫" */
+0x23,0x10,0x80,0x43,0x11,0x21,0xe2,0x24,0x29,0x20,0x01,0x11,0x22,0x04,0x18,0xe0,
+0xf0,0x20,0xc0,0xfc,0x24,0x24,0x44,0x84,0x28,0x10,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 28908 0x70ec "烬" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x12,0x14,0x28,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0x08,0x04,0x62,0x10,0x00,0xe0,0x18,0x04,0x00,
+/* 28909 0x70ed "热" */
+0x10,0x10,0x10,0xfd,0x10,0x10,0x1c,0x30,0xd0,0x10,0x51,0x22,0x00,0x48,0x44,0x84,
+0x40,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0x00,0x88,0x44,0x44,
+/* 28910 0x70ee "烮" */
+0x7f,0x08,0x10,0x3f,0x51,0x0a,0x04,0x08,0x30,0xc1,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x84,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 28911 0x70ef "烯" */
+0x11,0x10,0x10,0x14,0x5b,0x50,0x53,0x90,0x11,0x13,0x15,0x29,0x25,0x41,0x40,0x80,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 28912 0x70f0 "烰" */
+0x10,0x10,0x11,0x10,0x55,0x58,0x50,0x91,0x10,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 28913 0x70f1 "烱" */
+0x10,0x13,0x12,0x16,0x5a,0x53,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xfe,0x02,0x52,0x8a,0x06,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 28914 0x70f2 "烲" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 28915 0x70f3 "烳" */
+0x10,0x10,0x13,0x10,0x54,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 28916 0x70f4 "烴" */
+0x10,0x11,0x10,0x14,0x59,0x52,0x51,0x90,0x10,0x11,0x10,0x28,0x24,0x44,0x43,0x80,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28917 0x70f5 "烵" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x50,0x91,0x12,0x14,0x10,0x28,0x24,0x44,0x40,0x80,
+0x88,0x88,0xfe,0x88,0x00,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x28,0x10,
+/* 28918 0x70f6 "烶" */
+0x10,0x10,0x13,0x14,0x58,0x51,0x51,0x93,0x10,0x12,0x12,0x29,0x25,0x42,0x44,0x88,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 28919 0x70f7 "烷" */
+0x10,0x10,0x13,0x16,0x5c,0x51,0x50,0x90,0x13,0x10,0x10,0x28,0x25,0x41,0x42,0x84,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 28920 0x70f8 "烸" */
+0x10,0x10,0x10,0x15,0x5a,0x50,0x50,0x90,0x13,0x10,0x11,0x29,0x25,0x44,0x40,0x80,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 28921 0x70f9 "烹" */
+0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x00,0x01,0x01,0x05,0x02,0x48,0x44,0x84,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf0,0x60,0x80,0x00,0x00,0x00,0x88,0x44,0x44,
+/* 28922 0x70fa "烺" */
+0x10,0x10,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 28923 0x70fb "烻" */
+0x10,0x10,0x13,0x14,0x58,0x51,0x51,0x93,0x10,0x12,0x12,0x29,0x25,0x42,0x44,0x88,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 28924 0x70fc "烼" */
+0x10,0x13,0x10,0x14,0x59,0x52,0x50,0x90,0x11,0x12,0x10,0x28,0x25,0x42,0x40,0x80,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0x28,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 28925 0x70fd "烽" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x93,0x10,0x10,0x10,0x28,0x27,0x44,0x40,0x80,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 28926 0x70fe "烾" */
+0x01,0x09,0x09,0x12,0x04,0x19,0x69,0x09,0x12,0x04,0x18,0x61,0x1f,0x01,0x01,0x7f,
+0x00,0x10,0x20,0xc0,0x30,0x08,0x14,0x10,0xa0,0x40,0x30,0x0c,0xf0,0x00,0x00,0xfc,
+/* 28927 0x70ff "烿" */
+0x10,0x13,0x12,0x16,0x5b,0x52,0x52,0x92,0x1f,0x12,0x12,0x2a,0x26,0x42,0x44,0x88,
+0x02,0xc2,0x44,0x48,0x50,0xc2,0x42,0x44,0xe8,0x50,0x42,0x42,0x44,0x48,0x50,0xe0,
+/* 28928 0x7100 "焀" */
+0x10,0x10,0x10,0x10,0x55,0x58,0x50,0x90,0x11,0x12,0x10,0x28,0x24,0x44,0x40,0x80,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 28929 0x7101 "焁" */
+0x00,0x00,0x78,0x49,0x4a,0x48,0x78,0x03,0x0c,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xb0,0x0c,0x02,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 28930 0x7102 "焂" */
+0x10,0x10,0x24,0x64,0xa5,0x24,0x24,0x20,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x88,0x50,0x20,0x50,0x88,0x04,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28931 0x7103 "焃" */
+0x10,0x10,0x11,0x10,0x54,0x58,0x53,0x90,0x10,0x11,0x11,0x2a,0x24,0x44,0x41,0x82,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x48,0x48,0x4c,0x4a,0x4a,0x88,0x88,0x28,0x10,
+/* 28932 0x7104 "焄" */
+0x00,0x3f,0x04,0xff,0x04,0x3f,0x08,0x1f,0x28,0x48,0x8f,0x08,0x00,0x48,0x44,0x84,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,0x00,0x88,0x44,0x44,
+/* 28933 0x7105 "焅" */
+0x10,0x11,0x11,0x11,0x55,0x5a,0x50,0x93,0x10,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 28934 0x7106 "焆" */
+0x10,0x10,0x10,0x10,0x54,0x58,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 28935 0x7107 "焇" */
+0x10,0x11,0x10,0x10,0x54,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 28936 0x7108 "焈" */
+0x10,0x08,0x3e,0x22,0x22,0x3e,0x22,0x20,0x41,0x91,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x7c,0x44,0x44,0x7c,0x40,0x42,0x42,0x3e,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28937 0x7109 "焉" */
+0x00,0x7f,0x01,0x11,0x11,0x11,0xff,0x08,0x0f,0x10,0x1f,0x00,0x29,0x24,0x40,0x00,
+0x00,0xfc,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf8,0x00,0xfc,0x04,0x24,0x94,0x28,0x10,
+/* 28938 0x710a "焊" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x50,0x90,0x11,0x10,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 28939 0x710b "焋" */
+0x24,0x24,0x24,0x3d,0x04,0xfc,0x24,0x24,0x44,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xf8,0x00,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 28940 0x710c "焌" */
+0x10,0x10,0x10,0x15,0x5b,0x50,0x50,0x91,0x12,0x10,0x11,0x2a,0x24,0x40,0x41,0x86,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 28941 0x710d "焍" */
+0x11,0x10,0x10,0x15,0x58,0x50,0x51,0x91,0x11,0x11,0x10,0x28,0x25,0x42,0x44,0x80,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 28942 0x710e "焎" */
+0x10,0x10,0x11,0xfd,0x11,0x11,0x1d,0xf1,0x11,0x12,0x52,0x24,0x00,0x48,0x44,0x84,
+0x00,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x88,0x44,0x44,
+/* 28943 0x710f "焏" */
+0x00,0x3f,0x00,0x00,0x01,0x79,0x49,0x49,0x49,0x79,0x01,0x05,0x02,0x48,0x44,0x84,
+0x00,0xf0,0x20,0x40,0x80,0x3c,0x44,0x28,0x10,0x28,0x44,0x00,0x00,0x88,0x44,0x44,
+/* 28944 0x7110 "焐" */
+0x10,0x13,0x10,0x10,0x55,0x58,0x50,0x93,0x10,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 28945 0x7111 "焑" */
+0x10,0x13,0x12,0x16,0x5a,0x53,0x52,0x92,0x12,0x12,0x13,0x2a,0x26,0x42,0x43,0x82,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 28946 0x7112 "焒" */
+0x10,0x10,0x10,0x10,0x54,0x58,0x50,0x90,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfe,0x02,
+/* 28947 0x7113 "焓" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x50,0x90,0x10,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 28948 0x7114 "焔" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0x40,0x7c,0x84,0x08,0x10,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,
+/* 28949 0x7115 "焕" */
+0x10,0x10,0x10,0x15,0x5a,0x55,0x51,0x91,0x11,0x11,0x13,0x28,0x24,0x44,0x41,0x86,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 28950 0x7116 "焖" */
+0x11,0x10,0x12,0x16,0x5a,0x52,0x52,0x92,0x12,0x13,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xbe,0x82,0x02,0x22,0x12,0x52,0x42,0xca,0x56,0x52,0x32,0x02,0x02,0x0a,0x04,
+/* 28951 0x7117 "焗" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x26,0x42,0x44,0x80,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 28952 0x7118 "焘" */
+0x02,0x02,0x7f,0x02,0x3f,0x04,0xff,0x08,0x1f,0x20,0x44,0x82,0x02,0x00,0x24,0x42,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xfc,0x20,0x20,0x20,0xa0,0x40,0x88,0x44,
+/* 28953 0x7119 "焙" */
+0x10,0x10,0x11,0x10,0x55,0x58,0x50,0x93,0x10,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 28954 0x711a "焚" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x09,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0x20,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28955 0x711b "焛" */
+0x7c,0x44,0x7c,0x44,0x7d,0x41,0x41,0x49,0x49,0x49,0x51,0x42,0x42,0x44,0x48,0x50,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x24,0x24,0x44,0x84,0x44,0x24,0x24,0x04,0x0c,
+/* 28956 0x711c "焜" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 28957 0x711d "焝" */
+0x10,0x13,0x12,0x13,0x56,0x5a,0x53,0x92,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28958 0x711e "焞" */
+0x10,0x10,0x13,0x10,0x55,0x59,0x51,0x90,0x11,0x10,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 28959 0x711f "焟" */
+0x10,0x10,0x10,0x17,0x58,0x50,0x57,0x90,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28960 0x7120 "焠" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x51,0x92,0x10,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 28961 0x7121 "無" */
+0x10,0x10,0x1f,0x2a,0x4a,0x0a,0x7f,0x0a,0x0a,0x0a,0x7f,0x00,0x24,0x22,0x42,0x80,
+0x00,0x00,0xfc,0xa0,0xa0,0xa0,0xfc,0xa0,0xa0,0xa0,0xfc,0x00,0x88,0x44,0x44,0x04,
+/* 28962 0x7122 "焢" */
+0x10,0x10,0x10,0x15,0x59,0x52,0x50,0x91,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x80,
+0x20,0x10,0x10,0xfe,0x02,0x54,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 28963 0x7123 "焣" */
+0x00,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2f,0xf2,0x42,0x02,0x00,0x48,0x44,0x84,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,0x00,0x88,0x44,0x44,
+/* 28964 0x7124 "焤" */
+0x01,0x00,0x3f,0x22,0x22,0x25,0x2c,0x34,0x44,0x44,0x85,0x11,0x22,0x04,0x18,0xe0,
+0x00,0x80,0xfe,0x10,0x10,0xfe,0x90,0x50,0x10,0x50,0x20,0x10,0xa0,0x40,0x30,0x0e,
+/* 28965 0x7125 "焥" */
+0x10,0x10,0x13,0x12,0x55,0x59,0x51,0x92,0x12,0x13,0x14,0x28,0x25,0x45,0x42,0x84,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 28966 0x7126 "焦" */
+0x09,0x08,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x1f,0x10,0x48,0x44,0x84,
+0x00,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,0x88,0x44,0x44,
+/* 28967 0x7127 "焧" */
+0x10,0x10,0x11,0x15,0x5a,0x54,0x51,0x93,0x10,0x10,0x10,0x2a,0x26,0x42,0x44,0x80,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 28968 0x7128 "焨" */
+0x10,0x13,0x12,0x12,0x56,0x5a,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x04,0xf4,0x04,0xf4,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 28969 0x7129 "焩" */
+0x10,0x13,0x12,0x16,0x5a,0x53,0x52,0x92,0x12,0x13,0x12,0x2a,0x26,0x42,0x45,0x88,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 28970 0x712a "焪" */
+0x10,0x10,0x13,0x12,0x54,0x59,0x52,0x91,0x10,0x11,0x11,0x29,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x02,0x88,0x04,0x02,0xfc,0x04,0xfc,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 28971 0x712b "焫" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x54,0x4c,0x84,0x04,0x04,0x14,0x08,
+/* 28972 0x712c "焬" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x10,0x11,0x12,0x28,0x25,0x42,0x40,0x81,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x54,0x94,0x24,0x44,0x94,0x08,
+/* 28973 0x712d "焭" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x80,0x0f,0x08,0x08,0x08,0x10,0x20,0xc0,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 28974 0x712e "焮" */
+0x20,0x20,0x27,0x24,0xac,0xb4,0xa7,0xa5,0x25,0x25,0x25,0x25,0x55,0x49,0x49,0x90,
+0x10,0x90,0x10,0x3e,0x22,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 28975 0x712f "焯" */
+0x10,0x10,0x10,0x14,0x59,0x51,0x51,0x91,0x11,0x11,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 28976 0x7130 "焰" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 28977 0x7131 "焱" */
+0x01,0x11,0x11,0x22,0x04,0x18,0xe0,0x08,0x0a,0x2a,0x2c,0x48,0x14,0x22,0x42,0x80,
+0x00,0x08,0x08,0x90,0x40,0x30,0x0e,0x10,0x10,0x54,0x54,0x98,0x10,0x28,0x44,0x82,
+/* 28978 0x7132 "焲" */
+0x20,0x20,0x27,0x21,0xa9,0xb2,0xa2,0xa6,0x22,0x23,0x22,0x22,0x52,0x4a,0x42,0x83,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 28979 0x7133 "焳" */
+0x10,0x10,0x10,0x15,0x59,0x53,0x55,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 28980 0x7134 "焴" */
+0x10,0x10,0x13,0x10,0x55,0x5b,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 28981 0x7135 "焵" */
+0x10,0x13,0x12,0x16,0x5a,0x53,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 28982 0x7136 "然" */
+0x10,0x10,0x1e,0x22,0x33,0x4a,0xa4,0x14,0x08,0x10,0x21,0x42,0x00,0x48,0x44,0x84,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,0x00,0x88,0x44,0x44,
+/* 28983 0x7137 "焷" */
+0x10,0x10,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x10,0x11,0x2b,0x24,0x44,0x40,0x80,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 28984 0x7138 "焸" */
+0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 28985 0x7139 "焹" */
+0x10,0x13,0x12,0x16,0x5a,0x53,0x52,0x92,0x13,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 28986 0x713a "焺" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x50,0x90,0x11,0x10,0x10,0x2b,0x24,0x44,0x41,0x82,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x28,0xc8,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 28987 0x713b "焻" */
+0x11,0x11,0x11,0x15,0x59,0x51,0x51,0x90,0x13,0x12,0x12,0x2b,0x26,0x42,0x43,0x82,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 28988 0x713c "焼" */
+0x10,0x10,0x11,0x10,0x54,0x58,0x53,0x90,0x10,0x13,0x10,0x28,0x25,0x45,0x42,0x84,
+0x20,0x20,0xfc,0x20,0xa8,0x88,0xfe,0x88,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 28989 0x713d "焽" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x02,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x14,0x08,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 28990 0x713e "焾" */
+0x10,0x10,0x10,0x14,0x59,0x52,0x51,0x90,0x10,0x10,0x10,0x2a,0x26,0x42,0x44,0x80,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 28991 0x713f "焿" */
+0x10,0x10,0x13,0x16,0x5a,0x52,0x52,0x93,0x12,0x12,0x12,0x2a,0x26,0x44,0x44,0x89,
+0x40,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x20,0x50,0x50,0x88,0x06,
+/* 28992 0x7140 "煀" */
+0x10,0x13,0x12,0x16,0x5b,0x52,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x44,0x44,0x88,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 28993 0x7141 "煁" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x50,0x90,0x10,0x13,0x11,0x29,0x25,0x45,0x41,0x80,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 28994 0x7142 "煂" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x51,0x91,0x11,0x11,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 28995 0x7143 "煃" */
+0x10,0x10,0x13,0x10,0x54,0x5b,0x51,0x90,0x10,0x13,0x10,0x28,0x25,0x44,0x40,0x83,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 28996 0x7144 "煄" */
+0x10,0x10,0x11,0x14,0x5b,0x50,0x51,0x91,0x11,0x11,0x11,0x28,0x25,0x44,0x43,0x80,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 28997 0x7145 "煅" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x27,0x45,0x41,0x81,
+0x20,0xdc,0x14,0x14,0x14,0xd4,0x26,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 28998 0x7146 "煆" */
+0x10,0x13,0x12,0x16,0x5a,0x53,0x52,0x92,0x13,0x12,0x12,0x2b,0x26,0x42,0x42,0x82,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 28999 0x7147 "煇" */
+0x10,0x13,0x12,0x10,0x55,0x58,0x51,0x91,0x11,0x11,0x11,0x28,0x27,0x44,0x40,0x80,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29000 0x7148 "煈" */
+0x20,0x27,0x24,0x24,0xad,0xb4,0xa5,0xa5,0x25,0x25,0x24,0x24,0x55,0x4c,0x48,0x90,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 29001 0x7149 "煉" */
+0x10,0x10,0x13,0x10,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x28,0x24,0x45,0x42,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 29002 0x714a "煊" */
+0x10,0x10,0x13,0x12,0x54,0x59,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x44,0x43,0x80,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 29003 0x714b "煋" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x50,0x91,0x11,0x12,0x10,0x29,0x24,0x40,0x43,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29004 0x714c "煌" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x90,0x13,0x10,0x10,0x29,0x24,0x40,0x43,0x80,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29005 0x714d "煍" */
+0x20,0x21,0x27,0x21,0xa9,0xb1,0xa7,0xa1,0x23,0x23,0x25,0x25,0x59,0x49,0x41,0x81,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 29006 0x714e "煎" */
+0x10,0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2a,0x24,0x00,0x48,0x44,0x84,
+0x10,0x20,0xfe,0x00,0x48,0x48,0x48,0x48,0x08,0x08,0x28,0x10,0x00,0x88,0x44,0x44,
+/* 29007 0x714f "煏" */
+0x10,0x13,0x10,0x15,0x59,0x51,0x51,0x90,0x13,0x12,0x12,0x2b,0x26,0x42,0x43,0x82,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 29008 0x7150 "煐" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x51,0x91,0x11,0x11,0x13,0x28,0x24,0x44,0x41,0x82,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 29009 0x7151 "煑" */
+0x01,0x1f,0x01,0x7f,0x02,0x0f,0x38,0xcf,0x08,0x0f,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x08,0xd0,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 29010 0x7152 "煒" */
+0x20,0x20,0x21,0x20,0xab,0xb0,0xa1,0xa1,0x21,0x20,0x23,0x20,0x52,0x4b,0x40,0x80,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 29011 0x7153 "煓" */
+0x10,0x11,0x11,0x11,0x55,0x58,0x53,0x90,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 29012 0x7154 "煔" */
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x10,0x52,0x54,0x90,0x28,0x24,0x42,0x80,
+0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 29013 0x7155 "煕" */
+0x00,0x7f,0x44,0x54,0x57,0x51,0x51,0x57,0x54,0x44,0x7f,0x00,0x24,0x22,0x42,0x80,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,0x88,0x44,0x44,0x04,
+/* 29014 0x7156 "煖" */
+0x10,0x13,0x10,0x15,0x58,0x51,0x50,0x90,0x13,0x10,0x10,0x29,0x25,0x42,0x40,0x81,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 29015 0x7157 "煗" */
+0x10,0x13,0x10,0x10,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x2b,0x24,0x44,0x41,0x82,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 29016 0x7158 "煘" */
+0x20,0x20,0x20,0x27,0xac,0xb4,0xa5,0xa4,0x24,0x25,0x25,0x25,0x55,0x4c,0x48,0x90,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 29017 0x7159 "煙" */
+0x10,0x13,0x10,0x14,0x5b,0x52,0x52,0x92,0x13,0x10,0x10,0x2b,0x24,0x40,0x47,0x80,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0x52,0xfe,0x20,0x20,0xfe,0x20,0x20,0xfe,0x00,
+/* 29018 0x715a "煚" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xfe,0x80,0xfc,0x84,0xfc,0x80,0xfe,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 29019 0x715b "煛" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 29020 0x715c "煜" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x90,0x10,0x13,0x10,0x29,0x24,0x40,0x47,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x40,0x20,0xfe,0x00,0x04,0x88,0x00,0xfe,0x00,
+/* 29021 0x715d "煝" */
+0x10,0x13,0x12,0x16,0x5b,0x52,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x44,0x88,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 29022 0x715e "煞" */
+0x20,0x20,0x3c,0x44,0x88,0x7f,0x02,0x02,0x7e,0x02,0x02,0xfe,0x00,0x48,0x44,0x84,
+0x20,0x20,0x40,0x7e,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,0x88,0x44,0x44,
+/* 29023 0x715f "煟" */
+0x10,0x13,0x12,0x13,0x56,0x5b,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 29024 0x7160 "煠" */
+0x10,0x11,0x11,0x17,0x59,0x51,0x51,0x91,0x11,0x10,0x13,0x28,0x24,0x41,0x46,0x80,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29025 0x7161 "煡" */
+0x20,0x20,0x20,0x27,0xa9,0xb1,0xa2,0xa2,0x27,0x21,0x21,0x25,0x52,0x4b,0x44,0x88,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 29026 0x7162 "煢" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x80,0x1f,0x04,0x04,0x3f,0x04,0x04,0x04,0x04,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xe0,0x20,0x20,0xa0,0x20,0x14,0x0c,0x04,
+/* 29027 0x7163 "煣" */
+0x10,0x11,0x10,0x14,0x5b,0x50,0x50,0x91,0x12,0x10,0x13,0x28,0x24,0x41,0x46,0x80,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29028 0x7164 "煤" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x50,0x90,0x10,0x10,0x13,0x28,0x24,0x45,0x42,0x80,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29029 0x7165 "煥" */
+0x20,0x20,0x20,0x21,0xaa,0xb5,0xa1,0xa1,0x21,0x21,0x20,0x23,0x50,0x48,0x41,0x86,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0x54,0x8c,0x24,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 29030 0x7166 "煦" */
+0x01,0x79,0x49,0x4a,0x4c,0x79,0x49,0x49,0x49,0x48,0x78,0x00,0x24,0x22,0x42,0x80,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,0x88,0x44,0x44,0x04,
+/* 29031 0x7167 "照" */
+0x00,0x7d,0x44,0x44,0x44,0x44,0x7d,0x44,0x44,0x44,0x44,0x7c,0x00,0x48,0x44,0x84,
+0x00,0xfc,0x44,0x44,0x44,0x94,0x08,0xfc,0x84,0x84,0x84,0xfc,0x00,0x88,0x44,0x44,
+/* 29032 0x7168 "煨" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x10,0x13,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 29033 0x7169 "煩" */
+0x10,0x13,0x10,0x14,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x44,0x40,0x81,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 29034 0x716a "煪" */
+0x11,0x10,0x10,0x17,0x58,0x50,0x53,0x92,0x12,0x13,0x12,0x2b,0x26,0x42,0x43,0x82,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29035 0x716b "煫" */
+0x21,0x20,0x20,0x2b,0xb0,0xa1,0xa2,0xa4,0x21,0x22,0x24,0x21,0x52,0x4c,0x48,0x80,
+0x08,0x90,0x00,0xfe,0x80,0x84,0x44,0xa8,0x30,0x70,0xa8,0x28,0x24,0x22,0xa0,0x40,
+/* 29036 0x716c "煬" */
+0x20,0x23,0x22,0x2b,0xb2,0xa3,0xa0,0xa7,0x22,0x23,0x24,0x29,0x52,0x4c,0x49,0x82,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 29037 0x716d "煭" */
+0x24,0x49,0x24,0x00,0x7f,0x08,0x1f,0x61,0x12,0x0c,0x30,0xc0,0x00,0x48,0x44,0x84,
+0x84,0x04,0xa4,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x14,0x08,0x00,0x88,0x44,0x44,
+/* 29038 0x716e "煮" */
+0x02,0x02,0x3f,0x02,0xff,0x01,0x0f,0x38,0xcf,0x08,0x08,0x0f,0x00,0x48,0x44,0x84,
+0x00,0x08,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0x10,0xf0,0x00,0x88,0x44,0x44,
+/* 29039 0x716f "煯" */
+0x11,0x11,0x11,0x11,0x55,0x59,0x51,0x90,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29040 0x7170 "煰" */
+0x10,0x10,0x10,0x14,0x58,0x50,0x50,0x90,0x10,0x13,0x12,0x2a,0x26,0x42,0x43,0x82,
+0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,0x00,0xde,0x52,0x52,0x52,0x52,0xde,0x52,
+/* 29041 0x7171 "煱" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x93,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 29042 0x7172 "煲" */
+0x08,0x0b,0x12,0x33,0x50,0x97,0x11,0x12,0x14,0x10,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x00,0xf8,0x08,0xf8,0x40,0xfc,0x50,0x48,0x44,0x40,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 29043 0x7173 "煳" */
+0x11,0x11,0x11,0x17,0x59,0x51,0x51,0x93,0x12,0x12,0x12,0x2a,0x27,0x44,0x40,0x80,
+0x00,0x3c,0x24,0xa4,0x24,0x3c,0x24,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0x44,0x54,0x88,
+/* 29044 0x7174 "煴" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x10,0x13,0x12,0x2a,0x26,0x42,0x47,0x80,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 29045 0x7175 "煵" */
+0x10,0x10,0x13,0x14,0x58,0x53,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 29046 0x7176 "煶" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x10,0x13,0x10,0x29,0x25,0x41,0x42,0x84,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 29047 0x7177 "煷" */
+0x20,0x20,0x27,0x20,0xab,0xb2,0xa3,0xa0,0x27,0x24,0x29,0x21,0x51,0x4a,0x44,0x88,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf4,0x10,0x10,0x12,0x12,0x0e,
+/* 29048 0x7178 "煸" */
+0x10,0x10,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x12,0x2a,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 29049 0x7179 "煹" */
+0x10,0x10,0x13,0x14,0x59,0x50,0x53,0x90,0x11,0x11,0x11,0x29,0x27,0x41,0x41,0x81,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 29050 0x717a "煺" */
+0x20,0x24,0x22,0x22,0xa8,0xb0,0xae,0xa2,0x22,0x22,0x22,0x22,0x52,0x4a,0x45,0x88,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0xa2,0x94,0x88,0xa8,0xc4,0x84,0x00,0xfe,
+/* 29051 0x717b "煻" */
+0x10,0x10,0x13,0x16,0x5a,0x52,0x53,0x92,0x12,0x12,0x12,0x2a,0x26,0x44,0x44,0x88,
+0x20,0x10,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 29052 0x717c "煼" */
+0x20,0x20,0x21,0x2a,0xb1,0xa1,0xa0,0xa1,0x22,0x21,0x22,0x25,0x51,0x48,0x49,0x82,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 29053 0x717d "煽" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x66,
+/* 29054 0x717e "煾" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x10,0x28,0x24,0x42,0x42,0x84,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x54,0x8c,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,
+/* 29055 0x717f "煿" */
+0x10,0x10,0x13,0x10,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x2b,0x24,0x44,0x40,0x80,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 29056 0x7180 "熀" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x50,0x91,0x10,0x10,0x13,0x28,0x24,0x45,0x42,0x84,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 29057 0x7181 "熁" */
+0x10,0x11,0x10,0x10,0x55,0x5b,0x51,0x91,0x12,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x40,0xfc,0x44,0x94,0x08,0xde,0x4a,0x4a,0x94,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 29058 0x7182 "熂" */
+0x21,0x21,0x21,0x2a,0xb5,0xa0,0xa3,0xa0,0x22,0x21,0x27,0x20,0x51,0x4e,0x48,0x80,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 29059 0x7183 "熃" */
+0x00,0x7e,0x15,0x08,0xfe,0x1a,0x2c,0x48,0xa8,0x11,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x40,0xfc,0x44,0x38,0x44,0xa2,0xfc,0x44,0x94,0x08,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 29060 0x7184 "熄" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x10,0x10,0x28,0x26,0x42,0x44,0x80,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 29061 0x7185 "熅" */
+0x10,0x13,0x12,0x12,0x57,0x5a,0x53,0x90,0x10,0x17,0x14,0x2c,0x24,0x44,0x4f,0x80,
+0x00,0xf8,0x48,0xa8,0x18,0x08,0xf8,0x00,0x00,0xfc,0xa4,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 29062 0x7186 "熆" */
+0x10,0x10,0x11,0x14,0x58,0x53,0x50,0x91,0x13,0x10,0x13,0x2a,0x26,0x42,0x47,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 29063 0x7187 "熇" */
+0x10,0x10,0x13,0x14,0x59,0x51,0x51,0x90,0x13,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 29064 0x7188 "熈" */
+0x00,0x2f,0x2a,0x2a,0x2f,0x28,0x28,0x2f,0x2a,0x4a,0x4f,0x80,0x24,0x22,0x42,0x80,
+0x00,0xbc,0x24,0x24,0xa4,0xbc,0xa0,0xa0,0x22,0x22,0x9e,0x00,0x88,0x44,0x44,0x04,
+/* 29065 0x7189 "熉" */
+0x10,0x10,0x10,0x10,0x54,0x58,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x44,0x40,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0xfe,0x02,0xfe,0x02,0xfe,0x48,0x84,0x02,
+/* 29066 0x718a "熊" */
+0x10,0x24,0x42,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,0x00,0x48,0x44,0x84,
+0x80,0x98,0xe0,0x84,0x84,0x7c,0x80,0x98,0xe0,0x84,0x84,0x7c,0x00,0x88,0x44,0x44,
+/* 29067 0x718b "熋" */
+0x10,0x24,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,0x01,0x11,0x22,0x0c,0x70,
+0x80,0x98,0xe0,0x84,0x7c,0x00,0x98,0xe0,0x84,0x84,0x7c,0x00,0x10,0xa0,0x60,0x1c,
+/* 29068 0x718c "熌" */
+0x10,0x13,0x12,0x17,0x5a,0x53,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x0a,0x04,
+/* 29069 0x718d "熍" */
+0x10,0x10,0x11,0x11,0x54,0x58,0x50,0x90,0x10,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x10,0xfe,0x02,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0x02,0xfe,0x02,
+/* 29070 0x718e "熎" */
+0x10,0x10,0x13,0x10,0x56,0x59,0x51,0x92,0x10,0x13,0x10,0x29,0x25,0x45,0x41,0x80,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 29071 0x718f "熏" */
+0x00,0x3f,0x01,0xff,0x01,0x3f,0x29,0x25,0x3f,0x01,0x3f,0x01,0xff,0x48,0x44,0x84,
+0xf8,0x00,0x00,0xfe,0x00,0xf8,0x28,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x88,0x44,0x44,
+/* 29072 0x7190 "熐" */
+0x10,0x13,0x12,0x10,0x55,0x59,0x51,0x91,0x11,0x10,0x10,0x2b,0x24,0x44,0x41,0x82,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 29073 0x7191 "熑" */
+0x10,0x10,0x10,0x15,0x58,0x51,0x50,0x93,0x10,0x11,0x10,0x28,0x25,0x42,0x40,0x80,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 29074 0x7192 "熒" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x81,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 29075 0x7193 "熓" */
+0x20,0x21,0x23,0x22,0xaa,0xb3,0xa2,0xa3,0x22,0x23,0x20,0x25,0x55,0x48,0x40,0x80,
+0x80,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x04,0x54,0x54,0x04,0x28,0x10,
+/* 29076 0x7194 "熔" */
+0x10,0x10,0x13,0x16,0x58,0x50,0x51,0x90,0x10,0x11,0x12,0x28,0x24,0x44,0x40,0x80,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 29077 0x7195 "熕" */
+0x10,0x11,0x10,0x14,0x5b,0x50,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x44,0x41,0x82,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 29078 0x7196 "熖" */
+0x10,0x11,0x10,0x11,0x54,0x58,0x50,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 29079 0x7197 "熗" */
+0x20,0x20,0x20,0x29,0xb2,0xa7,0xaa,0xa3,0x22,0x23,0x22,0x23,0x55,0x4d,0x49,0x81,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 29080 0x7198 "熘" */
+0x10,0x13,0x12,0x16,0x5a,0x52,0x53,0x90,0x13,0x12,0x12,0x2b,0x26,0x42,0x43,0x82,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 29081 0x7199 "熙" */
+0x00,0x7f,0x44,0x44,0x5f,0x51,0x51,0x5f,0x44,0x44,0x7f,0x00,0x24,0x22,0x42,0x80,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x40,0x40,0x42,0x42,0xbe,0x00,0x88,0x44,0x44,0x04,
+/* 29082 0x719a "熚" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x50,0x90,0x13,0x10,0x10,0x29,0x24,0x43,0x40,0x80,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 29083 0x719b "熛" */
+0x10,0x13,0x10,0x11,0x55,0x59,0x51,0x90,0x11,0x10,0x13,0x28,0x24,0x45,0x42,0x80,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 29084 0x719c "熜" */
+0x10,0x10,0x11,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x10,0x28,0x25,0x45,0x41,0x82,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 29085 0x719d "熝" */
+0x10,0x10,0x13,0x12,0x56,0x5b,0x52,0x92,0x13,0x12,0x12,0x2a,0x26,0x44,0x44,0x88,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 29086 0x719e "熞" */
+0x10,0x13,0x12,0x17,0x5a,0x53,0x52,0x92,0x13,0x10,0x10,0x29,0x24,0x40,0x43,0x80,
+0x00,0xdc,0x94,0xd4,0x54,0xc8,0x88,0x94,0xe2,0x00,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29087 0x719f "熟" */
+0x10,0xfe,0x00,0x7d,0x44,0x7c,0x00,0x7c,0x08,0xfe,0x11,0x52,0x20,0x48,0x44,0x84,
+0x40,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0x00,0x88,0x44,0x44,
+/* 29088 0x71a0 "熠" */
+0x10,0x13,0x10,0x12,0x55,0x5a,0x50,0x90,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29089 0x71a1 "熡" */
+0x20,0x23,0x22,0x2f,0xaa,0xb3,0xa0,0xa3,0x22,0x23,0x20,0x2f,0x51,0x48,0x43,0x8c,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x48,0xf8,0x80,0xfe,0x10,0xe0,0x18,0x04,
+/* 29090 0x71a2 "熢" */
+0x10,0x14,0x12,0x15,0x58,0x50,0x56,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x45,0x88,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 29091 0x71a3 "熣" */
+0x10,0x12,0x13,0x10,0x54,0x59,0x53,0x95,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 29092 0x71a4 "熤" */
+0x10,0x13,0x10,0x11,0x54,0x59,0x52,0x90,0x10,0x10,0x11,0x28,0x25,0x44,0x40,0x83,
+0x00,0xde,0x42,0x4a,0xc6,0x4a,0x52,0x02,0x40,0x20,0xfc,0x00,0x08,0x88,0x90,0xfe,
+/* 29093 0x71a5 "熥" */
+0x20,0x24,0x22,0x22,0xa8,0xb0,0xae,0xa2,0x22,0x22,0x22,0x22,0x52,0x4d,0x48,0x80,
+0xfe,0x04,0x28,0x10,0xfe,0x92,0x92,0xfe,0x92,0xfe,0x92,0x92,0x96,0x00,0xfe,0x00,
+/* 29094 0x71a6 "熦" */
+0x10,0x11,0x11,0x15,0x5a,0x50,0x51,0x97,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x20,0x24,0x22,0x2a,0x32,0x60,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29095 0x71a7 "熧" */
+0x11,0x21,0xca,0x14,0x32,0xd2,0x15,0x14,0x08,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x10,0x10,0xa8,0x44,0x40,0x7c,0x40,0xfe,0x00,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 29096 0x71a8 "熨" */
+0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2c,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x08,0x08,0x7e,0x08,0x48,0x28,0xa8,0x08,0x28,0x90,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 29097 0x71a9 "熩" */
+0x10,0x10,0x13,0x16,0x5b,0x52,0x52,0x92,0x12,0x12,0x13,0x2b,0x25,0x45,0x49,0x80,
+0x40,0x20,0xfc,0x04,0xfc,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x02,0x02,0xfe,
+/* 29098 0x71aa "熪" */
+0x20,0x21,0x26,0x22,0xaa,0xb2,0xaf,0xa2,0x22,0x27,0x2a,0x22,0x52,0x4a,0x42,0x82,
+0x10,0x90,0x1e,0x22,0x54,0x08,0x90,0x64,0x08,0x1e,0xa2,0x42,0x14,0x08,0x10,0x60,
+/* 29099 0x71ab "熫" */
+0x10,0x10,0x13,0x12,0x56,0x5a,0x53,0x92,0x12,0x12,0x12,0x2a,0x25,0x45,0x4a,0x90,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 29100 0x71ac "熬" */
+0x08,0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x80,0x24,0x22,0x42,0x80,
+0x20,0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0x00,0x88,0x44,0x44,0x04,
+/* 29101 0x71ad "熭" */
+0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x3f,0x00,0x1f,0x00,0x3f,0x11,0x22,0x0c,0x70,
+0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x10,0xa0,0x60,0x1c,
+/* 29102 0x71ae "熮" */
+0x20,0x27,0x20,0x24,0xaa,0xb4,0xa0,0xa1,0x26,0x20,0x23,0x20,0x53,0x48,0x40,0x87,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 29103 0x71af "熯" */
+0x10,0x10,0x13,0x10,0x54,0x58,0x51,0x91,0x11,0x10,0x11,0x28,0x27,0x44,0x40,0x83,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,
+/* 29104 0x71b0 "熰" */
+0x10,0x13,0x12,0x16,0x5a,0x52,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x43,0x80,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 29105 0x71b1 "熱" */
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x92,0x7c,0x10,0x1c,0xe1,0x42,0x00,0x48,0x44,0x84,
+0x40,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0x00,0x88,0x44,0x44,
+/* 29106 0x71b2 "熲" */
+0x40,0x44,0x78,0x42,0x42,0x3e,0x00,0x10,0x52,0x52,0x54,0x90,0x28,0x24,0x44,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 29107 0x71b3 "熳" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x50,0x93,0x12,0x13,0x10,0x29,0x24,0x44,0x41,0x86,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 29108 0x71b4 "熴" */
+0x20,0x24,0x24,0x27,0xa8,0xb7,0xa4,0xa7,0x24,0x27,0x20,0x24,0x57,0x4c,0x45,0x86,
+0x40,0x44,0x44,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x24,0xa8,0x32,0xa2,0x1e,
+/* 29109 0x71b5 "熵" */
+0x10,0x10,0x13,0x14,0x58,0x53,0x52,0x92,0x13,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x52,0x8a,0x06,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 29110 0x71b6 "熶" */
+0x20,0x23,0x22,0x23,0xaa,0xb3,0xa0,0xaf,0x24,0x27,0x24,0x27,0x54,0x4f,0x40,0x80,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x80,0xbc,0x94,0x94,0xd4,0x88,0x94,0xa2,
+/* 29111 0x71b7 "熷" */
+0x11,0x10,0x10,0x13,0x56,0x5a,0x52,0x92,0x13,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 29112 0x71b8 "熸" */
+0x20,0x27,0x21,0x25,0xaf,0xb3,0xa5,0xa9,0x20,0x23,0x22,0x22,0x53,0x4a,0x42,0x83,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 29113 0x71b9 "熹" */
+0x01,0x7f,0x01,0x3f,0x00,0x3f,0x20,0x3f,0x08,0xff,0x00,0x3f,0x20,0x3f,0x24,0x42,
+0x00,0xfc,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x88,0x44,
+/* 29114 0x71ba "熺" */
+0x10,0x13,0x10,0x11,0x54,0x59,0x51,0x91,0x10,0x13,0x10,0x29,0x25,0x45,0x41,0x81,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 29115 0x71bb "熻" */
+0x20,0x20,0x21,0x2e,0xb0,0xa3,0xa2,0xa3,0x20,0x27,0x20,0x24,0x52,0x4c,0x4a,0x81,
+0x40,0xa0,0x18,0xe6,0x00,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,
+/* 29116 0x71bc "熼" */
+0x20,0x27,0x24,0x27,0xac,0xb7,0xa1,0xa1,0x27,0x21,0x21,0x2f,0x50,0x49,0x42,0x84,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0x10,0x08,0x04,
+/* 29117 0x71bd "熽" */
+0x10,0x11,0x10,0x17,0x58,0x51,0x50,0x92,0x13,0x12,0x13,0x2a,0x27,0x42,0x42,0x84,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 29118 0x71be "熾" */
+0x11,0x10,0x13,0x14,0x5a,0x51,0x57,0x90,0x13,0x12,0x12,0x2b,0x26,0x42,0x43,0x80,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 29119 0x71bf "熿" */
+0x10,0x10,0x11,0x10,0x54,0x5b,0x50,0x91,0x11,0x11,0x11,0x29,0x24,0x44,0x41,0x82,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 29120 0x71c0 "燀" */
+0x10,0x13,0x12,0x12,0x57,0x58,0x51,0x91,0x11,0x11,0x11,0x28,0x27,0x44,0x40,0x80,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29121 0x71c1 "燁" */
+0x10,0x13,0x10,0x10,0x55,0x58,0x50,0x93,0x10,0x10,0x11,0x28,0x27,0x44,0x40,0x80,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29122 0x71c2 "燂" */
+0x10,0x13,0x10,0x13,0x56,0x5b,0x50,0x91,0x11,0x11,0x11,0x29,0x24,0x47,0x40,0x80,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 29123 0x71c3 "燃" */
+0x11,0x11,0x11,0x16,0x5a,0x55,0x50,0x92,0x11,0x11,0x12,0x2c,0x24,0x42,0x42,0x84,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 29124 0x71c4 "燄" */
+0x10,0x10,0x3e,0x22,0x44,0x80,0x10,0x66,0x42,0x42,0x66,0x42,0x42,0x7e,0x42,0x00,
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x52,0x54,0x98,0x10,0x28,0x28,0x44,0x82,
+/* 29125 0x71c5 "燅" */
+0x08,0x08,0x7e,0x08,0x08,0xff,0x24,0x42,0x89,0x08,0x7e,0x08,0x08,0x0f,0xf8,0x40,
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x52,0x54,0x98,0x10,0x28,0x28,0x44,0x82,
+/* 29126 0x71c6 "燆" */
+0x10,0x11,0x10,0x17,0x58,0x51,0x52,0x94,0x10,0x10,0x13,0x2a,0x26,0x42,0x42,0x82,
+0x1c,0xe0,0x40,0xfe,0x88,0x04,0xfa,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x06,
+/* 29127 0x71c7 "燇" */
+0x10,0x10,0x13,0x10,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x2b,0x25,0x44,0x40,0x80,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 29128 0x71c8 "燈" */
+0x20,0x27,0x20,0x2a,0xb1,0xa2,0xa5,0xa8,0x23,0x22,0x22,0x23,0x52,0x49,0x4f,0x80,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 29129 0x71c9 "燉" */
+0x22,0x21,0x27,0x20,0xaf,0xb4,0xa7,0xa0,0x27,0x20,0x21,0x21,0x57,0x49,0x45,0x82,
+0x08,0x08,0xc8,0x10,0x9e,0x94,0xa4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 29130 0x71ca "燊" */
+0x11,0x21,0x02,0x0c,0x70,0x00,0x52,0x94,0x28,0xc4,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x08,0x10,0xe0,0x18,0x04,0x10,0x52,0x94,0x28,0xc4,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 29131 0x71cb "燋" */
+0x10,0x10,0x11,0x15,0x5b,0x55,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 29132 0x71cc "燌" */
+0x10,0x11,0x10,0x14,0x5b,0x50,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x44,0x41,0x82,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 29133 0x71cd "燍" */
+0x22,0x22,0x22,0x27,0xaa,0xb3,0xa2,0xa3,0x22,0x22,0x27,0x20,0x52,0x4c,0x48,0x80,
+0x40,0x42,0x5c,0xf0,0x50,0xd0,0x5e,0xd4,0x54,0x54,0xf4,0x14,0x94,0x64,0x24,0x44,
+/* 29134 0x71ce "燎" */
+0x20,0x20,0x27,0x20,0xad,0xb2,0xa7,0xaa,0x23,0x22,0x23,0x20,0x52,0x4c,0x49,0x80,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 29135 0x71cf "燏" */
+0x10,0x13,0x10,0x14,0x5b,0x50,0x50,0x93,0x10,0x13,0x12,0x2a,0x27,0x42,0x42,0x82,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 29136 0x71d0 "燐" */
+0x20,0x22,0x21,0x27,0xa9,0xb2,0xa4,0xa2,0x23,0x24,0x2a,0x21,0x51,0x4a,0x42,0x84,
+0x40,0x48,0x50,0xfc,0x50,0x48,0x44,0x10,0x90,0xbc,0x90,0x50,0x7e,0x10,0x10,0x10,
+/* 29137 0x71d1 "燑" */
+0x10,0x11,0x10,0x14,0x5b,0x50,0x51,0x91,0x11,0x11,0x11,0x28,0x25,0x44,0x43,0x80,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29138 0x71d2 "燒" */
+0x10,0x10,0x11,0x14,0x5b,0x51,0x53,0x91,0x11,0x16,0x10,0x2b,0x24,0x44,0x41,0x82,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 29139 0x71d3 "燓" */
+0x24,0x22,0xf9,0x22,0x64,0x72,0xa9,0x22,0x24,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x48,0x88,0x3e,0x88,0x58,0x9c,0x2a,0x88,0x48,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 29140 0x71d4 "燔" */
+0x10,0x13,0x11,0x10,0x55,0x58,0x51,0x92,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 29141 0x71d5 "燕" */
+0x04,0xff,0x04,0x04,0x17,0x10,0xf0,0x17,0x14,0x34,0xd7,0x10,0x00,0x48,0x44,0x84,
+0x40,0xfe,0x40,0x40,0xd0,0x12,0x1c,0xd0,0x50,0x52,0xd2,0x0e,0x00,0x88,0x44,0x44,
+/* 29142 0x71d6 "燖" */
+0x10,0x13,0x10,0x13,0x54,0x5b,0x50,0x93,0x11,0x17,0x10,0x2b,0x25,0x44,0x40,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 29143 0x71d7 "燗" */
+0x27,0x24,0x27,0x24,0xaf,0xb4,0xa4,0xa4,0x24,0x24,0x24,0x24,0x54,0x4d,0x44,0x84,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 29144 0x71d8 "燘" */
+0x10,0x13,0x12,0x17,0x5a,0x53,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0x00,0xde,0x52,0xde,0x52,0xde,0x42,0x22,0xfa,0x12,0x52,0x22,0x52,0x82,0x0a,0x04,
+/* 29145 0x71d9 "燙" */
+0x23,0x12,0x93,0x42,0x43,0x10,0x2f,0xe2,0x27,0x29,0x22,0x05,0x11,0x22,0x0c,0x70,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x24,0x54,0x88,0x10,0xa0,0x60,0x1c,
+/* 29146 0x71da "燚" */
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x10,0x52,0x54,0x90,0x28,0x24,0x42,0x80,
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x52,0x54,0x98,0x10,0x28,0x28,0x44,0x82,
+/* 29147 0x71db "燛" */
+0x00,0xfe,0x12,0x7e,0x42,0x7e,0x12,0xfe,0x01,0x11,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x00,0xfe,0x90,0xfc,0x84,0xfc,0x90,0xfe,0x00,0x10,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 29148 0x71dc "燜" */
+0x20,0x27,0x24,0x27,0xac,0xb7,0xa4,0xa4,0x24,0x25,0x25,0x25,0x56,0x4c,0x44,0x84,
+0x00,0x9e,0x92,0x9e,0x92,0x9e,0x42,0x22,0x0a,0x46,0x42,0x52,0x32,0x02,0x0a,0x04,
+/* 29149 0x71dd "燝" */
+0x10,0x11,0x11,0x15,0x59,0x51,0x50,0x93,0x10,0x11,0x11,0x29,0x24,0x45,0x42,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 29150 0x71de "燞" */
+0x14,0x12,0x3f,0x24,0x64,0xbf,0x24,0x3f,0x24,0x24,0x3f,0x20,0x00,0x48,0x44,0x84,
+0x20,0x20,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,0x00,0x88,0x44,0x44,
+/* 29151 0x71df "營" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x9f,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 29152 0x71e0 "燠" */
+0x20,0x21,0x27,0x24,0xad,0xb4,0xa7,0xa4,0x25,0x24,0x20,0x27,0x50,0x49,0x42,0x8c,
+0x80,0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x04,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 29153 0x71e1 "燡" */
+0x10,0x13,0x12,0x13,0x54,0x59,0x50,0x93,0x10,0x10,0x11,0x28,0x27,0x44,0x40,0x80,
+0x00,0xfe,0x52,0xfe,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29154 0x71e2 "燢" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x41,0x91,0x11,0x22,0x04,0x08,0x30,0xc0,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0x14,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 29155 0x71e3 "燣" */
+0x10,0x13,0x10,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x10,0x28,0x24,0x47,0x40,0x83,
+0x20,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x08,0xf0,0x20,0xfe,0xa8,0x26,
+/* 29156 0x71e4 "燤" */
+0x10,0x10,0x13,0x14,0x59,0x51,0x51,0x91,0x11,0x10,0x13,0x2a,0x26,0x42,0x42,0x82,
+0x88,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 29157 0x71e5 "燥" */
+0x10,0x10,0x10,0x14,0x58,0x51,0x51,0x91,0x11,0x10,0x13,0x28,0x24,0x41,0x42,0x80,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29158 0x71e6 "燦" */
+0x20,0x20,0x22,0x2b,0xb4,0xaa,0xa3,0xac,0x22,0x21,0x27,0x20,0x51,0x4a,0x4c,0x80,
+0x80,0xdc,0x84,0xd4,0x48,0x94,0x24,0x40,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 29159 0x71e7 "燧" */
+0x10,0x12,0x11,0x14,0x58,0x50,0x53,0x91,0x11,0x11,0x11,0x29,0x25,0x41,0x42,0x84,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 29160 0x71e8 "燨" */
+0x22,0x21,0x2f,0x28,0xb7,0xa0,0xaf,0xa0,0x27,0x21,0x2f,0x21,0x51,0x4f,0x49,0x83,
+0x08,0x10,0xfe,0x40,0xfc,0x40,0xfe,0x54,0x92,0x10,0xfe,0x10,0xd4,0x0a,0x16,0x22,
+/* 29161 0x71e9 "燩" */
+0x21,0x22,0x27,0x24,0xaf,0xb4,0xa7,0xa2,0x21,0x27,0x22,0x23,0x52,0x4c,0x45,0x88,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 29162 0x71ea "燪" */
+0x10,0x13,0x10,0x15,0x5b,0x55,0x50,0x93,0x10,0x10,0x13,0x28,0x24,0x42,0x42,0x84,
+0x88,0xfe,0x88,0x00,0xfc,0x54,0xd4,0x24,0x54,0x94,0x48,0x20,0xa4,0x8a,0x8a,0x78,
+/* 29163 0x71eb "燫" */
+0x10,0x13,0x12,0x12,0x57,0x5a,0x52,0x92,0x13,0x12,0x12,0x2a,0x26,0x45,0x46,0x88,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 29164 0x71ec "燬" */
+0x21,0x26,0x24,0x24,0xae,0xb4,0xa4,0xa7,0x20,0x20,0x27,0x21,0x51,0x49,0x47,0x82,
+0x00,0xdc,0x54,0x54,0xd4,0x54,0x66,0xc0,0x1c,0x14,0xd4,0x14,0x08,0xc8,0x14,0x22,
+/* 29165 0x71ed "燭" */
+0x20,0x23,0x22,0x2a,0xb3,0xa1,0xa3,0xa4,0x23,0x22,0x22,0x23,0x50,0x4f,0x48,0x80,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xfc,0x84,0xe4,0xa4,0xa4,0xe4,0x94,0xf4,0x14,0x08,
+/* 29166 0x71ee "燮" */
+0x21,0x27,0x20,0x6b,0xb0,0x23,0x20,0x53,0x4a,0x8b,0x00,0x3f,0x08,0x04,0x07,0xf8,
+0x08,0xc8,0x08,0x9a,0x2c,0x88,0x08,0x94,0x92,0xa2,0x00,0xf0,0x20,0xc0,0x80,0x7e,
+/* 29167 0x71ef "燯" */
+0x10,0x11,0x10,0x13,0x56,0x59,0x50,0x91,0x10,0x10,0x13,0x28,0x24,0x44,0x40,0x80,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x50,0xc8,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 29168 0x71f0 "燰" */
+0x20,0x23,0x20,0x22,0xa9,0xb7,0xa4,0xa2,0x22,0x24,0x20,0x20,0x51,0x4a,0x40,0x87,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 29169 0x71f1 "燱" */
+0x10,0x10,0x11,0x14,0x58,0x53,0x50,0x91,0x11,0x11,0x11,0x29,0x24,0x42,0x42,0x84,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 29170 0x71f2 "燲" */
+0x10,0x13,0x10,0x10,0x55,0x5b,0x51,0x92,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x40,0xfc,0x44,0x94,0x08,0xde,0x4a,0xd6,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,
+/* 29171 0x71f3 "燳" */
+0x20,0x27,0x24,0x24,0xac,0xb7,0xa4,0xa4,0x24,0x24,0x27,0x24,0x50,0x4a,0x42,0x84,
+0x00,0xbe,0x92,0x92,0xaa,0xa4,0xc0,0xbe,0xa2,0xa2,0xbe,0xa2,0x00,0xa4,0x52,0x52,
+/* 29172 0x71f4 "燴" */
+0x20,0x20,0x23,0x2d,0xb0,0xa7,0xa5,0xa4,0x27,0x20,0x23,0x22,0x53,0x4a,0x4b,0x82,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 29173 0x71f5 "燵" */
+0x10,0x14,0x12,0x14,0x58,0x50,0x56,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x45,0x88,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 29174 0x71f6 "燶" */
+0x10,0x13,0x12,0x17,0x5a,0x53,0x50,0x93,0x12,0x12,0x12,0x2b,0x25,0x45,0x45,0x89,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 29175 0x71f7 "燷" */
+0x10,0x13,0x10,0x15,0x59,0x51,0x51,0x91,0x11,0x11,0x10,0x29,0x24,0x43,0x41,0x82,
+0x20,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x00,0xfc,0x00,0xfe,0x24,0x62,
+/* 29176 0x71f8 "燸" */
+0x10,0x11,0x10,0x13,0x56,0x59,0x50,0x91,0x10,0x13,0x10,0x29,0x25,0x45,0x41,0x81,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 29177 0x71f9 "燹" */
+0xfe,0x20,0x50,0x9a,0x2c,0x48,0x9c,0x2a,0xc8,0x18,0x01,0x11,0x22,0x04,0x18,0xe0,
+0xfe,0x20,0x50,0x9a,0x2c,0x48,0x9c,0x2a,0xc8,0x18,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 29178 0x71fa "燺" */
+0x10,0x13,0x10,0x14,0x58,0x50,0x50,0x93,0x12,0x12,0x12,0x2a,0x24,0x43,0x40,0x83,
+0x20,0xfe,0x00,0xf8,0x88,0xf8,0x00,0xfe,0x02,0x72,0x52,0x76,0x20,0xfe,0xa8,0x26,
+/* 29179 0x71fb "燻" */
+0x10,0x11,0x10,0x13,0x54,0x59,0x51,0x91,0x11,0x10,0x11,0x28,0x27,0x44,0x41,0x82,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 29180 0x71fc "燼" */
+0x20,0x23,0x20,0x27,0xa8,0xb3,0xa0,0xa7,0x20,0x22,0x24,0x23,0x52,0x4a,0x4f,0x80,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 29181 0x71fd "燽" */
+0x20,0x27,0x20,0x23,0xa8,0xb7,0xa0,0xa3,0x20,0x27,0x20,0x27,0x50,0x4f,0x44,0x87,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 29182 0x71fe "燾" */
+0x01,0x7f,0x01,0x3f,0x00,0xff,0x00,0x3f,0x01,0xff,0x00,0x7d,0x44,0x7c,0x24,0x42,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x02,0xf0,0x00,0xfe,0x10,0xfc,0x90,0x30,0x88,0x44,
+/* 29183 0x71ff "燿" */
+0x10,0x13,0x10,0x12,0x55,0x5a,0x50,0x91,0x13,0x15,0x11,0x29,0x25,0x45,0x41,0x81,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 29184 0x7200 "爀" */
+0x21,0x21,0x21,0x27,0xa9,0xb1,0xaf,0xa2,0x22,0x26,0x2a,0x22,0x52,0x4d,0x44,0x88,
+0x10,0x10,0x10,0xbc,0x10,0x10,0xfe,0xa8,0xa8,0xec,0xaa,0xaa,0xa8,0xa8,0x48,0x98,
+/* 29185 0x7201 "爁" */
+0x10,0x13,0x12,0x17,0x5a,0x53,0x52,0x93,0x10,0x11,0x11,0x29,0x25,0x41,0x47,0x80,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 29186 0x7202 "爂" */
+0x2f,0x48,0x4b,0x68,0x4b,0x6a,0x4b,0x48,0xff,0x81,0x11,0x11,0x22,0x04,0x18,0xe0,
+0xec,0x24,0xa4,0x2c,0xa4,0xac,0xa4,0x24,0xfe,0x02,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 29187 0x7203 "爃" */
+0x10,0x12,0x12,0x14,0x59,0x52,0x50,0x93,0x12,0x10,0x13,0x28,0x24,0x41,0x46,0x80,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x22,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29188 0x7204 "爄" */
+0x10,0x13,0x12,0x17,0x5a,0x52,0x52,0x92,0x12,0x12,0x12,0x2b,0x27,0x45,0x45,0x89,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 29189 0x7205 "爅" */
+0x11,0x11,0x11,0x15,0x59,0x50,0x51,0x90,0x13,0x11,0x12,0x28,0x25,0x40,0x43,0x80,
+0xfc,0x24,0xac,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,0x20,0xfc,0x20,0xfe,0x00,
+/* 29190 0x7206 "爆" */
+0x11,0x11,0x11,0x15,0x59,0x50,0x53,0x90,0x17,0x10,0x11,0x2a,0x24,0x40,0x41,0x80,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfe,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 29191 0x7207 "爇" */
+0x08,0xff,0x08,0x10,0x7c,0x11,0xfe,0x44,0x92,0x7c,0x10,0x1d,0xe2,0x48,0x44,0x84,
+0x20,0xfe,0x20,0x40,0x40,0xf8,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,0x88,0x44,0x44,
+/* 29192 0x7208 "爈" */
+0x20,0x20,0x20,0x27,0xac,0xb5,0xa4,0xa5,0x25,0x25,0x25,0x25,0x58,0x4a,0x52,0x84,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0xfe,0x24,0xfc,0x24,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 29193 0x7209 "爉" */
+0x11,0x12,0x11,0x14,0x5b,0x52,0x52,0x92,0x13,0x12,0x13,0x2a,0x27,0x42,0x42,0x83,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 29194 0x720a "爊" */
+0x20,0x20,0x27,0x24,0xaf,0xb4,0xa7,0xa4,0x25,0x25,0x25,0x25,0x55,0x48,0x4a,0x94,
+0x80,0x40,0xfc,0xa0,0xfc,0xa4,0xfc,0x00,0x24,0xa8,0x30,0xa4,0x1c,0x00,0xa4,0x52,
+/* 29195 0x720b "爋" */
+0x21,0x27,0x21,0x27,0xa9,0xb7,0xa5,0xa7,0x25,0x27,0x21,0x27,0x51,0x4f,0x4a,0x91,
+0xc8,0x08,0x08,0xc8,0x3e,0xca,0x4a,0xca,0x4a,0xca,0x0a,0xca,0x0a,0xea,0xaa,0x56,
+/* 29196 0x720c "爌" */
+0x20,0x20,0x27,0x24,0xad,0xb4,0xa7,0xa4,0x25,0x25,0x25,0x25,0x55,0x4c,0x44,0x89,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 29197 0x720d "爍" */
+0x24,0x24,0x28,0x2a,0xae,0xb4,0xaa,0xae,0x22,0x20,0x2f,0x20,0x51,0x4a,0x4c,0x80,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 29198 0x720e "爎" */
+0x10,0x10,0x13,0x12,0x55,0x58,0x52,0x91,0x12,0x10,0x10,0x28,0x24,0x45,0x42,0x80,
+0x40,0x20,0xfe,0x22,0xfc,0x50,0x8a,0xfc,0x8a,0xf8,0x88,0xf8,0x20,0x24,0xa2,0x40,
+/* 29199 0x720f "爏" */
+0x20,0x27,0x24,0x25,0xac,0xb7,0xa4,0xa5,0x26,0x24,0x24,0x25,0x55,0x49,0x49,0x97,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 29200 0x7210 "爐" */
+0x10,0x10,0x10,0x13,0x56,0x5b,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x45,0x45,0x8b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 29201 0x7211 "爑" */
+0x10,0x10,0x13,0x14,0x58,0x51,0x51,0x93,0x15,0x11,0x11,0x29,0x25,0x42,0x42,0x84,
+0x88,0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,
+/* 29202 0x7212 "爒" */
+0x10,0x10,0x1e,0x22,0x54,0xa8,0x10,0x28,0xca,0x2a,0x2c,0x48,0x14,0x12,0x22,0x40,
+0x10,0x10,0xfe,0x10,0xaa,0x44,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x54,0x92,0x30,
+/* 29203 0x7213 "爓" */
+0x13,0x12,0x13,0x16,0x5b,0x52,0x52,0x92,0x13,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0xde,0x52,0xde,0x52,0xde,0x42,0x7a,0x8a,0x12,0xda,0x8a,0xda,0x8a,0xfa,0x0a,0x04,
+/* 29204 0x7214 "爔" */
+0x21,0x27,0x20,0x23,0xa8,0xb7,0xa0,0xa3,0x21,0x27,0x23,0x25,0x53,0x48,0x42,0x81,
+0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xd4,0x12,0xfe,0x50,0x34,0x8c,0x8a,0x96,0x02,
+/* 29205 0x7215 "爕" */
+0x21,0x27,0x20,0x6b,0xb0,0x23,0x20,0x53,0x4a,0x8b,0x01,0x11,0x22,0x04,0x18,0xe0,
+0x08,0xc8,0x08,0x9a,0x2c,0x88,0x08,0x94,0x92,0xa2,0x00,0x10,0xa0,0x40,0x30,0x0e,
+/* 29206 0x7216 "爖" */
+0x22,0x21,0x27,0x20,0xac,0xb2,0xa7,0xa0,0x27,0x24,0x27,0x24,0x57,0x4c,0x44,0x84,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 29207 0x7217 "爗" */
+0x11,0x11,0x11,0x15,0x59,0x50,0x53,0x90,0x11,0x10,0x13,0x28,0x25,0x44,0x43,0x80,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfe,0x88,0xfc,0xa8,0xfe,0xa8,0xfc,0x20,0xfe,0x20,
+/* 29208 0x7218 "爘" */
+0x10,0x10,0x12,0x13,0x54,0x5a,0x51,0x96,0x11,0x12,0x10,0x28,0x24,0x44,0x40,0x80,
+0x80,0xde,0x82,0xd4,0x48,0xb4,0x4a,0xa4,0xfa,0x88,0xf8,0x88,0xfa,0x94,0xa8,0xc4,
+/* 29209 0x7219 "爙" */
+0x10,0x13,0x10,0x15,0x59,0x51,0x50,0x93,0x10,0x13,0x10,0x2b,0x24,0x41,0x42,0x80,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 29210 0x721a "爚" */
+0x20,0x20,0x21,0x22,0xad,0xb0,0xae,0xaa,0x2e,0x20,0x2f,0x29,0x5f,0x49,0x49,0x88,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xee,0xaa,0xee,0x00,0xfe,0x22,0xfe,0x22,0x2a,0x04,
+/* 29211 0x721b "爛" */
+0x13,0x12,0x13,0x16,0x5b,0x52,0x52,0x92,0x12,0x12,0x12,0x2a,0x26,0x42,0x42,0x82,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 29212 0x721c "爜" */
+0x24,0x22,0x2f,0x29,0xb7,0xa0,0xa3,0xa0,0x2f,0x24,0x27,0x24,0x57,0x4c,0x4f,0x80,
+0x92,0x94,0xfe,0x10,0xfc,0x40,0xf8,0x40,0xfe,0x80,0xbc,0x94,0x94,0xc8,0x94,0xa2,
+/* 29213 0x721d "爝" */
+0x10,0x13,0x11,0x14,0x5b,0x52,0x53,0x90,0x13,0x12,0x13,0x2a,0x27,0x42,0x42,0x83,
+0x1e,0xe0,0x22,0x94,0xfe,0x52,0xfe,0x04,0xc4,0x7e,0xc4,0x54,0xcc,0x84,0xd4,0x48,
+/* 29214 0x721e "爞" */
+0x20,0x20,0x23,0x22,0xab,0xb0,0xa7,0xa0,0x22,0x2f,0x2a,0x2f,0x52,0x4a,0x4f,0x80,
+0x40,0x40,0xf8,0x48,0xf8,0x44,0xfc,0x04,0x08,0xbe,0xaa,0xbe,0x08,0x8a,0xbe,0x82,
+/* 29215 0x721f "爟" */
+0x20,0x23,0x20,0x23,0xaa,0xb3,0xa0,0xa0,0x21,0x21,0x23,0x25,0x51,0x49,0x41,0x81,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29216 0x7220 "爠" */
+0x27,0x24,0x27,0x24,0xaf,0xb4,0xa7,0xa1,0x23,0x22,0x27,0x2a,0x53,0x4a,0x43,0x82,
+0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29217 0x7221 "爡" */
+0x10,0x13,0x10,0x11,0x55,0x59,0x51,0x93,0x12,0x12,0x12,0x29,0x25,0x45,0x40,0x83,
+0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfe,0x2a,0xfa,0x26,0xfc,0x24,0xfc,0x22,0xfe,
+/* 29218 0x7222 "爢" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x21,0x2f,0x21,0x27,0x21,0x2f,0x41,0x52,0xa1,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0x20,0x3c,0x20,0x38,0x20,0x3c,0x20,0x44,0x22,
+/* 29219 0x7223 "爣" */
+0x22,0x21,0x27,0x24,0xa9,0xb1,0xa7,0xa5,0x24,0x27,0x20,0x27,0x50,0x4f,0x42,0x84,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 29220 0x7224 "爤" */
+0x21,0x27,0x21,0x27,0xac,0xb7,0xa4,0xa7,0x24,0x27,0x25,0x25,0x54,0x4c,0x45,0x84,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xfc,0x54,0xf4,0x44,0xe4,0x54,0x48,
+/* 29221 0x7225 "爥" */
+0x13,0x12,0x13,0x16,0x5a,0x52,0x52,0x92,0x12,0x13,0x12,0x2a,0x24,0x44,0x49,0x80,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 29222 0x7226 "爦" */
+0x27,0x25,0x27,0x24,0xaf,0xb5,0xa7,0xa0,0x23,0x22,0x23,0x22,0x53,0x48,0x41,0x86,
+0x90,0x1e,0xa8,0x84,0xbe,0x2a,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 29223 0x7227 "爧" */
+0x27,0x20,0x2f,0x28,0xab,0xb0,0xa3,0xa0,0x2e,0x2a,0x2e,0x20,0x5f,0x4a,0x45,0x8f,
+0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xee,0xaa,0xee,0x00,0xfe,0x48,0x54,0xfe,
+/* 29224 0x7228 "爨" */
+0x2f,0x48,0x6b,0x48,0x6b,0x4a,0xff,0x88,0x7e,0x2c,0x4a,0xff,0x11,0x29,0xc6,0x18,
+0xec,0x24,0xac,0x24,0xac,0xa4,0xfe,0x22,0xfc,0x68,0xa4,0xfe,0x10,0x28,0xc6,0x30,
+/* 29225 0x7229 "爩" */
+0x22,0x22,0x2f,0x22,0xaf,0xba,0xa2,0xaf,0x29,0x34,0x25,0x27,0x52,0x4b,0x42,0x83,
+0x88,0xe8,0x5e,0xec,0x5a,0xe8,0x08,0xfe,0x42,0x94,0x58,0xf2,0x04,0xe8,0x02,0xe4,
+/* 29226 0x722a "爪" */
+0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x42,0x80,
+0x10,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 29227 0x722b "爫" */
+0x00,0x00,0x00,0x07,0x7a,0x21,0x11,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x7c,0x80,0x10,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 29228 0x722c "爬" */
+0x0e,0x74,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x52,0x52,0x51,0x90,0x10,
+0x00,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,0x00,0xfe,0x00,
+/* 29229 0x722d "爭" */
+0x00,0x01,0x7e,0x22,0x11,0x3f,0x01,0x01,0xff,0x01,0x01,0x3f,0x01,0x01,0x05,0x02,
+0x08,0xfc,0x10,0x10,0x20,0xf8,0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 29230 0x722e "爮" */
+0x02,0x07,0x3a,0x2a,0x2b,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x48,0x48,0x88,
+0x40,0x40,0x7c,0x84,0x74,0x54,0x54,0x74,0x48,0x42,0x42,0xbe,0x40,0x30,0x0e,0x00,
+/* 29231 0x722f "爯" */
+0x00,0x01,0x7e,0x22,0x11,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0xff,0x20,0x20,0x20,
+0x08,0xfc,0x10,0x10,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x08,0x28,0x10,
+/* 29232 0x7230 "爰" */
+0x00,0x01,0x7e,0x22,0x11,0x3f,0x02,0x02,0x7f,0x04,0x0f,0x14,0x22,0x41,0x86,0x38,
+0x08,0xfc,0x10,0x10,0x20,0xf8,0x00,0x00,0xfc,0x00,0xe0,0x20,0x40,0x80,0x60,0x1c,
+/* 29233 0x7231 "爱" */
+0x00,0x01,0x7e,0x22,0x11,0x7f,0x42,0x82,0x7f,0x04,0x07,0x0a,0x11,0x20,0x43,0x1c,
+0x08,0xfc,0x10,0x10,0x20,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0x20,0xc0,0x30,0x0e,
+/* 29234 0x7232 "爲" */
+0x00,0x7f,0x12,0x09,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x20,0x2a,0x49,0x51,0x80,
+0xfc,0x00,0x10,0x20,0xf0,0x10,0x10,0xf8,0x08,0x08,0xfe,0x02,0xa2,0x52,0x54,0x08,
+/* 29235 0x7233 "爳" */
+0x00,0x3f,0x09,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x2a,0x40,0x9f,0x00,0x01,0x05,0x02,
+0xf8,0x20,0x40,0xe0,0x20,0xf0,0x10,0xfc,0x04,0xa4,0x0c,0xe0,0x40,0x80,0x00,0x00,
+/* 29236 0x7234 "爴" */
+0x00,0xff,0x8d,0x8b,0xff,0x89,0xe9,0xa9,0xeb,0x85,0xe5,0x8b,0x91,0xff,0x00,0x01,
+0x04,0x0e,0x74,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x92,0x92,0x00,
+/* 29237 0x7235 "爵" */
+0x00,0x7f,0x22,0x11,0x7f,0x44,0x7f,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x48,0x74,0x42,
+0xfc,0x00,0x08,0x10,0xfc,0x44,0xfc,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 29238 0x7236 "父" */
+0x04,0x08,0x10,0x20,0x40,0x08,0x08,0x04,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x20,0x10,0x08,0x24,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 29239 0x7237 "爷" */
+0x04,0x08,0x18,0x24,0x03,0x0c,0x30,0xc0,0x1f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x40,0x20,0x50,0x88,0x00,0xc0,0x30,0x0e,0xf0,0x10,0x10,0x10,0x50,0x20,0x00,0x00,
+/* 29240 0x7238 "爸" */
+0x04,0x08,0x18,0x24,0x03,0x0c,0x30,0xc0,0x1f,0x11,0x11,0x1f,0x10,0x10,0x10,0x0f,
+0x40,0x20,0x50,0x88,0x00,0xc0,0x30,0x0e,0xf0,0x10,0x10,0xf0,0x10,0x04,0x04,0xfc,
+/* 29241 0x7239 "爹" */
+0x04,0x08,0x18,0x24,0x03,0x0c,0x32,0xc7,0x1a,0x01,0x1e,0x01,0x0e,0x00,0x03,0x3c,
+0x40,0x20,0x50,0x88,0x00,0xc0,0x30,0xce,0x40,0xa0,0x78,0x88,0x90,0x60,0x80,0x00,
+/* 29242 0x723a "爺" */
+0x08,0x10,0x28,0x44,0x03,0x1c,0xe0,0x00,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,
+0x40,0x20,0x50,0x88,0x00,0xe0,0x1e,0x00,0x78,0x48,0x50,0x48,0x44,0xd4,0x48,0x40,
+/* 29243 0x723b "爻" */
+0x00,0x18,0x06,0x01,0x06,0x18,0x60,0x00,0x08,0x04,0x02,0x01,0x02,0x0c,0x30,0xc0,
+0x08,0x10,0x60,0x80,0x60,0x18,0x04,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x30,0x0e,
+/* 29244 0x723c "爼" */
+0x04,0x45,0x29,0x11,0x29,0x45,0x81,0x05,0x45,0x29,0x11,0x29,0x45,0x81,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 29245 0x723d "爽" */
+0x01,0x01,0x7f,0x01,0x29,0x11,0x29,0x01,0x29,0x11,0x2a,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x00,0x28,0x10,0x28,0x00,0x28,0x10,0xa8,0x80,0x40,0x20,0x18,0x06,
+/* 29246 0x723e "爾" */
+0x00,0x7f,0x21,0x41,0xbf,0x21,0x35,0x29,0x35,0x21,0x35,0x29,0x35,0x21,0x21,0x20,
+0x00,0xfc,0x08,0x04,0xfa,0x08,0x58,0x28,0x58,0x08,0x58,0x28,0x58,0x08,0x28,0x10,
+/* 29247 0x723f "爿" */
+0x00,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x10,0x10,0x20,0x40,
+0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 29248 0x7240 "牀" */
+0x04,0x24,0x24,0x24,0x25,0x3c,0x04,0x04,0xfc,0x24,0x25,0x25,0x26,0x44,0x44,0x84,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 29249 0x7241 "牁" */
+0x04,0x24,0x25,0x24,0x24,0x3d,0x05,0x05,0xfd,0x25,0x25,0x25,0x24,0x44,0x44,0x84,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 29250 0x7242 "牂" */
+0x04,0x24,0x24,0x24,0x25,0x3c,0x04,0x04,0xfc,0x24,0x25,0x24,0x24,0x44,0x44,0x84,
+0x84,0x44,0x48,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 29251 0x7243 "牃" */
+0x04,0x25,0x25,0x27,0x25,0x3d,0x05,0x05,0xfd,0x24,0x27,0x24,0x24,0x45,0x46,0x84,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29252 0x7244 "牄" */
+0x04,0x24,0x24,0x24,0x24,0x3d,0x06,0x04,0xfc,0x24,0x24,0x24,0x25,0x45,0x46,0x84,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 29253 0x7245 "牅" */
+0x10,0x57,0x54,0x55,0x54,0x77,0x14,0x15,0xf4,0x55,0x55,0x55,0x55,0x55,0x55,0x89,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 29254 0x7246 "牆" */
+0x08,0x28,0x2b,0x29,0x29,0x3a,0x0f,0x08,0xf9,0x29,0x29,0x29,0x29,0x49,0x49,0x89,
+0x20,0x20,0xfe,0x24,0x24,0xaa,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 29255 0x7247 "片" */
+0x00,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x20,0x20,0x40,
+0x40,0x40,0x40,0x40,0x40,0xfc,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 29256 0x7248 "版" */
+0x08,0x48,0x49,0x49,0x49,0x7d,0x41,0x41,0x79,0x49,0x49,0x49,0x49,0x4a,0x4a,0x8c,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 29257 0x7249 "牉" */
+0x04,0x24,0x25,0x24,0x24,0x3e,0x21,0x20,0x3c,0x24,0x27,0x24,0x24,0x44,0x44,0x84,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 29258 0x724a "牊" */
+0x04,0x25,0x24,0x24,0x24,0x3e,0x20,0x20,0x3d,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 29259 0x724b "牋" */
+0x04,0x24,0x24,0x25,0x24,0x3e,0x20,0x21,0x3c,0x24,0x25,0x24,0x24,0x44,0x44,0x85,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 29260 0x724c "牌" */
+0x08,0x48,0x49,0x49,0x49,0x7d,0x41,0x41,0x79,0x48,0x49,0x4b,0x48,0x48,0x48,0x88,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 29261 0x724d "牍" */
+0x08,0x48,0x48,0x48,0x48,0x7d,0x40,0x40,0x78,0x48,0x48,0x49,0x48,0x48,0x48,0x89,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x90,0x50,0xfe,0x28,0x44,0x82,0x02,
+/* 29262 0x724e "牎" */
+0x08,0x48,0x48,0x49,0x4a,0x7c,0x41,0x42,0x78,0x49,0x48,0x48,0x4a,0x4a,0x4c,0x88,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 29263 0x724f "牏" */
+0x08,0x48,0x48,0x49,0x4a,0x7c,0x41,0x41,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x89,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xe2,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x2a,0x64,
+/* 29264 0x7250 "牐" */
+0x08,0x48,0x49,0x48,0x48,0x7d,0x40,0x40,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x89,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 29265 0x7251 "牑" */
+0x08,0x48,0x49,0x49,0x49,0x7d,0x41,0x41,0x79,0x49,0x4a,0x4a,0x4c,0x48,0x48,0x88,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 29266 0x7252 "牒" */
+0x08,0x49,0x49,0x4b,0x49,0x7d,0x41,0x41,0x79,0x48,0x4b,0x48,0x48,0x49,0x4e,0x88,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29267 0x7253 "牓" */
+0x08,0x48,0x49,0x48,0x48,0x7d,0x41,0x42,0x78,0x49,0x48,0x48,0x48,0x48,0x48,0x89,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 29268 0x7254 "牔" */
+0x08,0x48,0x4b,0x48,0x49,0x7d,0x41,0x41,0x79,0x49,0x48,0x4b,0x48,0x48,0x48,0x88,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 29269 0x7255 "牕" */
+0x08,0x48,0x49,0x49,0x49,0x7d,0x41,0x41,0x79,0x49,0x48,0x48,0x4a,0x4a,0x4c,0x88,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 29270 0x7256 "牖" */
+0x08,0x48,0x4b,0x4a,0x4b,0x7e,0x43,0x42,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4c,0x88,
+0x40,0x20,0xfe,0x02,0xfe,0x14,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x92,0x96,
+/* 29271 0x7257 "牗" */
+0x08,0x49,0x49,0x49,0x49,0x7d,0x41,0x41,0x79,0x49,0x49,0x49,0x49,0x4a,0x4a,0x8c,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 29272 0x7258 "牘" */
+0x08,0x4b,0x48,0x49,0x48,0x7f,0x42,0x43,0x79,0x49,0x49,0x49,0x49,0x49,0x48,0x89,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29273 0x7259 "牙" */
+0x00,0x3f,0x00,0x00,0x10,0x10,0x20,0x3f,0x01,0x02,0x04,0x08,0x10,0x60,0x01,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 29274 0x725a "牚" */
+0x11,0x09,0x7f,0x40,0x9f,0x10,0x1f,0x00,0x7f,0x10,0x20,0x3f,0x02,0x04,0x19,0x60,
+0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,0x80,
+/* 29275 0x725b "牛" */
+0x01,0x11,0x11,0x11,0x1f,0x21,0x41,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 29276 0x725c "牜" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 29277 0x725d "牝" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x88,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x08,0x08,
+0x80,0x80,0x80,0x84,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 29278 0x725e "牞" */
+0x10,0x10,0x50,0x50,0x7d,0x50,0x90,0x10,0x1c,0xf0,0x50,0x10,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 29279 0x725f "牟" */
+0x02,0x04,0x08,0x10,0x3f,0x00,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0x20,0x10,0xf8,0x08,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 29280 0x7260 "牠" */
+0x10,0x10,0x50,0x51,0x7d,0x51,0x91,0x13,0x1d,0xf1,0x51,0x11,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 29281 0x7261 "牡" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x89,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x0b,0x08,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29282 0x7262 "牢" */
+0x02,0x01,0x7f,0x40,0x81,0x11,0x11,0x1f,0x21,0x41,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x04,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 29283 0x7263 "牣" */
+0x10,0x10,0x51,0x50,0x7c,0x51,0x91,0x11,0x1d,0xf2,0x50,0x10,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 29284 0x7264 "牤" */
+0x10,0x10,0x50,0x50,0x7d,0x50,0x90,0x10,0x1c,0xf0,0x50,0x10,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 29285 0x7265 "牥" */
+0x10,0x10,0x50,0x53,0x7c,0x50,0x90,0x10,0x1c,0xf0,0x50,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 29286 0x7266 "牦" */
+0x08,0x08,0x49,0x48,0x7e,0x48,0x89,0x08,0x0e,0xf8,0x4b,0x08,0x08,0x08,0x08,0x08,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 29287 0x7267 "牧" */
+0x08,0x08,0x48,0x48,0x7e,0x49,0x8a,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x09,0x0a,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 29288 0x7268 "牨" */
+0x10,0x10,0x50,0x53,0x7c,0x50,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x12,0x12,0x14,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 29289 0x7269 "物" */
+0x10,0x10,0x50,0x50,0x7d,0x52,0x90,0x10,0x1c,0xf1,0x52,0x10,0x10,0x10,0x11,0x10,
+0x80,0x80,0x80,0xfc,0x54,0x54,0x54,0x94,0x94,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 29290 0x726a "牪" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x89,0x08,0x0e,0xf9,0x48,0x08,0x08,0x08,0x08,0x08,
+0x10,0x10,0x90,0x90,0xfe,0x90,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 29291 0x726b "牫" */
+0x08,0x08,0x48,0x48,0x7e,0x49,0x88,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,0x0b,0x08,
+0x50,0x48,0x48,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 29292 0x726c "牬" */
+0x10,0x10,0x50,0x51,0x7d,0x51,0x91,0x11,0x1c,0xf0,0x50,0x11,0x16,0x10,0x10,0x10,
+0x20,0x20,0x2e,0xf0,0x20,0x20,0x20,0xfe,0x22,0x62,0xa2,0x2a,0x24,0x20,0x20,0x20,
+/* 29293 0x726d "牭" */
+0x10,0x10,0x53,0x52,0x7e,0x52,0x92,0x12,0x1e,0xf2,0x52,0x13,0x12,0x12,0x13,0x12,
+0x00,0x00,0xfc,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 29294 0x726e "牮" */
+0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x11,0x09,0x1f,0x21,0x01,0xff,0x01,0x01,0x01,
+0xa0,0x90,0xbe,0xc0,0x40,0x24,0x14,0x0c,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 29295 0x726f "牯" */
+0x10,0x10,0x50,0x50,0x7d,0x50,0x90,0x10,0x1d,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29296 0x7270 "牰" */
+0x10,0x10,0x50,0x50,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 29297 0x7271 "牱" */
+0x10,0x10,0x53,0x50,0x7c,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 29298 0x7272 "牲" */
+0x10,0x10,0x51,0x51,0x7d,0x51,0x92,0x10,0x1c,0xf1,0x50,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29299 0x7273 "牳" */
+0x10,0x10,0x50,0x50,0x7c,0x50,0x90,0x13,0x1d,0xf1,0x51,0x11,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 29300 0x7274 "牴" */
+0x10,0x10,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 29301 0x7275 "牵" */
+0x01,0x01,0x3f,0x02,0x04,0x08,0x7f,0x41,0x89,0x0f,0x11,0x01,0x7f,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x80,0x40,0x20,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 29302 0x7276 "牶" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x11,0x29,0xcf,0x11,0x01,0x7f,0x01,0x01,0x01,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0x08,0xf6,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 29303 0x7277 "牷" */
+0x10,0x10,0x50,0x50,0x7d,0x52,0x91,0x10,0x1c,0xf0,0x51,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 29304 0x7278 "牸" */
+0x10,0x10,0x53,0x52,0x7c,0x51,0x90,0x10,0x1c,0xf3,0x50,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x10,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 29305 0x7279 "特" */
+0x10,0x10,0x50,0x51,0x7c,0x50,0x93,0x10,0x1c,0xf1,0x50,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 29306 0x727a "牺" */
+0x10,0x17,0x50,0x50,0x7c,0x53,0x92,0x12,0x1e,0xf2,0x52,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 29307 0x727b "牻" */
+0x10,0x10,0x50,0x51,0x7c,0x50,0x90,0x10,0x1c,0xf0,0x51,0x11,0x11,0x12,0x12,0x14,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 29308 0x727c "牼" */
+0x10,0x11,0x50,0x50,0x7d,0x52,0x91,0x10,0x1c,0xf1,0x50,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29309 0x727d "牽" */
+0x01,0x7f,0x08,0x1f,0x02,0x7f,0x48,0x9f,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x00,0xfc,0x20,0xc0,0x00,0xfe,0x22,0xf4,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 29310 0x727e "牾" */
+0x10,0x13,0x50,0x50,0x7d,0x50,0x90,0x13,0x1c,0xf0,0x51,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29311 0x727f "牿" */
+0x10,0x11,0x51,0x51,0x7d,0x52,0x90,0x13,0x1c,0xf0,0x51,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29312 0x7280 "犀" */
+0x00,0x3f,0x20,0x3f,0x20,0x28,0x26,0x28,0x24,0x27,0x28,0x20,0x5f,0x40,0x80,0x00,
+0x00,0xfc,0x04,0xfc,0x00,0x88,0xb0,0x08,0x80,0xf8,0x80,0x80,0xfe,0x80,0x80,0x80,
+/* 29313 0x7281 "犁" */
+0x03,0x3c,0x04,0x7f,0x0c,0x16,0x25,0x44,0x05,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x08,0x08,0x48,0x48,0x48,0x48,0x08,0x28,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 29314 0x7282 "犂" */
+0x0c,0x70,0x11,0xfd,0x12,0x38,0x55,0x90,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x80,0xfc,0x24,0x24,0x44,0x84,0x28,0x10,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 29315 0x7283 "犃" */
+0x10,0x10,0x51,0x50,0x7d,0x50,0x90,0x13,0x1c,0xf0,0x51,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29316 0x7284 "犄" */
+0x10,0x10,0x51,0x50,0x7c,0x51,0x93,0x10,0x1d,0xf1,0x51,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 29317 0x7285 "犅" */
+0x10,0x13,0x52,0x52,0x7e,0x53,0x92,0x12,0x1e,0xf2,0x52,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 29318 0x7286 "犆" */
+0x10,0x10,0x53,0x50,0x7c,0x51,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfe,0x00,
+/* 29319 0x7287 "犇" */
+0x01,0x09,0x0f,0x11,0x01,0x7f,0x01,0x11,0x51,0x7c,0x90,0x1e,0xf0,0x50,0x10,0x10,
+0x00,0x00,0xf0,0x00,0x00,0xfc,0x00,0x10,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,0x10,
+/* 29320 0x7288 "犈" */
+0x10,0x11,0x50,0x50,0x7d,0x50,0x93,0x10,0x1d,0xf2,0x54,0x10,0x10,0x10,0x10,0x10,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 29321 0x7289 "犉" */
+0x10,0x10,0x53,0x50,0x7d,0x51,0x91,0x10,0x1d,0xf0,0x50,0x13,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 29322 0x728a "犊" */
+0x10,0x10,0x51,0x50,0x7c,0x53,0x90,0x10,0x1c,0xf1,0x50,0x13,0x10,0x10,0x10,0x13,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x10,0x90,0xfe,0x28,0x44,0x82,0x02,
+/* 29323 0x728b "犋" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x91,0x11,0x1d,0xf1,0x51,0x17,0x10,0x10,0x11,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 29324 0x728c "犌" */
+0x10,0x13,0x52,0x52,0x7a,0x53,0x92,0x12,0x1b,0x32,0xd2,0x13,0x12,0x12,0x12,0x12,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 29325 0x728d "犍" */
+0x10,0x10,0x57,0x51,0x7d,0x52,0x92,0x17,0x1d,0xf5,0x55,0x12,0x12,0x15,0x18,0x10,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 29326 0x728e "犎" */
+0x08,0x7e,0x08,0xfe,0x08,0x7e,0x08,0x0f,0xf1,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 29327 0x728f "犏" */
+0x10,0x10,0x53,0x52,0x7e,0x53,0x92,0x12,0x1f,0xf3,0x53,0x15,0x15,0x15,0x19,0x11,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x44,0x0c,
+/* 29328 0x7290 "犐" */
+0x10,0x17,0x51,0x51,0x79,0x57,0x91,0x11,0x1b,0x33,0xd5,0x15,0x11,0x11,0x11,0x11,
+0xc4,0x04,0x24,0x14,0x14,0x84,0x24,0x14,0x94,0x46,0x3c,0x04,0x04,0x04,0x04,0x04,
+/* 29329 0x7291 "犑" */
+0x10,0x11,0x51,0x51,0x7d,0x51,0x91,0x11,0x1c,0xf0,0x53,0x10,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 29330 0x7292 "犒" */
+0x10,0x10,0x53,0x50,0x7d,0x51,0x91,0x10,0x1f,0xf2,0x52,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 29331 0x7293 "犓" */
+0x10,0x10,0x51,0x52,0x79,0x51,0x90,0x11,0x1a,0x31,0xd2,0x15,0x11,0x10,0x11,0x12,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 29332 0x7294 "犔" */
+0x11,0x11,0x51,0x52,0x7d,0x50,0x93,0x10,0x1a,0x31,0xd7,0x10,0x11,0x16,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 29333 0x7295 "犕" */
+0x10,0x10,0x53,0x50,0x78,0x57,0x90,0x11,0x1b,0x35,0xd1,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x88,0xfe,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 29334 0x7296 "犖" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x41,0x89,0x1f,0x21,0x01,0xff,0x01,0x01,0x01,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 29335 0x7297 "犗" */
+0x10,0x10,0x53,0x52,0x7c,0x51,0x90,0x11,0x1c,0xf3,0x50,0x11,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 29336 0x7298 "犘" */
+0x01,0x00,0x3f,0x22,0x2f,0x26,0x2b,0x32,0x20,0x22,0x23,0x24,0x20,0x5f,0x40,0x80,
+0x00,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x40,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,
+/* 29337 0x7299 "犙" */
+0x10,0x10,0x51,0x51,0x7a,0x53,0x90,0x11,0x1e,0x30,0xd3,0x10,0x13,0x10,0x10,0x17,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 29338 0x729a "犚" */
+0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2c,0x11,0x1f,0x21,0xff,0x01,0x01,
+0x08,0x08,0x7e,0x08,0x48,0x28,0xa8,0x08,0x28,0x90,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 29339 0x729b "犛" */
+0x08,0x3e,0x08,0x7f,0x1c,0x2a,0x49,0x3f,0x24,0x24,0x27,0x28,0x20,0x5f,0x40,0x80,
+0x20,0x7e,0xa4,0x28,0x10,0x28,0x44,0xfe,0x80,0x80,0xf8,0x80,0x80,0xfc,0x80,0x80,
+/* 29340 0x729c "犜" */
+0x11,0x10,0x53,0x50,0x7b,0x52,0x93,0x10,0x1b,0x30,0xd0,0x10,0x13,0x10,0x12,0x11,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 29341 0x729d "犝" */
+0x10,0x11,0x50,0x50,0x7d,0x50,0x91,0x11,0x1d,0xf1,0x51,0x10,0x11,0x10,0x13,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29342 0x729e "犞" */
+0x10,0x11,0x50,0x53,0x7c,0x51,0x92,0x10,0x1c,0xf1,0x51,0x11,0x11,0x11,0x11,0x11,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 29343 0x729f "犟" */
+0x7c,0x04,0x04,0x7c,0x41,0x7d,0x05,0x04,0x2b,0x10,0x11,0x1f,0x21,0xff,0x01,0x01,
+0xf8,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x28,0xfc,0x04,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 29344 0x72a0 "犠" */
+0x11,0x10,0x53,0x50,0x7d,0x50,0x93,0x10,0x1d,0xf0,0x53,0x10,0x10,0x13,0x10,0x11,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 29345 0x72a1 "犡" */
+0x10,0x13,0x52,0x53,0x7e,0x52,0x92,0x12,0x1e,0xf2,0x52,0x13,0x13,0x15,0x15,0x19,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 29346 0x72a2 "犢" */
+0x10,0x13,0x50,0x51,0x7c,0x53,0x92,0x13,0x1d,0xf1,0x51,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29347 0x72a3 "犣" */
+0x11,0x12,0x51,0x50,0x7b,0x52,0x92,0x12,0x1b,0x32,0xd3,0x12,0x13,0x12,0x12,0x13,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 29348 0x72a4 "犤" */
+0x10,0x13,0x52,0x52,0x7b,0x51,0x92,0x13,0x18,0x33,0xd2,0x13,0x12,0x13,0x12,0x12,
+0x00,0xfc,0x94,0x94,0xfc,0x10,0x52,0xdc,0x12,0xce,0x40,0xd2,0x5c,0xd0,0x52,0xce,
+/* 29349 0x72a5 "犥" */
+0x10,0x10,0x53,0x52,0x7b,0x52,0x93,0x12,0x1a,0x32,0xd2,0x12,0x12,0x14,0x15,0x1a,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 29350 0x72a6 "犦" */
+0x13,0x12,0x53,0x52,0x7b,0x51,0x97,0x11,0x1f,0x31,0xd2,0x15,0x10,0x11,0x12,0x10,
+0xf8,0x08,0xf8,0x08,0xf8,0x10,0xfc,0x10,0xfe,0x10,0x48,0x54,0xe0,0x50,0x48,0xc0,
+/* 29351 0x72a7 "犧" */
+0x11,0x17,0x50,0x53,0x78,0x57,0x90,0x13,0x19,0x37,0xd3,0x15,0x13,0x10,0x12,0x11,
+0x10,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xd4,0x12,0xfe,0x50,0x34,0x8c,0x8a,0x96,0x02,
+/* 29352 0x72a8 "犨" */
+0x08,0x24,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,0x11,0x1f,0x21,0xff,0x01,0x01,
+0x10,0x48,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,0x40,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 29353 0x72a9 "犩" */
+0x7c,0x11,0xfd,0x39,0x55,0xfd,0x24,0x18,0x65,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,
+0x40,0xfc,0x24,0xfc,0x24,0xfc,0x68,0xa2,0x1e,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,
+/* 29354 0x72aa "犪" */
+0x21,0x27,0xa0,0xa2,0xfa,0xab,0xaa,0x2a,0x3b,0xec,0x22,0x25,0x22,0x20,0x21,0x26,
+0x10,0xfe,0x40,0xee,0xaa,0xea,0xae,0xe8,0xaa,0xe6,0x88,0xf4,0x90,0x60,0x98,0x06,
+/* 29355 0x72ab "犫" */
+0x51,0x4b,0x7c,0xd3,0x7c,0x53,0x7c,0x53,0x7e,0x43,0x11,0x1f,0x21,0xff,0x01,0x01,
+0x18,0x94,0x3e,0xa8,0x7e,0xa8,0x3e,0xa8,0xbe,0xa0,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 29356 0x72ac "犬" */
+0x01,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x00,0x20,0x10,0x10,0x00,0xfe,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x10,0x08,0x06,
+/* 29357 0x72ad "犭" */
+0x00,0x44,0x28,0x10,0x28,0x48,0x88,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 29358 0x72ae "犮" */
+0x01,0x01,0x01,0x01,0x7f,0x02,0x04,0x07,0x0a,0x0a,0x11,0x20,0x40,0x80,0x03,0x0c,
+0x10,0x08,0x08,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 29359 0x72af "犯" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x50,0x20,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 29360 0x72b0 "犰" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x88,0x08,0x18,0x28,0x48,0x88,0x09,0x09,0x52,0x24,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 29361 0x72b1 "犱" */
+0x00,0x44,0x28,0x10,0x29,0x48,0x88,0x08,0x19,0x28,0x48,0x88,0x08,0x09,0x52,0x24,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 29362 0x72b2 "犲" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x88,0x08,0x18,0x28,0x48,0x89,0x0a,0x08,0x50,0x20,
+0x10,0x10,0x10,0x10,0xfe,0x30,0x30,0x50,0x50,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 29363 0x72b3 "犳" */
+0x00,0x44,0x28,0x10,0x29,0x4a,0x88,0x09,0x18,0x28,0x48,0x88,0x08,0x08,0x50,0x20,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 29364 0x72b4 "犴" */
+0x00,0x45,0x28,0x10,0x28,0x48,0x88,0x0b,0x18,0x28,0x48,0x88,0x08,0x08,0x50,0x20,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 29365 0x72b5 "犵" */
+0x00,0x44,0x29,0x11,0x2a,0x4c,0x89,0x08,0x18,0x28,0x48,0x89,0x0a,0x0a,0x51,0x20,
+0x80,0x80,0x00,0xfe,0x00,0x00,0xf8,0x08,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 29366 0x72b6 "状" */
+0x08,0x08,0x08,0x48,0x28,0x2f,0x08,0x08,0x18,0x28,0xc8,0x08,0x09,0x09,0x0a,0x0c,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 29367 0x72b7 "犷" */
+0x00,0x44,0x28,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 29368 0x72b8 "犸" */
+0x00,0x47,0x28,0x10,0x29,0x49,0x89,0x09,0x18,0x28,0x48,0x8b,0x08,0x08,0x50,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 29369 0x72b9 "犹" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x88,0x08,0x18,0x28,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 29370 0x72ba "犺" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 29371 0x72bb "犻" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x08,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 29372 0x72bc "犼" */
+0x00,0x8f,0x50,0x20,0x51,0x91,0x11,0x11,0x31,0x57,0x91,0x11,0x11,0x11,0xa5,0x42,
+0x10,0xd0,0x50,0x90,0x10,0x10,0x50,0x90,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 29373 0x72bd "犽" */
+0x00,0x45,0x28,0x11,0x29,0x49,0x8a,0x0b,0x18,0x28,0x48,0x88,0x09,0x0a,0x50,0x20,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x50,0x90,0x10,0x10,0x50,0x20,
+/* 29374 0x72be "犾" */
+0x00,0x88,0x50,0x20,0x50,0x97,0x10,0x10,0x30,0x50,0x90,0x11,0x11,0x12,0xa4,0x48,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 29375 0x72bf "犿" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x88,0x08,0x18,0x28,0x48,0x88,0x08,0x08,0x50,0x20,
+0x40,0x20,0x20,0x00,0xfe,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,
+/* 29376 0x72c0 "狀" */
+0x04,0x24,0x24,0x24,0x24,0x3d,0x04,0x04,0xfc,0x24,0x24,0x24,0x24,0x44,0x45,0x86,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 29377 0x72c1 "狁" */
+0x00,0x44,0x28,0x10,0x29,0x4b,0x88,0x08,0x18,0x28,0x48,0x88,0x09,0x09,0x52,0x24,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 29378 0x72c2 "狂" */
+0x00,0x44,0x29,0x10,0x28,0x48,0x88,0x08,0x19,0x28,0x48,0x88,0x08,0x08,0x53,0x20,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29379 0x72c3 "狃" */
+0x00,0x45,0x28,0x10,0x28,0x48,0x88,0x0b,0x18,0x28,0x48,0x88,0x08,0x08,0x53,0x20,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfe,0x00,
+/* 29380 0x72c4 "狄" */
+0x00,0x44,0x28,0x10,0x29,0x49,0x89,0x0a,0x18,0x28,0x48,0x88,0x09,0x09,0x52,0x24,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 29381 0x72c5 "狅" */
+0x00,0x44,0x29,0x10,0x28,0x48,0x88,0x0b,0x18,0x28,0x48,0x88,0x08,0x08,0x51,0x20,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 29382 0x72c6 "狆" */
+0x00,0x44,0x28,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x88,0x08,0x08,0x50,0x20,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 29383 0x72c7 "狇" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x88,0x08,0x19,0x29,0x4a,0x8c,0x08,0x08,0x50,0x20,
+0x40,0x40,0x40,0x40,0xfe,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 29384 0x72c8 "狈" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x88,0x08,0x08,0x51,0x26,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x02,0x02,
+/* 29385 0x72c9 "狉" */
+0x00,0x45,0x28,0x10,0x28,0x48,0x88,0x08,0x19,0x2a,0x48,0x88,0x08,0x08,0x53,0x20,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 29386 0x72ca "狊" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 29387 0x72cb "狋" */
+0x00,0x45,0x28,0x10,0x28,0x4b,0x88,0x08,0x19,0x29,0x4a,0x8a,0x0c,0x08,0x50,0x20,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 29388 0x72cc "狌" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x8a,0x08,0x18,0x29,0x48,0x88,0x08,0x08,0x53,0x20,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29389 0x72cd "狍" */
+0x00,0x44,0x29,0x11,0x2a,0x4d,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x50,0x20,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 29390 0x72ce "狎" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x88,0x08,0x08,0x50,0x20,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 29391 0x72cf "狏" */
+0x00,0x44,0x28,0x11,0x2a,0x49,0x89,0x09,0x1b,0x29,0x49,0x89,0x09,0x09,0x50,0x20,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 29392 0x72d0 "狐" */
+0x00,0x88,0x53,0x22,0x52,0x92,0x12,0x12,0x32,0x52,0x92,0x12,0x12,0x14,0xa4,0x48,
+0x08,0x3c,0xd0,0x90,0x90,0x90,0x90,0x90,0x90,0x88,0x88,0xc8,0xa4,0xd4,0x92,0x00,
+/* 29393 0x72d1 "狑" */
+0x00,0x44,0x28,0x10,0x29,0x4a,0x8c,0x08,0x1b,0x28,0x48,0x89,0x08,0x08,0x50,0x20,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 29394 0x72d2 "狒" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x8b,0x0a,0x1a,0x2b,0x48,0x88,0x09,0x09,0x52,0x24,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 29395 0x72d3 "狓" */
+0x00,0x44,0x28,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 29396 0x72d4 "狔" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 29397 0x72d5 "狕" */
+0x00,0x89,0x51,0x22,0x52,0x94,0x17,0x11,0x32,0x52,0x94,0x17,0x10,0x10,0xa0,0x41,
+0x20,0x20,0x20,0x20,0xfc,0xa4,0x24,0x24,0x24,0x24,0xa4,0xa4,0xc4,0x44,0x94,0x08,
+/* 29398 0x72d6 "狖" */
+0x00,0x44,0x28,0x13,0x2a,0x4c,0x88,0x08,0x18,0x28,0x48,0x89,0x09,0x09,0x52,0x24,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 29399 0x72d7 "狗" */
+0x00,0x44,0x29,0x11,0x2a,0x4c,0x89,0x09,0x19,0x29,0x49,0x89,0x08,0x08,0x50,0x20,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 29400 0x72d8 "狘" */
+0x00,0x44,0x28,0x10,0x2b,0x4a,0x8a,0x0a,0x1a,0x2a,0x4a,0x8a,0x0b,0x0a,0x50,0x20,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 29401 0x72d9 "狙" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x57,0x20,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 29402 0x72da "狚" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x08,0x08,0x53,0x20,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 29403 0x72db "狛" */
+0x00,0x44,0x28,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29404 0x72dc "狜" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x88,0x08,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29405 0x72dd "狝" */
+0x00,0x44,0x28,0x11,0x29,0x4a,0x8c,0x08,0x19,0x29,0x4a,0x8a,0x0c,0x08,0x50,0x20,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 29406 0x72de "狞" */
+0x00,0x44,0x28,0x13,0x2a,0x4c,0x88,0x08,0x1b,0x28,0x48,0x88,0x08,0x08,0x50,0x20,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 29407 0x72df "狟" */
+0x00,0x45,0x28,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x08,0x08,0x53,0x20,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 29408 0x72e0 "狠" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 29409 0x72e1 "狡" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x89,0x0a,0x18,0x28,0x48,0x88,0x08,0x08,0x50,0x23,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 29410 0x72e2 "狢" */
+0x00,0x44,0x28,0x11,0x2b,0x4c,0x88,0x08,0x19,0x2a,0x4d,0x89,0x09,0x09,0x51,0x21,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 29411 0x72e3 "狣" */
+0x00,0x44,0x28,0x12,0x29,0x48,0x88,0x09,0x1a,0x2c,0x48,0x88,0x09,0x09,0x52,0x24,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 29412 0x72e4 "狤" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x89,0x08,0x18,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29413 0x72e5 "狥" */
+0x00,0x44,0x29,0x11,0x2a,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x08,0x50,0x20,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 29414 0x72e6 "狦" */
+0x00,0x8b,0x52,0x22,0x52,0x9f,0x12,0x12,0x32,0x5f,0x92,0x12,0x12,0x12,0xa2,0x42,
+0x00,0xf8,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xa8,0xa8,0x08,0x18,
+/* 29415 0x72e7 "狧" */
+0x00,0x44,0x29,0x10,0x28,0x4b,0x88,0x08,0x18,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29416 0x72e8 "狨" */
+0x00,0x44,0x28,0x10,0x2b,0x48,0x89,0x09,0x19,0x2b,0x49,0x89,0x0a,0x0a,0x54,0x20,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 29417 0x72e9 "狩" */
+0x00,0x88,0x53,0x22,0x54,0x90,0x10,0x13,0x30,0x51,0x90,0x10,0x10,0x10,0xa0,0x40,
+0x40,0x20,0xfe,0x02,0x14,0x10,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 29418 0x72ea "狪" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 29419 0x72eb "狫" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x8f,0x08,0x18,0x29,0x4a,0x8c,0x08,0x08,0x50,0x20,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 29420 0x72ec "独" */
+0x00,0x44,0x28,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x48,0x88,0x08,0x0b,0x51,0x20,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x02,0x00,
+/* 29421 0x72ed "狭" */
+0x00,0x44,0x28,0x11,0x28,0x49,0x88,0x08,0x18,0x2b,0x48,0x88,0x08,0x08,0x51,0x22,
+0x20,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 29422 0x72ee "狮" */
+0x01,0x89,0x51,0x25,0x55,0x95,0x15,0x15,0x35,0x55,0x95,0x11,0x12,0x12,0xa4,0x48,
+0x00,0xfe,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,
+/* 29423 0x72ef "狯" */
+0x00,0x88,0x50,0x21,0x52,0x94,0x11,0x10,0x30,0x57,0x90,0x10,0x11,0x12,0xa7,0x42,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x00,0x00,0xfc,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 29424 0x72f0 "狰" */
+0x00,0x44,0x29,0x12,0x28,0x4b,0x88,0x08,0x1f,0x28,0x48,0x8b,0x08,0x08,0x51,0x20,
+0x80,0x80,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x80,
+/* 29425 0x72f1 "狱" */
+0x00,0x94,0x52,0x22,0x50,0x9e,0x12,0x12,0x32,0x52,0x92,0x13,0x12,0x10,0xa1,0x42,
+0x20,0x28,0x24,0x24,0x20,0x20,0xfc,0x20,0x20,0x50,0xd0,0x50,0x88,0x88,0x04,0x02,
+/* 29426 0x72f2 "狲" */
+0x00,0x88,0x57,0x20,0x51,0x92,0x12,0x13,0x32,0x56,0x9a,0x13,0x12,0x12,0xa2,0x46,
+0x00,0x10,0x90,0x90,0x10,0x10,0xd8,0x54,0x54,0x92,0x92,0x12,0x10,0x10,0x50,0x20,
+/* 29427 0x72f3 "狳" */
+0x00,0x88,0x50,0x21,0x52,0x95,0x10,0x10,0x37,0x50,0x92,0x12,0x14,0x18,0xa1,0x40,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x40,0x80,
+/* 29428 0x72f4 "狴" */
+0x02,0x8a,0x52,0x23,0x52,0x92,0x12,0x13,0x30,0x50,0x93,0x10,0x10,0x10,0xa7,0x40,
+0x20,0x24,0x28,0xb0,0x20,0x22,0xa2,0x1e,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 29429 0x72f5 "狵" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x88,0x08,0x18,0x28,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 29430 0x72f6 "狶" */
+0x01,0x44,0x28,0x10,0x2b,0x48,0x8b,0x08,0x19,0x2b,0x4d,0x89,0x09,0x09,0x50,0x20,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 29431 0x72f7 "狷" */
+0x00,0x45,0x29,0x11,0x29,0x48,0x8b,0x0a,0x1a,0x2b,0x4a,0x8a,0x0b,0x0a,0x52,0x22,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 29432 0x72f8 "狸" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x18,0x28,0x49,0x88,0x08,0x08,0x53,0x20,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 29433 0x72f9 "狹" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x89,0x09,0x19,0x2a,0x48,0x88,0x08,0x08,0x51,0x22,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 29434 0x72fa "狺" */
+0x00,0x44,0x2b,0x10,0x28,0x49,0x88,0x08,0x19,0x28,0x48,0x89,0x09,0x09,0x51,0x21,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 29435 0x72fb "狻" */
+0x00,0x44,0x28,0x11,0x2b,0x48,0x88,0x09,0x1a,0x28,0x49,0x8a,0x08,0x08,0x51,0x26,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 29436 0x72fc "狼" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 29437 0x72fd "狽" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x88,0x08,0x08,0x51,0x22,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 29438 0x72fe "狾" */
+0x01,0x89,0x51,0x21,0x57,0x91,0x11,0x11,0x31,0x57,0x91,0x11,0x11,0x11,0xa5,0x42,
+0x04,0x0e,0x30,0x20,0xe0,0x20,0x3e,0x64,0xa4,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 29439 0x72ff "狿" */
+0x00,0x44,0x2b,0x10,0x28,0x49,0x89,0x0b,0x18,0x2a,0x4a,0x89,0x09,0x0a,0x54,0x28,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 29440 0x7300 "猀" */
+0x00,0x8a,0x51,0x21,0x54,0x92,0x12,0x10,0x30,0x51,0x96,0x12,0x12,0x12,0xa2,0x40,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 29441 0x7301 "猁" */
+0x00,0x89,0x57,0x21,0x51,0x91,0x1f,0x11,0x33,0x53,0x95,0x15,0x19,0x11,0xa1,0x41,
+0x84,0xc4,0x04,0x14,0x14,0x14,0xd4,0x14,0x14,0x94,0x54,0x04,0x04,0x04,0x14,0x08,
+/* 29442 0x7302 "猂" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x88,0x08,0x19,0x28,0x48,0x8b,0x08,0x08,0x50,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 29443 0x7303 "猃" */
+0x00,0x88,0x50,0x20,0x51,0x92,0x15,0x10,0x30,0x50,0x92,0x11,0x11,0x10,0xa7,0x40,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 29444 0x7304 "猄" */
+0x00,0x44,0x2b,0x10,0x28,0x49,0x89,0x09,0x19,0x29,0x48,0x88,0x09,0x0a,0x50,0x20,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 29445 0x7305 "猅" */
+0x00,0x88,0x50,0x27,0x50,0x90,0x10,0x13,0x30,0x50,0x90,0x17,0x10,0x10,0xa0,0x40,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 29446 0x7306 "猆" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0x20,0x10,0xfc,0x80,0x40,0x30,0x0e,
+/* 29447 0x7307 "猇" */
+0x00,0x44,0x28,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x0a,0x0a,0x54,0x29,
+0x20,0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 29448 0x7308 "猈" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x28,0x49,0x8b,0x08,0x08,0x50,0x20,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 29449 0x7309 "猉" */
+0x00,0x44,0x2b,0x10,0x28,0x48,0x88,0x08,0x18,0x28,0x48,0x8b,0x08,0x08,0x51,0x22,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 29450 0x730a "猊" */
+0x00,0x90,0x53,0x22,0x52,0x93,0x12,0x12,0x33,0x50,0x90,0x10,0x10,0x11,0xa2,0x44,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 29451 0x730b "猋" */
+0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,0x14,0x12,0xfd,0x10,0x28,0x24,0x44,0x81,
+0x10,0x08,0xfe,0x80,0x40,0x20,0x18,0x06,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x06,
+/* 29452 0x730c "猌" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x49,0x88,0x08,0x09,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 29453 0x730d "猍" */
+0x00,0x88,0x50,0x27,0x50,0x92,0x12,0x12,0x35,0x50,0x91,0x11,0x12,0x14,0xa8,0x40,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 29454 0x730e "猎" */
+0x00,0x44,0x28,0x13,0x28,0x48,0x8f,0x08,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29455 0x730f "猏" */
+0x00,0x88,0x53,0x22,0x52,0x93,0x12,0x12,0x32,0x52,0x92,0x12,0x14,0x14,0xa8,0x40,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 29456 0x7310 "猐" */
+0x02,0x89,0x51,0x27,0x50,0x90,0x13,0x10,0x30,0x5f,0x91,0x11,0x12,0x12,0xa4,0x48,
+0x08,0x08,0x10,0xfc,0x40,0x40,0xf8,0x40,0x80,0xfe,0x20,0x20,0x20,0x22,0x22,0x1e,
+/* 29457 0x7311 "猑" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x18,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 29458 0x7312 "猒" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x42,0x4a,0x45,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 29459 0x7313 "猓" */
+0x00,0x8b,0x52,0x22,0x53,0x92,0x12,0x13,0x30,0x57,0x90,0x11,0x12,0x14,0xa0,0x40,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 29460 0x7314 "猔" */
+0x00,0x44,0x2b,0x12,0x28,0x49,0x88,0x08,0x1b,0x28,0x49,0x89,0x0a,0x0c,0x50,0x20,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 29461 0x7315 "猕" */
+0x00,0x97,0x51,0x21,0x51,0x97,0x14,0x14,0x34,0x57,0x91,0x11,0x11,0x11,0xa5,0x42,
+0x20,0x20,0x20,0x3e,0x42,0x44,0x90,0x10,0x10,0x54,0x52,0x52,0x92,0x10,0x50,0x20,
+/* 29462 0x7316 "猖" */
+0x01,0x45,0x29,0x11,0x29,0x49,0x89,0x08,0x1b,0x2a,0x4a,0x8b,0x0a,0x0a,0x53,0x22,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29463 0x7317 "猗" */
+0x00,0x88,0x53,0x20,0x51,0x92,0x17,0x10,0x33,0x52,0x92,0x12,0x13,0x10,0xa0,0x40,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 29464 0x7318 "猘" */
+0x00,0x88,0x52,0x23,0x54,0x90,0x17,0x10,0x33,0x52,0x92,0x12,0x12,0x12,0xa0,0x40,
+0x82,0x82,0x82,0xea,0x8a,0x8a,0xfa,0x8a,0xea,0xaa,0xaa,0xaa,0xa2,0xe2,0x8a,0x84,
+/* 29465 0x7319 "猙" */
+0x00,0x47,0x2a,0x11,0x28,0x4b,0x88,0x08,0x1f,0x28,0x48,0x8b,0x08,0x08,0x51,0x20,
+0x3c,0xc0,0x44,0x28,0x00,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x48,0x40,0x40,0x80,
+/* 29466 0x731a "猚" */
+0x00,0x44,0x28,0x11,0x29,0x4b,0x8d,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 29467 0x731b "猛" */
+0x00,0x45,0x28,0x10,0x28,0x4b,0x88,0x08,0x18,0x29,0x49,0x89,0x09,0x09,0x57,0x20,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 29468 0x731c "猜" */
+0x00,0x44,0x2b,0x10,0x29,0x48,0x8b,0x08,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 29469 0x731d "猝" */
+0x00,0x88,0x57,0x20,0x51,0x91,0x12,0x14,0x30,0x50,0x97,0x10,0x10,0x10,0xa0,0x40,
+0x80,0x40,0xfc,0x00,0x10,0x10,0xa8,0x44,0x00,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 29470 0x731e "猞" */
+0x00,0x88,0x50,0x21,0x52,0x95,0x10,0x10,0x37,0x50,0x90,0x13,0x12,0x12,0xa3,0x42,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 29471 0x731f "猟" */
+0x00,0x94,0x52,0x22,0x50,0x93,0x12,0x12,0x33,0x52,0x92,0x13,0x12,0x14,0xa4,0x48,
+0x00,0x84,0x44,0x48,0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x4a,0x4a,0x46,0x02,
+/* 29472 0x7320 "猠" */
+0x00,0x44,0x28,0x13,0x2a,0x4a,0x8a,0x0b,0x1a,0x2a,0x4a,0x8f,0x08,0x08,0x51,0x22,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 29473 0x7321 "猡" */
+0x00,0x8b,0x52,0x22,0x52,0x93,0x10,0x10,0x30,0x51,0x92,0x10,0x10,0x10,0xa1,0x46,
+0x00,0xfe,0x52,0x52,0x52,0xfe,0x20,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0x00,
+/* 29474 0x7322 "猢" */
+0x01,0x89,0x51,0x27,0x51,0x91,0x11,0x17,0x34,0x54,0x94,0x17,0x14,0x10,0xa0,0x40,
+0x00,0x1e,0x12,0xd2,0x12,0x1e,0x12,0xd2,0x52,0x5e,0x52,0xd2,0x52,0x22,0x2a,0x44,
+/* 29475 0x7323 "猣" */
+0x00,0x44,0x2a,0x12,0x2a,0x4a,0x8a,0x0b,0x18,0x29,0x4a,0x88,0x09,0x08,0x50,0x27,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 29476 0x7324 "猤" */
+0x00,0x45,0x28,0x12,0x29,0x48,0x89,0x0a,0x18,0x28,0x49,0x88,0x08,0x08,0x51,0x22,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 29477 0x7325 "猥" */
+0x00,0x8b,0x52,0x22,0x53,0x92,0x12,0x13,0x30,0x57,0x92,0x12,0x12,0x12,0xa3,0x42,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 29478 0x7326 "猦" */
+0x00,0x97,0x54,0x24,0x65,0xa4,0x25,0x25,0x65,0xa5,0x24,0x24,0x25,0x24,0xa8,0x50,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 29479 0x7327 "猧" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x0b,0x1a,0x2a,0x4a,0x8a,0x0a,0x0a,0x52,0x22,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 29480 0x7328 "猨" */
+0x00,0x97,0x52,0x21,0x50,0x93,0x10,0x10,0x37,0x51,0x91,0x12,0x12,0x14,0xa8,0x43,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 29481 0x7329 "猩" */
+0x00,0x8b,0x52,0x23,0x52,0x93,0x10,0x12,0x33,0x54,0x90,0x13,0x10,0x10,0xa7,0x40,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 29482 0x732a "猪" */
+0x00,0x88,0x53,0x20,0x50,0x97,0x10,0x10,0x31,0x53,0x95,0x11,0x11,0x11,0xa1,0x41,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 29483 0x732b "猫" */
+0x00,0x44,0x2b,0x10,0x28,0x48,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 29484 0x732c "猬" */
+0x00,0x97,0x54,0x27,0x54,0x97,0x10,0x13,0x32,0x53,0x92,0x13,0x12,0x12,0xa2,0x42,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 29485 0x732d "猭" */
+0x01,0x89,0x52,0x23,0x50,0x97,0x10,0x11,0x36,0x50,0x91,0x16,0x10,0x11,0xa6,0x40,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 29486 0x732e "献" */
+0x08,0x08,0xff,0x08,0x08,0x7f,0x41,0x55,0x49,0x5d,0x49,0x7f,0x49,0x49,0x45,0x42,
+0x10,0x14,0x92,0x12,0x10,0x7e,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 29487 0x732f "猯" */
+0x00,0x94,0x54,0x24,0x57,0x90,0x1f,0x10,0x30,0x57,0x94,0x14,0x14,0x14,0xa4,0x44,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x40,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0xa4,0x0c,
+/* 29488 0x7330 "猰" */
+0x00,0x44,0x2b,0x10,0x29,0x48,0x8b,0x08,0x18,0x28,0x4b,0x88,0x08,0x08,0x51,0x26,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 29489 0x7331 "猱" */
+0x00,0x8b,0x50,0x20,0x57,0x90,0x11,0x12,0x34,0x50,0x97,0x10,0x11,0x12,0xac,0x40,
+0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0x20,0x60,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 29490 0x7332 "猲" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x88,0x09,0x1a,0x29,0x49,0x89,0x09,0x08,0x50,0x20,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 29491 0x7333 "猳" */
+0x00,0x97,0x54,0x24,0x54,0x97,0x14,0x14,0x37,0x54,0x94,0x17,0x14,0x14,0xa4,0x44,
+0x00,0xbc,0x84,0x84,0x84,0xbc,0x00,0x00,0xbc,0x24,0x24,0xa8,0x10,0x28,0x44,0x82,
+/* 29492 0x7334 "猴" */
+0x01,0x89,0x51,0x22,0x52,0x96,0x1a,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0xa2,0x42,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 29493 0x7335 "猵" */
+0x00,0x88,0x53,0x22,0x52,0x93,0x12,0x12,0x33,0x53,0x93,0x15,0x15,0x15,0xa9,0x41,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x44,0x0c,
+/* 29494 0x7336 "猶" */
+0x01,0x44,0x28,0x17,0x28,0x48,0x8b,0x0a,0x1a,0x2b,0x4a,0x8b,0x0a,0x0a,0x53,0x22,
+0x08,0x88,0x90,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29495 0x7337 "猷" */
+0x22,0x12,0x14,0xff,0x14,0x14,0x7f,0x55,0x55,0x63,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x14,0x12,0x92,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 29496 0x7338 "猸" */
+0x00,0x8b,0x52,0x22,0x53,0x92,0x12,0x12,0x32,0x52,0x92,0x12,0x12,0x12,0xa4,0x48,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 29497 0x7339 "猹" */
+0x00,0x90,0x57,0x20,0x51,0x92,0x14,0x13,0x32,0x53,0x92,0x13,0x12,0x10,0xa7,0x40,
+0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 29498 0x733a "猺" */
+0x00,0x44,0x2b,0x10,0x2a,0x49,0x89,0x0a,0x18,0x2b,0x48,0x89,0x09,0x09,0x51,0x20,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 29499 0x733b "猻" */
+0x00,0x8f,0x51,0x21,0x52,0x92,0x13,0x12,0x36,0x5a,0x92,0x12,0x12,0x12,0xa2,0x46,
+0x06,0x78,0x10,0x20,0x44,0x78,0x10,0x24,0x7e,0x12,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 29500 0x733c "猼" */
+0x00,0x44,0x2b,0x10,0x29,0x49,0x89,0x09,0x19,0x29,0x48,0x8b,0x08,0x08,0x50,0x20,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 29501 0x733d "猽" */
+0x00,0x47,0x2a,0x10,0x29,0x49,0x89,0x09,0x19,0x28,0x48,0x8b,0x08,0x08,0x51,0x22,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 29502 0x733e "猾" */
+0x00,0x8b,0x52,0x23,0x52,0x9f,0x18,0x13,0x32,0x53,0x92,0x13,0x12,0x12,0xa2,0x42,
+0x00,0xf8,0x08,0xc8,0x48,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 29503 0x733f "猿" */
+0x00,0x90,0x53,0x20,0x57,0x90,0x13,0x12,0x32,0x53,0x90,0x11,0x13,0x1d,0xa1,0x41,
+0x40,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x08,0xf8,0xa4,0x28,0x10,0x48,0x86,0x00,
+/* 29504 0x7340 "獀" */
+0x01,0x96,0x54,0x24,0x57,0x94,0x14,0x17,0x30,0x57,0x92,0x11,0x10,0x10,0xa1,0x46,
+0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x40,0xfc,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 29505 0x7341 "獁" */
+0x00,0x8b,0x52,0x23,0x52,0x93,0x12,0x12,0x33,0x50,0x95,0x15,0x15,0x14,0xa0,0x40,
+0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x04,0x54,0x54,0x54,0x04,0x28,0x10,
+/* 29506 0x7342 "獂" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x0a,0x52,0x24,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 29507 0x7343 "獃" */
+0x08,0x49,0x49,0x49,0x7f,0x00,0x7f,0x00,0x7f,0x41,0x7f,0x41,0x22,0x0f,0xf0,0x41,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 29508 0x7344 "獄" */
+0x02,0x91,0x51,0x27,0x50,0x97,0x10,0x17,0x30,0x57,0x94,0x14,0x14,0x17,0xa0,0x40,
+0x10,0x14,0x12,0xd2,0x10,0x90,0x3e,0x90,0x10,0x90,0xa8,0xa8,0xa8,0xc4,0x44,0x82,
+/* 29509 0x7345 "獅" */
+0x02,0x94,0x57,0x25,0x55,0x95,0x17,0x14,0x34,0x57,0x95,0x15,0x15,0x17,0xa5,0x40,
+0x00,0xfe,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0x10,0x10,
+/* 29510 0x7346 "獆" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x08,0x1b,0x28,0x49,0x8a,0x0d,0x08,0x50,0x20,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,
+/* 29511 0x7347 "獇" */
+0x02,0x89,0x57,0x20,0x50,0x93,0x10,0x10,0x37,0x50,0x91,0x11,0x12,0x12,0xa4,0x48,
+0x08,0x10,0xfc,0x40,0x40,0xf8,0x40,0x80,0xfc,0xa0,0x28,0x34,0x3c,0x22,0x22,0x1e,
+/* 29512 0x7348 "獈" */
+0x02,0x89,0x51,0x20,0x57,0x90,0x11,0x12,0x34,0x53,0x92,0x12,0x12,0x12,0xaf,0x40,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 29513 0x7349 "獉" */
+0x00,0x88,0x57,0x20,0x53,0x90,0x17,0x11,0x32,0x55,0x90,0x13,0x10,0x11,0xa6,0x40,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x68,0xc6,0x40,0xf8,0xe0,0x58,0x44,0x40,
+/* 29514 0x734a "獊" */
+0x00,0x88,0x50,0x21,0x52,0x97,0x1a,0x13,0x32,0x53,0x92,0x13,0x15,0x15,0xa9,0x41,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 29515 0x734b "獋" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x89,0x09,0x18,0x29,0x48,0x89,0x08,0x0b,0x50,0x20,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,
+/* 29516 0x734c "獌" */
+0x00,0x45,0x29,0x11,0x29,0x49,0x88,0x0b,0x1a,0x2b,0x48,0x89,0x08,0x08,0x51,0x26,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 29517 0x734d "獍" */
+0x00,0x88,0x53,0x21,0x50,0x97,0x10,0x13,0x32,0x53,0x92,0x13,0x11,0x11,0xa2,0x4c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 29518 0x734e "獎" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x84,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x20,0x10,0xfc,0x80,0x40,0x30,0x0e,
+/* 29519 0x734f "獏" */
+0x00,0x44,0x2b,0x10,0x28,0x49,0x89,0x09,0x19,0x29,0x48,0x8b,0x08,0x08,0x51,0x22,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 29520 0x7350 "獐" */
+0x00,0x45,0x28,0x10,0x2b,0x48,0x89,0x09,0x19,0x29,0x49,0x88,0x0b,0x08,0x50,0x20,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29521 0x7351 "獑" */
+0x01,0x89,0x51,0x27,0x51,0x97,0x15,0x17,0x35,0x57,0x91,0x17,0x11,0x11,0xa1,0x41,
+0x00,0x02,0x1c,0xd0,0x10,0xd0,0x5e,0xd4,0x54,0xd4,0x14,0xd4,0x14,0x24,0x24,0x44,
+/* 29522 0x7352 "獒" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x20,0x3e,0x42,0x87,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x20,0x20,0x3e,0x44,0x84,0x28,0x10,0x28,0x44,0x22,0x10,0xfc,0x80,0x40,0x30,0x0e,
+/* 29523 0x7353 "獓" */
+0x01,0x91,0x51,0x27,0x51,0x97,0x11,0x1f,0x32,0x53,0x92,0x12,0x12,0x14,0xa4,0x48,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 29524 0x7354 "獔" */
+0x00,0x44,0x29,0x11,0x29,0x49,0x89,0x08,0x19,0x28,0x49,0x88,0x0b,0x08,0x50,0x20,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 29525 0x7355 "獕" */
+0x00,0x46,0x2b,0x10,0x28,0x49,0x8b,0x0d,0x19,0x29,0x49,0x89,0x09,0x09,0x51,0x21,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 29526 0x7356 "獖" */
+0x00,0x45,0x28,0x10,0x2b,0x48,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x08,0x51,0x22,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 29527 0x7357 "獗" */
+0x00,0x9f,0x58,0x2a,0x69,0xab,0x28,0x28,0x6a,0xaa,0x2b,0x28,0x28,0x29,0xa9,0x52,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 29528 0x7358 "獘" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x40,0x01,0xff,0x02,0x0c,0x30,0xc0,
+0x20,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x44,0x20,0x10,0xfe,0x80,0x60,0x18,0x06,
+/* 29529 0x7359 "獙" */
+0x01,0x89,0x55,0x23,0x51,0x97,0x15,0x15,0x35,0x57,0x95,0x15,0x15,0x15,0xa4,0x44,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 29530 0x735a "獚" */
+0x00,0x44,0x29,0x10,0x28,0x4b,0x88,0x09,0x19,0x29,0x49,0x89,0x08,0x08,0x51,0x22,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 29531 0x735b "獛" */
+0x00,0x94,0x52,0x20,0x57,0x91,0x10,0x17,0x30,0x53,0x90,0x17,0x10,0x11,0xa2,0x4c,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 29532 0x735c "獜" */
+0x00,0x45,0x28,0x13,0x28,0x49,0x8a,0x09,0x19,0x29,0x4a,0x8d,0x08,0x09,0x52,0x24,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 29533 0x735d "獝" */
+0x00,0x45,0x28,0x10,0x2b,0x48,0x88,0x0b,0x18,0x2b,0x4a,0x8a,0x0b,0x0a,0x52,0x22,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 29534 0x735e "獞" */
+0x00,0x45,0x28,0x10,0x2b,0x48,0x89,0x09,0x19,0x29,0x49,0x88,0x09,0x08,0x53,0x20,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29535 0x735f "獟" */
+0x00,0x44,0x29,0x10,0x2b,0x49,0x8b,0x09,0x19,0x2e,0x48,0x8b,0x08,0x08,0x51,0x22,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 29536 0x7360 "獠" */
+0x00,0x90,0x57,0x20,0x55,0x92,0x17,0x1a,0x33,0x52,0x93,0x10,0x12,0x14,0xa9,0x40,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 29537 0x7361 "獡" */
+0x00,0x8b,0x52,0x22,0x53,0x92,0x12,0x13,0x31,0x53,0x94,0x12,0x12,0x14,0xa0,0x40,
+0x80,0x1c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 29538 0x7362 "獢" */
+0x00,0x8b,0x50,0x27,0x51,0x92,0x15,0x19,0x31,0x50,0x97,0x14,0x15,0x15,0xa5,0x44,
+0x38,0xc0,0x80,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x0c,
+/* 29539 0x7363 "獣" */
+0x90,0x49,0x02,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x90,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0xa8,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 29540 0x7364 "獤" */
+0x02,0x89,0x57,0x20,0x57,0x94,0x17,0x10,0x37,0x50,0x91,0x11,0x17,0x11,0xa5,0x42,
+0x08,0x08,0xc8,0x10,0x9e,0x94,0xa4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 29541 0x7365 "獥" */
+0x01,0x8a,0x57,0x24,0x57,0x94,0x17,0x12,0x31,0x57,0x92,0x13,0x12,0x14,0xa5,0x48,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 29542 0x7366 "獦" */
+0x00,0x47,0x28,0x11,0x29,0x49,0x89,0x09,0x18,0x29,0x4a,0x8d,0x09,0x09,0x50,0x20,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 29543 0x7367 "獧" */
+0x00,0x8b,0x52,0x22,0x53,0x90,0x17,0x10,0x33,0x52,0x93,0x10,0x11,0x13,0xad,0x41,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 29544 0x7368 "獨" */
+0x00,0x45,0x29,0x11,0x29,0x48,0x89,0x0a,0x19,0x29,0x49,0x89,0x08,0x0b,0x50,0x20,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfe,0x42,0xf2,0x52,0x52,0xf2,0x4a,0xfa,0x0a,0x04,
+/* 29545 0x7369 "獩" */
+0x00,0x89,0x51,0x27,0x50,0x90,0x13,0x12,0x33,0x52,0x92,0x12,0x13,0x14,0xa8,0x43,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 29546 0x736a "獪" */
+0x00,0x88,0x53,0x2d,0x50,0x97,0x15,0x14,0x37,0x50,0x93,0x12,0x13,0x12,0xa3,0x42,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 29547 0x736b "獫" */
+0x00,0x44,0x28,0x11,0x2a,0x4d,0x88,0x08,0x1b,0x2a,0x4a,0x8b,0x09,0x09,0x52,0x24,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xb8,0xa8,0xa8,0xb8,0x10,0x10,0xa8,0x44,
+/* 29548 0x736c "獬" */
+0x02,0x93,0x54,0x29,0x67,0xa5,0x25,0x27,0x65,0xa5,0x27,0x25,0x25,0x25,0xa4,0x48,
+0x00,0x9e,0x8a,0x0a,0xd2,0x66,0x40,0xd4,0x5e,0x64,0xc4,0x44,0x5e,0x44,0x44,0xc4,
+/* 29549 0x736d "獭" */
+0x02,0x92,0x5f,0x22,0x62,0xaf,0x2a,0x2a,0x6f,0xa2,0x27,0x2a,0x32,0x22,0xa2,0x42,
+0x10,0x10,0x9c,0x24,0x48,0xbe,0xa2,0xaa,0xaa,0x2a,0x2a,0xaa,0x88,0x14,0x22,0x42,
+/* 29550 0x736e "獮" */
+0x00,0x97,0x52,0x24,0x6f,0xa4,0x26,0x25,0x66,0xa4,0x26,0x25,0x26,0x24,0xa4,0x44,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 29551 0x736f "獯" */
+0x00,0x97,0x50,0x2f,0x50,0x97,0x15,0x14,0x37,0x50,0x97,0x10,0x1f,0x10,0xa5,0x48,
+0x3c,0xc0,0x40,0xfe,0x40,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0x00,0x24,0x92,
+/* 29552 0x7370 "獰" */
+0x00,0x88,0x57,0x24,0x52,0x92,0x14,0x10,0x33,0x52,0x9f,0x10,0x17,0x10,0xa1,0x40,
+0x80,0x40,0xfc,0x44,0xa8,0x94,0x74,0x00,0xf8,0xa8,0xfe,0x00,0xfc,0x40,0x40,0x80,
+/* 29553 0x7371 "獱" */
+0x00,0x44,0x2b,0x12,0x29,0x49,0x8a,0x09,0x1b,0x29,0x49,0x89,0x09,0x09,0x50,0x21,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29554 0x7372 "獲" */
+0x00,0x47,0x28,0x10,0x29,0x4b,0x89,0x09,0x19,0x29,0x49,0x89,0x0b,0x08,0x50,0x23,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 29555 0x7373 "獳" */
+0x00,0x45,0x28,0x13,0x2a,0x49,0x88,0x09,0x18,0x2b,0x48,0x89,0x09,0x09,0x51,0x21,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 29556 0x7374 "獴" */
+0x01,0x97,0x51,0x27,0x54,0x93,0x10,0x17,0x30,0x51,0x96,0x11,0x16,0x11,0xa6,0x40,
+0x10,0xfc,0x10,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x44,0xa8,0x70,0xa8,0x26,0xa0,0x40,
+/* 29557 0x7375 "獵" */
+0x01,0x8a,0x51,0x20,0x53,0x92,0x12,0x12,0x33,0x52,0x93,0x12,0x13,0x12,0xa2,0x43,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 29558 0x7376 "獶" */
+0x03,0x88,0x51,0x21,0x51,0x91,0x17,0x14,0x32,0x52,0x94,0x10,0x11,0x12,0xa0,0x43,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 29559 0x7377 "獷" */
+0x00,0x88,0x57,0x24,0x55,0x94,0x17,0x14,0x35,0x55,0x95,0x15,0x15,0x14,0xa4,0x49,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 29560 0x7378 "獸" */
+0x77,0x55,0x77,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x7f,0x41,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0xa8,0x28,0x44,0x44,0x84,0x02,
+/* 29561 0x7379 "獹" */
+0x00,0x88,0x50,0x23,0x52,0x93,0x12,0x12,0x32,0x52,0x92,0x12,0x12,0x15,0xa5,0x4b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 29562 0x737a "獺" */
+0x01,0x89,0x57,0x21,0x51,0x97,0x15,0x15,0x37,0x51,0x93,0x15,0x19,0x11,0xa1,0x41,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 29563 0x737b "獻" */
+0x08,0x0f,0x08,0x7f,0x49,0x5e,0x49,0x7f,0x4a,0x5f,0x51,0x5b,0x55,0x5f,0x55,0x95,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 29564 0x737c "獼" */
+0x00,0x9e,0x52,0x22,0x62,0xae,0x28,0x28,0x68,0xae,0x22,0x22,0x22,0x22,0xaa,0x44,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 29565 0x737d "獽" */
+0x00,0x97,0x50,0x23,0x52,0x93,0x11,0x17,0x31,0x57,0x91,0x1f,0x11,0x13,0xad,0x41,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 29566 0x737e "獾" */
+0x01,0x8f,0x51,0x27,0x54,0x97,0x11,0x11,0x33,0x52,0x97,0x1a,0x13,0x12,0xa3,0x42,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0x40,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29567 0x737f "獿" */
+0x00,0x97,0x50,0x22,0x62,0xab,0x2a,0x2a,0x6b,0xac,0x22,0x25,0x22,0x20,0xa1,0x46,
+0x00,0xfe,0x40,0xee,0xaa,0xea,0xae,0xe8,0xaa,0xe6,0x88,0xf4,0x90,0x60,0x98,0x06,
+/* 29568 0x7380 "玀" */
+0x00,0x97,0x54,0x24,0x67,0xa2,0x22,0x24,0x6f,0xa2,0x24,0x2f,0x20,0x2a,0xaa,0x40,
+0x00,0xfc,0xa4,0xa4,0xfc,0x10,0xa8,0xbe,0x68,0x3c,0xa8,0xbc,0x28,0xa8,0xbe,0x20,
+/* 29569 0x7381 "玁" */
+0x07,0x94,0x57,0x20,0x57,0x94,0x15,0x14,0x37,0x55,0x95,0x15,0x15,0x15,0xab,0x50,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 29570 0x7382 "玂" */
+0x02,0x97,0x52,0x2e,0x6a,0xae,0x20,0x27,0x65,0xa7,0x25,0x27,0x21,0x2f,0xa1,0x41,
+0x40,0xe2,0x5c,0xf0,0xb0,0xf0,0x1e,0xd4,0x54,0xd4,0x54,0xd4,0x14,0xe4,0x24,0x44,
+/* 29571 0x7383 "玃" */
+0x03,0x46,0x2b,0x12,0x2b,0x48,0x89,0x0b,0x1d,0x29,0x49,0x88,0x09,0x08,0x50,0x27,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 29572 0x7384 "玄" */
+0x02,0x01,0x01,0xff,0x02,0x04,0x08,0x10,0x3f,0x11,0x02,0x04,0x08,0x3f,0x10,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x20,0x10,0xf8,0x08,0x08,
+/* 29573 0x7385 "玅" */
+0x10,0x08,0x08,0xfe,0x10,0x10,0x20,0x42,0xfc,0x48,0x10,0x20,0x44,0xfe,0x42,0x00,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 29574 0x7386 "玆" */
+0x10,0x08,0x08,0xfe,0x10,0x10,0x20,0x42,0xfc,0x48,0x10,0x20,0x44,0xfe,0x42,0x00,
+0x10,0x08,0x08,0xfe,0x10,0x10,0x20,0x42,0xfc,0x48,0x10,0x20,0x44,0xfe,0x42,0x00,
+/* 29575 0x7387 "率" */
+0x02,0x01,0x7f,0x02,0x44,0x2f,0x11,0x22,0x4f,0x00,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x44,0x88,0x10,0x48,0xe4,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 29576 0x7388 "玈" */
+0x10,0x08,0x08,0xfe,0x11,0x10,0x20,0x42,0xfc,0x48,0x10,0x20,0x44,0xfe,0x42,0x00,
+0x40,0x40,0x7e,0x80,0x00,0x1c,0xe0,0xa0,0xa2,0xa4,0xa8,0x90,0x90,0xa8,0xc4,0x82,
+/* 29577 0x7389 "玉" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x20,0x10,0x10,0x00,0xfe,0x00,
+/* 29578 0x738a "玊" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfc,0x00,0x20,0x10,0x10,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 29579 0x738b "王" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 29580 0x738c "玌" */
+0x00,0x00,0xff,0x08,0x08,0x08,0x08,0x7e,0x08,0x08,0x08,0x08,0x0f,0xf0,0x40,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 29581 0x738d "玍" */
+0x10,0x10,0x10,0x3f,0x21,0x41,0x81,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 29582 0x738e "玎" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 29583 0x738f "玏" */
+0x00,0x00,0xfe,0x10,0x11,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf1,0x41,0x02,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 29584 0x7390 "玐" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1e,0xe2,0x44,0x08,0x10,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 29585 0x7391 "玑" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 29586 0x7392 "玒" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x03,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29587 0x7393 "玓" */
+0x00,0x00,0xfe,0x10,0x11,0x12,0x7c,0x11,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 29588 0x7394 "玔" */
+0x01,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 29589 0x7395 "玕" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x13,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 29590 0x7396 "玖" */
+0x00,0x00,0xfc,0x10,0x11,0x11,0x7d,0x12,0x10,0x10,0x10,0x1c,0xe0,0x41,0x02,0x04,
+0x80,0x80,0x80,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 29591 0x7397 "玗" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x13,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 29592 0x7398 "玘" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x10,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 29593 0x7399 "玙" */
+0x00,0x00,0xfc,0x10,0x10,0x11,0x11,0x7d,0x10,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,
+0x80,0x80,0x80,0xfe,0x80,0x00,0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 29594 0x739a "玚" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7d,0x10,0x10,0x10,0x11,0x1d,0xe2,0x44,0x00,0x01,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 29595 0x739b "玛" */
+0x00,0x03,0xfc,0x10,0x11,0x11,0x11,0x7d,0x10,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xfe,0x02,0x02,0x02,0xfa,0x02,0x02,0x14,0x08,
+/* 29596 0x739c "玜" */
+0x00,0x00,0xfc,0x10,0x10,0x11,0x7d,0x12,0x14,0x10,0x10,0x1c,0xe1,0x43,0x01,0x00,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x40,0x40,0x88,0x84,0x04,0xfe,0x02,0x00,
+/* 29597 0x739d "玝" */
+0x00,0x00,0xfc,0x11,0x11,0x12,0x7c,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 29598 0x739e "玞" */
+0x00,0x00,0xfc,0x10,0x11,0x10,0x7c,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 29599 0x739f "玟" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe0,0x41,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 29600 0x73a0 "玠" */
+0x00,0x00,0xfc,0x10,0x10,0x11,0x7e,0x10,0x10,0x10,0x10,0x1c,0xe0,0x41,0x01,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 29601 0x73a1 "玡" */
+0x00,0x01,0xfe,0x10,0x10,0x10,0x7d,0x11,0x10,0x10,0x10,0x1e,0xf1,0x42,0x00,0x00,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 29602 0x73a2 "玢" */
+0x00,0x00,0xfc,0x10,0x11,0x11,0x12,0x7d,0x10,0x10,0x10,0x10,0x1d,0xe1,0x42,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 29603 0x73a3 "玣" */
+0x00,0x00,0xfe,0x10,0x13,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x40,0x20,0x20,0x00,0xfe,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,
+/* 29604 0x73a4 "玤" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x10,0x7d,0x10,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 29605 0x73a5 "玥" */
+0x00,0x00,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf1,0x41,0x02,0x04,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 29606 0x73a6 "玦" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x7c,0x10,0x17,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 29607 0x73a7 "玧" */
+0x00,0x00,0xfc,0x10,0x11,0x13,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 29608 0x73a8 "玨" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x7c,0x10,0x11,0x10,0x10,0x1c,0xe0,0x40,0x03,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29609 0x73a9 "玩" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x13,0x7c,0x10,0x10,0x10,0x10,0x1d,0xe1,0x42,0x04,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 29610 0x73aa "玪" */
+0x00,0x00,0xfc,0x10,0x10,0x11,0x12,0x7c,0x10,0x11,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 29611 0x73ab "玫" */
+0x00,0x00,0xfe,0x10,0x10,0x11,0x7e,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x01,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 29612 0x73ac "玬" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x17,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x00,0xf8,0x08,0x08,0x48,0x28,0x28,0x08,0xfe,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 29613 0x73ad "玭" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 29614 0x73ae "玮" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x11,0x7c,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x42,0x42,0x4a,0x44,0x40,0x40,
+/* 29615 0x73af "环" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x10,0x7c,0x10,0x11,0x12,0x10,0x1c,0xe0,0x40,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 29616 0x73b0 "现" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x10,0x10,0x1c,0xe1,0x42,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 29617 0x73b1 "玱" */
+0x00,0x00,0xfe,0x10,0x10,0x11,0x7e,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 29618 0x73b2 "玲" */
+0x00,0x00,0xfc,0x10,0x10,0x11,0x12,0x7c,0x11,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 29619 0x73b3 "玳" */
+0x00,0x00,0xfc,0x10,0x10,0x11,0x11,0x7e,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x50,0x54,0x52,0x92,0x90,0x9e,0xf0,0x90,0x90,0x90,0x90,0x90,0x8a,0x8a,0x86,0x82,
+/* 29620 0x73b4 "玴" */
+0x00,0x01,0xfd,0x11,0x11,0x13,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 29621 0x73b5 "玵" */
+0x00,0x00,0xfe,0x10,0x13,0x10,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 29622 0x73b6 "玶" */
+0x00,0x01,0xfc,0x10,0x11,0x10,0x7c,0x10,0x13,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 29623 0x73b7 "玷" */
+0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0x7c,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29624 0x73b8 "玸" */
+0x00,0x00,0xfd,0x11,0x12,0x15,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 29625 0x73b9 "玹" */
+0x00,0x00,0xfe,0x11,0x10,0x10,0x7c,0x10,0x11,0x10,0x10,0x1e,0xf0,0x41,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 29626 0x73ba "玺" */
+0x08,0x08,0x1f,0x21,0x41,0x09,0x11,0x25,0x02,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x00,0xfc,0x04,0x08,0x20,0x10,0x08,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 29627 0x73bb "玻" */
+0x00,0x00,0xf8,0x23,0x22,0x22,0x22,0xfb,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x09,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 29628 0x73bc "玼" */
+0x00,0x00,0xf8,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x22,0x3a,0xe3,0x4e,0x04,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 29629 0x73bd "玽" */
+0x00,0x00,0xfd,0x11,0x12,0x14,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 29630 0x73be "玾" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe0,0x40,0x00,0x00,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 29631 0x73bf "玿" */
+0x00,0x01,0xfe,0x10,0x10,0x10,0x7c,0x10,0x11,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 29632 0x73c0 "珀" */
+0x00,0x00,0xfc,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29633 0x73c1 "珁" */
+0x00,0x00,0xfb,0x21,0x21,0x21,0x21,0xf9,0x21,0x22,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x90,0x50,0x50,0x10,0x12,0x92,0x12,0x0e,
+/* 29634 0x73c2 "珂" */
+0x00,0x00,0xfd,0x10,0x10,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe0,0x40,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 29635 0x73c3 "珃" */
+0x00,0x00,0xfc,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x13,0x11,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 29636 0x73c4 "珄" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x12,0x7c,0x10,0x11,0x10,0x10,0x1c,0xe0,0x43,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29637 0x73c5 "珅" */
+0x00,0x00,0xfc,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 29638 0x73c6 "珆" */
+0x00,0x00,0xfc,0x10,0x11,0x13,0x7c,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29639 0x73c7 "珇" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 29640 0x73c8 "珈" */
+0x02,0x02,0xfa,0x22,0x27,0x22,0x22,0xfa,0x22,0x22,0x22,0x3a,0xe4,0x44,0x09,0x10,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x5e,0x52,0x80,
+/* 29641 0x73c9 "珉" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 29642 0x73ca "珊" */
+0x00,0xf7,0x24,0x24,0x24,0x24,0xf4,0x2f,0x24,0x24,0x24,0x34,0xe4,0x45,0x08,0x10,
+0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0xfe,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x54,0x88,
+/* 29643 0x73cb "珋" */
+0x00,0x00,0xfb,0x22,0x22,0x22,0x22,0xfa,0x22,0x22,0x23,0x3a,0xe0,0x40,0x01,0x02,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 29644 0x73cc "珌" */
+0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0xfa,0x22,0x22,0x24,0x38,0xe1,0x42,0x04,0x00,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 29645 0x73cd "珍" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x7c,0x10,0x11,0x10,0x10,0x1c,0xe1,0x40,0x00,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 29646 0x73ce "珎" */
+0x00,0x00,0xfc,0x10,0x11,0x11,0x7e,0x10,0x10,0x10,0x11,0x1d,0xe2,0x40,0x00,0x00,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 29647 0x73cf "珏" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x10,0x7c,0x11,0x10,0x10,0x10,0x1c,0xe0,0x43,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x24,0x20,0xfe,0x00,
+/* 29648 0x73d0 "珐" */
+0x00,0x00,0xfc,0x11,0x10,0x10,0x10,0x7d,0x10,0x10,0x10,0x10,0x1c,0xe1,0x40,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 29649 0x73d1 "珑" */
+0x00,0x00,0xfc,0x10,0x13,0x10,0x10,0x7c,0x10,0x10,0x11,0x11,0x1d,0xe2,0x42,0x04,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0xa8,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 29650 0x73d2 "珒" */
+0x00,0x00,0xfd,0x10,0x13,0x10,0x7d,0x10,0x10,0x11,0x10,0x1c,0xe3,0x40,0x00,0x00,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 29651 0x73d3 "珓" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x7d,0x12,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 29652 0x73d4 "珔" */
+0x00,0x00,0xf8,0x27,0x20,0x20,0xf9,0x21,0x23,0x25,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 29653 0x73d5 "珕" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x7d,0x12,0x11,0x13,0x11,0x1d,0xe1,0x42,0x03,0x04,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 29654 0x73d6 "珖" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x13,0x7c,0x10,0x10,0x10,0x10,0x1d,0xe1,0x42,0x04,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 29655 0x73d7 "珗" */
+0x00,0x01,0xfd,0x11,0x11,0x12,0x7c,0x13,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 29656 0x73d8 "珘" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x13,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x20,0x40,0xf8,0x08,0x48,0x28,0x28,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 29657 0x73d9 "珙" */
+0x00,0x00,0xfc,0x10,0x13,0x10,0x10,0x7c,0x10,0x17,0x10,0x10,0x1c,0xe1,0x42,0x04,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 29658 0x73da "珚" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 29659 0x73db "珛" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x7c,0x11,0x12,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 29660 0x73dc "珜" */
+0x01,0x00,0xfc,0x10,0x13,0x10,0x7c,0x11,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 29661 0x73dd "珝" */
+0x00,0x03,0xf8,0x20,0x22,0x21,0xf9,0x20,0x20,0x21,0x22,0x38,0xe0,0x40,0x01,0x00,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 29662 0x73de "珞" */
+0x00,0x00,0xf8,0x21,0x23,0x24,0x20,0xf8,0x21,0x22,0x25,0x21,0x39,0xe1,0x01,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 29663 0x73df "珟" */
+0x00,0x07,0xf4,0x24,0x27,0x24,0x24,0xf4,0x25,0x25,0x26,0x24,0x34,0xc8,0x09,0x12,
+0x00,0xf8,0x08,0x08,0xf8,0x88,0x88,0xe8,0x28,0x28,0xa8,0x4a,0x4a,0x8a,0x06,0x02,
+/* 29664 0x73e0 "珠" */
+0x00,0x01,0xfd,0x11,0x11,0x12,0x7c,0x13,0x10,0x10,0x10,0x1d,0xe1,0x42,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 29665 0x73e1 "珡" */
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x01,0x01,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x00,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 29666 0x73e2 "珢" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 29667 0x73e3 "珣" */
+0x00,0x00,0xfd,0x11,0x12,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 29668 0x73e4 "珤" */
+0x00,0x00,0xfc,0x11,0x11,0x12,0x7c,0x10,0x17,0x10,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 29669 0x73e5 "珥" */
+0x00,0x03,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe3,0x40,0x00,0x00,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 29670 0x73e6 "珦" */
+0x00,0x00,0xfc,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x20,0x40,0xfe,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 29671 0x73e7 "珧" */
+0x00,0x00,0xf8,0x22,0x21,0x20,0x20,0xf9,0x22,0x24,0x20,0x20,0x39,0xe1,0x02,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 29672 0x73e8 "珨" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x11,0x7c,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 29673 0x73e9 "珩" */
+0x00,0x00,0xf9,0x22,0x24,0x20,0x21,0xfb,0x25,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 29674 0x73ea "珪" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x13,0x7c,0x10,0x10,0x11,0x10,0x1c,0xe0,0x43,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 29675 0x73eb "珫" */
+0x00,0x00,0xfc,0x13,0x10,0x10,0x7d,0x13,0x10,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 29676 0x73ec "珬" */
+0x00,0x00,0xf8,0x20,0x23,0x22,0x22,0xfa,0x22,0x23,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 29677 0x73ed "班" */
+0x00,0x00,0xf8,0x22,0x22,0x22,0x22,0xfa,0x22,0x24,0x20,0x39,0xe1,0x42,0x04,0x08,
+0x80,0x80,0xbe,0x88,0x88,0x88,0x88,0xbe,0x88,0x88,0x88,0x08,0x08,0x3e,0x00,0x00,
+/* 29678 0x73ee "珮" */
+0x00,0x07,0xf4,0x24,0x25,0x24,0x24,0xf5,0x25,0x25,0x25,0x25,0x35,0xc4,0x04,0x08,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0x44,0xf4,0x54,0x54,0x54,0x54,0x74,0x46,0x46,0x42,
+/* 29679 0x73ef "珯" */
+0x00,0x00,0xfc,0x11,0x10,0x10,0x13,0x7c,0x10,0x11,0x12,0x10,0x1c,0xe0,0x40,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 29680 0x73f0 "珰" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x11,0x7c,0x10,0x10,0x11,0x10,0x1c,0xe0,0x41,0x00,
+0x20,0x24,0xa4,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29681 0x73f1 "珱" */
+0x00,0x00,0xfa,0x21,0x21,0x20,0x20,0xf8,0x23,0x20,0x21,0x39,0xe0,0x40,0x01,0x06,
+0x40,0x24,0x24,0x08,0x08,0x10,0x40,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 29682 0x73f2 "珲" */
+0x00,0x03,0xfa,0x24,0x20,0x23,0x20,0xf8,0x21,0x21,0x20,0x38,0xe3,0x40,0x00,0x00,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 29683 0x73f3 "珳" */
+0x02,0x01,0xf9,0x2f,0x22,0x22,0x22,0xfa,0x22,0x21,0x21,0x39,0xe2,0x42,0x04,0x08,
+0x04,0x04,0x08,0xe8,0x94,0xa4,0x88,0x8a,0x92,0x24,0x04,0x08,0x90,0x40,0x3e,0x00,
+/* 29684 0x73f4 "珴" */
+0x00,0x00,0xfb,0x20,0x20,0x23,0xf8,0x20,0x20,0x20,0x23,0x38,0xe0,0x40,0x02,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 29685 0x73f5 "珵" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7c,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x03,0x00,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29686 0x73f6 "珶" */
+0x01,0x00,0xfc,0x11,0x10,0x10,0x11,0x7d,0x11,0x11,0x10,0x10,0x1d,0xe2,0x44,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 29687 0x73f7 "珷" */
+0x00,0x00,0xfb,0x20,0x20,0x27,0x20,0xf8,0x20,0x22,0x22,0x3a,0xe2,0x42,0x07,0x02,
+0x10,0x18,0xd4,0x14,0x10,0xfe,0x10,0x90,0x90,0xd0,0x90,0x90,0x8a,0xea,0x06,0x02,
+/* 29688 0x73f8 "珸" */
+0x00,0x03,0xf8,0x20,0x21,0x20,0x20,0xfb,0x20,0x20,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29689 0x73f9 "珹" */
+0x00,0x00,0xf8,0x20,0x23,0x22,0x22,0xfa,0x23,0x22,0x22,0x3a,0xe2,0x45,0x04,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 29690 0x73fa "珺" */
+0x00,0x01,0xfc,0x10,0x13,0x10,0x7c,0x11,0x10,0x10,0x11,0x1e,0xe4,0x40,0x00,0x00,
+0x00,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x80,0x80,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 29691 0x73fb "珻" */
+0x00,0x00,0xfc,0x11,0x12,0x10,0x7c,0x10,0x13,0x10,0x11,0x1d,0xe1,0x40,0x00,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 29692 0x73fc "珼" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe0,0x40,0x01,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 29693 0x73fd "珽" */
+0x00,0x00,0xfb,0x20,0x20,0x21,0x21,0xfb,0x20,0x22,0x22,0x39,0xe1,0x42,0x04,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 29694 0x73fe "現" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x10,0x1c,0xe0,0x41,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 29695 0x73ff "珿" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7c,0x10,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 29696 0x7400 "琀" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x10,0x7c,0x10,0x10,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29697 0x7401 "琁" */
+0x01,0x01,0xfd,0x12,0x14,0x11,0x7c,0x10,0x11,0x11,0x11,0x1d,0xe1,0x42,0x04,0x08,
+0x00,0x00,0xfe,0x00,0x00,0xfe,0x22,0x24,0x20,0x3c,0x20,0x20,0x20,0xa0,0x7e,0x00,
+/* 29698 0x7402 "琂" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x20,0x10,0xfe,0x00,0x00,0xfc,0x00,0x00,0xfc,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 29699 0x7403 "球" */
+0x00,0x00,0xfc,0x10,0x13,0x10,0x11,0x7c,0x10,0x10,0x10,0x11,0x1e,0xe0,0x40,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 29700 0x7404 "琄" */
+0x00,0x00,0xfc,0x10,0x10,0x10,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 29701 0x7405 "琅" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 29702 0x7406 "理" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x10,0x10,0x11,0x10,0x1c,0xe0,0x43,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 29703 0x7407 "琇" */
+0x00,0x01,0xfc,0x10,0x13,0x10,0x7d,0x12,0x11,0x10,0x10,0x1c,0xe1,0x41,0x02,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 29704 0x7408 "琈" */
+0x00,0x00,0xfd,0x10,0x11,0x10,0x10,0x7d,0x10,0x10,0x13,0x10,0x1c,0xe0,0x40,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 29705 0x7409 "琉" */
+0x00,0x00,0xfb,0x20,0x20,0x21,0x23,0xf8,0x21,0x21,0x21,0x39,0xe2,0x42,0x04,0x08,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 29706 0x740a "琊" */
+0x00,0x07,0xf8,0x24,0x24,0x24,0x27,0xf8,0x21,0x21,0x22,0x3a,0xe4,0x48,0x02,0x01,
+0x00,0xde,0x92,0x92,0x94,0x94,0xd8,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x90,0x10,
+/* 29707 0x740b "琋" */
+0x01,0x00,0xf8,0x20,0x23,0x20,0xfb,0x20,0x21,0x23,0x25,0x39,0xe1,0x41,0x00,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 29708 0x740c "琌" */
+0x00,0x01,0xfd,0x11,0x11,0x10,0x7c,0x10,0x11,0x12,0x10,0x1d,0xe0,0x40,0x00,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x10,0x10,0x20,
+/* 29709 0x740d "琍" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x27,0xf8,0x21,0x21,0x22,0x3a,0xe4,0x40,0x00,0x00,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 29710 0x740e "琎" */
+0x00,0x02,0xfd,0x11,0x10,0x10,0x7c,0x13,0x11,0x11,0x11,0x1d,0xe1,0x41,0x02,0x04,
+0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0x24,0x44,0x00,0xfe,0x00,
+/* 29711 0x740f "琏" */
+0x00,0x04,0xfa,0x22,0x20,0x20,0x2e,0xfa,0x22,0x22,0x23,0x3a,0xe2,0x45,0x08,0x00,
+0x20,0x20,0x20,0xfe,0x40,0x50,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 29712 0x7410 "琐" */
+0x00,0x01,0xfc,0x10,0x10,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe0,0x41,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x88,0x04,0x02,
+/* 29713 0x7411 "琑" */
+0x00,0x01,0xfc,0x10,0x10,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 29714 0x7412 "琒" */
+0x00,0x00,0xfc,0x10,0x11,0x10,0x7c,0x13,0x10,0x10,0x10,0x1c,0xe3,0x40,0x00,0x00,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 29715 0x7413 "琓" */
+0x00,0x00,0xfb,0x22,0x24,0x21,0x20,0xf8,0x23,0x20,0x20,0x38,0xe1,0x41,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 29716 0x7414 "琔" */
+0x00,0x00,0xfb,0x22,0x24,0x20,0x23,0xf8,0x20,0x21,0x21,0x39,0xe2,0x42,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 29717 0x7415 "琕" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x10,0x11,0x13,0x1c,0xe0,0x40,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 29718 0x7416 "琖" */
+0x00,0x00,0xfc,0x11,0x10,0x10,0x7c,0x11,0x10,0x10,0x11,0x1c,0xe0,0x40,0x00,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 29719 0x7417 "琗" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x7d,0x12,0x10,0x10,0x13,0x1c,0xe0,0x40,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 29720 0x7418 "琘" */
+0x00,0x03,0xfa,0x23,0x22,0x22,0x23,0xfa,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29721 0x7419 "琙" */
+0x00,0x00,0xf8,0x27,0x20,0x20,0xfb,0x22,0x22,0x22,0x23,0x38,0xe0,0x47,0x02,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 29722 0x741a "琚" */
+0x00,0x03,0xfa,0x22,0x23,0x22,0x22,0xfb,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 29723 0x741b "琛" */
+0x00,0x07,0xfc,0x24,0x21,0x22,0x20,0xf8,0x27,0x20,0x20,0x39,0xe2,0x4c,0x00,0x00,
+0x00,0xfc,0x04,0xa4,0x10,0x08,0x40,0x40,0xfc,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 29724 0x741c "琜" */
+0x00,0x00,0xf8,0x27,0x20,0x22,0x22,0xfa,0x25,0x20,0x21,0x39,0xe2,0x44,0x08,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x54,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 29725 0x741d "琝" */
+0x01,0x01,0xfd,0x11,0x11,0x11,0x7d,0x10,0x10,0x13,0x10,0x1c,0xe0,0x40,0x00,0x07,
+0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x40,0x20,0xfe,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 29726 0x741e "琞" */
+0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x02,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x14,0x08,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 29727 0x741f "琟" */
+0x00,0x00,0xfc,0x11,0x11,0x13,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0xa0,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 29728 0x7420 "琠" */
+0x00,0x00,0xfc,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x13,0x1c,0xe0,0x41,0x02,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x88,0x04,0x02,
+/* 29729 0x7421 "琡" */
+0x01,0x01,0xf9,0x21,0x21,0x21,0x27,0xf8,0x21,0x21,0x25,0x3d,0xe9,0x41,0x05,0x02,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 29730 0x7422 "琢" */
+0x00,0x03,0xf8,0x20,0x21,0x22,0x20,0xfa,0x21,0x22,0x20,0x38,0xe1,0x42,0x00,0x00,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 29731 0x7423 "琣" */
+0x00,0x00,0xf9,0x20,0x21,0x20,0x20,0xfb,0x20,0x20,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 29732 0x7424 "琤" */
+0x00,0x00,0xfd,0x11,0x12,0x15,0x7c,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x00,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 29733 0x7425 "琥" */
+0x00,0x00,0xf8,0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x22,0x3a,0xe4,0x44,0x09,0x12,
+0x40,0x40,0x7c,0x40,0xfc,0x44,0x70,0xc0,0x44,0x3c,0x00,0xf0,0x90,0x92,0x12,0x0e,
+/* 29734 0x7426 "琦" */
+0x00,0x00,0xfb,0x20,0x21,0x22,0x27,0xf8,0x23,0x22,0x22,0x3a,0xe3,0x40,0x00,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xfe,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 29735 0x7427 "琧" */
+0x00,0x7f,0x04,0x3c,0x20,0x3c,0x04,0xff,0x00,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x40,0x78,0x08,0x78,0x40,0xfe,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 29736 0x7428 "琨" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7d,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 29737 0x7429 "琩" */
+0x00,0x00,0xfc,0x10,0x10,0x10,0x7c,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 29738 0x742a "琪" */
+0x01,0x01,0xfb,0x21,0x21,0x21,0x21,0xf9,0x21,0x21,0x21,0x3b,0xe0,0x40,0x01,0x02,
+0x08,0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 29739 0x742b "琫" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x13,0x7c,0x11,0x12,0x10,0x10,0x1d,0xe0,0x40,0x00,
+0x20,0x20,0xfc,0x40,0xf8,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfc,0x20,0x20,0x20,
+/* 29740 0x742c "琬" */
+0x00,0x00,0xfb,0x22,0x25,0x21,0x21,0xfa,0x22,0x23,0x24,0x38,0xe1,0x41,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 29741 0x742d "琭" */
+0x00,0x01,0xfc,0x10,0x11,0x10,0x7c,0x13,0x10,0x12,0x11,0x1c,0xe1,0x42,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 29742 0x742e "琮" */
+0x00,0x00,0xfb,0x22,0x20,0x21,0x20,0xf8,0x23,0x20,0x21,0x39,0xe2,0x44,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 29743 0x742f "琯" */
+0x00,0x00,0xfd,0x11,0x12,0x10,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 29744 0x7430 "琰" */
+0x00,0x01,0xf9,0x22,0x20,0x20,0x23,0xf8,0x20,0x21,0x21,0x22,0x38,0xe0,0x01,0x06,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 29745 0x7431 "琱" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x42,0x02,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 29746 0x7432 "琲" */
+0x00,0x00,0xf8,0x23,0x20,0x20,0x20,0xfb,0x20,0x20,0x20,0x23,0x38,0xe0,0x00,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 29747 0x7433 "琳" */
+0x01,0x01,0xf9,0x21,0x27,0x21,0x21,0xfb,0x23,0x25,0x25,0x39,0xe1,0x41,0x01,0x01,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 29748 0x7434 "琴" */
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x01,0x06,0x1a,0xe1,0x1f,0x00,0x00,0x01,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0xc0,0x30,0x0e,0xe0,0x40,0x80,0x00,
+/* 29749 0x7435 "琵" */
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x80,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 29750 0x7436 "琶" */
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x1f,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x02,0x02,0xfe,
+/* 29751 0x7437 "琷" */
+0x01,0x00,0xf8,0x23,0x20,0x20,0x21,0xf8,0x20,0x27,0x20,0x38,0xe1,0x41,0x02,0x04,
+0x08,0x88,0x90,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0xa0,0xa0,0x20,0x22,0x22,0x1e,
+/* 29752 0x7438 "琸" */
+0x00,0x00,0xfc,0x10,0x11,0x11,0x11,0x7d,0x11,0x11,0x10,0x13,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 29753 0x7439 "琹" */
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x01,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 29754 0x743a "琺" */
+0x02,0x01,0xf9,0x24,0x22,0x22,0x20,0xf9,0x21,0x22,0x26,0x22,0x3a,0xe2,0x02,0x00,
+0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x7e,0x10,0x10,0x20,0x24,0x42,0xfe,0x42,0x00,
+/* 29755 0x743b "琻" */
+0x00,0x00,0xfc,0x10,0x11,0x12,0x10,0x7c,0x10,0x11,0x10,0x11,0x1c,0xe0,0x43,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 29756 0x743c "琼" */
+0x00,0x00,0xfb,0x20,0x20,0x21,0xf9,0x21,0x21,0x20,0x21,0x39,0xe2,0x44,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 29757 0x743d "琽" */
+0x00,0x00,0xfd,0x10,0x10,0x13,0x7c,0x10,0x10,0x11,0x12,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 29758 0x743e "琾" */
+0x03,0x02,0xfa,0x23,0x22,0x22,0x23,0xf8,0x21,0x22,0x25,0x21,0x39,0xe1,0x02,0x04,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,
+/* 29759 0x743f "琿" */
+0x00,0x03,0xfa,0x20,0x23,0x20,0xf9,0x21,0x21,0x21,0x21,0x38,0xe3,0x40,0x00,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29760 0x7440 "瑀" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0x21,0xf9,0x20,0x23,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 29761 0x7441 "瑁" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x11,0x7c,0x10,0x10,0x10,0x10,0x1c,0xe0,0x40,0x00,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 29762 0x7442 "瑂" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x00,0xfe,0x12,0x12,0xfe,0x00,0x7e,0x42,0x42,0x7e,0x42,0x7e,0x42,0x42,0x7e,0x42,
+/* 29763 0x7443 "瑃" */
+0x00,0x00,0xfb,0x20,0x21,0x20,0x23,0xf9,0x22,0x25,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 29764 0x7444 "瑄" */
+0x00,0x00,0xfb,0x22,0x24,0x21,0x20,0xf9,0x21,0x21,0x21,0x39,0xe1,0x40,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 29765 0x7445 "瑅" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x10,0x13,0x10,0x1d,0xe1,0x41,0x02,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 29766 0x7446 "瑆" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x10,0x7d,0x11,0x12,0x10,0x11,0x1c,0xe0,0x43,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29767 0x7447 "瑇" */
+0x00,0x01,0xfc,0x10,0x10,0x11,0x7c,0x10,0x10,0x10,0x11,0x1c,0xe1,0x41,0x00,0x00,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0xa4,0x94,0xfe,0xa4,0x14,0xfe,0x04,0x18,
+/* 29768 0x7448 "瑈" */
+0x00,0x01,0xfc,0x10,0x13,0x10,0x7c,0x11,0x12,0x10,0x13,0x1c,0xe0,0x41,0x06,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29769 0x7449 "瑉" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x10,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 29770 0x744a "瑊" */
+0x00,0x00,0xf8,0x23,0x22,0x22,0x22,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x04,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 29771 0x744b "瑋" */
+0x00,0x00,0xfd,0x10,0x13,0x10,0x7d,0x11,0x11,0x10,0x13,0x1c,0xe2,0x43,0x00,0x00,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 29772 0x744c "瑌" */
+0x00,0x03,0xfc,0x10,0x11,0x11,0x11,0x7d,0x11,0x11,0x10,0x13,0x1c,0xe0,0x41,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 29773 0x744d "瑍" */
+0x00,0x00,0xf8,0x21,0x22,0x25,0xf9,0x21,0x21,0x21,0x20,0x3b,0xe0,0x40,0x01,0x06,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0x54,0x8c,0x24,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 29774 0x744e "瑎" */
+0x01,0x01,0xfd,0x11,0x11,0x11,0x7d,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 29775 0x744f "瑏" */
+0x00,0x00,0xfb,0x22,0x20,0x21,0x21,0xf8,0x21,0x23,0x20,0x38,0xe1,0x46,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x88,0x04,0xfc,0x90,0x10,0xfe,0x50,0x90,0x10,0x10,0x50,0x20,
+/* 29776 0x7450 "瑐" */
+0x01,0x00,0xf8,0x27,0x20,0x23,0x22,0xfa,0x23,0x22,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 29777 0x7451 "瑑" */
+0x00,0x00,0xfd,0x11,0x10,0x13,0x10,0x7c,0x13,0x10,0x10,0x13,0x1c,0xe0,0x43,0x00,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 29778 0x7452 "瑒" */
+0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0x7d,0x10,0x10,0x11,0x12,0x1c,0xe1,0x40,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 29779 0x7453 "瑓" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0xf9,0x21,0x21,0x21,0x20,0x38,0xe0,0x41,0x02,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 29780 0x7454 "瑔" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x10,0x10,0x13,0x10,0x1d,0xe1,0x42,0x04,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 29781 0x7455 "瑕" */
+0x00,0x03,0xfa,0x22,0x22,0x23,0x22,0xfa,0x23,0x22,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 29782 0x7456 "瑖" */
+0x00,0x03,0xfa,0x22,0x23,0x22,0x22,0xfa,0x23,0x22,0x22,0x3b,0xe6,0x42,0x02,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 29783 0x7457 "瑗" */
+0x00,0x07,0xfa,0x21,0x20,0x23,0x20,0xf8,0x27,0x21,0x21,0x3a,0xe2,0x44,0x08,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 29784 0x7458 "瑘" */
+0x00,0x0f,0xf4,0x24,0x24,0x27,0x24,0xf4,0x27,0x24,0x24,0x25,0x3e,0xc0,0x00,0x00,
+0x00,0xde,0x92,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0x92,0xda,0x94,0x90,0x90,0x90,
+/* 29785 0x7459 "瑙" */
+0x00,0x01,0xfa,0x21,0x20,0x20,0x20,0xfb,0x22,0x22,0x22,0x3a,0xe2,0x42,0x03,0x02,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 29786 0x745a "瑚" */
+0x01,0x01,0xf9,0x27,0x21,0x21,0x21,0xfb,0x22,0x22,0x22,0x3a,0xe3,0x40,0x00,0x00,
+0x00,0x3c,0x24,0xe4,0x24,0x3c,0x24,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0x44,0x54,0x88,
+/* 29787 0x745b "瑛" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x21,0xf9,0x21,0x21,0x23,0x38,0xe0,0x40,0x01,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 29788 0x745c "瑜" */
+0x00,0x00,0xf9,0x22,0x25,0x20,0x23,0xfa,0x22,0x23,0x22,0x3a,0xe3,0x42,0x02,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 29789 0x745d "瑝" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x10,0x13,0x10,0x10,0x1d,0xe0,0x40,0x03,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 29790 0x745e "瑞" */
+0x00,0x02,0xfa,0x22,0x23,0x20,0x27,0xf8,0x20,0x23,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x20,0x22,0x22,0x22,0xfe,0x00,0xfe,0x20,0x40,0xfe,0x52,0x52,0x52,0x52,0x52,0x06,
+/* 29791 0x745f "瑟" */
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x01,0x08,0x48,0x49,0x8e,0x18,0xe7,0x00,
+0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x10,0xa0,0x44,0x82,0x12,0x10,0xf0,0x00,
+/* 29792 0x7460 "瑠" */
+0x00,0x03,0xfa,0x22,0x22,0x22,0x23,0xf8,0x23,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 29793 0x7461 "瑡" */
+0x01,0x02,0xfb,0x22,0x22,0x22,0x23,0xfa,0x22,0x23,0x22,0x3a,0xe2,0x43,0x02,0x00,
+0x00,0x7e,0x88,0x88,0xbe,0xaa,0xaa,0x2a,0x2a,0xaa,0xaa,0xae,0x88,0x88,0x88,0x08,
+/* 29794 0x7462 "瑢" */
+0x00,0x00,0xfb,0x22,0x24,0x21,0x22,0xf8,0x21,0x22,0x25,0x39,0xe1,0x41,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x94,0x08,0x64,0x90,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x08,
+/* 29795 0x7463 "瑣" */
+0x00,0x01,0xfc,0x10,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,0x01,
+0x20,0x24,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 29796 0x7464 "瑤" */
+0x00,0x00,0xfd,0x12,0x11,0x10,0x13,0x7d,0x12,0x10,0x13,0x10,0x1d,0xe1,0x41,0x00,
+0x40,0x80,0xfc,0x48,0x30,0xc0,0x00,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0xfc,0x04,
+/* 29797 0x7465 "瑥" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x10,0x13,0x12,0x1e,0xe2,0x42,0x07,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 29798 0x7466 "瑦" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x10,0x1e,0xe2,0x44,0x00,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 29799 0x7467 "瑧" */
+0x00,0x00,0xfb,0x20,0x21,0x20,0x23,0xf8,0x21,0x22,0x20,0x39,0xe0,0x40,0x03,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 29800 0x7468 "瑨" */
+0x00,0x03,0xf8,0x22,0x21,0x20,0x27,0xf8,0x21,0x21,0x21,0x21,0x39,0xe1,0x01,0x01,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 29801 0x7469 "瑩" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x80,0x3f,0x01,0x01,0x1f,0x01,0x01,0x01,0x7f,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xfc,0x00,0x00,0xf8,0x00,0x20,0x10,0xfe,
+/* 29802 0x746a "瑪" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7d,0x11,0x11,0x10,0x12,0x1e,0xe2,0x42,0x00,0x00,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 29803 0x746b "瑫" */
+0x00,0x01,0xfc,0x11,0x10,0x10,0x7c,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 29804 0x746c "瑬" */
+0x20,0x17,0x80,0x49,0x13,0xe1,0x22,0x24,0x00,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x40,0xfe,0x90,0x08,0xfc,0x50,0x52,0x4e,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 29805 0x746d "瑭" */
+0x00,0x00,0xfb,0x22,0x22,0x22,0x23,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x20,0x10,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 29806 0x746e "瑮" */
+0x00,0x03,0xf8,0x20,0x23,0x22,0x22,0xfb,0x20,0x20,0x23,0x38,0xe0,0x41,0x06,0x00,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29807 0x746f "瑯" */
+0x01,0x00,0xfb,0x22,0x22,0x23,0x22,0xfa,0x23,0x22,0x22,0x3a,0xe2,0x43,0x02,0x00,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 29808 0x7470 "瑰" */
+0x00,0x00,0xfb,0x22,0x22,0x23,0x22,0xfa,0x23,0x20,0x20,0x38,0xe1,0x41,0x02,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 29809 0x7471 "瑱" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0x21,0xf9,0x21,0x21,0x21,0x39,0xe3,0x40,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 29810 0x7472 "瑲" */
+0x00,0x00,0xf8,0x21,0x22,0x27,0xfa,0x23,0x22,0x23,0x22,0x3b,0xe5,0x45,0x09,0x01,
+0x40,0x40,0xa0,0x90,0x48,0xfe,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 29811 0x7473 "瑳" */
+0x00,0x00,0xfc,0x11,0x10,0x10,0x7c,0x11,0x10,0x10,0x10,0x1d,0xe2,0x44,0x01,0x00,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 29812 0x7474 "瑴" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0xfe,0x10,0x7c,0x10,0x1e,0xf0,0x41,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 29813 0x7475 "瑵" */
+0x00,0x01,0xfc,0x10,0x10,0x10,0x7c,0x13,0x10,0x11,0x11,0x1d,0xe1,0x40,0x03,0x00,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 29814 0x7476 "瑶" */
+0x00,0x00,0xfb,0x20,0x22,0x21,0xf9,0x22,0x20,0x23,0x20,0x39,0xe1,0x41,0x01,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 29815 0x7477 "瑷" */
+0x00,0x03,0xf8,0x22,0x21,0x23,0x22,0xf8,0x23,0x20,0x20,0x39,0xe1,0x42,0x04,0x01,
+0x0e,0xf0,0x44,0x24,0x08,0xfe,0x42,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 29816 0x7478 "瑸" */
+0x00,0x00,0xfb,0x22,0x24,0x21,0x21,0xf9,0x21,0x21,0x21,0x27,0x38,0xe0,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 29817 0x7479 "瑹" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x20,0xf9,0x22,0x20,0x21,0x38,0xe0,0x41,0x02,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x50,0x88,0x74,0x22,0x20,0xfc,0x20,0xa8,0x24,0xa2,0x40,
+/* 29818 0x747a "瑺" */
+0x00,0x01,0xfc,0x13,0x12,0x10,0x7c,0x10,0x10,0x10,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 29819 0x747b "瑻" */
+0x00,0x01,0xfd,0x13,0x11,0x11,0x7c,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x01,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29820 0x747c "瑼" */
+0x00,0x03,0xfc,0x11,0x11,0x11,0x11,0x7d,0x10,0x13,0x10,0x13,0x1d,0xe0,0x40,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 29821 0x747d "瑽" */
+0x01,0x01,0xfa,0x24,0x29,0x21,0xfa,0x26,0x2a,0x22,0x22,0x3a,0xe2,0x42,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 29822 0x747e "瑾" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x21,0xf9,0x21,0x20,0x23,0x38,0xe1,0x40,0x03,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 29823 0x747f "瑿" */
+0x00,0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x00,0x7f,0x01,0x3f,0x01,0xff,
+0x00,0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0xfc,0x00,0xf8,0x20,0xfe,
+/* 29824 0x7480 "璀" */
+0x00,0x02,0xfb,0x20,0x20,0x21,0x23,0xfd,0x21,0x21,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 29825 0x7481 "璁" */
+0x00,0x00,0xfb,0x22,0x22,0x23,0x22,0xfa,0x22,0x23,0x20,0x38,0xe5,0x45,0x09,0x00,
+0x40,0x80,0xfc,0x44,0xf4,0x14,0xa4,0x44,0xa4,0xfc,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 29826 0x7482 "璂" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x20,0xf8,0x23,0x20,0x21,0x3a,0xe0,0x40,0x03,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x24,0xfa,0x20,0x20,0xfe,0x00,
+/* 29827 0x7483 "璃" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0x21,0xf9,0x20,0x23,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 29828 0x7484 "璄" */
+0x00,0x00,0xfd,0x10,0x10,0x13,0x7c,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x01,0x06,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x92,0x12,0x0e,
+/* 29829 0x7485 "璅" */
+0x01,0x02,0xfd,0x10,0x11,0x11,0x7d,0x11,0x11,0x10,0x13,0x1c,0xe0,0x41,0x06,0x00,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29830 0x7486 "璆" */
+0x00,0x07,0xf8,0x24,0x22,0x24,0x20,0xf9,0x26,0x20,0x23,0x38,0xe3,0x40,0x00,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 29831 0x7487 "璇" */
+0x02,0x01,0xf9,0x27,0x22,0x22,0x23,0xfa,0x22,0x22,0x22,0x3a,0xe4,0x45,0x08,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 29832 0x7488 "璈" */
+0x01,0x01,0xf9,0x27,0x21,0x27,0xf9,0x2f,0x22,0x23,0x22,0x3a,0xe2,0x44,0x04,0x08,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 29833 0x7489 "璉" */
+0x00,0x04,0xfa,0x22,0x20,0x20,0x26,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x45,0x08,0x00,
+0x10,0x10,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 29834 0x748a "璊" */
+0x00,0x00,0xfb,0x20,0x20,0x20,0x20,0xfb,0x22,0x23,0x22,0x3b,0xe2,0x42,0x02,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 29835 0x748b "璋" */
+0x00,0x01,0xfc,0x10,0x13,0x10,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe3,0x40,0x00,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29836 0x748c "璌" */
+0x00,0x00,0xfb,0x22,0x20,0x21,0x20,0xf9,0x21,0x21,0x21,0x39,0xe0,0x40,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 29837 0x748d "璍" */
+0x00,0x03,0xf8,0x20,0x21,0x20,0x20,0xfb,0x20,0x20,0x21,0x38,0xe3,0x40,0x00,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 29838 0x748e "璎" */
+0x00,0x0f,0xf8,0x2a,0x2a,0x2a,0x25,0xf8,0x20,0x2f,0x21,0x3a,0xe3,0x40,0x01,0x0e,
+0x00,0xbe,0xa2,0xaa,0xaa,0xaa,0x14,0xa2,0x80,0xfe,0x10,0x10,0xa0,0x60,0x98,0x04,
+/* 29839 0x748f "璏" */
+0x01,0x01,0xfa,0x23,0x20,0x2f,0x20,0xfc,0x24,0x27,0x24,0x3d,0xe4,0x46,0x04,0x01,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x88,0xea,0x4a,0x4c,0xe8,0x4a,0x4a,0xa6,0x10,
+/* 29840 0x7490 "璐" */
+0x00,0x07,0xfc,0x24,0x24,0x27,0x21,0xf9,0x21,0x25,0x25,0x3d,0xe5,0x45,0x0e,0x00,
+0x10,0x90,0xbc,0xa4,0xc4,0xa8,0x10,0x28,0x46,0xc0,0x3c,0x24,0x24,0xa4,0x3c,0x24,
+/* 29841 0x7491 "璑" */
+0x00,0x00,0xf9,0x23,0x25,0x21,0x23,0xf9,0x21,0x21,0x27,0x20,0x39,0xe1,0x02,0x00,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 29842 0x7492 "璒" */
+0x00,0x07,0xf8,0x22,0x21,0x22,0x25,0xf8,0x23,0x22,0x22,0x3b,0xe2,0x41,0x0f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 29843 0x7493 "璓" */
+0x00,0x03,0xfc,0x10,0x11,0x10,0x13,0x7c,0x11,0x12,0x11,0x10,0x1c,0xe0,0x41,0x02,
+0x88,0xfe,0x88,0x1c,0xe0,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x9e,0x82,0x0a,0x04,
+/* 29844 0x7494 "璔" */
+0x01,0x00,0xf8,0x23,0x22,0x22,0x22,0xfa,0x23,0x20,0x21,0x39,0xe1,0x41,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 29845 0x7495 "璕" */
+0x00,0x03,0xf8,0x23,0x20,0x23,0x20,0xfb,0x21,0x27,0x20,0x3b,0xe1,0x40,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xbc,0x24,0xbc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 29846 0x7496 "璖" */
+0x02,0x01,0xf8,0x24,0x22,0x20,0xf9,0x26,0x22,0x20,0x23,0x38,0xe0,0x41,0x02,0x00,
+0x00,0x7e,0x40,0x7c,0x44,0xfc,0x40,0x7e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29847 0x7497 "璗" */
+0x21,0x11,0x41,0x21,0x0b,0x09,0x73,0x14,0x11,0x12,0x00,0x7f,0x01,0x3f,0x01,0xff,
+0xf8,0x08,0xf8,0x08,0xfe,0x00,0xfc,0xa4,0x54,0x88,0x00,0xfc,0x00,0xf8,0x20,0xfe,
+/* 29848 0x7498 "璘" */
+0x00,0x01,0xf8,0x23,0x20,0x21,0x22,0xf9,0x21,0x21,0x22,0x25,0x38,0xe1,0x02,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 29849 0x7499 "璙" */
+0x00,0x00,0xfb,0x20,0x22,0x21,0xfb,0x25,0x21,0x21,0x21,0x38,0xe1,0x42,0x04,0x00,
+0x20,0x20,0xfe,0x50,0x8a,0x04,0xfe,0x04,0xfc,0x04,0xfc,0x20,0x24,0x22,0xa2,0x40,
+/* 29850 0x749a "璚" */
+0x00,0x03,0xf8,0x20,0x23,0x20,0x20,0xfb,0x20,0x23,0x22,0x3a,0xe3,0x42,0x02,0x02,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 29851 0x749b "璛" */
+0x00,0x03,0xf8,0x27,0x20,0x23,0xf8,0x25,0x27,0x24,0x27,0x3c,0xe7,0x45,0x05,0x08,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 29852 0x749c "璜" */
+0x00,0x00,0xfd,0x10,0x10,0x13,0x10,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe0,0x41,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 29853 0x749d "璝" */
+0x00,0x01,0xfd,0x11,0x10,0x13,0x7c,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29854 0x749e "璞" */
+0x00,0x02,0xf9,0x20,0x23,0x20,0x20,0xfb,0x20,0x21,0x20,0x3b,0xe0,0x40,0x01,0x06,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 29855 0x749f "璟" */
+0x00,0x01,0xfd,0x11,0x11,0x11,0x7c,0x13,0x10,0x11,0x11,0x1d,0xe0,0x41,0x02,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 29856 0x74a0 "璠" */
+0x00,0x03,0xfd,0x10,0x13,0x10,0x7d,0x12,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 29857 0x74a1 "璡" */
+0x00,0x04,0xfa,0x22,0x21,0x20,0x26,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x45,0x08,0x00,
+0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0x00,0xfe,0x00,
+/* 29858 0x74a2 "璢" */
+0x00,0x03,0xf8,0x23,0x22,0x22,0x23,0xf8,0x23,0x22,0x22,0x3b,0xe2,0x42,0x03,0x02,
+0x00,0xfe,0x50,0xde,0x52,0x52,0xde,0x50,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 29859 0x74a3 "璣" */
+0x01,0x01,0xfa,0x23,0x21,0x22,0x23,0xf9,0x27,0x21,0x21,0x39,0xe2,0x42,0x02,0x04,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 29860 0x74a4 "璤" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0xf9,0x21,0x21,0x20,0x23,0x38,0xe0,0x42,0x02,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 29861 0x74a5 "璥" */
+0x02,0x02,0xf7,0x22,0x24,0x27,0x24,0xf8,0x27,0x25,0x25,0x37,0xe5,0x40,0x02,0x01,
+0x88,0x88,0xe8,0x90,0x1e,0xe4,0x54,0x54,0x54,0x54,0x54,0x48,0x48,0x54,0x94,0x22,
+/* 29862 0x74a6 "璦" */
+0x00,0x03,0xf8,0x22,0x21,0x27,0x24,0xfa,0x22,0x24,0x20,0x38,0xe1,0x42,0x00,0x07,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 29863 0x74a7 "璧" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x00,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xfc,0x00,0xf8,0x20,0x10,0xfe,0x00,
+/* 29864 0x74a8 "璨" */
+0x00,0x00,0xfa,0x23,0x24,0x2a,0x23,0xfc,0x22,0x21,0x27,0x38,0xe1,0x42,0x0c,0x00,
+0x80,0xdc,0x84,0xd4,0x48,0x94,0x24,0x40,0x48,0x50,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 29865 0x74a9 "璩" */
+0x00,0x00,0xf8,0x23,0x22,0x22,0x23,0xfa,0x22,0x23,0x22,0x3b,0xe2,0x45,0x04,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 29866 0x74aa "璪" */
+0x01,0x01,0xf9,0x21,0x20,0x23,0x22,0xfa,0x23,0x20,0x23,0x38,0xe0,0x41,0x06,0x00,
+0xfc,0x04,0x04,0xfc,0x00,0xde,0x52,0x52,0xde,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 29867 0x74ab "璫" */
+0x00,0x01,0xfc,0x13,0x12,0x10,0x10,0x7c,0x10,0x10,0x11,0x11,0x1d,0xe1,0x41,0x01,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 29868 0x74ac "璬" */
+0x01,0x02,0xf7,0x24,0x27,0x24,0x27,0xf2,0x21,0x27,0x22,0x23,0x32,0xc4,0x05,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 29869 0x74ad "璭" */
+0x00,0x04,0xfa,0x22,0x20,0x20,0x26,0xfa,0x22,0x22,0x22,0x22,0x3a,0xe5,0x08,0x00,
+0x00,0xfe,0x92,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 29870 0x74ae "璮" */
+0x00,0x07,0xf8,0x23,0x22,0x22,0x22,0xfb,0x20,0x21,0x21,0x39,0xe1,0x41,0x00,0x07,
+0x20,0xfe,0x00,0xfe,0x02,0xfa,0x8a,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,
+/* 29871 0x74af "璯" */
+0x00,0x00,0xfc,0x11,0x12,0x11,0x7d,0x11,0x11,0x11,0x10,0x1c,0xe0,0x40,0x00,0x00,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 29872 0x74b0 "環" */
+0x00,0x03,0xfa,0x22,0x23,0x20,0xfb,0x20,0x23,0x22,0x23,0x38,0xe1,0x43,0x0d,0x01,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 29873 0x74b1 "璱" */
+0x00,0x07,0xf1,0x21,0x27,0x21,0x21,0xf7,0x20,0x20,0x20,0x25,0x35,0xc9,0x03,0x0c,
+0x00,0xbe,0x08,0x08,0xbe,0x08,0x08,0xbe,0x00,0x80,0x44,0x12,0x22,0xc0,0x04,0xfc,
+/* 29874 0x74b2 "璲" */
+0x00,0x04,0xfa,0x20,0x20,0x20,0x26,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x42,0x05,0x08,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 29875 0x74b3 "璳" */
+0x00,0x00,0xfd,0x13,0x10,0x11,0x7e,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x01,
+0xa0,0xfc,0x20,0xfe,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29876 0x74b4 "璴" */
+0x00,0x00,0xfb,0x20,0x21,0x22,0x24,0xf8,0x23,0x20,0x21,0x39,0xe1,0x42,0x04,0x08,
+0x88,0x88,0xde,0x88,0xdc,0xaa,0x88,0x00,0xfe,0x22,0x20,0x3c,0x20,0xa0,0x7e,0x00,
+/* 29877 0x74b5 "璵" */
+0x01,0x02,0xfa,0x22,0x23,0x22,0x22,0xfb,0x22,0x22,0x27,0x38,0xe1,0x41,0x02,0x04,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 29878 0x74b6 "璶" */
+0x00,0x03,0xf8,0x27,0x20,0x23,0xf8,0x27,0x20,0x22,0x24,0x3b,0xe2,0x42,0x0f,0x00,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfe,0x00,0xa4,0x52,0xf8,0xa8,0xa8,0xfe,0x00,
+/* 29879 0x74b7 "璷" */
+0x01,0x07,0xf9,0x27,0x25,0x27,0xfd,0x27,0x25,0x21,0x27,0x3a,0xe3,0x42,0x05,0x08,
+0x48,0xc8,0x08,0xd0,0x5e,0xe4,0x54,0xd4,0x54,0x14,0xd4,0x08,0xc8,0x54,0x54,0xa2,
+/* 29880 0x74b8 "璸" */
+0x00,0x00,0xfb,0x22,0x21,0x21,0xfa,0x21,0x23,0x21,0x21,0x39,0xe1,0x41,0x00,0x01,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29881 0x74b9 "璹" */
+0x00,0x03,0xfc,0x11,0x10,0x13,0x10,0x7d,0x10,0x13,0x10,0x13,0x1c,0xe3,0x42,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 29882 0x74ba "璺" */
+0x2f,0x48,0x4b,0x68,0x4b,0x6a,0x4b,0x48,0xff,0x80,0x7f,0x01,0x3f,0x01,0x01,0xff,
+0xec,0x24,0xa4,0x2c,0xa4,0xac,0xa4,0x24,0xfe,0x02,0xfc,0x00,0xf8,0x20,0x10,0xfe,
+/* 29883 0x74bb "璻" */
+0x03,0x00,0xfa,0x21,0x22,0x20,0x23,0xf8,0x20,0x21,0x22,0x38,0xe7,0x40,0x00,0x00,
+0xde,0x42,0x52,0x4a,0x52,0x20,0xfe,0x88,0x88,0x54,0x22,0x20,0xfe,0x20,0x20,0x20,
+/* 29884 0x74bc "璼" */
+0x00,0x03,0xfa,0x23,0x22,0x23,0x22,0xfb,0x20,0x21,0x21,0x39,0xe1,0x41,0x07,0x00,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 29885 0x74bd "璽" */
+0x7f,0x21,0x7f,0xb5,0x29,0x35,0x21,0x35,0x29,0x35,0x00,0x7f,0x01,0x3f,0x01,0xff,
+0xfc,0x08,0xfc,0x5a,0x28,0x58,0x08,0x58,0x28,0x58,0x00,0xfc,0x00,0xf8,0x20,0xfe,
+/* 29886 0x74be "璾" */
+0x00,0x00,0xfb,0x20,0x20,0x27,0x22,0xfa,0x25,0x20,0x21,0x39,0xe1,0x41,0x01,0x02,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 29887 0x74bf "璿" */
+0x00,0x00,0xf8,0x27,0x24,0x23,0xfa,0x24,0x21,0x23,0x26,0x3b,0xe2,0x43,0x02,0x03,
+0x40,0x7c,0x40,0xfe,0x02,0xfc,0x48,0xa4,0x10,0xf8,0x0c,0xfa,0x08,0xf8,0x08,0xf8,
+/* 29888 0x74c0 "瓀" */
+0x00,0x01,0xfc,0x13,0x12,0x11,0x7c,0x11,0x10,0x13,0x10,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 29889 0x74c1 "瓁" */
+0x00,0x03,0xfc,0x10,0x11,0x13,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe3,0x40,0x00,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 29890 0x74c2 "瓂" */
+0x00,0x03,0xfc,0x10,0x11,0x10,0x13,0x7c,0x10,0x11,0x10,0x11,0x1d,0xe1,0x47,0x00,
+0x88,0xfe,0x88,0x20,0xfc,0x20,0xfe,0x40,0x88,0xfc,0x00,0xfc,0x54,0x54,0xfe,0x00,
+/* 29891 0x74c3 "瓃" */
+0x03,0x02,0xfa,0x23,0x22,0x22,0xfb,0x20,0x2f,0x2a,0x2a,0x3f,0xea,0x4a,0x0f,0x08,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 29892 0x74c4 "瓄" */
+0x00,0x03,0xfc,0x11,0x10,0x13,0x7e,0x13,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29893 0x74c5 "瓅" */
+0x04,0x04,0xf8,0x2a,0x2e,0x24,0x2a,0xfe,0x22,0x20,0x2f,0x20,0x31,0xc2,0x0c,0x00,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 29894 0x74c6 "瓆" */
+0x00,0x03,0xfa,0x23,0x22,0x22,0x24,0xfb,0x22,0x23,0x22,0x3b,0xe2,0x43,0x01,0x02,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 29895 0x74c7 "瓇" */
+0x03,0x00,0xf9,0x21,0x21,0x21,0x27,0xfc,0x22,0x22,0x24,0x38,0xe1,0x42,0x00,0x03,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 29896 0x74c8 "瓈" */
+0x00,0x01,0xfc,0x13,0x10,0x11,0x12,0x7c,0x10,0x10,0x13,0x10,0x1c,0xe0,0x41,0x00,
+0x50,0x90,0x9e,0xea,0x8a,0xd2,0x8a,0xa4,0x50,0x88,0x26,0xa8,0x70,0xa8,0x24,0x60,
+/* 29897 0x74c9 "瓉" */
+0x00,0x01,0xfc,0x13,0x10,0x11,0x7e,0x11,0x11,0x11,0x11,0x1d,0xe1,0x41,0x00,0x01,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 29898 0x74ca "瓊" */
+0x01,0x01,0xfa,0x27,0x22,0x22,0xf9,0x21,0x21,0x21,0x21,0x38,0xe1,0x42,0x00,0x03,
+0x00,0xf8,0x08,0xfe,0x62,0x92,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xf8,0x88,0x70,0x8e,
+/* 29899 0x74cb "瓋" */
+0x00,0x00,0xf4,0x22,0x22,0x20,0x20,0xf6,0x22,0x22,0x22,0x22,0x32,0xc5,0x08,0x00,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x92,0xfe,0x92,0xba,0xaa,0xba,0x86,0x00,0xfe,0x00,
+/* 29900 0x74cc "瓌" */
+0x00,0x00,0xfd,0x10,0x11,0x11,0x11,0x7c,0x11,0x10,0x11,0x10,0x1c,0xe1,0x42,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x54,0xfc,0x20,0x22,0x8c,0x22,0x54,0xc8,0x44,0x52,0x60,
+/* 29901 0x74cd "瓍" */
+0x00,0x07,0xf5,0x25,0x25,0x26,0x25,0xf5,0x25,0x25,0x25,0x26,0x34,0xc4,0x04,0x05,
+0x08,0x3e,0x90,0x5e,0x64,0x5e,0x00,0xde,0x52,0x5e,0x52,0x5e,0x52,0x56,0xa0,0x1e,
+/* 29902 0x74ce "瓎" */
+0x01,0x01,0xf7,0x21,0x21,0x27,0x25,0xf5,0x27,0x21,0x23,0x25,0x39,0xc1,0x01,0x01,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 29903 0x74cf "瓏" */
+0x01,0x00,0xfb,0x20,0x22,0x21,0xfb,0x20,0x23,0x22,0x23,0x3a,0xe3,0x42,0x02,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 29904 0x74d0 "瓐" */
+0x00,0x00,0xf8,0x23,0x22,0x23,0xfa,0x22,0x22,0x22,0x22,0x3a,0xe2,0x45,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 29905 0x74d1 "瓑" */
+0x00,0x07,0xf4,0x25,0x24,0x27,0x24,0xf5,0x26,0x24,0x24,0x25,0x35,0xc9,0x09,0x17,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 29906 0x74d2 "瓒" */
+0x01,0x05,0xf7,0x29,0x2f,0x21,0xf3,0x2d,0x23,0x22,0x22,0x3a,0xe2,0x00,0x01,0x06,
+0x04,0x14,0xde,0x24,0xff,0x0c,0x55,0xa7,0xfc,0x04,0x24,0x24,0x44,0xb0,0x08,0x04,
+/* 29907 0x74d3 "瓓" */
+0x03,0x02,0xfb,0x22,0x23,0x22,0x22,0xfa,0x22,0x22,0x22,0x3a,0xe2,0x42,0x02,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 29908 0x74d4 "瓔" */
+0x03,0x02,0xfb,0x22,0x23,0x22,0x23,0xf9,0x22,0x20,0x27,0x38,0xe1,0x40,0x00,0x03,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 29909 0x74d5 "瓕" */
+0xf7,0x12,0x17,0xfc,0x86,0xf5,0x16,0x15,0x56,0x24,0x00,0x7f,0x01,0x3f,0x01,0xff,
+0xfc,0x48,0xfc,0x46,0xec,0x54,0xec,0x54,0xec,0x44,0x00,0xfc,0x00,0xf8,0x20,0xfe,
+/* 29910 0x74d6 "瓖" */
+0x00,0x03,0xf8,0x21,0x21,0x21,0x20,0xfb,0x20,0x23,0x20,0x27,0x38,0xe1,0x06,0x00,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 29911 0x74d7 "瓗" */
+0x02,0x03,0xf8,0x21,0x23,0x25,0x21,0xf9,0x21,0x21,0x21,0x23,0x3a,0xe3,0x02,0x02,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 29912 0x74d8 "瓘" */
+0x00,0x03,0xf8,0x23,0x22,0x23,0x20,0xf8,0x21,0x21,0x23,0x3d,0xe1,0x41,0x01,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 29913 0x74d9 "瓙" */
+0x00,0x03,0xf8,0x21,0x20,0x23,0xf8,0x21,0x20,0x23,0x20,0x3b,0xe2,0x43,0x05,0x08,
+0x40,0xfc,0x40,0xf8,0x00,0xfc,0x04,0xf0,0x40,0xfc,0x08,0xbc,0xa8,0x98,0x24,0x92,
+/* 29914 0x74da "瓚" */
+0x05,0x07,0xf9,0x27,0x23,0x25,0xf9,0x23,0x22,0x23,0x22,0x3b,0xe2,0x43,0x01,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 29915 0x74db "瓛" */
+0x01,0x01,0xf1,0x2f,0x29,0x2b,0x29,0xff,0x29,0x2b,0x2a,0x2b,0x3a,0xcb,0x0a,0x12,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 29916 0x74dc "瓜" */
+0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x42,0x80,
+0x10,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x90,0x50,0xa8,0x28,0x04,0x02,
+/* 29917 0x74dd "瓝" */
+0x02,0x07,0x38,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x4a,0x4d,0x89,
+0x20,0x20,0x3c,0x44,0x84,0x24,0x14,0x14,0x04,0x04,0x28,0x90,0x40,0x30,0x0e,0x00,
+/* 29918 0x74de "瓞" */
+0x02,0x07,0x38,0x2a,0x2a,0x2b,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x4a,0x4d,0x89,
+0x10,0x10,0x50,0x7c,0x90,0x10,0xfe,0x10,0x28,0x24,0x42,0x82,0x40,0x30,0x0e,0x00,
+/* 29919 0x74df "瓟" */
+0x02,0x07,0x38,0x2a,0x2b,0x2a,0x2a,0x2a,0x2a,0x29,0x29,0x28,0x28,0x4a,0x4d,0x89,
+0x40,0x40,0x7c,0x84,0x74,0x54,0x54,0x74,0x48,0x42,0x42,0xbe,0x40,0x30,0x0e,0x00,
+/* 29920 0x74e0 "瓠" */
+0x10,0x10,0xfe,0x28,0x44,0x82,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x05,0x29,0x12,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 29921 0x74e1 "瓡" */
+0x10,0x10,0x7c,0x10,0x10,0xfe,0x44,0x28,0x7c,0x10,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 29922 0x74e2 "瓢" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x93,0x51,0x22,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 29923 0x74e3 "瓣" */
+0x40,0x21,0x27,0xfd,0x05,0x55,0x25,0xfd,0x25,0x25,0x75,0x25,0x25,0x49,0x49,0x91,
+0x90,0xc8,0x08,0x3e,0x80,0x54,0x48,0x7e,0x48,0x48,0x5c,0x28,0x08,0x48,0xa8,0x28,
+/* 29924 0x74e4 "瓤" */
+0x10,0xfe,0x00,0xee,0xaa,0xee,0x44,0xfe,0x44,0xfe,0x44,0xfe,0x50,0xcb,0x65,0x42,
+0x08,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xa4,0xa2,0x28,0x34,0x24,
+/* 29925 0x74e5 "瓥" */
+0x06,0x38,0x2c,0x2a,0x2a,0x29,0x54,0x5d,0x90,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0xfe,0x20,0x54,0xb4,0x58,0xb4,0x54,0x92,0x30,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 29926 0x74e6 "瓦" */
+0x00,0xff,0x04,0x04,0x04,0x07,0x08,0x0a,0x09,0x09,0x08,0x10,0x13,0x1c,0x10,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 29927 0x74e7 "瓧" */
+0x00,0xfc,0x20,0x20,0x20,0x3d,0x24,0x24,0x54,0x4c,0x44,0x44,0x54,0x64,0x43,0x00,
+0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x02,0xfe,0x00,
+/* 29928 0x74e8 "瓨" */
+0x00,0x01,0x7c,0x10,0x10,0x10,0x10,0x10,0x11,0x11,0x11,0x1d,0xe1,0x41,0x01,0x01,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 29929 0x74e9 "瓩" */
+0x00,0xfc,0x20,0x20,0x20,0x3c,0x25,0x24,0x54,0x4c,0x44,0x44,0x54,0x64,0x43,0x00,
+0x10,0x38,0xe0,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x22,0x02,0xfe,0x00,
+/* 29930 0x74ea "瓪" */
+0x00,0xfc,0x20,0x20,0x20,0x3c,0x24,0x24,0x54,0x4c,0x45,0x45,0x56,0x64,0x43,0x00,
+0x04,0x0e,0xf0,0x80,0x80,0xfc,0x84,0xc4,0xa8,0x90,0x28,0x44,0x02,0x02,0xfe,0x00,
+/* 29931 0x74eb "瓫" */
+0x04,0x08,0x30,0xdf,0x04,0x04,0x08,0x10,0x20,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x40,0x20,0x18,0xe6,0x20,0x20,0x20,0xa0,0x40,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29932 0x74ec "瓬" */
+0x20,0x11,0x00,0xfe,0x20,0x20,0x3c,0x24,0x25,0x25,0x25,0x25,0x45,0x55,0x89,0x01,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 29933 0x74ed "瓭" */
+0x00,0x11,0x10,0x10,0xfe,0x92,0x10,0x10,0x29,0x29,0x29,0x29,0x4b,0x4d,0x89,0x01,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 29934 0x74ee "瓮" */
+0x04,0x08,0x10,0x22,0xc4,0x08,0x1f,0x00,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x40,0x20,0x10,0x08,0x46,0x20,0xf0,0x00,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29935 0x74ef "瓯" */
+0x00,0x7e,0x40,0x44,0x64,0x54,0x48,0x48,0x54,0x54,0x64,0x40,0x40,0x7e,0x00,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29936 0x74f0 "瓰" */
+0x00,0xfc,0x20,0x20,0x20,0x3d,0x26,0x24,0x54,0x4c,0x44,0x45,0x56,0x64,0x43,0x00,
+0x10,0x50,0x48,0x88,0x84,0x02,0xf8,0x48,0x48,0x88,0x88,0x28,0x12,0x02,0xfe,0x00,
+/* 29937 0x74f1 "瓱" */
+0x00,0xfc,0x21,0x20,0x20,0x3d,0x24,0x24,0x57,0x4c,0x44,0x44,0x54,0x64,0x43,0x00,
+0x20,0x70,0xc0,0x40,0x70,0xc0,0x40,0x78,0xc0,0x48,0x48,0x48,0x3a,0x02,0xfe,0x00,
+/* 29938 0x74f2 "瓲" */
+0x00,0xfc,0x21,0x20,0x21,0x3d,0x25,0x25,0x54,0x4c,0x44,0x44,0x54,0x64,0x43,0x00,
+0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x20,0x24,0x24,0x1c,0x02,0x02,0xfe,0x00,
+/* 29939 0x74f3 "瓳" */
+0x10,0x11,0x10,0x10,0xfe,0x10,0x10,0x10,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 29940 0x74f4 "瓴" */
+0x10,0x10,0x28,0x24,0x42,0x91,0x08,0x08,0xfe,0x02,0x44,0x28,0x10,0x08,0x08,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29941 0x74f5 "瓵" */
+0x10,0x11,0x20,0x28,0x44,0xfe,0x42,0x00,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 29942 0x74f6 "瓶" */
+0x42,0x24,0x00,0x7e,0x24,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29943 0x74f7 "瓷" */
+0x01,0x41,0x21,0x0a,0x14,0xe0,0x21,0x26,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0x00,0xfc,0x44,0x48,0xa0,0x10,0x0c,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29944 0x74f8 "瓸" */
+0x00,0xfd,0x20,0x20,0x20,0x3c,0x24,0x24,0x54,0x4c,0x44,0x44,0x54,0x64,0x43,0x00,
+0x00,0xfc,0x20,0x40,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x02,0x02,0xfe,0x00,
+/* 29945 0x74f9 "瓹" */
+0x00,0x7e,0x42,0x42,0x7e,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x4a,0x44,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29946 0x74fa "瓺" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x20,0x3c,0x20,0x20,0xfe,0x20,0x24,0x42,0xfe,0x42,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29947 0x74fb "瓻" */
+0x42,0x24,0x18,0x24,0x52,0x10,0xff,0x20,0x28,0x7e,0xaa,0x2a,0x2a,0x2e,0x08,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29948 0x74fc "瓼" */
+0x00,0xfd,0x21,0x21,0x21,0x3d,0x25,0x25,0x54,0x4d,0x44,0x44,0x55,0x64,0x43,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xfe,0x00,
+/* 29949 0x74fd "瓽" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x1f,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29950 0x74fe "瓾" */
+0x0c,0x71,0x10,0xfe,0x38,0x54,0x92,0x00,0x11,0xfd,0x25,0x45,0x29,0x11,0x29,0xc5,
+0x00,0xfc,0x80,0x80,0x80,0xf8,0x88,0x88,0x48,0x28,0x28,0x08,0x08,0x4a,0x8a,0x06,
+/* 29951 0x74ff "瓿" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29952 0x7500 "甀" */
+0x02,0x0f,0x78,0x08,0xff,0x2a,0x2a,0xff,0x2a,0x2a,0xff,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x7c,0x20,0x20,0xa0,0x38,0x28,0xa8,0x58,0x48,0xc8,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29953 0x7501 "甁" */
+0x22,0x22,0x44,0xee,0x44,0x44,0x44,0x44,0xef,0x44,0x44,0x44,0x44,0x44,0x44,0x84,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29954 0x7502 "甂" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x40,0x7f,0x55,0x55,0x7f,0xd5,0x55,0x55,0x43,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29955 0x7503 "甃" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x09,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29956 0x7504 "甄" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xfe,0x10,0x10,0xfe,0x10,0x10,0x1e,0xf0,0x40,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29957 0x7505 "甅" */
+0x00,0xfd,0x21,0x21,0x21,0x3d,0x25,0x25,0x55,0x4d,0x45,0x46,0x54,0x64,0x43,0x00,
+0x00,0xfe,0x00,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x7c,0x10,0xfe,0x02,0x02,0xfe,0x00,
+/* 29958 0x7506 "甆" */
+0x08,0x04,0x7f,0x12,0x3c,0x08,0x14,0x3e,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x20,0x40,0xfc,0x48,0xf0,0x20,0x50,0xf8,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29959 0x7507 "甇" */
+0x08,0x2a,0x2c,0x49,0x14,0x22,0x7f,0x40,0x80,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x20,0xa4,0xa8,0x20,0x50,0x88,0xfe,0x02,0x04,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29960 0x7508 "甈" */
+0x08,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x08,0xff,0x18,0x2c,0x4a,0x88,0x08,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29961 0x7509 "甉" */
+0x22,0x14,0xff,0x14,0x14,0x7f,0x15,0xff,0x15,0x7f,0x14,0x36,0x55,0x94,0x14,0x14,
+0x00,0x7c,0xa0,0x20,0x20,0x38,0x28,0xa8,0x58,0x48,0x48,0x48,0x5a,0xea,0x4a,0x06,
+/* 29962 0x750a "甊" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x00,0x7c,0x20,0xa0,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29963 0x750b "甋" */
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x82,0x92,0xfe,0x92,0xba,0xaa,0xaa,0xba,0x82,0x86,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29964 0x750c "甌" */
+0x00,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xbc,0x80,0xee,0xaa,0xaa,0xee,0x80,0xfe,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29965 0x750d "甍" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x00,0x7f,0x40,0xbf,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xfe,0x02,0xf4,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29966 0x750e "甎" */
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x12,0xfe,0x08,0xfe,0x48,0x28,0x18,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29967 0x750f "甏" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x22,0x3e,0x14,0x7f,0x00,0x7f,0x08,0x0f,0x11,0x1c,
+0x04,0x08,0x10,0x64,0x08,0x10,0x64,0x08,0x10,0x60,0x00,0xfc,0x00,0xe0,0x24,0x9c,
+/* 29968 0x7510 "甐" */
+0x08,0x49,0x2a,0x08,0xff,0x2a,0x49,0x88,0x42,0x77,0x92,0x5a,0x2f,0x22,0x42,0x82,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29969 0x7511 "甑" */
+0x44,0x24,0x28,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+0x00,0xfc,0x40,0x40,0x40,0x78,0x48,0x48,0xa8,0x98,0x88,0x88,0xaa,0xca,0x8a,0x06,
+/* 29970 0x7512 "甒" */
+0x20,0x20,0x7f,0xd5,0x55,0x55,0xff,0x55,0x55,0x55,0xff,0x00,0x6a,0x55,0x95,0x00,
+0x00,0x7c,0xa0,0x20,0x20,0x38,0xa8,0x28,0x58,0x48,0xc8,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29971 0x7513 "甓" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x00,0x7f,0x08,0x0f,0x11,0x1c,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xfc,0x00,0xe0,0x24,0x9c,
+/* 29972 0x7514 "甔" */
+0x20,0x3e,0x42,0xff,0x51,0x64,0x7f,0x40,0x5f,0x40,0x5f,0x40,0x5f,0x51,0x5f,0x91,
+0x00,0x7c,0x20,0xa0,0x20,0xb8,0xa8,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29973 0x7515 "甕" */
+0x01,0xff,0x10,0x24,0x79,0x10,0x22,0x7c,0x08,0x30,0xc0,0x7f,0x08,0x0f,0x11,0x1c,
+0x00,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xfc,0x00,0xe0,0x24,0x9c,
+/* 29974 0x7516 "甖" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x22,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 29975 0x7517 "甗" */
+0x08,0x0f,0x08,0x7f,0x49,0x5e,0x49,0x7f,0x4a,0x5f,0x51,0x5b,0x55,0x5f,0x55,0x95,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0x6a,0x4a,0x06,
+/* 29976 0x7518 "甘" */
+0x08,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x0f,0x08,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 29977 0x7519 "甙" */
+0x00,0x00,0x00,0xff,0x00,0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x00,
+0x50,0x48,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x20,0x20,0x12,0x12,0x0a,0x06,0x02,
+/* 29978 0x751a "甚" */
+0x08,0x08,0x7f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0xff,0x12,0x14,0x10,0x1f,
+0x20,0x20,0xfc,0x20,0x20,0xe0,0x20,0x20,0xe0,0x20,0x20,0xfe,0x20,0x10,0x00,0xf8,
+/* 29979 0x751b "甛" */
+0x44,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+0x04,0x1e,0xf0,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 29980 0x751c "甜" */
+0x08,0x1c,0x70,0x10,0x11,0xfc,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 29981 0x751d "甝" */
+0x08,0x0f,0x08,0x7f,0x49,0x4e,0x78,0x49,0x47,0x40,0x5e,0x52,0x52,0x52,0x91,0x20,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x48,0x48,0x48,0x7a,0x02,0xfe,0x00,
+/* 29982 0x751e "甞" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x1f,0x00,0x10,0xff,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x00,0x10,0xfe,0x10,0xf0,0x10,0xf0,0x10,
+/* 29983 0x751f "生" */
+0x01,0x11,0x11,0x11,0x3f,0x21,0x41,0x81,0x01,0x3f,0x01,0x01,0x01,0x01,0xff,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 29984 0x7520 "甠" */
+0x00,0x00,0x7d,0x45,0x45,0x45,0x46,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x03,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 29985 0x7521 "甡" */
+0x08,0x08,0x48,0x48,0x7e,0x48,0x89,0x08,0x08,0x7e,0x08,0x08,0x08,0x0e,0xf1,0x40,
+0x10,0x10,0x90,0x90,0xfe,0x90,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 29986 0x7522 "產" */
+0x01,0x00,0x3f,0x02,0x01,0x02,0x3f,0x20,0x24,0x27,0x28,0x30,0x27,0x40,0x40,0x9f,
+0x00,0x80,0xfe,0x20,0xc0,0x20,0xfe,0x80,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfe,
+/* 29987 0x7523 "産" */
+0x01,0x00,0x3f,0x04,0x02,0x3f,0x20,0x24,0x27,0x28,0x30,0x27,0x40,0x40,0x9f,0x00,
+0x00,0x80,0xfe,0x10,0x20,0xfe,0x80,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfe,0x00,
+/* 29988 0x7524 "甤" */
+0x00,0x00,0xff,0x08,0x10,0x30,0x4a,0x9c,0x28,0x4c,0x9a,0x29,0x48,0x88,0x28,0x10,
+0x10,0x10,0x50,0x7c,0x50,0x90,0x10,0x7c,0x10,0x10,0x10,0xfe,0x80,0x60,0x1e,0x00,
+/* 29989 0x7525 "甥" */
+0x11,0x11,0x51,0x51,0x7d,0x51,0x91,0x10,0x7c,0x13,0x10,0x10,0x1c,0xe1,0x42,0x04,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x40,0xfe,0x42,0x82,0x82,0x02,0x14,0x08,
+/* 29990 0x7526 "甦" */
+0x00,0xff,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x90,0x50,0x20,0x5f,0x80,
+0x10,0x10,0x50,0x7c,0x50,0x90,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 29991 0x7527 "甧" */
+0x10,0x50,0x7e,0x90,0x7c,0x10,0x1e,0xe0,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x10,0x50,0x7e,0x90,0x7c,0x10,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 29992 0x7528 "用" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x41,0x41,0x80,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 29993 0x7529 "甩" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x41,0x41,0x80,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x28,0x12,0x02,0xfe,
+/* 29994 0x752a "甪" */
+0x04,0x08,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x41,0x41,0x80,
+0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x28,0x10,
+/* 29995 0x752b "甫" */
+0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x21,0x21,0x20,
+0x20,0x10,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 29996 0x752c "甬" */
+0x00,0x3f,0x00,0x06,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x21,0x21,0x20,
+0x00,0xf0,0x20,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 29997 0x752d "甭" */
+0x7f,0x01,0x07,0x19,0xe1,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x41,0x41,0x81,
+0xfc,0x00,0x70,0x0c,0x02,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x28,0x10,
+/* 29998 0x752e "甮" */
+0x08,0x1f,0x22,0x44,0x09,0x12,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x41,0x41,0x81,
+0x00,0xf8,0x48,0x88,0x50,0x20,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x28,0x10,
+/* 29999 0x752f "甯" */
+0x02,0x01,0x7f,0x41,0x94,0x14,0x23,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,0x20,
+0x00,0x00,0xfe,0x02,0x94,0x28,0xe8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 30000 0x7530 "田" */
+0x00,0x3f,0x21,0x21,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x21,0x21,0x3f,0x20,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 30001 0x7531 "由" */
+0x01,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x21,0x3f,0x20,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30002 0x7532 "甲" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,0x01,0x01,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 30003 0x7533 "申" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 30004 0x7534 "甴" */
+0x01,0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30005 0x7535 "电" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x0a,0x02,0x02,0xfe,
+/* 30006 0x7536 "甶" */
+0x02,0x02,0x04,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x21,0x3f,0x20,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 30007 0x7537 "男" */
+0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x01,0x7f,0x01,0x01,0x02,0x04,0x18,0x60,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 30008 0x7538 "甸" */
+0x08,0x08,0x10,0x1f,0x20,0x40,0xbf,0x24,0x24,0x3f,0x24,0x24,0x3f,0x20,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x50,0x20,
+/* 30009 0x7539 "甹" */
+0x01,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x08,0x10,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 30010 0x753a "町" */
+0x00,0x00,0x7d,0x54,0x54,0x54,0x54,0x7c,0x54,0x54,0x54,0x54,0x7c,0x44,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 30011 0x753b "画" */
+0x00,0xff,0x00,0x00,0x4f,0x49,0x49,0x4f,0x49,0x49,0x49,0x4f,0x40,0x40,0x7f,0x00,
+0x00,0xfe,0x00,0x00,0xe4,0x24,0x24,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0xfc,0x04,
+/* 30012 0x753c "甼" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x00,0x00,0xff,0x01,0x01,0x01,0x05,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 30013 0x753d "甽" */
+0x00,0x00,0x7c,0x54,0x54,0x54,0x54,0x7c,0x54,0x54,0x54,0x54,0x7c,0x45,0x01,0x02,
+0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 30014 0x753e "甾" */
+0x08,0x11,0x22,0x11,0x08,0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x88,0x10,0x20,0x10,0x88,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 30015 0x753f "甿" */
+0x00,0x00,0x7c,0x54,0x55,0x54,0x54,0x7c,0x54,0x54,0x54,0x54,0x7c,0x44,0x00,0x00,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 30016 0x7540 "畀" */
+0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x00,0x00,0xff,0x08,0x08,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30017 0x7541 "畁" */
+0x01,0x01,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x00,0xff,0x08,0x08,0x08,0x10,0x20,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30018 0x7542 "畂" */
+0x00,0x00,0x7c,0x54,0x55,0x55,0x55,0x7e,0x54,0x54,0x54,0x54,0x7c,0x45,0x02,0x04,
+0x80,0x80,0x80,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 30019 0x7543 "畃" */
+0x10,0x10,0x10,0xfe,0x92,0x92,0xff,0x92,0x92,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0x7c,0x84,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 30020 0x7544 "畄" */
+0x04,0x42,0x21,0x11,0x10,0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x08,0x08,0x10,0x10,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 30021 0x7545 "畅" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x7d,0x54,0x54,0x54,0x7d,0x54,0x10,0x10,0x11,0x10,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfc,0x54,0x54,0x94,0x24,0x24,0x44,0x84,0x28,0x10,
+/* 30022 0x7546 "畆" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x7f,0x49,0x49,0x49,0x7f,0x49,0x49,0x49,0x7f,0x41,
+0x00,0x08,0x08,0x88,0x08,0x08,0x10,0x10,0x10,0x20,0x24,0x24,0x42,0xfe,0x42,0x02,
+/* 30023 0x7547 "畇" */
+0x00,0x00,0x7c,0x54,0x55,0x56,0x54,0x7c,0x54,0x54,0x54,0x54,0x7d,0x44,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 30024 0x7548 "畈" */
+0x00,0x00,0x7d,0x55,0x55,0x55,0x55,0x7d,0x55,0x55,0x55,0x55,0x7d,0x46,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 30025 0x7549 "畉" */
+0x00,0x00,0x7c,0x54,0x55,0x54,0x54,0x7c,0x57,0x54,0x54,0x54,0x7c,0x44,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30026 0x754a "畊" */
+0x00,0x00,0x7c,0x54,0x55,0x54,0x54,0x7c,0x57,0x54,0x54,0x54,0x7c,0x45,0x01,0x02,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30027 0x754b "畋" */
+0x00,0x00,0x7c,0x54,0x54,0x55,0x56,0x7c,0x54,0x54,0x54,0x54,0x7c,0x44,0x01,0x02,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 30028 0x754c "界" */
+0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x02,0x0c,0x34,0xc4,0x04,0x08,0x08,0x10,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x80,0x60,0x58,0x46,0x40,0x40,0x40,0x40,
+/* 30029 0x754d "畍" */
+0x00,0x00,0x7c,0x54,0x54,0x55,0x56,0x7c,0x54,0x54,0x54,0x54,0x7c,0x45,0x01,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30030 0x754e "畎" */
+0x00,0x00,0x7c,0x54,0x54,0x55,0x54,0x7c,0x54,0x54,0x54,0x54,0x7c,0x44,0x01,0x02,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30031 0x754f "畏" */
+0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x00,0xff,0x11,0x10,0x10,0x14,0x18,0x10,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x10,0xa0,0x40,0x30,0x0e,0x00,
+/* 30032 0x7550 "畐" */
+0x00,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30033 0x7551 "畑" */
+0x10,0x11,0x11,0x11,0x55,0x59,0x51,0x91,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 30034 0x7552 "畒" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x7f,0x49,0x49,0x49,0x7f,0x49,0x49,0x49,0x7f,0x41,
+0x10,0x10,0x10,0x90,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x84,0x02,
+/* 30035 0x7553 "畓" */
+0x01,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30036 0x7554 "畔" */
+0x00,0x00,0x7d,0x54,0x54,0x54,0x55,0x7c,0x54,0x54,0x57,0x54,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30037 0x7555 "畕" */
+0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30038 0x7556 "畖" */
+0x00,0x00,0x7d,0x55,0x55,0x55,0x55,0x7d,0x55,0x55,0x55,0x55,0x7d,0x46,0x02,0x04,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 30039 0x7557 "畗" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30040 0x7558 "畘" */
+0x00,0x00,0x7c,0x55,0x55,0x55,0x55,0x7d,0x55,0x55,0x57,0x55,0x7d,0x45,0x01,0x01,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 30041 0x7559 "留" */
+0x06,0x78,0x40,0x48,0x44,0x5a,0x61,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0xfc,0x44,0x44,0x44,0x94,0x08,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30042 0x755a "畚" */
+0x02,0x04,0x08,0x1f,0x02,0x7f,0x08,0x10,0x3f,0xd1,0x11,0x1f,0x11,0x11,0x1f,0x10,
+0x00,0x40,0x20,0xf0,0x00,0xfc,0x20,0x10,0xf8,0x16,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 30043 0x755b "畛" */
+0x00,0x00,0x7c,0x54,0x55,0x56,0x54,0x7c,0x55,0x54,0x54,0x54,0x7d,0x44,0x00,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 30044 0x755c "畜" */
+0x02,0x01,0x7f,0x04,0x08,0x1f,0x03,0x0c,0x3f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0x00,0xfc,0x00,0x20,0xc0,0x10,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30045 0x755d "畝" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x7f,0x49,0x49,0x49,0x7f,0x49,0x49,0x49,0x7f,0x41,
+0x20,0x20,0x20,0xbc,0x24,0x44,0x44,0x88,0x08,0x10,0x10,0x28,0x28,0x44,0x84,0x02,
+/* 30046 0x755e "畞" */
+0x01,0x01,0xff,0x01,0x01,0x7d,0x55,0x55,0x55,0x7d,0x55,0x55,0x55,0x7d,0x45,0x01,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x38,0x48,0x48,0x88,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 30047 0x755f "畟" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x12,0x22,0x47,0x88,0x14,0x22,0x01,0x06,0x18,0xe0,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0xe4,0x22,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 30048 0x7560 "畠" */
+0x01,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30049 0x7561 "畡" */
+0x00,0x00,0x7c,0x55,0x54,0x54,0x54,0x7c,0x54,0x54,0x54,0x55,0x7c,0x44,0x00,0x01,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 30050 0x7562 "畢" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x09,0x09,0x7f,0x09,0x09,0x3f,0x01,0x7f,0x01,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x20,0xfc,0x20,0x20,0xf8,0x00,0xfc,0x00,0x00,
+/* 30051 0x7563 "畣" */
+0x01,0x02,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30052 0x7564 "畤" */
+0x00,0x00,0x7c,0x55,0x54,0x54,0x57,0x7c,0x54,0x55,0x54,0x54,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 30053 0x7565 "略" */
+0x00,0x00,0xf8,0xa9,0xab,0xac,0xf8,0xa8,0xa9,0xaa,0xad,0xf9,0x89,0x01,0x01,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 30054 0x7566 "畦" */
+0x00,0x00,0x7d,0x54,0x54,0x54,0x57,0x7c,0x54,0x54,0x55,0x54,0x7c,0x44,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30055 0x7567 "畧" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x08,0x1f,0x28,0x07,0x18,0xe0,0x1f,0x10,0x1f,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x10,
+/* 30056 0x7568 "畨" */
+0x01,0x11,0x09,0xff,0x05,0x09,0x31,0xc0,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x10,
+0x00,0x10,0x20,0xfe,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 30057 0x7569 "畩" */
+0x00,0x00,0x7c,0x55,0x54,0x54,0x54,0x7c,0x55,0x56,0x54,0x54,0x7c,0x44,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x88,0xa4,0xc2,0x80,
+/* 30058 0x756a "番" */
+0x00,0x3f,0x11,0x09,0x01,0xff,0x09,0x10,0x3f,0xd1,0x11,0x1f,0x11,0x11,0x1f,0x10,
+0xf8,0x00,0x10,0x20,0x00,0xfe,0x20,0x10,0xf8,0x16,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 30059 0x756b "畫" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 30060 0x756c "畬" */
+0x01,0x02,0x0c,0x30,0xcf,0x01,0x3f,0x11,0x25,0x02,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf8,0x10,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30061 0x756d "畭" */
+0x00,0x00,0x7c,0x54,0x55,0x56,0x54,0x7c,0x57,0x54,0x55,0x55,0x7e,0x44,0x00,0x00,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 30062 0x756e "畮" */
+0x00,0x00,0x7c,0x55,0x56,0x54,0x54,0x7c,0x57,0x54,0x55,0x55,0x7d,0x44,0x00,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 30063 0x756f "畯" */
+0x00,0x00,0xf8,0xa9,0xab,0xa8,0xf8,0xa9,0xaa,0xa8,0xa9,0xfa,0x88,0x00,0x01,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 30064 0x7570 "異" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x08,0x10,0x20,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0x10,0x08,
+/* 30065 0x7571 "畱" */
+0x00,0x7f,0x02,0x3e,0x22,0x22,0x3e,0x02,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,
+0x00,0xfc,0x80,0xf8,0x88,0x88,0xf8,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30066 0x7572 "畲" */
+0x01,0x02,0x0c,0x37,0xc0,0x3f,0x09,0x11,0x25,0x02,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0x80,0x60,0xd8,0x06,0xf8,0x20,0x10,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30067 0x7573 "畳" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x80,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,
+/* 30068 0x7574 "畴" */
+0x00,0x00,0xfb,0xa8,0xa9,0xa8,0xfb,0xa8,0xa8,0xa8,0xa9,0xf9,0x8a,0x04,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 30069 0x7575 "畵" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0xff,0x00,0x1f,0x51,0x5f,0x51,0x5f,0x40,0x7f,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfe,0x00,0xf0,0x14,0xf4,0x14,0xf4,0x04,0xfc,
+/* 30070 0x7576 "當" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30071 0x7577 "畷" */
+0x00,0x03,0xf8,0xa9,0xa8,0xa9,0xfa,0xac,0xa8,0xab,0xa8,0xf9,0x88,0x01,0x02,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 30072 0x7578 "畸" */
+0x00,0x00,0x7d,0x54,0x54,0x55,0x57,0x7c,0x55,0x55,0x55,0x55,0x7d,0x44,0x00,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 30073 0x7579 "畹" */
+0x00,0x00,0xfb,0xaa,0xad,0xa9,0xf9,0xaa,0xaa,0xab,0xac,0xf8,0x89,0x01,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 30074 0x757a "畺" */
+0x00,0x7f,0x00,0x3f,0x21,0x3f,0x21,0xff,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 30075 0x757b "畻" */
+0x00,0x01,0x7c,0x54,0x55,0x54,0x57,0x7c,0x55,0x56,0x54,0x55,0x7c,0x44,0x03,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 30076 0x757c "畼" */
+0x00,0x00,0x7c,0x54,0x54,0x54,0x54,0x7d,0x54,0x54,0x55,0x56,0x7c,0x45,0x00,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 30077 0x757d "畽" */
+0x00,0x00,0x7d,0x54,0x57,0x54,0x55,0x7d,0x55,0x55,0x55,0x54,0x7d,0x44,0x03,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 30078 0x757e "畾" */
+0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 30079 0x757f "畿" */
+0x11,0x21,0x45,0x79,0x11,0x25,0x7d,0x05,0x01,0xff,0x00,0x7c,0x54,0x7c,0x54,0x7d,
+0x10,0x20,0x44,0x78,0x10,0x24,0x7c,0x24,0x10,0xfe,0x80,0x88,0x52,0x22,0x5a,0x86,
+/* 30080 0x7580 "疀" */
+0x00,0x54,0x55,0xa8,0x55,0x54,0x03,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7d,0x45,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xa0,0xbc,0xa0,0x60,0x3e,0x00,
+/* 30081 0x7581 "疁" */
+0x00,0x07,0xf8,0xac,0xaa,0xac,0xf8,0xa9,0xae,0xa8,0xab,0xf8,0x8b,0x00,0x00,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 30082 0x7582 "疂" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x18,0x06,0x18,0x7f,0x50,0x9f,0x10,0x1f,0x10,0xff,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x30,0xc0,0x30,0xfe,0x12,0xf4,0x10,0xf0,0x10,0xfe,
+/* 30083 0x7583 "疃" */
+0x00,0x01,0x7c,0x54,0x57,0x54,0x55,0x7d,0x55,0x55,0x55,0x54,0x7d,0x44,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 30084 0x7584 "疄" */
+0x00,0x01,0xf8,0xab,0xa8,0xa9,0xfa,0xa9,0xa9,0xa9,0xaa,0xfd,0x88,0x01,0x02,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 30085 0x7585 "疅" */
+0x00,0x03,0xf8,0xa9,0xa9,0xa9,0xf9,0xab,0xa8,0xa9,0xa9,0xf9,0x89,0x01,0x00,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 30086 0x7586 "疆" */
+0x00,0xfb,0x08,0x09,0xf9,0x81,0x81,0xfb,0x48,0x49,0xe9,0x49,0x69,0x89,0x50,0x23,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 30087 0x7587 "疇" */
+0x00,0x03,0xf8,0xa9,0xa8,0xab,0xf8,0xa9,0xa8,0xab,0xa8,0xfb,0x88,0x03,0x02,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 30088 0x7588 "疈" */
+0x00,0xf8,0x00,0x70,0x52,0x72,0x02,0xfa,0xaa,0xac,0xf8,0xa8,0xa8,0xf9,0x89,0x02,
+0x80,0xbe,0x80,0x9c,0x94,0x9c,0x80,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0x3e,0x22,0x00,
+/* 30089 0x7589 "疉" */
+0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0xff,0x88,0x0f,0x10,0x1f,0x00,0xff,0x00,
+0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xfe,0x02,0xf0,0x10,0xe0,0x20,0xfe,0x00,
+/* 30090 0x758a "疊" */
+0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0xff,0x90,0x1f,0x10,0x1f,0x10,0xff,0x00,
+0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xfe,0x12,0xf0,0x10,0xf0,0x10,0xfe,0x00,
+/* 30091 0x758b "疋" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0x29,0x25,0x43,0x80,
+0x00,0x00,0xfc,0x04,0x08,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 30092 0x758c "疌" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 30093 0x758d "疍" */
+0x00,0x7f,0x01,0x11,0x11,0x29,0x47,0x80,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,0x00,
+0x00,0xfc,0x04,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 30094 0x758e "疎" */
+0x00,0x00,0x7d,0x04,0x08,0x11,0x51,0x51,0x5d,0x50,0x50,0x50,0x5d,0x72,0xc0,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 30095 0x758f "疏" */
+0x00,0x00,0x7d,0x04,0x08,0x10,0x51,0x50,0x5c,0x50,0x50,0x50,0x5d,0x71,0xc2,0x04,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0x2a,0x2a,0x2a,0x06,
+/* 30096 0x7590 "疐" */
+0x01,0x3f,0x01,0x7f,0x40,0x9f,0x11,0x1f,0x11,0x1f,0x00,0x7f,0x01,0x11,0x29,0xc7,
+0x00,0xf8,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xf0,0x00,0xfe,
+/* 30097 0x7591 "疑" */
+0x40,0x4d,0x70,0x44,0x44,0x3d,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x25,0x45,0x82,
+0x00,0xfc,0x08,0x50,0x20,0xfe,0x24,0x28,0xa0,0xb8,0xa0,0xa0,0xe0,0x20,0x1e,0x00,
+/* 30098 0x7592 "疒" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x50,0x10,0x30,0x50,0x90,0x10,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 30099 0x7593 "疓" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x51,0x11,0x31,0x51,0x91,0x11,0x22,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x10,0x20,0x3c,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 30100 0x7594 "疔" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x30,0x50,0x90,0x10,0x20,0x20,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 30101 0x7595 "疕" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x52,0x12,0x32,0x53,0x92,0x12,0x22,0x22,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x00,0x00,0x08,0x10,0x60,0x80,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 30102 0x7596 "疖" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x30,0x50,0x90,0x10,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,0x80,
+/* 30103 0x7597 "疗" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x30,0x50,0x90,0x10,0x20,0x20,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x80,
+/* 30104 0x7598 "疘" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x50,0x90,0x10,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 30105 0x7599 "疙" */
+0x00,0x00,0x1f,0x11,0x91,0x53,0x54,0x18,0x33,0x50,0x90,0x10,0x21,0x22,0x42,0x81,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x00,0x00,0xf8,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,
+/* 30106 0x759a "疚" */
+0x00,0x00,0x1f,0x11,0x91,0x51,0x53,0x12,0x34,0x58,0x90,0x10,0x20,0x21,0x46,0x98,
+0x80,0x40,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x20,0x20,0x40,0xa0,0x10,0x08,0x06,
+/* 30107 0x759b "疛" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x52,0x91,0x11,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 30108 0x759c "疜" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x50,0x90,0x10,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0x00,0xfe,0x40,0x40,0x50,0x48,0x44,0x40,0x40,0x40,0x40,
+/* 30109 0x759d "疝" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x50,0x14,0x34,0x54,0x94,0x14,0x24,0x27,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x40,0x40,0x40,0x44,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,0x00,
+/* 30110 0x759e "疞" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x50,0x10,0x37,0x50,0x91,0x13,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 30111 0x759f "疟" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x32,0x5f,0x92,0x12,0x22,0x23,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 30112 0x75a0 "疠" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x51,0x11,0x31,0x51,0x91,0x12,0x22,0x24,0x48,0x90,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 30113 0x75a1 "疡" */
+0x00,0x00,0x1f,0x10,0x93,0x50,0x50,0x11,0x33,0x51,0x91,0x12,0x22,0x24,0x48,0x81,
+0x80,0x40,0xfe,0x00,0xf0,0x20,0xc0,0x00,0xfc,0x24,0x24,0x24,0x44,0x44,0xa8,0x10,
+/* 30114 0x75a2 "疢" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x52,0x12,0x32,0x54,0x90,0x10,0x21,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x00,0x40,0x40,0x44,0x44,0x48,0x50,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 30115 0x75a3 "疣" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x50,0x17,0x30,0x51,0x91,0x11,0x22,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x00,0x90,0x88,0x80,0xfe,0xa0,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,
+/* 30116 0x75a4 "疤" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x32,0x52,0x93,0x12,0x22,0x22,0x41,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xf8,0x00,0x02,0x02,0xfe,0x00,
+/* 30117 0x75a5 "疥" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x51,0x12,0x3d,0x51,0x91,0x11,0x21,0x22,0x42,0x84,
+0x80,0x40,0xfe,0x40,0x40,0xa0,0x10,0x08,0x16,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 30118 0x75a6 "疦" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x53,0x10,0x30,0x50,0x97,0x10,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xf8,0x48,0x48,0x48,0xfe,0xa0,0xa0,0x10,0x08,0x06,
+/* 30119 0x75a7 "疧" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x34,0x57,0x94,0x14,0x24,0x25,0x46,0x84,
+0x80,0x40,0xfe,0x00,0x3c,0xc0,0x40,0x40,0x40,0xfe,0x20,0x20,0x12,0x0a,0x06,0x02,
+/* 30120 0x75a8 "疨" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x12,0x34,0x57,0x90,0x10,0x21,0x22,0x4c,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x10,0x10,0x10,0xfe,0x50,0x90,0x10,0x10,0x50,0x20,
+/* 30121 0x75a9 "疩" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x51,0x11,0x32,0x54,0x90,0x17,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x80,0x80,0xf0,0x10,0x12,0x12,0x4e,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 30122 0x75aa "疪" */
+0x00,0x00,0x1f,0x10,0x92,0x52,0x52,0x12,0x33,0x52,0x92,0x12,0x22,0x23,0x42,0x80,
+0x80,0x40,0xfe,0x20,0x20,0x20,0x22,0x24,0xa8,0x30,0x20,0x22,0xa2,0x22,0x1e,0x00,
+/* 30123 0x75ab "疫" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x52,0x14,0x38,0x57,0x92,0x11,0x20,0x20,0x41,0x8e,
+0x80,0x40,0xfe,0x00,0xf0,0x10,0x10,0x0e,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 30124 0x75ac "疬" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x52,0x12,0x32,0x52,0x92,0x12,0x22,0x24,0x44,0x89,
+0x80,0x40,0xfe,0x00,0xfe,0x00,0x20,0x20,0xfc,0x24,0x24,0x44,0x44,0x84,0xa8,0x10,
+/* 30125 0x75ad "疭" */
+0x00,0x00,0x1f,0x10,0x91,0x51,0x51,0x11,0x31,0x52,0x92,0x12,0x24,0x24,0x48,0x91,
+0x80,0x40,0xfe,0x00,0x10,0x10,0x10,0x10,0x10,0xa8,0x68,0x28,0x44,0x44,0x84,0x02,
+/* 30126 0x75ae "疮" */
+0x00,0x00,0x1f,0x10,0x90,0x51,0x52,0x14,0x3b,0x52,0x92,0x12,0x22,0x22,0x42,0x81,
+0x80,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,0xf0,0x10,0x10,0x50,0x20,0x04,0x04,0xfc,
+/* 30127 0x75af "疯" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x13,0x32,0x52,0x92,0x12,0x25,0x24,0x48,0x90,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x28,0xa8,0x48,0x48,0xa8,0x2a,0x0a,0x06,0x02,
+/* 30128 0x75b0 "疰" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x50,0x93,0x10,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x80,0x40,0x00,0xfc,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 30129 0x75b1 "疱" */
+0x00,0x00,0x1f,0x12,0x92,0x53,0x54,0x1b,0x32,0x52,0x93,0x12,0x22,0x22,0x42,0x81,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,0x02,0x02,0xfe,
+/* 30130 0x75b2 "疲" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x37,0x55,0x95,0x14,0x24,0x28,0x49,0x96,
+0x80,0x40,0xfe,0x40,0x40,0xfc,0x44,0x40,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 30131 0x75b3 "疳" */
+0x00,0x00,0x1f,0x10,0x92,0x52,0x5f,0x12,0x32,0x52,0x93,0x12,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x00,0x08,0x08,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 30132 0x75b4 "疴" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x33,0x52,0x92,0x13,0x22,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0xc8,0x48,0x08,0x28,0x10,
+/* 30133 0x75b5 "疵" */
+0x00,0x00,0x1f,0x10,0x91,0x51,0x55,0x15,0x35,0x55,0x95,0x15,0x25,0x25,0x5e,0x88,
+0x80,0x40,0xfe,0x00,0x10,0x10,0x12,0x14,0xd8,0x10,0x10,0x10,0x12,0xd2,0x12,0x0e,
+/* 30134 0x75b6 "疶" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x52,0x12,0x3f,0x52,0x92,0x12,0x22,0x22,0x43,0x80,
+0x80,0x40,0xfe,0x00,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0x00,0xfe,0x00,
+/* 30135 0x75b7 "疷" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x34,0x57,0x94,0x14,0x24,0x25,0x46,0x84,
+0x80,0x40,0xfe,0x00,0x3c,0xc0,0x40,0x40,0x40,0xfe,0x20,0x20,0x12,0x0a,0x46,0x22,
+/* 30136 0x75b8 "疸" */
+0x01,0x00,0x3f,0x20,0x20,0xa7,0x64,0x24,0x27,0x64,0xa4,0x27,0x20,0x40,0x5f,0x80,
+0x00,0x80,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 30137 0x75b9 "疹" */
+0x00,0x00,0x1f,0x10,0x90,0x51,0x52,0x14,0x30,0x53,0x90,0x10,0x23,0x20,0x40,0x87,
+0x80,0x40,0xfe,0x40,0xa0,0x10,0x08,0x26,0xc0,0x10,0x20,0xc0,0x08,0x10,0xe0,0x00,
+/* 30138 0x75ba "疺" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x37,0x50,0x90,0x10,0x23,0x24,0x48,0x90,
+0x80,0x40,0xfe,0x00,0x78,0x80,0x40,0x20,0xfc,0x08,0x30,0xc0,0x00,0x80,0x7e,0x00,
+/* 30139 0x75bb "疻" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x32,0x52,0x93,0x12,0x20,0x21,0x42,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x90,0x08,0x04,0x02,
+/* 30140 0x75bc "疼" */
+0x00,0x00,0x1f,0x11,0x91,0x53,0x56,0x19,0x30,0x53,0x9c,0x10,0x20,0x23,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x10,0x20,0xc0,0x30,0x0e,0xc0,0x20,0x00,0xc0,0x20,
+/* 30141 0x75bd "疽" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x52,0x12,0x33,0x52,0x92,0x13,0x22,0x22,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 30142 0x75be "疾" */
+0x00,0x00,0x1f,0x12,0x92,0x53,0x52,0x14,0x30,0x5f,0x90,0x10,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 30143 0x75bf "疿" */
+0x01,0x00,0x3f,0x21,0x3f,0xa1,0x61,0x2f,0x29,0x69,0xaf,0x21,0x22,0x42,0x44,0x88,
+0x00,0x80,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,
+/* 30144 0x75c0 "痀" */
+0x00,0x00,0x1f,0x12,0x92,0x53,0x54,0x18,0x33,0x52,0x92,0x13,0x22,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 30145 0x75c1 "痁" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x50,0x10,0x30,0x57,0x94,0x14,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x80,0x80,0x80,0xfc,0x80,0x80,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30146 0x75c2 "痂" */
+0x01,0x00,0x3f,0x24,0x24,0xa4,0x6f,0x24,0x24,0x64,0xa4,0x24,0x28,0x48,0x52,0xa1,
+0x00,0x80,0xfe,0x00,0x00,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,0x00,
+/* 30147 0x75c3 "痃" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x50,0x11,0x32,0x57,0x90,0x10,0x21,0x22,0x47,0x82,
+0x80,0x40,0xfe,0x80,0x40,0xfe,0x80,0x08,0x10,0xe0,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 30148 0x75c4 "痄" */
+0x00,0x00,0x1f,0x12,0x92,0x53,0x55,0x19,0x31,0x51,0x91,0x11,0x21,0x21,0x41,0x81,
+0x80,0x40,0xfe,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,
+/* 30149 0x75c5 "病" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x37,0x54,0x94,0x15,0x26,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x40,0x40,0xfc,0x44,0xa4,0x14,0x14,0x04,0x14,0x08,
+/* 30150 0x75c6 "痆" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x52,0x13,0x32,0x52,0x92,0x12,0x22,0x24,0x44,0x88,
+0x80,0x40,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x42,0x42,0x3e,
+/* 30151 0x75c7 "症" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x50,0x10,0x32,0x52,0x92,0x12,0x22,0x22,0x5f,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 30152 0x75c8 "痈" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x37,0x54,0x94,0x17,0x24,0x28,0x48,0x90,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 30153 0x75c9 "痉" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x50,0x10,0x33,0x5c,0x93,0x10,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0xf8,0x10,0x20,0xd8,0x04,0x02,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 30154 0x75ca "痊" */
+0x00,0x00,0x1f,0x10,0x90,0x51,0x52,0x1d,0x30,0x50,0x93,0x10,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 30155 0x75cb "痋" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x14,0x34,0x54,0x97,0x10,0x20,0x20,0x4f,0x84,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xfc,0x44,0x44,0x44,0xfc,0x40,0x48,0x7c,0x82,0x02,
+/* 30156 0x75cc "痌" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x15,0x34,0x55,0x95,0x15,0x25,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x04,0xf4,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 30157 0x75cd "痍" */
+0x00,0x00,0x1f,0x10,0x9f,0x50,0x5f,0x10,0x37,0x54,0x97,0x10,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x42,0xaa,0x14,0x08,0x06,
+/* 30158 0x75ce "痎" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x50,0x11,0x33,0x50,0x90,0x11,0x26,0x20,0x41,0x86,
+0x80,0x40,0xfe,0x80,0x40,0xfe,0x80,0x08,0xf0,0x20,0x44,0x88,0x10,0x68,0x84,0x02,
+/* 30159 0x75cf "痏" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x11,0x33,0x55,0x99,0x11,0x21,0x21,0x41,0x81,
+0x80,0x40,0xfe,0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 30160 0x75d0 "痐" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x35,0x55,0x95,0x15,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x04,0x04,0xf4,0x14,0x14,0xf4,0x04,0x04,0xfc,0x04,
+/* 30161 0x75d1 "痑" */
+0x00,0x00,0x1f,0x10,0x91,0x52,0x5d,0x10,0x31,0x56,0x90,0x11,0x26,0x20,0x40,0x87,
+0x80,0x40,0xfe,0x80,0xf8,0x10,0x20,0xc0,0xa0,0x7c,0x84,0x08,0x90,0x60,0xc0,0x00,
+/* 30162 0x75d2 "痒" */
+0x00,0x00,0x1f,0x11,0x90,0x57,0x50,0x10,0x33,0x50,0x90,0x17,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x10,0xa0,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,
+/* 30163 0x75d3 "痓" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x51,0x12,0x37,0x50,0x90,0x17,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0xfc,0x80,0x10,0x08,0xfc,0x44,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 30164 0x75d4 "痔" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x10,0x3f,0x50,0x90,0x1f,0x22,0x21,0x41,0x80,
+0x80,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 30165 0x75d5 "痕" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x57,0x14,0x37,0x54,0x94,0x14,0x24,0x25,0x46,0x84,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x84,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 30166 0x75d6 "痖" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x50,0x10,0x34,0x52,0x92,0x10,0x20,0x20,0x47,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x90,0x90,0x92,0x92,0x94,0x98,0x90,0x90,0xfe,0x00,
+/* 30167 0x75d7 "痗" */
+0x00,0x00,0x1f,0x12,0x92,0x53,0x54,0x1b,0x32,0x52,0x9f,0x14,0x24,0x27,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfe,0x00,0xf8,0x88,0x48,0xfe,0x88,0x48,0xfc,0x08,0x30,
+/* 30168 0x75d8 "痘" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x50,0x13,0x32,0x52,0x93,0x10,0x21,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0x10,0xa0,0xfe,0x00,
+/* 30169 0x75d9 "痙" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x52,0x14,0x32,0x50,0x97,0x10,0x20,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0xfc,0x00,0x48,0x90,0x48,0x00,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 30170 0x75da "痚" */
+0x01,0x00,0x3f,0x20,0x20,0xa7,0x60,0x3f,0x20,0x6f,0xa6,0x38,0x27,0x40,0x41,0x80,
+0x00,0x80,0xfe,0x80,0x88,0xf0,0xa0,0xfe,0x80,0xf0,0x20,0x40,0xfc,0x40,0x40,0x80,
+/* 30171 0x75db "痛" */
+0x01,0x00,0x1f,0x10,0x97,0x50,0x50,0x17,0x34,0x57,0x94,0x17,0x24,0x24,0x44,0x84,
+0x00,0x80,0xfe,0x00,0xf8,0xa0,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x48,
+/* 30172 0x75dc "痜" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x50,0x17,0x31,0x52,0x94,0x11,0x21,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x00,0x38,0xc0,0x40,0xfc,0x50,0x48,0x46,0xf0,0x10,0x10,0x12,0x0e,
+/* 30173 0x75dd "痝" */
+0x01,0x00,0x3f,0x22,0x22,0xbf,0x62,0x22,0x22,0x62,0xa2,0x22,0x24,0x44,0x48,0x93,
+0x00,0x80,0xfe,0x10,0x08,0xfe,0x48,0x50,0x64,0x48,0x52,0x64,0x4a,0x72,0xc2,0x3e,
+/* 30174 0x75de "痞" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x50,0x11,0x36,0x50,0x90,0x13,0x22,0x22,0x42,0x83,
+0x80,0x40,0xfe,0x00,0xfc,0x20,0x40,0xd0,0x48,0x44,0x00,0xf8,0x08,0x08,0x08,0xf8,
+/* 30175 0x75df "痟" */
+0x00,0x00,0x1f,0x10,0x92,0x51,0x50,0x13,0x32,0x53,0x92,0x13,0x22,0x22,0x42,0x82,
+0x80,0x40,0xfe,0x40,0x48,0x50,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 30176 0x75e0 "痠" */
+0x00,0x00,0x1f,0x10,0x91,0x52,0x57,0x11,0x32,0x54,0x91,0x13,0x24,0x20,0x41,0x8e,
+0x80,0x40,0xfe,0x80,0x08,0x04,0xfe,0x0a,0x84,0x82,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 30177 0x75e1 "痡" */
+0x00,0x00,0x1f,0x10,0x90,0x5f,0x50,0x17,0x34,0x57,0x94,0x17,0x24,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x50,0x48,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x48,
+/* 30178 0x75e2 "痢" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x51,0x11,0x3f,0x53,0x93,0x15,0x25,0x29,0x41,0x81,
+0x80,0x40,0xfe,0x00,0xc4,0x04,0x14,0x14,0xd4,0x14,0x94,0x54,0x04,0x04,0x14,0x08,
+/* 30179 0x75e3 "痣" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x53,0x90,0x10,0x21,0x25,0x45,0x88,
+0x80,0x40,0xfe,0x00,0x40,0x40,0xfc,0x40,0x40,0xfc,0x00,0x40,0x24,0x2a,0x0a,0xf8,
+/* 30180 0x75e4 "痤" */
+0x00,0x00,0x1f,0x10,0x90,0x52,0x52,0x15,0x38,0x50,0x90,0x17,0x20,0x20,0x40,0x8f,
+0x80,0x40,0xfe,0x40,0x40,0x48,0x48,0x54,0xe2,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,
+/* 30181 0x75e5 "痥" */
+0x00,0x00,0x1f,0x10,0x92,0x51,0x57,0x14,0x34,0x54,0x97,0x11,0x21,0x22,0x44,0x98,
+0x80,0x40,0xfe,0x00,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 30182 0x75e6 "痦" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x53,0x10,0x31,0x5f,0x90,0x13,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x00,0xfc,0x80,0xf8,0x88,0x08,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30183 0x75e7 "痧" */
+0x00,0x00,0x1f,0x10,0x92,0x51,0x51,0x14,0x32,0x52,0x91,0x16,0x22,0x22,0x42,0x80,
+0x80,0x40,0xfe,0x10,0x10,0x10,0x54,0x52,0x92,0x10,0x14,0x04,0x08,0x10,0x20,0xc0,
+/* 30184 0x75e8 "痨" */
+0x00,0x00,0x1f,0x11,0x91,0x57,0x51,0x10,0x37,0x54,0x90,0x17,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x08,0x08,0xfe,0x08,0x00,0xfe,0x02,0x40,0xfc,0x84,0x04,0x28,0x10,
+/* 30185 0x75e9 "痩" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x57,0x14,0x37,0x50,0x97,0x12,0x21,0x20,0x43,0x8c,
+0x80,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xf8,0x08,0x10,0xe0,0x18,0x06,
+/* 30186 0x75ea "痪" */
+0x00,0x00,0x1f,0x11,0x91,0x52,0x54,0x1b,0x32,0x52,0x92,0x1f,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x00,0xf0,0x10,0x20,0xf8,0x48,0x48,0x48,0xfe,0xa0,0x10,0x08,0x06,
+/* 30187 0x75eb "痫" */
+0x00,0x00,0x1f,0x10,0x92,0x51,0x54,0x14,0x35,0x54,0x94,0x15,0x26,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x00,0x00,0x7c,0x04,0x44,0xf4,0x44,0xe4,0x54,0x44,0x44,0x54,0x08,
+/* 30188 0x75ec "痬" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x51,0x93,0x14,0x29,0x22,0x44,0x81,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0x24,0x44,0xa8,0x10,
+/* 30189 0x75ed "痭" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x54,0x17,0x34,0x54,0x97,0x14,0x24,0x24,0x4a,0x91,
+0x80,0x40,0xfe,0x00,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xa4,0x4c,
+/* 30190 0x75ee "痮" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x52,0x9f,0x14,0x24,0x25,0x46,0x84,
+0x80,0x40,0xfe,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 30191 0x75ef "痯" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x13,0x32,0x52,0x93,0x12,0x23,0x22,0x42,0x83,
+0x80,0x40,0xfe,0x80,0x40,0xfc,0x04,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,
+/* 30192 0x75f0 "痰" */
+0x00,0x00,0x1f,0x10,0x92,0x52,0x54,0x11,0x32,0x5c,0x92,0x12,0x24,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x40,0x48,0x50,0xa0,0x10,0x08,0x44,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 30193 0x75f1 "痱" */
+0x00,0x00,0x1f,0x10,0x90,0x50,0x57,0x10,0x30,0x53,0x90,0x10,0x27,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x90,0x90,0x9e,0x90,0x90,0x9c,0x90,0x90,0x9e,0x90,0x90,0x90,
+/* 30194 0x75f2 "痲" */
+0x00,0x00,0x1f,0x11,0x91,0x51,0x5f,0x11,0x35,0x55,0x95,0x15,0x25,0x29,0x41,0x81,
+0x80,0x40,0xfe,0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0x54,0x54,0x56,0x10,0x10,
+/* 30195 0x75f3 "痳" */
+0x01,0x00,0x3f,0x22,0x22,0xa2,0x7f,0x22,0x26,0x67,0xaa,0x2a,0x32,0x42,0x42,0x82,
+0x00,0x80,0xfe,0x10,0x10,0x10,0xbe,0x10,0x10,0x38,0xb4,0x54,0x92,0x10,0x10,0x10,
+/* 30196 0x75f4 "痴" */
+0x00,0x00,0x1f,0x12,0x92,0x53,0x55,0x19,0x31,0x5f,0x91,0x11,0x22,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x00,0x00,0xbc,0x24,0x24,0x24,0xe4,0x24,0x24,0xa4,0xbc,0x24,0x00,
+/* 30197 0x75f5 "痵" */
+0x00,0x1f,0x10,0x10,0x93,0x50,0x17,0x31,0x52,0x9c,0x11,0x10,0x2f,0x20,0x41,0x80,
+0x80,0xfe,0x00,0x38,0xc0,0x40,0xfc,0x50,0x48,0x46,0xf0,0x20,0xfe,0x40,0x40,0x80,
+/* 30198 0x75f6 "痶" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x54,0x14,0x37,0x54,0x94,0x1f,0x20,0x21,0x42,0x84,
+0x80,0x40,0xfe,0xa0,0xa0,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,
+/* 30199 0x75f7 "痷" */
+0x01,0x00,0x3f,0x20,0x20,0xaf,0x61,0x22,0x24,0x6f,0xb4,0x27,0x24,0x47,0x40,0x80,
+0x00,0x80,0xfe,0x00,0x80,0xfc,0x20,0x10,0x88,0xf6,0x90,0xf0,0x90,0xf2,0x82,0x7e,
+/* 30200 0x75f8 "痸" */
+0x01,0x00,0x3f,0x21,0x25,0xa7,0x69,0x3f,0x21,0x67,0xa5,0x25,0x25,0x45,0x41,0x81,
+0x00,0x80,0xfe,0x00,0x04,0xc4,0x14,0xf4,0x14,0xd4,0x54,0x54,0x54,0xc4,0x14,0x08,
+/* 30201 0x75f9 "痹" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x50,0x9f,0x11,0x21,0x21,0x42,0x84,
+0x80,0x40,0xfe,0x00,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 30202 0x75fa "痺" */
+0x00,0x00,0x1f,0x10,0x91,0x57,0x54,0x17,0x34,0x57,0x91,0x12,0x3f,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x80,0x00,0xfc,0x44,0xfc,0x84,0xfc,0x40,0x40,0xfe,0x40,0x40,0x40,
+/* 30203 0x75fb "痻" */
+0x00,0x3f,0x20,0x20,0xaf,0x68,0x2f,0x28,0x6b,0xac,0x27,0x24,0x27,0x44,0x47,0x84,
+0x80,0xfe,0x00,0x38,0xc0,0x40,0xfc,0x20,0x1a,0x06,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30204 0x75fc "痼" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x54,0x17,0x34,0x55,0x95,0x15,0x25,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0xfc,0x44,0x44,0xfc,0x44,0xf4,0x14,0x14,0xf4,0x04,0xfc,0x04,
+/* 30205 0x75fd "痽" */
+0x00,0x00,0x1f,0x11,0x91,0x53,0x52,0x16,0x3b,0x52,0x92,0x13,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x20,0x10,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 30206 0x75fe "痾" */
+0x00,0x00,0x1f,0x10,0x97,0x55,0x55,0x16,0x35,0x55,0x95,0x15,0x27,0x24,0x44,0x84,
+0x80,0x40,0xfe,0x00,0x7e,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x14,0x08,
+/* 30207 0x75ff "痿" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x5f,0x11,0x32,0x5c,0x90,0x1f,0x21,0x23,0x40,0x8f,
+0x80,0x40,0xfe,0x38,0xc0,0x40,0xfe,0x50,0x48,0x46,0x80,0xfe,0x08,0x10,0xe0,0x1c,
+/* 30208 0x7600 "瘀" */
+0x01,0x00,0x3f,0x20,0x24,0xa2,0x6f,0x24,0x24,0x67,0xa4,0x24,0x28,0x48,0x52,0xa1,
+0x00,0x80,0xfe,0x00,0x10,0x10,0xa8,0x28,0x44,0x92,0x88,0x88,0xa0,0x90,0x88,0x08,
+/* 30209 0x7601 "瘁" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x51,0x11,0x32,0x54,0x90,0x1f,0x20,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x00,0x40,0xfc,0x10,0x10,0xa8,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 30210 0x7602 "瘂" */
+0x00,0x00,0x1f,0x10,0x9f,0x51,0x51,0x17,0x34,0x54,0x97,0x11,0x21,0x21,0x5f,0x80,
+0x80,0x40,0xfe,0x00,0xfc,0x20,0x20,0x38,0x08,0x08,0x38,0x20,0x20,0x20,0xfe,0x00,
+/* 30211 0x7603 "瘃" */
+0x01,0x00,0x3f,0x20,0x2f,0xa1,0x63,0x24,0x2d,0x62,0xa5,0x29,0x22,0x44,0x59,0x80,
+0x00,0x80,0xfe,0x00,0xfc,0x00,0x08,0x88,0x50,0x60,0xe0,0x50,0x50,0x48,0x44,0x80,
+/* 30212 0x7604 "瘄" */
+0x01,0x00,0x3f,0x22,0x2f,0xa2,0x62,0x3f,0x20,0x67,0xa4,0x24,0x27,0x44,0x44,0x87,
+0x00,0x80,0xfe,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 30213 0x7605 "瘅" */
+0x00,0x00,0x1f,0x12,0x91,0x57,0x54,0x17,0x34,0x57,0x94,0x10,0x2f,0x20,0x40,0x80,
+0x80,0x40,0xfe,0x08,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x40,0xfe,0x40,0x40,0x40,
+/* 30214 0x7606 "瘆" */
+0x00,0x00,0x1f,0x10,0x91,0x53,0x50,0x17,0x31,0x52,0x9d,0x10,0x21,0x20,0x40,0x83,
+0x80,0x40,0xfe,0x90,0x08,0xfc,0x40,0xfe,0x10,0x68,0x86,0x30,0xc0,0x18,0x60,0x80,
+/* 30215 0x7607 "瘇" */
+0x00,0x3f,0x20,0x27,0xa0,0x6f,0x20,0x27,0x64,0xa7,0x24,0x27,0x20,0x47,0x40,0x8f,
+0x80,0xfe,0x08,0xf0,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfc,0x40,0xfe,
+/* 30216 0x7608 "瘈" */
+0x00,0x00,0x1f,0x11,0x97,0x51,0x57,0x11,0x37,0x51,0x90,0x1f,0x20,0x21,0x42,0x8c,
+0x80,0x40,0xfe,0x00,0xbc,0x14,0x94,0x14,0xa4,0x4c,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 30217 0x7609 "瘉" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x5d,0x10,0x37,0x54,0x97,0x14,0x27,0x24,0x44,0x85,
+0x80,0x40,0xfe,0x40,0xa0,0x18,0xf6,0x00,0x84,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x88,
+/* 30218 0x760a "瘊" */
+0x01,0x00,0x3f,0x20,0x22,0xa2,0x64,0x2d,0x34,0x64,0xa5,0x24,0x25,0x44,0x44,0x85,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0x08,0xfe,0x80,0xf8,0x20,0x20,0xfe,0x50,0x88,0x06,
+/* 30219 0x760b "瘋" */
+0x01,0x00,0x3f,0x20,0x2f,0xa8,0x68,0x2b,0x28,0x6b,0xaa,0x2b,0x28,0x50,0x57,0xa0,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0x68,0x88,0x88,0xe8,0xa8,0xe8,0x8a,0xea,0x26,0x02,
+/* 30220 0x760c "瘌" */
+0x00,0x00,0x1f,0x11,0x91,0x57,0x51,0x17,0x35,0x57,0x91,0x13,0x25,0x29,0x41,0x81,
+0x80,0x40,0xfe,0x00,0x04,0xc4,0x14,0xd4,0x54,0xd4,0x14,0x94,0x54,0x44,0x14,0x08,
+/* 30221 0x760d "瘍" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x12,0x33,0x50,0x9f,0x12,0x27,0x29,0x42,0x84,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x24,0x54,0x88,
+/* 30222 0x760e "瘎" */
+0x00,0x00,0x1f,0x11,0x97,0x51,0x51,0x11,0x31,0x51,0x97,0x12,0x22,0x23,0x42,0x83,
+0x80,0x40,0xfe,0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x00,0x90,0x08,0x00,0xfc,
+/* 30223 0x760f "瘏" */
+0x00,0x00,0x1f,0x10,0x90,0x53,0x50,0x10,0x37,0x50,0x91,0x13,0x25,0x29,0x41,0x81,
+0x80,0x40,0xfe,0x40,0x44,0xf4,0x48,0x50,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30224 0x7610 "瘐" */
+0x01,0x00,0x3f,0x20,0x22,0xac,0x68,0x28,0x2e,0x68,0xa8,0x2f,0x21,0x42,0x4c,0xb0,
+0x00,0x80,0xfe,0x00,0x80,0xb8,0x88,0x88,0xb8,0x88,0x88,0xf8,0x40,0x20,0x18,0x06,
+/* 30225 0x7611 "瘑" */
+0x01,0x00,0x3f,0x20,0x23,0xa2,0x63,0x22,0x22,0x6f,0xa8,0x29,0x29,0x49,0x48,0x88,
+0x00,0x80,0xfe,0x00,0xf0,0x10,0xd0,0x50,0x50,0xfc,0x04,0xe4,0x24,0xe4,0x14,0x08,
+/* 30226 0x7612 "瘒" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x5b,0x10,0x33,0x52,0x93,0x12,0x23,0x20,0x4f,0x80,
+0x80,0x40,0xfe,0x00,0xfe,0x42,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfe,0x40,
+/* 30227 0x7613 "瘓" */
+0x01,0x00,0x3f,0x22,0x23,0xa4,0x6f,0x34,0x25,0x64,0xa0,0x2f,0x20,0x41,0x42,0x8c,
+0x00,0x80,0xfe,0x00,0xf0,0x20,0xfc,0xa4,0x14,0x44,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 30228 0x7614 "瘔" */
+0x00,0x00,0x1f,0x11,0x91,0x5f,0x51,0x10,0x3f,0x50,0x90,0x17,0x24,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x10,0x10,0xfe,0x10,0x40,0xfe,0x40,0x40,0xfc,0x04,0x04,0xfc,0x04,
+/* 30229 0x7615 "瘕" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x54,0x17,0x34,0x54,0x97,0x14,0x24,0x27,0x44,0x84,
+0x80,0x40,0xfe,0x00,0xbc,0x84,0x84,0xbc,0x00,0x7c,0xa4,0x24,0x28,0x90,0x28,0x46,
+/* 30230 0x7616 "瘖" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x52,0x11,0x3f,0x50,0x93,0x12,0x23,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x80,0x40,0xfc,0x10,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30231 0x7617 "瘗" */
+0x01,0x00,0x3f,0x20,0x2f,0xa4,0x62,0x3f,0x21,0x62,0xac,0x30,0x2f,0x40,0x40,0x9f,
+0x00,0x80,0xfe,0x80,0xf8,0x90,0xa0,0xfe,0x40,0x20,0x98,0x86,0xf8,0x80,0x80,0xfc,
+/* 30232 0x7618 "瘘" */
+0x00,0x00,0x1f,0x12,0x91,0x5f,0x51,0x12,0x34,0x50,0x9f,0x11,0x23,0x20,0x41,0x86,
+0x80,0x40,0xfe,0x48,0x50,0xfe,0x50,0x48,0x44,0x80,0xfe,0x08,0x90,0x60,0x98,0x04,
+/* 30233 0x7619 "瘙" */
+0x00,0x00,0x1f,0x10,0x97,0x52,0x51,0x10,0x33,0x5c,0x93,0x12,0x23,0x20,0x47,0x80,
+0x80,0x40,0xfe,0x00,0xfc,0x48,0x10,0xe0,0x18,0x46,0xf8,0x48,0xf8,0x44,0xfc,0x04,
+/* 30234 0x761a "瘚" */
+0x01,0x00,0x3f,0x28,0x25,0xaf,0x62,0x22,0x2a,0x6a,0xaf,0x22,0x22,0x44,0x44,0x88,
+0x00,0x80,0xfe,0x90,0x10,0xbe,0x22,0x44,0x90,0x90,0x90,0x10,0x28,0x28,0x44,0x82,
+/* 30235 0x761b "瘛" */
+0x00,0x00,0x1f,0x11,0x97,0x51,0x53,0x11,0x37,0x51,0x91,0x10,0x20,0x25,0x45,0x88,
+0x80,0x40,0xfe,0x00,0xbc,0x14,0x94,0x14,0xa4,0x4c,0x00,0x40,0x24,0x22,0x0a,0xf8,
+/* 30236 0x761c "瘜" */
+0x01,0x00,0x3f,0x21,0x27,0xa4,0x67,0x24,0x27,0x64,0xa7,0x20,0x20,0x4a,0x4a,0x91,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x44,0x42,0x12,0xf0,
+/* 30237 0x761d "瘝" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x54,0x17,0x30,0x51,0x92,0x14,0x21,0x22,0x44,0x80,
+0x80,0x40,0xfe,0x00,0xfc,0xa4,0xa4,0xfc,0x40,0x50,0x48,0x44,0x50,0x48,0x44,0x40,
+/* 30238 0x761e "瘞" */
+0x01,0x00,0x3f,0x20,0x27,0xa2,0x62,0x25,0x28,0x63,0xac,0x23,0x20,0x40,0x4f,0x80,
+0x00,0x80,0xfe,0x40,0xfc,0x48,0x48,0x54,0xa2,0x18,0x46,0xf8,0x40,0x40,0xfe,0x00,
+/* 30239 0x761f "瘟" */
+0x01,0x00,0x3f,0x20,0x27,0xa4,0x67,0x24,0x27,0x60,0xaf,0x29,0x29,0x49,0x7f,0x80,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfe,0x00,
+/* 30240 0x7620 "瘠" */
+0x00,0x00,0x1f,0x14,0x92,0x54,0x51,0x12,0x37,0x5a,0x93,0x12,0x23,0x22,0x42,0x82,
+0x80,0x40,0xfe,0x44,0x48,0xa4,0x10,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 30241 0x7621 "瘡" */
+0x00,0x00,0x1f,0x10,0x91,0x5e,0x53,0x12,0x33,0x52,0x93,0x12,0x25,0x25,0x49,0x81,
+0x80,0x40,0xfe,0x40,0xb0,0x4e,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,
+/* 30242 0x7622 "瘢" */
+0x01,0x00,0x3f,0x24,0x2f,0xa9,0x6d,0x2b,0x3f,0x69,0xa9,0x2d,0x2b,0x49,0x49,0x93,
+0x00,0x80,0xfe,0x00,0x78,0x48,0x48,0x86,0x00,0x78,0x48,0x48,0x28,0x10,0x28,0x46,
+/* 30243 0x7623 "瘣" */
+0x01,0x00,0x3f,0x20,0x21,0xaf,0x68,0x2f,0x28,0x6f,0xa1,0x21,0x22,0x44,0x48,0xb0,
+0x00,0x80,0xfe,0x80,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x54,0x5c,0x46,0x42,0x3e,
+/* 30244 0x7624 "瘤" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x55,0x15,0x36,0x50,0x97,0x14,0x27,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x80,0x7c,0x24,0xa4,0x54,0x48,0x80,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 30245 0x7625 "瘥" */
+0x00,0x00,0x1f,0x11,0x90,0x57,0x50,0x13,0x30,0x57,0x91,0x13,0x24,0x28,0x47,0x80,
+0x80,0x40,0xfe,0x10,0xa0,0xfc,0x40,0xf8,0x80,0xfc,0x00,0xf8,0x40,0x40,0xfe,0x00,
+/* 30246 0x7626 "瘦" */
+0x00,0x00,0x1f,0x11,0x96,0x54,0x57,0x14,0x37,0x50,0x97,0x12,0x21,0x20,0x43,0x8c,
+0x80,0x40,0xfe,0x40,0x5c,0x44,0x5c,0x44,0xfc,0x40,0xfc,0x08,0x10,0xe0,0x18,0x06,
+/* 30247 0x7627 "瘧" */
+0x00,0x3f,0x20,0x20,0xa0,0x6f,0x28,0x28,0x6f,0xa8,0x28,0x29,0x29,0x4b,0x49,0x91,
+0x80,0xfe,0x80,0xfc,0x80,0xfe,0x82,0xf0,0x84,0x7c,0x00,0xfc,0x00,0xfe,0x00,0xfc,
+/* 30248 0x7628 "瘨" */
+0x00,0x1f,0x10,0x17,0x90,0x53,0x12,0x33,0x52,0x93,0x12,0x13,0x22,0x2f,0x41,0x82,
+0x80,0xfe,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,
+/* 30249 0x7629 "瘩" */
+0x00,0x00,0x1f,0x11,0x91,0x57,0x51,0x10,0x31,0x52,0x9c,0x13,0x22,0x22,0x43,0x82,
+0x80,0x40,0xfe,0x10,0x10,0xfc,0x50,0xa0,0x10,0xe8,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 30250 0x762a "瘪" */
+0x00,0x3f,0x21,0x27,0xa4,0x67,0x24,0x27,0x64,0xa7,0x21,0x26,0x3a,0x43,0x42,0x81,
+0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x18,0x66,0x88,0x08,0xf8,
+/* 30251 0x762b "瘫" */
+0x01,0x00,0x3f,0x20,0x20,0xbe,0x72,0x2a,0x2b,0x64,0xa4,0x2a,0x2a,0x52,0x40,0x80,
+0x00,0x80,0xfe,0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 30252 0x762c "瘬" */
+0x00,0x00,0x1f,0x10,0x97,0x51,0x51,0x17,0x34,0x54,0x97,0x11,0x21,0x21,0x45,0x82,
+0x80,0x40,0xfe,0x00,0x3c,0x20,0x3c,0x20,0x3c,0x20,0x7e,0x28,0x2a,0x24,0x24,0x32,
+/* 30253 0x762d "瘭" */
+0x00,0x3f,0x20,0x3f,0xa1,0x6f,0x29,0x2f,0x60,0xa7,0x20,0x2f,0x22,0x44,0x49,0x80,
+0x80,0xfe,0x00,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x44,0x42,0x80,
+/* 30254 0x762e "瘮" */
+0x00,0x00,0x1f,0x11,0x93,0x52,0x54,0x17,0x30,0x53,0x9c,0x13,0x20,0x23,0x40,0x83,
+0x80,0x40,0xfe,0x10,0xf8,0x10,0xa4,0xfc,0xa0,0x18,0x46,0x90,0x64,0x98,0x60,0x80,
+/* 30255 0x762f "瘯" */
+0x00,0x00,0x1f,0x14,0x92,0x5f,0x54,0x14,0x37,0x55,0x95,0x15,0x25,0x29,0x4b,0x90,
+0x80,0x40,0xfe,0x20,0x20,0x7e,0x40,0xa0,0x3c,0x50,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 30256 0x7630 "瘰" */
+0x00,0x3f,0x20,0x27,0xa4,0x67,0x24,0x27,0x61,0xa2,0x27,0x20,0x2f,0x44,0x49,0x90,
+0x80,0xfe,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0x08,0xf0,0xc4,0xfe,0x48,0x44,0x82,
+/* 30257 0x7631 "瘱" */
+0x01,0x00,0x3f,0x20,0x2f,0xa2,0x62,0x25,0x28,0x63,0xac,0x20,0x2a,0x4a,0x52,0x81,
+0x00,0x80,0xfe,0x40,0xfe,0x48,0x48,0x54,0xa2,0x18,0x06,0x80,0x44,0x4a,0x0a,0xf8,
+/* 30258 0x7632 "瘲" */
+0x01,0x00,0x3f,0x22,0x24,0xa8,0x70,0x22,0x25,0x6c,0xb4,0x24,0x24,0x45,0x46,0x84,
+0x00,0x80,0xfe,0x00,0x48,0x48,0x54,0xa4,0x00,0x10,0x90,0x9c,0x90,0x50,0x3e,0x00,
+/* 30259 0x7633 "瘳" */
+0x00,0x3f,0x20,0x2f,0xa9,0x65,0x29,0x21,0x66,0xb8,0x23,0x2c,0x21,0x4e,0x41,0x8e,
+0x80,0xfe,0x00,0x7c,0x24,0x14,0xa4,0x60,0x18,0x86,0x20,0x40,0x88,0x30,0xc0,0x00,
+/* 30260 0x7634 "瘴" */
+0x00,0x3f,0x20,0x27,0xa1,0x6f,0x20,0x23,0x62,0xa3,0x22,0x23,0x20,0x4f,0x40,0x80,
+0x80,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,0x40,
+/* 30261 0x7635 "瘵" */
+0x01,0x00,0x3f,0x22,0x23,0xa4,0x6a,0x25,0x22,0x65,0xa8,0x27,0x22,0x44,0x49,0x80,
+0x00,0x80,0xfe,0x20,0xbc,0xa4,0xa8,0x10,0x08,0xf6,0x00,0xfc,0x50,0x48,0x44,0x80,
+/* 30262 0x7636 "瘶" */
+0x01,0x00,0x3f,0x22,0x22,0xaf,0x62,0x2f,0x2a,0x6a,0xaf,0x22,0x27,0x4a,0x52,0x82,
+0x00,0x80,0xfe,0x20,0x20,0xa0,0x3e,0xc2,0x94,0x90,0x90,0x10,0x28,0xa8,0x44,0x82,
+/* 30263 0x7637 "瘷" */
+0x01,0x00,0x3f,0x22,0x22,0xaf,0x62,0x2f,0x2a,0x6a,0xaf,0x22,0x27,0x4a,0x52,0x82,
+0x00,0x80,0xfe,0x10,0x10,0x90,0x3e,0xa4,0xd4,0x94,0x94,0x08,0x08,0x94,0x24,0x42,
+/* 30264 0x7638 "瘸" */
+0x00,0x00,0x1f,0x12,0x97,0x52,0x54,0x15,0x38,0x57,0x94,0x15,0x24,0x24,0x45,0x84,
+0x80,0x40,0xfe,0x00,0xbc,0xa4,0xa4,0xbc,0x40,0xfc,0xa4,0x54,0x44,0xa4,0x14,0x0c,
+/* 30265 0x7639 "瘹" */
+0x01,0x00,0x3f,0x22,0x25,0xa8,0x77,0x22,0x22,0x6f,0xa2,0x2a,0x27,0x43,0x5c,0x80,
+0x00,0x80,0xfe,0x10,0x20,0xbc,0x44,0x04,0x24,0x94,0x14,0x84,0x04,0xc4,0x28,0x10,
+/* 30266 0x763a "瘺" */
+0x01,0x00,0x3f,0x20,0x2f,0xa8,0x6f,0x28,0x2f,0x68,0xab,0x2b,0x2a,0x4b,0x4a,0x92,
+0x00,0x80,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x20,0xfe,0x32,0xaa,0x32,0xaa,0x06,
+/* 30267 0x763b "瘻" */
+0x01,0x00,0x3f,0x20,0x2f,0xa8,0x7f,0x28,0x2f,0x64,0xa7,0x21,0x3f,0x44,0x43,0x9c,
+0x00,0x80,0xfe,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x90,0xf0,0x00,0xfe,0x10,0xe0,0x1c,
+/* 30268 0x763c "瘼" */
+0x00,0x00,0x1f,0x11,0x97,0x51,0x53,0x12,0x33,0x52,0x93,0x10,0x2f,0x20,0x43,0x8c,
+0x80,0x40,0xfe,0x10,0xfc,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0xa0,0x18,0x06,
+/* 30269 0x763d "瘽" */
+0x00,0x3f,0x22,0x3f,0xa2,0x63,0x20,0x27,0x64,0xa7,0x20,0x2f,0x20,0x47,0x40,0x9f,
+0x80,0xfe,0x08,0xfe,0x08,0xf8,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x40,0xfc,0x40,0xfe,
+/* 30270 0x763e "瘾" */
+0x00,0x3f,0x20,0x2e,0xaa,0x6b,0x2c,0x2a,0x6a,0xaa,0x2b,0x2e,0x28,0x49,0x49,0x8a,
+0x80,0xfe,0x40,0x78,0x88,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x14,0x52,0x4a,0x38,
+/* 30271 0x763f "瘿" */
+0x00,0x3f,0x20,0x2f,0xa8,0x6a,0x2a,0x2a,0x65,0xa8,0x3f,0x22,0x27,0x40,0x43,0x9c,
+0x80,0xfe,0x00,0xbe,0xa2,0xaa,0xaa,0xaa,0x14,0xa2,0xfe,0x08,0x10,0xe0,0x1c,0x02,
+/* 30272 0x7640 "癀" */
+0x01,0x00,0x3f,0x22,0x2f,0xa2,0x7f,0x20,0x2f,0x68,0xaf,0x28,0x2f,0x42,0x44,0x88,
+0x00,0x80,0xfe,0x20,0xf8,0x20,0xfc,0x80,0xf8,0x88,0xf8,0x88,0xf8,0x20,0x10,0x08,
+/* 30273 0x7641 "癁" */
+0x00,0x00,0x1f,0x10,0x94,0x55,0x58,0x12,0x32,0x54,0x9c,0x14,0x24,0x25,0x44,0x85,
+0x80,0x40,0xfe,0x80,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfc,0x48,0x30,0xce,
+/* 30274 0x7642 "療" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x55,0x13,0x36,0x5b,0x92,0x13,0x20,0x24,0x49,0x80,
+0x80,0x40,0xfe,0x40,0xfc,0xa0,0x14,0xf8,0x0c,0xfa,0x08,0xf8,0x40,0x44,0x42,0x80,
+/* 30275 0x7643 "癃" */
+0x00,0x3f,0x20,0x2f,0xa9,0x6a,0x2c,0x2a,0x69,0xa9,0x2d,0x2a,0x28,0x48,0x48,0x88,
+0x80,0xfe,0x20,0x3c,0x44,0xa8,0x10,0x28,0x46,0x38,0x50,0x7e,0x90,0x7c,0x10,0xfe,
+/* 30276 0x7644 "癄" */
+0x00,0x00,0x1f,0x11,0x91,0x53,0x56,0x1b,0x32,0x53,0x92,0x13,0x22,0x25,0x44,0x88,
+0x80,0x40,0xfe,0x20,0x10,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x24,0x92,0x92,
+/* 30277 0x7645 "癅" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x57,0x14,0x37,0x50,0x97,0x14,0x27,0x24,0x47,0x84,
+0x80,0x40,0xfe,0x00,0xfe,0xa0,0xbc,0xa4,0xbc,0xa0,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 30278 0x7646 "癆" */
+0x01,0x00,0x3f,0x21,0x25,0xa5,0x69,0x22,0x24,0x6f,0xa8,0x30,0x2f,0x41,0x42,0x8c,
+0x00,0x80,0xfe,0x10,0x54,0xb8,0x10,0xa8,0x44,0xfe,0x82,0x84,0xf8,0x08,0x28,0x10,
+/* 30279 0x7647 "癇" */
+0x00,0x3f,0x20,0x2f,0xa9,0x6f,0x29,0x2f,0x68,0xa9,0x29,0x29,0x29,0x49,0x49,0x8a,
+0x80,0xfe,0x00,0x3c,0x24,0x3c,0x24,0x3c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x6c,
+/* 30280 0x7648 "癈" */
+0x01,0x00,0x3f,0x20,0x2f,0xa1,0x6a,0x24,0x3b,0x61,0xaf,0x28,0x2f,0x41,0x45,0x82,
+0x00,0x80,0xfe,0x40,0x50,0x24,0x18,0x08,0x76,0x50,0x8c,0x78,0x48,0x30,0x48,0x84,
+/* 30281 0x7649 "癉" */
+0x00,0x3f,0x20,0x2f,0xa8,0x6f,0x20,0x27,0x64,0xa7,0x24,0x27,0x20,0x7f,0x40,0x80,
+0x80,0xfe,0x00,0xbe,0xa2,0xbe,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfe,0x40,0x40,
+/* 30282 0x764a "癊" */
+0x01,0x00,0x3f,0x20,0x2f,0xa9,0x6a,0x2c,0x2a,0x69,0xa9,0x2d,0x2a,0x48,0x48,0x88,
+0x00,0x80,0xfe,0x10,0x28,0x44,0x92,0x7c,0x08,0x10,0x7e,0x00,0xfe,0x20,0x44,0xfe,
+/* 30283 0x764b "癋" */
+0x00,0x00,0x1f,0x10,0x97,0x50,0x53,0x12,0x33,0x50,0x9f,0x10,0x21,0x25,0x45,0x88,
+0x80,0x40,0xfe,0x00,0xfc,0xa0,0xb8,0x08,0xb8,0xa0,0xfe,0x40,0x24,0x2a,0x0a,0xf8,
+/* 30284 0x764c "癌" */
+0x00,0x00,0x1f,0x10,0x93,0x52,0x53,0x10,0x37,0x54,0x97,0x10,0x24,0x24,0x47,0x80,
+0x80,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xbc,0xa4,0xbc,0x40,0x44,0x44,0xfc,0x04,
+/* 30285 0x764d "癍" */
+0x01,0x00,0x3f,0x20,0x2e,0xa4,0x65,0x24,0x25,0x6e,0xa4,0x24,0x24,0x46,0x59,0x82,
+0x00,0x80,0xfe,0x80,0x4e,0x44,0xf4,0x24,0x24,0xae,0x44,0x44,0xa4,0xa4,0x0e,0x00,
+/* 30286 0x764e "癎" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x57,0x14,0x37,0x54,0x95,0x15,0x25,0x25,0x45,0x84,
+0x80,0x40,0xfe,0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x0c,
+/* 30287 0x764f "癏" */
+0x00,0x1f,0x10,0x17,0x94,0x57,0x10,0x3f,0x50,0x93,0x12,0x13,0x21,0x23,0x4d,0x81,
+0x80,0xfe,0x00,0xfc,0xa4,0xfc,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x44,0x28,0x10,0x8c,
+/* 30288 0x7650 "癐" */
+0x00,0x1f,0x10,0x13,0x9d,0x50,0x17,0x35,0x54,0x97,0x10,0x13,0x22,0x23,0x42,0x83,
+0x80,0xfe,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 30289 0x7651 "癑" */
+0x00,0x3f,0x21,0x27,0xa5,0x67,0x25,0x2f,0x68,0xab,0x28,0x2f,0x2a,0x4a,0x52,0xa3,
+0x80,0xfe,0x20,0xf8,0x28,0xf8,0x28,0xfe,0x00,0xfc,0x00,0xfe,0x44,0x28,0x98,0x06,
+/* 30290 0x7652 "癒" */
+0x00,0x3f,0x20,0x21,0xa6,0x7b,0x20,0x27,0x64,0xa7,0x24,0x27,0x24,0x45,0x4a,0x91,
+0x80,0xfe,0x40,0xa0,0x18,0xf6,0x00,0xa8,0xa8,0xa8,0xa8,0x88,0xa8,0x90,0x54,0xf2,
+/* 30291 0x7653 "癓" */
+0x01,0x00,0x3f,0x25,0x29,0xb5,0x67,0x28,0x3b,0x68,0xab,0x2a,0x2a,0x4a,0x4a,0x8c,
+0x00,0x80,0xfe,0x10,0x50,0x50,0xde,0x24,0x94,0x14,0x94,0x94,0x88,0xc8,0x94,0x22,
+/* 30292 0x7654 "癔" */
+0x00,0x00,0x1f,0x10,0x97,0x51,0x5f,0x10,0x33,0x52,0x93,0x12,0x23,0x25,0x45,0x88,
+0x80,0x40,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 30293 0x7655 "癕" */
+0x00,0x00,0x1f,0x10,0x90,0x57,0x52,0x12,0x34,0x57,0x92,0x14,0x27,0x22,0x44,0x88,
+0x80,0x40,0xfe,0x40,0x20,0xfe,0x28,0x7e,0xc8,0x7e,0x48,0xc8,0x7e,0x48,0x7e,0x40,
+/* 30294 0x7656 "癖" */
+0x01,0x00,0x3f,0x20,0x27,0xa4,0x64,0x27,0x24,0x64,0xaf,0x2c,0x34,0x47,0x44,0x80,
+0x00,0x80,0xfe,0x10,0x88,0xbe,0x80,0xa2,0x94,0x3e,0x88,0x88,0xbe,0x88,0x88,0x08,
+/* 30295 0x7657 "癗" */
+0x00,0x3f,0x20,0x27,0xa0,0x6f,0x28,0x23,0x60,0xa3,0x20,0x27,0x24,0x47,0x44,0x87,
+0x80,0xfe,0x00,0xfc,0x40,0xfe,0x42,0x58,0x40,0x58,0x00,0xfc,0x44,0xfc,0x44,0xfc,
+/* 30296 0x7658 "癘" */
+0x00,0x1f,0x11,0x1f,0x91,0x53,0x12,0x33,0x52,0x93,0x10,0x17,0x24,0x25,0x44,0x84,
+0x80,0xfe,0x10,0xfe,0x10,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x54,0xf4,0x14,0x0c,
+/* 30297 0x7659 "癙" */
+0x01,0x00,0x3f,0x21,0x2e,0xa8,0x6f,0x28,0x2f,0x68,0xac,0x2a,0x2c,0x4a,0x4c,0x88,
+0x00,0x80,0xfe,0x00,0x78,0x08,0x78,0x08,0xf8,0x88,0xc8,0xa8,0xca,0xaa,0xc6,0x82,
+/* 30298 0x765a "癚" */
+0x00,0x3f,0x22,0x23,0xa4,0x6f,0x35,0x26,0x64,0xa5,0x24,0x25,0x24,0x49,0x49,0x91,
+0x80,0xfe,0x00,0xf8,0x10,0xfe,0x24,0xfa,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,
+/* 30299 0x765b "癛" */
+0x00,0x3f,0x20,0x2f,0xa0,0x67,0x24,0x25,0x65,0xa7,0x20,0x23,0x20,0x4f,0x41,0x8e,
+0x80,0xfe,0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 30300 0x765c "癜" */
+0x01,0x00,0x3f,0x20,0x2f,0xa8,0x6f,0x2a,0x2a,0x6f,0xaa,0x2f,0x28,0x52,0x54,0xa8,
+0x00,0x80,0xfe,0x00,0xdc,0x54,0xd4,0xa2,0x80,0xdc,0x94,0xd4,0x08,0x88,0x54,0x62,
+/* 30301 0x765d "癝" */
+0x00,0x3f,0x20,0x2f,0xa0,0x67,0x24,0x25,0x65,0xa7,0x20,0x27,0x20,0x4f,0x42,0x84,
+0x80,0xfe,0x40,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xfc,0x00,0xfc,0x00,0xfe,0x48,0xc4,
+/* 30302 0x765e "癞" */
+0x00,0x3f,0x22,0x2f,0xa2,0x62,0x2f,0x2a,0x6a,0xaf,0x22,0x27,0x2a,0x52,0x42,0x82,
+0x80,0xfe,0x10,0x9c,0x24,0x48,0xbe,0xa2,0xaa,0xaa,0x2a,0x2a,0xaa,0x94,0x22,0x42,
+/* 30303 0x765f "癟" */
+0x00,0x3f,0x21,0x27,0xa6,0x65,0x24,0x27,0x62,0xa5,0x38,0x27,0x25,0x47,0x45,0x85,
+0x80,0xfe,0x00,0xf8,0x48,0x28,0x98,0xf8,0x10,0xe8,0x06,0xf8,0x48,0xf8,0x48,0x58,
+/* 30304 0x7660 "癠" */
+0x01,0x00,0x3f,0x20,0x2f,0xa0,0x6f,0x25,0x25,0x6b,0xa2,0x23,0x22,0x43,0x44,0x88,
+0x00,0x80,0xfe,0x40,0xfe,0xa0,0x5e,0x54,0x54,0x5a,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 30305 0x7661 "癡" */
+0x01,0x00,0x3f,0x24,0x27,0xa4,0x63,0x24,0x27,0x6a,0xa2,0x2f,0x22,0x45,0x48,0x90,
+0x00,0x80,0xfe,0x80,0x3c,0x84,0x94,0x08,0x7e,0x0a,0x28,0xae,0x28,0x58,0x4e,0x80,
+/* 30306 0x7662 "癢" */
+0x00,0x1f,0x12,0x11,0x97,0x50,0x13,0x30,0x5f,0x92,0x17,0x1a,0x23,0x22,0x43,0x82,
+0x80,0xfe,0x08,0x10,0xfc,0x40,0xf8,0x80,0xfe,0x10,0xf8,0x16,0xf0,0x64,0x18,0x04,
+/* 30307 0x7663 "癣" */
+0x01,0x00,0x3f,0x24,0x27,0xa9,0x72,0x2f,0x2a,0x6f,0xaa,0x2f,0x20,0x43,0x5c,0x80,
+0x00,0x80,0xfe,0x00,0x44,0x28,0x7e,0x90,0x90,0xbc,0x90,0x90,0x7e,0x90,0x10,0x10,
+/* 30308 0x7664 "癤" */
+0x00,0x00,0x1f,0x12,0x93,0x55,0x58,0x17,0x34,0x57,0x94,0x17,0x24,0x25,0x46,0x84,
+0x80,0x40,0xfe,0x10,0xde,0x28,0x84,0xbc,0xa4,0xa4,0xa4,0xa4,0x34,0x28,0xa0,0x20,
+/* 30309 0x7665 "癥" */
+0x01,0x00,0x3f,0x25,0x29,0xb5,0x67,0x28,0x3b,0x68,0xaf,0x29,0x2b,0x49,0x4f,0x88,
+0x00,0x80,0xfe,0x10,0x50,0x50,0xde,0x24,0x94,0x14,0xd4,0x14,0x88,0x08,0xd4,0x22,
+/* 30310 0x7666 "癦" */
+0x00,0x3f,0x20,0x27,0xa5,0x64,0x27,0x20,0x67,0xa0,0x2f,0x24,0x28,0x47,0x40,0x8f,
+0x80,0xfe,0x00,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,0xfc,0x40,0xfe,
+/* 30311 0x7667 "癧" */
+0x00,0x3f,0x20,0x2f,0xa8,0x6b,0x29,0x2f,0x6b,0xad,0x29,0x28,0x29,0x49,0x49,0x97,
+0x80,0xfe,0x00,0xfc,0x88,0x30,0x10,0xbc,0xb8,0x54,0x12,0x40,0x78,0x40,0x40,0xfc,
+/* 30312 0x7668 "癨" */
+0x00,0x3f,0x20,0x27,0xa0,0x6f,0x28,0x23,0x62,0xa7,0x2c,0x37,0x24,0x47,0x44,0x87,
+0x80,0xfe,0x00,0xfc,0x40,0xfe,0x42,0x58,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,
+/* 30313 0x7669 "癩" */
+0x01,0x00,0x3f,0x22,0x22,0xbf,0x62,0x2f,0x2a,0x6a,0xaf,0x22,0x27,0x4a,0x52,0x82,
+0x00,0x80,0xfe,0x10,0x1e,0xa2,0x44,0xbe,0xa2,0xbe,0xa2,0x3e,0x22,0xbe,0x94,0x22,
+/* 30314 0x766a "癪" */
+0x00,0x3f,0x20,0x23,0xae,0x62,0x2f,0x22,0x66,0xa7,0x2a,0x2a,0x32,0x42,0x42,0x82,
+0x80,0xfe,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x44,0x7c,0xc4,0x7c,0x44,0x7c,0x28,0x44,
+/* 30315 0x766b "癫" */
+0x00,0x3f,0x24,0x3f,0xa4,0x6f,0x29,0x2f,0x69,0xaf,0x29,0x2f,0x29,0x7f,0x49,0x90,
+0x80,0xfe,0x00,0xbe,0x08,0x10,0x3e,0x22,0x2a,0x2a,0x2a,0x2a,0x2a,0x94,0x12,0xa2,
+/* 30316 0x766c "癬" */
+0x01,0x00,0x3f,0x24,0x27,0xa9,0x72,0x2f,0x2a,0x6f,0xaa,0x2f,0x20,0x55,0x55,0x80,
+0x00,0x80,0xfe,0x00,0x22,0x14,0x3e,0x88,0x88,0x9c,0x88,0x88,0x3e,0x48,0x48,0x08,
+/* 30317 0x766d "癭" */
+0x00,0x3f,0x20,0x2f,0xa8,0x6f,0x28,0x2f,0x68,0xaf,0x25,0x28,0x2f,0x43,0x40,0x8f,
+0x80,0xfe,0x00,0xbe,0xa2,0xbe,0xa2,0xbe,0xa2,0xbe,0x14,0xa2,0xfe,0x10,0xe0,0x1c,
+/* 30318 0x766e "癮" */
+0x00,0x3f,0x20,0x2e,0xaa,0x6a,0x2c,0x2a,0x6a,0xaa,0x2a,0x2e,0x28,0x49,0x4a,0x88,
+0x80,0xfe,0x04,0xf8,0x54,0xfe,0x10,0xfe,0x04,0xfc,0x04,0xfc,0x20,0x54,0x4a,0x38,
+/* 30319 0x766f "癯" */
+0x00,0x1f,0x14,0x17,0x94,0x57,0x14,0x37,0x51,0x93,0x12,0x17,0x2a,0x23,0x42,0x83,
+0x80,0xfe,0xa4,0xbc,0xa4,0xbc,0xa4,0xbc,0x20,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,
+/* 30320 0x7670 "癰" */
+0x00,0x3f,0x20,0x2a,0xb5,0x6a,0x2f,0x29,0x6f,0xa0,0x2f,0x2a,0x2f,0x48,0x48,0x87,
+0x80,0xfe,0x00,0xa8,0x24,0xbe,0x68,0x68,0xbe,0x28,0xa8,0xbe,0xa8,0x28,0xbe,0xa0,
+/* 30321 0x7671 "癱" */
+0x00,0x3f,0x25,0x2f,0xa5,0x67,0x22,0x2f,0x6a,0xaf,0x22,0x2f,0x22,0x5f,0x45,0x88,
+0x80,0xfe,0x18,0x94,0x3e,0x28,0x68,0xbe,0xa8,0xa8,0x3e,0xa8,0x28,0xbe,0x20,0xa0,
+/* 30322 0x7672 "癲" */
+0x00,0x3f,0x22,0x3f,0xa2,0x6f,0x28,0x2f,0x68,0xaf,0x28,0x2f,0x28,0x5f,0x49,0x90,
+0x80,0xfe,0x00,0xbe,0x08,0x90,0xbe,0xa2,0xbe,0xa2,0xbe,0xa2,0xbe,0xc0,0x14,0xa2,
+/* 30323 0x7673 "癳" */
+0x00,0x3f,0x24,0x27,0xa4,0x6f,0x2a,0x2f,0x6a,0xaf,0x22,0x27,0x20,0x4f,0x42,0x84,
+0x80,0xfe,0x44,0xfc,0x44,0xfe,0xaa,0xbe,0xaa,0xbe,0x08,0xf0,0xc4,0xfe,0x48,0xc4,
+/* 30324 0x7674 "癴" */
+0x00,0x3f,0x24,0x2a,0xae,0x64,0x2a,0x2e,0x60,0xa7,0x20,0x27,0x20,0x4f,0x40,0x80,
+0x80,0xfe,0x44,0xea,0x0e,0xe4,0xaa,0xee,0x00,0xfc,0x40,0xfc,0x40,0xfe,0x40,0xc0,
+/* 30325 0x7675 "癵" */
+0x00,0x3f,0x24,0x28,0xae,0x64,0x2a,0x2e,0x60,0xaa,0x20,0x2f,0x28,0x49,0x48,0x88,
+0x80,0xfe,0x44,0xe8,0x0e,0xe4,0x0a,0xee,0xa0,0xea,0x40,0xfe,0xa2,0x12,0x42,0xa6,
+/* 30326 0x7676 "癶" */
+0x00,0x7c,0x04,0x04,0x44,0x24,0x24,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+0x88,0x90,0xa0,0xc0,0x82,0x44,0x48,0x50,0x20,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+/* 30327 0x7677 "癷" */
+0x00,0x7e,0x02,0x44,0x28,0x10,0x20,0xdf,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x90,0xa0,0x44,0x48,0x30,0x10,0x08,0xf6,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 30328 0x7678 "癸" */
+0x00,0x7e,0x02,0x44,0x28,0x10,0x20,0xcf,0x01,0x01,0x7f,0x01,0x02,0x04,0x18,0x60,
+0x90,0xa0,0x44,0x48,0x30,0x10,0x08,0xe6,0x00,0x00,0xfc,0x00,0xc0,0x20,0x10,0x08,
+/* 30329 0x7679 "癹" */
+0x00,0x7e,0x02,0x44,0x28,0x10,0x2f,0xc8,0x08,0x10,0x2f,0x00,0x0c,0x03,0x0c,0x70,
+0x90,0xa0,0x44,0x48,0x30,0x10,0xe8,0x26,0x20,0x1c,0xe0,0x20,0x40,0x80,0x70,0x08,
+/* 30330 0x767a "発" */
+0x00,0x7e,0x02,0x44,0x28,0x10,0x20,0xdf,0x04,0x04,0x7f,0x04,0x08,0x08,0x10,0x60,
+0x90,0xa0,0x44,0x48,0x30,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x40,0x44,0x44,0x3c,
+/* 30331 0x767b "登" */
+0x00,0x3e,0x02,0x24,0x14,0x08,0x17,0x20,0xdf,0x10,0x10,0x1f,0x08,0x04,0x7f,0x00,
+0x80,0x90,0xa4,0x48,0x50,0x20,0xd0,0x08,0xf6,0x10,0x10,0xf0,0x20,0x40,0xfc,0x00,
+/* 30332 0x767c "發" */
+0x00,0x7e,0x04,0x28,0x10,0x3c,0xc4,0x04,0x3d,0x20,0x41,0x7c,0x04,0x04,0x28,0x11,
+0x90,0xa0,0x44,0x28,0x10,0xf8,0x96,0x90,0x0c,0x00,0xf8,0x08,0xd0,0x20,0x50,0x88,
+/* 30333 0x767d "白" */
+0x01,0x02,0x04,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30334 0x767e "百" */
+0x00,0xff,0x01,0x02,0x04,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30335 0x767f "癿" */
+0x08,0x08,0x10,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 30336 0x7680 "皀" */
+0x02,0x04,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x00,0x20,0x23,0x3c,0x20,0x20,0x1f,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x38,0xc0,0x04,0x04,0x04,0xfc,
+/* 30337 0x7681 "皁" */
+0x02,0x04,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 30338 0x7682 "皂" */
+0x01,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x02,0x02,0x03,0xfe,0x02,0x02,0x01,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,0xfc,0x00,0x04,0x04,0xfc,
+/* 30339 0x7683 "皃" */
+0x04,0x08,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 30340 0x7684 "的" */
+0x10,0x10,0x20,0x7e,0x42,0x42,0x43,0x42,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x00,
+0x40,0x40,0x40,0x7c,0x84,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 30341 0x7685 "皅" */
+0x10,0x10,0x21,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x45,0x45,0x45,0x7d,0x44,0x00,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 30342 0x7686 "皆" */
+0x20,0x20,0x3c,0x20,0x20,0x2c,0x31,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x80,0x88,0xb0,0xc0,0x84,0x84,0x7c,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 30343 0x7687 "皇" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 30344 0x7688 "皈" */
+0x10,0x10,0x20,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x45,0x7d,0x46,0x00,
+0x04,0x0e,0xf0,0x80,0x80,0xfc,0xa4,0xa4,0xa4,0xa8,0xa8,0x90,0x10,0x28,0x44,0x82,
+/* 30345 0x7689 "皉" */
+0x10,0x10,0x20,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x7f,0x4a,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 30346 0x768a "皊" */
+0x10,0x10,0x20,0x7c,0x44,0x45,0x46,0x44,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 30347 0x768b "皋" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x04,0x09,0x31,0xcf,0x01,0x01,0x01,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x00,0x00,
+/* 30348 0x768c "皌" */
+0x10,0x10,0x20,0x7d,0x44,0x44,0x44,0x45,0x7c,0x44,0x44,0x45,0x45,0x7e,0x44,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 30349 0x768d "皍" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x20,0x3e,0x20,0x20,0x26,0x38,0x00,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x88,0x88,0x88,0xa8,0x90,0x80,0x80,
+/* 30350 0x768e "皎" */
+0x10,0x10,0x20,0x7b,0x48,0x48,0x49,0x4a,0x78,0x48,0x48,0x48,0x48,0x78,0x49,0x06,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 30351 0x768f "皏" */
+0x10,0x10,0x20,0x7c,0x44,0x44,0x44,0x44,0x7d,0x44,0x44,0x44,0x44,0x7c,0x44,0x01,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 30352 0x7690 "皐" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x21,0x11,0x09,0x11,0x21,0xff,0x01,0x01,0x01,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x10,0x20,0x10,0x08,0xfe,0x00,0x00,0x00,
+/* 30353 0x7691 "皑" */
+0x10,0x11,0x21,0x7d,0x45,0x44,0x45,0x44,0x7c,0x45,0x45,0x45,0x45,0x7d,0x44,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 30354 0x7692 "皒" */
+0x10,0x10,0x23,0x78,0x48,0x4b,0x48,0x48,0x78,0x48,0x4b,0x48,0x48,0x78,0x4a,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 30355 0x7693 "皓" */
+0x10,0x11,0x21,0x7d,0x45,0x46,0x44,0x47,0x7c,0x44,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 30356 0x7694 "皔" */
+0x10,0x11,0x21,0x7d,0x45,0x45,0x44,0x44,0x7d,0x44,0x44,0x47,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 30357 0x7695 "皕" */
+0x00,0x00,0xfe,0x10,0x10,0x20,0x7e,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x7e,0x42,
+0x00,0x00,0xfe,0x20,0x20,0x40,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 30358 0x7696 "皖" */
+0x10,0x10,0x23,0x7a,0x4c,0x49,0x48,0x48,0x7b,0x48,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 30359 0x7697 "皗" */
+0x10,0x11,0x21,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 30360 0x7698 "皘" */
+0x10,0x10,0x23,0x7c,0x45,0x44,0x47,0x44,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 30361 0x7699 "皙" */
+0x08,0x08,0x7e,0x18,0x2c,0x2a,0x48,0x88,0x09,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30362 0x769a "皚" */
+0x10,0x11,0x21,0x79,0x49,0x48,0x4b,0x48,0x79,0x49,0x49,0x49,0x48,0x78,0x4b,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 30363 0x769b "皛" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,
+/* 30364 0x769c "皜" */
+0x10,0x10,0x21,0x7c,0x44,0x44,0x44,0x44,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 30365 0x769d "皝" */
+0x10,0x20,0x7d,0x44,0x7c,0x44,0x7d,0x00,0xfe,0x10,0x10,0x7c,0x10,0x1e,0xf0,0x41,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 30366 0x769e "皞" */
+0x10,0x10,0x21,0x79,0x49,0x49,0x49,0x48,0x7b,0x48,0x49,0x4a,0x4d,0x78,0x48,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x88,0x24,0x22,0xfc,0x20,0x20,0x20,
+/* 30367 0x769f "皟" */
+0x10,0x13,0x20,0x7d,0x44,0x47,0x44,0x45,0x7d,0x45,0x45,0x45,0x45,0x7d,0x44,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 30368 0x76a0 "皠" */
+0x10,0x12,0x23,0x78,0x48,0x49,0x4b,0x4d,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 30369 0x76a1 "皡" */
+0x10,0x10,0x21,0x7d,0x45,0x45,0x45,0x44,0x7d,0x44,0x45,0x44,0x47,0x7c,0x44,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 30370 0x76a2 "皢" */
+0x10,0x10,0x21,0x78,0x4b,0x49,0x4b,0x49,0x79,0x4e,0x48,0x4b,0x48,0x78,0x49,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 30371 0x76a3 "皣" */
+0x10,0x13,0x20,0x78,0x49,0x48,0x48,0x4b,0x78,0x48,0x49,0x48,0x4b,0x78,0x48,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30372 0x76a4 "皤" */
+0x10,0x13,0x21,0x78,0x4b,0x48,0x49,0x4a,0x79,0x49,0x49,0x49,0x49,0x79,0x49,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 30373 0x76a5 "皥" */
+0x10,0x11,0x21,0x79,0x49,0x49,0x49,0x49,0x78,0x49,0x48,0x49,0x48,0x7b,0x48,0x00,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x24,0x20,0xfe,0x20,0x20,
+/* 30374 0x76a6 "皦" */
+0x10,0x11,0x23,0x7a,0x4b,0x4a,0x4b,0x49,0x78,0x4f,0x49,0x49,0x49,0x7a,0x4b,0x04,
+0x88,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x94,0xf4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 30375 0x76a7 "皧" */
+0x10,0x13,0x20,0x7a,0x49,0x4f,0x4c,0x4a,0x7a,0x4c,0x48,0x48,0x49,0x7a,0x48,0x07,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 30376 0x76a8 "皨" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x7e,0x42,0x7e,0x42,0x7e,0x01,0x3f,0x01,0xff,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xf8,0x00,0xfe,
+/* 30377 0x76a9 "皩" */
+0x10,0x21,0x7d,0x45,0x7d,0x45,0x7c,0x01,0xfc,0x10,0x13,0x7c,0x10,0x1d,0xe2,0x44,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 30378 0x76aa "皪" */
+0x11,0x11,0x22,0x7a,0x4b,0x49,0x4a,0x4b,0x78,0x48,0x4b,0x48,0x48,0x79,0x4a,0x00,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 30379 0x76ab "皫" */
+0x10,0x10,0x23,0x7a,0x4b,0x4a,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x7c,0x49,0x02,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 30380 0x76ac "皬" */
+0x11,0x10,0x23,0x7a,0x4d,0x48,0x49,0x48,0x79,0x4b,0x4d,0x49,0x49,0x79,0x49,0x01,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 30381 0x76ad "皭" */
+0x10,0x13,0x21,0x78,0x4b,0x4a,0x4b,0x48,0x7b,0x4a,0x4b,0x4a,0x4b,0x7a,0x4a,0x03,
+0x1e,0xe0,0x22,0x94,0xfe,0x52,0xfe,0x04,0xc4,0x7e,0xc4,0x54,0xcc,0x84,0xd4,0x48,
+/* 30382 0x76ae "皮" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x2f,0x24,0x24,0x22,0x21,0x20,0x41,0x46,0x98,
+0x80,0x80,0x80,0xfc,0x84,0x88,0x80,0xf0,0x10,0x10,0x20,0x40,0x80,0x40,0x30,0x0e,
+/* 30383 0x76af "皯" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x20,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 30384 0x76b0 "皰" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x20,
+0x20,0x20,0x7e,0x42,0x82,0x7a,0x4a,0x4a,0x7a,0x42,0x4a,0x44,0x42,0x42,0x3e,0x00,
+/* 30385 0x76b1 "皱" */
+0x20,0x20,0x3e,0x42,0x84,0x08,0xfe,0x02,0x02,0x7e,0x02,0x02,0x02,0xff,0x02,0x00,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30386 0x76b2 "皲" */
+0x00,0xff,0x91,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x49,0x09,0x0a,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30387 0x76b3 "皳" */
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0x92,0x54,0x10,0x38,0x54,0x92,0x11,0x51,0x22,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30388 0x76b4 "皴" */
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x29,0x45,0x82,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30389 0x76b5 "皵" */
+0x24,0x24,0x7e,0x24,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7f,0x42,0x00,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30390 0x76b6 "皶" */
+0x10,0x10,0xfe,0x38,0x54,0x92,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x1d,0xe1,0x42,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30391 0x76b7 "皷" */
+0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf1,0x42,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30392 0x76b8 "皸" */
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30393 0x76b9 "皹" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7e,0x42,0x42,0x52,0x4c,0x44,0x4a,0x92,0x20,
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 30394 0x76ba "皺" */
+0x40,0x40,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x48,0xfe,0x22,0xaa,0xfa,0x43,0x94,0x08,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30395 0x76bb "皻" */
+0x10,0x1e,0x10,0x7e,0x52,0x5c,0x72,0x4e,0x40,0x5c,0x54,0x5c,0x54,0x5d,0x96,0x38,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30396 0x76bc "皼" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x44,0x7c,0x44,0x29,0x0f,0xf2,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30397 0x76bd "皽" */
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7d,0x00,0xfe,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30398 0x76be "皾" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0xaa,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7d,0x28,0x44,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 30399 0x76bf "皿" */
+0x00,0x00,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xff,0x00,0x00,
+0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,0x00,
+/* 30400 0x76c0 "盀" */
+0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30401 0x76c1 "盁" */
+0x00,0x3f,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf0,0x10,0x20,0x3c,0x04,0x04,0x14,0x08,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30402 0x76c2 "盂" */
+0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x05,0x02,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30403 0x76c3 "盃" */
+0x00,0x7f,0x01,0x03,0x05,0x09,0x31,0xc1,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x70,0x0c,0x02,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30404 0x76c4 "盄" */
+0x00,0x7f,0x01,0x3f,0x21,0x3f,0x01,0x01,0x01,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x14,0x08,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30405 0x76c5 "盅" */
+0x01,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30406 0x76c6 "盆" */
+0x04,0x08,0x10,0x2f,0xc4,0x04,0x08,0x10,0x60,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x20,0x10,0xe8,0x26,0x20,0x20,0xa0,0x40,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30407 0x76c7 "盇" */
+0x01,0x01,0x7f,0x02,0x04,0x0a,0x31,0xc0,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30408 0x76c8 "盈" */
+0x00,0x3f,0x08,0x0f,0x08,0x12,0x11,0x22,0x44,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf0,0x10,0xa0,0xbc,0x84,0x04,0x94,0x48,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30409 0x76c9 "盉" */
+0x00,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xc0,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x70,0x80,0x00,0x00,0xfe,0x40,0x20,0x18,0x06,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30410 0x76ca "益" */
+0x10,0x08,0x00,0xff,0x00,0x08,0x10,0x20,0x40,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x10,0x20,0x00,0xfe,0x00,0x20,0x10,0x08,0x04,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30411 0x76cb "盋" */
+0x02,0x02,0x7f,0x04,0x0b,0x11,0x20,0x43,0x1c,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x20,0xfc,0x00,0xf0,0x20,0xc0,0x30,0x0e,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30412 0x76cc "盌" */
+0x10,0x10,0x3e,0x42,0xa2,0x14,0x08,0x10,0x20,0xc0,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf8,0x88,0x88,0xa8,0x90,0x84,0x84,0x7c,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30413 0x76cd "盍" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x04,0x08,0x1f,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0xf0,0x10,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30414 0x76ce "盎" */
+0x01,0x01,0x1f,0x11,0x11,0xff,0x02,0x0c,0x30,0xc0,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xf0,0x10,0x10,0xfe,0x80,0x60,0x18,0x06,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30415 0x76cf "盏" */
+0x02,0x02,0x03,0x7e,0x03,0xfe,0x01,0x03,0x1c,0xe0,0x00,0x3f,0x24,0x24,0x24,0xff,
+0x40,0x20,0xf8,0x00,0xfc,0x10,0x60,0x82,0x62,0x1e,0x00,0xf8,0x48,0x48,0x48,0xfe,
+/* 30416 0x76d0 "盐" */
+0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x20,0x20,0x20,0x28,0x24,0x22,0x20,0x20,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30417 0x76d1 "监" */
+0x04,0x24,0x24,0x24,0x24,0x24,0x25,0x04,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x40,0x40,0x7c,0x40,0x90,0x88,0x08,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30418 0x76d2 "盒" */
+0x01,0x02,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30419 0x76d3 "盓" */
+0x10,0x09,0x40,0x20,0x0b,0x10,0x70,0x10,0x10,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30420 0x76d4 "盔" */
+0x04,0x04,0x7f,0x08,0x12,0x12,0x24,0x41,0x82,0x0c,0x00,0x3f,0x24,0x24,0x24,0xff,
+0x00,0x00,0xfc,0x40,0x48,0x50,0xa0,0x10,0x08,0x06,0x00,0xf8,0x48,0x48,0x48,0xfe,
+/* 30421 0x76d5 "盕" */
+0x10,0x09,0x41,0x25,0x05,0x09,0x71,0x11,0x12,0x14,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf0,0x10,0x90,0x50,0x50,0x12,0x12,0x0e,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30422 0x76d6 "盖" */
+0x08,0x04,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x00,0x3f,0x24,0x24,0x24,0xff,
+0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x48,0x48,0x48,0xfe,
+/* 30423 0x76d7 "盗" */
+0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30424 0x76d8 "盘" */
+0x02,0x04,0x1f,0x11,0x10,0xff,0x10,0x12,0x21,0x40,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xf0,0x10,0x90,0xfe,0x10,0x10,0x50,0x20,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30425 0x76d9 "盙" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x00,0x3f,0x24,0x24,0xff,0x00,
+0x20,0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 30426 0x76da "盚" */
+0x01,0x01,0x7f,0x01,0x21,0x11,0x07,0x19,0xe1,0x45,0x02,0x3f,0x24,0x24,0xff,0x00,
+0x10,0x08,0xfc,0x00,0x18,0xa0,0x40,0x20,0x18,0x06,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 30427 0x76db "盛" */
+0x00,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x4a,0x44,0x81,0x3f,0x24,0x24,0xff,0x00,
+0x90,0x88,0xfc,0x80,0x88,0x48,0x50,0x24,0x54,0x8c,0x04,0xf8,0x48,0x48,0xfe,0x00,
+/* 30428 0x76dc "盜" */
+0x00,0x20,0x11,0x82,0x54,0x20,0xe0,0x23,0x2c,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30429 0x76dd "盝" */
+0x3f,0x00,0x1f,0x00,0xff,0x11,0x09,0x05,0x19,0xe5,0x02,0x3f,0x24,0x24,0xff,0x00,
+0xf0,0x10,0xf0,0x10,0xfe,0x10,0xa0,0x40,0x30,0x0e,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 30430 0x76de "盞" */
+0x02,0x02,0x7f,0x00,0x07,0x78,0x02,0x02,0x7f,0x00,0x07,0x78,0x00,0x3f,0x24,0xff,
+0x10,0xfc,0x40,0x84,0x64,0x1c,0x10,0xfc,0x40,0x84,0x64,0x1c,0x00,0xf8,0x48,0xfe,
+/* 30431 0x76df "盟" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x02,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x14,0x08,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30432 0x76e0 "盠" */
+0x08,0x0f,0x10,0x1f,0x00,0x7f,0x06,0x19,0x06,0x39,0x06,0x39,0x00,0x3f,0x24,0xff,
+0x00,0xe0,0x20,0xc0,0x40,0xfc,0x00,0x20,0xc0,0xb0,0x8c,0x80,0x00,0xf8,0x48,0xfe,
+/* 30433 0x76e1 "盡" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7f,0x24,0x42,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x88,0x44,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30434 0x76e2 "盢" */
+0x00,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x01,0x02,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x20,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30435 0x76e3 "監" */
+0x00,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x20,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 30436 0x76e4 "盤" */
+0x10,0x3e,0x22,0x2a,0xff,0x22,0x2a,0x42,0x4a,0x84,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x10,0x28,0x46,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30437 0x76e5 "盥" */
+0x11,0x61,0x4d,0x45,0x75,0x49,0x49,0x75,0x42,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x1c,0x44,0x44,0x9c,0x84,0x44,0x5c,0x04,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30438 0x76e6 "盦" */
+0x01,0x06,0x19,0xe7,0x00,0xff,0x04,0x3f,0x28,0x37,0x20,0x3f,0x00,0x3f,0x24,0xff,
+0x00,0xc0,0x30,0xce,0x80,0xfe,0x40,0xf8,0x48,0xb8,0x08,0xf8,0x00,0xf8,0x48,0xfe,
+/* 30439 0x76e7 "盧" */
+0x01,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x27,0x20,0x4f,0x49,0xbf,
+0x00,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x90,0xf0,0x90,0xf0,0x00,0xf8,0x48,0xfe,
+/* 30440 0x76e8 "盨" */
+0x0b,0x10,0x61,0x09,0x11,0x61,0x05,0x09,0x31,0xc0,0x01,0x3f,0x24,0x24,0xff,0x00,
+0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0xf8,0x48,0x48,0xfe,0x00,
+/* 30441 0x76e9 "盩" */
+0x08,0x7f,0x08,0xff,0x22,0x7f,0x08,0xff,0x08,0x08,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x10,0x28,0x46,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30442 0x76ea "盪" */
+0x23,0x12,0x93,0x42,0x43,0x10,0x2f,0xe2,0x27,0x29,0x22,0x04,0x3f,0x24,0x24,0xff,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x24,0x54,0x88,0xf8,0x48,0x48,0xfe,
+/* 30443 0x76eb "盫" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x7f,0x04,0x1f,0x14,0x1b,0x10,0x3f,0x24,0xff,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xfc,0x40,0xf0,0x50,0xb0,0x10,0xf8,0x48,0xfe,
+/* 30444 0x76ec "盬" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x48,0x7e,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x7c,0x90,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 30445 0x76ed "盭" */
+0x10,0x22,0x7c,0x0a,0x7f,0x08,0x7f,0x14,0x7f,0x08,0x7f,0x08,0x3f,0x24,0x24,0xff,
+0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,0xf8,0x48,0x48,0xfe,
+/* 30446 0x76ee "目" */
+0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x3f,0x20,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30447 0x76ef "盯" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x48,0x48,0x78,0x48,0x48,0x48,0x78,0x48,0x00,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 30448 0x76f0 "盰" */
+0x00,0x01,0x7c,0x44,0x44,0x7c,0x44,0x47,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 30449 0x76f1 "盱" */
+0x00,0x01,0x7c,0x44,0x44,0x7c,0x44,0x47,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 30450 0x76f2 "盲" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30451 0x76f3 "盳" */
+0x00,0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 30452 0x76f4 "直" */
+0x01,0x01,0x7f,0x01,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 30453 0x76f5 "盵" */
+0x00,0x00,0x7c,0x44,0x45,0x7e,0x44,0x44,0x7c,0x44,0x44,0x44,0x7d,0x45,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 30454 0x76f6 "盶" */
+0x00,0x00,0x7d,0x44,0x44,0x7c,0x47,0x44,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 30455 0x76f7 "盷" */
+0x00,0x00,0x7c,0x44,0x45,0x7e,0x44,0x44,0x7c,0x44,0x44,0x44,0x7d,0x44,0x00,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 30456 0x76f8 "相" */
+0x08,0x08,0x08,0x08,0xfe,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,0x08,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 30457 0x76f9 "盹" */
+0x00,0x00,0x78,0x4b,0x48,0x79,0x49,0x49,0x79,0x49,0x48,0x48,0x78,0x48,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 30458 0x76fa "盺" */
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 30459 0x76fb "盻" */
+0x00,0x00,0x79,0x49,0x4a,0x7c,0x4b,0x48,0x79,0x49,0x48,0x48,0x78,0x48,0x00,0x00,
+0x90,0x90,0x08,0x08,0x04,0x02,0xfc,0x80,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 30460 0x76fc "盼" */
+0x00,0x00,0x78,0x48,0x49,0x79,0x4a,0x4d,0x78,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 30461 0x76fd "盽" */
+0x00,0x00,0x7c,0x45,0x44,0x7c,0x44,0x45,0x7c,0x44,0x44,0x47,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 30462 0x76fe "盾" */
+0x00,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x28,0x28,0x2f,0x48,0x48,0x8f,0x08,
+0x7c,0x80,0x80,0xfc,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30463 0x76ff "盿" */
+0x00,0x00,0x7c,0x47,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 30464 0x7700 "眀" */
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,0x04,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 30465 0x7701 "省" */
+0x01,0x11,0x11,0x21,0x40,0x03,0x0c,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x10,0x08,0x24,0xc0,0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30466 0x7702 "眂" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 30467 0x7703 "眃" */
+0x00,0x00,0x79,0x48,0x48,0x78,0x4b,0x48,0x78,0x48,0x48,0x48,0x79,0x4b,0x01,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 30468 0x7704 "眄" */
+0x00,0x03,0x7c,0x44,0x45,0x7d,0x45,0x45,0x7d,0x45,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfe,0x20,0x20,0x20,0x3e,0x22,0x22,0x22,0xfe,0x02,0x02,0x02,0x02,0x14,0x08,
+/* 30469 0x7705 "眅" */
+0x00,0x00,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 30470 0x7706 "眆" */
+0x00,0x00,0x7c,0x45,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 30471 0x7707 "眇" */
+0x00,0x00,0x78,0x49,0x49,0x7a,0x4a,0x4c,0x78,0x48,0x48,0x48,0x78,0x48,0x01,0x06,
+0x40,0x40,0x40,0x48,0x44,0x42,0x42,0x48,0x48,0x48,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 30472 0x7708 "眈" */
+0x00,0x00,0x78,0x4b,0x4a,0x7c,0x48,0x48,0x78,0x48,0x48,0x49,0x79,0x4a,0x04,0x08,
+0x40,0x40,0x40,0xfc,0x44,0x48,0x40,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 30473 0x7709 "眉" */
+0x00,0x3f,0x21,0x21,0x3f,0x20,0x2f,0x28,0x28,0x2f,0x28,0x2f,0x48,0x48,0x8f,0x08,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 30474 0x770a "眊" */
+0x00,0x00,0x7d,0x44,0x44,0x7c,0x45,0x44,0x7c,0x44,0x47,0x44,0x7c,0x44,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 30475 0x770b "看" */
+0x00,0x7f,0x01,0x3f,0x02,0xff,0x04,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x0f,0x08,
+0xf8,0x00,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30476 0x770c "県" */
+0x00,0x0f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x7f,0x01,0x11,0x11,0x21,0x45,0x02,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 30477 0x770d "眍" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x00,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 30478 0x770e "眎" */
+0x00,0x01,0x78,0x48,0x48,0x7b,0x48,0x48,0x79,0x49,0x4a,0x4a,0x7c,0x48,0x00,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 30479 0x770f "眏" */
+0x00,0x00,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7d,0x47,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 30480 0x7710 "眐" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x07,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30481 0x7711 "眑" */
+0x00,0x00,0x78,0x49,0x49,0x7a,0x4b,0x48,0x79,0x49,0x4a,0x4b,0x78,0x48,0x00,0x00,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 30482 0x7712 "眒" */
+0x00,0x00,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x44,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 30483 0x7713 "眓" */
+0x00,0x00,0x78,0x48,0x4b,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7b,0x4a,0x00,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 30484 0x7714 "眔" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x09,0x11,0x21,0x41,0x09,0x11,0x21,0x41,0x01,0x01,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x20,0x10,0x08,0x04,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 30485 0x7715 "眕" */
+0x00,0x00,0x7c,0x44,0x45,0x7e,0x44,0x44,0x7d,0x44,0x44,0x44,0x7d,0x44,0x00,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 30486 0x7716 "眖" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x45,0x44,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 30487 0x7717 "眗" */
+0x00,0x00,0x7d,0x45,0x46,0x7c,0x45,0x45,0x7d,0x45,0x45,0x45,0x7c,0x44,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 30488 0x7718 "眘" */
+0x01,0x01,0xff,0x01,0x22,0x14,0x08,0x30,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x00,0x88,0x50,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30489 0x7719 "眙" */
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 30490 0x771a "眚" */
+0x01,0x11,0x1f,0x21,0x5f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xf8,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30491 0x771b "眛" */
+0x00,0x00,0x7c,0x45,0x44,0x7c,0x44,0x47,0x7c,0x44,0x44,0x45,0x7d,0x46,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 30492 0x771c "眜" */
+0x00,0x00,0x7c,0x47,0x44,0x7c,0x44,0x45,0x7c,0x44,0x44,0x45,0x7d,0x46,0x00,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 30493 0x771d "眝" */
+0x00,0x00,0x78,0x4b,0x4a,0x7c,0x48,0x48,0x7b,0x48,0x48,0x48,0x78,0x48,0x00,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 30494 0x771e "眞" */
+0x20,0x3f,0x20,0x1f,0x00,0x0f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x7f,0x10,0x20,
+0x70,0x84,0x04,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x10,0x08,
+/* 30495 0x771f "真" */
+0x01,0x01,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x10,0x20,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x10,0x08,
+/* 30496 0x7720 "眠" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 30497 0x7721 "眡" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 30498 0x7722 "眢" */
+0x10,0x1e,0x22,0x62,0x94,0x08,0x30,0xc0,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xf8,0x88,0xa8,0x92,0x82,0x7e,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30499 0x7723 "眣" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x46,0x44,0x7d,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30500 0x7724 "眤" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x46,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 30501 0x7725 "眥" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30502 0x7726 "眦" */
+0x00,0x00,0x78,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4f,0x02,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 30503 0x7727 "眧" */
+0x00,0x01,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 30504 0x7728 "眨" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x4b,0x48,0x78,0x48,0x48,0x48,0x79,0x4a,0x04,0x00,
+0x08,0x3c,0xc0,0x00,0x40,0x20,0xfc,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x7e,0x00,
+/* 30505 0x7729 "眩" */
+0x00,0x00,0x78,0x4b,0x48,0x78,0x48,0x49,0x7b,0x48,0x48,0x48,0x79,0x4b,0x01,0x00,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x88,0x08,0xf0,0x20,0x40,0x88,0x04,0xfc,0x04,0x00,
+/* 30506 0x772a "眪" */
+0x00,0x01,0x7c,0x44,0x44,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 30507 0x772b "眫" */
+0x00,0x00,0x7d,0x44,0x44,0x7c,0x45,0x44,0x7c,0x44,0x47,0x44,0x7c,0x44,0x00,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30508 0x772c "眬" */
+0x00,0x00,0x78,0x48,0x4b,0x78,0x48,0x48,0x78,0x49,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0x28,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 30509 0x772d "眭" */
+0x00,0x00,0x7d,0x44,0x44,0x7c,0x47,0x44,0x7c,0x44,0x45,0x44,0x7c,0x44,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30510 0x772e "眮" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 30511 0x772f "眯" */
+0x00,0x00,0x79,0x48,0x48,0x78,0x48,0x4b,0x78,0x48,0x48,0x49,0x79,0x4a,0x00,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 30512 0x7730 "眰" */
+0x00,0x01,0x7c,0x44,0x44,0x7d,0x45,0x44,0x7c,0x44,0x45,0x44,0x7c,0x44,0x03,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 30513 0x7731 "眱" */
+0x00,0x00,0x7b,0x48,0x49,0x78,0x49,0x49,0x79,0x48,0x48,0x48,0x78,0x48,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 30514 0x7732 "眲" */
+0x00,0x03,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x47,0x7c,0x44,0x00,0x00,
+0x00,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x8e,0xf8,0x08,0x08,0x08,0x08,
+/* 30515 0x7733 "眳" */
+0x00,0x00,0x7c,0x45,0x46,0x7c,0x44,0x44,0x7c,0x45,0x46,0x44,0x7c,0x44,0x00,0x00,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 30516 0x7734 "眴" */
+0x00,0x00,0x79,0x49,0x4a,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x48,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 30517 0x7735 "眵" */
+0x00,0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7d,0x44,0x44,0x45,0x7c,0x44,0x00,0x01,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 30518 0x7736 "眶" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x00,
+0x00,0xfe,0x00,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 30519 0x7737 "眷" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x2f,0xc8,0x0f,0x08,0x0f,0x08,0x0f,0x08,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0xe8,0x26,0xe0,0x20,0xe0,0x20,0xe0,0x20,
+/* 30520 0x7738 "眸" */
+0x00,0x00,0x78,0x49,0x4b,0x78,0x49,0x49,0x79,0x4a,0x48,0x4f,0x78,0x48,0x00,0x00,
+0x40,0x40,0x90,0x08,0xfc,0x24,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 30521 0x7739 "眹" */
+0x00,0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7f,0x44,0x44,0x44,0x7c,0x44,0x01,0x02,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30522 0x773a "眺" */
+0x00,0x00,0x78,0x4a,0x49,0x78,0x48,0x49,0x7a,0x4c,0x48,0x48,0x79,0x49,0x02,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 30523 0x773b "眻" */
+0x01,0x00,0x7c,0x44,0x47,0x7c,0x44,0x45,0x7c,0x44,0x47,0x44,0x7c,0x44,0x00,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30524 0x773c "眼" */
+0x00,0x03,0x7a,0x4a,0x4b,0x7a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 30525 0x773d "眽" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x46,0x02,0x04,
+0x04,0x1e,0xe0,0x00,0x06,0x78,0x50,0x50,0x52,0x54,0x48,0x48,0x44,0x54,0x62,0x40,
+/* 30526 0x773e "眾" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x00,0x7f,0x11,0x11,0x11,0x29,0x25,0x45,0x81,0x01,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xfc,0x00,0x10,0x10,0x10,0x28,0x28,0x44,0x82,0x00,
+/* 30527 0x773f "眿" */
+0x00,0x00,0x78,0x49,0x48,0x78,0x4b,0x48,0x78,0x48,0x49,0x49,0x7a,0x4c,0x00,0x00,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 30528 0x7740 "着" */
+0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x04,0x0f,0x18,0x2f,0xc8,0x0f,0x08,0x0f,0x08,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30529 0x7741 "睁" */
+0x01,0x01,0x79,0x4a,0x4c,0x7b,0x48,0x48,0x7b,0x48,0x48,0x4b,0x78,0x48,0x01,0x00,
+0x00,0x00,0xf0,0x10,0x20,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x48,0x40,0x40,0x80,
+/* 30530 0x7742 "睂" */
+0x02,0x05,0x08,0x12,0x05,0x08,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x48,0x4f,0x88,
+0x08,0x08,0x88,0x48,0x08,0x88,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30531 0x7743 "睃" */
+0x00,0x00,0x78,0x49,0x4b,0x78,0x48,0x49,0x7a,0x48,0x49,0x4a,0x78,0x48,0x01,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 30532 0x7744 "睄" */
+0x00,0x01,0x7c,0x44,0x44,0x7d,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 30533 0x7745 "睅" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x44,0x44,0x7d,0x44,0x44,0x47,0x7c,0x44,0x00,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 30534 0x7746 "睆" */
+0x00,0x00,0x7b,0x4a,0x4c,0x79,0x48,0x48,0x7b,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 30535 0x7747 "睇" */
+0x01,0x00,0x78,0x4b,0x48,0x78,0x4b,0x4a,0x7a,0x4b,0x48,0x48,0x79,0x4a,0x04,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 30536 0x7748 "睈" */
+0x00,0x01,0x7d,0x45,0x45,0x7d,0x44,0x44,0x7d,0x44,0x44,0x45,0x7c,0x44,0x03,0x00,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 30537 0x7749 "睉" */
+0x00,0x00,0x79,0x49,0x49,0x79,0x4a,0x4c,0x78,0x48,0x49,0x48,0x78,0x48,0x03,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xaa,0x72,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30538 0x774a "睊" */
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 30539 0x774b "睋" */
+0x00,0x00,0x7b,0x48,0x48,0x7b,0x48,0x48,0x78,0x48,0x4b,0x48,0x78,0x48,0x02,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 30540 0x774c "睌" */
+0x00,0x00,0x79,0x4a,0x4c,0x7b,0x4a,0x4a,0x7a,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x44,0x44,0x44,0xfc,0xa0,0xa0,0x22,0x22,0x1e,0x00,
+/* 30541 0x774d "睍" */
+0x00,0x03,0x7a,0x4a,0x4b,0x7a,0x4a,0x4b,0x7a,0x4a,0x4b,0x49,0x79,0x4a,0x04,0x18,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0x22,0x22,0x1e,
+/* 30542 0x774e "睎" */
+0x01,0x00,0x78,0x48,0x4b,0x78,0x4b,0x48,0x79,0x4b,0x4d,0x49,0x79,0x49,0x00,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 30543 0x774f "睏" */
+0x00,0x03,0x7a,0x4a,0x4a,0x7b,0x4a,0x4a,0x7a,0x4a,0x4b,0x4a,0x7a,0x4a,0x03,0x02,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 30544 0x7750 "睐" */
+0x00,0x00,0x78,0x4b,0x48,0x79,0x48,0x48,0x7b,0x48,0x48,0x48,0x79,0x4a,0x04,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0xa4,0xa8,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 30545 0x7751 "睑" */
+0x00,0x00,0x78,0x48,0x49,0x7a,0x4d,0x48,0x78,0x48,0x4a,0x49,0x79,0x48,0x07,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 30546 0x7752 "睒" */
+0x00,0x01,0x79,0x4a,0x48,0x78,0x4b,0x48,0x78,0x49,0x49,0x4a,0x78,0x48,0x01,0x06,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 30547 0x7753 "睓" */
+0x00,0x00,0x78,0x4b,0x4a,0x7a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4f,0x78,0x48,0x01,0x02,
+0x90,0x90,0x90,0xfc,0x94,0x94,0x94,0xfc,0x94,0x94,0x94,0xfe,0x00,0x90,0x08,0x04,
+/* 30548 0x7754 "睔" */
+0x00,0x00,0x78,0x48,0x49,0x7a,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 30549 0x7755 "睕" */
+0x00,0x00,0x7b,0x4a,0x4d,0x79,0x49,0x4a,0x7a,0x4b,0x4c,0x48,0x79,0x49,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 30550 0x7756 "睖" */
+0x00,0x00,0x79,0x48,0x48,0x7b,0x48,0x49,0x7a,0x48,0x49,0x4a,0x78,0x48,0x01,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 30551 0x7757 "睗" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x49,0x78,0x49,0x4a,0x4c,0x79,0x4a,0x00,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x54,0x94,0x24,0x44,0x94,0x08,
+/* 30552 0x7758 "睘" */
+0x00,0x3f,0x24,0x24,0x3f,0x00,0xff,0x00,0x1f,0x10,0x1f,0x03,0x0c,0x18,0xea,0x0c,
+0x00,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x04,0x88,0x70,0x18,0x06,
+/* 30553 0x7759 "睙" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x7a,0x4c,0x05,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 30554 0x775a "睚" */
+0x00,0x03,0x7a,0x4a,0x4a,0x7a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x7a,0x4c,0x05,0x08,
+0x00,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 30555 0x775b "睛" */
+0x00,0x00,0x7b,0x48,0x49,0x78,0x4b,0x48,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 30556 0x775c "睜" */
+0x00,0x07,0x7a,0x49,0x48,0x7b,0x48,0x48,0x7f,0x48,0x48,0x4b,0x78,0x48,0x01,0x00,
+0x3c,0xc0,0x44,0x28,0x00,0xf8,0x48,0x48,0xfe,0x48,0x48,0xf8,0x48,0x40,0x40,0x80,
+/* 30557 0x775d "睝" */
+0x0c,0x70,0x11,0xfe,0x38,0x54,0x91,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x80,0xfc,0x24,0x24,0x44,0xa8,0x10,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30558 0x775e "睞" */
+0x00,0x00,0x78,0x4b,0x48,0x79,0x49,0x49,0x7a,0x48,0x48,0x48,0x79,0x4a,0x04,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 30559 0x775f "睟" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x49,0x4a,0x78,0x48,0x4b,0x48,0x78,0x48,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30560 0x7760 "睠" */
+0x00,0x01,0x78,0x48,0x49,0x78,0x4b,0x48,0x79,0x4a,0x4c,0x48,0x78,0x48,0x00,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 30561 0x7761 "睡" */
+0x00,0x00,0xf3,0x90,0x90,0xf7,0x92,0x92,0xf7,0x92,0x92,0x97,0xf0,0x90,0x07,0x00,
+0x10,0x78,0xc0,0x40,0x40,0xfc,0x48,0x48,0xfe,0x48,0x48,0xfc,0x40,0x40,0xfc,0x00,
+/* 30562 0x7762 "睢" */
+0x00,0x00,0x78,0x49,0x49,0x7b,0x4d,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 30563 0x7763 "督" */
+0x08,0x0e,0x08,0xff,0x08,0x2a,0x49,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0x44,0xf2,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30564 0x7764 "睤" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x49,0x78,0x48,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x00,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 30565 0x7765 "睥" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x48,0x49,0x4f,0x78,0x48,0x00,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 30566 0x7766 "睦" */
+0x00,0x00,0x79,0x48,0x48,0x7b,0x48,0x49,0x7a,0x48,0x49,0x48,0x78,0x48,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30567 0x7767 "睧" */
+0x00,0x03,0x7a,0x4b,0x4a,0x7a,0x4b,0x4a,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 30568 0x7768 "睨" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x48,0x48,0x48,0x78,0x49,0x02,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 30569 0x7769 "睩" */
+0x00,0x01,0x78,0x48,0x49,0x78,0x48,0x4b,0x78,0x4a,0x49,0x48,0x79,0x4a,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 30570 0x776a "睪" */
+0x00,0x7f,0x44,0x7f,0x01,0x3f,0x01,0xff,0x08,0x04,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x00,0xfc,0x44,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x40,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 30571 0x776b "睫" */
+0x00,0x00,0x7b,0x48,0x49,0x78,0x4b,0x48,0x79,0x48,0x49,0x49,0x79,0x4a,0x02,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 30572 0x776c "睬" */
+0x00,0x00,0x7b,0x48,0x4a,0x79,0x49,0x48,0x7b,0x48,0x48,0x48,0x79,0x4a,0x04,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 30573 0x776d "睭" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 30574 0x776e "睮" */
+0x00,0x00,0x79,0x4a,0x4d,0x78,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 30575 0x776f "睯" */
+0x00,0x7e,0x42,0x7e,0x48,0x7f,0x48,0x65,0x43,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0x20,0x7e,0xa4,0x24,0x28,0x10,0x28,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30576 0x7770 "睰" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x4b,0x48,0x78,0x48,0x49,0x4a,0x78,0x48,0x00,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 30577 0x7771 "睱" */
+0x00,0x03,0x7a,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 30578 0x7772 "睲" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x48,0x49,0x79,0x4a,0x48,0x49,0x78,0x48,0x03,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 30579 0x7773 "睳" */
+0x00,0x00,0x7b,0x48,0x48,0x7b,0x49,0x48,0x78,0x4b,0x48,0x48,0x79,0x48,0x00,0x03,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 30580 0x7774 "睴" */
+0x00,0x03,0x7a,0x48,0x4b,0x78,0x49,0x49,0x79,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30581 0x7775 "睵" */
+0x01,0x01,0x7b,0x49,0x49,0x7f,0x48,0x48,0x7b,0x4a,0x4a,0x4a,0x7b,0x48,0x00,0x00,
+0x28,0x24,0xa4,0x20,0x20,0xfe,0x20,0x24,0xa4,0xa8,0xa8,0x90,0x92,0x2a,0x46,0x82,
+/* 30582 0x7776 "睶" */
+0x00,0x00,0x7b,0x48,0x49,0x78,0x4b,0x49,0x7a,0x4d,0x49,0x49,0x79,0x49,0x01,0x01,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,
+/* 30583 0x7777 "睷" */
+0x00,0x00,0xf0,0x9e,0x93,0xf2,0x94,0x94,0xfe,0x92,0x92,0x9b,0xf4,0x96,0x09,0x10,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfe,0x00,
+/* 30584 0x7778 "睸" */
+0x00,0x03,0x7a,0x4a,0x4b,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,0x08,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 30585 0x7779 "睹" */
+0x00,0x00,0x7b,0x48,0x48,0x7f,0x48,0x48,0x79,0x4b,0x4d,0x49,0x79,0x49,0x01,0x01,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 30586 0x777a "睺" */
+0x00,0x00,0x78,0x49,0x49,0x7b,0x4d,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 30587 0x777b "睻" */
+0x00,0x00,0x7b,0x4a,0x4c,0x79,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x48,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 30588 0x777c "睼" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x49,0x78,0x4b,0x48,0x49,0x79,0x49,0x02,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 30589 0x777d "睽" */
+0x00,0x03,0x78,0x4a,0x49,0x78,0x49,0x4a,0x78,0x48,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 30590 0x777e "睾" */
+0x04,0x08,0x7f,0x44,0x7f,0x01,0x3f,0x01,0xff,0x08,0x04,0x3f,0x01,0xff,0x01,0x01,
+0x00,0x00,0xfc,0x44,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x40,0xf8,0x00,0xfe,0x00,0x00,
+/* 30591 0x777f "睿" */
+0x01,0x01,0x01,0x7f,0x40,0x9f,0x09,0x32,0x0c,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0xf8,0x00,0xfe,0x02,0xf4,0x20,0x90,0x60,0xf8,0x16,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30592 0x7780 "瞀" */
+0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 30593 0x7781 "瞁" */
+0x00,0x03,0x7a,0x4b,0x4a,0x7b,0x4a,0x4b,0x78,0x48,0x4f,0x48,0x78,0x49,0x02,0x0c,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x50,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 30594 0x7782 "瞂" */
+0x02,0x07,0x3c,0x24,0x24,0x3f,0x24,0x2f,0x29,0x2f,0x29,0x2f,0x29,0x49,0x4f,0x89,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x3c,0x34,0x54,0x54,0x54,0x88,0x88,0x14,0x22,
+/* 30595 0x7783 "瞃" */
+0x00,0x00,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 30596 0x7784 "瞄" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 30597 0x7785 "瞅" */
+0x00,0x01,0xf7,0x91,0x91,0xf1,0x97,0x91,0xf3,0x93,0x95,0x95,0xf9,0x91,0x01,0x01,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 30598 0x7786 "瞆" */
+0x00,0x00,0x79,0x49,0x49,0x78,0x4f,0x48,0x79,0x49,0x49,0x49,0x79,0x48,0x00,0x03,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 30599 0x7787 "瞇" */
+0x00,0x00,0x7a,0x49,0x49,0x78,0x48,0x4b,0x79,0x49,0x49,0x49,0x79,0x4a,0x04,0x00,
+0x10,0x92,0x52,0x54,0x10,0x7e,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x80,0x7e,0x00,
+/* 30600 0x7788 "瞈" */
+0x00,0x00,0x79,0x4a,0x4c,0x79,0x48,0x48,0x7b,0x48,0x4a,0x49,0x7a,0x48,0x01,0x00,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 30601 0x7789 "瞉" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7d,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 30602 0x778a "瞊" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7a,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4c,0x04,0x08,
+0x20,0x10,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 30603 0x778b "瞋" */
+0x00,0x00,0x7b,0x48,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x49,0x7b,0x48,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 30604 0x778c "瞌" */
+0x00,0x00,0x79,0x48,0x48,0x7b,0x48,0x49,0x7b,0x48,0x4b,0x4a,0x7a,0x4a,0x07,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 30605 0x778d "瞍" */
+0x01,0x06,0xf4,0x94,0x97,0xf4,0x94,0x97,0xf0,0x97,0x92,0x91,0xf0,0x90,0x01,0x0e,
+0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x40,0xfc,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 30606 0x778e "瞎" */
+0x00,0x00,0x7b,0x4a,0x4c,0x79,0x48,0x49,0x78,0x4b,0x48,0x49,0x79,0x49,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 30607 0x778f "瞏" */
+0x7f,0x44,0x7f,0x01,0x1f,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x04,0x08,0x38,0xcb,0x0c,
+0xfc,0x44,0xfc,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x88,0x50,0x20,0x18,0x06,
+/* 30608 0x7790 "瞐" */
+0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+/* 30609 0x7791 "瞑" */
+0x00,0x03,0x7a,0x48,0x49,0x79,0x49,0x49,0x79,0x48,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 30610 0x7792 "瞒" */
+0x01,0x01,0xf7,0x91,0x90,0xf7,0x90,0x90,0xf7,0x94,0x94,0x95,0xf6,0x94,0x04,0x04,
+0x08,0x08,0xfe,0x08,0x00,0xfe,0x90,0x90,0xfe,0x92,0x92,0x6a,0x46,0x02,0x0a,0x04,
+/* 30611 0x7793 "瞓" */
+0x02,0x01,0x78,0x4f,0x48,0x7b,0x48,0x4b,0x78,0x4b,0x4a,0x4a,0x7b,0x4a,0x00,0x00,
+0x02,0x22,0x2a,0xea,0x2a,0xaa,0x2a,0xaa,0x2a,0xaa,0xaa,0xaa,0xaa,0xaa,0x42,0x82,
+/* 30612 0x7794 "瞔" */
+0x00,0x03,0x78,0x49,0x48,0x7b,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x00,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 30613 0x7795 "瞕" */
+0x00,0x01,0x78,0x48,0x4b,0x78,0x49,0x49,0x79,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30614 0x7796 "瞖" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30615 0x7797 "瞗" */
+0x00,0x00,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x48,0x7a,0x4a,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 30616 0x7798 "瞘" */
+0x00,0x03,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 30617 0x7799 "瞙" */
+0x00,0x00,0x7b,0x48,0x48,0x79,0x49,0x49,0x79,0x49,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 30618 0x779a "瞚" */
+0x00,0x00,0x7b,0x4a,0x48,0x79,0x48,0x49,0x79,0x49,0x49,0x49,0x78,0x48,0x01,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 30619 0x779b "瞛" */
+0x01,0x01,0xf2,0x94,0x99,0xf1,0x92,0x96,0xfa,0x92,0x92,0x92,0xf2,0x92,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 30620 0x779c "瞜" */
+0x00,0x01,0x79,0x4b,0x49,0x79,0x48,0x49,0x79,0x49,0x48,0x4b,0x78,0x49,0x00,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 30621 0x779d "瞝" */
+0x00,0x00,0x7b,0x48,0x49,0x79,0x49,0x49,0x78,0x4b,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 30622 0x779e "瞞" */
+0x00,0x00,0x7b,0x48,0x48,0x78,0x48,0x4b,0x7a,0x4b,0x4a,0x4b,0x7a,0x4a,0x02,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 30623 0x779f "瞟" */
+0x00,0x03,0x78,0x49,0x49,0x79,0x49,0x48,0x79,0x48,0x4b,0x48,0x78,0x49,0x02,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 30624 0x77a0 "瞠" */
+0x00,0x01,0x78,0x4b,0x4a,0x78,0x48,0x48,0x78,0x48,0x48,0x49,0x78,0x48,0x03,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 30625 0x77a1 "瞡" */
+0x02,0x02,0xf2,0x97,0x92,0xf2,0x92,0x97,0xf2,0x92,0x92,0x92,0xf5,0x95,0x08,0x10,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 30626 0x77a2 "瞢" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x00,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30627 0x77a3 "瞣" */
+0x00,0x00,0x79,0x49,0x49,0x78,0x4b,0x4a,0x7b,0x48,0x48,0x48,0x7a,0x4a,0x04,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x20,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 30628 0x77a4 "瞤" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x22,0x72,0x22,0x22,0xfa,0x02,0x0a,0x04,
+/* 30629 0x77a5 "瞥" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x43,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30630 0x77a6 "瞦" */
+0x00,0x03,0x78,0x49,0x48,0x79,0x49,0x49,0x78,0x4b,0x48,0x49,0x79,0x49,0x01,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 30631 0x77a7 "瞧" */
+0x00,0x00,0x79,0x49,0x4b,0x7d,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0xa0,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 30632 0x77a8 "瞨" */
+0x00,0x04,0xf2,0x90,0x97,0xf1,0x90,0x97,0xf0,0x93,0x90,0x97,0xf0,0x91,0x02,0x0c,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 30633 0x77a9 "瞩" */
+0x00,0x07,0xf4,0x97,0x94,0xf5,0x94,0x95,0xf5,0x95,0x94,0x97,0xf6,0x96,0x0a,0x12,
+0x00,0xfc,0x04,0xfc,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x2a,0xfa,0x0a,0x06,
+/* 30634 0x77aa "瞪" */
+0x00,0x07,0xf0,0x92,0x91,0xf2,0x95,0x98,0xf3,0x92,0x92,0x93,0xf2,0x91,0x0f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 30635 0x77ab "瞫" */
+0x00,0x03,0x78,0x4b,0x4a,0x7b,0x48,0x49,0x79,0x49,0x49,0x49,0x78,0x4b,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 30636 0x77ac "瞬" */
+0x00,0x07,0xf0,0x92,0x91,0xf7,0x94,0x9a,0xf2,0x93,0x94,0x9a,0xf1,0x92,0x04,0x08,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x02,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 30637 0x77ad "瞭" */
+0x00,0x00,0xf7,0x90,0x95,0xf2,0x97,0x9a,0xf3,0x92,0x93,0x90,0xf2,0x94,0x09,0x00,
+0x40,0x40,0xfc,0xa0,0x14,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,
+/* 30638 0x77ae "瞮" */
+0x02,0x01,0xf7,0x92,0x94,0xff,0x90,0x97,0xf4,0x97,0x94,0x97,0xf4,0x94,0x04,0x05,
+0x08,0x08,0xc8,0x10,0x9e,0xd4,0x64,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0xa4,0xc2,
+/* 30639 0x77af "瞯" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x02,
+0xde,0x52,0xde,0x52,0xde,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 30640 0x77b0 "瞰" */
+0x00,0x07,0xf0,0x91,0x9f,0xf4,0x94,0x97,0xf4,0x97,0x94,0x94,0xf7,0x9c,0x00,0x00,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 30641 0x77b1 "瞱" */
+0x00,0x03,0x78,0x48,0x49,0x78,0x48,0x4b,0x78,0x48,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30642 0x77b2 "瞲" */
+0x00,0x03,0x78,0x48,0x4b,0x78,0x48,0x4b,0x78,0x4b,0x4a,0x4a,0x7b,0x4a,0x02,0x02,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 30643 0x77b3 "瞳" */
+0x00,0x01,0x78,0x48,0x4b,0x78,0x49,0x49,0x79,0x49,0x49,0x48,0x79,0x48,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 30644 0x77b4 "瞴" */
+0x00,0x00,0x79,0x4b,0x4d,0x79,0x4b,0x49,0x79,0x49,0x4f,0x48,0x79,0x49,0x02,0x00,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 30645 0x77b5 "瞵" */
+0x00,0x02,0xf1,0x97,0x91,0xf2,0x94,0x92,0xf2,0x93,0x94,0x9a,0xf1,0x92,0x04,0x08,
+0x40,0x48,0x50,0xfc,0x50,0x48,0x44,0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,
+/* 30646 0x77b6 "瞶" */
+0x00,0x01,0x79,0x49,0x48,0x7b,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x00,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 30647 0x77b7 "瞷" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 30648 0x77b8 "瞸" */
+0x00,0x03,0x78,0x48,0x49,0x7b,0x49,0x49,0x79,0x49,0x48,0x4b,0x78,0x48,0x03,0x00,
+0x88,0xfe,0x88,0x00,0x48,0xfe,0x48,0x78,0x00,0xfc,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 30649 0x77b9 "瞹" */
+0x00,0x03,0xf0,0x92,0x91,0xf7,0x94,0x92,0xf2,0x94,0x90,0x90,0xf1,0x92,0x00,0x07,
+0x3c,0xc0,0x44,0x24,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x08,0x90,0x60,0x9e,
+/* 30650 0x77ba "瞺" */
+0x00,0x00,0xf3,0x9d,0x90,0xf7,0x95,0x94,0xf7,0x90,0x93,0x92,0xf3,0x92,0x03,0x02,
+0x40,0xa0,0x18,0xf6,0x00,0xfc,0x54,0xe4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 30651 0x77bb "瞻" */
+0x01,0x01,0x7a,0x4f,0x4a,0x7b,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4c,0x04,0x08,
+0x00,0xf8,0x08,0xfe,0x88,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x84,0xfc,0x84,
+/* 30652 0x77bc "瞼" */
+0x00,0x00,0x78,0x49,0x4a,0x7d,0x48,0x48,0x7b,0x4a,0x4a,0x4b,0x79,0x49,0x02,0x04,
+0x40,0x40,0xa0,0x10,0x08,0xf6,0x00,0x00,0xb8,0xa8,0xa8,0xb8,0x10,0x10,0xa8,0x44,
+/* 30653 0x77bd "瞽" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0xfe,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x10,0x7e,0x10,0x7c,0x44,0x28,0x18,0xe6,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30654 0x77be "瞾" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x01,0x7f,0x48,0x10,0x2f,0x01,0x01,0x7f,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xfc,0x24,0x10,0xe8,0x00,0x00,0xfc,
+/* 30655 0x77bf "瞿" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 30656 0x77c0 "矀" */
+0x02,0x02,0xf6,0x9b,0x90,0xf2,0x95,0x9c,0xf4,0x95,0x95,0x95,0xf5,0x95,0x06,0x04,
+0x88,0xa8,0xa8,0xf0,0x1e,0x24,0xd4,0x14,0x14,0xd4,0x54,0x48,0x68,0x54,0x14,0x22,
+/* 30657 0x77c1 "矁" */
+0x00,0x07,0xf1,0x91,0x9f,0xf1,0x93,0x95,0xf9,0x91,0x90,0x90,0xf5,0x95,0x09,0x00,
+0xc8,0x08,0x2a,0x2c,0xc8,0x08,0x88,0x54,0x14,0x22,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 30658 0x77c2 "矂" */
+0x01,0x01,0x79,0x49,0x48,0x7b,0x4a,0x4a,0x7b,0x48,0x4b,0x48,0x78,0x49,0x06,0x00,
+0xfc,0x04,0x04,0xfc,0x00,0xde,0x52,0x52,0xde,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 30659 0x77c3 "矃" */
+0x00,0x00,0x7b,0x4a,0x49,0x79,0x4a,0x48,0x79,0x49,0x4b,0x48,0x79,0x48,0x00,0x00,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 30660 0x77c4 "矄" */
+0x00,0x01,0x78,0x4b,0x48,0x79,0x49,0x49,0x79,0x48,0x49,0x48,0x7b,0x48,0x01,0x02,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 30661 0x77c5 "矅" */
+0x00,0x03,0x78,0x4a,0x49,0x7a,0x48,0x49,0x7b,0x4d,0x49,0x49,0x79,0x49,0x01,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 30662 0x77c6 "矆" */
+0x00,0x03,0x78,0x48,0x49,0x7b,0x49,0x49,0x79,0x49,0x49,0x49,0x7b,0x48,0x00,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 30663 0x77c7 "矇" */
+0x00,0x03,0x78,0x4b,0x4a,0x79,0x48,0x4b,0x78,0x48,0x4b,0x48,0x7b,0x48,0x03,0x00,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 30664 0x77c8 "矈" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x48,0x4b,0x7a,0x49,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x8a,0x24,0xfe,0x80,0xfc,0x84,0x14,0x08,
+/* 30665 0x77c9 "矉" */
+0x00,0x00,0x7b,0x4a,0x49,0x79,0x4a,0x49,0x7b,0x49,0x49,0x49,0x79,0x49,0x00,0x01,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 30666 0x77ca "矊" */
+0x01,0x01,0xf2,0x92,0x94,0xf7,0x91,0x92,0xf4,0x97,0x90,0x90,0xf5,0x95,0x04,0x00,
+0x08,0x10,0x3e,0x22,0xbe,0x22,0x3e,0x08,0xbe,0xaa,0x2a,0xaa,0x6a,0x2e,0x08,0x08,
+/* 30667 0x77cb "矋" */
+0x00,0x03,0x7a,0x4b,0x4a,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4b,0x7b,0x4d,0x05,0x09,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 30668 0x77cc "矌" */
+0x00,0x00,0x7b,0x4a,0x4a,0x7a,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,
+0x20,0x10,0xfe,0x44,0xfe,0x44,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x00,0x44,0x82,
+/* 30669 0x77cd "矍" */
+0x7c,0x44,0x7c,0x44,0x7c,0x09,0x1f,0x31,0x5f,0x91,0x1f,0x10,0x3f,0x08,0x07,0xf8,
+0xf8,0x88,0xf8,0x88,0xf8,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x20,0xc0,0x3e,
+/* 30670 0x77ce "矎" */
+0x01,0x01,0x7a,0x4f,0x4a,0x7a,0x49,0x49,0x79,0x49,0x49,0x48,0x79,0x4a,0x00,0x03,
+0x00,0xf8,0x08,0xfe,0x62,0x92,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xf8,0x88,0x70,0x8e,
+/* 30671 0x77cf "矏" */
+0x00,0x01,0x79,0x49,0x49,0x79,0x49,0x48,0x7b,0x4a,0x49,0x4b,0x78,0x48,0x01,0x02,
+0x40,0xfc,0x24,0x94,0x4c,0x24,0xfc,0x20,0xfe,0x8a,0x24,0xfe,0x80,0xfc,0x04,0x0c,
+/* 30672 0x77d0 "矐" */
+0x01,0x78,0x4b,0x4a,0x4d,0x78,0x49,0x48,0x79,0x4b,0x4d,0x49,0x79,0x49,0x01,0x01,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 30673 0x77d1 "矑" */
+0x00,0x00,0x78,0x4b,0x4a,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4d,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 30674 0x77d2 "矒" */
+0x01,0x07,0x79,0x4b,0x4a,0x7b,0x48,0x4f,0x7c,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x08,0xfe,0x08,0xfc,0x94,0xfc,0x00,0xfe,0x02,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,
+/* 30675 0x77d3 "矓" */
+0x01,0x78,0x4b,0x48,0x4a,0x79,0x4b,0x48,0x7b,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 30676 0x77d4 "矔" */
+0x00,0x7b,0x48,0x4b,0x4a,0x7b,0x48,0x48,0x79,0x49,0x4b,0x4d,0x79,0x49,0x01,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 30677 0x77d5 "矕" */
+0x21,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x08,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 30678 0x77d6 "矖" */
+0x03,0x78,0x4b,0x4a,0x4b,0x7a,0x48,0x4b,0x7a,0x4b,0x4a,0x4b,0x7a,0x4a,0x02,0x04,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 30679 0x77d7 "矗" */
+0x01,0x3f,0x01,0x0f,0x08,0x09,0x09,0x7f,0x08,0x7e,0x08,0x3e,0x22,0x2a,0x2a,0xff,
+0x00,0xf8,0x00,0xe0,0x20,0x20,0x20,0xfc,0x20,0xfc,0x20,0xf8,0x88,0xa8,0xa8,0xfe,
+/* 30680 0x77d8 "矘" */
+0x02,0x01,0xf7,0x94,0x91,0xf1,0x97,0x95,0xf4,0x97,0x90,0x97,0xf0,0x9f,0x02,0x04,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 30681 0x77d9 "矙" */
+0x0f,0x08,0xef,0xa8,0xaf,0xe8,0xab,0xa8,0xef,0xaa,0xab,0xaa,0xeb,0xaa,0x0f,0x08,
+0xbe,0xa2,0xbe,0xa2,0xbe,0x02,0x92,0x92,0xde,0xaa,0xca,0xaa,0x92,0xd2,0xaa,0xc4,
+/* 30682 0x77da "矚" */
+0x03,0x02,0x7b,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x4b,0x4a,0x4a,0x7a,0x4a,0x05,0x00,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 30683 0x77db "矛" */
+0x00,0x1f,0x00,0x02,0x01,0x00,0x7f,0x01,0x02,0x04,0x08,0x10,0x20,0xc0,0x02,0x01,
+0x00,0xf0,0x10,0x20,0x40,0x80,0xfe,0x82,0x84,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
+/* 30684 0x77dc "矜" */
+0x00,0x7e,0x02,0x24,0x18,0x09,0xfe,0x0a,0x18,0x19,0x28,0x48,0x88,0x08,0x28,0x10,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 30685 0x77dd "矝" */
+0x00,0x7c,0x04,0x28,0x10,0x09,0xfe,0x1a,0x29,0x28,0x48,0x48,0x88,0x08,0x28,0x10,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 30686 0x77de "矞" */
+0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x01,0x3f,0x24,0x28,0x37,0x24,0x24,0x27,0x20,
+0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,0xf8,0x48,0x28,0xd8,0x48,0x48,0xc8,0x18,
+/* 30687 0x77df "矟" */
+0x00,0x7c,0x04,0x28,0x10,0x08,0xfe,0x1a,0x28,0x28,0x48,0x48,0x88,0x08,0x28,0x10,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 30688 0x77e0 "矠" */
+0x00,0x7c,0x04,0x29,0x10,0x08,0xff,0x1a,0x28,0x28,0x48,0x48,0x88,0x08,0x28,0x10,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 30689 0x77e1 "矡" */
+0x03,0xfa,0x0b,0x52,0x23,0x10,0xfd,0x37,0x35,0x51,0x51,0x50,0x91,0x10,0x50,0x27,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 30690 0x77e2 "矢" */
+0x08,0x08,0x08,0x1f,0x11,0x21,0x41,0x01,0xff,0x01,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 30691 0x77e3 "矣" */
+0x02,0x04,0x08,0x10,0x3f,0x08,0x08,0x1f,0x21,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x20,0x10,0xf8,0x08,0x00,0xf0,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,
+/* 30692 0x77e4 "矤" */
+0x00,0x7c,0x04,0x04,0x05,0x7e,0x40,0x40,0x43,0x7c,0x04,0x04,0x04,0x04,0x29,0x12,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30693 0x77e5 "知" */
+0x20,0x20,0x20,0x7e,0x48,0x88,0x08,0x08,0xff,0x08,0x14,0x14,0x22,0x22,0x42,0x80,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,
+/* 30694 0x77e6 "矦" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x24,0x24,0x2f,0x30,0x20,0x3f,0x41,0x42,0x84,0x18,
+0x00,0x00,0xe0,0x20,0x40,0xfc,0x00,0x00,0xf8,0x80,0x80,0xfc,0x40,0x20,0x10,0x0c,
+/* 30695 0x77e7 "矧" */
+0x20,0x21,0x3c,0x50,0x90,0x11,0x11,0xff,0x11,0x11,0x10,0x28,0x24,0x44,0x41,0x80,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 30696 0x77e8 "矨" */
+0x20,0x20,0x21,0x7c,0x50,0x90,0x13,0xfc,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x82,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30697 0x77e9 "矩" */
+0x20,0x21,0x3d,0x51,0x91,0x11,0x11,0xff,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x80,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 30698 0x77ea "矪" */
+0x20,0x20,0x20,0x7c,0x50,0x90,0x10,0xfd,0x10,0x10,0x10,0x28,0x24,0x45,0x41,0x82,
+0x10,0x20,0xfc,0x84,0xa4,0x94,0x94,0xfe,0x84,0xa4,0x94,0x94,0x84,0x04,0x14,0x08,
+/* 30699 0x77eb "矫" */
+0x20,0x20,0x21,0x7c,0x50,0x93,0x10,0xfc,0x11,0x12,0x10,0x28,0x24,0x45,0x41,0x82,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30700 0x77ec "矬" */
+0x20,0x20,0x21,0x7d,0x51,0x91,0x12,0xfc,0x10,0x10,0x11,0x28,0x24,0x44,0x43,0x80,
+0x20,0x20,0x24,0x24,0x24,0x24,0xaa,0x72,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30701 0x77ed "短" */
+0x20,0x21,0x3c,0x50,0x90,0x10,0x10,0xfe,0x10,0x10,0x10,0x28,0x24,0x44,0x41,0x80,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 30702 0x77ee "矮" */
+0x20,0x21,0x3c,0x50,0x93,0x10,0x11,0xfe,0x10,0x13,0x10,0x29,0x24,0x44,0x40,0x81,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 30703 0x77ef "矯" */
+0x20,0x21,0x3c,0x53,0x90,0x11,0x12,0xfe,0x10,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 30704 0x77f0 "矰" */
+0x21,0x20,0x3c,0x53,0x92,0x12,0x12,0xfe,0x13,0x10,0x11,0x29,0x25,0x45,0x41,0x81,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 30705 0x77f1 "矱" */
+0x20,0x23,0x20,0x7c,0x51,0x93,0x11,0xfd,0x11,0x11,0x11,0x29,0x27,0x44,0x40,0x83,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 30706 0x77f2 "矲" */
+0x20,0x23,0x42,0x7a,0xa3,0x21,0x22,0x23,0xf8,0x23,0x22,0x23,0x52,0x4b,0x4a,0x82,
+0x00,0xfe,0x52,0x52,0xfe,0x10,0x52,0xdc,0x12,0xce,0x40,0xd2,0x5c,0xd0,0x52,0xce,
+/* 30707 0x77f3 "石" */
+0x00,0xff,0x02,0x02,0x04,0x04,0x08,0x0f,0x18,0x28,0x48,0x88,0x08,0x08,0x0f,0x08,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 30708 0x77f4 "矴" */
+0x00,0x00,0xfe,0x10,0x10,0x20,0x3e,0x62,0x62,0xa2,0x22,0x22,0x3e,0x22,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 30709 0x77f5 "矵" */
+0x00,0x00,0xfe,0x10,0x10,0x20,0x3e,0x62,0x62,0xa2,0x22,0x22,0x3e,0x22,0x00,0x00,
+0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x04,0x14,0x08,
+/* 30710 0x77f6 "矶" */
+0x00,0x01,0xf9,0x21,0x21,0x41,0x79,0xc9,0x49,0x49,0x49,0x49,0x7a,0x42,0x04,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 30711 0x77f7 "矷" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3c,0x67,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 30712 0x77f8 "矸" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3c,0x67,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 30713 0x77f9 "矹" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x92,0x0e,0x00,
+/* 30714 0x77fa "矺" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 30715 0x77fb "矻" */
+0x00,0x00,0xfe,0x10,0x11,0x22,0x3c,0x64,0xa4,0x24,0x24,0x24,0x3d,0x25,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xf8,0x10,0x20,0x40,0x40,0x82,0x02,0x02,0xfe,0x00,
+/* 30716 0x77fc "矼" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30717 0x77fd "矽" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3d,0x66,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x03,
+0x40,0x40,0x40,0x7e,0x82,0x82,0x42,0x24,0x14,0x08,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 30718 0x77fe "矾" */
+0x00,0x01,0xf9,0x21,0x21,0x41,0x79,0xc9,0x49,0x49,0x49,0x49,0x7a,0x42,0x04,0x08,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 30719 0x77ff "矿" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x20,0x10,0x10,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 30720 0x7800 "砀" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3d,0x64,0x64,0xa4,0x25,0x25,0x3e,0x24,0x20,0x01,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 30721 0x7801 "码" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x25,0x3c,0x24,0x20,0x00,
+0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0xfe,0x02,0x02,0x02,0xfa,0x02,0x02,0x14,0x08,
+/* 30722 0x7802 "砂" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3d,0x65,0x66,0xa4,0x24,0x24,0x3c,0x24,0x20,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 30723 0x7803 "砃" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x00,0xfc,0x84,0x84,0xa4,0x94,0x94,0x84,0xfe,0x84,0x84,0x84,0x84,0x04,0x14,0x08,
+/* 30724 0x7804 "砄" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30725 0x7805 "砅" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3c,0x64,0x64,0xa4,0x25,0x25,0x3e,0x24,0x20,0x00,
+0x20,0x20,0x20,0x20,0x32,0xb2,0xb4,0xa8,0xa8,0xa8,0x24,0x24,0x22,0x20,0xa0,0x40,
+/* 30726 0x7806 "砆" */
+0x00,0x00,0xfc,0x10,0x11,0x20,0x3c,0x64,0x67,0xa4,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30727 0x7807 "砇" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x21,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 30728 0x7808 "砈" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x22,0x04,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 30729 0x7809 "砉" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0x7f,0x01,0x7f,0x04,0x08,0x3f,0xc8,0x08,0x0f,0x08,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 30730 0x780a "砊" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 30731 0x780b "砋" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x10,0x10,0x10,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 30732 0x780c "砌" */
+0x00,0x01,0xf9,0x21,0x21,0x41,0x79,0x4f,0xc9,0x49,0x49,0x49,0x79,0x48,0x00,0x00,
+0x00,0x00,0x7e,0x12,0x12,0x12,0xd2,0x12,0x12,0x12,0x52,0x92,0x22,0x22,0x4a,0x84,
+/* 30733 0x780d "砍" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3d,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30734 0x780e "砎" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x64,0x64,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30735 0x780f "砏" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3d,0x66,0x64,0xa4,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 30736 0x7810 "砐" */
+0x00,0x03,0xf8,0x20,0x20,0x40,0x78,0xc8,0x49,0x49,0x49,0x49,0x7a,0x42,0x04,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 30737 0x7811 "砑" */
+0x00,0x03,0xf8,0x21,0x21,0x41,0x7a,0xcb,0x48,0x48,0x48,0x49,0x7a,0x44,0x00,0x00,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 30738 0x7812 "砒" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 30739 0x7813 "砓" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x65,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x03,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 30740 0x7814 "研" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3c,0x67,0x64,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x00,0xfc,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30741 0x7815 "砕" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3d,0x66,0x64,0xa4,0x27,0x24,0x3c,0x24,0x20,0x00,
+0x40,0x40,0xf8,0x48,0x88,0x8a,0x0a,0x26,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30742 0x7816 "砖" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3d,0x64,0x64,0xa5,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x40,0xfe,0x40,0x80,0xfc,0x04,0x88,0x50,0x20,0x10,0x10,
+/* 30743 0x7817 "砗" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3d,0x65,0x64,0xa4,0x24,0x27,0x3c,0x24,0x20,0x00,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 30744 0x7818 "砘" */
+0x00,0x00,0xfc,0x13,0x10,0x21,0x3d,0x65,0x65,0xa5,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 30745 0x7819 "砙" */
+0x00,0x00,0xfb,0x21,0x21,0x41,0x79,0x49,0xc9,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x90,0x50,0x50,0x10,0x12,0x92,0x12,0x0e,
+/* 30746 0x781a "砚" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x24,0x24,0x3c,0x25,0x22,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 30747 0x781b "砛" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x64,0x64,0xa5,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 30748 0x781c "砜" */
+0x00,0x03,0xfa,0x22,0x23,0x42,0x7a,0xca,0x4a,0x4a,0x4a,0x4b,0x7c,0x44,0x08,0x10,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 30749 0x781d "砝" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3c,0x65,0x64,0xa4,0x24,0x24,0x3c,0x25,0x20,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 30750 0x781e "砞" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3c,0x65,0x64,0xa4,0x24,0x25,0x3d,0x26,0x20,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 30751 0x781f "砟" */
+0x00,0x00,0xfc,0x10,0x11,0x21,0x3e,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 30752 0x7820 "砠" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 30753 0x7821 "砡" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x24,0x20,0xfe,0x00,
+/* 30754 0x7822 "砢" */
+0x00,0x00,0xfd,0x10,0x10,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3c,0x24,0x20,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 30755 0x7823 "砣" */
+0x00,0x00,0xfc,0x11,0x11,0x22,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 30756 0x7824 "砤" */
+0x00,0x00,0xfc,0x11,0x12,0x21,0x3d,0x65,0x67,0xa5,0x25,0x25,0x3d,0x25,0x20,0x00,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 30757 0x7825 "砥" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 30758 0x7826 "砦" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x00,0x7f,0x04,0x08,0x3f,0xc8,0x08,0x0f,0x08,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 30759 0x7827 "砧" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x64,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 30760 0x7828 "砨" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x26,0x22,0x04,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x08,0x10,0x20,0x42,0x82,0x7e,0x00,
+/* 30761 0x7829 "砩" */
+0x00,0x00,0xf8,0x23,0x20,0x40,0x7b,0x4a,0xca,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 30762 0x782a "砪" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x67,0x65,0xa5,0x25,0x25,0x3d,0x24,0x20,0x00,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 30763 0x782b "砫" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30764 0x782c "砬" */
+0x00,0x00,0xfc,0x10,0x11,0x20,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x40,0x20,0x20,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 30765 0x782d "砭" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3d,0x64,0x64,0xa4,0x24,0x24,0x3c,0x25,0x22,0x00,
+0x04,0x1e,0xe0,0x00,0x20,0x10,0xfe,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x3e,0x00,
+/* 30766 0x782e "砮" */
+0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0x00,0xfc,0x44,0x28,0x10,0x28,0xc6,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30767 0x782f "砯" */
+0x00,0x00,0xfd,0x10,0x10,0x21,0x3c,0x64,0x64,0xa4,0x25,0x25,0x3e,0x24,0x20,0x00,
+0x20,0x20,0x20,0xa0,0x32,0xb2,0xb4,0xa8,0xa8,0xa8,0x24,0x24,0x22,0x20,0xa0,0x40,
+/* 30768 0x7830 "砰" */
+0x00,0x01,0xfc,0x10,0x11,0x20,0x3c,0x64,0x67,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 30769 0x7831 "砱" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 30770 0x7832 "砲" */
+0x00,0x00,0xfd,0x11,0x12,0x25,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x20,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 30771 0x7833 "砳" */
+0x00,0x00,0xfe,0x10,0x10,0x20,0x3e,0x62,0x62,0xa3,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x7c,0xc4,0xc4,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 30772 0x7834 "破" */
+0x00,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x26,0x22,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 30773 0x7835 "砵" */
+0x00,0x00,0xfc,0x10,0x11,0x20,0x3c,0x64,0x64,0xa4,0x25,0x26,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0xfa,0x20,0x20,0x20,0x20,
+/* 30774 0x7836 "砶" */
+0x00,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 30775 0x7837 "砷" */
+0x00,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x24,0x20,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 30776 0x7838 "砸" */
+0x00,0x03,0xfa,0x22,0x22,0x42,0x7a,0x4a,0xca,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x00,
+0x00,0xfe,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,0xfe,0x00,
+/* 30777 0x7839 "砹" */
+0x01,0x01,0xfb,0x21,0x21,0x40,0x7a,0xca,0x49,0x49,0x48,0x48,0x78,0x41,0x02,0x0c,
+0x10,0x10,0xfc,0x10,0x10,0x00,0x08,0x08,0x10,0x10,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 30778 0x783a "砺" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x00,0xfe,0x00,0x00,0x00,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+/* 30779 0x783b "砻" */
+0x04,0x04,0xff,0x09,0x11,0x21,0x4f,0x80,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x40,0x20,0xfc,0x10,0x60,0x84,0x04,0xfc,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30780 0x783c "砼" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30781 0x783d "砽" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x02,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x04,0x0c,
+/* 30782 0x783e "砾" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x64,0xa4,0x24,0x24,0x3d,0x26,0x20,0x00,
+0x08,0x1c,0xe0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 30783 0x783f "砿" */
+0x00,0x00,0xf8,0x21,0x21,0x41,0x79,0x49,0xc9,0x49,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 30784 0x7840 "础" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x64,0x64,0xa5,0x25,0x25,0x3d,0x25,0x21,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 30785 0x7841 "硁" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3c,0x67,0x64,0xa5,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30786 0x7842 "硂" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3d,0x64,0x64,0xa4,0x25,0x24,0x3c,0x24,0x23,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30787 0x7843 "硃" */
+0x00,0x01,0xfd,0x11,0x11,0x22,0x3c,0x67,0x64,0xa4,0x24,0x25,0x3d,0x26,0x20,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 30788 0x7844 "硄" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3d,0x64,0x64,0xa4,0x24,0x24,0x3d,0x25,0x22,0x04,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 30789 0x7845 "硅" */
+0x00,0x00,0xf9,0x20,0x20,0x40,0x7b,0x48,0xc8,0x48,0x49,0x48,0x78,0x48,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 30790 0x7846 "硆" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3e,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 30791 0x7847 "硇" */
+0x00,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x94,0x54,0x24,0x24,0x54,0x94,0x04,0x04,0xfc,0x04,
+/* 30792 0x7848 "硈" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3d,0x64,0x64,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 30793 0x7849 "硉" */
+0x00,0x00,0xfd,0x10,0x13,0x20,0x21,0x7c,0x64,0xa5,0x24,0x24,0x27,0x3c,0x24,0x00,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 30794 0x784a "硊" */
+0x00,0x00,0xfc,0x11,0x12,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x02,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 30795 0x784b "硋" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3c,0x65,0x64,0xa4,0x24,0x27,0x3c,0x24,0x20,0x03,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 30796 0x784c "硌" */
+0x00,0x00,0xfc,0x10,0x11,0x20,0x3c,0x64,0x65,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 30797 0x784d "硍" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 30798 0x784e "硎" */
+0x00,0x07,0xfa,0x22,0x22,0x42,0x7a,0x4f,0xca,0x4a,0x4a,0x4a,0x7a,0x4c,0x04,0x08,
+0x02,0xe2,0x42,0x4a,0x4a,0x4a,0x4a,0xea,0x4a,0x4a,0x4a,0x4a,0x42,0x42,0x4a,0x44,
+/* 30799 0x784f "硏" */
+0x00,0x01,0xfc,0x10,0x10,0x20,0x3c,0x67,0x64,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x00,0xdc,0x88,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30800 0x7850 "硐" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 30801 0x7851 "硑" */
+0x01,0x00,0xfc,0x10,0x13,0x20,0x3c,0x64,0x64,0xa7,0x24,0x24,0x3d,0x25,0x22,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 30802 0x7852 "硒" */
+0x00,0x03,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x54,0x8c,0x04,0x04,0x04,0xfc,0x04,
+/* 30803 0x7853 "硓" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x23,0x7c,0x64,0xa5,0x26,0x24,0x24,0x3c,0x24,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 30804 0x7854 "硔" */
+0x00,0x00,0xfc,0x10,0x13,0x20,0x3c,0x64,0x64,0xa7,0x24,0x24,0x3c,0x25,0x22,0x04,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 30805 0x7855 "硕" */
+0x00,0x03,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3c,0x24,0x21,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x04,
+/* 30806 0x7856 "硖" */
+0x00,0x00,0xfc,0x11,0x10,0x21,0x3c,0x64,0x64,0xa7,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x20,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 30807 0x7857 "硗" */
+0x00,0x00,0xf8,0x23,0x20,0x40,0x78,0x4b,0xc8,0x4b,0x48,0x48,0x79,0x49,0x02,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 30808 0x7858 "硘" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,0x00,
+/* 30809 0x7859 "硙" */
+0x00,0x01,0xfd,0x11,0x11,0x20,0x3d,0x64,0x64,0xa5,0x25,0x25,0x3d,0x25,0x20,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 30810 0x785a "硚" */
+0x00,0x00,0xfd,0x10,0x10,0x23,0x3c,0x64,0x65,0xa6,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 30811 0x785b "硛" */
+0x00,0x00,0xf8,0x27,0x20,0x40,0x78,0x4a,0xca,0x4a,0x4c,0x48,0x79,0x49,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x90,0x90,0x90,0x94,0x92,0x92,0x92,0x90,0x10,0x10,0x50,0x20,
+/* 30812 0x785c "硜" */
+0x00,0x01,0xfc,0x10,0x11,0x22,0x3d,0x64,0x64,0xa5,0x24,0x24,0x3c,0x24,0x23,0x00,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30813 0x785d "硝" */
+0x00,0x01,0xfc,0x10,0x10,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 30814 0x785e "硞" */
+0x00,0x01,0xfd,0x11,0x11,0x22,0x3c,0x67,0x64,0xa4,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 30815 0x785f "硟" */
+0x00,0x00,0xfb,0x20,0x20,0x41,0x79,0x4b,0xc8,0x4a,0x4a,0x49,0x79,0x4a,0x04,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 30816 0x7860 "硠" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 30817 0x7861 "硡" */
+0x00,0x00,0xfb,0x22,0x24,0x40,0x7b,0x48,0xc8,0x48,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x90,0x90,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 30818 0x7862 "硢" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x67,0xa4,0x25,0x25,0x3e,0x24,0x20,0x00,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 30819 0x7863 "硣" */
+0x00,0x00,0xfd,0x10,0x10,0x23,0x3c,0x64,0x65,0xa4,0x25,0x26,0x3c,0x24,0x20,0x00,
+0x20,0x22,0xfa,0x24,0x24,0xfe,0x10,0x20,0xfc,0x88,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 30820 0x7864 "硤" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3d,0x65,0x65,0xa6,0x24,0x24,0x3c,0x24,0x21,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 30821 0x7865 "硥" */
+0x00,0x00,0xfc,0x13,0x10,0x20,0x3c,0x64,0x64,0xa4,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 30822 0x7866 "硦" */
+0x00,0x03,0xfc,0x10,0x11,0x20,0x3c,0x67,0x64,0xa4,0x27,0x24,0x3c,0x25,0x21,0x02,
+0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,
+/* 30823 0x7867 "硧" */
+0x00,0x01,0xfc,0x10,0x10,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 30824 0x7868 "硨" */
+0x00,0x00,0xfd,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x24,0x3d,0x24,0x20,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30825 0x7869 "硩" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30826 0x786a "硪" */
+0x00,0x00,0xfb,0x20,0x20,0x43,0x78,0x48,0xc8,0x48,0x4b,0x48,0x78,0x48,0x02,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 30827 0x786b "硫" */
+0x00,0x00,0xfb,0x20,0x20,0x41,0x7b,0x48,0xc9,0x49,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 30828 0x786c "硬" */
+0x00,0x01,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3c,0x24,0x20,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 30829 0x786d "硭" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x65,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x48,0x48,0xfe,0x48,0x48,0x20,0x10,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 30830 0x786e "确" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x25,0x21,0x02,
+0x40,0x40,0x7c,0x84,0x08,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x12,0x0a,0x04,
+/* 30831 0x786f "硯" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x24,0x3c,0x21,0x02,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 30832 0x7870 "硰" */
+0x10,0x08,0x40,0x24,0x09,0x72,0x10,0x17,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x20,0x20,0xa8,0xa4,0x2a,0x30,0xc0,0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30833 0x7871 "硱" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x64,0x74,0xac,0x24,0x24,0x24,0x04,0xfc,0x04,
+/* 30834 0x7872 "硲" */
+0x00,0x00,0xfc,0x10,0x11,0x20,0x3c,0x64,0x65,0xa6,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 30835 0x7873 "硳" */
+0x00,0x00,0xf9,0x20,0x20,0x40,0x7b,0x48,0xc8,0x49,0x49,0x4a,0x78,0x48,0x01,0x02,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x48,0x48,0x4c,0x4a,0x4a,0x88,0x88,0x28,0x10,
+/* 30836 0x7874 "硴" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x65,0xa6,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x88,0x88,0xfe,0x88,0x88,0x50,0x50,0x94,0x94,0x98,0x90,0xb2,0xd2,0x92,0x8e,0x80,
+/* 30837 0x7875 "硵" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x02,0x4a,0x2a,0x12,0x12,0x2a,0x4a,0x02,0xfe,0x02,
+/* 30838 0x7876 "硶" */
+0x00,0x01,0xfd,0x11,0x11,0x20,0x3c,0x64,0x65,0xa6,0x24,0x25,0x3c,0x24,0x20,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x10,0x10,0x20,
+/* 30839 0x7877 "硷" */
+0x00,0x00,0xf8,0x20,0x21,0x42,0x7d,0x48,0xc8,0x48,0x4a,0x49,0x79,0x48,0x07,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 30840 0x7878 "硸" */
+0x00,0x01,0xfd,0x11,0x11,0x20,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 30841 0x7879 "硹" */
+0x02,0x02,0xf2,0x22,0x2f,0x42,0x72,0xd6,0x57,0x5a,0x5a,0x52,0x72,0x52,0x02,0x02,
+0x08,0x28,0x28,0x28,0xa4,0x44,0x54,0x92,0x10,0xa0,0x20,0x28,0x44,0xfc,0x44,0x00,
+/* 30842 0x787a "硺" */
+0x00,0x01,0xfc,0x10,0x10,0x21,0x3c,0x65,0x64,0xa5,0x24,0x24,0x3c,0x25,0x20,0x00,
+0x00,0xfe,0x20,0x40,0xa2,0x12,0x34,0x58,0x98,0x54,0x34,0x52,0x90,0x10,0x50,0x20,
+/* 30843 0x787b "硻" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30844 0x787c "硼" */
+0x00,0x03,0xfa,0x22,0x22,0x43,0x7a,0x4a,0xca,0x4b,0x4a,0x4a,0x7a,0x4a,0x05,0x08,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 30845 0x787d "硽" */
+0x00,0x00,0xfb,0x21,0x22,0x44,0x7b,0x4a,0xca,0x4b,0x4a,0x4a,0x7b,0x48,0x00,0x00,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 30846 0x787e "硾" */
+0x00,0x00,0xfd,0x10,0x13,0x20,0x3c,0x64,0x67,0xa4,0x24,0x27,0x3c,0x24,0x21,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 30847 0x787f "硿" */
+0x00,0x00,0xf8,0x23,0x22,0x44,0x79,0x4a,0xc8,0x49,0x48,0x48,0x78,0x48,0x07,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 30848 0x7880 "碀" */
+0x00,0x00,0xfc,0x11,0x10,0x21,0x3c,0x64,0x67,0xa4,0x24,0x25,0x3c,0x24,0x20,0x00,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 30849 0x7881 "碁" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x10,0x3f,0xc4,0x0f,0x18,0x68,0x0f,0x08,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0xf8,0x06,0xe0,0x20,0x20,0xe0,0x20,
+/* 30850 0x7882 "碂" */
+0x00,0x00,0xfb,0x22,0x20,0x41,0x78,0x48,0xcb,0x48,0x49,0x49,0x7a,0x4c,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 30851 0x7883 "碃" */
+0x00,0x00,0xfb,0x20,0x21,0x40,0x7b,0x48,0xc9,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 30852 0x7884 "碄" */
+0x01,0x01,0xf9,0x21,0x27,0x41,0x79,0x4b,0xcb,0x4d,0x4d,0x49,0x79,0x49,0x01,0x01,
+0x10,0x10,0x10,0x10,0xbc,0x10,0x10,0x38,0xb8,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 30853 0x7885 "碅" */
+0x00,0x03,0xfa,0x22,0x22,0x42,0x7a,0x4b,0xca,0x4a,0x4a,0x4b,0x7a,0x4a,0x03,0x02,
+0x00,0xfe,0x02,0x1a,0xe2,0x22,0x22,0xfe,0x22,0x72,0xaa,0x26,0x22,0x22,0xfe,0x02,
+/* 30854 0x7886 "碆" */
+0x20,0x13,0x82,0x4b,0x12,0x24,0xe4,0x29,0x20,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x20,0xfc,0x24,0xf8,0x88,0x50,0x70,0x8c,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30855 0x7887 "碇" */
+0x00,0x00,0xfb,0x22,0x24,0x40,0x7b,0x48,0xc8,0x49,0x49,0x49,0x7a,0x4a,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 30856 0x7888 "碈" */
+0x00,0x03,0xfa,0x23,0x22,0x42,0x7b,0x4a,0xc9,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 30857 0x7889 "碉" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 30858 0x788a "碊" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3c,0x65,0x64,0xa4,0x25,0x24,0x3c,0x24,0x20,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 30859 0x788b "碋" */
+0x00,0x01,0xfd,0x11,0x11,0x20,0x3d,0x64,0x65,0xa5,0x25,0x25,0x3d,0x24,0x20,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 30860 0x788c "碌" */
+0x00,0x01,0xf8,0x20,0x21,0x40,0x78,0x4b,0xc8,0x4a,0x49,0x48,0x79,0x4a,0x00,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 30861 0x788d "碍" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3c,0x65,0x64,0xa7,0x24,0x25,0x3c,0x24,0x20,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x10,0xfe,0x10,0x10,0x90,0x10,0x50,0x20,
+/* 30862 0x788e "碎" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3d,0x66,0x64,0xa4,0x27,0x24,0x3c,0x24,0x20,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 30863 0x788f "碏" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3d,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 30864 0x7890 "碐" */
+0x00,0x00,0xf9,0x20,0x20,0x43,0x78,0x49,0xca,0x48,0x49,0x4a,0x78,0x48,0x01,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 30865 0x7891 "碑" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa4,0x25,0x27,0x3c,0x24,0x20,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 30866 0x7892 "碒" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x64,0xa5,0x24,0x25,0x3c,0x24,0x23,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 30867 0x7893 "碓" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 30868 0x7894 "碔" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3c,0x64,0x65,0xa5,0x25,0x25,0x3d,0x25,0x23,0x01,
+0x08,0x0c,0xea,0x0a,0x08,0xfe,0x48,0x48,0x48,0x68,0x48,0x48,0x4a,0x6a,0x86,0x02,
+/* 30869 0x7895 "碕" */
+0x00,0x00,0xfd,0x10,0x10,0x21,0x23,0x7c,0x65,0xa5,0x25,0x25,0x25,0x3c,0x24,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 30870 0x7896 "碖" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 30871 0x7897 "碗" */
+0x00,0x00,0xfb,0x22,0x25,0x41,0x79,0x4a,0xca,0x4b,0x4c,0x48,0x79,0x49,0x02,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 30872 0x7898 "碘" */
+0x00,0x00,0xfc,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x27,0x3c,0x24,0x21,0x02,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x88,0x04,0x02,
+/* 30873 0x7899 "碙" */
+0x00,0x03,0xfa,0x22,0x22,0x43,0x7a,0x4a,0xca,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 30874 0x789a "碚" */
+0x00,0x00,0xfd,0x10,0x11,0x20,0x3c,0x67,0x64,0xa4,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 30875 0x789b "碛" */
+0x00,0x00,0xfb,0x20,0x21,0x40,0x7b,0x48,0xc9,0x49,0x49,0x49,0x79,0x48,0x00,0x03,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 30876 0x789c "碜" */
+0x00,0x00,0xf9,0x23,0x20,0x47,0x79,0x4a,0xcc,0x4b,0x48,0x48,0x7b,0x48,0x00,0x07,
+0x80,0x90,0x08,0xfc,0x40,0xfe,0x10,0x48,0x86,0x10,0x20,0xc4,0x08,0x30,0xc0,0x00,
+/* 30877 0x789d "碝" */
+0x00,0x03,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x24,0x27,0x3c,0x24,0x21,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 30878 0x789e "碞" */
+0x00,0x1f,0x10,0x1f,0x00,0x7c,0x44,0x7c,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0xf0,0x10,0xf0,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30879 0x789f "碟" */
+0x00,0x02,0xfa,0x27,0x22,0x42,0x7a,0xca,0x4b,0x48,0x4f,0x48,0x79,0x42,0x0c,0x00,
+0x90,0x90,0x90,0xfe,0x90,0x90,0xf0,0x00,0xfc,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 30880 0x78a0 "碠" */
+0x00,0x00,0xfb,0x20,0x21,0x41,0x79,0x48,0xcb,0x4a,0x49,0x48,0x78,0x48,0x00,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 30881 0x78a1 "碡" */
+0x00,0x01,0xfc,0x10,0x10,0x21,0x3c,0x64,0x64,0xa4,0x25,0x24,0x3d,0x25,0x20,0x00,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0xa4,0x94,0xfe,0xa4,0x14,0xfe,0x04,0x18,
+/* 30882 0x78a2 "碢" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x84,0x84,0xf4,0x94,0x94,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 30883 0x78a3 "碣" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3c,0x65,0x66,0xa5,0x25,0x25,0x3d,0x24,0x20,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 30884 0x78a4 "碤" */
+0x00,0x00,0xfb,0x20,0x20,0x40,0x79,0x49,0xc9,0x49,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 30885 0x78a5 "碥" */
+0x00,0x00,0xfb,0x22,0x22,0x43,0x7a,0xca,0x4b,0x4b,0x4b,0x4d,0x7d,0x45,0x09,0x01,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x44,0x0c,
+/* 30886 0x78a6 "碦" */
+0x00,0x00,0xfb,0x22,0x20,0x40,0x79,0x4a,0xc8,0x49,0x4e,0x49,0x79,0x49,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 30887 0x78a7 "碧" */
+0x00,0xfe,0x10,0x7c,0x10,0x1e,0xf0,0x00,0x7f,0x04,0x08,0x3f,0xc8,0x08,0x0f,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 30888 0x78a8 "碨" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x64,0xa7,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 30889 0x78a9 "碩" */
+0x00,0x03,0xfc,0x10,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x24,0x20,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 30890 0x78aa "碪" */
+0x00,0x00,0xfb,0x20,0x20,0x40,0x78,0x48,0xc8,0x4b,0x49,0x49,0x79,0x49,0x01,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 30891 0x78ab "碫" */
+0x00,0x03,0xfa,0x22,0x23,0x42,0x7a,0x4a,0xcb,0x4a,0x4a,0x4b,0x7e,0x4a,0x02,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 30892 0x78ac "碬" */
+0x00,0x03,0xfa,0x22,0x22,0x43,0x7a,0x4a,0xcb,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 30893 0x78ad "碭" */
+0x00,0x01,0xf9,0x21,0x21,0x41,0x78,0x4b,0xc9,0x49,0x4a,0x4c,0x79,0x4a,0x00,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 30894 0x78ae "碮" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x64,0xa7,0x24,0x25,0x3d,0x25,0x22,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 30895 0x78af "碯" */
+0x00,0x01,0xfa,0x21,0x20,0x40,0x78,0x4b,0xca,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 30896 0x78b0 "碰" */
+0x01,0x00,0xf8,0x23,0x20,0x40,0x78,0x4c,0xca,0x4a,0x48,0x48,0x78,0x48,0x07,0x00,
+0x08,0x90,0x00,0xfc,0x90,0x90,0x92,0x92,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 30897 0x78b1 "碱" */
+0x00,0x00,0xf0,0x27,0x24,0x44,0x75,0xd4,0x54,0x55,0x55,0x55,0x75,0x54,0x08,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 30898 0x78b2 "碲" */
+0x00,0x00,0xf9,0x20,0x20,0x40,0x7b,0x4a,0xcc,0x49,0x49,0x49,0x79,0x49,0x00,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 30899 0x78b3 "碳" */
+0x00,0x01,0xf9,0x21,0x21,0x40,0x78,0x4b,0xc8,0x49,0x49,0x4a,0x7a,0x4c,0x08,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x80,0x80,0xfe,0x90,0x10,0x52,0x54,0xa8,0x28,0x44,0x82,
+/* 30900 0x78b4 "碴" */
+0x00,0x00,0xfb,0x20,0x20,0x41,0x7a,0x49,0xc9,0x49,0x49,0x49,0x79,0x48,0x03,0x00,
+0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 30901 0x78b5 "碵" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3c,0x24,0x21,0x02,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 30902 0x78b6 "碶" */
+0x00,0x00,0xfb,0x20,0x21,0x40,0x7b,0x48,0xc8,0x48,0x4b,0x48,0x78,0x48,0x01,0x06,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 30903 0x78b7 "碷" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 30904 0x78b8 "碸" */
+0x00,0x07,0xf4,0x24,0x25,0x44,0x75,0xd5,0x55,0x55,0x54,0x54,0x75,0x54,0x08,0x10,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 30905 0x78b9 "碹" */
+0x00,0x00,0xfb,0x22,0x24,0x41,0x78,0x49,0xc9,0x49,0x49,0x49,0x79,0x48,0x03,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 30906 0x78ba "確" */
+0x00,0x00,0xfb,0x22,0x20,0x41,0x79,0x4b,0xcd,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x40,0x40,0xfe,0xa2,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 30907 0x78bb "碻" */
+0x00,0x00,0xfd,0x10,0x10,0x20,0x3c,0x64,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 30908 0x78bc "碼" */
+0x00,0x01,0xf9,0x21,0x21,0x41,0x79,0x49,0xc9,0x48,0x4a,0x4a,0x7a,0x4a,0x00,0x00,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 30909 0x78bd "碽" */
+0x00,0x01,0xfc,0x10,0x13,0x20,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x24,0x21,0x02,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 30910 0x78be "碾" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x26,0x22,0x04,
+0x00,0xfe,0x02,0x02,0xfe,0x24,0x24,0x7e,0x24,0x24,0xfe,0x52,0x54,0x48,0x64,0x42,
+/* 30911 0x78bf "碿" */
+0x00,0x03,0xfa,0x22,0x23,0x42,0x7a,0xca,0x4a,0x4a,0x4a,0x4a,0x7a,0x44,0x04,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x54,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x8a,0x84,
+/* 30912 0x78c0 "磀" */
+0x02,0x01,0xf9,0x20,0x20,0x43,0x79,0x49,0xc9,0x49,0x49,0x49,0x79,0x4a,0x04,0x00,
+0x44,0x24,0x28,0x7e,0x10,0x54,0x54,0x54,0x7c,0x14,0x20,0x20,0x40,0x80,0x7e,0x00,
+/* 30913 0x78c1 "磁" */
+0x01,0x00,0xf0,0x27,0x21,0x41,0x72,0xd2,0x54,0x57,0x51,0x52,0x72,0x54,0x07,0x00,
+0x08,0x88,0x90,0xfe,0x08,0x08,0x10,0x94,0xa4,0x38,0x08,0x10,0x10,0xa4,0xbc,0x84,
+/* 30914 0x78c2 "磂" */
+0x00,0x03,0xfa,0x22,0x22,0x42,0x7b,0x48,0xcb,0x4a,0x4a,0x4b,0x7a,0x4a,0x03,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 30915 0x78c3 "磃" */
+0x00,0x00,0xfb,0x22,0x22,0x42,0x7a,0xca,0x4a,0x4a,0x4a,0x4a,0x7a,0x44,0x05,0x0a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 30916 0x78c4 "磄" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 30917 0x78c5 "磅" */
+0x00,0x00,0xfb,0x21,0x20,0x43,0x7a,0x4c,0xc8,0x4b,0x48,0x48,0x78,0x49,0x01,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 30918 0x78c6 "磆" */
+0x00,0x01,0xfd,0x11,0x11,0x23,0x22,0x7d,0x65,0xa5,0x25,0x25,0x25,0x3d,0x25,0x01,
+0x00,0xfc,0x04,0xe4,0x24,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 30919 0x78c7 "磇" */
+0x00,0x00,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa4,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 30920 0x78c8 "磈" */
+0x00,0x00,0xfb,0x22,0x22,0x43,0x7a,0x4a,0xcb,0x48,0x48,0x48,0x79,0x49,0x02,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 30921 0x78c9 "磉" */
+0x03,0x01,0xf0,0x23,0x20,0x47,0x74,0xd3,0x54,0x50,0x57,0x50,0x71,0x52,0x0c,0x00,
+0xf0,0x10,0xe0,0x18,0x00,0xbc,0xa4,0x18,0xa4,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,
+/* 30922 0x78ca "磊" */
+0x7f,0x04,0x08,0x1f,0x28,0x48,0x8f,0x00,0x7e,0x10,0x20,0x7e,0xa3,0x22,0x3e,0x22,
+0xfc,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,
+/* 30923 0x78cb "磋" */
+0x00,0x00,0xfc,0x11,0x10,0x20,0x3c,0x65,0x64,0xa4,0x24,0x25,0x3e,0x24,0x21,0x00,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 30924 0x78cc "磌" */
+0x00,0x00,0xfb,0x20,0x21,0x41,0x79,0x49,0xc9,0x49,0x49,0x49,0x7b,0x48,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 30925 0x78cd "磍" */
+0x00,0x00,0xfb,0x22,0x24,0x41,0x78,0x49,0xc8,0x4b,0x48,0x49,0x79,0x49,0x01,0x01,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 30926 0x78ce "磎" */
+0x00,0x03,0xfd,0x10,0x10,0x20,0x21,0x7c,0x64,0xa5,0x24,0x24,0x27,0x3c,0x24,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 30927 0x78cf "磏" */
+0x00,0x00,0xfc,0x13,0x10,0x21,0x3c,0x67,0x64,0xa5,0x24,0x24,0x3d,0x26,0x20,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 30928 0x78d0 "磐" */
+0x08,0x3e,0x22,0x2a,0x7e,0x22,0x2a,0x46,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x78,0x48,0x8e,0x00,0xf8,0x48,0x30,0xcc,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30929 0x78d1 "磑" */
+0x00,0x01,0xfd,0x11,0x11,0x20,0x3f,0x64,0x65,0xa5,0x25,0x25,0x3c,0x24,0x23,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 30930 0x78d2 "磒" */
+0x00,0x00,0xfc,0x10,0x10,0x20,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x24,0x20,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0xfe,0x02,0xfe,0x02,0xfe,0x48,0x84,0x02,
+/* 30931 0x78d3 "磓" */
+0x00,0x02,0xf9,0x21,0x20,0x40,0x7b,0x49,0xc9,0x49,0x49,0x49,0x79,0x4a,0x04,0x00,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 30932 0x78d4 "磔" */
+0x02,0x02,0xf3,0x24,0x2a,0x41,0x72,0xd4,0x58,0x57,0x50,0x51,0x72,0x5c,0x00,0x00,
+0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x48,0x48,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 30933 0x78d5 "磕" */
+0x00,0x00,0xfc,0x10,0x10,0x21,0x3c,0x64,0x65,0xa4,0x25,0x25,0x3d,0x25,0x23,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x84,0xfe,0x02,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 30934 0x78d6 "磖" */
+0x00,0x01,0xfc,0x11,0x10,0x21,0x3c,0x64,0x64,0xa4,0x24,0x24,0x3c,0x24,0x20,0x00,
+0x00,0xde,0x42,0x52,0xca,0x52,0x42,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 30935 0x78d7 "磗" */
+0x00,0x00,0xfb,0x20,0x21,0x41,0x79,0x49,0xc9,0x49,0x48,0x4b,0x78,0x48,0x00,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 30936 0x78d8 "磘" */
+0x00,0x00,0xfb,0x20,0x22,0x41,0x79,0x4a,0xc8,0x4b,0x48,0x49,0x79,0x49,0x01,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 30937 0x78d9 "磙" */
+0x00,0x00,0xfb,0x20,0x21,0x42,0x78,0x49,0xc8,0x48,0x48,0x49,0x7a,0x4c,0x00,0x00,
+0x40,0x20,0xfe,0x88,0x24,0x42,0x90,0xf8,0x08,0x44,0xa8,0x90,0x88,0xa4,0xc2,0x80,
+/* 30938 0x78da "磚" */
+0x00,0x03,0xfc,0x11,0x11,0x21,0x3d,0x65,0x64,0xa7,0x24,0x27,0x3d,0x24,0x20,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 30939 0x78db "磛" */
+0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x1f,0x68,0x0f,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0xfc,0x00,0xf8,0x08,0xf8,
+/* 30940 0x78dc "磜" */
+0x01,0x01,0xfb,0x22,0x25,0x42,0x79,0x4a,0xcc,0x48,0x4b,0x48,0x79,0x4a,0x05,0x00,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 30941 0x78dd "磝" */
+0x00,0x00,0xf8,0x23,0x20,0x43,0x78,0x4f,0xc9,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0x88,0x88,0x88,0xd0,0x9e,0xe4,0x94,0xd4,0x14,0xd4,0x54,0x48,0x48,0x54,0xd4,0x22,
+/* 30942 0x78de "磞" */
+0x00,0x02,0xfa,0x23,0x20,0x43,0x7a,0x4a,0xcb,0x4a,0x4a,0x4b,0x7a,0x4a,0x05,0x08,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 30943 0x78df "磟" */
+0x00,0x07,0xf8,0x24,0x22,0x44,0x78,0x49,0xce,0x48,0x4b,0x48,0x7b,0x48,0x00,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 30944 0x78e0 "磠" */
+0x00,0x00,0xf8,0x20,0x20,0x43,0x7a,0x4b,0xca,0x4a,0x4b,0x4a,0x7a,0x4b,0x03,0x02,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x02,0x26,0x8a,0x52,0x26,0x52,0x8a,0x26,0xfe,0x02,
+/* 30945 0x78e1 "磡" */
+0x02,0x02,0xf7,0x22,0x23,0x42,0x73,0xd2,0x52,0x5f,0x54,0x55,0x76,0x54,0x07,0x00,
+0x48,0x48,0xe8,0x48,0xde,0x4a,0xca,0x4a,0x4a,0xea,0x0a,0x4a,0x32,0x12,0xea,0x44,
+/* 30946 0x78e2 "磢" */
+0x00,0x00,0xfb,0x20,0x22,0x41,0x7a,0x48,0xca,0x49,0x4a,0x48,0x78,0x48,0x01,0x06,
+0x20,0x20,0xfe,0x20,0xaa,0x24,0xaa,0x20,0xaa,0x24,0xaa,0x50,0x50,0x88,0x04,0x02,
+/* 30947 0x78e3 "磣" */
+0x00,0x00,0xf9,0x21,0x22,0x43,0x78,0x49,0xce,0x48,0x4b,0x48,0x7b,0x48,0x00,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 30948 0x78e4 "磤" */
+0x00,0x00,0xfb,0x22,0x23,0x42,0x7b,0xca,0x4b,0x4a,0x4b,0x4a,0x7a,0x44,0x05,0x08,
+0x00,0xdc,0x14,0x14,0xd4,0x54,0xe6,0x40,0xdc,0x14,0xd4,0x54,0x48,0x48,0x54,0xa2,
+/* 30949 0x78e5 "磥" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3c,0x64,0x65,0xa4,0x24,0x27,0x3c,0x25,0x22,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 30950 0x78e6 "磦" */
+0x00,0x03,0xfc,0x11,0x11,0x21,0x3d,0x64,0x65,0xa4,0x27,0x24,0x3c,0x25,0x22,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 30951 0x78e7 "磧" */
+0x00,0x03,0xfc,0x11,0x10,0x23,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x20,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 30952 0x78e8 "磨" */
+0x00,0x3f,0x22,0x2f,0x22,0x27,0x2a,0x22,0x2f,0x21,0x22,0x27,0x4a,0x52,0x83,0x02,
+0x80,0xfe,0x10,0x7c,0x10,0x38,0xd4,0x10,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30953 0x78e9 "磩" */
+0x00,0x00,0xf8,0x23,0x22,0x42,0x7a,0xca,0x4b,0x4a,0x4a,0x4a,0x7b,0x44,0x04,0x08,
+0x0c,0x0a,0x08,0xfe,0x08,0x48,0x6a,0x4a,0xfa,0x4c,0x4c,0xec,0x5a,0x4a,0xd6,0x22,
+/* 30954 0x78ea "磪" */
+0x00,0x02,0xfb,0x20,0x20,0x41,0x7b,0x4d,0xc9,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 30955 0x78eb "磫" */
+0x01,0x01,0xf2,0x24,0x29,0x41,0x72,0xd6,0x5a,0x52,0x52,0x52,0x72,0x52,0x02,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 30956 0x78ec "磬" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30957 0x78ed "磭" */
+0x03,0x02,0xfa,0x22,0x23,0x42,0x7a,0xca,0x4a,0x4a,0x4a,0x4a,0x7a,0x44,0x04,0x08,
+0xfe,0x00,0xfc,0x00,0xfe,0x94,0xa8,0xc4,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,
+/* 30958 0x78ee "磮" */
+0x00,0x01,0xfd,0x11,0x10,0x20,0x3c,0x65,0x66,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x24,0x24,0xfc,0x20,0x50,0x88,0x74,0x02,0xfc,0x54,0x54,0xfc,0x54,0x54,0x0c,
+/* 30959 0x78ef "磯" */
+0x01,0x01,0xfa,0x23,0x21,0x42,0x7b,0x49,0xcf,0x49,0x49,0x49,0x7a,0x4a,0x02,0x04,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 30960 0x78f0 "磰" */
+0x00,0x00,0xfb,0x20,0x21,0x40,0x7b,0x49,0xc8,0x4b,0x48,0x49,0x79,0x49,0x01,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 30961 0x78f1 "磱" */
+0x00,0x02,0xfa,0x24,0x21,0x42,0x78,0x4b,0xca,0x4c,0x4b,0x48,0x78,0x48,0x01,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 30962 0x78f2 "磲" */
+0x02,0x01,0xf8,0x24,0x22,0x40,0x79,0x4e,0xca,0x48,0x4b,0x48,0x78,0x49,0x02,0x00,
+0x00,0x7e,0x40,0x7c,0x44,0xfc,0x40,0x7e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 30963 0x78f3 "磳" */
+0x01,0x00,0xf8,0x23,0x22,0x42,0x7a,0x4a,0xcb,0x48,0x49,0x49,0x79,0x49,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 30964 0x78f4 "磴" */
+0x00,0x07,0xf0,0x22,0x21,0x42,0x75,0xd8,0x53,0x52,0x52,0x53,0x72,0x51,0x0f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 30965 0x78f5 "磵" */
+0x00,0x03,0xfa,0x23,0x22,0x43,0x7a,0x4a,0xca,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 30966 0x78f6 "磶" */
+0x00,0x03,0xfa,0x22,0x23,0x42,0x7a,0xcb,0x49,0x4b,0x4c,0x4a,0x7a,0x44,0x00,0x00,
+0x80,0x1c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 30967 0x78f7 "磷" */
+0x00,0x01,0xf8,0x23,0x20,0x41,0x7a,0x49,0xc9,0x49,0x4a,0x4d,0x78,0x49,0x02,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 30968 0x78f8 "磸" */
+0x00,0x00,0xfb,0x20,0x21,0x41,0x79,0x49,0xc9,0x49,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 30969 0x78f9 "磹" */
+0x00,0x03,0xfc,0x13,0x12,0x23,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3c,0x23,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 30970 0x78fa "磺" */
+0x00,0x00,0xfd,0x10,0x10,0x23,0x3c,0x65,0x65,0xa5,0x25,0x25,0x3c,0x24,0x21,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 30971 0x78fb "磻" */
+0x00,0x03,0xfd,0x10,0x13,0x20,0x3d,0x66,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 30972 0x78fc "磼" */
+0x00,0x00,0xfd,0x13,0x11,0x21,0x3d,0x65,0x65,0xa5,0x24,0x27,0x3c,0x24,0x23,0x00,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 30973 0x78fd "磽" */
+0x00,0x00,0xf9,0x20,0x23,0x41,0x7b,0x49,0xc9,0x4e,0x48,0x4b,0x78,0x48,0x01,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 30974 0x78fe "磾" */
+0x00,0x03,0xfa,0x22,0x23,0x40,0x79,0x49,0xc9,0x49,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30975 0x78ff "磿" */
+0x3f,0x21,0x2e,0x22,0x2f,0x27,0x2a,0x32,0x20,0x2f,0x21,0x23,0x26,0x5a,0x43,0x82,
+0xfe,0x04,0x38,0x10,0xbc,0x18,0xb4,0x52,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30976 0x7900 "礀" */
+0x03,0x02,0xfb,0x22,0x23,0x42,0x7a,0x4a,0xca,0x4a,0x4a,0x4a,0x7a,0x4b,0x02,0x02,
+0xde,0x52,0xde,0x52,0xde,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 30977 0x7901 "礁" */
+0x00,0x00,0xf9,0x21,0x23,0x45,0x79,0x49,0xc9,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0xa0,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 30978 0x7902 "礂" */
+0x00,0x03,0xfc,0x11,0x10,0x21,0x3d,0x65,0x64,0xa7,0x24,0x25,0x3d,0x25,0x21,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 30979 0x7903 "礃" */
+0x01,0x00,0xfb,0x22,0x20,0x40,0x78,0x48,0xc9,0x48,0x49,0x48,0x7b,0x48,0x00,0x00,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 30980 0x7904 "礄" */
+0x00,0x01,0xfc,0x13,0x10,0x21,0x3e,0x64,0x64,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 30981 0x7905 "礅" */
+0x02,0x01,0xf7,0x20,0x27,0x44,0x77,0xd0,0x57,0x50,0x51,0x51,0x77,0x51,0x05,0x02,
+0x08,0x08,0xc8,0x10,0x9e,0x94,0xa4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 30982 0x7906 "礆" */
+0x00,0x00,0xfc,0x10,0x11,0x22,0x3c,0x64,0x65,0xa5,0x25,0x25,0x3c,0x24,0x21,0x02,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 30983 0x7907 "礇" */
+0x00,0x00,0xfb,0x22,0x22,0x42,0x7b,0x4a,0xca,0x4a,0x48,0x4b,0x78,0x48,0x01,0x06,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 30984 0x7908 "礈" */
+0x00,0x02,0xf9,0x20,0x20,0x40,0x7b,0x49,0xc9,0x49,0x49,0x49,0x79,0x49,0x02,0x04,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 30985 0x7909 "礉" */
+0x01,0x02,0xf7,0x24,0x27,0x44,0x77,0xd2,0x51,0x57,0x52,0x53,0x72,0x54,0x05,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 30986 0x790a "礊" */
+0x08,0xff,0x08,0x3e,0x2b,0x3e,0x2a,0xff,0x49,0x7f,0x00,0x7f,0x08,0x1f,0x68,0x0f,
+0x78,0xc8,0x48,0x86,0x78,0x48,0x28,0x90,0x28,0x46,0x00,0xfc,0x00,0xf8,0x08,0xf8,
+/* 30987 0x790b "礋" */
+0x00,0x01,0xfd,0x11,0x10,0x21,0x3c,0x67,0x64,0xa4,0x25,0x24,0x3f,0x24,0x20,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 30988 0x790c "礌" */
+0x00,0x01,0xfc,0x13,0x12,0x21,0x3c,0x65,0x64,0xa5,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,
+/* 30989 0x790d "礍" */
+0x00,0x03,0xfc,0x11,0x11,0x21,0x3d,0x65,0x64,0xa5,0x26,0x25,0x3d,0x25,0x20,0x00,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 30990 0x790e "礎" */
+0x00,0x00,0xfb,0x20,0x21,0x42,0x7c,0x48,0xcb,0x48,0x49,0x49,0x79,0x4a,0x04,0x08,
+0x88,0x88,0xde,0x88,0xdc,0xaa,0x88,0x00,0xfe,0x22,0x20,0x3c,0x20,0xa0,0x7e,0x00,
+/* 30991 0x790f "礏" */
+0x00,0x02,0xf9,0x20,0x23,0x40,0x78,0x4b,0xc8,0x49,0x48,0x4b,0x78,0x49,0x06,0x00,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 30992 0x7910 "礐" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x40,0xbf,0x04,0x0f,0x18,0x68,0x0f,0x08,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0xf4,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 30993 0x7911 "礑" */
+0x00,0x01,0xfc,0x13,0x12,0x20,0x3c,0x64,0x64,0xa4,0x25,0x25,0x3d,0x25,0x21,0x01,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 30994 0x7912 "礒" */
+0x01,0x00,0xfb,0x20,0x21,0x40,0x7b,0x48,0xc9,0x48,0x4b,0x48,0x78,0x4b,0x00,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 30995 0x7913 "礓" */
+0x00,0x03,0xfc,0x11,0x11,0x21,0x3d,0x67,0x64,0xa5,0x25,0x25,0x3d,0x25,0x20,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 30996 0x7914 "礔" */
+0x00,0x03,0xfa,0x22,0x22,0x43,0x7a,0x4a,0xcb,0x4a,0x4e,0x4a,0x7a,0x4b,0x02,0x00,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 30997 0x7915 "礕" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x00,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 30998 0x7916 "礖" */
+0x01,0x02,0xfa,0x22,0x23,0x42,0x7a,0x4b,0xca,0x4a,0x4f,0x48,0x79,0x49,0x02,0x04,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 30999 0x7917 "礗" */
+0x00,0x00,0xfb,0x22,0x21,0x41,0x7a,0x49,0xcb,0x49,0x49,0x49,0x79,0x49,0x00,0x01,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 31000 0x7918 "礘" */
+0x00,0x03,0xfa,0x23,0x22,0x43,0x79,0x4a,0xcb,0x49,0x4a,0x4b,0x78,0x4a,0x02,0x04,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 31001 0x7919 "礙" */
+0x02,0x02,0xfb,0x22,0x21,0x40,0x7a,0x4b,0xcd,0x49,0x4f,0x49,0x7a,0x4a,0x04,0x00,
+0x00,0xbe,0x02,0x54,0xc8,0x3e,0x0a,0xca,0x28,0x28,0xee,0x28,0xa8,0x58,0x4e,0x80,
+/* 31002 0x791a "礚" */
+0x00,0x03,0xf8,0x20,0x21,0x40,0x7b,0x48,0xc8,0x49,0x48,0x49,0x79,0x49,0x07,0x00,
+0x88,0xfe,0x88,0x20,0xfc,0x20,0xfe,0x40,0x88,0xfc,0x00,0xfc,0x54,0x54,0xfe,0x00,
+/* 31003 0x791b "礛" */
+0x00,0x03,0xfa,0x23,0x22,0x43,0x7a,0x4b,0xc8,0x49,0x49,0x49,0x79,0x49,0x07,0x00,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 31004 0x791c "礜" */
+0x0a,0x33,0x22,0x3b,0x20,0x3a,0x22,0xff,0x10,0x3f,0xc4,0x0f,0x18,0x68,0x0f,0x08,
+0x00,0xb8,0x08,0xb8,0x88,0xb8,0x88,0xfe,0x10,0xf8,0x06,0xf0,0x10,0x10,0xf0,0x10,
+/* 31005 0x791d "礝" */
+0x00,0x01,0xfc,0x13,0x12,0x21,0x3c,0x65,0x64,0xa7,0x24,0x25,0x3d,0x25,0x21,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 31006 0x791e "礞" */
+0x00,0x03,0xf8,0x23,0x22,0x41,0x78,0x4b,0xc8,0x48,0x4b,0x48,0x7b,0x48,0x03,0x00,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 31007 0x791f "礟" */
+0x00,0x07,0xf5,0x27,0x25,0x47,0x75,0xd5,0x57,0x50,0x55,0x55,0x75,0x54,0x00,0x01,
+0x00,0xc4,0x14,0xc8,0x08,0xd4,0x14,0x00,0xd4,0x54,0x54,0x48,0x48,0x54,0x54,0xa2,
+/* 31008 0x7920 "礠" */
+0x01,0x00,0xfb,0x21,0x21,0x42,0x7b,0x49,0xca,0x4b,0x48,0x48,0x7a,0x4a,0x04,0x00,
+0x08,0x90,0xfe,0x08,0x08,0x52,0x9c,0x08,0x52,0xde,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 31009 0x7921 "礡" */
+0x00,0x03,0xfc,0x10,0x13,0x20,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3c,0x25,0x20,0x00,
+0x88,0xfe,0x88,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x58,
+/* 31010 0x7922 "礢" */
+0x01,0x00,0xfb,0x20,0x21,0x40,0x7b,0x49,0xc9,0x4b,0x4d,0x49,0x79,0x49,0x01,0x01,
+0x08,0x90,0xfc,0x40,0xf8,0x80,0xfc,0x48,0xfc,0x0a,0xf8,0x08,0xfa,0x34,0x8c,0x02,
+/* 31011 0x7923 "礣" */
+0x00,0x01,0xfc,0x10,0x11,0x21,0x3d,0x65,0x64,0xa5,0x25,0x25,0x3d,0x25,0x21,0x02,
+0x48,0xfe,0x48,0x00,0xfe,0x4a,0x4a,0xfe,0x14,0xfe,0x10,0x92,0x4c,0x4a,0x16,0x22,
+/* 31012 0x7924 "礤" */
+0x00,0x00,0xfb,0x20,0x21,0x41,0x7a,0x4d,0xca,0x49,0x4a,0x49,0x78,0x49,0x02,0x00,
+0x88,0x88,0xfe,0x88,0x10,0xde,0x52,0x54,0x88,0x74,0x02,0xfc,0x20,0x24,0x22,0x60,
+/* 31013 0x7925 "礥" */
+0x07,0x05,0xf7,0x24,0x27,0x45,0x77,0xd0,0x53,0x52,0x53,0x52,0x73,0x52,0x03,0x01,
+0xde,0x12,0xd2,0x54,0xc8,0x14,0xe2,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,
+/* 31014 0x7926 "礦" */
+0x00,0x00,0xfb,0x22,0x22,0x42,0x7b,0x4a,0xca,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x04,
+0x20,0x10,0xfe,0x44,0xfe,0x44,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x00,0x44,0x82,
+/* 31015 0x7927 "礧" */
+0x00,0x01,0xf9,0x21,0x21,0x41,0x79,0x48,0xcb,0x4a,0x4a,0x4b,0x7a,0x4a,0x03,0x02,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xfe,0x22,
+/* 31016 0x7928 "礨" */
+0x00,0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0x3e,0x00,0x7f,0x08,0x1f,0x68,0x0f,
+0x00,0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x00,0xf8,0x08,0xf8,
+/* 31017 0x7929 "礩" */
+0x00,0x03,0xfa,0x23,0x22,0x42,0x7c,0x4b,0xca,0x4b,0x4a,0x4b,0x7a,0x4b,0x01,0x02,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 31018 0x792a "礪" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x22,0x02,0x04,
+0x00,0xfe,0x28,0xfe,0x28,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x92,0xba,0x8a,0x84,
+/* 31019 0x792b "礫" */
+0x01,0x01,0xfa,0x22,0x23,0x41,0x7a,0x4b,0xc8,0x48,0x4b,0x48,0x78,0x49,0x02,0x00,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 31020 0x792c "礬" */
+0x22,0x21,0xfa,0x20,0x72,0xa9,0x22,0xff,0x08,0x3f,0xc4,0x0f,0x18,0x68,0x0f,0x08,
+0x88,0x08,0xbe,0x08,0x9c,0x2a,0x88,0xfe,0x20,0xf8,0x06,0xf0,0x10,0x10,0xf0,0x10,
+/* 31021 0x792d "礭" */
+0x01,0x00,0xfb,0x22,0x25,0x40,0x79,0x48,0xc9,0x4b,0x4d,0x49,0x79,0x49,0x01,0x01,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 31022 0x792e "礮" */
+0x00,0x07,0xf5,0x27,0x25,0x47,0x75,0xd5,0x57,0x50,0x55,0x55,0x75,0x54,0x00,0x01,
+0x10,0xc8,0x3e,0xc0,0x14,0xd2,0x22,0x00,0xd4,0x54,0x54,0x48,0x48,0x54,0x54,0xa2,
+/* 31023 0x792f "礯" */
+0x00,0x02,0xfa,0x24,0x21,0x42,0x7b,0x4a,0xc8,0x49,0x48,0x4b,0x78,0x49,0x02,0x00,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0xfe,0x42,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 31024 0x7930 "礰" */
+0x00,0x07,0xf4,0x25,0x24,0x47,0x74,0xd5,0x56,0x54,0x54,0x54,0x74,0x54,0x04,0x0b,
+0x00,0xfe,0x44,0x98,0x88,0xde,0x88,0xdc,0xaa,0x88,0x20,0x20,0xbc,0xa0,0xa0,0xfe,
+/* 31025 0x7931 "礱" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x00,0x7f,0x08,0x1f,0x68,0x0f,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,0x00,0xfc,0x00,0xf8,0x08,0xf8,
+/* 31026 0x7932 "礲" */
+0x01,0x00,0xfb,0x20,0x22,0x41,0x7b,0x48,0xcb,0x4a,0x4b,0x4a,0x7b,0x4a,0x02,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 31027 0x7933 "礳" */
+0x00,0x00,0xfb,0x22,0x23,0x42,0x7a,0x4b,0xca,0x4b,0x4a,0x4a,0x7a,0x4b,0x04,0x08,
+0x40,0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0xfe,0x20,0x7c,0xc4,0x44,0x7c,0x44,
+/* 31028 0x7934 "礴" */
+0x00,0x03,0xf0,0x24,0x22,0x40,0x74,0xd2,0x52,0x50,0x51,0x52,0x76,0x52,0x02,0x02,
+0x88,0xfe,0x88,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x2c,
+/* 31029 0x7935 "礵" */
+0x01,0x00,0xfb,0x22,0x21,0x40,0x79,0x48,0xc8,0x4b,0x48,0x49,0x7a,0x4c,0x00,0x00,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0x9e,0xf2,0x9e,0xd2,0xbe,0x92,0x9e,0x92,
+/* 31030 0x7936 "礶" */
+0x00,0x03,0xf8,0x23,0x22,0x43,0x78,0x48,0xc9,0x49,0x4b,0x4d,0x79,0x49,0x01,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 31031 0x7937 "礷" */
+0x00,0x07,0xf8,0x23,0x22,0x43,0x7a,0x4b,0xca,0x4b,0x48,0x4b,0x7a,0x4a,0x07,0x00,
+0x90,0xfe,0x90,0xe8,0x88,0xce,0x50,0xd4,0xa2,0xe2,0x00,0xfc,0x94,0x94,0xfe,0x00,
+/* 31032 0x7938 "礸" */
+0x05,0x07,0xf9,0x27,0x23,0x45,0x79,0x4b,0xca,0x4b,0x4a,0x4b,0x7a,0x4b,0x01,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 31033 0x7939 "礹" */
+0x07,0x04,0xf7,0x20,0x27,0x44,0x75,0xd4,0x57,0x55,0x55,0x55,0x75,0x55,0x0b,0x10,
+0xbc,0xa4,0xbc,0x00,0xfe,0x00,0x90,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x68,0xc8,0x54,
+/* 31034 0x793a "示" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0xff,0x01,0x01,0x11,0x11,0x21,0x41,0x81,0x05,0x02,
+0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x10,0x08,0x04,0x02,0x02,0x00,0x00,
+/* 31035 0x793b "礻" */
+0x20,0x10,0x10,0xf8,0x08,0x10,0x10,0x38,0x54,0x94,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 31036 0x793c "礼" */
+0x20,0x10,0x10,0xf8,0x08,0x10,0x10,0x38,0x54,0x94,0x10,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 31037 0x793d "礽" */
+0x20,0x10,0x13,0xf8,0x08,0x10,0x10,0x38,0x54,0x94,0x11,0x11,0x11,0x12,0x12,0x14,
+0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 31038 0x793e "社" */
+0x20,0x10,0x10,0xf8,0x08,0x10,0x13,0x38,0x54,0x94,0x10,0x10,0x10,0x10,0x17,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 31039 0x793f "礿" */
+0x20,0x10,0x10,0xf8,0x09,0x12,0x10,0x39,0x54,0x94,0x10,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 31040 0x7940 "祀" */
+0x20,0x10,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x10,0x10,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 31041 0x7941 "祁" */
+0x20,0x10,0x10,0xfc,0x04,0x08,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x88,0x88,0x84,0x84,0xc4,0xa8,0x90,0x80,0x80,0x80,
+/* 31042 0x7942 "祂" */
+0x20,0x10,0x10,0xf9,0x09,0x11,0x11,0x3b,0x55,0x95,0x11,0x11,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 31043 0x7943 "祃" */
+0x20,0x13,0x10,0xf8,0x09,0x11,0x11,0x39,0x54,0x94,0x10,0x13,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0x28,0x10,
+/* 31044 0x7944 "祄" */
+0x20,0x10,0x10,0xf8,0x08,0x11,0x12,0x38,0x54,0x94,0x10,0x10,0x10,0x11,0x11,0x12,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 31045 0x7945 "祅" */
+0x20,0x10,0x11,0xf8,0x08,0x10,0x13,0x38,0x54,0x94,0x10,0x10,0x10,0x10,0x11,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 31046 0x7946 "祆" */
+0x20,0x10,0x11,0xf8,0x08,0x10,0x10,0x3b,0x54,0x94,0x10,0x10,0x10,0x10,0x11,0x12,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 31047 0x7947 "祇" */
+0x20,0x10,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 31048 0x7948 "祈" */
+0x20,0x10,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 31049 0x7949 "祉" */
+0x20,0x10,0x10,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x17,0x10,
+0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 31050 0x794a "祊" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x10,0x38,0x54,0x94,0x10,0x10,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 31051 0x794b "祋" */
+0x20,0x10,0x10,0xf8,0x08,0x11,0x12,0x39,0x54,0x94,0x10,0x10,0x10,0x10,0x10,0x13,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 31052 0x794c "祌" */
+0x20,0x10,0x10,0xf8,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 31053 0x794d "祍" */
+0x20,0x10,0x11,0xf8,0x08,0x10,0x10,0x3b,0x54,0x94,0x10,0x10,0x10,0x10,0x11,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 31054 0x794e "祎" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x19,0x34,0x50,0x93,0x10,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 31055 0x794f "祏" */
+0x20,0x10,0x13,0xf8,0x08,0x10,0x18,0x34,0x51,0x92,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 31056 0x7950 "祐" */
+0x20,0x10,0x10,0xf8,0x0b,0x10,0x10,0x38,0x54,0x91,0x12,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfe,0x40,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 31057 0x7951 "祑" */
+0x20,0x10,0x11,0xf9,0x09,0x11,0x12,0x38,0x57,0x94,0x10,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 31058 0x7952 "祒" */
+0x20,0x13,0x10,0xf8,0x08,0x11,0x11,0x3a,0x54,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31059 0x7953 "祓" */
+0x20,0x10,0x10,0xf8,0x0b,0x10,0x10,0x38,0x55,0x95,0x11,0x11,0x12,0x12,0x14,0x11,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31060 0x7954 "祔" */
+0x20,0x10,0x10,0xf9,0x09,0x13,0x15,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 31061 0x7955 "祕" */
+0x20,0x10,0x10,0xf8,0x08,0x10,0x10,0x3a,0x56,0x92,0x14,0x10,0x11,0x12,0x14,0x10,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 31062 0x7956 "祖" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 31063 0x7957 "祗" */
+0x40,0x20,0x23,0xfa,0x12,0x12,0x22,0x33,0x6a,0xaa,0x22,0x22,0x22,0x22,0x23,0x22,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 31064 0x7958 "祘" */
+0x00,0x3e,0x00,0x00,0x00,0x7e,0x08,0x08,0x2a,0x29,0x49,0x88,0x08,0x08,0x28,0x10,
+0x00,0x7c,0x00,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x10,0x50,0x20,
+/* 31065 0x7959 "祙" */
+0x20,0x10,0x10,0xf9,0x08,0x10,0x10,0x3b,0x54,0x94,0x10,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 31066 0x795a "祚" */
+0x20,0x10,0x10,0xf8,0x09,0x11,0x12,0x38,0x54,0x94,0x10,0x10,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 31067 0x795b "祛" */
+0x20,0x10,0x10,0xf9,0x08,0x10,0x10,0x3b,0x54,0x94,0x10,0x10,0x10,0x11,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 31068 0x795c "祜" */
+0x20,0x10,0x10,0xf8,0x0b,0x10,0x10,0x38,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31069 0x795d "祝" */
+0x20,0x13,0x12,0xfa,0x0a,0x12,0x13,0x38,0x54,0x94,0x10,0x11,0x11,0x12,0x14,0x18,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,0x00,
+/* 31070 0x795e "神" */
+0x20,0x10,0x10,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 31071 0x795f "祟" */
+0x01,0x11,0x11,0x1f,0x41,0x41,0x7f,0x00,0x3f,0x00,0xff,0x01,0x11,0x21,0x45,0x02,
+0x00,0x10,0x10,0xf0,0x04,0x04,0xfc,0x00,0xf8,0x00,0xfe,0x00,0x10,0x08,0x04,0x00,
+/* 31072 0x7960 "祠" */
+0x20,0x11,0x10,0xf8,0x0b,0x10,0x10,0x39,0x55,0x95,0x11,0x11,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 31073 0x7961 "祡" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x00,0x3f,0x00,0xff,0x01,0x11,0x21,0x45,0x02,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0x00,0xf8,0x00,0xfe,0x00,0x10,0x08,0x04,0x00,
+/* 31074 0x7962 "祢" */
+0x20,0x10,0x10,0xf8,0x09,0x11,0x12,0x38,0x54,0x94,0x11,0x11,0x12,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 31075 0x7963 "祣" */
+0x20,0x10,0x10,0xf9,0x0a,0x10,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xfe,0x00,0x00,0x1c,0xe0,0x20,0x22,0x24,0x28,0x10,0x10,0x48,0x84,0x02,
+/* 31076 0x7964 "祤" */
+0x20,0x13,0x10,0xf8,0x0a,0x11,0x11,0x38,0x54,0x91,0x12,0x10,0x10,0x10,0x11,0x10,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 31077 0x7965 "祥" */
+0x21,0x10,0x10,0xf8,0x0b,0x10,0x10,0x39,0x54,0x90,0x13,0x10,0x10,0x10,0x10,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31078 0x7966 "祦" */
+0x20,0x11,0x11,0xf9,0x09,0x10,0x10,0x39,0x54,0x90,0x13,0x10,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 31079 0x7967 "祧" */
+0x20,0x10,0x10,0xfa,0x09,0x10,0x18,0x35,0x52,0x94,0x10,0x10,0x11,0x11,0x12,0x14,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 31080 0x7968 "票" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x00,0x3f,0x00,0xff,0x01,0x11,0x21,0x45,0x02,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x00,0x10,0x08,0x04,0x00,
+/* 31081 0x7969 "祩" */
+0x20,0x11,0x11,0xf9,0x09,0x12,0x10,0x3b,0x54,0x94,0x10,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 31082 0x796a "祪" */
+0x20,0x10,0x10,0xf9,0x0a,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x12,0x12,0x14,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 31083 0x796b "祫" */
+0x20,0x10,0x10,0xf8,0x09,0x12,0x11,0x38,0x54,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31084 0x796c "祬" */
+0x20,0x13,0x10,0xf8,0x08,0x11,0x13,0x38,0x54,0x90,0x13,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 31085 0x796d "祭" */
+0x10,0x10,0x1e,0x22,0x54,0xa8,0x10,0x2f,0xc0,0x00,0x7f,0x01,0x11,0x21,0x45,0x02,
+0x00,0x80,0xbc,0x44,0x48,0x30,0x10,0xe8,0x06,0x00,0xfc,0x00,0x10,0x08,0x04,0x00,
+/* 31086 0x796e "祮" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x11,0x38,0x54,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31087 0x796f "祯" */
+0x20,0x10,0x10,0xf8,0x08,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x10,0x10,0x10,0x11,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 31088 0x7970 "祰" */
+0x20,0x11,0x11,0xf9,0x09,0x12,0x10,0x3b,0x54,0x94,0x11,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 31089 0x7971 "祱" */
+0x21,0x10,0x10,0xf8,0x09,0x11,0x11,0x39,0x55,0x94,0x10,0x10,0x10,0x11,0x12,0x14,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 31090 0x7972 "祲" */
+0x20,0x11,0x10,0xf8,0x08,0x11,0x10,0x3b,0x56,0x91,0x10,0x10,0x10,0x10,0x10,0x13,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 31091 0x7973 "祳" */
+0x20,0x13,0x12,0xfa,0x0a,0x12,0x12,0x3b,0x56,0x92,0x12,0x12,0x12,0x14,0x14,0x18,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0xa0,0xa4,0xa8,0x90,0x90,0x88,0xa4,0xc2,
+/* 31092 0x7974 "祴" */
+0x20,0x10,0x10,0xf8,0x0b,0x10,0x11,0x39,0x57,0x95,0x11,0x11,0x12,0x12,0x14,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x50,0x54,0xf4,0x54,0x54,0x48,0x4a,0x5a,0x26,0x42,
+/* 31093 0x7975 "祵" */
+0x40,0x23,0x22,0xfa,0x12,0x13,0x22,0x32,0x6a,0xaa,0x23,0x22,0x22,0x22,0x23,0x22,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 31094 0x7976 "祶" */
+0x41,0x20,0x20,0xfb,0x10,0x10,0x23,0x32,0x6a,0xab,0x20,0x20,0x21,0x22,0x24,0x20,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 31095 0x7977 "祷" */
+0x20,0x10,0x13,0xf8,0x09,0x10,0x13,0x38,0x54,0x94,0x11,0x11,0x12,0x14,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 31096 0x7978 "祸" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x18,0x34,0x53,0x92,0x12,0x12,0x13,0x12,0x12,0x12,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 31097 0x7979 "祹" */
+0x20,0x10,0x10,0xf9,0x0a,0x10,0x11,0x38,0x57,0x94,0x11,0x11,0x11,0x10,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x82,0xf2,0x42,0x42,0xfa,0x42,0x52,0x52,0xf2,0x02,0x14,0x08,
+/* 31098 0x797a "祺" */
+0x21,0x11,0x13,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x17,0x10,0x10,0x11,0x12,
+0x08,0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,0x90,0x08,0x04,
+/* 31099 0x797b "祻" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 31100 0x797c "祼" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x19,0x35,0x50,0x93,0x10,0x10,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 31101 0x797d "祽" */
+0x20,0x10,0x13,0xf8,0x08,0x10,0x11,0x3a,0x54,0x90,0x13,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31102 0x797e "祾" */
+0x20,0x10,0x11,0xf8,0x08,0x13,0x18,0x35,0x52,0x90,0x11,0x12,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 31103 0x797f "祿" */
+0x20,0x10,0x10,0xf9,0x09,0x10,0x18,0x37,0x50,0x92,0x11,0x10,0x11,0x12,0x10,0x10,
+0x80,0xf8,0x88,0x08,0xf0,0x10,0x10,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 31104 0x7980 "禀" */
+0x01,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x00,0x3f,0x00,0xff,0x11,0x23,
+0x00,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x00,0xf8,0x00,0xfe,0x10,0x08,
+/* 31105 0x7981 "禁" */
+0x08,0x08,0x7e,0x1c,0x2a,0x49,0x8a,0x00,0x1f,0x00,0x00,0xff,0x01,0x11,0x25,0x42,
+0x20,0x20,0xfc,0x70,0xa8,0x26,0x20,0x00,0xf0,0x00,0x00,0xfe,0x00,0x10,0x08,0x04,
+/* 31106 0x7982 "禂" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 31107 0x7983 "禃" */
+0x40,0x20,0x27,0xf8,0x10,0x13,0x22,0x33,0x6a,0xab,0x22,0x23,0x22,0x22,0x2f,0x20,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 31108 0x7984 "禄" */
+0x40,0x21,0x20,0xf8,0x11,0x10,0x20,0x33,0x68,0xaa,0x21,0x20,0x21,0x22,0x20,0x20,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 31109 0x7985 "禅" */
+0x21,0x10,0x10,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x10,0x10,0x13,0x10,0x10,0x10,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 31110 0x7986 "禆" */
+0x20,0x10,0x13,0xfa,0x0a,0x13,0x1a,0x36,0x53,0x90,0x11,0x17,0x10,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 31111 0x7987 "禇" */
+0x20,0x10,0x13,0xf8,0x08,0x17,0x10,0x38,0x55,0x93,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 31112 0x7988 "禈" */
+0x20,0x13,0x12,0xf8,0x0b,0x10,0x11,0x39,0x55,0x95,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 31113 0x7989 "禉" */
+0x20,0x10,0x10,0xfb,0x08,0x10,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 31114 0x798a "禊" */
+0x41,0x21,0x27,0xf9,0x13,0x11,0x27,0x31,0x69,0xa8,0x27,0x20,0x20,0x21,0x22,0x2c,
+0x00,0x3c,0xd4,0x14,0x94,0x14,0xd4,0x24,0x4c,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 31115 0x798b "禋" */
+0x20,0x13,0x10,0xf8,0x09,0x11,0x11,0x39,0x55,0x94,0x10,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 31116 0x798c "禌" */
+0x40,0x20,0x20,0xfb,0x10,0x10,0x21,0x31,0x6a,0xab,0x20,0x21,0x21,0x22,0x23,0x20,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 31117 0x798d "禍" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x3b,0x56,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 31118 0x798e "禎" */
+0x20,0x10,0x10,0xf8,0x08,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x10,0x10,0x11,0x12,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 31119 0x798f "福" */
+0x40,0x23,0x20,0xf9,0x11,0x11,0x21,0x30,0x6b,0xaa,0x22,0x23,0x22,0x22,0x23,0x22,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 31120 0x7990 "禐" */
+0x20,0x17,0x12,0xf9,0x08,0x13,0x10,0x38,0x57,0x95,0x11,0x12,0x12,0x14,0x18,0x13,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 31121 0x7991 "禑" */
+0x21,0x11,0x11,0xf9,0x09,0x11,0x19,0x34,0x50,0x93,0x12,0x12,0x12,0x12,0x12,0x12,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 31122 0x7992 "禒" */
+0x21,0x11,0x12,0xfb,0x08,0x17,0x10,0x39,0x56,0x94,0x11,0x16,0x10,0x11,0x16,0x10,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 31123 0x7993 "禓" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x10,0x3b,0x55,0x95,0x12,0x14,0x11,0x12,0x10,0x11,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 31124 0x7994 "禔" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x19,0x35,0x50,0x93,0x10,0x11,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 31125 0x7995 "禕" */
+0x20,0x10,0x11,0xf8,0x0b,0x10,0x11,0x39,0x55,0x90,0x13,0x10,0x12,0x13,0x10,0x10,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 31126 0x7996 "禖" */
+0x20,0x10,0x13,0xf8,0x08,0x10,0x10,0x38,0x54,0x90,0x13,0x10,0x10,0x11,0x12,0x10,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 31127 0x7997 "禗" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x54,0x94,0x10,0x12,0x12,0x14,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 31128 0x7998 "禘" */
+0x20,0x10,0x11,0xf8,0x08,0x10,0x13,0x3a,0x54,0x95,0x11,0x11,0x11,0x11,0x10,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 31129 0x7999 "禙" */
+0x20,0x10,0x13,0xf8,0x08,0x13,0x10,0x39,0x55,0x95,0x11,0x11,0x11,0x11,0x11,0x11,
+0x50,0x52,0xdc,0x50,0xd2,0x4e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 31130 0x799a "禚" */
+0x21,0x10,0x10,0xf8,0x0b,0x10,0x18,0x35,0x50,0x90,0x13,0x10,0x12,0x12,0x14,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 31131 0x799b "禛" */
+0x20,0x10,0x13,0xf8,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x13,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 31132 0x799c "禜" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x80,0x3f,0x00,0xff,0x01,0x11,0x21,0x45,0x02,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xf8,0x00,0xfe,0x00,0x10,0x08,0x04,0x00,
+/* 31133 0x799d "禝" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x18,0x35,0x52,0x90,0x11,0x12,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 31134 0x799e "禞" */
+0x20,0x10,0x13,0xf8,0x09,0x11,0x19,0x34,0x53,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 31135 0x799f "禟" */
+0x20,0x10,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x11,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 31136 0x79a0 "禠" */
+0x40,0x20,0x23,0xfa,0x12,0x12,0x22,0x32,0x6a,0xaa,0x22,0x22,0x22,0x24,0x25,0x2a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 31137 0x79a1 "禡" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x90,0x12,0x12,0x12,0x12,0x10,0x10,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 31138 0x79a2 "禢" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x18,0x34,0x53,0x90,0x12,0x11,0x12,0x10,0x11,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 31139 0x79a3 "禣" */
+0x20,0x10,0x13,0xf8,0x09,0x11,0x11,0x39,0x55,0x95,0x10,0x13,0x10,0x10,0x10,0x10,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 31140 0x79a4 "禤" */
+0x20,0x13,0x12,0xfa,0x0b,0x10,0x13,0x38,0x56,0x95,0x10,0x13,0x10,0x10,0x11,0x10,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x42,0x4a,0x84,
+/* 31141 0x79a5 "禥" */
+0x20,0x10,0x13,0xf8,0x08,0x10,0x10,0x38,0x57,0x94,0x11,0x12,0x10,0x10,0x13,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x24,0xfa,0x20,0x20,0xfe,0x00,
+/* 31142 0x79a6 "禦" */
+0x02,0x27,0x49,0x97,0x21,0x65,0xa5,0x2f,0x00,0x3f,0x00,0xff,0x01,0x11,0x25,0x02,
+0x00,0xde,0x12,0xd2,0x12,0xda,0x14,0xd0,0x00,0xf8,0x00,0xfe,0x00,0x10,0x08,0x00,
+/* 31143 0x79a7 "禧" */
+0x40,0x27,0x20,0xfb,0x10,0x13,0x22,0x33,0x69,0xaf,0x20,0x23,0x22,0x22,0x23,0x22,
+0x40,0xfc,0x40,0xf8,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 31144 0x79a8 "禨" */
+0x41,0x21,0x22,0xfb,0x11,0x12,0x23,0x31,0x6f,0xa9,0x21,0x21,0x22,0x22,0x22,0x24,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 31145 0x79a9 "禩" */
+0x40,0x23,0x22,0xfb,0x12,0x13,0x20,0x30,0x6b,0xa8,0x20,0x27,0x20,0x20,0x21,0x22,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 31146 0x79aa "禪" */
+0x20,0x13,0x12,0xfa,0x0b,0x10,0x11,0x39,0x55,0x95,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 31147 0x79ab "禫" */
+0x20,0x13,0x10,0xfb,0x0a,0x13,0x10,0x39,0x55,0x95,0x11,0x11,0x10,0x13,0x10,0x10,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 31148 0x79ac "禬" */
+0x20,0x10,0x10,0xf9,0x0a,0x11,0x11,0x39,0x55,0x95,0x10,0x10,0x10,0x10,0x10,0x10,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 31149 0x79ad "禭" */
+0x40,0x24,0x22,0xf8,0x10,0x10,0x26,0x32,0x6a,0xaa,0x22,0x22,0x22,0x22,0x25,0x28,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 31150 0x79ae "禮" */
+0x40,0x23,0x22,0xfb,0x12,0x13,0x20,0x33,0x68,0xab,0x22,0x23,0x21,0x20,0x27,0x20,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x08,0x90,0xfe,0x00,
+/* 31151 0x79af "禯" */
+0x40,0x23,0x22,0xfb,0x12,0x13,0x20,0x33,0x6a,0xaa,0x22,0x23,0x25,0x25,0x25,0x29,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 31152 0x79b0 "禰" */
+0x40,0x23,0x21,0xfa,0x17,0x12,0x23,0x32,0x6b,0xaa,0x23,0x22,0x23,0x22,0x22,0x22,
+0x00,0xfe,0x24,0x22,0xfe,0x22,0x76,0xaa,0x76,0x22,0x76,0xaa,0x76,0x22,0x2a,0x04,
+/* 31153 0x79b1 "禱" */
+0x40,0x27,0x20,0xfb,0x10,0x17,0x20,0x33,0x68,0xaf,0x20,0x27,0x20,0x27,0x24,0x27,
+0x40,0xfc,0x40,0xfc,0x00,0xfe,0x02,0xf8,0x40,0xfe,0x00,0xfe,0x08,0xfe,0xa8,0x98,
+/* 31154 0x79b2 "禲" */
+0x20,0x13,0x12,0xfb,0x0a,0x12,0x12,0x3a,0x56,0x92,0x12,0x13,0x13,0x15,0x15,0x19,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 31155 0x79b3 "禳" */
+0x20,0x13,0x10,0xf9,0x09,0x11,0x18,0x37,0x50,0x93,0x10,0x17,0x10,0x11,0x16,0x10,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 31156 0x79b4 "禴" */
+0x40,0x20,0x21,0x02,0xf5,0x10,0x2e,0x2a,0x6e,0xb0,0x2f,0x29,0x2f,0x29,0x29,0x28,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xee,0xaa,0xee,0x00,0xfe,0x22,0xfe,0x22,0x2a,0x04,
+/* 31157 0x79b5 "禵" */
+0x40,0x23,0x22,0xfb,0x12,0x13,0x20,0x37,0x69,0xa9,0x25,0x25,0x25,0x25,0x2b,0x30,
+0x00,0xbe,0x88,0x90,0xbe,0xa2,0x3e,0xe2,0x3e,0x22,0xbe,0x14,0x22,0x00,0xfe,0x00,
+/* 31158 0x79b6 "禶" */
+0x45,0x27,0x29,0xff,0x13,0x15,0x29,0x33,0x6a,0xab,0x22,0x23,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 31159 0x79b7 "禷" */
+0x41,0x25,0x23,0xf9,0x17,0x11,0x23,0x35,0x69,0xa8,0x21,0x2f,0x21,0x22,0x24,0x28,
+0x00,0x5e,0x84,0x08,0xde,0x12,0x92,0x5e,0x12,0x1e,0x52,0xf2,0x1e,0x80,0x4c,0x12,
+/* 31160 0x79b8 "禸" */
+0x01,0x01,0x01,0x7f,0x42,0x42,0x44,0x44,0x48,0x5f,0x48,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x44,0x24,0xf4,0x14,0x04,0x04,0x04,0x14,0x08,
+/* 31161 0x79b9 "禹" */
+0x00,0x00,0x3f,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x41,0x41,0x5f,0x48,0x40,0x40,
+0x10,0xf8,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x04,0x24,0xf4,0x14,0x04,0x0c,
+/* 31162 0x79ba "禺" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x7f,0x41,0x41,0x5f,0x48,0x40,0x40,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x24,0xe4,0x24,0x14,0x08,
+/* 31163 0x79bb "离" */
+0x02,0x01,0xff,0x00,0x14,0x13,0x14,0x1f,0x01,0x7f,0x42,0x44,0x4f,0x44,0x40,0x40,
+0x00,0x00,0xfe,0x00,0x50,0x90,0x50,0xf0,0x00,0xfc,0x04,0x44,0xe4,0x24,0x14,0x08,
+/* 31164 0x79bc "禼" */
+0x01,0x01,0x01,0x1f,0x14,0x13,0x14,0x1f,0x01,0x7f,0x42,0x44,0x4f,0x44,0x40,0x40,
+0x00,0xfc,0x00,0xf0,0x50,0x90,0x50,0xf0,0x00,0xfc,0x04,0x44,0xe4,0x24,0x14,0x08,
+/* 31165 0x79bd "禽" */
+0x01,0x02,0x0c,0x31,0xcf,0x04,0x13,0x14,0x1f,0x01,0x7f,0x42,0x44,0x4f,0x44,0x40,
+0x00,0x80,0x60,0x18,0xe6,0x40,0x90,0x50,0xf0,0x00,0xfc,0x04,0x44,0xe4,0x24,0x0c,
+/* 31166 0x79be "禾" */
+0x00,0x00,0x3f,0x01,0x01,0x01,0x7f,0x03,0x05,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x10,0xf8,0x00,0x00,0x00,0x00,0xfc,0x80,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 31167 0x79bf "禿" */
+0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xc0,0x04,0x04,0x04,0x04,0x08,0x10,0x60,
+0x70,0x80,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0x40,0x40,0x40,0x40,0x42,0x42,0x3e,
+/* 31168 0x79c0 "秀" */
+0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xcf,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x70,0x80,0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x20,0x40,0x78,0x08,0x08,0x50,0x20,
+/* 31169 0x79c1 "私" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x89,0x08,0x08,0x08,
+0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x40,0x40,0x48,0x84,0x84,0xfe,0x82,0x02,0x00,
+/* 31170 0x79c2 "秂" */
+0x00,0x3f,0x01,0x01,0xff,0x05,0x09,0x11,0x20,0xc1,0x01,0x02,0x04,0x08,0x30,0xc0,
+0xf8,0x00,0x00,0x00,0xfe,0x40,0x20,0x10,0x08,0x04,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 31171 0x79c3 "秃" */
+0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xc0,0x0f,0x08,0x08,0x08,0x10,0x20,0x40,
+0x70,0x80,0x00,0x00,0xfc,0x40,0x20,0x18,0x06,0xc0,0x40,0x40,0x44,0x44,0x3c,0x00,
+/* 31172 0x79c4 "秄" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 31173 0x79c5 "秅" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x10,0x30,0x3b,0x54,0x50,0x90,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 31174 0x79c6 "秆" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x10,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 31175 0x79c7 "秇" */
+0x08,0x1c,0xf0,0x10,0x11,0xfc,0x10,0x30,0x39,0x54,0x54,0x90,0x10,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 31176 0x79c8 "秈" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 31177 0x79c9 "秉" */
+0x00,0x3f,0x01,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0xf8,0x00,0x00,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 31178 0x79ca "秊" */
+0x00,0x1f,0x01,0x01,0x7f,0x05,0x09,0x31,0xc0,0x1f,0x01,0x01,0x7f,0x01,0x01,0x01,
+0x70,0x80,0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 31179 0x79cb "秋" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x11,0x32,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 31180 0x79cc "秌" */
+0x10,0x11,0x10,0x14,0x58,0x53,0x50,0x90,0x10,0x11,0x11,0x2a,0x24,0x48,0x40,0x80,
+0x38,0xc0,0x40,0x40,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 31181 0x79cd "种" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 31182 0x79ce "秎" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x12,0x35,0x38,0x54,0x54,0x90,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 31183 0x79cf "秏" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x11,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 31184 0x79d0 "秐" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x54,0x90,0x11,0x13,0x11,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 31185 0x79d1 "科" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x10,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x10,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 31186 0x79d2 "秒" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x11,0x31,0x3a,0x54,0x54,0x90,0x10,0x10,0x10,0x13,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 31187 0x79d3 "秓" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x10,0x31,0x38,0x54,0x54,0x90,0x10,0x10,0x11,0x16,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 31188 0x79d4 "秔" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 31189 0x79d5 "秕" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 31190 0x79d6 "秖" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 31191 0x79d7 "秗" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x13,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x11,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 31192 0x79d8 "秘" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x10,0x3a,0x36,0x52,0x54,0x90,0x11,0x12,0x14,0x10,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 31193 0x79d9 "秙" */
+0x08,0x1c,0xf0,0x10,0x13,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31194 0x79da "秚" */
+0x08,0x1c,0xf1,0x10,0x10,0xfc,0x11,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31195 0x79db "秛" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31196 0x79dc "秜" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 31197 0x79dd "秝" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x91,0x11,0x12,0x10,0x10,
+0x38,0xe0,0x20,0x20,0x20,0xfc,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 31198 0x79de "秞" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 31199 0x79df "租" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 31200 0x79e0 "秠" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x10,0x38,0x35,0x52,0x50,0x90,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 31201 0x79e1 "秡" */
+0x08,0x1c,0xf0,0x10,0x13,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x12,0x12,0x14,0x11,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31202 0x79e2 "秢" */
+0x08,0x1c,0xf0,0x10,0x10,0xfd,0x12,0x30,0x39,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 31203 0x79e3 "秣" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x10,0x31,0x38,0x54,0x54,0x91,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 31204 0x79e4 "秤" */
+0x08,0x1d,0xf0,0x10,0x11,0xfc,0x10,0x30,0x3b,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 31205 0x79e5 "秥" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31206 0x79e6 "秦" */
+0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x10,0x2f,0xc1,0x1f,0x05,0x09,0x11,0x61,0x01,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xd0,0x08,0x06,0xf0,0x40,0x20,0x10,0x08,0x00,
+/* 31207 0x79e7 "秧" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x31,0x39,0x57,0x54,0x90,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 31208 0x79e8 "秨" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x12,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,
+/* 31209 0x79e9 "秩" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x12,0x30,0x39,0x54,0x54,0x90,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 31210 0x79ea "秪" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 31211 0x79eb "秫" */
+0x08,0x1c,0xf0,0x10,0x17,0xfc,0x10,0x38,0x35,0x51,0x52,0x94,0x18,0x10,0x10,0x10,
+0x40,0x50,0x48,0x40,0xfc,0x40,0xe0,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,0x40,
+/* 31212 0x79ec "秬" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 31213 0x79ed "秭" */
+0x08,0x1c,0xf0,0x11,0x11,0xfd,0x11,0x39,0x34,0x54,0x50,0x91,0x16,0x10,0x10,0x10,
+0x20,0x20,0x2e,0xf0,0x20,0x20,0x20,0xfe,0x22,0x62,0xa2,0x2a,0x24,0x20,0x20,0x20,
+/* 31214 0x79ee "秮" */
+0x08,0x1c,0xf0,0x10,0x10,0xfd,0x13,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31215 0x79ef "积" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 31216 0x79f0 "称" */
+0x08,0x1c,0xf0,0x10,0x11,0xfd,0x12,0x30,0x38,0x54,0x51,0x91,0x12,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 31217 0x79f1 "秱" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 31218 0x79f2 "秲" */
+0x08,0x1c,0xf0,0x11,0x10,0xfc,0x13,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 31219 0x79f3 "秳" */
+0x08,0x1c,0xf1,0x10,0x10,0xfd,0x10,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31220 0x79f4 "秴" */
+0x08,0x1c,0xf0,0x10,0x11,0xfe,0x11,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31221 0x79f5 "秵" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 31222 0x79f6 "秶" */
+0x01,0x41,0x21,0x0a,0x14,0xe0,0x21,0x26,0x00,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0x00,0xfc,0x44,0x48,0xa0,0x10,0x08,0xe0,0x00,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 31223 0x79f7 "秷" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x11,0x30,0x38,0x54,0x55,0x90,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 31224 0x79f8 "秸" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x11,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31225 0x79f9 "秹" */
+0x00,0x18,0x70,0x11,0x11,0xfb,0x15,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x11,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 31226 0x79fa "秺" */
+0x08,0x1c,0xf3,0x12,0x10,0xfc,0x13,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x00,0x38,0xc0,0x40,0x40,0x7c,0xc0,0x40,0x42,0x42,0x3e,0x00,
+/* 31227 0x79fb "移" */
+0x08,0x1c,0xf0,0x10,0x11,0xfc,0x10,0x30,0x39,0x54,0x54,0x91,0x10,0x10,0x10,0x11,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 31228 0x79fc "秼" */
+0x08,0x1d,0xf1,0x11,0x11,0xfe,0x10,0x33,0x38,0x54,0x50,0x91,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 31229 0x79fd "秽" */
+0x08,0x1d,0xf1,0x11,0x11,0xfc,0x10,0x38,0x35,0x52,0x50,0x90,0x10,0x10,0x10,0x13,
+0x20,0x24,0x24,0x24,0xfc,0x40,0x40,0xfc,0x04,0x84,0x48,0x50,0x20,0x40,0x80,0x00,
+/* 31230 0x79fe "秾" */
+0x08,0x1c,0xf0,0x13,0x12,0xfc,0x10,0x38,0x35,0x52,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x42,0x44,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 31231 0x79ff "秿" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 31232 0x7a00 "稀" */
+0x09,0x1c,0xf0,0x10,0x13,0xfc,0x13,0x38,0x35,0x53,0x55,0x91,0x11,0x11,0x10,0x10,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 31233 0x7a01 "稁" */
+0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x80,0x1f,0x01,0xff,0x05,0x19,0xe1,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0x74,0x80,0x00,0xfe,0x40,0x30,0x0e,
+/* 31234 0x7a02 "稂" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 31235 0x7a03 "稃" */
+0x08,0x1c,0xf1,0x10,0x11,0xfc,0x10,0x39,0x34,0x50,0x53,0x90,0x10,0x10,0x10,0x10,
+0x04,0x1e,0xe0,0x02,0x22,0x94,0x00,0xfc,0x08,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 31236 0x7a04 "稄" */
+0x08,0x1c,0xf0,0x11,0x13,0xfc,0x10,0x31,0x3a,0x54,0x51,0x92,0x10,0x10,0x11,0x16,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 31237 0x7a05 "稅" */
+0x08,0x1c,0xf0,0x11,0x12,0xfd,0x11,0x31,0x39,0x55,0x54,0x90,0x10,0x11,0x12,0x14,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 31238 0x7a06 "稆" */
+0x08,0x1c,0xf0,0x10,0x10,0xfc,0x10,0x38,0x34,0x55,0x51,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfe,0x02,
+/* 31239 0x7a07 "稇" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x64,0x74,0xac,0x24,0x24,0x24,0x04,0xfc,0x04,
+/* 31240 0x7a08 "稈" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x38,0x35,0x54,0x50,0x93,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 31241 0x7a09 "稉" */
+0x08,0x1d,0xf0,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x10,0x13,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 31242 0x7a0a "稊" */
+0x09,0x1c,0xf0,0x11,0x10,0xfc,0x11,0x31,0x39,0x55,0x54,0x90,0x11,0x12,0x14,0x10,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 31243 0x7a0b "程" */
+0x00,0x0d,0xf1,0x11,0x11,0xfd,0x10,0x38,0x35,0x54,0x50,0x91,0x10,0x10,0x10,0x17,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,
+/* 31244 0x7a0c "稌" */
+0x08,0x1c,0xf0,0x10,0x11,0xfe,0x10,0x30,0x3b,0x54,0x55,0x91,0x12,0x14,0x10,0x10,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 31245 0x7a0d "稍" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 31246 0x7a0e "税" */
+0x09,0x1c,0xf0,0x10,0x11,0xfd,0x11,0x31,0x39,0x54,0x54,0x90,0x10,0x11,0x12,0x14,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 31247 0x7a0f "稏" */
+0x08,0x1d,0xf0,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x50,0x90,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x48,0x48,0x48,0xce,0x02,0x02,0x02,0xce,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 31248 0x7a10 "稐" */
+0x08,0x1c,0xf0,0x10,0x11,0xfe,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 31249 0x7a11 "稑" */
+0x08,0x1c,0xf1,0x10,0x10,0xfd,0x10,0x31,0x3a,0x54,0x51,0x90,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 31250 0x7a12 "稒" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 31251 0x7a13 "稓" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x17,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 31252 0x7a14 "稔" */
+0x08,0x1c,0xf0,0x10,0x11,0xfe,0x11,0x38,0x34,0x54,0x50,0x92,0x12,0x12,0x14,0x10,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 31253 0x7a15 "稕" */
+0x08,0x1c,0xf3,0x10,0x11,0xfd,0x11,0x38,0x35,0x54,0x50,0x93,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 31254 0x7a16 "稖" */
+0x08,0x1c,0xf1,0x10,0x11,0xfc,0x10,0x33,0x38,0x54,0x55,0x91,0x11,0x11,0x11,0x11,
+0x80,0x40,0xfc,0x00,0x08,0x88,0x90,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 31255 0x7a17 "稗" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x39,0x35,0x54,0x51,0x93,0x10,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 31256 0x7a18 "稘" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x10,0x38,0x34,0x54,0x50,0x93,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 31257 0x7a19 "稙" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfe,0x00,
+/* 31258 0x7a1a "稚" */
+0x08,0x1c,0xf0,0x11,0x11,0xff,0x15,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0xa0,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 31259 0x7a1b "稛" */
+0x10,0x3b,0xe2,0x22,0x22,0xfa,0x22,0x33,0x6a,0x62,0xa2,0x23,0x22,0x22,0x23,0x22,
+0x00,0xfe,0x02,0x1a,0xe2,0x22,0x22,0xfe,0x22,0x72,0xaa,0x26,0x22,0x22,0xfe,0x02,
+/* 31260 0x7a1c "稜" */
+0x10,0x38,0xe1,0x20,0x20,0xfb,0x20,0x31,0x6a,0x60,0xa1,0x22,0x20,0x20,0x21,0x26,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 31261 0x7a1d "稝" */
+0x10,0x3b,0xe2,0x22,0x22,0xfb,0x22,0x32,0x6a,0x63,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 31262 0x7a1e "稞" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x38,0x57,0x54,0x90,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 31263 0x7a1f "稟" */
+0x01,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,0x00,0x1f,0x01,0xff,0x09,0x71,
+0x00,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x00,0xf0,0x00,0xfe,0x20,0x1c,
+/* 31264 0x7a20 "稠" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 31265 0x7a21 "稡" */
+0x08,0x1c,0xf3,0x10,0x10,0xfc,0x11,0x32,0x38,0x54,0x53,0x90,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31266 0x7a22 "稢" */
+0x10,0x38,0xe0,0x27,0x20,0xf8,0x23,0x32,0x6a,0x62,0xa3,0x20,0x20,0x27,0x22,0x20,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xea,0x1a,0x26,0x42,
+/* 31267 0x7a23 "稣" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x01,0x1c,0xe0,0x40,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x70,0x68,0xa8,0xa4,0x22,0x20,0x20,0x20,
+/* 31268 0x7a24 "稤" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x11,0x31,0x39,0x54,0x55,0x91,0x12,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 31269 0x7a25 "稥" */
+0x00,0x1f,0x01,0x7f,0x05,0x09,0x31,0xc0,0x14,0x22,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x70,0x80,0x00,0xfc,0x40,0x20,0x18,0x06,0x90,0x48,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 31270 0x7a26 "稦" */
+0x08,0x1c,0xf1,0x10,0x13,0xfc,0x11,0x39,0x35,0x50,0x53,0x90,0x12,0x13,0x10,0x10,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 31271 0x7a27 "稧" */
+0x08,0x1c,0xf3,0x10,0x11,0xfc,0x13,0x38,0x34,0x50,0x53,0x90,0x10,0x10,0x11,0x16,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 31272 0x7a28 "稨" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x39,0x35,0x55,0x51,0x92,0x12,0x12,0x14,0x10,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 31273 0x7a29 "稩" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 31274 0x7a2a "稪" */
+0x09,0x1d,0xf1,0x12,0x15,0xfd,0x11,0x31,0x39,0x54,0x54,0x91,0x12,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 31275 0x7a2b "稫" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x10,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 31276 0x7a2c "稬" */
+0x08,0x1d,0xf0,0x10,0x11,0xfd,0x11,0x39,0x35,0x55,0x50,0x93,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x20,0x40,0xfc,0x54,0x54,0x54,0x44,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 31277 0x7a2d "稭" */
+0x09,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 31278 0x7a2e "種" */
+0x08,0x1c,0xf1,0x10,0x13,0xfc,0x11,0x31,0x39,0x55,0x55,0x90,0x11,0x10,0x13,0x10,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 31279 0x7a2f "稯" */
+0x08,0x1c,0xf2,0x12,0x12,0xfe,0x12,0x3b,0x34,0x51,0x52,0x90,0x11,0x10,0x10,0x17,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 31280 0x7a30 "稰" */
+0x08,0x1d,0xf0,0x10,0x10,0xfc,0x11,0x32,0x38,0x54,0x50,0x90,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x12,0x90,0x9c,0x90,0x7e,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 31281 0x7a31 "稱" */
+0x08,0x1d,0xf0,0x11,0x10,0xfc,0x11,0x39,0x35,0x55,0x51,0x91,0x13,0x11,0x11,0x11,
+0x1e,0xe0,0x44,0x24,0x88,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfe,0x04,0x14,0x08,
+/* 31282 0x7a32 "稲" */
+0x08,0x1c,0xf1,0x10,0x11,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x3e,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,
+/* 31283 0x7a33 "稳" */
+0x08,0x1c,0xf1,0x12,0x11,0xfc,0x10,0x39,0x34,0x54,0x51,0x90,0x10,0x12,0x12,0x14,
+0x40,0xf8,0x08,0x10,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x40,0x24,0xa2,0x8a,0x78,
+/* 31284 0x7a34 "稴" */
+0x08,0x1c,0xf0,0x11,0x10,0xfd,0x10,0x33,0x38,0x55,0x54,0x90,0x11,0x12,0x10,0x10,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 31285 0x7a35 "稵" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x11,0x31,0x3a,0x57,0x50,0x91,0x11,0x12,0x13,0x10,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 31286 0x7a36 "稶" */
+0x08,0x1c,0xf0,0x13,0x10,0xfc,0x13,0x32,0x3a,0x56,0x53,0x90,0x10,0x17,0x10,0x10,
+0x14,0x12,0x10,0xfe,0x14,0x18,0x90,0xb4,0x98,0x90,0xb2,0x0c,0xca,0x1a,0x66,0x02,
+/* 31287 0x7a37 "稷" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x31,0x3a,0x54,0x51,0x92,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 31288 0x7a38 "稸" */
+0x08,0x1c,0xf3,0x10,0x10,0xfd,0x10,0x30,0x39,0x54,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x40,0x88,0xf0,0x20,0x44,0xfe,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 31289 0x7a39 "稹" */
+0x08,0x1c,0xf3,0x10,0x11,0xfd,0x11,0x39,0x35,0x55,0x51,0x91,0x17,0x10,0x11,0x12,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 31290 0x7a3a "稺" */
+0x10,0x3b,0xe2,0x22,0x23,0xfa,0x22,0x33,0x6a,0x62,0xa3,0x22,0x25,0x24,0x28,0x20,
+0x00,0xfc,0x04,0x04,0xfc,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x20,
+/* 31291 0x7a3b "稻" */
+0x08,0x1d,0xf0,0x11,0x10,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 31292 0x7a3c "稼" */
+0x08,0x1c,0xf3,0x12,0x10,0xfd,0x10,0x30,0x3b,0x54,0x50,0x93,0x10,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 31293 0x7a3d "稽" */
+0x08,0x1c,0xf3,0x10,0x11,0xfe,0x11,0x31,0x39,0x54,0x54,0x91,0x11,0x11,0x11,0x11,
+0x50,0x48,0xfc,0xa0,0x22,0x1e,0x10,0xe0,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,
+/* 31294 0x7a3e "稾" */
+0x01,0x7f,0x08,0x0f,0x00,0x7f,0x48,0x4f,0x40,0x5f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x00,0xfc,0x20,0xe0,0x00,0xfc,0x24,0xe4,0x04,0xec,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 31295 0x7a3f "稿" */
+0x08,0x1c,0xf3,0x10,0x11,0xfd,0x11,0x38,0x37,0x52,0x52,0x92,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x14,0x08,
+/* 31296 0x7a40 "穀" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x10,0xfe,0x38,0x54,0x92,0x11,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31297 0x7a41 "穁" */
+0x08,0x1c,0xf1,0x10,0x10,0xfd,0x10,0x30,0x38,0x54,0x54,0x90,0x10,0x11,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x88,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 31298 0x7a42 "穂" */
+0x08,0x1c,0xf3,0x10,0x11,0xfd,0x11,0x39,0x35,0x54,0x50,0x92,0x12,0x14,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 31299 0x7a43 "穃" */
+0x08,0x1c,0xf3,0x12,0x10,0xfc,0x11,0x30,0x38,0x55,0x52,0x90,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 31300 0x7a44 "穄" */
+0x11,0x39,0xe3,0x22,0x25,0xfa,0x21,0x32,0x6c,0x60,0xa3,0x20,0x21,0x22,0x25,0x20,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 31301 0x7a45 "穅" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x39,0x35,0x55,0x51,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 31302 0x7a46 "穆" */
+0x08,0x1c,0xf1,0x11,0x11,0xfd,0x11,0x38,0x35,0x56,0x50,0x93,0x10,0x11,0x10,0x13,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0x32,0xc0,0x18,0x60,0x8c,0x30,0xc0,
+/* 31303 0x7a47 "穇" */
+0x10,0x38,0xe1,0x21,0x22,0xfb,0x20,0x31,0x6e,0x60,0xa3,0x20,0x23,0x20,0x20,0x27,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 31304 0x7a48 "穈" */
+0x01,0x00,0x3f,0x22,0x2f,0x26,0x2b,0x32,0x20,0x27,0x20,0x2f,0x21,0x42,0x4c,0x80,
+0x00,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x38,0xc0,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 31305 0x7a49 "穉" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x11,0x39,0x35,0x55,0x51,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x02,0xfe,0x10,0x54,0x38,0x54,0x82,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,
+/* 31306 0x7a4a "穊" */
+0x10,0xe7,0x24,0x24,0x27,0xfc,0x24,0x37,0x6c,0x65,0xa4,0x25,0x26,0x24,0x20,0x20,
+0x00,0xbe,0x88,0x88,0xa8,0xa8,0xa8,0xbe,0x10,0x18,0x98,0xa8,0xaa,0x4a,0x46,0x80,
+/* 31307 0x7a4b "穋" */
+0x10,0x3b,0xe0,0x22,0x21,0xfa,0x20,0x30,0x6b,0x60,0xa1,0x20,0x21,0x20,0x20,0x23,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 31308 0x7a4c "穌" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x70,0x68,0xa8,0xa4,0x22,0x20,0x20,0x20,
+/* 31309 0x7a4d "積" */
+0x08,0x1d,0xf0,0x11,0x10,0xfd,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 31310 0x7a4e "穎" */
+0x40,0x4c,0x70,0x44,0x44,0x3c,0x00,0x0c,0x70,0x10,0xfe,0x10,0x38,0x54,0x90,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 31311 0x7a4f "穏" */
+0x08,0x1c,0xf1,0x10,0x11,0xfc,0x11,0x30,0x38,0x54,0x55,0x90,0x10,0x12,0x12,0x14,
+0x08,0x3c,0xc0,0x44,0x24,0xa8,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0xaa,0x8a,0x78,
+/* 31312 0x7a50 "穐" */
+0x11,0xe1,0x22,0x27,0x2a,0xfb,0x22,0x33,0x68,0x67,0xa4,0x27,0x24,0x27,0x20,0x20,
+0x00,0xf0,0x20,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x44,0xfc,0x44,0xfe,0x42,0x3e,
+/* 31313 0x7a51 "穑" */
+0x08,0x1c,0xf3,0x10,0x11,0xfc,0x13,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x20,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 31314 0x7a52 "穒" */
+0x00,0x1f,0x01,0xff,0x05,0x19,0xe2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x70,0x80,0x00,0xfe,0x40,0x30,0x0e,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 31315 0x7a53 "穓" */
+0x10,0x3b,0xe2,0x23,0x22,0xfb,0x20,0x30,0x6b,0x60,0xa0,0x27,0x20,0x20,0x21,0x22,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 31316 0x7a54 "穔" */
+0x00,0x18,0x71,0x10,0x10,0xfb,0x10,0x31,0x39,0x55,0x51,0x91,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 31317 0x7a55 "穕" */
+0x08,0x1c,0xf1,0x13,0x11,0xfd,0x11,0x39,0x35,0x55,0x50,0x93,0x10,0x10,0x13,0x10,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 31318 0x7a56 "穖" */
+0x01,0x19,0x72,0x13,0x11,0xfa,0x13,0x31,0x3b,0x55,0x51,0x91,0x12,0x12,0x12,0x14,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 31319 0x7a57 "穗" */
+0x08,0x1c,0xf3,0x10,0x11,0xfd,0x11,0x39,0x35,0x50,0x53,0x90,0x10,0x12,0x12,0x14,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 31320 0x7a58 "穘" */
+0x08,0x1c,0xf1,0x10,0x13,0xfd,0x13,0x31,0x39,0x56,0x50,0x93,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 31321 0x7a59 "穙" */
+0x08,0x1e,0xf1,0x10,0x13,0xfc,0x10,0x33,0x38,0x55,0x50,0x93,0x10,0x10,0x11,0x16,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 31322 0x7a5a "穚" */
+0x08,0x1d,0xf0,0x13,0x10,0xfd,0x12,0x30,0x38,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 31323 0x7a5b "穛" */
+0x08,0x1c,0xf1,0x11,0x13,0xfd,0x11,0x39,0x35,0x55,0x51,0x91,0x11,0x12,0x12,0x14,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 31324 0x7a5c "穜" */
+0x08,0x1d,0xf0,0x10,0x13,0xfc,0x11,0x31,0x39,0x55,0x55,0x90,0x11,0x10,0x13,0x10,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 31325 0x7a5d "穝" */
+0x10,0x39,0xe1,0x21,0x21,0xf9,0x20,0x37,0x6a,0x63,0xa2,0x23,0x22,0x27,0x20,0x20,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0xdc,0x54,0xd4,0x68,0xc8,0x54,0x62,
+/* 31326 0x7a5e "穞" */
+0x08,0x1c,0xf1,0x13,0x15,0xfd,0x11,0x31,0x38,0x57,0x54,0x91,0x11,0x11,0x11,0x11,
+0x80,0xf8,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,
+/* 31327 0x7a5f "穟" */
+0x10,0xe4,0x22,0x20,0x20,0xf8,0x26,0x32,0x6a,0x62,0xa2,0x22,0x22,0x22,0x25,0x28,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 31328 0x7a60 "穠" */
+0x08,0x1d,0xf1,0x11,0x11,0xfd,0x10,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x12,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfe,0x00,0x7c,0x00,0xfe,0x50,0x54,0x48,0x66,
+/* 31329 0x7a61 "穡" */
+0x00,0x18,0x73,0x11,0x11,0xfa,0x17,0x30,0x39,0x55,0x51,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0xfe,0x24,0x24,0xaa,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 31330 0x7a62 "穢" */
+0x08,0x1d,0xf1,0x17,0x10,0xfc,0x13,0x32,0x3b,0x56,0x52,0x92,0x13,0x14,0x18,0x13,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 31331 0x7a63 "穣" */
+0x10,0x38,0xe7,0x21,0x22,0xfd,0x23,0x31,0x6b,0x61,0xa7,0x21,0x23,0x2d,0x21,0x21,
+0x80,0x40,0xfe,0x10,0x08,0x14,0xf8,0x10,0xf8,0x10,0xfc,0x28,0x10,0x48,0x86,0x00,
+/* 31332 0x7a64 "穤" */
+0x08,0x1d,0xf0,0x13,0x12,0xfd,0x10,0x31,0x38,0x57,0x50,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 31333 0x7a65 "穥" */
+0x11,0x3a,0xe2,0x22,0x23,0xfa,0x22,0x33,0x6a,0x62,0xa7,0x20,0x21,0x21,0x22,0x24,
+0x40,0x4c,0x64,0x44,0x4c,0x64,0xa4,0xac,0xa4,0xa4,0xfe,0x00,0x10,0x08,0x04,0x04,
+/* 31334 0x7a66 "穦" */
+0x08,0x1c,0xf3,0x12,0x11,0xfd,0x12,0x39,0x37,0x55,0x51,0x91,0x11,0x11,0x10,0x11,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 31335 0x7a67 "穧" */
+0x10,0x38,0xe7,0x21,0x20,0xff,0x25,0x35,0x6b,0x60,0xa2,0x23,0x22,0x23,0x22,0x24,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 31336 0x7a68 "穨" */
+0x0c,0x71,0x11,0xfd,0x10,0x3b,0x54,0x91,0x01,0x39,0x29,0x29,0x29,0x4d,0x48,0x81,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 31337 0x7a69 "穩" */
+0x10,0xe7,0x22,0x21,0x23,0xf8,0x27,0x30,0x6b,0x60,0xa3,0x20,0x23,0x25,0x25,0x28,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 31338 0x7a6a "穪" */
+0x10,0x3b,0xe1,0x22,0x27,0xfa,0x23,0x32,0x6b,0x62,0xa3,0x22,0x23,0x22,0x22,0x22,
+0x00,0xfe,0x24,0x22,0xfe,0x22,0x76,0xaa,0x76,0x22,0x76,0xaa,0x76,0x22,0x2a,0x04,
+/* 31339 0x7a6b "穫" */
+0x00,0x1b,0x70,0x10,0x11,0xfb,0x11,0x31,0x39,0x55,0x51,0x91,0x13,0x10,0x10,0x13,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 31340 0x7a6c "穬" */
+0x10,0x38,0xe7,0x24,0x25,0xfc,0x27,0x34,0x6d,0x65,0xa5,0x25,0x25,0x24,0x24,0x29,
+0x40,0x20,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,
+/* 31341 0x7a6d "穭" */
+0x08,0x1d,0xf2,0x15,0x11,0xfd,0x11,0x31,0x39,0x56,0x55,0x91,0x11,0x11,0x11,0x11,
+0x80,0xf8,0x08,0xfc,0x24,0xfc,0x24,0xfc,0x54,0x2a,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 31342 0x7a6e "穮" */
+0x08,0x1c,0xf3,0x12,0x13,0xfe,0x13,0x32,0x3a,0x56,0x52,0x92,0x12,0x14,0x15,0x1a,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 31343 0x7a6f "穯" */
+0x00,0x1b,0x70,0x13,0x12,0xfb,0x10,0x33,0x38,0x57,0x52,0x92,0x12,0x12,0x12,0x13,
+0x20,0xfe,0x20,0xae,0xaa,0xae,0x20,0xfe,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0xfe,
+/* 31344 0x7a70 "穰" */
+0x10,0xe7,0x20,0x23,0x22,0xfb,0x21,0x37,0x69,0x67,0xa1,0x2f,0x21,0x23,0x2d,0x21,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 31345 0x7a71 "穱" */
+0x00,0x1b,0x71,0x10,0x13,0xfa,0x13,0x30,0x3b,0x56,0x53,0x92,0x13,0x12,0x12,0x13,
+0x1e,0xe0,0x22,0x94,0xfe,0x52,0xfe,0x04,0xc4,0x7e,0xc4,0x54,0xcc,0x84,0xd4,0x48,
+/* 31346 0x7a72 "穲" */
+0x13,0x38,0xe3,0x22,0x23,0xfa,0x20,0x33,0x6a,0x63,0xa2,0x23,0x22,0x22,0x22,0x24,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 31347 0x7a73 "穳" */
+0x15,0xe7,0x29,0x27,0x23,0xfd,0x29,0x33,0x6a,0x63,0xa2,0x23,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 31348 0x7a74 "穴" */
+0x02,0x01,0x01,0x7f,0x40,0x80,0x04,0x04,0x04,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x00,0x00,0xfe,0x02,0x44,0x40,0x40,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x02,
+/* 31349 0x7a75 "穵" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x20,0x1f,0x00,0x03,0x04,0x08,0x10,0x10,0x0f,0x00,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0xe0,0xc0,0x00,0x00,0x00,0x08,0x08,0xf8,0x00,
+/* 31350 0x7a76 "究" */
+0x02,0x01,0x7f,0x40,0x88,0x12,0x22,0x02,0x3f,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xe0,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 31351 0x7a77 "穷" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x22,0x02,0x7f,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 31352 0x7a78 "穸" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x22,0x04,0x0f,0x10,0x68,0x04,0x02,0x03,0x1c,0xe0,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 31353 0x7a79 "穹" */
+0x02,0x01,0x7f,0x48,0x90,0x2f,0x00,0x00,0x1f,0x10,0x20,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 31354 0x7a7a "空" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x20,0x00,0x1f,0x01,0x01,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 31355 0x7a7b "穻" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x2f,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x05,0x02,
+0x00,0x00,0xfe,0x02,0x24,0x10,0xe8,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 31356 0x7a7c "穼" */
+0x02,0x01,0x7f,0x40,0x88,0x10,0x21,0x01,0x7f,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0xfc,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 31357 0x7a7d "穽" */
+0x02,0x01,0x7f,0x48,0x90,0x28,0x08,0x3f,0x08,0x08,0x08,0xff,0x08,0x10,0x10,0x20,
+0x00,0x00,0xfe,0x22,0x14,0x28,0x20,0xf8,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 31358 0x7a7e "穾" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x00,0x3f,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xf0,0x00,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 31359 0x7a7f "穿" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x3f,0x00,0x10,0x20,0x3f,0x01,0x06,0x18,0x61,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x80,
+/* 31360 0x7a80 "窀" */
+0x02,0x01,0x7f,0x48,0x91,0x21,0xff,0x01,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xfe,0x00,0x08,0x08,0x08,0xf8,0x0a,0x02,0x02,0xfe,
+/* 31361 0x7a81 "突" */
+0x02,0x01,0x7f,0x40,0x88,0x11,0x21,0x01,0x01,0x7f,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfe,0x02,0x24,0x10,0x48,0x20,0x00,0xfc,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 31362 0x7a82 "窂" */
+0x02,0x01,0x7f,0x48,0x90,0x21,0x11,0x1f,0x21,0x41,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 31363 0x7a83 "窃" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x21,0x2c,0xf0,0x20,0x20,0x24,0x28,0x31,0x22,0x04,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 31364 0x7a84 "窄" */
+0x02,0x01,0x7f,0x48,0x90,0x28,0x0f,0x14,0x24,0x47,0x04,0x04,0x07,0x04,0x04,0x04,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xf8,0x00,0x00,0xf0,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 31365 0x7a85 "窅" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 31366 0x7a86 "窆" */
+0x02,0x01,0x7f,0x48,0x90,0x01,0x3e,0x02,0x01,0x7f,0x00,0x01,0x0e,0x30,0x48,0x87,
+0x00,0x00,0xfe,0x22,0x14,0xf0,0x00,0x00,0x00,0xf8,0x60,0x80,0x00,0x00,0x00,0xfe,
+/* 31367 0x7a87 "窇" */
+0x02,0x01,0x7f,0x48,0x90,0x08,0x1f,0x20,0x5f,0x10,0x10,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x50,0x24,0x04,0xfc,
+/* 31368 0x7a88 "窈" */
+0x02,0x01,0x7f,0x48,0x90,0x08,0x08,0x12,0x22,0x7c,0x08,0x14,0x22,0x7e,0x21,0x02,
+0x00,0x00,0xfe,0x22,0x14,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 31369 0x7a89 "窉" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x1f,0x01,0x01,0x3f,0x21,0x22,0x24,0x28,0x20,0x20,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xf0,0x00,0x00,0xf8,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 31370 0x7a8a "窊" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x1f,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x82,
+0x00,0x00,0xfe,0x22,0x14,0x78,0xa0,0x20,0x20,0x20,0x10,0x90,0x48,0xa8,0x24,0x02,
+/* 31371 0x7a8b "窋" */
+0x02,0x01,0x7f,0x48,0x90,0x21,0x11,0x11,0x11,0x1f,0x01,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x10,0x10,0x10,0xf0,0x00,0x08,0x08,0x08,0xf8,0x08,
+/* 31372 0x7a8c "窌" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x0c,0x70,0x40,0x44,0x44,0x5c,0x64,0x48,0x08,0x10,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,
+/* 31373 0x7a8d "窍" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x00,0x7d,0x10,0x10,0x11,0x10,0x1e,0xe0,0x40,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,
+/* 31374 0x7a8e "窎" */
+0x02,0x01,0x7f,0x48,0x91,0x22,0x1f,0x10,0x12,0x11,0x10,0x1f,0x00,0x00,0x7f,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0xf0,0x10,0x10,0x50,0x20,0xfc,0x04,0x04,0xd4,0x08,
+/* 31375 0x7a8f "窏" */
+0x02,0x01,0x7f,0x48,0x90,0x10,0x09,0x48,0x20,0x20,0x0b,0x10,0x70,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 31376 0x7a90 "窐" */
+0x02,0x01,0x7f,0x48,0x90,0x01,0x3f,0x01,0x01,0xff,0x00,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 31377 0x7a91 "窑" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x08,0x1f,0x21,0x01,0xff,0x01,0x21,0x21,0x3f,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,0x08,0x08,0xf8,0x08,
+/* 31378 0x7a92 "窒" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x7f,0x04,0x08,0x1f,0x01,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x00,0x20,0xf0,0x10,0x00,0xf8,0x00,0x00,0xfe,
+/* 31379 0x7a93 "窓" */
+0x02,0x01,0x7f,0x48,0x92,0x24,0x08,0x10,0x3f,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x20,0x10,0xf8,0x08,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 31380 0x7a94 "窔" */
+0x02,0x01,0x7f,0x48,0x92,0x01,0x7f,0x08,0x10,0x24,0x44,0x02,0x01,0x06,0x18,0xe0,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x20,0x10,0x48,0x44,0x80,0x00,0xc0,0x30,0x0e,
+/* 31381 0x7a95 "窕" */
+0x02,0x01,0x7f,0x48,0x90,0x04,0x44,0x24,0x24,0x0c,0x34,0xc8,0x08,0x10,0x20,0x40,
+0x00,0x00,0xfe,0x22,0x14,0x40,0x48,0x50,0x60,0x40,0x60,0x52,0x4a,0x42,0x3e,0x00,
+/* 31382 0x7a96 "窖" */
+0x02,0x01,0x7f,0x48,0x91,0x09,0x0f,0x11,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf0,0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 31383 0x7a97 "窗" */
+0x02,0x01,0x7f,0x48,0x92,0x04,0x3f,0x22,0x23,0x24,0x2a,0x21,0x22,0x24,0x3f,0x20,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf8,0x08,0xc8,0x48,0x88,0x08,0x88,0x08,0xf8,0x08,
+/* 31384 0x7a98 "窘" */
+0x02,0x01,0x7f,0x48,0x90,0x3f,0x04,0xff,0x04,0x3f,0x08,0x1f,0x28,0x48,0x8f,0x08,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 31385 0x7a99 "窙" */
+0x02,0x01,0x7f,0x48,0x91,0x0f,0x01,0xff,0x01,0x1f,0x08,0x30,0xcf,0x00,0x02,0x01,
+0x00,0x00,0xfe,0x22,0x1c,0xd0,0x20,0xfe,0x00,0xf0,0x20,0xc0,0xfc,0x80,0x80,0x00,
+/* 31386 0x7a9a "窚" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x2a,0x44,0x41,0x86,
+0x00,0x00,0xfe,0x22,0x94,0x88,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 31387 0x7a9b "窛" */
+0x02,0x01,0x7f,0x48,0x90,0x20,0x3e,0x01,0x00,0x7e,0x14,0x14,0x14,0x25,0x24,0x43,
+0x00,0x00,0xfe,0x22,0x14,0x08,0x20,0xfe,0x24,0x44,0xe8,0x10,0x6a,0x86,0x02,0xfe,
+/* 31388 0x7a9c "窜" */
+0x02,0x01,0x7f,0x48,0x91,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x41,0x7f,0x41,0x01,0x01,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xfc,0x04,0x00,0x00,
+/* 31389 0x7a9d "窝" */
+0x02,0x01,0x7f,0x48,0x90,0x2f,0x08,0x08,0x0f,0x01,0x3f,0x21,0x22,0x24,0x20,0x20,
+0x00,0x00,0xfe,0x22,0x14,0xe8,0x20,0x20,0xe0,0x00,0xf8,0x08,0x88,0x48,0x08,0x18,
+/* 31390 0x7a9e "窞" */
+0x02,0x01,0x7f,0x48,0x94,0x27,0x08,0x10,0x26,0x18,0x10,0x1e,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x22,0x14,0xe8,0x20,0x40,0x78,0x08,0x08,0x78,0x08,0x08,0xf8,0x08,
+/* 31391 0x7a9f "窟" */
+0x02,0x01,0x7f,0x48,0x90,0x3f,0x20,0x3f,0x20,0x24,0x24,0x27,0x20,0x48,0x48,0x8f,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x80,0x90,0x90,0xf0,0x80,0x88,0x88,0xf8,
+/* 31392 0x7aa0 "窠" */
+0x02,0x01,0x7f,0x48,0x90,0x3f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 31393 0x7aa1 "窡" */
+0x01,0x7f,0x48,0x90,0x3e,0x02,0x14,0x08,0x14,0x62,0x3e,0x02,0x14,0x08,0x34,0xc2,
+0x00,0xfe,0x22,0x14,0xf8,0x08,0xd0,0x20,0x50,0x88,0xf8,0x88,0x50,0x20,0x58,0x86,
+/* 31394 0x7aa2 "窢" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x00,0xff,0x00,0x3e,0x22,0x3e,0x00,0x0e,0x70,0x03,
+0x00,0x00,0xfe,0x22,0x14,0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x02,
+/* 31395 0x7aa3 "窣" */
+0x02,0x01,0x7f,0x48,0x92,0x01,0x7f,0x08,0x14,0x22,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x20,0x50,0x88,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 31396 0x7aa4 "窤" */
+0x02,0x01,0x7f,0x48,0x90,0x3f,0x10,0x1f,0x10,0x1f,0x20,0x20,0x3e,0x20,0x26,0x38,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x8c,0xf0,0x82,0x82,0x7e,
+/* 31397 0x7aa5 "窥" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x11,0x7d,0x11,0x11,0xfd,0x11,0x28,0x24,0x41,0x86,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xfc,0x04,0x24,0x24,0x24,0x54,0x50,0x90,0x12,0x0e,
+/* 31398 0x7aa6 "窦" */
+0x02,0x01,0x7f,0x48,0x91,0x2f,0x01,0x7f,0x04,0x12,0x09,0xff,0x02,0x04,0x18,0x60,
+0x00,0x00,0xfe,0x22,0x14,0xe8,0x00,0xfc,0x84,0x88,0x00,0xfe,0x60,0x10,0x08,0x04,
+/* 31399 0x7aa7 "窧" */
+0x02,0x01,0x7f,0x48,0x91,0x01,0x01,0x3f,0x20,0x3f,0x20,0x3f,0x01,0xff,0x01,0x01,
+0x00,0x00,0xfe,0x22,0x14,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,
+/* 31400 0x7aa8 "窨" */
+0x02,0x01,0x7f,0x4a,0x91,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 31401 0x7aa9 "窩" */
+0x02,0x01,0x7f,0x48,0x90,0x3f,0x10,0x1f,0x10,0x7f,0x40,0x4f,0x48,0x4f,0x40,0x40,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x10,0x90,0x90,0xfc,0x04,0xe4,0x24,0xe4,0x04,0x0c,
+/* 31402 0x7aaa "窪" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x23,0x10,0x80,0x47,0x10,0x20,0xe3,0x20,0x20,0x27,
+0x00,0x00,0xfe,0x22,0x14,0x40,0xf8,0x40,0x40,0xfc,0x00,0x40,0xf8,0x40,0x40,0xfc,
+/* 31403 0x7aab "窫" */
+0x01,0x7f,0x48,0x90,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x02,0xff,0x04,0x18,0xe0,
+0x00,0xfe,0x22,0x14,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x40,0x30,0x0e,
+/* 31404 0x7aac "窬" */
+0x02,0x01,0x7f,0x49,0x92,0x0c,0x37,0xc0,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0x26,
+0x00,0x00,0xfe,0x22,0x94,0x60,0xd8,0x06,0x08,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 31405 0x7aad "窭" */
+0x02,0x01,0x7f,0x48,0x91,0x09,0x7f,0x05,0x19,0x61,0x04,0xff,0x08,0x1e,0x03,0x3c,
+0x00,0x00,0xfe,0x22,0x14,0x20,0xfc,0x40,0x30,0x0c,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 31406 0x7aae "窮" */
+0x01,0x7f,0x48,0x90,0x08,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x7f,0x05,0x19,0xe5,0x02,
+0x00,0xfe,0x22,0x14,0x00,0x7c,0x04,0x04,0x7c,0x40,0x40,0x7c,0x04,0x04,0x28,0x10,
+/* 31407 0x7aaf "窯" */
+0x02,0x01,0x7f,0x48,0x90,0x24,0x02,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x24,0x22,0x42,
+0x00,0x00,0xfe,0x22,0x14,0x48,0x80,0xf8,0x00,0xf0,0x00,0xfc,0x00,0x88,0x44,0x44,
+/* 31408 0x7ab0 "窰" */
+0x01,0x7f,0x48,0x90,0x01,0x7e,0x22,0x11,0x20,0x3f,0x41,0x01,0xff,0x01,0x21,0x3f,
+0x00,0xfe,0x22,0x14,0xf8,0x00,0x08,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,0x08,0xf8,
+/* 31409 0x7ab1 "窱" */
+0x02,0x01,0x7f,0x48,0x90,0x11,0x22,0x68,0xab,0x28,0x29,0x28,0x28,0x29,0x22,0x20,
+0x00,0x00,0xfe,0x22,0x94,0xf8,0x88,0x70,0xae,0x20,0xfc,0x20,0xa8,0x24,0xa4,0x40,
+/* 31410 0x7ab2 "窲" */
+0x02,0x01,0x7f,0x48,0x90,0x08,0x49,0x2a,0x08,0xff,0x18,0x2c,0x4a,0x88,0x08,0x08,
+0x00,0x00,0xfe,0x22,0x14,0x00,0x48,0x28,0x08,0x48,0x2e,0xf8,0x08,0x08,0x08,0x08,
+/* 31411 0x7ab3 "窳" */
+0x02,0x01,0x7f,0x48,0x90,0x06,0x38,0x28,0x2c,0x2a,0x2a,0x2a,0x28,0x55,0x5d,0x82,
+0x00,0x00,0xfe,0x22,0x14,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0x54,0x74,0x12,
+/* 31412 0x7ab4 "窴" */
+0x01,0x7f,0x48,0x90,0x01,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x10,0x20,
+0x00,0xfe,0x22,0x14,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x10,0x08,
+/* 31413 0x7ab5 "窵" */
+0x01,0x7f,0x48,0x94,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x84,0x00,
+0x00,0xfe,0x22,0x14,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x94,0x08,
+/* 31414 0x7ab6 "窶" */
+0x01,0x7f,0x48,0x91,0x3f,0x21,0xff,0x21,0x3f,0x11,0x1f,0x04,0xff,0x08,0x07,0x78,
+0x00,0xfe,0x22,0x14,0xf8,0x08,0xfe,0x08,0xf8,0x10,0xf0,0x00,0xfe,0x20,0xc0,0x38,
+/* 31415 0x7ab7 "窷" */
+0x01,0x7f,0x48,0x90,0x00,0xfd,0x49,0x49,0x79,0x49,0x79,0x49,0x5d,0xe8,0x08,0x09,
+0x00,0xfe,0x22,0x14,0x40,0x9e,0x52,0x52,0x52,0x52,0x52,0xda,0x54,0x90,0x90,0x10,
+/* 31416 0x7ab8 "窸" */
+0x01,0x7f,0x48,0x90,0x00,0x3f,0x11,0x09,0xff,0x09,0x31,0xc2,0x09,0x29,0x28,0x47,
+0x00,0xfe,0x22,0x14,0xf8,0x00,0x10,0x20,0xfe,0x20,0x18,0x06,0x00,0x08,0x24,0xe4,
+/* 31417 0x7ab9 "窹" */
+0x01,0x7f,0x48,0x90,0x05,0x24,0x24,0x3c,0x04,0x05,0x7c,0x24,0x24,0x24,0x44,0x84,
+0x00,0xfe,0x22,0x14,0xfc,0x20,0xf8,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,
+/* 31418 0x7aba "窺" */
+0x02,0x01,0x7f,0x48,0x90,0x00,0x11,0x7d,0x11,0x11,0xfd,0x11,0x29,0x24,0x41,0x86,
+0x00,0x00,0xfe,0x22,0x14,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x12,0x0e,
+/* 31419 0x7abb "窻" */
+0x01,0x7f,0x48,0x91,0x02,0x3f,0x22,0x27,0x2a,0x21,0x26,0x3f,0x01,0x48,0x48,0x87,
+0x00,0xfe,0x22,0x14,0x00,0xf8,0x08,0xe8,0x48,0x88,0x48,0xf8,0x00,0x84,0x12,0xf2,
+/* 31420 0x7abc "窼" */
+0x01,0x7f,0x48,0x91,0x22,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x7f,0x05,0x19,0xe1,
+0x00,0xfe,0x22,0x14,0x20,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x30,0x0e,
+/* 31421 0x7abd "窽" */
+0x02,0x01,0x7f,0x48,0x90,0x22,0x3c,0x21,0x1f,0x20,0x3f,0x48,0xff,0x14,0x22,0x41,
+0x00,0x00,0xfe,0x22,0x14,0x20,0x20,0x3e,0x42,0x94,0x10,0x10,0xa8,0x28,0x44,0x82,
+/* 31422 0x7abe "窾" */
+0x01,0x7f,0x48,0x90,0x08,0x7f,0x08,0x3e,0x00,0x3e,0x00,0x7f,0x08,0x2a,0x49,0x18,
+0x00,0xfe,0x22,0x14,0x20,0x20,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 31423 0x7abf "窿" */
+0x01,0x7f,0x48,0x91,0x79,0x4a,0x50,0x61,0x56,0x49,0x4a,0x6b,0x54,0x43,0x40,0x47,
+0x00,0xfe,0x22,0x14,0xf0,0x90,0x60,0x98,0x06,0xf0,0x40,0xf8,0x40,0xf8,0x40,0xfc,
+/* 31424 0x7ac0 "竀" */
+0x02,0x01,0x7f,0x48,0x90,0x01,0xfd,0x11,0x11,0x51,0x5d,0x51,0x50,0x5c,0xf1,0x06,
+0x00,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x90,0x12,0x0e,
+/* 31425 0x7ac1 "竁" */
+0x01,0x7f,0x48,0x90,0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,0x0c,0x70,0x1d,0xf0,0x1c,
+0x00,0xfe,0x22,0x14,0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,0x20,0x3c,0xe2,0x22,0x1e,
+/* 31426 0x7ac2 "竂" */
+0x01,0x7f,0x48,0x91,0x7f,0x04,0x28,0x1f,0x28,0xcf,0x08,0x0f,0x01,0x11,0x25,0x02,
+0x00,0xfe,0x22,0x14,0xfc,0x40,0x28,0xf0,0x28,0xe6,0x20,0xe0,0x00,0x10,0x08,0x00,
+/* 31427 0x7ac3 "竃" */
+0x01,0x7f,0x49,0x97,0x01,0x7f,0x11,0x1f,0x11,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x00,0xfe,0x22,0xd4,0x00,0xfc,0x10,0xf0,0x10,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 31428 0x7ac4 "竄" */
+0x01,0x7f,0x48,0x96,0x38,0x20,0x3c,0x20,0x3f,0x00,0x29,0x25,0x29,0x25,0x29,0x31,
+0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x48,0x28,0x48,0x2a,0x46,0x82,
+/* 31429 0x7ac5 "竅" */
+0x01,0x7f,0x48,0x90,0x3e,0x22,0x3e,0x22,0x3e,0x08,0x7f,0x10,0x1e,0x22,0x2a,0x44,
+0x00,0xfe,0x22,0x14,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31430 0x7ac6 "竆" */
+0x01,0x7f,0x48,0x90,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x22,0xfe,0x12,0x22,0xca,0x04,
+0x00,0xfe,0x22,0x14,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0x82,0x82,0xfe,0x82,
+/* 31431 0x7ac7 "竇" */
+0x01,0x7f,0x49,0x97,0x01,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfe,0x22,0xd4,0x00,0xf8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 31432 0x7ac8 "竈" */
+0x01,0x7f,0x49,0x97,0x01,0x7f,0x00,0x1f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xfe,0x22,0xd4,0x00,0xfc,0x00,0xf0,0x90,0xf8,0x88,0xf8,0x88,0xfa,0x82,0xfe,
+/* 31433 0x7ac9 "竉" */
+0x01,0x7f,0x48,0x90,0x08,0x7e,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,
+0x00,0xfe,0x22,0x14,0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,
+/* 31434 0x7aca "竊" */
+0x01,0x7f,0x48,0x90,0x0c,0x70,0x10,0x55,0x39,0x11,0xfd,0x33,0x3a,0x56,0x92,0x12,
+0x00,0xfe,0x22,0x14,0x40,0x7c,0x40,0xfc,0x24,0x54,0x04,0xfe,0x22,0x4a,0xfa,0x06,
+/* 31435 0x7acb "立" */
+0x02,0x01,0x01,0x00,0x7f,0x00,0x00,0x10,0x08,0x08,0x04,0x04,0x04,0x00,0xff,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x00,0xfe,0x00,
+/* 31436 0x7acc "竌" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x28,0x28,0x0e,0xf0,0x41,0x01,0x02,
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 31437 0x7acd "竍" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x47,0x44,0x24,0x28,0x28,0x0e,0xf0,0x40,0x00,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 31438 0x7ace "竎" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,0x04,0x04,0x7f,0x04,0x08,0x08,0x10,0x20,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,
+/* 31439 0x7acf "竏" */
+0x10,0x08,0x09,0x7e,0x00,0x04,0x44,0x47,0x24,0x28,0x28,0x0e,0xf0,0x40,0x00,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 31440 0x7ad0 "竐" */
+0x10,0x08,0x08,0x7e,0x00,0x05,0x46,0x45,0x24,0x28,0x28,0x0e,0xf0,0x40,0x00,0x03,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 31441 0x7ad1 "竑" */
+0x20,0x10,0x10,0xfc,0x03,0x08,0x88,0x88,0x48,0x49,0x51,0x52,0x1e,0xe4,0x41,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 31442 0x7ad2 "竒" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x10,0x10,0x90,0x90,0x90,0x90,0x10,0x50,0x20,
+/* 31443 0x7ad3 "竓" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x28,0x29,0x0e,0xf0,0x40,0x00,0x00,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 31444 0x7ad4 "竔" */
+0x20,0x10,0x13,0xfc,0x00,0x08,0x88,0x8b,0x48,0x48,0x50,0x50,0x1d,0xe1,0x42,0x04,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 31445 0x7ad5 "竕" */
+0x20,0x10,0x10,0xfc,0x01,0x09,0x8a,0x8d,0x48,0x48,0x50,0x50,0x1d,0xe1,0x42,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 31446 0x7ad6 "竖" */
+0x08,0x4b,0x4a,0x49,0x48,0x48,0x48,0x4b,0x0a,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,
+0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0c,0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,
+/* 31447 0x7ad7 "竗" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x45,0x45,0x26,0x28,0x28,0x0e,0xf0,0x40,0x00,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 31448 0x7ad8 "竘" */
+0x10,0x08,0x08,0x7e,0x01,0x06,0x44,0x44,0x24,0x28,0x28,0x0e,0xf0,0x40,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x02,0x02,0xf2,0x92,0x92,0x92,0xf2,0x92,0x02,0x02,0x14,0x08,
+/* 31449 0x7ad9 "站" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x25,0x29,0x29,0x0f,0xf1,0x41,0x01,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31450 0x7ada "竚" */
+0x20,0x10,0x10,0xfd,0x01,0x0a,0x88,0x88,0x49,0x48,0x50,0x50,0x1c,0xe0,0x40,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 31451 0x7adb "竛" */
+0x10,0x08,0x08,0x7e,0x00,0x05,0x46,0x44,0x25,0x28,0x28,0x0e,0xf0,0x40,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 31452 0x7adc "竜" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x01,0x00,0x00,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x12,0x02,0xfe,0x00,
+/* 31453 0x7add "竝" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x28,0x28,0x0e,0xf0,0x41,0x00,0x00,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x84,0x84,0x44,0x48,0x48,0x10,0x10,0xfe,0x00,0x00,
+/* 31454 0x7ade "竞" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x10,0x1f,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x40,0x40,0x42,0x42,0x3e,
+/* 31455 0x7adf "竟" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,0x60,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x42,0x42,0x3e,
+/* 31456 0x7ae0 "章" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 31457 0x7ae1 "竡" */
+0x10,0x09,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x28,0x28,0x0e,0xf0,0x40,0x00,0x00,
+0x00,0xfe,0x10,0x10,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 31458 0x7ae2 "竢" */
+0x20,0x10,0x10,0xfd,0x01,0x08,0x88,0x88,0x49,0x48,0x53,0x50,0x1c,0xe0,0x41,0x02,
+0x20,0x40,0x88,0x04,0xfe,0x02,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 31459 0x7ae3 "竣" */
+0x20,0x10,0x10,0xfd,0x03,0x08,0x88,0x89,0x4a,0x48,0x51,0x52,0x1c,0xe0,0x41,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 31460 0x7ae4 "竤" */
+0x20,0x10,0x13,0x02,0xfc,0x00,0x0b,0x88,0x88,0x48,0x51,0x51,0x1a,0xe2,0x04,0x08,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x90,0x90,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 31461 0x7ae5 "童" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 31462 0x7ae6 "竦" */
+0x20,0x10,0x13,0xfc,0x00,0x09,0x89,0x89,0x49,0x48,0x50,0x50,0x1d,0xe2,0x40,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 31463 0x7ae7 "竧" */
+0x10,0x08,0x08,0x7e,0x00,0x04,0x44,0x44,0x24,0x29,0x28,0x0e,0xf0,0x40,0x03,0x00,
+0x20,0x40,0xf8,0x88,0xf8,0x88,0xf8,0x8a,0x8c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 31464 0x7ae8 "竨" */
+0x20,0x10,0x10,0xfc,0x01,0x09,0x89,0x89,0x49,0x49,0x50,0x53,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 31465 0x7ae9 "竩" */
+0x20,0x10,0x11,0xfd,0x02,0x08,0x88,0x88,0x48,0x48,0x50,0x50,0x1c,0xe0,0x43,0x00,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,
+/* 31466 0x7aea "竪" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,
+/* 31467 0x7aeb "竫" */
+0x20,0x10,0x10,0xfd,0x00,0x09,0x88,0x88,0x4b,0x48,0x50,0x51,0x1c,0xe0,0x40,0x00,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 31468 0x7aec "竬" */
+0x20,0x10,0x13,0xfc,0x01,0x09,0x89,0x89,0x48,0x4b,0x52,0x52,0x1e,0xe2,0x42,0x02,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 31469 0x7aed "竭" */
+0x20,0x11,0x11,0xfd,0x01,0x09,0x88,0x89,0x4a,0x49,0x51,0x51,0x1d,0xe0,0x40,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 31470 0x7aee "竮" */
+0x20,0x13,0x12,0xfe,0x03,0x0a,0x8a,0x8a,0x4a,0x4a,0x52,0x53,0x1c,0xe4,0x48,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x84,0x48,0xfc,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 31471 0x7aef "端" */
+0x20,0x11,0x11,0xfd,0x01,0x08,0x8b,0x88,0x48,0x49,0x51,0x51,0x1d,0xe1,0x41,0x01,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 31472 0x7af0 "竰" */
+0x10,0x09,0x09,0x7f,0x01,0x05,0x45,0x45,0x25,0x29,0x29,0x0f,0xf1,0x42,0x02,0x04,
+0x00,0xfe,0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x10,0x7c,0x10,0x10,0xfe,
+/* 31473 0x7af1 "竱" */
+0x20,0x13,0x10,0xfd,0x01,0x09,0x89,0x89,0x48,0x4b,0x50,0x53,0x1d,0xe0,0x40,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 31474 0x7af2 "竲" */
+0x21,0x10,0x10,0x03,0xfa,0x02,0x0a,0x8a,0x8b,0x48,0x51,0x51,0x19,0xe1,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 31475 0x7af3 "竳" */
+0x20,0x13,0x10,0xfd,0x00,0x09,0x8a,0x8c,0x49,0x49,0x51,0x51,0x1d,0xe0,0x47,0x00,
+0x10,0xd2,0x54,0x48,0x8a,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 31476 0x7af4 "竴" */
+0x20,0x10,0x13,0xfc,0x01,0x09,0x89,0x89,0x49,0x49,0x50,0x53,0x1d,0xe0,0x40,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 31477 0x7af5 "竵" */
+0x20,0x13,0x10,0x03,0xfa,0x02,0x0a,0x8b,0x88,0x4b,0x52,0x52,0x1b,0xe2,0x02,0x02,
+0x00,0xfe,0x08,0xbe,0x88,0xa8,0xbe,0x88,0x08,0xfe,0x8a,0x52,0xfe,0x22,0x2a,0x24,
+/* 31478 0x7af6 "競" */
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x00,0x7e,0x42,0x42,0x7e,0x28,0x2a,0x2c,0x49,0x82,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 31479 0x7af7 "竷" */
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,0x11,
+0x20,0x7c,0xa4,0x18,0xe6,0x10,0xfe,0x10,0x90,0xfe,0x10,0x20,0x7c,0xc8,0x30,0xce,
+/* 31480 0x7af8 "竸" */
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x2a,0x4c,0x88,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x28,0x4a,0x86,
+/* 31481 0x7af9 "竹" */
+0x10,0x10,0x10,0x10,0x3e,0x28,0x49,0x8a,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x40,0xfe,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 31482 0x7afa "竺" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x80,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 31483 0x7afb "竻" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x82,0x02,0x7f,0x02,0x04,0x04,0x08,0x10,0x20,0x40,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 31484 0x7afc "竼" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x80,0x0f,0x08,0x08,0x0a,0x09,0x09,0x10,0x20,0x40,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,
+/* 31485 0x7afd "竽" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x05,0x02,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 31486 0x7afe "竾" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x81,0x11,0x13,0x1d,0xf1,0x11,0x11,0x11,0x10,0x0f,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0x70,0x90,0x10,0x10,0x50,0x22,0x02,0x02,0xfe,
+/* 31487 0x7aff "竿" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 31488 0x7b00 "笀" */
+0x10,0x10,0x3f,0x48,0x85,0x02,0x01,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 31489 0x7b01 "笁" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x80,0x00,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 31490 0x7b02 "笂" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x02,0x7f,0x02,0x0a,0x04,0x06,0x09,0x10,0x20,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 31491 0x7b03 "笃" */
+0x10,0x10,0x3f,0x28,0x45,0xbf,0x00,0x10,0x10,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0x10,0x10,0xfc,0x04,0x04,0xe4,0x04,0x28,0x10,
+/* 31492 0x7b04 "笄" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31493 0x7b05 "笅" */
+0x10,0x10,0x3f,0x28,0x45,0x98,0x06,0x01,0x06,0x18,0x6c,0x02,0x01,0x06,0x18,0xe0,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x60,0x80,0x60,0x18,0x24,0x40,0x80,0x60,0x18,0x06,
+/* 31494 0x7b06 "笆" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x1f,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x02,0x02,0x02,0xfe,
+/* 31495 0x7b07 "笇" */
+0x10,0x10,0x3f,0x28,0x45,0x81,0x00,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x80,0x00,0xfe,0x00,0x20,0x10,0x08,0x00,0x00,0x00,
+/* 31496 0x7b08 "笈" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x08,0x08,0x0c,0x0a,0x12,0x11,0x20,0x43,0x8c,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xe0,0x20,0x40,0x78,0x08,0x10,0x20,0xc0,0x30,0x0e,
+/* 31497 0x7b09 "笉" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x1f,0x20,0x4c,0x82,0x00,0x01,0x1e,0x08,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x08,0x68,0x88,0x08,0x08,0x50,0x20,
+/* 31498 0x7b0a "笊" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x00,0x1f,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x82,
+0x40,0x40,0x7e,0x90,0x08,0x10,0xf8,0x20,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x02,
+/* 31499 0x7b0b "笋" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x02,0x02,0xff,0x02,0x04,0x3f,0x08,0x10,0x20,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0x10,0xfe,0x10,0x10,0xf0,0x10,0x00,0x00,0x00,
+/* 31500 0x7b0c "笌" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x00,0x10,0x20,0x3f,0x01,0x02,0x0c,0x30,0xc0,0x00,
+0x40,0x40,0x7e,0x90,0x08,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 31501 0x7b0d "笍" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x3f,0x21,0x21,0x22,0x24,0x28,0x20,0x20,0x20,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x88,0x48,0x28,0x08,0x08,0x28,0x10,
+/* 31502 0x7b0e "笎" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x10,0x60,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x00,0x00,0xfc,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 31503 0x7b0f "笏" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x1f,0x22,0x42,0x84,0x08,0x11,0x22,0x44,0x08,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x48,0x48,0x88,0x88,0x08,0x08,0x08,0x50,0x20,
+/* 31504 0x7b10 "笐" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x7f,0x00,0x00,0x0f,0x08,0x08,0x08,0x10,0x20,0xc0,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfc,0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 31505 0x7b11 "笑" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x01,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x00,0x00,0x00,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 31506 0x7b12 "笒" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x04,0x0a,0x31,0xc1,0x1f,0x00,0x00,0x00,0x00,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x40,0x20,0x18,0x06,0xe0,0x20,0x40,0x40,0x80,0x00,
+/* 31507 0x7b13 "笓" */
+0x10,0x10,0x3f,0x48,0x85,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x24,0x28,0x30,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x84,0x7c,0x00,
+/* 31508 0x7b14 "笔" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x3f,0x01,0x01,0x3f,0x01,0x01,0x7f,0x01,0x01,0x00,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfc,0x02,0x02,0x02,0xfe,
+/* 31509 0x7b15 "笕" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x1f,0x10,0x11,0x11,0x11,0x12,0x14,0x08,0x30,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x90,0x82,0x82,0x7e,
+/* 31510 0x7b16 "笖" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x24,0x22,0x21,0x21,0x20,0x24,0x28,0x30,0x21,0x06,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0x30,0x48,0x84,0x02,
+/* 31511 0x7b17 "笗" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x1f,0x28,0x44,0x03,0x1c,0xe3,0x00,0x0e,0x01,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xc0,0x00,0x80,0x40,
+/* 31512 0x7b18 "笘" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x81,0x01,0x01,0x01,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 31513 0x7b19 "笙" */
+0x10,0x10,0x3f,0x28,0x45,0x91,0x11,0x3f,0x41,0x81,0x01,0x3f,0x01,0x01,0x01,0xff,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,
+/* 31514 0x7b1a "笚" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,
+/* 31515 0x7b1b "笛" */
+0x10,0x10,0x3f,0x28,0x45,0x81,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 31516 0x7b1c "笜" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x01,0x21,0x21,0x3f,0x01,0x01,0x41,0x41,0x7f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0x08,0x08,0xf8,0x00,0x00,0x04,0x04,0xfc,0x04,
+/* 31517 0x7b1d "笝" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x20,0x2f,0x20,0x26,0x21,0x22,0x2c,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x08,0xc8,0x48,0x88,0x08,0x88,0x48,0x08,0xf8,0x08,
+/* 31518 0x7b1e "笞" */
+0x10,0x10,0x3f,0x48,0x85,0x08,0x10,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x10,0xf8,0x08,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 31519 0x7b1f "笟" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x1f,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x82,
+0x40,0x40,0x7e,0x90,0x08,0x78,0xa0,0x20,0x20,0x20,0x10,0x90,0x48,0xa8,0x24,0x02,
+/* 31520 0x7b20 "笠" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x82,0x01,0x01,0x7f,0x00,0x10,0x08,0x04,0x00,0xff,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0x00,0x00,0xfc,0x00,0x10,0x20,0x40,0x00,0xfe,
+/* 31521 0x7b21 "笡" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 31522 0x7b22 "笢" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2c,0x30,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfc,0x40,0x24,0x14,0x0c,
+/* 31523 0x7b23 "笣" */
+0x20,0x3f,0x48,0x85,0x08,0x1f,0x20,0x5f,0x10,0x10,0x1f,0x10,0x10,0x10,0x0f,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x50,0x24,0x04,0xfc,0x00,
+/* 31524 0x7b24 "笤" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x04,0x08,0x10,0x20,0xdf,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x50,0x20,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 31525 0x7b25 "笥" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x00,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x10,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xe8,0x08,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 31526 0x7b26 "符" */
+0x10,0x10,0x3f,0x48,0x85,0x08,0x08,0x13,0x30,0x51,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 31527 0x7b27 "笧" */
+0x20,0x3f,0x48,0x85,0x00,0x1e,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x26,0x41,
+0x40,0x7e,0x90,0x08,0x00,0x78,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x88,0xa8,0x10,
+/* 31528 0x7b28 "笨" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x7f,0x03,0x05,0x09,0x11,0x2f,0xc1,0x01,0x01,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0x00,0x00,
+/* 31529 0x7b29 "笩" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x50,0x48,0x40,0x7c,0xc0,0x40,0x20,0x20,0x14,0x0c,0x04,
+/* 31530 0x7b2a "笪" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x00,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x00,
+/* 31531 0x7b2b "笫" */
+0x10,0x10,0x3f,0x28,0x45,0x81,0x1f,0x11,0x21,0x3f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x70,0x80,0x00,0x00,0xfc,0x04,0x04,0x04,0x28,0x10,0x00,
+/* 31532 0x7b2c "第" */
+0x20,0x3f,0x48,0x85,0x3f,0x01,0x01,0x3f,0x21,0x21,0x3f,0x03,0x05,0x19,0xe1,0x01,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x28,0x10,0x00,
+/* 31533 0x7b2d "笭" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x04,0x0a,0x31,0xc1,0x1f,0x00,0x00,0x0c,0x03,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x40,0x20,0x18,0x06,0xe0,0x20,0x40,0x80,0x00,0x80,
+/* 31534 0x7b2e "笮" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x1f,0x24,0x44,0x87,0x04,0x04,0x07,0x04,0x04,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0x00,0xf8,0x00,0x00,
+/* 31535 0x7b2f "笯" */
+0x10,0x10,0x3f,0x28,0x45,0x90,0x11,0xfe,0x12,0x22,0x24,0x64,0x18,0x18,0x24,0xc3,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 31536 0x7b30 "笰" */
+0x20,0x3f,0x48,0x85,0x04,0x3f,0x04,0x04,0x1f,0x14,0x24,0x3f,0x08,0x10,0x20,0x40,
+0x40,0x7e,0x90,0x08,0x40,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0x44,0x54,0x48,0x40,
+/* 31537 0x7b31 "笱" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x1f,0x20,0x40,0x9f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0x88,0x08,0x50,0x20,
+/* 31538 0x7b32 "笲" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x10,0x3f,0x00,0x08,0x08,0xff,0x08,0x08,0x10,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x10,0xf8,0x08,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 31539 0x7b33 "笳" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 31540 0x7b34 "笴" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfe,0x10,0x10,0x90,0x90,0x90,0x90,0x10,0x50,0x20,
+/* 31541 0x7b35 "笵" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x09,0x49,0x21,0x25,0x05,0x09,0x71,0x11,0x11,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0x08,0x28,0x10,0x02,0x02,0x02,0xfe,
+/* 31542 0x7b36 "笶" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x1f,0x21,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xf0,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,
+/* 31543 0x7b37 "笷" */
+0x10,0x10,0x3f,0x48,0x85,0x0c,0x70,0x40,0x44,0x44,0x5c,0x64,0x48,0x08,0x10,0x60,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,
+/* 31544 0x7b38 "笸" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,
+/* 31545 0x7b39 "笹" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x12,0x12,0xff,0x12,0x12,0x13,0x10,0x10,0x1f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x20,0x20,0xfe,0x20,0x20,0xe0,0x00,0x00,0xfc,0x00,
+/* 31546 0x7b3a "笺" */
+0x20,0x3f,0x48,0x85,0x02,0x02,0x03,0x7e,0x02,0x03,0xfe,0x01,0x00,0x07,0x38,0x00,
+0x40,0x7e,0x90,0x08,0x40,0x20,0xf8,0x00,0x00,0xfc,0x10,0x20,0xc0,0x44,0x34,0x0c,
+/* 31547 0x7b3b "笻" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x7c,0x10,0x10,0x10,0x10,0x1e,0xf0,0x40,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,
+/* 31548 0x7b3c "笼" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x04,0x7f,0x04,0x04,0x08,0x08,0x10,0x23,0x4c,0x80,
+0x40,0x40,0x7e,0x90,0x08,0x40,0x20,0xfc,0x80,0x88,0x90,0xa0,0xc2,0x82,0x82,0x7e,
+/* 31549 0x7b3d "笽" */
+0x10,0x10,0x1f,0x28,0x24,0x45,0x80,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0xff,0x00,
+0x40,0x40,0x7e,0x90,0x88,0x08,0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 31550 0x7b3e "笾" */
+0x10,0x10,0x3f,0x48,0x85,0x20,0x10,0x17,0x00,0x70,0x11,0x11,0x12,0x14,0x28,0x47,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x80,0xf8,0x88,0x88,0x08,0x08,0x28,0x10,0x00,0xfe,
+/* 31551 0x7b3f "笿" */
+0x20,0x3f,0x48,0x85,0x08,0x0f,0x10,0x2c,0x03,0x1c,0xe0,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x10,
+/* 31552 0x7b40 "筀" */
+0x10,0x10,0x3f,0x28,0x45,0x81,0x3f,0x01,0x01,0xff,0x00,0x01,0x3f,0x01,0x01,0xff,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 31553 0x7b41 "筁" */
+0x10,0x10,0x3f,0x28,0x45,0x84,0x3f,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x48,0x40,0xf8,0x48,0x48,0x48,0xf8,0x48,0x48,0x48,0xf8,0x08,
+/* 31554 0x7b42 "筂" */
+0x10,0x10,0x3f,0x48,0x85,0x20,0x12,0x92,0x43,0x4e,0x0a,0x12,0xe2,0x22,0x21,0x20,
+0x40,0x40,0x7e,0x90,0x48,0x40,0x58,0x68,0xc8,0x48,0x48,0x5a,0x42,0x02,0xfe,0x00,
+/* 31555 0x7b43 "筃" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x21,0x21,0x2f,0x21,0x22,0x24,0x28,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x08,0x08,0xe8,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 31556 0x7b44 "筄" */
+0x10,0x10,0x3f,0x48,0x85,0x04,0x44,0x24,0x24,0x0c,0x34,0xc8,0x08,0x10,0x20,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x40,0x48,0x50,0x60,0x40,0x60,0x52,0x4a,0x42,0x3e,0x00,
+/* 31557 0x7b45 "筅" */
+0x10,0x10,0x3f,0x48,0x85,0x11,0x11,0x3f,0x41,0x01,0xff,0x04,0x08,0x10,0x20,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xf8,0x00,0x00,0xfe,0x40,0x40,0x42,0x42,0x3e,
+/* 31558 0x7b46 "筆" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x01,0xff,0x01,0x3f,0x01,0x3f,0x01,0xff,0x01,0x01,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 31559 0x7b47 "筇" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x0e,0xf0,0x40,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x84,0x88,0x90,0x88,0x84,0x84,0xa8,0x90,0x80,
+/* 31560 0x7b48 "筈" */
+0x20,0x3f,0x48,0x85,0x00,0x1f,0x01,0x01,0xff,0x01,0x01,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0xf0,0x00,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 31561 0x7b49 "等" */
+0x20,0x3f,0x48,0x85,0x01,0x3f,0x01,0x01,0xff,0x00,0x00,0x7f,0x08,0x04,0x04,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0xfc,0x20,0x20,0xa0,0x40,
+/* 31562 0x7b4a "筊" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x7f,0x08,0x10,0x24,0x44,0x02,0x01,0x06,0x18,0xe0,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfc,0x20,0x10,0x48,0x44,0x80,0x00,0xc0,0x30,0x0e,
+/* 31563 0x7b4b "筋" */
+0x10,0x10,0x3f,0x48,0x85,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x42,0x4a,0x85,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 31564 0x7b4c "筌" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x04,0x08,0x30,0xcf,0x01,0x01,0x1f,0x01,0x01,0x7f,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf0,0x00,0x00,0xfc,
+/* 31565 0x7b4d "筍" */
+0x20,0x3f,0x48,0x95,0x10,0x1f,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x00,0x00,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xc8,0x48,0x08,0x50,0x20,
+/* 31566 0x7b4e "筎" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0xfe,0x12,0x22,0x22,0x64,0x14,0x08,0x14,0x22,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 31567 0x7b4f "筏" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x11,0x16,
+0x40,0x40,0x7e,0x90,0x08,0xa0,0x90,0x80,0xfc,0x80,0x48,0x50,0x24,0x54,0x8c,0x04,
+/* 31568 0x7b50 "筐" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x20,0x2f,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,0x3f,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,0xfe,
+/* 31569 0x7b51 "筑" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x10,0x90,0x50,0x12,0x12,0x12,0x0e,0x00,
+/* 31570 0x7b52 "筒" */
+0x10,0x10,0x3f,0x28,0x45,0xbf,0x20,0x2f,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x20,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x08,0xe8,0x08,0xc8,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 31571 0x7b53 "筓" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x7e,0x08,0x08,0x08,0xfe,0x08,0x08,0x10,0x20,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31572 0x7b54 "答" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 31573 0x7b55 "筕" */
+0x20,0x3f,0x48,0x85,0x10,0x21,0x40,0x88,0x13,0x30,0x50,0x90,0x10,0x10,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 31574 0x7b56 "策" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0xff,0x01,0x3f,0x21,0x23,0x25,0x09,0x11,0x61,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfe,0x00,0xf8,0x08,0x88,0x58,0x20,0x10,0x0c,0x00,
+/* 31575 0x7b57 "筗" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x10,0x27,0x64,0xa4,0x24,0x27,0x24,0x20,0x20,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x40,0x40,0xfc,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,
+/* 31576 0x7b58 "筘" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x7e,0x08,0x08,0x0e,0x78,0x08,0x08,0x28,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 31577 0x7b59 "筙" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x7f,0x01,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 31578 0x7b5a "筚" */
+0x20,0x3f,0x48,0x85,0x20,0x20,0x3e,0x20,0x20,0x26,0x39,0x01,0xff,0x01,0x01,0x01,
+0x40,0x7e,0x90,0x08,0x80,0x88,0xb0,0xc4,0x84,0x7c,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 31579 0x7b5b "筛" */
+0x20,0x3f,0x48,0x85,0x08,0x4b,0x48,0x48,0x49,0x49,0x49,0x49,0x11,0x11,0x20,0x40,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 31580 0x7b5c "筜" */
+0x10,0x10,0x3f,0x28,0x45,0x91,0x09,0x01,0x7f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 31581 0x7b5d "筝" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x1f,0x20,0x5f,0x01,0xff,0x01,0x1f,0x01,0x05,0x02,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x20,0xf8,0x08,0xfe,0x08,0xf8,0x08,0x00,0x00,
+/* 31582 0x7b5e "筞" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x3f,0x20,0x41,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfc,0x04,0x08,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31583 0x7b5f "筟" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x22,0x11,0x3f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x40,0x7e,0x90,0x08,0xf8,0x00,0x10,0x20,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 31584 0x7b60 "筠" */
+0x10,0x10,0x3f,0x28,0x45,0x90,0x10,0x7d,0x12,0x10,0x10,0x1c,0xe0,0x41,0x00,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x80,0xfc,0x04,0x04,0x84,0x54,0x24,0x44,0x84,0x28,0x10,
+/* 31585 0x7b61 "筡" */
+0x20,0x20,0x7e,0x51,0x8a,0x04,0x08,0x37,0xc1,0x01,0x3f,0x01,0x11,0x21,0x45,0x02,
+0x40,0x40,0xfe,0x10,0x88,0x40,0x20,0xd8,0x06,0x00,0xf8,0x00,0x10,0x08,0x04,0x00,
+/* 31586 0x7b62 "筢" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x11,0xfd,0x11,0x11,0x1d,0xf1,0x11,0x11,0x51,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 31587 0x7b63 "筣" */
+0x20,0x20,0x7e,0x51,0x88,0x06,0x78,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x40,0x40,0xfe,0x10,0x08,0x08,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 31588 0x7b64 "筤" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x10,0x12,0x14,0x18,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x18,0x06,
+/* 31589 0x7b65 "筥" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 31590 0x7b66 "筦" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x3f,0x20,0x5f,0x00,0x7f,0x04,0x04,0x08,0x10,0x60,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfc,0x04,0xe8,0x00,0xfc,0x40,0x40,0x44,0x44,0x3c,
+/* 31591 0x7b67 "筧" */
+0x10,0x10,0x3f,0x28,0x45,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,0x60,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x42,0x42,0x3e,
+/* 31592 0x7b68 "筨" */
+0x10,0x10,0x3f,0x48,0x85,0x02,0x0c,0x31,0xcf,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x60,0x18,0xe6,0x40,0x80,0xf0,0x10,0x10,0xf0,0x10,
+/* 31593 0x7b69 "筩" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x04,0x02,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,0x20,
+0x40,0x40,0x7e,0x90,0x08,0xe0,0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 31594 0x7b6a "筪" */
+0x10,0x10,0x3f,0x28,0x45,0xbf,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x20,0x20,0x3f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x80,0x80,0xfe,0x00,
+/* 31595 0x7b6b "筫" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 31596 0x7b6c "筬" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x4a,0x44,0x81,
+0x40,0x40,0x7e,0x90,0x08,0x90,0x88,0xfc,0x80,0x88,0x48,0x50,0x24,0x54,0x8c,0x04,
+/* 31597 0x7b6d "筭" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x08,0xff,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x00,0x20,0xfe,0x20,0x20,0x20,
+/* 31598 0x7b6e "筮" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7f,0x01,0x11,0x11,0x11,0x29,0x45,0x85,0x01,0xff,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0x10,0x10,0x10,0x28,0x44,0x84,0x00,0xfe,
+/* 31599 0x7b6f "筯" */
+0x10,0x10,0x3f,0x48,0x85,0x3e,0x22,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2f,0xf0,0x41,
+0x40,0x40,0x7e,0x90,0x28,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 31600 0x7b70 "筰" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x10,0x11,0x32,0x54,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x80,0xfe,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,
+/* 31601 0x7b71 "筱" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x10,0x24,0x24,0x64,0xa5,0x24,0x24,0x20,0x20,0x23,
+0x40,0x40,0x7e,0x90,0x08,0x40,0x40,0x7e,0x88,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 31602 0x7b72 "筲" */
+0x10,0x10,0x3f,0x48,0x85,0x11,0x09,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x10,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 31603 0x7b73 "筳" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7b,0x08,0x10,0x23,0x78,0x08,0x2b,0x10,0x28,0x47,
+0x40,0x40,0x7e,0x90,0x08,0x38,0xc0,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0x00,0xfe,
+/* 31604 0x7b74 "筴" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x7f,0x11,0x11,0x29,0x45,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x10,0x10,0x28,0x44,0x80,0x40,0x20,0x18,0x06,
+/* 31605 0x7b75 "筵" */
+0x20,0x3f,0x48,0x85,0x00,0x7b,0x08,0x10,0x22,0x7a,0x0a,0x2b,0x10,0x28,0x47,0x80,
+0x40,0x7e,0x90,0x08,0x18,0xe0,0x40,0x40,0x78,0x40,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 31606 0x7b76 "筶" */
+0x10,0x10,0x3f,0x48,0x85,0x11,0x1f,0x21,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 31607 0x7b77 "筷" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x11,0x18,0x54,0x50,0x53,0x90,0x10,0x11,0x12,0x14,
+0x40,0x40,0x7e,0x90,0x08,0x40,0xf8,0x48,0x48,0x48,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 31608 0x7b78 "筸" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 31609 0x7b79 "筹" */
+0x20,0x3f,0x48,0x85,0x01,0x7f,0x02,0x3f,0x04,0xff,0x08,0x1f,0x24,0x42,0x80,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xfc,0x20,0x20,0xa0,0x40,
+/* 31610 0x7b7a "筺" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x20,0x2f,0x20,0x20,0x27,0x20,0x20,0x2f,0x20,0x3f,
+0x40,0x40,0x7e,0x90,0x08,0xfe,0x00,0xfc,0x80,0x80,0xf8,0xa0,0x90,0xfc,0x00,0xfe,
+/* 31611 0x7b7b "筻" */
+0x20,0x3f,0x48,0x85,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x1a,0x06,0x19,0x60,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0x00,0xc0,0x3e,
+/* 31612 0x7b7c "筼" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x21,0x22,0x04,0x18,0xe0,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x08,0xe0,0x18,0x04,
+/* 31613 0x7b7d "筽" */
+0x10,0x10,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x00,0x3f,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x40,0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 31614 0x7b7e "签" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x04,0x08,0x37,0xc0,0x02,0x11,0x09,0x08,0x7f,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x80,0x40,0x20,0xd8,0x06,0x10,0x10,0x20,0x40,0xfc,0x00,
+/* 31615 0x7b7f "筿" */
+0x10,0x10,0x3f,0x28,0x45,0x8f,0x14,0x03,0x1c,0xe1,0x01,0x3f,0x01,0x11,0x25,0x02,
+0x40,0x40,0x7e,0x90,0x08,0xe0,0x40,0x80,0x70,0x0e,0x00,0xf8,0x00,0x10,0x08,0x00,
+/* 31616 0x7b80 "简" */
+0x20,0x3f,0x48,0x85,0x10,0x0b,0x20,0x27,0x24,0x24,0x27,0x24,0x24,0x27,0x20,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xc8,0x48,0x48,0xc8,0x48,0x48,0xc8,0x08,0x18,
+/* 31617 0x7b81 "箁" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 31618 0x7b82 "箂" */
+0x10,0x10,0x3f,0x48,0x85,0x01,0x7f,0x11,0x11,0x29,0x45,0x03,0x05,0x09,0x31,0xc1,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x10,0x10,0x28,0x44,0x80,0x40,0x20,0x18,0x06,
+/* 31619 0x7b83 "箃" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2f,0xf2,0x42,0x02,
+0x40,0x7e,0x90,0x08,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31620 0x7b84 "箄" */
+0x20,0x20,0x7e,0x51,0x8a,0x04,0x3f,0x21,0x3f,0x22,0x3f,0x08,0x10,0xff,0x00,0x00,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x80,0xfe,0x80,0x80,
+/* 31621 0x7b85 "箅" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x08,0x08,0x10,0x20,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x20,0x20,0x20,0x20,
+/* 31622 0x7b86 "箆" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x21,0x22,0x24,0x00,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x88,0x48,0x00,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 31623 0x7b87 "箇" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x21,0x21,0x2f,0x21,0x27,0x24,0x27,0x20,0x3f,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x08,0xf8,0x08,
+/* 31624 0x7b88 "箈" */
+0x20,0x3f,0x48,0x85,0x20,0x11,0x12,0x87,0x42,0x50,0x13,0x22,0xe2,0x22,0x23,0x22,
+0x40,0x7e,0x90,0x08,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 31625 0x7b89 "箉" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0xfd,0x11,0x15,0x18,0x33,0xd0,0x10,0x10,0x51,0x22,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0x08,0xf8,0x40,0xfc,0x44,0x84,0x84,0x14,0x08,
+/* 31626 0x7b8a "箊" */
+0x10,0x10,0x3f,0x48,0x95,0x08,0x7e,0x10,0x10,0x1f,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x40,0x40,0x7e,0x90,0x28,0x20,0x50,0x50,0x88,0x06,0x60,0x10,0x00,0xc0,0x30,0x08,
+/* 31627 0x7b8b "箋" */
+0x20,0x3f,0x48,0x85,0x02,0x02,0x7f,0x00,0x07,0x78,0x02,0x02,0x7f,0x00,0x07,0x78,
+0x40,0x7e,0x90,0x08,0x10,0xfc,0x40,0x84,0x64,0x1c,0x10,0xfc,0x40,0x84,0x64,0x1c,
+/* 31628 0x7b8c "箌" */
+0x20,0x3f,0x48,0x85,0x7f,0x10,0x22,0x7f,0x09,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x40,0x7e,0x90,0x08,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 31629 0x7b8d "箍" */
+0x20,0x3f,0x48,0x85,0x10,0x13,0x12,0xfe,0x12,0x12,0x1e,0xf2,0x12,0x12,0x52,0x23,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x20,0x20,0xfc,0xa4,0xa4,0xa4,0xb4,0xa8,0x20,0xfe,
+/* 31630 0x7b8e "箎" */
+0x20,0x3f,0x48,0x85,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x27,0x44,0x48,0xb0,
+0x40,0x7e,0x90,0x08,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xe0,0x22,0x22,0x1e,
+/* 31631 0x7b8f "箏" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x22,0x11,0x3f,0x01,0xff,0x01,0x3f,0x01,0x05,0x02,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0x08,0x10,0xf8,0x08,0xfe,0x08,0xf8,0x08,0x00,0x00,
+/* 31632 0x7b90 "箐" */
+0x20,0x3f,0x49,0xbf,0x01,0x1f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x40,0x7e,0x90,0xf8,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 31633 0x7b91 "箑" */
+0x20,0x3f,0x48,0x85,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x11,0x11,0x29,0x47,0x80,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x00,0xfe,0x00,
+/* 31634 0x7b92 "箒" */
+0x20,0x3f,0x48,0x85,0x1f,0x00,0x0f,0x00,0x1f,0x00,0x7f,0x41,0x9f,0x11,0x11,0x11,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x10,0x50,0x20,
+/* 31635 0x7b93 "箓" */
+0x20,0x3f,0x48,0x85,0x3f,0x00,0x1f,0x00,0xff,0x11,0x09,0x05,0x19,0xe1,0x05,0x02,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xa0,0x40,0x30,0x0e,0x00,0x00,
+/* 31636 0x7b94 "箔" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x09,0x49,0x21,0x25,0x05,0x09,0x71,0x11,0x11,0x11,
+0x40,0x40,0x7e,0x90,0x28,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 31637 0x7b95 "箕" */
+0x20,0x3f,0x48,0x85,0x08,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x08,0x20,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x20,0x10,0x08,
+/* 31638 0x7b96 "箖" */
+0x10,0x10,0x3f,0x48,0x85,0x08,0x08,0x7e,0x08,0x0c,0x1a,0x2a,0x49,0x88,0x08,0x08,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x20,0xfc,0x20,0x70,0x68,0xa4,0x22,0x20,0x20,0x20,
+/* 31639 0x7b97 "算" */
+0x20,0x3e,0x48,0x80,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0xff,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 31640 0x7b98 "箘" */
+0x20,0x3f,0x48,0x85,0x3f,0x20,0x20,0x27,0x21,0x2f,0x23,0x25,0x29,0x21,0x3f,0x20,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xc8,0x08,0x08,0xe8,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 31641 0x7b99 "箙" */
+0x20,0x3f,0x48,0x85,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x22,0x4a,0x84,
+0x40,0x7e,0x90,0x08,0xfc,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,
+/* 31642 0x7b9a "箚" */
+0x10,0x10,0x3f,0x28,0x45,0x8c,0x12,0x21,0x5e,0x80,0x3f,0x21,0x21,0x21,0x3f,0x21,
+0x40,0x40,0x7e,0x90,0x08,0x04,0x24,0x24,0xa4,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 31643 0x7b9b "箛" */
+0x20,0x3f,0x48,0x85,0x00,0x7d,0x09,0x11,0x11,0x1d,0x31,0xd1,0x11,0x12,0x52,0x24,
+0x40,0x7e,0x90,0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x48,0x48,0x44,0x54,0x5a,0x68,
+/* 31644 0x7b9c "箜" */
+0x20,0x3f,0x48,0x85,0x01,0x7f,0x40,0x88,0x10,0x20,0x1f,0x01,0x01,0x01,0x7f,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x02,0x24,0x10,0x08,0xf0,0x00,0x00,0x00,0xfc,0x00,
+/* 31645 0x7b9d "箝" */
+0x10,0x10,0x3f,0x48,0x85,0x10,0x10,0xfb,0x10,0x10,0x1c,0xf0,0x10,0x10,0x50,0x20,
+0x40,0x40,0x7e,0x90,0x08,0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,
+/* 31646 0x7b9e "箞" */
+0x20,0x3f,0x48,0x85,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x2f,0xc8,0x08,0x08,0x07,
+0x40,0x7e,0x90,0x08,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0xe8,0x26,0x68,0x08,0xf8,
+/* 31647 0x7b9f "箟" */
+0x10,0x10,0x3f,0x28,0x45,0x9f,0x10,0x1f,0x10,0x1f,0x20,0x20,0x3e,0x20,0x26,0x38,
+0x40,0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x8c,0xf0,0x82,0x82,0x7e,
+/* 31648 0x7ba0 "箠" */
+0x20,0x3e,0x49,0x80,0x3f,0x01,0x7f,0x09,0x09,0xff,0x09,0x09,0x7f,0x01,0x01,0x3f,
+0x80,0xfe,0x10,0xf8,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xf8,
+/* 31649 0x7ba1 "管" */
+0x20,0x3f,0x48,0x85,0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x02,0xe4,0x20,0xe0,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 31650 0x7ba2 "箢" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x7f,0x40,0x90,0x1e,0x22,0x24,0x54,0x08,0x10,0x60,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfe,0x02,0x04,0xf8,0x88,0xa8,0x90,0x84,0x84,0x7c,
+/* 31651 0x7ba3 "箣" */
+0x20,0x20,0x7e,0x51,0x88,0x08,0xff,0x08,0x7f,0x49,0x4b,0x1c,0x2a,0x49,0x88,0x08,
+0x40,0x40,0xfe,0x10,0x08,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 31652 0x7ba4 "箤" */
+0x20,0x20,0x7e,0x51,0x8a,0x01,0x7f,0x08,0x08,0x14,0x22,0x01,0xff,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x10,0x08,0x00,0xfc,0x20,0x20,0x50,0x88,0x00,0xfe,0x00,0x00,0x00,
+/* 31653 0x7ba5 "箥" */
+0x20,0x3f,0x48,0x85,0x20,0x10,0x13,0x82,0x42,0x4b,0x0a,0x12,0xe2,0x24,0x24,0x29,
+0x40,0x7e,0x90,0x08,0x20,0x20,0xfc,0x24,0x20,0xf8,0x88,0x88,0x50,0x20,0x50,0x8c,
+/* 31654 0x7ba6 "箦" */
+0x20,0x3f,0x48,0x85,0x3f,0x01,0x1f,0x01,0x7f,0x00,0x1f,0x10,0x11,0x02,0x0c,0x70,
+0x40,0x7e,0x90,0x08,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x10,0x10,0xc0,0x30,0x08,
+/* 31655 0x7ba7 "箧" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x20,0x20,0x2f,0x24,0x22,0x2f,0x21,0x22,0x24,0x3f,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x80,0x80,0xf8,0x90,0xa0,0xfc,0x40,0x20,0x10,0xfe,
+/* 31656 0x7ba8 "箨" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0x10,0xfc,0x13,0x10,0x1d,0x30,0xd3,0x10,0x50,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x88,0x70,0x8e,0x20,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 31657 0x7ba9 "箩" */
+0x20,0x3f,0x48,0x85,0x3f,0x24,0x24,0x3f,0x02,0x07,0x08,0x34,0x02,0x01,0x0e,0x70,
+0x40,0x7e,0x90,0x08,0xf8,0x48,0x48,0xf8,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 31658 0x7baa "箪" */
+0x20,0x3f,0x48,0x85,0x08,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x40,0x7e,0x90,0x08,0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 31659 0x7bab "箫" */
+0x10,0x1f,0x28,0x45,0x3f,0x01,0xff,0x01,0x3f,0x01,0x25,0x25,0x25,0x29,0x21,0x41,
+0x40,0x7c,0xa0,0x10,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x48,0x28,0x28,0x28,0x08,0x08,
+/* 31660 0x7bac "箬" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x02,0xff,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0x40,0x7e,0x90,0x08,0x20,0xfc,0x20,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 31661 0x7bad "箭" */
+0x20,0x3f,0x48,0x85,0x10,0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2a,0x24,
+0x40,0x7e,0x90,0x08,0x10,0x20,0xfe,0x00,0x48,0x48,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 31662 0x7bae "箮" */
+0x20,0x3f,0x50,0x8a,0x01,0x7f,0x40,0x9f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x02,0xf4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 31663 0x7baf "箯" */
+0x20,0x3f,0x48,0x85,0x08,0x17,0x30,0x53,0x92,0x13,0x12,0x13,0x11,0x10,0x13,0x1c,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xc0,0x30,0x0e,
+/* 31664 0x7bb0 "箰" */
+0x20,0x3e,0x48,0x9f,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x00,0x1f,0x00,0xff,0x01,0x03,
+0x40,0x7e,0x90,0xf8,0x08,0xc8,0x48,0xc8,0x68,0xd0,0x00,0xe0,0x40,0xfe,0x00,0x00,
+/* 31665 0x7bb1 "箱" */
+0x10,0x10,0x3f,0x28,0x45,0x88,0x08,0x7e,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,
+/* 31666 0x7bb2 "箲" */
+0x20,0x3f,0x48,0x85,0x11,0x09,0x09,0x42,0x20,0x2b,0x08,0x10,0x70,0x11,0x11,0x12,
+0x40,0x7e,0x90,0x28,0x20,0x20,0xfc,0x20,0x20,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 31667 0x7bb3 "箳" */
+0x20,0x3f,0x48,0x85,0x3f,0x20,0x3f,0x24,0x22,0x2f,0x22,0x22,0x2f,0x42,0x44,0x88,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x10,0x20,0xf8,0x20,0x20,0xfc,0x20,0x20,0x20,
+/* 31668 0x7bb4 "箴" */
+0x10,0x10,0x3f,0x28,0x45,0x80,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x28,0x4f,0x40,0x80,
+0x40,0x40,0x7e,0x90,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x92,0xaa,0x46,0x82,
+/* 31669 0x7bb5 "箵" */
+0x20,0x3f,0x48,0x85,0x11,0x21,0x43,0x1c,0xff,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x10,0x68,0x84,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 31670 0x7bb6 "箶" */
+0x20,0x20,0x7e,0x51,0x88,0x08,0x7f,0x08,0x08,0x3e,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x40,0x40,0xfe,0x10,0x08,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x84,0x94,0x08,
+/* 31671 0x7bb7 "箷" */
+0x10,0x10,0x3f,0x48,0xa5,0x10,0xfe,0x21,0x20,0x3c,0x25,0x24,0x24,0x44,0x54,0x88,
+0x40,0x40,0x7e,0x90,0x48,0x40,0xfe,0x20,0xac,0xb4,0xe4,0xac,0xa0,0xa2,0x82,0x7e,
+/* 31672 0x7bb8 "箸" */
+0x10,0x10,0x3f,0x28,0x45,0x82,0x1f,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,0x08,
+0x40,0x40,0x7e,0x90,0x08,0x00,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 31673 0x7bb9 "箹" */
+0x20,0x3f,0x48,0x85,0x10,0x14,0x24,0x78,0x11,0x24,0x7e,0x00,0x54,0x4a,0x8a,0x00,
+0x40,0x7e,0x90,0x08,0x40,0x40,0x7c,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x28,0x10,
+/* 31674 0x7bba "箺" */
+0x20,0x3f,0x48,0x85,0x7f,0x01,0x3f,0x02,0xff,0x08,0x1f,0x28,0xcf,0x08,0x0f,0x08,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf0,0x28,0xe6,0x20,0xe0,0x20,
+/* 31675 0x7bbb "箻" */
+0x20,0x3f,0x48,0x85,0x00,0x13,0x20,0x47,0x88,0x13,0x30,0x53,0x90,0x17,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,
+/* 31676 0x7bbc "箼" */
+0x20,0x3f,0x48,0x85,0x3f,0x20,0x3f,0x20,0x2f,0x22,0x24,0x2f,0x20,0x4f,0x40,0xbf,
+0x40,0x7e,0x90,0x08,0xfc,0x04,0xfc,0x00,0xf8,0x00,0x10,0xf8,0x80,0xf8,0x80,0xfe,
+/* 31677 0x7bbd "箽" */
+0x20,0x3e,0x48,0x9f,0x01,0x7f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,
+0x40,0x7e,0x90,0xf0,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 31678 0x7bbe "箾" */
+0x20,0x3f,0x48,0x85,0x08,0x49,0x2a,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x41,0x45,0x42,
+0x40,0x7e,0x90,0x08,0x00,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 31679 0x7bbf "箿" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x00,0x7f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x00,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x3e,0xd0,0x10,
+/* 31680 0x7bc0 "節" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x48,0x44,0x5a,0x62,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 31681 0x7bc1 "篁" */
+0x20,0x20,0x7e,0x51,0x8a,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x01,0x3f,0x01,0xff,
+0x40,0x40,0xfe,0x10,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,
+/* 31682 0x7bc2 "篂" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x1f,0x21,0x3f,0x41,0x9f,0x01,0xff,0x00,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xf0,0x00,0xfe,0x00,
+/* 31683 0x7bc3 "篃" */
+0x20,0x3f,0x48,0x85,0x3f,0x21,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x4f,0x48,0x8f,0x08,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 31684 0x7bc4 "範" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x44,0x44,0x44,0x54,0x48,0x42,0xc2,0x42,0x3e,
+/* 31685 0x7bc5 "篅" */
+0x20,0x3f,0x48,0x85,0x01,0x21,0x21,0x3f,0x00,0xff,0x02,0x3f,0x24,0x24,0x24,0x20,
+0x40,0x7e,0x90,0x08,0x00,0x08,0x08,0xf8,0x00,0xfe,0x00,0xf8,0x88,0x88,0xa8,0x10,
+/* 31686 0x7bc6 "篆" */
+0x20,0x3e,0x48,0x88,0x0f,0x10,0x1f,0x00,0xff,0x06,0x3b,0x04,0x19,0x62,0x0c,0x73,
+0x40,0x7e,0x90,0x00,0xe0,0x20,0xc0,0x40,0xfe,0x00,0x08,0xb0,0xc0,0xa0,0x98,0x06,
+/* 31687 0x7bc7 "篇" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x20,0x3f,0x20,0x2f,0x29,0x29,0x2f,0x49,0x49,0x88,
+0x40,0x7e,0x90,0x08,0x80,0xfc,0x04,0xfc,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0x0c,
+/* 31688 0x7bc8 "篈" */
+0x20,0x3f,0x48,0x85,0x08,0x08,0x7f,0x08,0xff,0x08,0x08,0x7f,0x08,0x0f,0xf0,0x40,
+0x40,0x7e,0x90,0x08,0x00,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 31689 0x7bc9 "築" */
+0x20,0x3f,0x48,0x85,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x01,0x7f,0x05,0x09,0x31,0xc1,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0xfc,0x40,0x20,0x18,0x06,
+/* 31690 0x7bca "篊" */
+0x10,0x10,0x3f,0x48,0x85,0x20,0x10,0x13,0x80,0x48,0x48,0x17,0xe0,0x20,0x21,0x22,
+0x40,0x40,0x7e,0x90,0x08,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x00,0x90,0x08,0x04,
+/* 31691 0x7bcb "篋" */
+0x10,0x10,0x3f,0x48,0x85,0x3f,0x20,0x2f,0x20,0x24,0x24,0x2a,0x31,0x22,0x24,0x3f,
+0x40,0x40,0x7e,0x90,0x08,0xfc,0x80,0xf8,0x80,0x90,0x90,0xa8,0x44,0x20,0x10,0xfe,
+/* 31692 0x7bcc "篌" */
+0x20,0x3f,0x48,0x85,0x09,0x08,0x10,0x37,0x51,0x91,0x12,0x10,0x17,0x10,0x11,0x12,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0x10,0xfc,0x00,0xf8,0x40,0x40,0xfc,0xa0,0x10,0x0c,
+/* 31693 0x7bcd "篍" */
+0x20,0x3f,0x48,0x85,0x0c,0x70,0x10,0x10,0xfc,0x31,0x38,0x54,0x50,0x90,0x11,0x12,
+0x40,0x7e,0x90,0x08,0x20,0x20,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 31694 0x7bce "篎" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7c,0x44,0x7c,0x45,0x7d,0x46,0x44,0x7c,0x01,0x06,
+0x40,0x40,0x7e,0x90,0x08,0x20,0x20,0xa8,0xa4,0x22,0x22,0x28,0x10,0x60,0x80,0x00,
+/* 31695 0x7bcf "篏" */
+0x10,0x10,0x3f,0x48,0x85,0x22,0x22,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x00,
+0x40,0x40,0x7e,0x90,0x28,0x20,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 31696 0x7bd0 "篐" */
+0x20,0x3f,0x48,0x85,0x10,0x13,0xfe,0x12,0x32,0x3a,0x56,0x92,0x12,0x12,0x12,0x13,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x20,0x20,0xfc,0xa4,0xa4,0xa4,0xb4,0xa8,0x20,0xfe,
+/* 31697 0x7bd1 "篑" */
+0x20,0x3f,0x48,0x85,0x1f,0x11,0x1f,0x01,0xff,0x00,0x1f,0x10,0x11,0x02,0x0c,0x70,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0x10,0xc0,0x30,0x08,
+/* 31698 0x7bd2 "篒" */
+0x20,0x20,0x7e,0x51,0x8a,0x0e,0x31,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x11,0x14,0x18,
+0x40,0x40,0xfe,0x10,0x88,0x60,0x18,0xe6,0x20,0xe0,0x20,0xe0,0x08,0x90,0x60,0x10,
+/* 31699 0x7bd3 "篓" */
+0x20,0x3f,0x48,0x85,0x11,0x09,0x7f,0x05,0x19,0x61,0x04,0xff,0x08,0x1e,0x03,0x3c,
+0x40,0x7e,0x90,0x08,0x10,0x20,0xfc,0x40,0x30,0x0c,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 31700 0x7bd4 "篔" */
+0x20,0x3e,0x49,0x9f,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,
+0x80,0xfe,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,
+/* 31701 0x7bd5 "篕" */
+0x20,0x3f,0x48,0x85,0x01,0x3f,0x01,0x7f,0x08,0x10,0x3f,0x00,0x3f,0x24,0x24,0xff,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0xfc,0x00,0x10,0xf8,0x00,0xf8,0x48,0x48,0xfe,
+/* 31702 0x7bd6 "篖" */
+0x20,0x3e,0x49,0x80,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x20,0x4f,0x48,0x8f,0x08,
+0x80,0xfe,0x10,0x80,0xfc,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x80,0xf8,0x08,0xf8,0x08,
+/* 31703 0x7bd7 "篗" */
+0x20,0x3e,0x49,0x88,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3f,0x0c,0x03,0x7c,
+0x80,0xfe,0x10,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xf0,0x60,0x80,0x7c,
+/* 31704 0x7bd8 "篘" */
+0x20,0x3e,0x49,0x90,0x1f,0x21,0x51,0x1f,0x02,0x14,0x1f,0x21,0x51,0x1f,0x04,0x38,
+0x80,0xfe,0x10,0x00,0xfc,0x04,0x14,0xf4,0x08,0x00,0xfc,0x04,0x14,0xf4,0x14,0x08,
+/* 31705 0x7bd9 "篙" */
+0x20,0x3e,0x48,0x82,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,
+0x40,0x7e,0x90,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x0c,
+/* 31706 0x7bda "篚" */
+0x20,0x3f,0x48,0x85,0x3f,0x22,0x22,0x3e,0x22,0x2e,0x22,0x3e,0x22,0x22,0x3f,0x00,
+0x40,0x7e,0x90,0x08,0xfc,0x40,0x40,0x78,0x40,0x70,0x40,0x78,0x40,0x40,0xfc,0x00,
+/* 31707 0x7bdb "篛" */
+0x20,0x3f,0x48,0x85,0x00,0x7e,0x02,0x7e,0x40,0x7e,0x02,0x22,0x1a,0x62,0x14,0x08,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x04,0xfc,0x80,0xfc,0x04,0x44,0x34,0xc4,0x28,0x10,
+/* 31708 0x7bdc "篜" */
+0x20,0x3f,0x48,0x85,0x1f,0x00,0x7d,0x05,0x09,0x31,0xc5,0x02,0x3f,0x00,0x24,0x42,
+0x40,0x7e,0x90,0x08,0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x00,0x88,0x44,
+/* 31709 0x7bdd "篝" */
+0x20,0x3f,0x48,0x85,0x7f,0x04,0x3f,0x04,0xff,0x11,0x1f,0x11,0xff,0x10,0x10,0x10,
+0x40,0x7e,0x90,0x48,0xfc,0x40,0xf8,0x40,0xfe,0x10,0xf0,0x10,0xfe,0x10,0x50,0x20,
+/* 31710 0x7bde "篞" */
+0x20,0x3f,0x48,0x85,0x20,0x17,0x14,0x87,0x44,0x57,0x10,0x27,0xe0,0x20,0x2f,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 31711 0x7bdf "篟" */
+0x20,0x3f,0x48,0x85,0x08,0x0f,0x10,0x33,0x50,0x97,0x12,0x13,0x12,0x13,0x12,0x12,
+0x40,0x7e,0x90,0x08,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 31712 0x7be0 "篠" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0x22,0x68,0xab,0x28,0x29,0x28,0x28,0x29,0x22,0x20,
+0x40,0x7e,0x90,0x08,0x80,0xf8,0x88,0x70,0xae,0x20,0xfc,0x20,0xa8,0x24,0xa4,0x40,
+/* 31713 0x7be1 "篡" */
+0x20,0x3f,0x48,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x02,0x7f,0x04,0x1a,0xe4,0x0f,
+0x40,0x7e,0x90,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x30,0x4e,0xe0,
+/* 31714 0x7be2 "篢" */
+0x20,0x3e,0x49,0xbf,0x01,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x80,0xfe,0x10,0xf8,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 31715 0x7be3 "篣" */
+0x20,0x3f,0x48,0x85,0x3f,0x08,0x04,0x7f,0x42,0x81,0x3f,0x04,0x07,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x08,0xf8,0x20,0x40,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0x50,0x20,
+/* 31716 0x7be4 "篤" */
+0x20,0x3f,0x48,0x85,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x00,0x29,0x44,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 31717 0x7be5 "篥" */
+0x10,0x10,0x3f,0x48,0x85,0x7f,0x04,0x3f,0x24,0x3f,0x01,0x7f,0x05,0x19,0xe1,0x01,
+0x40,0x40,0x7e,0x90,0x08,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x40,0x30,0x0e,0x00,
+/* 31718 0x7be6 "篦" */
+0x20,0x3e,0x48,0x82,0x3f,0x24,0x23,0x24,0x3f,0x00,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x40,0x7e,0x90,0x00,0xf8,0x48,0x88,0x48,0xf8,0x00,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 31719 0x7be7 "篧" */
+0x20,0x3f,0x48,0x85,0x04,0x7f,0x45,0x08,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xfc,0x04,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 31720 0x7be8 "篨" */
+0x20,0x3f,0x48,0x85,0x78,0x48,0x51,0x62,0x55,0x48,0x4b,0x68,0x51,0x42,0x45,0x40,
+0x40,0x7e,0x90,0x08,0x40,0xa0,0x10,0x08,0xf6,0x40,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 31721 0x7be9 "篩" */
+0x20,0x3e,0x48,0x90,0x23,0x7c,0x44,0x45,0x7d,0x41,0x7d,0x45,0x45,0x7d,0x44,0x00,
+0x40,0x7e,0x90,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 31722 0x7bea "篪" */
+0x20,0x3f,0x48,0x85,0x3f,0x20,0x20,0x2f,0x28,0x28,0x2b,0x28,0x48,0x51,0x92,0x24,
+0x40,0x7e,0x90,0x7c,0x80,0xf8,0x80,0xfc,0x84,0xf0,0x88,0x78,0x00,0xe0,0x24,0x1c,
+/* 31723 0x7beb "篫" */
+0x20,0x3f,0x48,0x85,0x7d,0x11,0x11,0x1d,0xe2,0x5f,0x01,0x1f,0x01,0x7f,0x01,0x03,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0x90,0x52,0x0e,0xf0,0x00,0xf0,0x00,0xfc,0x00,0x00,
+/* 31724 0x7bec "篬" */
+0x20,0x3f,0x48,0x85,0x06,0x1a,0xe1,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x2f,0x48,0x8f,
+0x40,0x7e,0x90,0x08,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,
+/* 31725 0x7bed "篭" */
+0x20,0x3f,0x50,0x8a,0x01,0x3f,0x08,0xff,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 31726 0x7bee "篮" */
+0x20,0x3f,0x48,0x85,0x04,0x24,0x24,0x24,0x25,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x7e,0x90,0x08,0x80,0x80,0xfc,0xa0,0x10,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 31727 0x7bef "篯" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x3c,0x41,0xbc,0x10,0x13,0xfc,0x10,0x10,0x15,0x18,
+0x40,0x40,0x7e,0x90,0x28,0x24,0x3e,0xe0,0x20,0x2e,0xf4,0x28,0x12,0x6a,0x86,0x02,
+/* 31728 0x7bf0 "篰" */
+0x20,0x3f,0x48,0x85,0x10,0x08,0x7f,0x22,0x14,0xff,0x00,0x3e,0x22,0x22,0x3e,0x22,
+0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x48,0x50,0xc8,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 31729 0x7bf1 "篱" */
+0x20,0x3f,0x48,0x85,0x00,0xff,0x04,0x13,0x14,0x1f,0x01,0x7f,0x44,0x4f,0x44,0x40,
+0x40,0x7e,0x90,0x08,0x80,0xfe,0x40,0x90,0x50,0xf0,0x00,0xfc,0x44,0xe4,0x24,0x0c,
+/* 31730 0x7bf2 "篲" */
+0x20,0x3f,0x48,0x85,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x3f,0x00,0x1f,0x00,0x3f,
+0x40,0x7e,0x90,0x08,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,
+/* 31731 0x7bf3 "篳" */
+0x20,0x3f,0x48,0x85,0x3f,0x21,0x3f,0x21,0x3f,0x09,0xff,0x09,0x3f,0x01,0x7f,0x01,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfe,0x20,0xf8,0x00,0xfc,0x00,
+/* 31732 0x7bf4 "篴" */
+0x20,0x3f,0x48,0x85,0x23,0x10,0x11,0x06,0x70,0x11,0x16,0x10,0x11,0x16,0x28,0x47,
+0x40,0x7e,0x90,0x08,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x24,0xa0,0x40,0xfe,
+/* 31733 0x7bf5 "篵" */
+0x20,0x3f,0x48,0x85,0x11,0x21,0x41,0x8a,0x14,0x30,0x52,0x92,0x12,0x15,0x14,0x18,
+0x40,0x7e,0x90,0x08,0x10,0x10,0x10,0xa8,0x44,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 31734 0x7bf6 "篶" */
+0x20,0x3e,0x48,0xff,0x01,0x11,0x11,0xff,0x10,0x1f,0x20,0x3f,0x00,0x49,0x84,0x00,
+0x40,0x7e,0x90,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 31735 0x7bf7 "篷" */
+0x20,0x3f,0x48,0x85,0x23,0x15,0x10,0x07,0x70,0x13,0x10,0x11,0x10,0x17,0x28,0x47,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xe0,0x1c,0x40,0xf8,0x40,0xf0,0x40,0xfc,0x40,0xfe,
+/* 31736 0x7bf8 "篸" */
+0x20,0x3e,0x49,0x88,0x1f,0x10,0x25,0x7e,0x04,0x19,0xe6,0x19,0x06,0x18,0x07,0x38,
+0x80,0xfe,0x10,0x20,0xf0,0x20,0x48,0xfc,0x40,0x30,0x4e,0x90,0x20,0xc0,0x00,0x00,
+/* 31737 0x7bf9 "篹" */
+0x20,0x3f,0x48,0x85,0x1f,0x14,0x12,0x1f,0x02,0xff,0x08,0x3f,0xc8,0x08,0x08,0x07,
+0x40,0x7e,0x90,0x08,0xf0,0x90,0x50,0xf0,0x00,0xfe,0x20,0xd8,0x46,0xc0,0x08,0xf8,
+/* 31738 0x7bfa "篺" */
+0x10,0x10,0x3f,0x48,0x95,0x10,0x11,0x7d,0x11,0x11,0x1d,0x70,0x10,0x13,0x50,0x20,
+0x40,0x40,0x7e,0x90,0x28,0x40,0xfc,0x24,0xfc,0x44,0xfc,0x50,0x90,0xfe,0x10,0x10,
+/* 31739 0x7bfb "篻" */
+0x20,0x3f,0x48,0x85,0x7f,0x04,0x3f,0x24,0x3f,0x00,0x3f,0x00,0xff,0x11,0x25,0x02,
+0x40,0x7e,0x90,0x08,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x10,0x08,0x00,
+/* 31740 0x7bfc "篼" */
+0x20,0x3f,0x48,0x85,0x12,0x67,0x44,0x47,0x44,0x57,0x60,0x04,0x04,0x08,0x10,0x60,
+0x40,0x7e,0x90,0x08,0x00,0xdc,0x44,0xc4,0x44,0xdc,0x00,0x40,0x40,0x42,0x42,0x3e,
+/* 31741 0x7bfd "篽" */
+0x20,0x3f,0x48,0x85,0x14,0x27,0x49,0x81,0x17,0x21,0x61,0xa5,0x25,0x25,0x2e,0x24,
+0x40,0x7e,0x90,0x08,0x00,0xde,0x12,0x12,0xd2,0x12,0x12,0xd2,0x1a,0xd4,0x10,0x10,
+/* 31742 0x7bfe "篾" */
+0x20,0x3f,0x48,0x85,0x3f,0x24,0x24,0x3f,0x00,0x3f,0x20,0x30,0x28,0x24,0x40,0x83,
+0x40,0x7e,0x90,0x08,0xf8,0x48,0x48,0xf8,0x90,0xfc,0x80,0x48,0x50,0x24,0xd4,0x0c,
+/* 31743 0x7bff "篿" */
+0x20,0x3e,0x49,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x7f,0x00,0xff,0x08,0x04,
+0x80,0xfe,0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x04,0xfc,0x20,0xfe,0x20,0x60,
+/* 31744 0x7c00 "簀" */
+0x20,0x3e,0x49,0xbf,0x01,0x3f,0x01,0xff,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x80,0xfe,0x10,0xf8,0x00,0xf8,0x00,0xfe,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 31745 0x7c01 "簁" */
+0x20,0x3f,0x48,0x85,0x10,0x21,0x41,0x89,0x17,0x30,0x50,0x91,0x11,0x11,0x12,0x14,
+0x40,0x7e,0x90,0x08,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x20,0x3e,0x20,0xa0,0x7e,
+/* 31746 0x7c02 "簂" */
+0x20,0x3f,0x48,0x85,0x7f,0x40,0x7f,0x40,0x5e,0x52,0x5e,0x40,0x46,0x59,0x7f,0x40,
+0x40,0x7e,0x90,0x08,0xfc,0xa4,0xfc,0x84,0x94,0x94,0x64,0x54,0xb4,0x14,0xfc,0x04,
+/* 31747 0x7c03 "簃" */
+0x20,0x3f,0x48,0x85,0x0c,0x70,0x13,0x10,0xfc,0x30,0x3b,0x54,0x55,0x90,0x10,0x13,
+0x40,0x7e,0x90,0x28,0x40,0xfc,0x08,0x90,0x60,0x90,0x3e,0x42,0xa4,0x18,0x60,0x80,
+/* 31748 0x7c04 "簄" */
+0x20,0x3e,0x49,0xbf,0x20,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x28,0x4f,0x48,0x87,
+0x80,0xfe,0x10,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x88,0xf8,0x02,0xfe,
+/* 31749 0x7c05 "簅" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x04,0x02,0x3f,0x20,0x24,0x2f,0x30,0x47,0x40,0x9f,
+0x40,0x7e,0x90,0x08,0x80,0xfc,0x10,0x20,0xfe,0x80,0x80,0xfc,0x80,0xf8,0x80,0xfe,
+/* 31750 0x7c06 "簆" */
+0x20,0x3f,0x50,0x8a,0x01,0x7f,0x40,0xbe,0x00,0x7e,0x14,0x14,0x14,0x24,0x44,0x83,
+0x40,0x7e,0x90,0x08,0x00,0xfe,0x22,0x3c,0x20,0xf8,0x08,0x50,0x24,0xd4,0x04,0xfc,
+/* 31751 0x7c07 "簇" */
+0x20,0x3f,0x48,0x85,0x20,0x10,0xfe,0x21,0x20,0x3c,0x25,0x24,0x25,0x44,0x54,0x89,
+0x40,0x7e,0x90,0x08,0x40,0x40,0xfe,0x20,0x40,0xfc,0x20,0x20,0xfe,0x50,0x88,0x06,
+/* 31752 0x7c08 "簈" */
+0x20,0x3f,0x48,0x85,0x3f,0x20,0x3f,0x22,0x24,0x2f,0x24,0x24,0x3f,0x44,0x44,0x88,
+0x40,0x7e,0x90,0x08,0xfc,0x04,0xfc,0x08,0x10,0x78,0x10,0x10,0x7c,0x10,0x10,0x10,
+/* 31753 0x7c09 "簉" */
+0x20,0x3f,0x48,0x85,0x22,0x13,0x14,0x00,0x77,0x10,0x13,0x12,0x13,0x28,0x47,0x00,
+0x40,0x7e,0x90,0x48,0x40,0xf8,0x40,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x00,
+/* 31754 0x7c0a "簊" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x11,0x2f,0xc1,0x3f,
+0x40,0x7e,0x90,0x08,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0xe8,0x06,0xf8,
+/* 31755 0x7c0b "簋" */
+0x20,0x3f,0x48,0x85,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x14,0x18,0x3f,0x24,0x24,0xff,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xf0,0x10,0xf4,0x88,0x70,0x0e,0xf8,0x48,0x48,0xfe,
+/* 31756 0x7c0c "簌" */
+0x20,0x3f,0x48,0x85,0x08,0xff,0x08,0x7f,0x49,0x49,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x40,0x7e,0x90,0x08,0x20,0xa0,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 31757 0x7c0d "簍" */
+0x20,0x3f,0x48,0x85,0x3f,0x21,0xff,0x21,0x3f,0x11,0x1f,0x04,0xff,0x08,0x07,0x78,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xfe,0x08,0xf8,0x10,0xf0,0x00,0xfe,0x20,0xc0,0x38,
+/* 31758 0x7c0e "簎" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0x13,0xfc,0x13,0x10,0x1d,0xf1,0x11,0x11,0x51,0x21,
+0x40,0x7e,0x90,0x08,0x90,0x90,0xfc,0x90,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 31759 0x7c0f "簏" */
+0x20,0x3f,0x48,0x85,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x28,0x2f,0x48,0x4b,0x8c,
+0x40,0x7e,0x90,0x08,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x48,0x70,0x44,0x44,0x3c,
+/* 31760 0x7c10 "簐" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x42,0x84,0x10,0x10,0x10,0x28,0xa8,0x44,0x82,
+/* 31761 0x7c11 "簑" */
+0x20,0x3f,0x48,0x85,0x7f,0x00,0x1f,0x10,0xff,0x10,0x1f,0x04,0x08,0x38,0xcb,0x0c,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf0,0x10,0xfe,0x10,0xf0,0x88,0x50,0x20,0x18,0x06,
+/* 31762 0x7c12 "簒" */
+0x20,0x3e,0x49,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x02,0xff,0x08,0x35,0xca,0x17,
+0x80,0xfe,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x18,0x26,0xf0,
+/* 31763 0x7c13 "簓" */
+0x20,0x3f,0x48,0x85,0x00,0x7f,0x49,0x5d,0x49,0x7f,0x41,0x5d,0x55,0x5d,0x45,0x82,
+0x40,0x7e,0x90,0x08,0x04,0x08,0x10,0x60,0x04,0x08,0x10,0x62,0x04,0x08,0x10,0x60,
+/* 31764 0x7c14 "簔" */
+0x20,0x3f,0x48,0x85,0x7f,0x00,0x3f,0x10,0xff,0x10,0x3f,0x04,0x08,0x38,0xcb,0x0c,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x10,0xfe,0x10,0xf8,0x88,0x50,0x20,0x18,0x06,
+/* 31765 0x7c15 "簕" */
+0x20,0x3f,0x48,0x85,0x22,0x7f,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0xff,0x08,0x09,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 31766 0x7c16 "簖" */
+0x20,0x3f,0x48,0x85,0x04,0x55,0x4e,0x44,0x5f,0x44,0x4e,0x55,0x44,0x7f,0x00,0x01,
+0x40,0x7e,0x90,0x08,0x0c,0x70,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 31767 0x7c17 "簗" */
+0x20,0x3f,0x48,0x95,0x0b,0x40,0x2a,0x12,0x75,0x12,0x14,0x01,0x7f,0x05,0x19,0xe1,
+0x40,0x7e,0x90,0x08,0xf0,0x90,0x94,0x92,0x12,0x50,0x20,0x00,0xfc,0x40,0x30,0x0e,
+/* 31768 0x7c18 "簘" */
+0x20,0x3f,0x48,0x85,0x3f,0x01,0xff,0x01,0x3f,0x09,0x25,0x2f,0x23,0x25,0x29,0x41,
+0x40,0x7e,0x90,0x08,0xf0,0x10,0xfc,0x10,0xf0,0x20,0x48,0xe8,0x88,0x48,0x28,0x08,
+/* 31769 0x7c19 "簙" */
+0x20,0x3e,0x49,0x80,0x27,0x20,0x23,0xfa,0x23,0x22,0x23,0x22,0x20,0x2f,0x21,0x20,
+0x80,0xfe,0x50,0x48,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x48,0x10,0xfe,0x10,0xb0,
+/* 31770 0x7c1a "簚" */
+0x20,0x3f,0x48,0x85,0x7f,0x44,0x44,0x7f,0x00,0xff,0x08,0x7f,0x49,0x4d,0x4a,0x08,
+0x40,0x7e,0x90,0x08,0xfc,0x44,0x44,0xfc,0x28,0xfe,0x20,0x24,0x28,0x10,0x2a,0x46,
+/* 31771 0x7c1b "簛" */
+0x20,0x3f,0x48,0x85,0x22,0x22,0xff,0x22,0x3e,0x22,0x3e,0x22,0xff,0x22,0x41,0x80,
+0x40,0x7e,0x90,0x08,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,
+/* 31772 0x7c1c "簜" */
+0x20,0x3f,0x48,0x85,0x23,0x12,0x93,0x42,0x43,0x10,0x2f,0xe2,0x27,0x29,0x22,0x04,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x24,0x54,0x88,
+/* 31773 0x7c1d "簝" */
+0x20,0x3f,0x48,0x85,0x7f,0x04,0x28,0x1f,0x28,0xcf,0x08,0x0f,0x01,0x11,0x25,0x02,
+0x40,0x7e,0x90,0x08,0xfc,0x40,0x28,0xf0,0x28,0xe6,0x20,0xe0,0x00,0x10,0x08,0x00,
+/* 31774 0x7c1e "簞" */
+0x20,0x3f,0x48,0x85,0x3e,0x22,0x3e,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x40,0x7e,0x90,0x08,0xf8,0x88,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 31775 0x7c1f "簟" */
+0x20,0x3e,0x48,0xff,0x04,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,
+0x40,0x7e,0x90,0xfc,0x40,0xf8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 31776 0x7c20 "簠" */
+0x20,0x3f,0x48,0x85,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x00,0x3f,0x24,0xff,
+0x40,0x7e,0x90,0x28,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x00,0xf8,0x48,0xfe,
+/* 31777 0x7c21 "簡" */
+0x20,0x3f,0x48,0x85,0x3e,0x22,0x3e,0x22,0x3e,0x20,0x27,0x24,0x27,0x24,0x27,0x20,
+0x40,0x7e,0x90,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xf4,0x08,
+/* 31778 0x7c22 "簢" */
+0x20,0x3f,0x48,0x85,0x3e,0x22,0x3e,0x22,0x3f,0x20,0x2f,0x20,0x22,0x21,0x26,0x20,
+0x40,0x7e,0x90,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x84,0xf4,0x44,0x44,0x84,0x54,0x08,
+/* 31779 0x7c23 "簣" */
+0x20,0x3e,0x49,0x9f,0x11,0x1f,0x01,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x80,0xfe,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 31780 0x7c24 "簤" */
+0x20,0x3e,0x48,0xbf,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0x7e,0x90,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 31781 0x7c25 "簥" */
+0x20,0x3f,0x48,0x85,0x00,0x1f,0x02,0xff,0x08,0x37,0xc4,0x3f,0x20,0x27,0x24,0x27,
+0x40,0x7e,0x90,0x08,0x70,0x80,0x00,0xfe,0x20,0xd8,0x46,0xf8,0x08,0xc8,0x48,0xd8,
+/* 31782 0x7c26 "簦" */
+0x20,0x3f,0x48,0x85,0x00,0x7e,0x04,0x28,0x17,0x20,0xdf,0x10,0x1f,0x08,0x04,0x7f,
+0x40,0x7e,0x90,0x08,0x90,0xa0,0x44,0x28,0xd0,0x08,0xf6,0x10,0xf0,0x20,0x40,0xfc,
+/* 31783 0x7c27 "簧" */
+0x20,0x3e,0x48,0x84,0x3f,0x04,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 31784 0x7c28 "簨" */
+0x20,0x3f,0x48,0x85,0x7c,0x44,0x7c,0x42,0x3e,0x04,0x3f,0x04,0xff,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x08,0xf8,0x88,0xf8,0x84,0x7c,0x40,0xf8,0x40,0xfe,0x20,0x10,0x08,
+/* 31785 0x7c29 "簩" */
+0x20,0x3f,0x48,0x85,0x08,0x2a,0x08,0x14,0x22,0x7f,0x40,0x02,0x3f,0x04,0x08,0x30,
+0x40,0x7e,0x90,0x08,0x20,0xa8,0x20,0x50,0x88,0xfc,0x04,0x00,0xf8,0x08,0x50,0x20,
+/* 31786 0x7c2a "簪" */
+0x20,0x3f,0x48,0x85,0x3e,0x08,0x48,0x7e,0x14,0x24,0x46,0x3f,0x20,0x3f,0x20,0x3f,
+0x40,0x7e,0x90,0x08,0x7c,0x10,0x90,0xfe,0x28,0x4a,0x86,0xf8,0x08,0xf8,0x08,0xf8,
+/* 31787 0x7c2b "簫" */
+0x20,0x3e,0x49,0xbf,0x01,0xff,0x01,0x3f,0x25,0x3d,0x21,0x3f,0x21,0x3d,0x25,0x45,
+0x80,0xfe,0x10,0xf8,0x08,0xfe,0x08,0xf8,0x48,0x78,0x08,0xf8,0x08,0x78,0x48,0x48,
+/* 31788 0x7c2c "簬" */
+0x20,0x3f,0x48,0x85,0x00,0x78,0x49,0x4a,0x78,0x11,0x12,0x5d,0x51,0x51,0x5d,0xe1,
+0x40,0x7e,0x90,0x08,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 31789 0x7c2d "簭" */
+0x20,0x3f,0x48,0x85,0x7f,0x11,0x29,0x45,0xff,0x08,0x30,0xdf,0x10,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0xfc,0x10,0x28,0x44,0xfe,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,
+/* 31790 0x7c2e "簮" */
+0x20,0x3f,0x48,0x85,0x08,0x3e,0x08,0x7e,0x14,0x22,0x5f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x7e,0x90,0x08,0x20,0xf8,0x20,0xfc,0x50,0x88,0xf4,0x10,0xf0,0x10,0xf0,0x10,
+/* 31791 0x7c2f "簯" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0x13,0xfc,0x10,0x38,0x34,0x50,0x53,0x90,0x11,0x12,
+0x40,0x7e,0x90,0x08,0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x04,0x02,
+/* 31792 0x7c30 "簰" */
+0x20,0x3f,0x48,0x85,0x08,0x48,0x49,0x7d,0x41,0x41,0x79,0x48,0x49,0x4b,0x48,0x88,
+0x40,0x7e,0x90,0x08,0x20,0x40,0xfc,0x24,0xfc,0x44,0xfc,0xa0,0x20,0xfe,0x20,0x20,
+/* 31793 0x7c31 "簱" */
+0x20,0x3f,0x48,0x85,0x10,0x08,0x7e,0x10,0x10,0x1e,0x12,0x12,0x22,0x23,0x4a,0x84,
+0x40,0x7e,0x90,0x08,0x48,0x48,0xfc,0x48,0x78,0x48,0x78,0x48,0x48,0xfe,0x48,0x84,
+/* 31794 0x7c32 "簲" */
+0x20,0x3f,0x48,0x85,0x00,0x3c,0x25,0x25,0x3d,0x25,0x25,0x3c,0x24,0x27,0x54,0x88,
+0x40,0x7e,0x90,0x08,0x20,0x40,0xfc,0x24,0xfc,0x44,0xfc,0x50,0x90,0xfe,0x10,0x10,
+/* 31795 0x7c33 "簳" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x08,0x7f,0x08,0x08,
+0x40,0x7e,0x90,0x08,0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 31796 0x7c34 "簴" */
+0x20,0x3f,0x48,0x85,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x29,0x25,0x5f,0x42,0x84,
+0x40,0x7e,0x90,0x08,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x24,0x28,0xfe,0x10,0x08,
+/* 31797 0x7c35 "簵" */
+0x20,0x3f,0x48,0x85,0x10,0xfe,0x10,0x7d,0x54,0x7c,0x57,0x7c,0x10,0xfe,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x40,0x78,0x88,0x50,0x20,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,
+/* 31798 0x7c36 "簶" */
+0x20,0x3f,0x48,0x85,0x20,0x11,0xfc,0x08,0x10,0x3b,0x54,0x95,0x10,0x11,0x12,0x10,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x20,0x34,0xa8,0x24,0xa2,0x40,
+/* 31799 0x7c37 "簷" */
+0x20,0x3f,0x48,0x9f,0x20,0x7f,0xa4,0x2b,0x20,0x27,0x20,0x27,0x20,0x47,0x44,0x87,
+0x40,0x7e,0x90,0xf8,0x20,0xfe,0x88,0xf4,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 31800 0x7c38 "簸" */
+0x20,0x3f,0x48,0x85,0x24,0x24,0xfe,0x24,0x3c,0x24,0x3c,0x24,0xfe,0x29,0x45,0x82,
+0x40,0x7e,0x90,0x08,0x10,0x10,0xfe,0x92,0x90,0xfc,0xa4,0xa4,0xa8,0x10,0x28,0x46,
+/* 31801 0x7c39 "簹" */
+0x20,0x3e,0x48,0x91,0x09,0x3f,0x20,0x4f,0x08,0x0f,0x00,0x3f,0x21,0x3f,0x21,0x3f,
+0x40,0x7e,0x90,0x10,0x20,0xfc,0x04,0xe8,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 31802 0x7c3a "簺" */
+0x20,0x3f,0x48,0x85,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x11,0x2f,0xc1,0x1f,
+0x40,0x7e,0x90,0x08,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0xe8,0x06,0xf0,
+/* 31803 0x7c3b "簻" */
+0x20,0x3f,0x48,0x85,0x21,0x11,0x11,0x01,0x73,0x12,0x12,0x12,0x12,0x12,0x2a,0x47,
+0x40,0x7e,0x90,0x08,0xf8,0x08,0xe8,0x28,0xfc,0x04,0xf4,0x94,0xf4,0x14,0x08,0xfe,
+/* 31804 0x7c3c "簼" */
+0x20,0x3f,0x48,0x85,0x21,0x27,0xf9,0x27,0x29,0x37,0xe2,0x23,0x22,0x2f,0xa2,0x42,
+0x40,0x7e,0x90,0x08,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x48,0xf8,0x48,0xfe,0x08,0x18,
+/* 31805 0x7c3d "簽" */
+0x20,0x3f,0x50,0x89,0x02,0x04,0x18,0x67,0x00,0x3e,0x22,0x22,0x3e,0x08,0x14,0x22,
+0x40,0x7e,0x90,0x08,0x80,0x40,0x30,0xcc,0x00,0xf8,0x88,0x88,0xf8,0x20,0x50,0x88,
+/* 31806 0x7c3e "簾" */
+0x20,0x3f,0x48,0x85,0x3f,0x22,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x46,0x4a,0xb2,
+0x40,0x7e,0x90,0x08,0xfc,0x20,0xfc,0x40,0xf8,0x48,0xfc,0x48,0xf8,0x60,0x50,0x4c,
+/* 31807 0x7c3f "簿" */
+0x20,0x3f,0x48,0x85,0x27,0x10,0x13,0x82,0x43,0x4a,0x0b,0x12,0xf0,0x27,0x22,0x21,
+0x40,0x7e,0x90,0x48,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x48,0x10,0xfc,0x10,0x30,
+/* 31808 0x7c40 "籀" */
+0x20,0x3f,0x48,0x85,0x20,0x27,0xf4,0x25,0x36,0x20,0xe7,0x24,0x27,0x24,0xa7,0x44,
+0x40,0x7e,0x90,0x08,0x80,0x7c,0xa4,0xa4,0x54,0x88,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 31809 0x7c41 "籁" */
+0x20,0x3f,0x48,0x85,0x08,0x7f,0x08,0x3e,0x2a,0x2a,0x3e,0x08,0x1c,0x2a,0x48,0x08,
+0x40,0x7e,0x90,0x08,0x20,0x3c,0x44,0x88,0x7c,0x44,0x54,0x54,0x54,0x28,0x44,0x82,
+/* 31810 0x7c42 "籂" */
+0x20,0x3f,0x48,0x85,0x08,0x14,0x2a,0x7f,0xa2,0x3e,0x22,0x3e,0x28,0x24,0x2a,0x30,
+0x40,0x7e,0x90,0x08,0x40,0x40,0xfe,0x10,0x10,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 31811 0x7c43 "籃" */
+0x20,0x3f,0x48,0x85,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x3f,0x24,0x24,0xff,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xf8,0x48,0x48,0xfe,
+/* 31812 0x7c44 "籄" */
+0x20,0x3f,0x48,0xbf,0x20,0x27,0x24,0x27,0x20,0x3f,0x24,0x27,0x24,0x27,0x22,0x3f,
+0x40,0x7e,0x90,0xfc,0x80,0xf0,0x90,0xf0,0x80,0xfc,0x10,0xf0,0x10,0xf0,0x20,0xfc,
+/* 31813 0x7c45 "籅" */
+0x20,0x3f,0x48,0x85,0x0a,0x33,0x22,0x3a,0x23,0x20,0x3a,0x22,0xff,0x08,0x10,0x20,
+0x40,0x7e,0x90,0x08,0x00,0xb8,0x08,0x38,0x88,0x88,0xb8,0x88,0xfe,0x20,0x10,0x08,
+/* 31814 0x7c46 "籆" */
+0x20,0x3e,0x49,0x88,0x7f,0x09,0x1f,0x31,0x5f,0x91,0x1f,0x10,0x3f,0x08,0x07,0xf8,
+0x80,0xfe,0x10,0x20,0xfc,0x20,0xf8,0x00,0xf0,0x00,0xfc,0x00,0xf0,0x20,0xc0,0x3e,
+/* 31815 0x7c47 "籇" */
+0x20,0x3e,0x49,0x80,0x3f,0x00,0x0f,0x08,0x7f,0x40,0x9f,0x01,0x06,0x39,0x06,0x39,
+0x80,0xfe,0x10,0x80,0xfc,0x00,0xf0,0x10,0xfe,0x02,0xf4,0x00,0x98,0xe0,0x90,0x8c,
+/* 31816 0x7c48 "籈" */
+0x20,0x3f,0x48,0x85,0x7f,0x14,0x7f,0x55,0x55,0x7f,0x08,0x08,0x7f,0x08,0x0f,0xf0,
+0x40,0x7e,0x90,0x08,0x7c,0x20,0x20,0x38,0x28,0x48,0x68,0x58,0x4a,0x4a,0x6a,0x46,
+/* 31817 0x7c49 "籉" */
+0x20,0x3e,0x49,0xff,0x01,0x3f,0x00,0x1f,0x10,0x7f,0x48,0x9f,0x01,0x3f,0x01,0xff,
+0x80,0xfe,0x10,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xfe,0x22,0xf4,0x00,0xf8,0x00,0xfe,
+/* 31818 0x7c4a "籊" */
+0x20,0x3e,0x49,0xbe,0x12,0x0a,0x12,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x80,0xfe,0x10,0xf8,0x48,0x28,0x48,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 31819 0x7c4b "籋" */
+0x20,0x3e,0x48,0x80,0x7f,0x21,0x41,0xbf,0x21,0x35,0x29,0x35,0x21,0x35,0x29,0x35,
+0x40,0x7e,0x90,0x00,0xfc,0x08,0x04,0xfa,0x08,0x58,0x28,0x58,0x08,0x58,0x28,0x58,
+/* 31820 0x7c4c "籌" */
+0x20,0x3e,0x49,0xff,0x01,0x3f,0x00,0xff,0x00,0x3f,0x01,0xff,0x00,0x7d,0x44,0x7c,
+0x80,0xfe,0x10,0xfc,0x00,0xf8,0x00,0xfe,0x02,0xf0,0x00,0xfe,0x10,0xfc,0x90,0x30,
+/* 31821 0x7c4d "籍" */
+0x20,0x3f,0x48,0x85,0x10,0x7c,0x10,0x7c,0x11,0xfe,0x10,0x38,0x54,0x94,0x10,0x10,
+0x40,0x7e,0x90,0x08,0x48,0xfc,0x48,0x48,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 31822 0x7c4e "籎" */
+0x20,0x3f,0x48,0x85,0x24,0x3a,0x22,0x1e,0x20,0x3e,0x48,0x08,0x7f,0x14,0x22,0x41,
+0x40,0x7e,0x90,0x08,0x7c,0x04,0x28,0x10,0xfe,0x12,0x50,0x5e,0x50,0xb0,0x9e,0x00,
+/* 31823 0x7c4f "籏" */
+0x20,0x3f,0x48,0x85,0x20,0x11,0xfe,0x21,0x20,0x3c,0x24,0x24,0x24,0x45,0x54,0x89,
+0x40,0x7e,0x90,0x08,0x80,0xfe,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x88,0x04,
+/* 31824 0x7c50 "籐" */
+0x20,0x3e,0x48,0x80,0x3d,0x24,0x25,0x3c,0x27,0x24,0x3d,0x26,0x24,0x44,0x55,0x8a,
+0x40,0x7e,0x90,0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x62,
+/* 31825 0x7c51 "籑" */
+0x20,0x3e,0x48,0x9f,0x14,0x12,0x1f,0x02,0xff,0x09,0x3f,0xca,0x09,0x0f,0x08,0x0e,
+0x40,0x7e,0x90,0xf0,0x90,0x50,0xf0,0x00,0xfe,0x20,0xf8,0x26,0x20,0xe8,0xd0,0x38,
+/* 31826 0x7c52 "籒" */
+0x20,0x3f,0x48,0x85,0x27,0x20,0xf7,0x24,0x37,0x20,0x67,0xa4,0x27,0x24,0xa7,0x44,
+0x40,0x7e,0x90,0x08,0xfe,0xa0,0xbc,0xa4,0xbc,0xa0,0xfc,0x44,0xfc,0x44,0xfc,0x04,
+/* 31827 0x7c53 "籓" */
+0x20,0x3e,0x49,0xa0,0x17,0x12,0x81,0x47,0x52,0x14,0x2b,0xe2,0x23,0x22,0x23,0x22,
+0x80,0xfe,0x10,0x38,0xc0,0x48,0x50,0xfc,0x48,0x04,0xfa,0x48,0xf8,0x48,0xf8,0x08,
+/* 31828 0x7c54 "籔" */
+0x20,0x3e,0x48,0x88,0x7f,0x49,0xff,0x49,0x7f,0x2a,0x3e,0x10,0xff,0x22,0x1c,0x62,
+0x40,0x7e,0x90,0x00,0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31829 0x7c55 "籕" */
+0x20,0x3f,0x48,0x85,0x10,0x11,0x11,0xfd,0x11,0x30,0x39,0x55,0x51,0x91,0x11,0x11,
+0x40,0x7e,0x90,0x08,0x40,0xbc,0x14,0x54,0xac,0x40,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 31830 0x7c56 "籖" */
+0x20,0x3e,0x48,0x84,0x3f,0x04,0xff,0x12,0x73,0x12,0x73,0x12,0x73,0x12,0x17,0xf8,
+0x40,0x7e,0x90,0x20,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x28,0x92,0x1a,0xa6,0x42,
+/* 31831 0x7c57 "籗" */
+0x20,0x3e,0x48,0xbf,0x01,0x7f,0x41,0x9d,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,
+0x40,0x7e,0x90,0xf8,0x00,0xfe,0x02,0x74,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,
+/* 31832 0x7c58 "籘" */
+0x20,0x3e,0x48,0x81,0x3c,0x25,0x24,0x3d,0x24,0x25,0x3e,0x24,0x24,0x45,0x54,0x89,
+0x40,0x7e,0x90,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x44,0x8a,0xf0,0x24,0xfc,0xa8,0x64,
+/* 31833 0x7c59 "籙" */
+0x20,0x3f,0x48,0x85,0x10,0x29,0x44,0xb8,0x10,0x7d,0x10,0x95,0x50,0x1d,0xe2,0x40,
+0x40,0x7e,0x90,0x08,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x20,0x34,0xa8,0x24,0xa2,0x40,
+/* 31834 0x7c5a "籚" */
+0x20,0x3e,0x49,0x81,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x4f,0x49,0x9f,
+0x80,0xfe,0x10,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x90,0xf0,0x90,0xf8,0x48,0xfc,
+/* 31835 0x7c5b "籛" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0x2b,0x44,0xb8,0x11,0x7c,0x10,0x97,0x50,0x1c,0xe1,
+0x40,0x7e,0x90,0x08,0x90,0x88,0xfe,0x48,0x32,0xce,0x90,0x88,0xfe,0x48,0x32,0xce,
+/* 31836 0x7c5c "籜" */
+0x20,0x3f,0x48,0x85,0x11,0x11,0xfd,0x10,0x15,0x18,0x33,0xd0,0x11,0x10,0x53,0x20,
+0x40,0x7e,0x90,0x08,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0xfc,0x20,0xfe,0x20,
+/* 31837 0x7c5d "籝" */
+0x20,0x3f,0x48,0x85,0x7f,0x10,0x1f,0x08,0x0f,0x79,0x4f,0x7a,0x4a,0x79,0x4a,0x9c,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x20,0xe0,0x38,0xa8,0xa8,0xb8,0x2a,0xaa,0x46,
+/* 31838 0x7c5e "籞" */
+0x20,0x3e,0x4a,0xa7,0x49,0x97,0x21,0x65,0xa5,0x2f,0x00,0x3f,0x00,0xff,0x11,0x23,
+0x40,0x7e,0x90,0xde,0x12,0xd2,0x12,0xda,0x14,0xd0,0x00,0xf8,0x00,0xfe,0x10,0x08,
+/* 31839 0x7c5f "籟" */
+0x20,0x3f,0x48,0x95,0x10,0xfe,0x11,0x7e,0x54,0x54,0x7c,0x10,0x38,0x54,0x90,0x10,
+0x40,0x7e,0x90,0x08,0x80,0xf8,0x08,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 31840 0x7c60 "籠" */
+0x20,0x3f,0x48,0x95,0x08,0x7e,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,
+0x40,0x7e,0x90,0x08,0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,
+/* 31841 0x7c61 "籡" */
+0x20,0x3f,0x48,0x85,0x10,0x10,0xfd,0x12,0x14,0x1b,0x32,0xd3,0x11,0x11,0x52,0x24,
+0x40,0x7e,0x90,0x08,0x40,0xa0,0x10,0xe8,0x06,0xb8,0xa8,0xb8,0x10,0x10,0xa8,0x44,
+/* 31842 0x7c62 "籢" */
+0x20,0x3f,0x48,0x85,0x08,0x14,0x22,0x5d,0x80,0x77,0x55,0x77,0x22,0x22,0x55,0x88,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31843 0x7c63 "籣" */
+0x20,0x3f,0x48,0xfd,0x44,0x7c,0x44,0x7c,0x41,0x5f,0x41,0x5f,0x55,0x5f,0x45,0x59,
+0x40,0x7e,0x90,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xf4,0x54,0xf4,0x44,0x2c,
+/* 31844 0x7c64 "籤" */
+0x20,0x3e,0x48,0x91,0x11,0x2a,0xff,0x12,0x73,0x12,0x73,0x12,0x73,0x12,0x17,0xf8,
+0x40,0x7e,0x90,0x20,0x28,0xa4,0xfe,0x20,0xa4,0x24,0xa8,0x28,0x92,0x1a,0xa6,0x42,
+/* 31845 0x7c65 "籥" */
+0x20,0x3e,0x49,0x82,0x0c,0x37,0xc0,0x3b,0x2a,0x3b,0x00,0x3f,0x24,0x3f,0x24,0x24,
+0x80,0xfe,0x10,0x80,0x60,0xd8,0x06,0xb8,0xa8,0xb8,0x00,0xf8,0x88,0xf8,0x88,0xb8,
+/* 31846 0x7c66 "籦" */
+0x20,0x3f,0x48,0x85,0x10,0x2b,0x44,0xb9,0x11,0x7d,0x11,0x95,0x50,0x1d,0xe0,0x47,
+0x40,0x7e,0x90,0xfc,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfe,
+/* 31847 0x7c67 "籧" */
+0x20,0x3f,0x48,0x85,0x40,0x2f,0x28,0x0b,0xe8,0x2b,0x29,0x2a,0x31,0x22,0x51,0x8f,
+0x40,0x7e,0x90,0xf8,0x80,0xfc,0x84,0xf0,0x88,0xf8,0x40,0xa8,0x70,0xa8,0x60,0xfe,
+/* 31848 0x7c68 "籨" */
+0x20,0x3f,0x48,0x85,0x08,0x14,0x22,0x5d,0x80,0x77,0x55,0x77,0x22,0x22,0x55,0x88,
+0x40,0x7e,0x90,0x08,0x20,0x20,0x3e,0x42,0x84,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 31849 0x7c69 "籩" */
+0x20,0x3e,0x48,0x87,0x45,0x24,0x27,0x00,0xef,0x2a,0x24,0x2b,0x21,0x21,0x52,0x8f,
+0x40,0x7e,0x90,0xf8,0x48,0xa8,0xf8,0x40,0xfc,0x14,0x88,0xf4,0x00,0xf0,0x10,0xfe,
+/* 31850 0x7c6a "籪" */
+0x20,0x3e,0x49,0x88,0x51,0x5d,0x48,0x5d,0x44,0x7f,0x51,0x5d,0x48,0x5d,0x44,0x7f,
+0x80,0xfe,0x10,0x82,0x1c,0xd0,0x90,0xd0,0x5e,0xf4,0x14,0xd4,0x94,0xd4,0x54,0xe4,
+/* 31851 0x7c6b "籫" */
+0x20,0x3f,0x48,0x85,0x28,0x3e,0x48,0xfe,0x15,0x26,0x5f,0x14,0x12,0x1f,0x08,0x10,
+0x40,0x7e,0x90,0x08,0x50,0x7c,0x90,0xfe,0x28,0x4a,0xf6,0x90,0x50,0xf0,0x20,0x10,
+/* 31852 0x7c6c "籬" */
+0x20,0x3f,0x48,0x95,0x08,0x7f,0x14,0x49,0x55,0x7f,0x08,0x7f,0x51,0x55,0x5d,0x43,
+0x40,0x7e,0x90,0x08,0x28,0x24,0x7e,0x48,0xc8,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x40,
+/* 31853 0x7c6d "籭" */
+0x20,0x3e,0x48,0xbf,0x12,0x1b,0x12,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x40,0x7e,0x90,0x7e,0x24,0x34,0xa4,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 31854 0x7c6e "籮" */
+0x20,0x3e,0x48,0xff,0x44,0x7f,0x10,0x20,0x45,0x79,0x13,0x25,0x7d,0x01,0x55,0x81,
+0x40,0x7e,0x90,0xfc,0x44,0xfc,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 31855 0x7c6f "籯" */
+0x20,0x3f,0x48,0x85,0x7f,0x10,0x1f,0x08,0x0f,0x7b,0x4a,0x7b,0x4a,0x7b,0x49,0x9a,
+0x40,0x7e,0x90,0x08,0xfc,0x00,0xf8,0x20,0xe0,0xb8,0xa8,0xa8,0xb8,0xaa,0x2a,0xc6,
+/* 31856 0x7c70 "籰" */
+0x20,0x3f,0x48,0x85,0x3e,0x22,0x3e,0x22,0x3f,0x31,0x5f,0x91,0x1f,0x08,0x07,0xf8,
+0x40,0x7e,0x90,0x08,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xf0,0x00,0xfc,0x20,0xc0,0x3e,
+/* 31857 0x7c71 "籱" */
+0x20,0x3e,0x48,0xbf,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x48,0x7e,0xc9,0x7e,0x48,0x7e,
+0x40,0x7e,0x90,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x90,0xfc,0x90,0xfc,0x90,0xfc,
+/* 31858 0x7c72 "籲" */
+0x20,0x3f,0x48,0x85,0x18,0x24,0x7e,0x81,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,
+0x40,0x7e,0x90,0x08,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x82,
+/* 31859 0x7c73 "米" */
+0x01,0x21,0x11,0x09,0x09,0x01,0x7f,0x03,0x05,0x05,0x09,0x11,0x21,0xc1,0x01,0x01,
+0x00,0x08,0x08,0x10,0x20,0x00,0xfc,0x80,0x40,0x40,0x20,0x10,0x08,0x06,0x00,0x00,
+/* 31860 0x7c74 "籴" */
+0x06,0x01,0x02,0x04,0x18,0xe1,0x11,0x09,0x05,0x7f,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x00,0x00,0x80,0x40,0x30,0x0e,0x10,0x20,0x40,0xfc,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 31861 0x7c75 "籵" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 31862 0x7c76 "籶" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x09,0x09,0x0a,
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 31863 0x7c77 "籷" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1d,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x08,0x1c,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 31864 0x7c78 "籸" */
+0x10,0x13,0x94,0x54,0x58,0x10,0xfc,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 31865 0x7c79 "籹" */
+0x10,0x10,0x94,0x54,0x5b,0x10,0xfc,0x30,0x38,0x55,0x54,0x90,0x10,0x10,0x10,0x13,
+0x40,0x40,0x40,0x40,0xfe,0x88,0x88,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x88,0x04,
+/* 31866 0x7c7a "籺" */
+0x08,0x08,0x4a,0x2a,0x2c,0x09,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x89,0x09,0x08,0x08,
+0x40,0x40,0x40,0xfe,0x80,0x00,0x7c,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 31867 0x7c7b "类" */
+0x01,0x11,0x09,0x01,0x7f,0x05,0x09,0x11,0x60,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x10,0x20,0x00,0xfc,0x40,0x20,0x10,0x08,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 31868 0x7c7c "籼" */
+0x10,0x10,0x94,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 31869 0x7c7d "籽" */
+0x10,0x11,0x94,0x54,0x58,0x10,0xfc,0x33,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 31870 0x7c7e "籾" */
+0x10,0x10,0x95,0x54,0x58,0x11,0xfd,0x31,0x39,0x56,0x54,0x90,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 31871 0x7c7f "籿" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x28,0x10,
+/* 31872 0x7c80 "粀" */
+0x10,0x10,0x94,0x54,0x5b,0x10,0xfc,0x31,0x39,0x54,0x54,0x90,0x10,0x10,0x11,0x16,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 31873 0x7c81 "粁" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x19,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x08,0x1c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 31874 0x7c82 "粂" */
+0x04,0x04,0x0f,0x10,0x20,0x03,0x0c,0x70,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xe0,0x40,0x80,0x60,0x18,0x04,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31875 0x7c83 "粃" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x10,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 31876 0x7c84 "粄" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 31877 0x7c85 "粅" */
+0x10,0x10,0x94,0x54,0x59,0x12,0xfc,0x30,0x38,0x55,0x56,0x90,0x10,0x10,0x11,0x10,
+0x80,0x80,0x80,0xfc,0x54,0x54,0x54,0x94,0x94,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 31878 0x7c86 "粆" */
+0x10,0x10,0x94,0x54,0x58,0x10,0xfd,0x31,0x3a,0x54,0x54,0x90,0x10,0x10,0x10,0x13,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 31879 0x7c87 "粇" */
+0x10,0x10,0x94,0x57,0x58,0x10,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 31880 0x7c88 "粈" */
+0x10,0x11,0x94,0x54,0x58,0x10,0xfc,0x31,0x38,0x54,0x54,0x90,0x10,0x10,0x13,0x10,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 31881 0x7c89 "粉" */
+0x10,0x10,0x94,0x54,0x58,0x10,0xfd,0x32,0x38,0x54,0x54,0x90,0x10,0x10,0x11,0x12,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 31882 0x7c8a "粊" */
+0x20,0x20,0x3c,0x20,0x20,0x2c,0x30,0x00,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x80,0x88,0xb0,0xc0,0x84,0x84,0x7c,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31883 0x7c8b "粋" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfd,0x32,0x38,0x54,0x57,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0xf8,0x48,0x88,0x8a,0x0a,0x26,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31884 0x7c8c "粌" */
+0x10,0x11,0x94,0x54,0x58,0x11,0xfd,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x11,0x10,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 31885 0x7c8d "粍" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfd,0x30,0x38,0x54,0x57,0x90,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 31886 0x7c8e "粎" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x89,0x09,0x0a,0x0c,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0xa0,0xa0,0xa0,0x90,0x90,0x08,0x08,0x04,0x02,
+/* 31887 0x7c8f "粏" */
+0x08,0x08,0x4a,0x2a,0x2c,0x09,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x09,0x0a,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 31888 0x7c90 "粐" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x09,0x09,0x0a,
+0x20,0x10,0x10,0xfe,0x82,0x82,0x82,0xfe,0x82,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 31889 0x7c91 "粑" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x10,0x10,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 31890 0x7c92 "粒" */
+0x08,0x08,0x4a,0x2a,0x2d,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x09,0x08,
+0x20,0x10,0x10,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 31891 0x7c93 "粓" */
+0x08,0x08,0x4a,0x2a,0x2d,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 31892 0x7c94 "粔" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 31893 0x7c95 "粕" */
+0x10,0x10,0x94,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31894 0x7c96 "粖" */
+0x10,0x10,0x94,0x55,0x58,0x10,0xfc,0x31,0x38,0x54,0x54,0x91,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 31895 0x7c97 "粗" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 31896 0x7c98 "粘" */
+0x10,0x10,0x94,0x54,0x58,0x10,0xfc,0x30,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 31897 0x7c99 "粙" */
+0x10,0x10,0x94,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 31898 0x7c9a "粚" */
+0x10,0x10,0x94,0x55,0x5a,0x11,0xfd,0x31,0x3b,0x55,0x55,0x91,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 31899 0x7c9b "粛" */
+0x01,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x29,0x25,0x2f,0x23,0x25,0x29,0x41,0x81,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x28,0x48,0xe8,0x88,0x48,0x28,0x08,0x08,
+/* 31900 0x7c9c "粜" */
+0x01,0x11,0x11,0x1f,0x41,0x41,0x7f,0x00,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x10,0x10,0xf0,0x04,0x04,0xfc,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31901 0x7c9d "粝" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x00,0x00,0x00,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+/* 31902 0x7c9e "粞" */
+0x10,0x13,0x94,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x54,0x8c,0x04,0x04,0x04,0xfc,0x04,
+/* 31903 0x7c9f "粟" */
+0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x00,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31904 0x7ca0 "粠" */
+0x10,0x10,0x94,0x54,0x59,0x10,0xfc,0x30,0x38,0x57,0x54,0x90,0x10,0x11,0x12,0x14,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,0x02,0x02,
+/* 31905 0x7ca1 "粡" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 31906 0x7ca2 "粢" */
+0x01,0x41,0x21,0x0a,0x14,0xe0,0x21,0x26,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xfc,0x44,0x48,0xa0,0x10,0x08,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31907 0x7ca3 "粣" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x33,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0xd4,0x24,0x4c,
+/* 31908 0x7ca4 "粤" */
+0x02,0x3f,0x29,0x25,0x2f,0x23,0x25,0x29,0x3f,0x00,0xff,0x10,0x1f,0x00,0x00,0x00,
+0x00,0xf8,0x28,0x48,0xe8,0x88,0x48,0x28,0xf8,0x00,0xfe,0x00,0xf8,0x08,0x50,0x20,
+/* 31909 0x7ca5 "粥" */
+0x01,0xf9,0x09,0x0d,0x0b,0x79,0x41,0x47,0x41,0x79,0x0b,0x0d,0x09,0x09,0x51,0x21,
+0x00,0x3c,0x04,0x44,0x84,0x3c,0x20,0xe0,0x20,0x3c,0x84,0x44,0x04,0x04,0x28,0x10,
+/* 31910 0x7ca6 "粦" */
+0x01,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x10,0x3e,0x42,0xa2,0x14,0x08,0x30,0xc0,
+0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x10,0xfc,0x10,0x90,0x90,0xfe,0x10,0x10,
+/* 31911 0x7ca7 "粧" */
+0x10,0x10,0x94,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 31912 0x7ca8 "粨" */
+0x08,0x09,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 31913 0x7ca9 "粩" */
+0x10,0x10,0x94,0x55,0x58,0x10,0xfd,0x30,0x38,0x55,0x56,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 31914 0x7caa "粪" */
+0x01,0x11,0x09,0x7f,0x05,0x09,0x31,0xc4,0x04,0x3f,0x04,0x04,0xff,0x08,0x10,0x20,
+0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x46,0x40,0xf8,0x40,0x40,0xfe,0x20,0x10,0x08,
+/* 31915 0x7cab "粫" */
+0x10,0x13,0x94,0x54,0x58,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 31916 0x7cac "粬" */
+0x10,0x10,0x94,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x50,0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0x54,0xfc,0x04,
+/* 31917 0x7cad "粭" */
+0x08,0x08,0x4a,0x2a,0x2c,0x09,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x08,
+0x20,0x20,0x50,0x48,0x84,0x02,0xfc,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 31918 0x7cae "粮" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 31919 0x7caf "粯" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x90,0x10,0x11,0x12,0x14,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 31920 0x7cb0 "粰" */
+0x10,0x10,0x95,0x54,0x59,0x10,0xfc,0x31,0x38,0x54,0x57,0x90,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 31921 0x7cb1 "粱" */
+0x00,0x23,0x90,0x42,0x12,0xe5,0x22,0x24,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xf0,0x90,0x94,0x92,0x12,0x50,0x20,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 31922 0x7cb2 "粲" */
+0x08,0x0f,0x28,0x3f,0x61,0x92,0x0c,0x31,0xc0,0x11,0x09,0x7f,0x05,0x09,0x31,0xc1,
+0x00,0x7c,0x04,0x44,0x28,0x10,0x68,0x84,0x00,0x10,0x20,0xfc,0x40,0x20,0x18,0x06,
+/* 31923 0x7cb3 "粳" */
+0x10,0x11,0x94,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x10,0x13,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 31924 0x7cb4 "粴" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x38,0x54,0x55,0x90,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 31925 0x7cb5 "粵" */
+0x04,0x3f,0x20,0x2f,0x25,0x3f,0x25,0x29,0x3f,0x00,0xff,0x10,0x1f,0x00,0x00,0x00,
+0x00,0xf8,0xc8,0x28,0x48,0xf8,0x48,0x28,0xf8,0x00,0xfe,0x00,0xf8,0x08,0x50,0x20,
+/* 31926 0x7cb6 "粶" */
+0x10,0x11,0x94,0x54,0x59,0x10,0xfc,0x33,0x38,0x56,0x55,0x90,0x11,0x12,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 31927 0x7cb7 "粷" */
+0x10,0x10,0x94,0x55,0x5a,0x12,0xfd,0x30,0x3b,0x54,0x54,0x91,0x12,0x10,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x42,0x4a,0x52,0x42,0xfe,0x42,0xe2,0x52,0x4a,0x42,0x54,0x08,
+/* 31928 0x7cb8 "粸" */
+0x10,0x10,0x97,0x54,0x58,0x10,0xfc,0x30,0x38,0x54,0x54,0x93,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 31929 0x7cb9 "粹" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfd,0x32,0x38,0x54,0x55,0x90,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 31930 0x7cba "粺" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x54,0x55,0x93,0x10,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 31931 0x7cbb "粻" */
+0x10,0x10,0x94,0x54,0x58,0x10,0xfc,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 31932 0x7cbc "粼" */
+0x08,0x49,0x2a,0x08,0xff,0x2a,0x49,0x88,0x42,0x77,0x92,0x5a,0x2f,0x22,0x42,0x82,
+0x00,0x12,0x12,0x12,0x24,0x24,0x48,0x90,0x48,0x48,0x24,0x24,0x92,0x12,0x12,0x00,
+/* 31933 0x7cbd "粽" */
+0x20,0x20,0x23,0xaa,0x70,0x21,0xf8,0x20,0x73,0x68,0xa9,0x21,0x22,0x24,0x20,0x20,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 31934 0x7cbe "精" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfd,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 31935 0x7cbf "粿" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x38,0x57,0x54,0x90,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 31936 0x7cc0 "糀" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfc,0x30,0x39,0x56,0x54,0x90,0x10,0x10,0x10,0x10,
+0x88,0x88,0xfe,0x88,0x88,0x50,0x50,0x94,0x94,0x98,0x90,0xb2,0xd2,0x92,0x8e,0x80,
+/* 31937 0x7cc1 "糁" */
+0x10,0x10,0x94,0x55,0x58,0x13,0xfc,0x31,0x3a,0x55,0x54,0x90,0x11,0x10,0x10,0x13,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x62,0x84,0x18,0x60,0x80,
+/* 31938 0x7cc2 "糂" */
+0x10,0x10,0x97,0x54,0x58,0x10,0xfc,0x30,0x38,0x57,0x55,0x91,0x11,0x11,0x11,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 31939 0x7cc3 "糃" */
+0x10,0x10,0x94,0x54,0x58,0x10,0xfc,0x31,0x38,0x54,0x55,0x92,0x10,0x11,0x10,0x10,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 31940 0x7cc4 "糄" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x92,0x12,0x12,0x14,0x10,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 31941 0x7cc5 "糅" */
+0x20,0x21,0x20,0xa8,0x73,0x20,0xf8,0x21,0x72,0x68,0xab,0x20,0x20,0x21,0x26,0x20,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 31942 0x7cc6 "糆" */
+0x10,0x13,0x94,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x74,0x54,0x54,0x74,0x54,0x54,0x54,0xfc,0x04,
+/* 31943 0x7cc7 "糇" */
+0x10,0x10,0x94,0x55,0x59,0x13,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 31944 0x7cc8 "糈" */
+0x20,0x23,0x20,0xa9,0x71,0x21,0xfa,0x24,0x71,0x69,0xa9,0x21,0x21,0x21,0x21,0x21,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 31945 0x7cc9 "糉" */
+0x20,0x20,0x22,0xaa,0x72,0x22,0xfa,0x23,0x70,0x69,0xaa,0x20,0x21,0x20,0x20,0x27,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 31946 0x7cca "糊" */
+0x10,0x10,0x94,0x55,0x58,0x10,0xfc,0x31,0x39,0x55,0x55,0x91,0x11,0x10,0x10,0x10,
+0x80,0x9e,0x92,0xd2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 31947 0x7ccb "糋" */
+0x21,0x20,0x20,0xab,0x70,0x23,0xfa,0x22,0x73,0x6a,0xaa,0x23,0x22,0x22,0x22,0x22,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 31948 0x7ccc "糌" */
+0x20,0x20,0x21,0xa9,0x72,0x25,0xf8,0x21,0x76,0x69,0xa9,0x21,0x21,0x21,0x21,0x21,
+0x88,0x88,0xec,0x2a,0x28,0x48,0x88,0x7e,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,
+/* 31949 0x7ccd "糍" */
+0x21,0x20,0x20,0xaf,0x71,0x21,0xfa,0x22,0x74,0x6f,0xa9,0x22,0x22,0x24,0x27,0x20,
+0x08,0x88,0x90,0xfe,0x08,0x08,0x10,0x94,0xa4,0x38,0x08,0x10,0x10,0xa4,0xbc,0x84,
+/* 31950 0x7cce "糎" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x10,0x7c,0x10,0x10,0xfe,
+/* 31951 0x7ccf "糏" */
+0x20,0x23,0x22,0xaa,0x73,0x22,0xfa,0x22,0x72,0x6a,0xaa,0x22,0x22,0x24,0x24,0x28,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x54,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x8a,0x84,
+/* 31952 0x7cd0 "糐" */
+0x10,0x10,0x97,0x54,0x59,0x11,0xfd,0x31,0x39,0x55,0x54,0x93,0x10,0x10,0x10,0x10,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 31953 0x7cd1 "糑" */
+0x20,0x23,0x20,0xa8,0x73,0x22,0xfa,0x23,0x70,0x6a,0xa9,0x21,0x22,0x20,0x22,0x21,
+0x00,0xde,0x42,0x42,0xde,0x10,0x10,0xde,0x42,0x52,0x4a,0x4a,0x52,0x42,0x94,0x08,
+/* 31954 0x7cd2 "糒" */
+0x10,0x10,0x97,0x54,0x58,0x13,0xfc,0x31,0x3b,0x55,0x55,0x91,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x88,0xfe,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 31955 0x7cd3 "糓" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x10,0x54,0x38,0xfe,0x10,0x38,0x54,0x91,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 31956 0x7cd4 "糔" */
+0x10,0x11,0x94,0x54,0x58,0x10,0xfc,0x33,0x38,0x55,0x55,0x91,0x11,0x10,0x13,0x10,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 31957 0x7cd5 "糕" */
+0x11,0x10,0x94,0x54,0x5b,0x10,0xfc,0x31,0x38,0x54,0x57,0x90,0x12,0x12,0x14,0x10,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 31958 0x7cd6 "糖" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 31959 0x7cd7 "糗" */
+0x20,0x20,0x23,0xaa,0x73,0x22,0xfb,0x22,0x73,0x68,0xa8,0x27,0x20,0x21,0x22,0x2c,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x50,0x48,0xfe,0xa0,0x10,0x08,0x06,
+/* 31960 0x7cd8 "糘" */
+0x10,0x10,0x95,0x55,0x58,0x10,0xfc,0x30,0x3b,0x54,0x54,0x93,0x10,0x10,0x13,0x10,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 31961 0x7cd9 "糙" */
+0x10,0x10,0x96,0x55,0x58,0x10,0xfc,0x33,0x39,0x55,0x55,0x91,0x11,0x11,0x12,0x14,
+0x10,0x50,0x50,0x7c,0x90,0x10,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 31962 0x7cda "糚" */
+0x10,0x10,0x95,0x54,0x58,0x10,0xfd,0x31,0x39,0x54,0x54,0x93,0x11,0x11,0x11,0x12,
+0x48,0x48,0xfe,0x48,0x00,0x48,0x48,0x48,0xfe,0x48,0x48,0xc8,0x48,0x48,0x7e,0x40,
+/* 31963 0x7cdb "糛" */
+0x10,0x11,0x94,0x57,0x5a,0x10,0xfc,0x30,0x38,0x54,0x54,0x91,0x10,0x10,0x13,0x10,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 31964 0x7cdc "糜" */
+0x01,0x00,0x3f,0x22,0x2f,0x26,0x2b,0x32,0x20,0x24,0x22,0x3f,0x21,0x42,0x44,0x98,
+0x00,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x80,0x90,0xa0,0xfc,0xc0,0xa0,0x98,0x86,
+/* 31965 0x7cdd "糝" */
+0x20,0x20,0x21,0xa9,0x72,0x23,0xf8,0x21,0x76,0x68,0xab,0x20,0x23,0x20,0x20,0x27,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 31966 0x7cde "糞" */
+0x11,0x09,0x7f,0x05,0x19,0x7f,0x11,0x1f,0x11,0x1f,0x04,0x3f,0x04,0xff,0x08,0x10,
+0x10,0x20,0xfc,0x40,0x30,0xfc,0x10,0xf0,0x10,0xf0,0x40,0xf8,0x40,0xfe,0x20,0x10,
+/* 31967 0x7cdf "糟" */
+0x20,0x20,0x27,0xa8,0x73,0x22,0xfb,0x22,0x73,0x68,0xa9,0x21,0x21,0x21,0x21,0x21,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 31968 0x7ce0 "糠" */
+0x10,0x10,0x95,0x55,0x59,0x11,0xfd,0x31,0x39,0x55,0x55,0x91,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 31969 0x7ce1 "糡" */
+0x10,0x10,0x95,0x54,0x58,0x13,0xfc,0x31,0x39,0x55,0x55,0x91,0x10,0x10,0x11,0x16,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x92,0x12,0x0e,
+/* 31970 0x7ce2 "糢" */
+0x10,0x10,0x97,0x54,0x58,0x11,0xfd,0x31,0x39,0x55,0x54,0x93,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 31971 0x7ce3 "糣" */
+0x20,0x27,0x21,0xad,0x77,0x23,0xfd,0x29,0x70,0x6b,0xaa,0x22,0x23,0x22,0x22,0x23,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 31972 0x7ce4 "糤" */
+0x22,0x22,0x27,0xaa,0x72,0x27,0xf8,0x27,0x74,0x6f,0xac,0x27,0x24,0x24,0x24,0x24,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 31973 0x7ce5 "糥" */
+0x10,0x11,0x94,0x55,0x59,0x11,0xfd,0x31,0x38,0x55,0x54,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0xfe,0x52,0x52,0x52,0x06,0x00,0xfe,0x20,0xfe,0x52,0x52,0x52,0x06,
+/* 31974 0x7ce6 "糦" */
+0x10,0x13,0x94,0x55,0x58,0x11,0xfd,0x31,0x38,0x57,0x54,0x91,0x11,0x11,0x11,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 31975 0x7ce7 "糧" */
+0x10,0x11,0x95,0x55,0x59,0x13,0xfc,0x31,0x39,0x55,0x55,0x91,0x10,0x11,0x10,0x13,
+0x00,0xfc,0x04,0xfc,0x04,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,
+/* 31976 0x7ce8 "糨" */
+0x20,0x23,0x20,0xa8,0x70,0x23,0xfa,0x22,0x72,0x6b,0xa8,0x20,0x20,0x20,0x25,0x22,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 31977 0x7ce9 "糩" */
+0x10,0x10,0x94,0x55,0x5a,0x11,0xfd,0x31,0x39,0x55,0x54,0x90,0x10,0x10,0x10,0x10,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 31978 0x7cea "糪" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3c,0x11,0x09,0x7f,0x05,0x19,0xe1,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x10,0x20,0xfc,0x40,0x30,0x0e,
+/* 31979 0x7ceb "糫" */
+0x20,0x23,0x22,0xaa,0x73,0x20,0xfb,0x20,0x73,0x6a,0xab,0x20,0x21,0x23,0x2d,0x21,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 31980 0x7cec "糬" */
+0x20,0x27,0x24,0xac,0x77,0x20,0xfb,0x20,0x77,0x68,0xa9,0x23,0x25,0x21,0x21,0x21,
+0x00,0xfc,0xa4,0xa4,0xfc,0x48,0xf8,0x50,0xfe,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 31981 0x7ced "糭" */
+0x20,0x20,0x22,0xab,0x72,0x22,0xfa,0x23,0x70,0x69,0xaa,0x20,0x21,0x20,0x20,0x27,
+0x20,0x88,0x52,0x26,0x52,0x8a,0x22,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 31982 0x7cee "糮" */
+0x20,0x27,0x25,0xaf,0x74,0x27,0xfd,0x27,0x70,0x6b,0xaa,0x22,0x22,0x22,0x2f,0x20,
+0x10,0xd0,0x10,0xde,0x50,0xe8,0x04,0xc4,0x00,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 31983 0x7cef "糯" */
+0x10,0x11,0x94,0x57,0x5a,0x11,0xfc,0x31,0x38,0x57,0x54,0x91,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 31984 0x7cf0 "糰" */
+0x23,0x22,0x23,0xaa,0x72,0x22,0xfa,0x22,0x72,0x6a,0xab,0x22,0x23,0x22,0x22,0x23,
+0xfe,0x22,0xfe,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x26,0xfe,0x0a,0xfe,0x8a,0x5a,0xfe,
+/* 31985 0x7cf1 "糱" */
+0x52,0x7e,0x28,0x7e,0xa2,0x3e,0x20,0x3e,0x22,0x3e,0x11,0x09,0x7f,0x05,0x19,0xe1,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0x20,0xfc,0x40,0x30,0x0e,
+/* 31986 0x7cf2 "糲" */
+0x20,0x23,0x22,0xab,0x72,0x22,0xfa,0x22,0x72,0x6a,0xaa,0x23,0x23,0x25,0x25,0x29,
+0x00,0xfe,0x48,0xfe,0x48,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0xfe,0x2a,0x7a,0x0a,0x06,
+/* 31987 0x7cf3 "糳" */
+0x55,0x14,0xff,0x22,0x7f,0x08,0xff,0x08,0x6b,0x49,0x7f,0x10,0x09,0xff,0x09,0x71,
+0x3c,0x24,0xa4,0x42,0x00,0x3c,0x84,0x28,0x10,0x28,0x44,0x10,0x20,0xfe,0x20,0x1c,
+/* 31988 0x7cf4 "糴" */
+0x20,0x11,0x28,0x45,0x90,0x11,0x54,0x38,0x10,0xfd,0x12,0x38,0x54,0x94,0x10,0x10,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x00,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,
+/* 31989 0x7cf5 "糵" */
+0x08,0xff,0x28,0x7d,0x44,0x7c,0x41,0x7c,0x45,0x7c,0x11,0x09,0x7f,0x05,0x19,0xe1,
+0x20,0xfe,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x10,0x20,0xfc,0x40,0x30,0x0e,
+/* 31990 0x7cf6 "糶" */
+0x54,0x55,0x7c,0x11,0x54,0x55,0x7c,0x00,0x54,0x39,0x12,0xfc,0x38,0x54,0x92,0x10,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x00,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,
+/* 31991 0x7cf7 "糷" */
+0x20,0x23,0x20,0xab,0x72,0x23,0xfa,0x23,0x72,0x6b,0xaa,0x22,0x22,0x22,0x22,0x22,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0xaa,0xfa,0x22,0x72,0xaa,0x24,
+/* 31992 0x7cf8 "糸" */
+0x02,0x04,0x08,0x10,0x3f,0x01,0x06,0x18,0x7f,0x01,0x09,0x09,0x11,0x21,0x45,0x02,
+0x00,0x00,0x20,0x40,0x80,0x00,0x10,0x08,0xfc,0x04,0x20,0x10,0x08,0x04,0x04,0x00,
+/* 31993 0x7cf9 "糹" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 31994 0x7cfa "糺" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,0x00,
+/* 31995 0x7cfb "系" */
+0x00,0x3f,0x04,0x08,0x10,0x3f,0x01,0x06,0x18,0x7f,0x01,0x09,0x11,0x21,0x45,0x02,
+0xf8,0x00,0x00,0x20,0x40,0x80,0x00,0x10,0x08,0xfc,0x04,0x20,0x10,0x08,0x04,0x00,
+/* 31996 0x7cfc "糼" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 31997 0x7cfd "糽" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 31998 0x7cfe "糾" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x54,0x64,0x44,0x04,0x04,0x04,0x04,
+/* 31999 0x7cff "糿" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x82,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 32000 0x7d00 "紀" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32001 0x7d01 "紁" */
+0x10,0x13,0x21,0x25,0x45,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x06,
+0x00,0xfc,0x04,0x44,0x24,0xa8,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 32002 0x7d02 "紂" */
+0x08,0x08,0x10,0x12,0x22,0x7c,0x08,0x10,0x24,0x7e,0x02,0x00,0x52,0x49,0x89,0x00,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x28,0x10,
+/* 32003 0x7d03 "紃" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x81,0x02,
+0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 32004 0x7d04 "約" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x21,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 32005 0x7d05 "紅" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x83,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32006 0x7d06 "紆" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x23,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32007 0x7d07 "紇" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x20,0x48,0xfc,0x04,0x00,0x55,0x55,0x80,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 32008 0x7d08 "紈" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x49,0xfc,0x04,0x00,0x54,0x55,0x82,0x04,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 32009 0x7d09 "紉" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x11,0x21,0x49,0xfe,0x04,0x00,0x54,0x55,0x82,0x04,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 32010 0x7d0a "紊" */
+0x02,0x01,0x7f,0x08,0x07,0x18,0xe2,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0x00,0xfc,0x20,0xc0,0x30,0x0e,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32011 0x7d0b "紋" */
+0x10,0x10,0x20,0x27,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x06,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 32012 0x7d0c "紌" */
+0x10,0x10,0x20,0x24,0x44,0xf9,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x81,0x02,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 32013 0x7d0d "納" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 32014 0x7d0e "紎" */
+0x10,0x10,0x20,0x24,0x44,0xfb,0x10,0x20,0x48,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x40,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 32015 0x7d0f "紏" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x05,0x00,0x54,0x54,0x80,0x00,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 32016 0x7d10 "紐" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x21,0x48,0xfc,0x04,0x00,0x54,0x54,0x83,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 32017 0x7d11 "紑" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x20,0x48,0xfd,0x06,0x00,0x54,0x54,0x80,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 32018 0x7d12 "紒" */
+0x10,0x10,0x20,0x24,0x44,0xf9,0x12,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x81,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 32019 0x7d13 "紓" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x13,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32020 0x7d14 "純" */
+0x10,0x10,0x20,0x2b,0x48,0xf1,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 32021 0x7d15 "紕" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 32022 0x7d16 "紖" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x54,0x81,0x00,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 32023 0x7d17 "紗" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x11,0x21,0x4a,0xfc,0x04,0x00,0x54,0x54,0x80,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 32024 0x7d18 "紘" */
+0x10,0x10,0x20,0x28,0x4b,0xf0,0x10,0x20,0x48,0xf9,0x09,0x02,0xaa,0xac,0x81,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 32025 0x7d19 "紙" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 32026 0x7d1a "級" */
+0x10,0x13,0x20,0x24,0x44,0xf8,0x10,0x20,0x49,0xfd,0x05,0x01,0xaa,0xaa,0x84,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32027 0x7d1b "紛" */
+0x10,0x10,0x20,0x24,0x45,0xf9,0x12,0x25,0x48,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 32028 0x7d1c "紜" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x11,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x80,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x84,0xfe,0x82,0x00,
+/* 32029 0x7d1d "紝" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x23,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 32030 0x7d1e "紞" */
+0x10,0x10,0x20,0x25,0x45,0xfa,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 32031 0x7d1f "紟" */
+0x10,0x10,0x20,0x24,0x44,0xf9,0x12,0x20,0x48,0xfd,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 32032 0x7d20 "素" */
+0x01,0x3f,0x01,0x1f,0x01,0xff,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0xf8,0x00,0xf0,0x00,0xfe,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32033 0x7d21 "紡" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 32034 0x7d22 "索" */
+0x01,0x01,0x3f,0x01,0x01,0x7f,0x42,0x84,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x02,0x24,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32035 0x7d23 "紣" */
+0x10,0x10,0x21,0x28,0x48,0xf0,0x11,0x22,0x48,0xf8,0x0b,0x00,0xa8,0xa8,0x80,0x00,
+0x40,0x40,0xf8,0x48,0x88,0x8a,0x0a,0x26,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32036 0x7d24 "紤" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x81,0x02,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 32037 0x7d25 "紥" */
+0x08,0x08,0x7f,0x08,0x0e,0x78,0x08,0x28,0x14,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x3c,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32038 0x7d26 "紦" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32039 0x7d27 "紧" */
+0x04,0x25,0x24,0x24,0x24,0x24,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0xfc,0x88,0x50,0x20,0x50,0x8c,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32040 0x7d28 "紨" */
+0x10,0x10,0x20,0x29,0x49,0xf3,0x15,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 32041 0x7d29 "紩" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x12,0x20,0x4b,0xfc,0x04,0x00,0x54,0x54,0x81,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32042 0x7d2a "紪" */
+0x10,0x10,0x20,0x2a,0x4a,0xf2,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaf,0x82,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 32043 0x7d2b "紫" */
+0x08,0x28,0x2e,0x28,0x2e,0xf0,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32044 0x7d2c "紬" */
+0x10,0x10,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 32045 0x7d2d "紭" */
+0x20,0x27,0x40,0x40,0x90,0xe7,0x24,0x44,0x94,0xf7,0x00,0x10,0xa8,0xa0,0x85,0x02,
+0x08,0x88,0x88,0x88,0x88,0x88,0x08,0x10,0x10,0x90,0x94,0xa4,0xa2,0xbe,0x02,0x00,
+/* 32046 0x7d2e "紮" */
+0x04,0x04,0x7f,0x0e,0x15,0x64,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x20,0x20,0xa0,0x22,0x22,0x9e,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32047 0x7d2f "累" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32048 0x7d30 "細" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 32049 0x7d31 "紱" */
+0x10,0x10,0x20,0x24,0x47,0xf8,0x10,0x20,0x49,0xfd,0x05,0x01,0xaa,0xaa,0x84,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32050 0x7d32 "紲" */
+0x10,0x11,0x21,0x25,0x45,0xfb,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 32051 0x7d33 "紳" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x54,0x80,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 32052 0x7d34 "紴" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x82,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32053 0x7d35 "紵" */
+0x10,0x10,0x20,0x2b,0x4a,0xf4,0x10,0x20,0x4b,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32054 0x7d36 "紶" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x23,0x48,0xfc,0x04,0x00,0x54,0x55,0x80,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 32055 0x7d37 "紷" */
+0x10,0x10,0x20,0x24,0x44,0xf9,0x12,0x20,0x49,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 32056 0x7d38 "紸" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x49,0xfc,0x04,0x00,0x54,0x54,0x83,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32057 0x7d39 "紹" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x20,0x49,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 32058 0x7d3a "紺" */
+0x10,0x10,0x20,0x24,0x47,0xf8,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 32059 0x7d3b "紻" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xff,0x04,0x00,0x54,0x54,0x81,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 32060 0x7d3c "紼" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x13,0x22,0x4a,0xfb,0x08,0x00,0xa9,0xa9,0x82,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 32061 0x7d3d "紽" */
+0x10,0x10,0x20,0x25,0x45,0xfa,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 32062 0x7d3e "紾" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x20,0x49,0xfc,0x04,0x00,0x55,0x54,0x80,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 32063 0x7d3f "紿" */
+0x10,0x10,0x20,0x24,0x44,0xf9,0x13,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32064 0x7d40 "絀" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 32065 0x7d41 "絁" */
+0x10,0x10,0x20,0x25,0x46,0xf9,0x11,0x21,0x4b,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 32066 0x7d42 "終" */
+0x10,0x10,0x20,0x28,0x49,0xf2,0x10,0x20,0x48,0xfb,0x08,0x00,0xa8,0xa8,0x80,0x00,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 32067 0x7d43 "絃" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x49,0xfc,0x04,0x00,0x54,0x55,0x80,0x00,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 32068 0x7d44 "組" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xa9,0x87,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 32069 0x7d45 "絅" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x02,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x04,
+/* 32070 0x7d46 "絆" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x11,0x20,0x48,0xfc,0x07,0x00,0x54,0x54,0x80,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32071 0x7d47 "絇" */
+0x10,0x10,0x21,0x29,0x4a,0xf4,0x11,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x80,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 32072 0x7d48 "絈" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32073 0x7d49 "絉" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x48,0xfc,0x05,0x02,0x54,0x54,0x80,0x00,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 32074 0x7d4a "絊" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x49,0xfd,0x06,0x00,0x54,0x54,0x80,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0xf8,0x20,0x20,0x20,0x20,
+/* 32075 0x7d4b "絋" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xaa,0xaa,0x84,0x08,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 32076 0x7d4c "経" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x20,0x4b,0xfc,0x05,0x00,0x54,0x54,0x83,0x00,
+0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x26,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 32077 0x7d4d "絍" */
+0x10,0x10,0x20,0x25,0x45,0xfb,0x15,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 32078 0x7d4e "絎" */
+0x10,0x10,0x20,0x25,0x46,0xf8,0x10,0x21,0x4a,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x40,0x40,0x9c,0x00,0x40,0x40,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0xa8,0x90,
+/* 32079 0x7d4f "絏" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfc,0x04,0x00,0x54,0x54,0x83,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 32080 0x7d50 "結" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x11,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32081 0x7d51 "絑" */
+0x10,0x11,0x21,0x25,0x45,0xfa,0x10,0x23,0x48,0xfc,0x04,0x01,0x55,0x56,0x80,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 32082 0x7d52 "絒" */
+0x11,0x11,0x21,0x29,0x49,0xf1,0x15,0x25,0x49,0xf9,0x09,0x01,0xa9,0xaa,0x82,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0xb4,0x6c,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 32083 0x7d53 "絓" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x13,0x20,0x48,0xfc,0x05,0x00,0x54,0x54,0x83,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 32084 0x7d54 "絔" */
+0x10,0x13,0x20,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32085 0x7d55 "絕" */
+0x10,0x13,0x20,0x24,0x44,0xf9,0x12,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x00,0xfc,0x44,0x44,0x84,0x28,0x10,0xfc,0x24,0x24,0xfc,0x00,0x02,0x02,0xfe,0x00,
+/* 32086 0x7d56 "絖" */
+0x10,0x10,0x22,0x29,0x49,0xf0,0x17,0x20,0x48,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 32087 0x7d57 "絗" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x00,0x00,0xfe,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0xfe,0x02,0x00,
+/* 32088 0x7d58 "絘" */
+0x10,0x10,0x22,0x29,0x49,0xf0,0x10,0x20,0x48,0xfb,0x09,0x01,0xa9,0xa9,0x80,0x00,
+0x10,0x10,0x10,0x3e,0x22,0x44,0x10,0x90,0x90,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 32089 0x7d59 "絙" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x83,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 32090 0x7d5a "絚" */
+0x10,0x13,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfd,0x05,0x00,0x54,0x54,0x83,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x7c,0x84,0xa4,0x94,0x04,0x44,0x28,0x08,0x08,0xfe,0x00,
+/* 32091 0x7d5b "絛" */
+0x10,0x10,0x11,0x22,0x20,0x65,0x66,0xa4,0x25,0x24,0x24,0x25,0x20,0x21,0x22,0x20,
+0x80,0xf8,0x08,0x90,0x60,0x98,0x46,0x88,0xf0,0x20,0x48,0xfc,0x20,0x24,0xa2,0x40,
+/* 32092 0x7d5c "絜" */
+0x08,0x7f,0x08,0x3e,0x08,0x7f,0x0a,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32093 0x7d5d "絝" */
+0x10,0x10,0x23,0x24,0x44,0xf9,0x12,0x20,0x4b,0xfc,0x04,0x01,0x54,0x54,0x80,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 32094 0x7d5e "絞" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x11,0x22,0x48,0xfc,0x04,0x00,0x54,0x54,0x80,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 32095 0x7d5f "絟" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x11,0x20,0x48,0xfc,0x05,0x00,0x54,0x54,0x83,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 32096 0x7d60 "絠" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x21,0x4a,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 32097 0x7d61 "絡" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x49,0xfc,0x04,0x00,0x54,0x54,0x80,0x00,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 32098 0x7d62 "絢" */
+0x10,0x10,0x21,0x25,0x46,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x54,0x80,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 32099 0x7d63 "絣" */
+0x11,0x10,0x20,0x28,0x49,0xf0,0x10,0x20,0x48,0xfb,0x08,0x00,0xa9,0xa9,0x82,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 32100 0x7d64 "絤" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x54,0x8c,0x04,0x04,0x04,0xfc,0x04,
+/* 32101 0x7d65 "絥" */
+0x10,0x10,0x20,0x29,0x49,0xf3,0x15,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x90,0x94,0x92,0x12,0x10,0x7e,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 32102 0x7d66 "給" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x11,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32103 0x7d67 "絧" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 32104 0x7d68 "絨" */
+0x10,0x10,0x20,0x28,0x4b,0xf0,0x11,0x21,0x49,0xfb,0x09,0x01,0xaa,0xaa,0x84,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 32105 0x7d69 "絩" */
+0x10,0x10,0x20,0x2a,0x49,0xf0,0x10,0x21,0x4a,0xfc,0x08,0x00,0xa9,0xa9,0x82,0x04,
+0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x98,0x94,0x92,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 32106 0x7d6a "絪" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 32107 0x7d6b "絫" */
+0x04,0x08,0x1f,0x10,0x24,0x7e,0x02,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0x20,0xf0,0x20,0x48,0xfc,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32108 0x7d6c "絬" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32109 0x7d6d "絭" */
+0x11,0x09,0x7f,0x02,0xff,0x08,0x32,0xc4,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x10,0x20,0xfc,0x00,0xfe,0x20,0x18,0x26,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32110 0x7d6e "絮" */
+0x08,0x7f,0x11,0x32,0x0c,0x32,0xc2,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32111 0x7d6f "絯" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x01,0x54,0x54,0x80,0x01,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 32112 0x7d70 "絰" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x20,0x48,0xfc,0x05,0x00,0x54,0x54,0x83,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 32113 0x7d71 "統" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x11,0x23,0x48,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 32114 0x7d72 "絲" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x49,0xfc,0x04,0x00,0x55,0x56,0x80,0x00,
+0x20,0x20,0x48,0x88,0xf0,0x20,0x40,0x88,0xfc,0x24,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 32115 0x7d73 "絳" */
+0x10,0x10,0x20,0x29,0x4a,0xf0,0x11,0x26,0x48,0xf9,0x08,0x02,0xab,0xa8,0x80,0x00,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 32116 0x7d74 "絴" */
+0x11,0x10,0x20,0x28,0x4b,0xf0,0x10,0x21,0x48,0xfc,0x07,0x00,0x54,0x54,0x80,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32117 0x7d75 "絵" */
+0x10,0x10,0x20,0x28,0x49,0xf2,0x10,0x20,0x48,0xfb,0x08,0x00,0xa8,0xa9,0x83,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 32118 0x7d76 "絶" */
+0x10,0x10,0x20,0x25,0x46,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32119 0x7d77 "絷" */
+0x10,0xfb,0x10,0x19,0xf0,0x11,0x52,0x24,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x80,0xf0,0x90,0x90,0x94,0x54,0x0c,0x24,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32120 0x7d78 "絸" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x00,0x54,0x55,0x82,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 32121 0x7d79 "絹" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 32122 0x7d7a "絺" */
+0x11,0x10,0x20,0x28,0x4b,0xf0,0x13,0x20,0x49,0xfb,0x0d,0x01,0xa9,0xa9,0x80,0x00,
+0x84,0x68,0x30,0xc8,0x04,0x40,0xfe,0xa0,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 32123 0x7d7b "絻" */
+0x10,0x10,0x20,0x25,0x46,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x54,0x81,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 32124 0x7d7c "絼" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x21,0x48,0xfc,0x05,0x00,0x54,0x55,0x80,0x00,
+0x08,0x3c,0xe0,0x96,0x48,0x30,0x48,0x94,0x24,0x4c,0x94,0x24,0x44,0x84,0x28,0x10,
+/* 32125 0x7d7d "絽" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfe,0x02,
+/* 32126 0x7d7e "絾" */
+0x10,0x10,0x20,0x28,0x4b,0xf2,0x12,0x22,0x4b,0xfa,0x0a,0x02,0xaa,0xad,0x84,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 32127 0x7d7f "絿" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x11,0x20,0x48,0xfc,0x04,0x01,0x56,0x54,0x80,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 32128 0x7d80 "綀" */
+0x10,0x10,0x23,0x24,0x44,0xf9,0x11,0x21,0x49,0xfc,0x04,0x00,0x55,0x56,0x80,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 32129 0x7d81 "綁" */
+0x21,0x21,0x41,0x47,0x91,0xe1,0x27,0x41,0x91,0xf7,0x01,0x11,0xa9,0xa2,0x82,0x04,
+0x00,0x1e,0x12,0xd2,0x14,0x14,0xd8,0x14,0x12,0xd2,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 32130 0x7d82 "綂" */
+0x10,0x10,0x23,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x54,0x81,0x02,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 32131 0x7d83 "綃" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 32132 0x7d84 "綄" */
+0x10,0x10,0x23,0x2a,0x4c,0xf1,0x10,0x20,0x4b,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 32133 0x7d85 "綅" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x10,0x23,0x4a,0xfd,0x04,0x00,0x54,0x54,0x80,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 32134 0x7d86 "綆" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x80,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 32135 0x7d87 "綇" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x8c,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 32136 0x7d88 "綈" */
+0x11,0x10,0x20,0x25,0x44,0xf8,0x11,0x21,0x49,0xfd,0x04,0x00,0x55,0x56,0x84,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 32137 0x7d89 "綉" */
+0x10,0x11,0x20,0x24,0x47,0xf8,0x11,0x22,0x49,0xfc,0x04,0x00,0x55,0x55,0x82,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 32138 0x7d8a "綊" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x11,0x21,0x49,0xfa,0x08,0x00,0xa8,0xa8,0x81,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 32139 0x7d8b "綋" */
+0x10,0x10,0x23,0x2a,0x4c,0xf0,0x13,0x20,0x48,0xf8,0x09,0x01,0xaa,0xaa,0x84,0x08,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x90,0x90,0x10,0x20,0x24,0x42,0xfe,0x42,
+/* 32140 0x7d8c "綌" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x49,0xfe,0x04,0x00,0x54,0x54,0x80,0x00,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 32141 0x7d8d "綍" */
+0x10,0x10,0x23,0x28,0x48,0xf3,0x12,0x24,0x49,0xfc,0x04,0x03,0x54,0x54,0x80,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 32142 0x7d8e "綎" */
+0x10,0x10,0x23,0x28,0x48,0xf1,0x11,0x23,0x48,0xfa,0x0a,0x01,0xa9,0xaa,0x84,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 32143 0x7d8f "綏" */
+0x10,0x10,0x23,0x28,0x4a,0xf1,0x11,0x20,0x4b,0xf8,0x09,0x03,0xa8,0xa8,0x81,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 32144 0x7d90 "綐" */
+0x11,0x10,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfc,0x04,0x00,0x54,0x55,0x82,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 32145 0x7d91 "綑" */
+0x10,0x13,0x22,0x2a,0x4a,0xf3,0x12,0x22,0x4a,0xfa,0x0b,0x02,0xaa,0xaa,0x83,0x02,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 32146 0x7d92 "綒" */
+0x10,0x10,0x21,0x24,0x45,0xf8,0x10,0x21,0x48,0xfc,0x07,0x00,0x54,0x54,0x80,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 32147 0x7d93 "經" */
+0x10,0x11,0x20,0x28,0x49,0xf2,0x11,0x20,0x48,0xfd,0x04,0x00,0x54,0x54,0x83,0x00,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32148 0x7d94 "綔" */
+0x10,0x10,0xfe,0x28,0x44,0x82,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x05,0x28,0x10,
+0x00,0x0c,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x12,0x50,0x54,0x92,0x12,0x50,0x20,
+/* 32149 0x7d95 "綕" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x10,0x21,0x48,0xf8,0x08,0x02,0xaa,0xaa,0x84,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 32150 0x7d96 "綖" */
+0x10,0x10,0x23,0x28,0x48,0xf1,0x11,0x23,0x48,0xfa,0x0a,0x01,0xa9,0xaa,0x84,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 32151 0x7d97 "綗" */
+0x10,0x13,0x22,0x2a,0x4a,0xf3,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x00,0xfe,0x02,0x52,0x8a,0x06,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 32152 0x7d98 "綘" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x23,0x48,0xfc,0x04,0x00,0x57,0x54,0x80,0x00,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 32153 0x7d99 "継" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x00,
+0x10,0x10,0x10,0x92,0x54,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0xfe,0x00,
+/* 32154 0x7d9a "続" */
+0x10,0x10,0x23,0x28,0x49,0xf0,0x13,0x22,0x4c,0xf8,0x08,0x00,0xa8,0xa9,0x81,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0x04,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 32155 0x7d9b "綛" */
+0x10,0x13,0x20,0x29,0x49,0xf2,0x10,0x21,0x4a,0xf8,0x08,0x02,0xaa,0xaa,0x84,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 32156 0x7d9c "綜" */
+0x10,0x10,0x23,0x2a,0x48,0xf1,0x10,0x20,0x4b,0xf8,0x09,0x01,0xaa,0xac,0x80,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 32157 0x7d9d "綝" */
+0x10,0x10,0x20,0x28,0x4b,0xf0,0x10,0x21,0x49,0xfa,0x0a,0x04,0xa8,0xa8,0x80,0x00,
+0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x9c,0xdc,0xaa,0xaa,0xc8,0x88,0x88,0x88,0x88,
+/* 32158 0x7d9e "綞" */
+0x10,0x10,0x21,0x28,0x4b,0xf0,0x10,0x20,0x4b,0xfc,0x04,0x03,0x54,0x54,0x81,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 32159 0x7d9f "綟" */
+0x10,0x10,0x23,0x2a,0x4a,0xf3,0x12,0x22,0x4a,0xfb,0x0a,0x02,0xaa,0xac,0x85,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 32160 0x7da0 "綠" */
+0x10,0x10,0x20,0x29,0x49,0xf0,0x10,0x23,0x48,0xfa,0x09,0x00,0xa9,0xaa,0x80,0x00,
+0x80,0xf8,0x88,0x08,0xf0,0x10,0x10,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 32161 0x7da1 "綡" */
+0x10,0x10,0x23,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x55,0x56,0x80,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 32162 0x7da2 "綢" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x56,0x82,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 32163 0x7da3 "綣" */
+0x10,0x11,0x20,0x24,0x45,0xf8,0x13,0x20,0x49,0xfe,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 32164 0x7da4 "綤" */
+0x7e,0x12,0x2a,0x44,0xbe,0x22,0x22,0x3e,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x7c,0x44,0x48,0x44,0x44,0x54,0x48,0x00,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32165 0x7da5 "綥" */
+0x10,0x11,0x21,0x29,0x49,0xf1,0x11,0x21,0x48,0xf8,0x0b,0x00,0xa8,0xa8,0x81,0x02,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x00,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 32166 0x7da6 "綦" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x14,0x28,0xdf,0x02,0x3f,0x01,0x15,0x22,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x50,0x88,0x06,0x10,0xf8,0x08,0x20,0x10,
+/* 32167 0x7da7 "綧" */
+0x10,0x10,0x23,0x24,0x45,0xf9,0x11,0x20,0x49,0xfc,0x04,0x03,0x54,0x54,0x80,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 32168 0x7da8 "綨" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x04,0x03,0x54,0x54,0x81,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 32169 0x7da9 "綩" */
+0x10,0x10,0x23,0x2a,0x4d,0xf1,0x11,0x22,0x4a,0xfb,0x0c,0x00,0xa9,0xa9,0x82,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 32170 0x7daa "綪" */
+0x10,0x10,0x23,0x24,0x45,0xf8,0x13,0x20,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 32171 0x7dab "綫" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x21,0x48,0xfc,0x05,0x00,0x54,0x54,0x80,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 32172 0x7dac "綬" */
+0x10,0x13,0x20,0x2a,0x49,0xf1,0x17,0x24,0x48,0xfb,0x09,0x01,0xa8,0xa8,0x81,0x06,
+0x1c,0xe0,0x84,0x44,0x48,0x10,0xfe,0x02,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 32173 0x7dad "維" */
+0x10,0x10,0x20,0x25,0x45,0xfb,0x15,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 32174 0x7dae "綮" */
+0x10,0x08,0x3e,0x22,0x23,0x3e,0x20,0x41,0x84,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x40,0x40,0x7e,0x88,0x50,0x20,0x58,0x86,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32175 0x7daf "綯" */
+0x10,0x10,0x21,0x25,0x46,0xf8,0x11,0x20,0x4b,0xfc,0x05,0x01,0x55,0x54,0x80,0x00,
+0x80,0x80,0xfc,0x04,0x84,0xf4,0x44,0x44,0xfc,0x44,0x54,0x54,0xf4,0x04,0x28,0x10,
+/* 32176 0x7db0 "綰" */
+0x10,0x10,0x23,0x2a,0x4c,0xf1,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 32177 0x7db1 "綱" */
+0x10,0x13,0x22,0x2a,0x4a,0xf3,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 32178 0x7db2 "網" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x11,0x21,0x21,0x49,0xf5,0x01,0x55,0x55,0x55,0x81,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x12,0xfe,0x42,0x42,0x7a,0x02,0x02,0x0a,0x04,
+/* 32179 0x7db3 "綳" */
+0x10,0x13,0x22,0x2a,0x4a,0xf3,0x12,0x22,0x4a,0xfb,0x0a,0x02,0xaa,0xaa,0x85,0x08,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 32180 0x7db4 "綴" */
+0x10,0x13,0x20,0x29,0x48,0xf1,0x12,0x24,0x48,0xfb,0x08,0x01,0xa8,0xa9,0x82,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 32181 0x7db5 "綵" */
+0x10,0x10,0x23,0x28,0x4a,0xf1,0x11,0x20,0x4b,0xf8,0x08,0x00,0xa9,0xaa,0x84,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 32182 0x7db6 "綶" */
+0x10,0x11,0x21,0x29,0x49,0xf1,0x11,0x21,0x48,0xfb,0x08,0x00,0xa9,0xaa,0x80,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 32183 0x7db7 "綷" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x11,0x22,0x48,0xfc,0x05,0x00,0x54,0x54,0x80,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32184 0x7db8 "綸" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 32185 0x7db9 "綹" */
+0x10,0x10,0x20,0x25,0x45,0xfa,0x10,0x20,0x49,0xfe,0x04,0x00,0x54,0x54,0x80,0x00,
+0x88,0x88,0xe8,0x2c,0x2a,0xa8,0x48,0xa0,0x1e,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 32186 0x7dba "綺" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x13,0x20,0x49,0xfd,0x05,0x01,0x55,0x54,0x80,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 32187 0x7dbb "綻" */
+0x10,0x10,0x23,0x2a,0x4c,0xf0,0x13,0x20,0x48,0xf9,0x09,0x01,0xaa,0xaa,0x84,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 32188 0x7dbc "綼" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfc,0x05,0x03,0x54,0x54,0x80,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 32189 0x7dbd "綽" */
+0x10,0x10,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x03,0x54,0x54,0x80,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 32190 0x7dbe "綾" */
+0x10,0x10,0x21,0x28,0x48,0xf3,0x10,0x21,0x4a,0xf8,0x09,0x02,0xa8,0xa8,0x81,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 32191 0x7dbf "綿" */
+0x10,0x10,0x21,0x29,0x49,0xf1,0x11,0x20,0x48,0xfb,0x0a,0x02,0xaa,0xaa,0x80,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 32192 0x7dc0 "緀" */
+0x10,0x10,0x23,0x24,0x45,0xf8,0x13,0x20,0x49,0xfc,0x07,0x00,0x55,0x54,0x80,0x03,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x40,0xfe,0x84,0xc8,0x30,0xcc,0x02,
+/* 32193 0x7dc1 "緁" */
+0x10,0x10,0x23,0x24,0x45,0xf8,0x13,0x20,0x49,0xfc,0x05,0x01,0xa9,0xaa,0x82,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 32194 0x7dc2 "緂" */
+0x10,0x11,0x21,0x2a,0x48,0xf0,0x13,0x20,0x48,0xf9,0x09,0x02,0xa8,0xa8,0x81,0x06,
+0x20,0x22,0x22,0x24,0x50,0x88,0x04,0x22,0x20,0x24,0x24,0x28,0x50,0x88,0x04,0x02,
+/* 32195 0x7dc3 "緃" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x14,0x20,0x48,0xfd,0x05,0x01,0xaa,0xaa,0x84,0x08,
+0x88,0x88,0x88,0x88,0x54,0x22,0x42,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 32196 0x7dc4 "緄" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 32197 0x7dc5 "緅" */
+0x20,0x2f,0x44,0x44,0x94,0xe7,0x24,0x44,0x97,0xf4,0x04,0x15,0xae,0xa0,0x80,0x00,
+0x00,0xc0,0xbc,0xa4,0xa4,0xa4,0xa4,0xa8,0xa8,0xa8,0x90,0xd0,0xa8,0xa8,0xc4,0x82,
+/* 32198 0x7dc6 "緆" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x20,0x49,0xfe,0x04,0x00,0xa9,0xaa,0x80,0x01,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0x80,0xfe,0x4a,0x4a,0x92,0x22,0x42,0x94,0x08,
+/* 32199 0x7dc7 "緇" */
+0x10,0x10,0x21,0x2a,0x49,0xf0,0x10,0x20,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 32200 0x7dc8 "緈" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x20,0x49,0xfc,0x04,0x03,0x54,0x54,0x80,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x50,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 32201 0x7dc9 "緉" */
+0x10,0x13,0x20,0x28,0x4b,0xf2,0x12,0x23,0x4a,0xfa,0x0b,0x02,0xaa,0xaa,0x82,0x02,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 32202 0x7dca "緊" */
+0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x04,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x20,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32203 0x7dcb "緋" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x10,0x23,0x48,0xf8,0x08,0x03,0xa8,0xa8,0x80,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 32204 0x7dcc "緌" */
+0x10,0x11,0x20,0x28,0x4b,0xf0,0x11,0x22,0x48,0xfb,0x08,0x01,0xa8,0xa8,0x80,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 32205 0x7dcd "緍" */
+0x10,0x13,0x22,0x2b,0x4a,0xf2,0x13,0x22,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 32206 0x7dce "緎" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x13,0x22,0x4a,0xfa,0x0b,0x00,0xa8,0xab,0x81,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x0c,0x6a,0x8a,0x16,0x22,
+/* 32207 0x7dcf "総" */
+0x10,0x10,0x21,0x29,0x4a,0xf4,0x11,0x23,0x48,0xf8,0x08,0x02,0xaa,0xaa,0x84,0x00,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 32208 0x7dd0 "緐" */
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x64,0x54,0xfe,0x44,0xa4,0x94,0xfe,0x05,0x28,0x10,
+0x00,0x0c,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x12,0x50,0x54,0x92,0x12,0x50,0x20,
+/* 32209 0x7dd1 "緑" */
+0x10,0x11,0x20,0x28,0x49,0xf0,0x10,0x23,0x48,0xfa,0x09,0x00,0xa9,0xaa,0x80,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 32210 0x7dd2 "緒" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x20,0x48,0xfd,0x06,0x00,0x54,0x54,0x80,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 32211 0x7dd3 "緓" */
+0x10,0x10,0x23,0x28,0x48,0xf0,0x11,0x21,0x49,0xf9,0x0b,0x00,0xa8,0xa8,0x81,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 32212 0x7dd4 "緔" */
+0x10,0x11,0x20,0x28,0x48,0xf3,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 32213 0x7dd5 "緕" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x10,0x23,0x48,0xfc,0x04,0x00,0x54,0x55,0x81,0x02,
+0x40,0x20,0xfe,0x88,0x50,0x20,0xd8,0x06,0x88,0xf8,0x88,0x88,0xf8,0x08,0x08,0x08,
+/* 32214 0x7dd6 "緖" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x20,0x48,0xfd,0x06,0x00,0x54,0x54,0x80,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x24,0x42,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 32215 0x7dd7 "緗" */
+0x11,0x11,0x21,0x29,0x4b,0xf1,0x11,0x23,0x4b,0xfd,0x09,0x01,0xa9,0xa9,0x81,0x01,
+0x00,0x00,0x3c,0x24,0xa4,0x24,0x3c,0xa4,0x64,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,
+/* 32216 0x7dd8 "緘" */
+0x10,0x10,0x20,0x2b,0x4a,0xf2,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x04,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 32217 0x7dd9 "緙" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x11,0x21,0x49,0xfd,0x04,0x03,0x54,0x54,0x80,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 32218 0x7dda "線" */
+0x10,0x10,0x21,0x29,0x49,0xf1,0x11,0x20,0x48,0xfb,0x08,0x01,0xa9,0xaa,0x84,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 32219 0x7ddb "緛" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x03,0x54,0x54,0x81,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 32220 0x7ddc "緜" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0xfe,0x92,0x92,0x92,0x97,0x10,0x10,
+0x00,0x0c,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x12,0x50,0x54,0x92,0x12,0x50,0x20,
+/* 32221 0x7ddd "緝" */
+0x10,0x11,0x21,0x29,0x49,0xf0,0x17,0x21,0x49,0xf9,0x09,0x01,0xa9,0xaf,0x80,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 32222 0x7dde "緞" */
+0x10,0x13,0x22,0x2a,0x4b,0xf2,0x12,0x22,0x4b,0xfa,0x0a,0x03,0xae,0xaa,0x82,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 32223 0x7ddf "緟" */
+0x10,0x10,0x21,0x28,0x4b,0xf0,0x11,0x21,0x49,0xfd,0x05,0x00,0x55,0x54,0x83,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 32224 0x7de0 "締" */
+0x10,0x10,0x23,0x28,0x49,0xf0,0x17,0x24,0x48,0xfb,0x0a,0x02,0xaa,0xaa,0x80,0x00,
+0x80,0x40,0xfc,0x00,0x08,0x90,0xfe,0x42,0x44,0xfc,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 32225 0x7de1 "緡" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfc,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 32226 0x7de2 "緢" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 32227 0x7de3 "緣" */
+0x10,0x10,0x21,0x29,0x48,0xf3,0x10,0x20,0x4b,0xf8,0x08,0x03,0xa8,0xa8,0x83,0x00,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 32228 0x7de4 "緤" */
+0x10,0x11,0x21,0x2b,0x49,0xf1,0x11,0x21,0x49,0xf8,0x0b,0x00,0xa8,0xa9,0x86,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 32229 0x7de5 "緥" */
+0x11,0x11,0x21,0x2a,0x4a,0xf6,0x1a,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xab,0x82,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 32230 0x7de6 "緦" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x48,0xfc,0x04,0x01,0x55,0x55,0x82,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 32231 0x7de7 "緧" */
+0x10,0x10,0x20,0x2b,0x48,0xf0,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 32232 0x7de8 "編" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x02,0xaa,0xaa,0x84,0x00,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 32233 0x7de9 "緩" */
+0x10,0x13,0x20,0x25,0x44,0xf9,0x10,0x20,0x4b,0xfc,0x04,0x01,0x55,0x56,0x80,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 32234 0x7dea "緪" */
+0x11,0x11,0x21,0x25,0x45,0xf9,0x13,0x25,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0x7e,0x10,0x10,0x90,0x5e,0x22,0x2a,0x26,0x42,0x52,0x0c,0x04,0x04,0x7e,0x00,
+/* 32235 0x7deb "緫" */
+0x10,0x10,0x20,0x29,0x4a,0xf0,0x11,0x22,0x48,0xf9,0x08,0x00,0xaa,0xaa,0x84,0x00,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 32236 0x7dec "緬" */
+0x10,0x17,0x20,0x28,0x4b,0xf2,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x83,0x02,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 32237 0x7ded "緭" */
+0x10,0x13,0x22,0x2b,0x4a,0xf3,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 32238 0x7dee "緮" */
+0x11,0x11,0x21,0x2a,0x4d,0xf1,0x11,0x21,0x49,0xfc,0x04,0x01,0x56,0x54,0x81,0x06,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 32239 0x7def "緯" */
+0x10,0x10,0x21,0x28,0x4b,0xf0,0x11,0x21,0x49,0xf8,0x0b,0x00,0xaa,0xab,0x80,0x00,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 32240 0x7df0 "緰" */
+0x10,0x10,0x21,0x2a,0x4d,0xf0,0x13,0x22,0x4a,0xfb,0x0a,0x02,0xab,0xaa,0x82,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 32241 0x7df1 "緱" */
+0x11,0x11,0x21,0x2a,0x4a,0xf6,0x1a,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 32242 0x7df2 "緲" */
+0x10,0x10,0x23,0x2a,0x4a,0xf3,0x12,0x22,0x4b,0xfa,0x0a,0x03,0xaa,0xa8,0x80,0x01,
+0x10,0x10,0x90,0x90,0x94,0xb2,0xb2,0xd2,0x90,0x94,0x84,0x88,0x90,0x20,0x40,0x80,
+/* 32243 0x7df3 "緳" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x24,0x2f,0x41,0x5f,0x88,0x11,
+0x00,0x80,0xfe,0x00,0xbc,0x14,0x94,0x14,0xa4,0x0c,0x20,0xc0,0x08,0xfc,0x88,0x84,
+/* 32244 0x7df4 "練" */
+0x10,0x10,0x23,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x55,0x82,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 32245 0x7df5 "緵" */
+0x10,0x10,0x22,0x2a,0x4a,0xf2,0x12,0x23,0x48,0xf9,0x0a,0x00,0xa9,0xa8,0x80,0x03,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 32246 0x7df6 "緶" */
+0x11,0x11,0x21,0x2a,0x4a,0xf2,0x16,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x00,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x90,0x50,0x20,0x58,0x86,
+/* 32247 0x7df7 "緷" */
+0x10,0x13,0x22,0x24,0x45,0xf8,0x11,0x21,0x49,0xfd,0x05,0x00,0x57,0x54,0x80,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 32248 0x7df8 "緸" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x49,0xfc,0x04,0x01,0x54,0x54,0x83,0x00,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 32249 0x7df9 "緹" */
+0x10,0x11,0x21,0x29,0x49,0xf1,0x11,0x21,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x82,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 32250 0x7dfa "緺" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x84,0x84,0xf4,0x94,0x94,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 32251 0x7dfb "緻" */
+0x20,0x20,0x47,0x42,0x92,0xe4,0x27,0x41,0x91,0xf7,0x01,0x11,0xa9,0xae,0x84,0x00,
+0x08,0x08,0xc8,0x10,0x1e,0xa4,0xd4,0x14,0x14,0xd4,0x14,0x08,0xc8,0x14,0x14,0x22,
+/* 32252 0x7dfc "緼" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x83,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 32253 0x7dfd "緽" */
+0x10,0x10,0x20,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x81,0x02,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 32254 0x7dfe "緾" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x56,0x82,0x04,
+0x00,0xfe,0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x10,0x7c,0x10,0x10,0xfe,
+/* 32255 0x7dff "緿" */
+0x10,0x10,0x21,0x2b,0x48,0xf0,0x11,0x21,0x49,0xf9,0x08,0x00,0xaa,0xaa,0x84,0x00,
+0x40,0x90,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0xf8,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 32256 0x7e00 "縀" */
+0x10,0x13,0x22,0x2a,0x4a,0xf3,0x12,0x22,0x4b,0xfa,0x0a,0x03,0xaa,0xaa,0x82,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 32257 0x7e01 "縁" */
+0x10,0x11,0x20,0x28,0x48,0xf3,0x10,0x20,0x4b,0xf8,0x08,0x03,0xa8,0xa8,0x83,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 32258 0x7e02 "縂" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x48,0xfc,0x04,0x01,0x55,0x55,0x82,0x00,
+0x88,0x48,0x50,0xfc,0x04,0x04,0x04,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 32259 0x7e03 "縃" */
+0x10,0x13,0x20,0x25,0x45,0xf9,0x12,0x24,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 32260 0x7e04 "縄" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x80,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x22,0x22,0x1e,
+/* 32261 0x7e05 "縅" */
+0x10,0x10,0x20,0x2b,0x4a,0xf3,0x12,0x22,0x4b,0xfa,0x0a,0x02,0xaa,0xab,0x82,0x04,
+0x0c,0x0a,0x08,0xfe,0x08,0xf8,0x4a,0x4a,0xea,0xac,0xac,0x4c,0xaa,0x0a,0x16,0x22,
+/* 32262 0x7e06 "縆" */
+0x21,0x21,0x41,0x41,0x91,0xe5,0x25,0x45,0x95,0xf1,0x01,0x11,0xa9,0xa1,0x81,0x01,
+0x00,0x3c,0x00,0x00,0xbc,0x64,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x00,0x7e,0x00,
+/* 32263 0x7e07 "縇" */
+0x10,0x10,0x23,0x2a,0x4c,0xf1,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x54,0x83,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 32264 0x7e08 "縈" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x42,0x84,0x1f,0x01,0x06,0x3f,0x01,0x11,0x25,0x42,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x24,0xc0,0x80,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 32265 0x7e09 "縉" */
+0x10,0x13,0x20,0x2a,0x49,0xf0,0x17,0x20,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 32266 0x7e0a "縊" */
+0x11,0x10,0x20,0x28,0x4b,0xf0,0x10,0x21,0x4a,0xf9,0x09,0x01,0xa9,0xa9,0x87,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 32267 0x7e0b "縋" */
+0x10,0x12,0x21,0x25,0x44,0xf8,0x13,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x84,0x00,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 32268 0x7e0c "縌" */
+0x12,0x11,0x21,0x24,0x44,0xfb,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x84,0x00,
+0x44,0x24,0x28,0x7e,0x10,0x54,0x54,0x54,0x7c,0x14,0x20,0x20,0x40,0x80,0x7e,0x00,
+/* 32269 0x7e0d "縍" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x11,0x22,0x48,0xfd,0x04,0x00,0x54,0x54,0x80,0x01,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 32270 0x7e0e "縎" */
+0x10,0x11,0x21,0x25,0x45,0xfb,0x12,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x00,0xfc,0x04,0xe4,0x24,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 32271 0x7e0f "縏" */
+0x08,0x3e,0x22,0x2a,0x7e,0x22,0x2a,0x46,0x84,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x78,0x48,0x8e,0x00,0xf8,0x48,0x30,0xcc,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32272 0x7e10 "縐" */
+0x10,0x10,0x21,0x2a,0x49,0xf1,0x10,0x21,0x4a,0xf9,0x0a,0x05,0xa9,0xa8,0x81,0x02,
+0x80,0x80,0xfc,0x44,0x54,0xf4,0x84,0x28,0x90,0xfc,0x44,0x54,0xf4,0x84,0x28,0x10,
+/* 32273 0x7e11 "縑" */
+0x10,0x10,0x20,0x25,0x44,0xf9,0x10,0x23,0x48,0xfd,0x04,0x00,0x55,0x56,0x80,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 32274 0x7e12 "縒" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x21,0x48,0xfc,0x04,0x01,0x56,0x54,0x81,0x00,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 32275 0x7e13 "縓" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x82,0x04,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 32276 0x7e14 "縔" */
+0x11,0x10,0x20,0x29,0x48,0xf3,0x12,0x21,0x4a,0xf8,0x0b,0x00,0xa8,0xa9,0x86,0x00,
+0xf8,0x88,0x70,0x8c,0x00,0xde,0x52,0x8c,0x52,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 32277 0x7e15 "縕" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x83,0x00,
+0x00,0xf8,0xa8,0xa8,0xd8,0x88,0xf8,0x00,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 32278 0x7e16 "縖" */
+0x10,0x10,0x23,0x2a,0x4c,0xf1,0x10,0x21,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x81,0x01,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 32279 0x7e17 "縗" */
+0x10,0x10,0x23,0x28,0x49,0xf1,0x17,0x21,0x49,0xfc,0x04,0x01,0x56,0x54,0x80,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfe,0x04,0xfc,0x52,0x94,0x88,0x88,0xa4,0xc2,0x80,
+/* 32280 0x7e18 "縘" */
+0x10,0x13,0x21,0x28,0x48,0xf0,0x11,0x20,0x48,0xf9,0x08,0x00,0xab,0xa8,0x80,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 32281 0x7e19 "縙" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x10,0x20,0x48,0xfc,0x04,0x00,0x54,0x55,0x80,0x00,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x88,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 32282 0x7e1a "縚" */
+0x10,0x11,0x20,0x25,0x44,0xf8,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 32283 0x7e1b "縛" */
+0x10,0x10,0x23,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x03,0x54,0x54,0x80,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 32284 0x7e1c "縜" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x54,0x80,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0xfe,0x02,0xfe,0x02,0xfe,0x48,0x84,0x02,
+/* 32285 0x7e1d "縝" */
+0x10,0x10,0x23,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0x57,0x54,0x81,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 32286 0x7e1e "縞" */
+0x10,0x10,0x23,0x28,0x49,0xf1,0x11,0x20,0x4b,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x40,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf4,0x94,0xf4,0x04,0x14,0x08,
+/* 32287 0x7e1f "縟" */
+0x10,0x13,0x22,0x22,0x4a,0xfb,0x12,0x22,0x4a,0xfa,0x0a,0x13,0xaa,0xa4,0x84,0x08,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 32288 0x7e20 "縠" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x20,0x44,0x78,0x14,0xfe,0x54,0x92,0x31,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32289 0x7e21 "縡" */
+0x10,0x10,0x23,0x2a,0x48,0xf1,0x10,0x20,0x4b,0xfc,0x04,0x01,0x54,0x54,0x80,0x00,
+0x40,0x20,0xfe,0x42,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 32290 0x7e22 "縢" */
+0x00,0x79,0x48,0x49,0x48,0x7b,0x48,0x49,0x4a,0x78,0x48,0x49,0x48,0x49,0x4a,0x98,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x44,0x8a,0xf0,0x24,0xfc,0x20,0x24,0x22,0x60,
+/* 32291 0x7e23 "縣" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x10,0x54,0x52,0x93,0x50,0x20,
+0x00,0x0c,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x12,0x50,0x54,0x92,0x12,0x50,0x20,
+/* 32292 0x7e24 "縤" */
+0x10,0x10,0x23,0x24,0x45,0xf8,0x13,0x20,0x48,0xfd,0x04,0x03,0x54,0x55,0x82,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 32293 0x7e25 "縥" */
+0x10,0x10,0x23,0x24,0x45,0xf8,0x13,0x20,0x49,0xfe,0x04,0x01,0x54,0x54,0x83,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 32294 0x7e26 "縦" */
+0x10,0x10,0x21,0x25,0x46,0xf8,0x11,0x21,0x4b,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x80,0xa2,0x12,0x14,0x80,0xfe,0x08,0x08,0x28,0x2e,0x28,0x28,0x28,0x58,0x4e,0x80,
+/* 32295 0x7e27 "縧" */
+0x11,0x11,0x21,0x2a,0x4a,0xf6,0x1a,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x10,0x1e,0x22,0x54,0x08,0x94,0xe2,0x88,0x88,0xbe,0x88,0xac,0x2a,0x4a,0x28,0x10,
+/* 32296 0x7e28 "縨" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x21,0x48,0xfc,0x07,0x00,0x54,0x55,0x82,0x04,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 32297 0x7e29 "縩" */
+0x11,0x11,0x23,0x2a,0x4d,0xf2,0x11,0x22,0x4c,0xf8,0x0b,0x00,0xa9,0xaa,0x85,0x00,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 32298 0x7e2a "縪" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x20,0x4b,0xfc,0x04,0x01,0xa8,0xab,0x80,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 32299 0x7e2b "縫" */
+0x10,0x14,0x22,0x29,0x48,0xf0,0x16,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x85,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 32300 0x7e2c "縬" */
+0x10,0x10,0x20,0x23,0x4a,0xfa,0x12,0x22,0x4b,0xfa,0x0a,0x12,0xab,0xa4,0x84,0x08,
+0x0c,0x0a,0x08,0xfe,0x08,0x48,0x6a,0x4a,0xfa,0x4c,0x4c,0xec,0x5a,0x4a,0xd6,0x22,
+/* 32301 0x7e2d "縭" */
+0x10,0x10,0x23,0x28,0x49,0xf1,0x11,0x21,0x48,0xfb,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 32302 0x7e2e "縮" */
+0x10,0x10,0x23,0x2a,0x48,0xf0,0x11,0x23,0x4d,0xf9,0x09,0x01,0xa9,0xa9,0x81,0x01,
+0x20,0x10,0xfe,0x02,0x80,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 32303 0x7e2f "縯" */
+0x10,0x10,0x23,0x2a,0x48,0xf1,0x10,0x21,0x49,0xfd,0x05,0x01,0x54,0x54,0x81,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 32304 0x7e30 "縰" */
+0x11,0x11,0x22,0x24,0x44,0xf9,0x13,0x25,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x08,0x08,0x28,0xae,0xa8,0x28,0x7e,0x00,0x08,0x28,0x2e,0x28,0x58,0x48,0x86,0x00,
+/* 32305 0x7e31 "縱" */
+0x11,0x11,0x22,0x2c,0x49,0xf1,0x12,0x26,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x03,
+0x24,0x24,0x24,0x24,0x54,0x4a,0x92,0x10,0x10,0x50,0x5c,0x50,0x50,0xb0,0x9e,0x00,
+/* 32306 0x7e32 "縲" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x20,0x49,0xfc,0x04,0x03,0x54,0x55,0x82,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 32307 0x7e33 "縳" */
+0x10,0x13,0x20,0x25,0x45,0xf9,0x11,0x21,0x48,0xfd,0x04,0x01,0x55,0x54,0x80,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 32308 0x7e34 "縴" */
+0x10,0x13,0x20,0x20,0x48,0xfb,0x12,0x20,0x49,0xf8,0x09,0x11,0xaa,0xa7,0x80,0x00,
+0x20,0xfe,0x48,0xf0,0x20,0xfe,0x42,0x90,0xf8,0x28,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 32309 0x7e35 "縵" */
+0x10,0x11,0x21,0x29,0x49,0xf1,0x10,0x23,0x4a,0xfb,0x08,0x01,0xa8,0xa8,0x81,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 32310 0x7e36 "縶" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x0a,0x04,0x0f,0x02,0x3f,0x01,0x15,0x22,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x20,0xc0,0x10,0xf8,0x08,0x20,0x10,
+/* 32311 0x7e37 "縷" */
+0x10,0x11,0x21,0x2b,0x49,0xf1,0x10,0x21,0x49,0xfd,0x04,0x03,0x54,0x55,0x80,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 32312 0x7e38 "縸" */
+0x10,0x10,0x23,0x24,0x44,0xf9,0x11,0x21,0x49,0xfd,0x04,0x03,0x54,0x54,0x81,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 32313 0x7e39 "縹" */
+0x10,0x13,0x20,0x25,0x45,0xf9,0x11,0x20,0x49,0xfc,0x07,0x00,0x54,0x55,0x82,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 32314 0x7e3a "縺" */
+0x10,0x10,0x22,0x25,0x45,0xf8,0x10,0x23,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x84,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 32315 0x7e3b "縻" */
+0x01,0x00,0x3f,0x22,0x2f,0x26,0x2b,0x32,0x21,0x27,0x20,0x23,0x2f,0x40,0x45,0x88,
+0x00,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x08,0xf0,0x60,0x84,0xfe,0x42,0x48,0x84,
+/* 32316 0x7e3c "縼" */
+0x12,0x11,0x21,0x27,0x4a,0xfa,0x13,0x22,0x4a,0xfa,0x0a,0x12,0xac,0xa5,0x88,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 32317 0x7e3d "總" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x55,0x55,0x81,0x02,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 32318 0x7e3e "績" */
+0x10,0x13,0x20,0x25,0x44,0xfb,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32319 0x7e3f "縿" */
+0x10,0x10,0x21,0x29,0x4a,0xf3,0x10,0x21,0x4e,0xf8,0x0b,0x00,0xab,0xa8,0x80,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 32320 0x7e40 "繀" */
+0x10,0x12,0x23,0x28,0x48,0xf1,0x13,0x25,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 32321 0x7e41 "繁" */
+0x20,0x3f,0x40,0xbe,0x2a,0xff,0x4a,0x7f,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0x28,0x46,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32322 0x7e42 "繂" */
+0x10,0x10,0x23,0x28,0x48,0xf2,0x11,0x22,0x48,0xfc,0x04,0x03,0x54,0x54,0x80,0x00,
+0x40,0x20,0xfe,0x20,0x48,0xf2,0x24,0x52,0xf8,0x08,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 32323 0x7e43 "繃" */
+0x10,0x12,0x22,0x2b,0x48,0xf3,0x12,0x22,0x4b,0xfa,0x0a,0x03,0xaa,0xaa,0x85,0x08,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 32324 0x7e44 "繄" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32325 0x7e45 "繅" */
+0x11,0x12,0x21,0x28,0x49,0xf1,0x11,0x21,0x49,0xf8,0x0b,0x00,0xa8,0xa9,0x86,0x00,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 32326 0x7e46 "繆" */
+0x10,0x13,0x20,0x2a,0x49,0xf2,0x10,0x20,0x4b,0xf8,0x09,0x00,0xa9,0xa8,0x80,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 32327 0x7e47 "繇" */
+0x00,0x0e,0xf0,0x22,0x92,0x44,0x20,0x3c,0x50,0x10,0xfe,0x10,0x54,0x55,0x5c,0x64,
+0x00,0x0c,0xf0,0x20,0x44,0xf8,0x10,0x24,0xfe,0x12,0x50,0x54,0x92,0x12,0x50,0x20,
+/* 32328 0x7e48 "繈" */
+0x10,0x13,0x20,0x28,0x48,0xf3,0x12,0x22,0x4a,0xfb,0x08,0x00,0xa8,0xa8,0x82,0x01,
+0x08,0x88,0x90,0xa4,0xbe,0x8a,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0xbe,0x02,
+/* 32329 0x7e49 "繉" */
+0x11,0x11,0x21,0x25,0x45,0xf9,0x11,0x20,0x49,0xfc,0x04,0x01,0x56,0x54,0x80,0x01,
+0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x50,0x54,0xd8,0xd8,0x54,0x52,0x90,0x92,0x0e,
+/* 32330 0x7e4a "繊" */
+0x10,0x10,0x23,0x28,0x48,0xf7,0x10,0x21,0x49,0xfd,0x0b,0x01,0xa9,0xa9,0x87,0x00,
+0x88,0x8c,0xea,0x88,0x88,0xfe,0x08,0x4a,0x4a,0x5a,0x6c,0x4c,0x4a,0xea,0x16,0x22,
+/* 32331 0x7e4b "繋" */
+0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0xfe,0x14,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x78,0x48,0x48,0x86,0x78,0x48,0x30,0xce,0x40,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32332 0x7e4c "繌" */
+0x10,0x10,0x23,0x2a,0x4a,0xf2,0x13,0x20,0x49,0xfa,0x0c,0x01,0xaa,0xa8,0x81,0x06,
+0x40,0x80,0xfc,0x94,0x64,0x94,0xfc,0x90,0x08,0x84,0xfa,0x08,0x90,0x60,0x98,0x06,
+/* 32333 0x7e4d "繍" */
+0x10,0x10,0x21,0x24,0x47,0xf8,0x11,0x20,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x83,0x04,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xac,0x74,0x24,0xfc,0x64,0xb4,0x2c,0x24,
+/* 32334 0x7e4e "繎" */
+0x11,0x11,0x21,0x2a,0x4a,0xf5,0x10,0x22,0x49,0xf9,0x0a,0x04,0xa8,0xaa,0x82,0x04,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 32335 0x7e4f "繏" */
+0x10,0x13,0x22,0x2b,0x4a,0xf2,0x11,0x20,0x48,0xfb,0x08,0x00,0xab,0xa8,0x81,0x02,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 32336 0x7e50 "繐" */
+0x10,0x10,0x23,0x28,0x49,0xf1,0x11,0x21,0x49,0xf8,0x0b,0x00,0xa8,0xaa,0x82,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 32337 0x7e51 "繑" */
+0x10,0x11,0x20,0x2b,0x48,0xf1,0x12,0x20,0x48,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 32338 0x7e52 "繒" */
+0x11,0x10,0x20,0x2b,0x4a,0xf2,0x12,0x22,0x4b,0xf8,0x09,0x01,0xa9,0xa9,0x81,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 32339 0x7e53 "繓" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x10,0x27,0x4a,0xfb,0x0a,0x13,0xaa,0xa7,0x80,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0xdc,0x54,0xd4,0x68,0xc8,0x54,0x62,
+/* 32340 0x7e54 "織" */
+0x11,0x10,0x23,0x28,0x4a,0xf1,0x17,0x20,0x4b,0xfa,0x0a,0x03,0xaa,0xaa,0x83,0x00,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 32341 0x7e55 "繕" */
+0x10,0x10,0x23,0x28,0x49,0xf0,0x13,0x21,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x81,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 32342 0x7e56 "繖" */
+0x22,0x22,0x47,0x42,0x92,0xef,0x20,0x47,0x94,0xf7,0x04,0x17,0xac,0xa4,0x84,0x04,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 32343 0x7e57 "繗" */
+0x10,0x11,0x20,0x2b,0x48,0xf1,0x12,0x21,0x49,0xf9,0x0a,0x05,0xa8,0xa9,0x82,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 32344 0x7e58 "繘" */
+0x10,0x13,0x20,0x28,0x4b,0xf0,0x10,0x23,0x48,0xfb,0x0a,0x02,0xab,0xaa,0x82,0x02,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 32345 0x7e59 "繙" */
+0x10,0x13,0x21,0x28,0x4b,0xf0,0x11,0x22,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 32346 0x7e5a "繚" */
+0x10,0x10,0x21,0x24,0x45,0xf8,0x11,0x22,0x48,0xfc,0x04,0x00,0x54,0x54,0x81,0x00,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 32347 0x7e5b "繛" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0xff,0x22,0x7c,0x08,0x12,0x7f,0x08,0x2a,0x49,0x18,
+0x10,0x10,0x1e,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x52,0x10,0x7e,0x10,0x10,0x10,0x10,
+/* 32348 0x7e5c "繜" */
+0x10,0x10,0x23,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x03,0x55,0x54,0x80,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 32349 0x7e5d "繝" */
+0x13,0x12,0x23,0x2a,0x4b,0xf2,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xab,0x82,0x02,
+0xde,0x52,0xde,0x52,0xde,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 32350 0x7e5e "繞" */
+0x10,0x10,0x21,0x28,0x4b,0xf1,0x13,0x21,0x49,0xfe,0x08,0x03,0xa8,0xa8,0x81,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 32351 0x7e5f "繟" */
+0x10,0x13,0x22,0x2a,0x4b,0xf0,0x11,0x21,0x49,0xfd,0x05,0x00,0x57,0x54,0x80,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 32352 0x7e60 "繠" */
+0x01,0x24,0x24,0x43,0x00,0x24,0x12,0xa0,0xa4,0x1c,0x04,0x1f,0x02,0x3f,0x09,0x13,
+0x00,0x88,0x24,0xe4,0x00,0x24,0x12,0xa0,0xa4,0x1c,0x20,0xc0,0x10,0xf8,0x20,0x10,
+/* 32353 0x7e61 "繡" */
+0x20,0x23,0x40,0x47,0x90,0xe3,0x20,0x45,0x97,0xf4,0x07,0x14,0xaf,0xa5,0x85,0x08,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 32354 0x7e62 "繢" */
+0x10,0x11,0x21,0x25,0x44,0xfb,0x10,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32355 0x7e63 "繣" */
+0x10,0x11,0x20,0x2b,0x48,0xf1,0x10,0x23,0x48,0xfd,0x05,0x01,0x55,0x55,0x80,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 32356 0x7e64 "繤" */
+0x08,0xff,0x08,0x1f,0x14,0x12,0x11,0x1f,0x04,0xff,0x12,0x2f,0xc2,0x1f,0x09,0x13,
+0x20,0xfe,0x20,0xf0,0x90,0x50,0x30,0xf0,0x00,0xfe,0x50,0x88,0x26,0xf0,0x48,0x20,
+/* 32357 0x7e65 "繥" */
+0x10,0x13,0x20,0x29,0x48,0xf1,0x11,0x21,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x81,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 32358 0x7e66 "繦" */
+0x20,0x27,0x41,0x41,0x91,0xe7,0x24,0x44,0x94,0xf7,0x01,0x11,0xa9,0xa1,0x8a,0x04,
+0x00,0x7c,0x44,0x44,0x7c,0x10,0x10,0x7c,0x54,0x54,0x54,0x7c,0x10,0x14,0xfe,0x02,
+/* 32359 0x7e67 "繧" */
+0x10,0x11,0x20,0x2b,0x4a,0xf1,0x10,0x21,0x48,0xfd,0x04,0x03,0x54,0x54,0x81,0x00,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x40,0x88,0xfc,0x84,
+/* 32360 0x7e68 "繨" */
+0x10,0x12,0x21,0x24,0x44,0xf8,0x13,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x82,0x04,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 32361 0x7e69 "繩" */
+0x10,0x11,0x21,0x25,0x45,0xf8,0x11,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x00,
+0x00,0xfc,0x54,0x54,0xdc,0x50,0xdc,0x54,0x54,0xdc,0x54,0x54,0xdc,0x50,0x52,0x3e,
+/* 32362 0x7e6a "繪" */
+0x10,0x10,0x20,0x29,0x4a,0xf1,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x54,0x80,0x00,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 32363 0x7e6b "繫" */
+0x08,0xff,0x08,0x3e,0x2b,0x3e,0x2a,0xff,0x49,0x7f,0x04,0x1f,0x02,0x3f,0x09,0x13,
+0x78,0xc8,0x48,0x86,0x78,0x48,0x28,0x90,0x28,0x46,0x20,0xc0,0x10,0xf8,0x20,0x10,
+/* 32364 0x7e6c "繬" */
+0x10,0x10,0x23,0x29,0x49,0xf2,0x17,0x20,0x49,0xfd,0x05,0x01,0x55,0x55,0x81,0x01,
+0x20,0x20,0xfe,0x24,0x24,0xaa,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 32365 0x7e6d "繭" */
+0x08,0xff,0x08,0x00,0x7f,0x49,0x49,0x55,0x5d,0x49,0x55,0x5d,0x41,0x6b,0x41,0x40,
+0x20,0xfe,0x20,0x00,0xfc,0x24,0x24,0xfc,0xac,0xfc,0x24,0x3c,0xcc,0x04,0x14,0x08,
+/* 32366 0x7e6e "繮" */
+0x10,0x13,0x20,0x25,0x45,0xf9,0x11,0x23,0x48,0xfd,0x05,0x01,0x55,0x55,0x80,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 32367 0x7e6f "繯" */
+0x10,0x13,0x22,0x2a,0x4b,0xf0,0x17,0x20,0x4b,0xfa,0x0b,0x00,0xa9,0xab,0x8d,0x01,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 32368 0x7e70 "繰" */
+0x11,0x11,0x21,0x29,0x48,0xf3,0x12,0x22,0x4b,0xf8,0x0b,0x00,0xa8,0xa9,0x86,0x00,
+0xfc,0x04,0x04,0xfc,0x00,0xde,0x52,0x52,0xde,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 32369 0x7e71 "繱" */
+0x10,0x13,0x20,0x29,0x4b,0xf5,0x10,0x23,0x48,0xf8,0x0b,0x00,0xa8,0xaa,0x82,0x04,
+0x88,0xfe,0x88,0x00,0xfc,0x54,0xd4,0x24,0x54,0x94,0x48,0x20,0xa4,0x8a,0x8a,0x78,
+/* 32370 0x7e72 "繲" */
+0x11,0x11,0x22,0x2c,0x4b,0xf2,0x12,0x23,0x4a,0xfa,0x0b,0x02,0xaa,0xaa,0x82,0x04,
+0x00,0xde,0x4a,0x8a,0xea,0xb6,0xa4,0xf4,0xbe,0xa4,0xe4,0xbe,0xa4,0xa4,0x24,0x64,
+/* 32371 0x7e73 "繳" */
+0x21,0x22,0x47,0x44,0x97,0xe4,0x27,0x42,0x91,0xf7,0x02,0x13,0xaa,0xa4,0x85,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 32372 0x7e74 "繴" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x04,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x50,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32373 0x7e75 "繵" */
+0x10,0x17,0x20,0x2b,0x4a,0xf2,0x12,0x23,0x48,0xf9,0x09,0x01,0xa9,0xa9,0x80,0x07,
+0x20,0xfe,0x00,0xfe,0x02,0xfa,0x8a,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,
+/* 32374 0x7e76 "繶" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x21,0x49,0xfd,0x05,0x01,0xa8,0xaa,0x82,0x04,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 32375 0x7e77 "繷" */
+0x10,0x13,0x22,0x23,0x4a,0xfb,0x10,0x23,0x4a,0xfa,0x0a,0x13,0xad,0xa5,0x85,0x09,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 32376 0x7e78 "繸" */
+0x10,0x14,0x22,0x28,0x48,0xf0,0x16,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x85,0x08,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 32377 0x7e79 "繹" */
+0x10,0x11,0x21,0x25,0x44,0xf9,0x10,0x23,0x48,0xfc,0x05,0x00,0x57,0x54,0x80,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 32378 0x7e7a "繺" */
+0x12,0x12,0x23,0x2c,0x48,0xf3,0x10,0x20,0x4b,0xf8,0x08,0x07,0xa8,0xaa,0x82,0x04,
+0x10,0x10,0xd0,0x5e,0xa4,0xd4,0x54,0x54,0xc8,0x48,0x54,0xe2,0x00,0xa4,0x52,0x52,
+/* 32379 0x7e7b "繻" */
+0x10,0x11,0x20,0x2b,0x4a,0xf1,0x10,0x21,0x48,0xfb,0x08,0x01,0xa9,0xa9,0x81,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 32380 0x7e7c "繼" */
+0x10,0x12,0x22,0x2a,0x4a,0xf2,0x12,0x23,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x03,
+0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,0x44,0x84,0xea,0x4e,0xa4,0xee,0x22,0xfe,
+/* 32381 0x7e7d "繽" */
+0x10,0x10,0x23,0x2a,0x49,0xf1,0x12,0x21,0x4b,0xf9,0x09,0x01,0xa9,0xa9,0x80,0x01,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32382 0x7e7e "繾" */
+0x10,0x10,0x22,0x25,0x45,0xf8,0x10,0x23,0x49,0xfd,0x05,0x01,0x55,0x55,0x82,0x04,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x40,0x7c,0x44,0x7c,0x80,0x7e,
+/* 32383 0x7e7f "繿" */
+0x10,0x13,0x22,0x2b,0x4a,0xf3,0x12,0x23,0x48,0xf9,0x09,0x01,0xa9,0xa9,0x87,0x00,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 32384 0x7e80 "纀" */
+0x11,0x11,0x21,0x2a,0x4a,0xf6,0x16,0x2a,0x4a,0xfa,0x0a,0x02,0xaa,0xaa,0x82,0x02,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 32385 0x7e81 "纁" */
+0x10,0x11,0x20,0x2b,0x48,0xf1,0x11,0x21,0x49,0xfc,0x05,0x00,0x57,0x54,0x81,0x02,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 32386 0x7e82 "纂" */
+0x20,0x3e,0x48,0xbf,0x24,0x22,0x3f,0x02,0xff,0x09,0x12,0x2f,0xc2,0x1f,0x09,0x13,
+0x40,0x7e,0x90,0xf8,0x88,0x48,0xf8,0x00,0xfe,0x20,0x50,0x88,0x26,0xf0,0x48,0x20,
+/* 32387 0x7e83 "纃" */
+0x20,0x20,0x47,0x41,0x90,0xef,0x25,0x45,0x9b,0xf0,0x02,0x13,0xaa,0xa3,0x82,0x04,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 32388 0x7e84 "纄" */
+0x10,0x13,0x20,0x28,0x4a,0xf1,0x10,0x20,0x4b,0xf9,0x09,0x01,0xa9,0xa9,0x83,0x04,
+0x88,0xfe,0x88,0x20,0x3c,0x44,0x38,0xd6,0x38,0x10,0x7c,0x10,0x7e,0x10,0x10,0xfe,
+/* 32389 0x7e85 "纅" */
+0x24,0x24,0x48,0x4a,0x9e,0xe4,0x2a,0x4e,0x92,0xf0,0x0f,0x10,0xa9,0xa2,0x8c,0x00,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 32390 0x7e86 "纆" */
+0x11,0x11,0x21,0x25,0x45,0xf8,0x11,0x20,0x4b,0xfd,0x06,0x00,0x55,0x54,0x83,0x00,
+0xfc,0x24,0xac,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,0x20,0xfc,0x20,0xfe,0x00,
+/* 32391 0x7e87 "纇" */
+0x92,0x54,0xfe,0x30,0x54,0x92,0x20,0x44,0x78,0x10,0x24,0xfe,0x10,0x54,0x92,0x31,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 32392 0x7e88 "纈" */
+0x11,0x11,0x21,0x2f,0x49,0xf1,0x13,0x20,0x48,0xfb,0x0a,0x02,0xaa,0xab,0x82,0x00,
+0x00,0x3e,0x08,0xd0,0x3e,0x22,0xa2,0x3e,0x22,0xbe,0xa2,0xa2,0xbe,0x80,0x94,0x22,
+/* 32393 0x7e89 "纉" */
+0x10,0x11,0x20,0x2b,0x48,0xf1,0x12,0x21,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x01,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32394 0x7e8a "纊" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x49,0xfd,0x05,0x01,0xa9,0xaa,0x82,0x04,
+0x20,0x10,0xfe,0x28,0x7c,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x44,0x82,
+/* 32395 0x7e8b "纋" */
+0x13,0x10,0x21,0x29,0x49,0xf1,0x17,0x24,0x4a,0xfa,0x0c,0x00,0xa9,0xaa,0x80,0x03,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 32396 0x7e8c "續" */
+0x10,0x13,0x20,0x29,0x48,0xf3,0x12,0x23,0x49,0xfd,0x05,0x01,0x55,0x55,0x80,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32397 0x7e8d "纍" */
+0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0x3e,0x08,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xf8,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 32398 0x7e8e "纎" */
+0x10,0x10,0x23,0x28,0x48,0xf3,0x11,0x23,0x49,0xfb,0x09,0x03,0xa9,0xa9,0x87,0x00,
+0x88,0x8c,0xea,0x88,0x88,0xfe,0x48,0x6a,0x4a,0x6a,0x4c,0x6c,0x4a,0x6a,0x96,0x22,
+/* 32399 0x7e8f "纏" */
+0x20,0x27,0x44,0x45,0x95,0xe5,0x25,0x45,0x94,0xf5,0x04,0x17,0xad,0xaa,0x88,0x13,
+0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x24,0xfa,0x20,0xfe,
+/* 32400 0x7e90 "纐" */
+0x12,0x11,0x27,0x28,0x4a,0xf2,0x14,0x20,0x4a,0xfa,0x09,0x01,0xaa,0xaa,0x84,0x00,
+0x00,0x3e,0xc8,0x10,0xbe,0x62,0x22,0xbe,0xa2,0xbe,0x22,0x22,0xbe,0x80,0x14,0x22,
+/* 32401 0x7e91 "纑" */
+0x10,0x10,0x20,0x2b,0x4a,0xf3,0x12,0x22,0x4a,0xfa,0x0a,0x02,0xaa,0xad,0x85,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 32402 0x7e92 "纒" */
+0x13,0x12,0x22,0x22,0x4a,0xfa,0x12,0x22,0x4a,0xfa,0x0b,0x12,0xaa,0xa2,0x84,0x09,
+0xfe,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x10,0xfe,0xaa,0x10,0xfe,0x10,0xfe,
+/* 32403 0x7e93 "纓" */
+0x13,0x12,0x23,0x2a,0x4b,0xf2,0x13,0x21,0x4a,0xf8,0x0f,0x00,0xa9,0xa8,0x80,0x03,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 32404 0x7e94 "纔" */
+0x11,0x12,0x27,0x2a,0x4b,0xf2,0x13,0x22,0x49,0xfa,0x0f,0x02,0xab,0xa8,0x81,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 32405 0x7e95 "纕" */
+0x10,0x13,0x20,0x29,0x49,0xf1,0x10,0x23,0x48,0xfb,0x08,0x07,0xa8,0xa9,0x86,0x00,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 32406 0x7e96 "纖" */
+0x11,0x11,0x22,0x28,0x4f,0xf1,0x13,0x21,0x4b,0xf9,0x0b,0x01,0xa9,0xab,0x80,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 32407 0x7e97 "纗" */
+0x12,0x13,0x20,0x29,0x4b,0xf5,0x11,0x21,0x49,0xf9,0x09,0x03,0xaa,0xab,0x82,0x02,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 32408 0x7e98 "纘" */
+0x25,0x27,0x49,0x47,0x93,0xe5,0x29,0x43,0x92,0xf3,0x02,0x13,0xaa,0xa3,0x81,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 32409 0x7e99 "纙" */
+0x20,0x23,0x42,0x42,0x93,0xe1,0x21,0x42,0x97,0xf1,0x02,0x17,0xa8,0xa5,0x85,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x08,0x54,0x5e,0xb4,0x1e,0x54,0xde,0x14,0x54,0x5e,0x10,
+/* 32410 0x7e9a "纚" */
+0x13,0x10,0x23,0x2a,0x4b,0xf2,0x10,0x23,0x4a,0xfb,0x0a,0x03,0xaa,0xaa,0x82,0x04,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 32411 0x7e9b "纛" */
+0x01,0xff,0x01,0x1f,0x12,0xff,0x10,0x1f,0x00,0x3e,0x22,0x2a,0x2a,0xff,0x2a,0x59,
+0x00,0xfe,0x00,0xf0,0x10,0xfe,0x90,0xf0,0x1c,0xe0,0x24,0xf8,0x24,0xfe,0x54,0xb2,
+/* 32412 0x7e9c "纜" */
+0x17,0x15,0x27,0x2c,0x4f,0xf5,0x17,0x20,0x4b,0xfa,0x0b,0x02,0xab,0xa8,0x81,0x06,
+0x90,0x1e,0xa8,0x84,0xbe,0x2a,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x24,0x1c,
+/* 32413 0x7e9d "纝" */
+0x11,0x11,0x21,0x29,0x4b,0xf2,0x13,0x22,0x4b,0xf8,0x09,0x00,0xab,0xa9,0x82,0x00,
+0xfc,0x24,0xfc,0x24,0xfe,0xaa,0xfe,0xaa,0xfe,0x88,0xf0,0x64,0xfe,0x24,0x22,0x60,
+/* 32414 0x7e9e "纞" */
+0x44,0x44,0x4a,0x4e,0xa4,0xaa,0xce,0x40,0x4a,0x8a,0xa0,0xe0,0x05,0xa5,0xa9,0x00,
+0x44,0xe4,0x0a,0xee,0x04,0xea,0x0e,0xe0,0xaa,0xea,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 32415 0x7e9f "纟" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 32416 0x7ea0 "纠" */
+0x10,0x10,0x20,0x24,0x44,0xf8,0x10,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0xb4,0xc4,0x84,0x04,0x04,0x04,0x04,
+/* 32417 0x7ea1 "纡" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x23,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32418 0x7ea2 "红" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x43,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32419 0x7ea3 "纣" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x28,0x10,
+/* 32420 0x7ea4 "纤" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x23,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 32421 0x7ea5 "纥" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x20,0x40,0xfc,0x40,0x00,0x1d,0xe1,0x40,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 32422 0x7ea6 "约" */
+0x10,0x10,0x20,0x24,0x45,0xfa,0x10,0x21,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 32423 0x7ea7 "级" */
+0x10,0x13,0x20,0x20,0x48,0xf8,0x10,0x20,0x41,0xf9,0x41,0x01,0x1a,0xe2,0x44,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32424 0x7ea8 "纨" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x41,0xfc,0x40,0x00,0x1c,0xe1,0x42,0x04,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 32425 0x7ea9 "纩" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe2,0x42,0x04,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 32426 0x7eaa "纪" */
+0x10,0x10,0x23,0x20,0x48,0xf0,0x10,0x23,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x41,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 32427 0x7eab "纫" */
+0x10,0x10,0x23,0x20,0x48,0xfa,0x12,0x22,0x44,0xf8,0x40,0x01,0x19,0xe2,0x44,0x08,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 32428 0x7eac "纬" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x10,0x20,0x40,0xfd,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 32429 0x7ead "纭" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x13,0x20,0x40,0xfc,0x40,0x00,0x1d,0xe3,0x41,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 32430 0x7eae "纮" */
+0x10,0x10,0x20,0x20,0x4b,0xf8,0x10,0x20,0x40,0xf9,0x41,0x02,0x1a,0xe4,0x41,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 32431 0x7eaf "纯" */
+0x10,0x10,0x20,0x23,0x48,0xfa,0x12,0x22,0x42,0xfb,0x40,0x00,0x18,0xe0,0x40,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 32432 0x7eb0 "纰" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 32433 0x7eb1 "纱" */
+0x10,0x10,0x20,0x21,0x49,0xfa,0x12,0x24,0x40,0xf8,0x40,0x00,0x18,0xe0,0x41,0x06,
+0x40,0x40,0x40,0x48,0x44,0x42,0x42,0x48,0x48,0x48,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 32434 0x7eb2 "纲" */
+0x10,0x13,0x22,0x22,0x4a,0xfa,0x12,0x22,0x42,0xfa,0x42,0x03,0x1a,0xe2,0x42,0x02,
+0x00,0xfc,0x04,0x04,0x94,0x54,0x24,0x24,0x54,0x54,0x94,0x04,0x04,0x04,0x14,0x08,
+/* 32435 0x7eb3 "纳" */
+0x10,0x10,0x20,0x20,0x4b,0xf2,0x12,0x22,0x42,0xfa,0x42,0x03,0x1a,0xe2,0x42,0x02,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 32436 0x7eb4 "纴" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x23,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x41,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 32437 0x7eb5 "纵" */
+0x11,0x11,0x21,0x21,0x49,0xf9,0x11,0x21,0x41,0xfa,0x42,0x02,0x1c,0xe4,0x48,0x11,
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xa8,0x68,0x28,0x44,0x44,0x84,0x02,
+/* 32438 0x7eb6 "纶" */
+0x10,0x10,0x20,0x20,0x49,0xfa,0x14,0x21,0x41,0xf9,0x41,0x01,0x19,0xe1,0x40,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 32439 0x7eb7 "纷" */
+0x10,0x10,0x20,0x20,0x49,0xf9,0x12,0x25,0x40,0xf8,0x40,0x00,0x19,0xe1,0x42,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 32440 0x7eb8 "纸" */
+0x10,0x10,0x23,0x22,0x4a,0xfa,0x12,0x23,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x43,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x06,0x02,
+/* 32441 0x7eb9 "纹" */
+0x10,0x10,0x20,0x27,0x49,0xf1,0x11,0x21,0x41,0xf8,0x40,0x00,0x18,0xe1,0x42,0x0c,
+0x80,0x40,0x40,0xfc,0x10,0x10,0x10,0x10,0x10,0xa0,0xa0,0x40,0xa0,0x10,0x08,0x06,
+/* 32442 0x7eba "纺" */
+0x10,0x10,0x20,0x27,0x44,0xf8,0x10,0x20,0x40,0xfc,0x40,0x00,0x1d,0xe1,0x42,0x04,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 32443 0x7ebb "纻" */
+0x10,0x10,0x20,0x24,0x45,0xf9,0x12,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe1,0x40,0x00,
+0x40,0x20,0x20,0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 32444 0x7ebc "纼" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x21,0x41,0xfd,0x40,0x00,0x1c,0xe0,0x41,0x00,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 32445 0x7ebd "纽" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x21,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x47,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfe,0x00,
+/* 32446 0x7ebe "纾" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x13,0x20,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32447 0x7ebf "线" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x23,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x43,0x00,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 32448 0x7ec0 "绀" */
+0x11,0x11,0x21,0x25,0x47,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 32449 0x7ec1 "绁" */
+0x10,0x12,0x22,0x22,0x4a,0xf7,0x12,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x43,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 32450 0x7ec2 "绂" */
+0x10,0x10,0x20,0x20,0x4b,0xf8,0x10,0x20,0x41,0xf9,0x41,0x01,0x1a,0xe2,0x44,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32451 0x7ec3 "练" */
+0x10,0x10,0x27,0x20,0x48,0xfb,0x11,0x22,0x43,0xf8,0x41,0x01,0x1a,0xe4,0x40,0x00,
+0x40,0x40,0xfc,0x80,0x80,0xe0,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 32452 0x7ec4 "组" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x11,0x21,0x41,0xf9,0x41,0x01,0x19,0xe1,0x47,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 32453 0x7ec5 "绅" */
+0x10,0x10,0x20,0x25,0x45,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe0,0x40,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 32454 0x7ec6 "细" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 32455 0x7ec7 "织" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x21,0x41,0xfd,0x40,0x00,0x1c,0xe1,0x42,0x04,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 32456 0x7ec8 "终" */
+0x10,0x10,0x20,0x21,0x4b,0xfc,0x10,0x20,0x43,0xfc,0x40,0x00,0x18,0xe1,0x40,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xc0,0x20,0x10,0x80,0x60,0x10,
+/* 32457 0x7ec9 "绉" */
+0x10,0x10,0x20,0x21,0x4a,0xfc,0x13,0x20,0x40,0xf8,0x41,0x00,0x18,0xe0,0x43,0x00,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 32458 0x7eca "绊" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x11,0x20,0x40,0xfc,0x43,0x00,0x1c,0xe0,0x40,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32459 0x7ecb "绋" */
+0x10,0x10,0x20,0x23,0x48,0xf8,0x13,0x22,0x42,0xfb,0x40,0x00,0x19,0xe1,0x42,0x04,
+0x90,0x90,0x90,0xfc,0x94,0x94,0xfc,0x90,0x90,0xfe,0x92,0x92,0x1a,0x14,0x10,0x10,
+/* 32460 0x7ecc "绌" */
+0x10,0x10,0x21,0x25,0x45,0xf9,0x11,0x20,0x40,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 32461 0x7ecd "绍" */
+0x10,0x13,0x20,0x20,0x48,0xf9,0x11,0x22,0x44,0xf9,0x41,0x01,0x19,0xe1,0x41,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32462 0x7ece "绎" */
+0x10,0x13,0x21,0x20,0x48,0xf8,0x10,0x23,0x40,0xf9,0x40,0x00,0x1b,0xe0,0x40,0x00,
+0x00,0xfc,0x04,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 32463 0x7ecf "经" */
+0x10,0x11,0x20,0x24,0x44,0xf8,0x10,0x23,0x40,0xfd,0x40,0x00,0x1c,0xe0,0x43,0x00,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32464 0x7ed0 "绐" */
+0x10,0x10,0x20,0x24,0x45,0xfb,0x10,0x20,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32465 0x7ed1 "绑" */
+0x21,0x21,0x21,0x47,0x51,0xf1,0x27,0x21,0x41,0xf7,0x41,0x01,0x31,0xc2,0x02,0x04,
+0x00,0x1e,0x12,0xd2,0x14,0x14,0xd8,0x14,0x12,0xd2,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 32466 0x7ed2 "绒" */
+0x10,0x10,0x20,0x20,0x4b,0xf8,0x11,0x21,0x41,0xfb,0x41,0x01,0x1a,0xe2,0x44,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 32467 0x7ed3 "结" */
+0x10,0x10,0x20,0x27,0x44,0xf8,0x11,0x20,0x40,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32468 0x7ed4 "绔" */
+0x10,0x10,0x27,0x20,0x49,0xfa,0x1d,0x20,0x47,0xf8,0x41,0x03,0x18,0xe0,0x40,0x00,
+0x40,0x40,0xfc,0xa0,0x10,0x08,0xf6,0x00,0xfc,0x80,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 32469 0x7ed5 "绕" */
+0x10,0x10,0x20,0x23,0x48,0xf8,0x10,0x23,0x40,0xfb,0x40,0x00,0x19,0xe1,0x42,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 32470 0x7ed6 "绖" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x20,0x40,0xfc,0x41,0x00,0x1c,0xe0,0x43,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 32471 0x7ed7 "绗" */
+0x10,0x10,0x21,0x22,0x4c,0xf0,0x11,0x23,0x45,0xf9,0x41,0x01,0x19,0xe1,0x41,0x01,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 32472 0x7ed8 "绘" */
+0x10,0x10,0x20,0x21,0x4a,0xf4,0x11,0x20,0x40,0xfb,0x40,0x00,0x19,0xe2,0x47,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf0,0x00,0x00,0xfc,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 32473 0x7ed9 "给" */
+0x10,0x10,0x20,0x21,0x4a,0xf4,0x13,0x20,0x40,0xfb,0x42,0x02,0x1a,0xe2,0x43,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 32474 0x7eda "绚" */
+0x10,0x10,0x21,0x21,0x4a,0xf4,0x13,0x22,0x42,0xfb,0x42,0x02,0x1b,0xe0,0x40,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,
+/* 32475 0x7edb "绛" */
+0x10,0x10,0x20,0x21,0x4a,0xf8,0x11,0x26,0x40,0xf9,0x40,0x02,0x1b,0xe0,0x40,0x00,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 32476 0x7edc "络" */
+0x10,0x10,0x20,0x21,0x4b,0xfc,0x10,0x20,0x41,0xfa,0x45,0x01,0x19,0xe1,0x41,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 32477 0x7edd "绝" */
+0x10,0x10,0x20,0x21,0x4a,0xf5,0x11,0x21,0x41,0xf9,0x41,0x01,0x19,0xe1,0x40,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32478 0x7ede "绞" */
+0x10,0x10,0x20,0x25,0x44,0xf8,0x11,0x22,0x40,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 32479 0x7edf "统" */
+0x10,0x10,0x20,0x23,0x48,0xf8,0x11,0x23,0x40,0xf8,0x40,0x00,0x19,0xe1,0x42,0x04,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 32480 0x7ee0 "绠" */
+0x10,0x13,0x20,0x24,0x45,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1c,0xe0,0x40,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 32481 0x7ee1 "绡" */
+0x10,0x11,0x20,0x24,0x44,0xf9,0x11,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 32482 0x7ee2 "绢" */
+0x10,0x11,0x21,0x21,0x49,0xf8,0x13,0x22,0x42,0xfb,0x42,0x02,0x1b,0xe2,0x42,0x02,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 32483 0x7ee3 "绣" */
+0x10,0x13,0x20,0x20,0x4f,0xf9,0x12,0x24,0x43,0xf9,0x41,0x01,0x1a,0xe2,0x44,0x08,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x46,0xf0,0x10,0x20,0x7c,0x04,0x04,0x28,0x10,
+/* 32484 0x7ee4 "绤" */
+0x10,0x10,0x20,0x24,0x45,0xf8,0x10,0x20,0x41,0xfc,0x40,0x00,0x1c,0xe0,0x40,0x00,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 32485 0x7ee5 "绥" */
+0x10,0x10,0x23,0x20,0x4a,0xf9,0x11,0x20,0x43,0xf8,0x41,0x03,0x18,0xe0,0x41,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 32486 0x7ee6 "绦" */
+0x10,0x10,0x21,0x23,0x4c,0xf0,0x11,0x26,0x40,0xfb,0x40,0x02,0x1a,0xe4,0x41,0x00,
+0x80,0x80,0xf8,0x08,0x90,0x60,0x98,0x46,0x40,0xfc,0x40,0x48,0x44,0x44,0x40,0x80,
+/* 32487 0x7ee7 "继" */
+0x10,0x12,0x22,0x23,0x4a,0xf2,0x13,0x22,0x42,0xfa,0x43,0x02,0x1a,0xe2,0x43,0x00,
+0x20,0x20,0x20,0x24,0xa8,0x20,0xfc,0x20,0x70,0xa8,0x24,0x20,0x20,0x20,0xfe,0x00,
+/* 32488 0x7ee8 "绨" */
+0x11,0x10,0x20,0x23,0x48,0xf8,0x13,0x22,0x42,0xfb,0x40,0x00,0x19,0xe2,0x44,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 32489 0x7ee9 "绩" */
+0x10,0x10,0x27,0x20,0x4b,0xf0,0x17,0x20,0x43,0xfa,0x42,0x02,0x1a,0xe0,0x41,0x06,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x48,0x48,0x48,0xa0,0x10,0x08,
+/* 32490 0x7eea "绪" */
+0x10,0x10,0x23,0x20,0x48,0xf7,0x10,0x20,0x41,0xfb,0x45,0x01,0x19,0xe1,0x41,0x01,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 32491 0x7eeb "绫" */
+0x10,0x10,0x21,0x20,0x48,0xfb,0x10,0x21,0x42,0xf8,0x41,0x02,0x18,0xe0,0x41,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 32492 0x7eec "绬" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x11,0x21,0x41,0xfd,0x43,0x00,0x1c,0xe0,0x41,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 32493 0x7eed "续" */
+0x10,0x10,0x21,0x24,0x44,0xfb,0x10,0x20,0x40,0xfd,0x40,0x03,0x1c,0xe0,0x40,0x03,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x10,0x90,0xfe,0x28,0x44,0x82,0x02,
+/* 32494 0x7eee "绮" */
+0x10,0x10,0x21,0x24,0x44,0xf9,0x13,0x20,0x41,0xfd,0x41,0x01,0x1d,0xe0,0x40,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 32495 0x7eef "绯" */
+0x10,0x10,0x20,0x27,0x48,0xf8,0x10,0x23,0x40,0xf8,0x40,0x07,0x18,0xe0,0x40,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 32496 0x7ef0 "绰" */
+0x10,0x10,0x20,0x20,0x4b,0xfa,0x13,0x22,0x43,0xfa,0x40,0x07,0x18,0xe0,0x40,0x00,
+0x40,0x40,0x7e,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x44,0x40,0xfe,0x40,0x40,0x40,0x40,
+/* 32497 0x7ef1 "绱" */
+0x10,0x11,0x20,0x20,0x48,0xfb,0x12,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 32498 0x7ef2 "绲" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x11,0x21,0x40,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 32499 0x7ef3 "绳" */
+0x10,0x11,0x21,0x21,0x49,0xf8,0x13,0x22,0x42,0xfb,0x42,0x02,0x1b,0xe0,0x40,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfa,0x42,0x42,0x3e,
+/* 32500 0x7ef4 "维" */
+0x10,0x10,0x20,0x25,0x45,0xfb,0x15,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe1,0x41,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 32501 0x7ef5 "绵" */
+0x10,0x10,0x21,0x21,0x49,0xf1,0x11,0x20,0x40,0xfb,0x42,0x02,0x1a,0xe2,0x40,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 32502 0x7ef6 "绶" */
+0x10,0x13,0x20,0x22,0x49,0xf9,0x17,0x24,0x40,0xfb,0x41,0x01,0x18,0xe0,0x41,0x06,
+0x1c,0xe0,0x84,0x44,0x48,0x10,0xfe,0x02,0x00,0xf8,0x08,0x10,0xa0,0x40,0xb0,0x0e,
+/* 32503 0x7ef7 "绷" */
+0x20,0x27,0x24,0x44,0x54,0xf7,0x24,0x24,0x44,0xf7,0x44,0x04,0x34,0xc4,0x0a,0x11,
+0x00,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0x4c,
+/* 32504 0x7ef8 "绸" */
+0x10,0x13,0x22,0x22,0x4a,0xfa,0x12,0x23,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x04,
+0x00,0xfe,0x22,0x22,0xfa,0x22,0x22,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 32505 0x7ef9 "绹" */
+0x10,0x10,0x20,0x25,0x46,0xf8,0x11,0x20,0x43,0xfc,0x41,0x01,0x1d,0xe0,0x40,0x00,
+0x80,0x80,0xfe,0x02,0x82,0xf2,0x42,0x42,0xfa,0x42,0x52,0x52,0xf2,0x02,0x14,0x08,
+/* 32506 0x7efa "绺" */
+0x10,0x10,0x21,0x21,0x4a,0xf5,0x10,0x21,0x46,0xf8,0x41,0x01,0x19,0xe1,0x41,0x01,
+0x88,0x88,0xec,0x2a,0x28,0x48,0x88,0x7e,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 32507 0x7efb "绻" */
+0x10,0x12,0x21,0x20,0x4b,0xf8,0x17,0x21,0x42,0xfd,0x49,0x01,0x19,0xe1,0x41,0x00,
+0x40,0x48,0x50,0x40,0xf8,0x80,0xfc,0x10,0x08,0xf4,0x12,0x10,0x50,0x24,0x04,0xfc,
+/* 32508 0x7efc "综" */
+0x10,0x10,0x23,0x22,0x48,0xf9,0x10,0x20,0x43,0xf8,0x41,0x01,0x1a,0xe4,0x40,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 32509 0x7efd "绽" */
+0x10,0x10,0x23,0x22,0x4c,0xf8,0x13,0x20,0x40,0xf9,0x41,0x01,0x1a,0xe2,0x44,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 32510 0x7efe "绾" */
+0x10,0x10,0x23,0x22,0x4c,0xf9,0x11,0x21,0x41,0xf9,0x41,0x01,0x19,0xe1,0x41,0x01,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 32511 0x7eff "绿" */
+0x10,0x11,0x20,0x20,0x49,0xf8,0x10,0x23,0x40,0xfa,0x41,0x00,0x19,0xe2,0x40,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 32512 0x7f00 "缀" */
+0x20,0x27,0x20,0x42,0x51,0xf2,0x24,0x28,0x40,0xf7,0x40,0x02,0x31,0xc2,0x04,0x08,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 32513 0x7f01 "缁" */
+0x11,0x11,0x22,0x24,0x4a,0xf9,0x11,0x20,0x43,0xfa,0x42,0x03,0x1a,0xe2,0x43,0x02,
+0x24,0x24,0x48,0x90,0x48,0x24,0x24,0x00,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x04,
+/* 32514 0x7f02 "缂" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x11,0x21,0x41,0xfd,0x40,0x03,0x1c,0xe0,0x40,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 32515 0x7f03 "缃" */
+0x11,0x11,0x21,0x21,0x4f,0xf1,0x11,0x23,0x43,0xfd,0x49,0x01,0x19,0xe1,0x41,0x01,
+0x00,0x00,0x3e,0x22,0xa2,0x22,0x3e,0xa2,0x62,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,
+/* 32516 0x7f04 "缄" */
+0x20,0x20,0x20,0x47,0x54,0xf4,0x25,0x24,0x44,0xf5,0x45,0x05,0x35,0xc4,0x08,0x10,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x12,0x12,0xd4,0x54,0x48,0xda,0x2a,0x46,0x82,
+/* 32517 0x7f05 "缅" */
+0x10,0x17,0x20,0x20,0x4b,0xf2,0x12,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x43,0x02,
+0x00,0xfe,0x40,0x80,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,
+/* 32518 0x7f06 "缆" */
+0x10,0x12,0x22,0x22,0x4a,0xf8,0x11,0x21,0x41,0xf9,0x41,0x01,0x18,0xe0,0x41,0x06,
+0x90,0x90,0x9e,0xa8,0xc4,0x80,0xfc,0x04,0x24,0x24,0x24,0x54,0x50,0x90,0x12,0x0e,
+/* 32519 0x7f07 "缇" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x11,0x21,0x40,0xfb,0x40,0x01,0x19,0xe1,0x42,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 32520 0x7f08 "缈" */
+0x20,0x20,0x27,0x45,0x55,0xf7,0x25,0x25,0x47,0xf5,0x45,0x07,0x35,0xc0,0x00,0x03,
+0x10,0x10,0x10,0x10,0x14,0x52,0x52,0x92,0x10,0x14,0x08,0x10,0x20,0x40,0x80,0x00,
+/* 32521 0x7f09 "缉" */
+0x10,0x11,0x21,0x21,0x49,0xf0,0x17,0x21,0x41,0xf9,0x41,0x01,0x19,0xe7,0x40,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 32522 0x7f0a "缊" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x11,0x21,0x40,0xfb,0x42,0x02,0x1a,0xe2,0x47,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 32523 0x7f0b "缋" */
+0x10,0x10,0x21,0x25,0x45,0xf8,0x13,0x20,0x41,0xfd,0x41,0x01,0x1d,0xe0,0x40,0x03,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 32524 0x7f0c "缌" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x11,0x21,0x40,0xf8,0x40,0x02,0x1a,0xe4,0x40,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 32525 0x7f0d "缍" */
+0x10,0x10,0x21,0x20,0x48,0xfb,0x11,0x21,0x47,0xf9,0x41,0x03,0x18,0xe0,0x43,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x24,0x24,0xfe,0x24,0x24,0xfe,0x20,0x20,0xfe,0x00,
+/* 32526 0x7f0e "缎" */
+0x10,0x13,0x22,0x22,0x4b,0xfa,0x12,0x22,0x43,0xfa,0x42,0x03,0x1e,0xe2,0x42,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 32527 0x7f0f "缏" */
+0x11,0x11,0x21,0x22,0x4a,0xf2,0x16,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x00,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x90,0x50,0x20,0x58,0x86,
+/* 32528 0x7f10 "缐" */
+0x10,0x10,0x21,0x21,0x49,0xf9,0x11,0x20,0x40,0xfb,0x40,0x01,0x19,0xe2,0x44,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 32529 0x7f11 "缑" */
+0x11,0x11,0x21,0x22,0x4a,0xf6,0x1a,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x00,0x78,0x08,0x08,0xfe,0x40,0x40,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 32530 0x7f12 "缒" */
+0x10,0x12,0x21,0x25,0x44,0xf8,0x13,0x21,0x41,0xfd,0x41,0x01,0x1d,0xe2,0x44,0x00,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 32531 0x7f13 "缓" */
+0x10,0x17,0x22,0x21,0x48,0xfb,0x10,0x20,0x47,0xf9,0x41,0x02,0x1a,0xe4,0x48,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 32532 0x7f14 "缔" */
+0x10,0x10,0x21,0x24,0x44,0xf8,0x13,0x22,0x44,0xfd,0x41,0x01,0x1d,0xe1,0x40,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 32533 0x7f15 "缕" */
+0x10,0x11,0x20,0x20,0x4b,0xf8,0x11,0x22,0x40,0xfb,0x40,0x01,0x19,0xe0,0x41,0x06,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 32534 0x7f16 "编" */
+0x10,0x10,0x23,0x22,0x4a,0xfb,0x12,0x22,0x43,0xfb,0x43,0x05,0x1d,0xe5,0x49,0x01,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x44,0x0c,
+/* 32535 0x7f17 "缗" */
+0x10,0x13,0x22,0x23,0x4a,0xfb,0x12,0x22,0x43,0xf8,0x43,0x02,0x1b,0xe2,0x43,0x02,
+0x00,0xfc,0x04,0xfc,0x20,0xfe,0x10,0x8a,0x06,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 32536 0x7f18 "缘" */
+0x10,0x10,0x21,0x21,0x48,0xfb,0x10,0x20,0x43,0xf8,0x40,0x03,0x18,0xe0,0x43,0x00,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 32537 0x7f19 "缙" */
+0x10,0x13,0x20,0x22,0x49,0xf8,0x17,0x20,0x41,0xf9,0x41,0x01,0x19,0xe1,0x41,0x01,
+0x00,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 32538 0x7f1a "缚" */
+0x10,0x10,0x27,0x20,0x4b,0xfa,0x13,0x22,0x43,0xfa,0x40,0x03,0x19,0xe0,0x40,0x00,
+0x50,0x48,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 32539 0x7f1b "缛" */
+0x10,0x13,0x22,0x22,0x4a,0xfb,0x12,0x22,0x42,0xfa,0x42,0x03,0x1a,0xe4,0x44,0x08,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 32540 0x7f1c "缜" */
+0x10,0x10,0x27,0x20,0x4b,0xfa,0x13,0x22,0x43,0xfa,0x43,0x02,0x1f,0xe1,0x42,0x04,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 32541 0x7f1d "缝" */
+0x10,0x14,0x22,0x21,0x48,0xf8,0x16,0x22,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x45,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 32542 0x7f1e "缞" */
+0x10,0x10,0x23,0x20,0x49,0xf9,0x17,0x21,0x41,0xf8,0x40,0x01,0x1a,0xe4,0x40,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfe,0x04,0xfc,0x52,0x94,0x88,0x88,0xa4,0xc2,0x80,
+/* 32543 0x7f1f "缟" */
+0x10,0x10,0x23,0x20,0x49,0xf9,0x11,0x20,0x43,0xfa,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 32544 0x7f20 "缠" */
+0x20,0x20,0x27,0x44,0x55,0xf5,0x25,0x25,0x45,0xf5,0x45,0x04,0x35,0xc8,0x08,0x13,
+0x40,0x20,0xfe,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,
+/* 32545 0x7f21 "缡" */
+0x10,0x10,0x23,0x20,0x49,0xf9,0x11,0x21,0x40,0xfb,0x42,0x02,0x1a,0xe2,0x42,0x02,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 32546 0x7f22 "缢" */
+0x11,0x10,0x20,0x20,0x4b,0xf8,0x10,0x21,0x42,0xf9,0x41,0x01,0x19,0xe1,0x47,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 32547 0x7f23 "缣" */
+0x10,0x10,0x20,0x25,0x44,0xf9,0x10,0x23,0x40,0xfd,0x40,0x00,0x1d,0xe2,0x40,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 32548 0x7f24 "缤" */
+0x10,0x10,0x23,0x22,0x4c,0xf9,0x11,0x21,0x41,0xf9,0x41,0x07,0x18,0xe0,0x41,0x02,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 32549 0x7f25 "缥" */
+0x10,0x13,0x20,0x25,0x45,0xf9,0x11,0x20,0x41,0xfc,0x43,0x00,0x1c,0xe1,0x42,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 32550 0x7f26 "缦" */
+0x10,0x11,0x21,0x21,0x49,0xf9,0x10,0x23,0x42,0xfb,0x40,0x01,0x18,0xe0,0x41,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 32551 0x7f27 "缧" */
+0x10,0x11,0x21,0x25,0x45,0xf9,0x10,0x20,0x41,0xfc,0x40,0x03,0x1c,0xe1,0x42,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 32552 0x7f28 "缨" */
+0x20,0x2f,0x28,0x4a,0x5a,0xfa,0x25,0x28,0x40,0xf7,0x41,0x02,0x33,0xc0,0x01,0x0e,
+0x00,0xbe,0xa2,0xaa,0xaa,0xaa,0x14,0xa2,0x80,0xfe,0x10,0x10,0xa0,0x60,0x98,0x04,
+/* 32553 0x7f29 "缩" */
+0x20,0x20,0x27,0x44,0x51,0xf1,0x22,0x26,0x4a,0xf2,0x42,0x02,0x32,0xc2,0x02,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 32554 0x7f2a "缪" */
+0x10,0x17,0x20,0x24,0x4a,0xf4,0x10,0x21,0x46,0xf8,0x43,0x00,0x1b,0xe0,0x40,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 32555 0x7f2b "缫" */
+0x11,0x12,0x21,0x24,0x45,0xf9,0x11,0x21,0x41,0xfc,0x43,0x00,0x1c,0xe1,0x46,0x00,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 32556 0x7f2c "缬" */
+0x22,0x22,0x22,0x4f,0x52,0xf2,0x27,0x20,0x40,0xf7,0x45,0x05,0x35,0xc7,0x05,0x00,
+0x00,0xfe,0x10,0xa0,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 32557 0x7f2d "缭" */
+0x10,0x10,0x23,0x20,0x4a,0xf9,0x13,0x25,0x41,0xf9,0x41,0x00,0x19,0xe2,0x44,0x00,
+0x20,0x20,0xfe,0x50,0x8a,0x04,0xfe,0x04,0xfc,0x04,0xfc,0x20,0x24,0x22,0xa2,0x40,
+/* 32558 0x7f2e "缮" */
+0x10,0x10,0x23,0x20,0x49,0xf8,0x13,0x21,0x40,0xfb,0x40,0x01,0x19,0xe1,0x41,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 32559 0x7f2f "缯" */
+0x11,0x10,0x20,0x23,0x4a,0xfa,0x12,0x22,0x43,0xf8,0x41,0x01,0x19,0xe1,0x41,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 32560 0x7f30 "缰" */
+0x10,0x13,0x20,0x25,0x45,0xf9,0x11,0x23,0x40,0xfd,0x41,0x01,0x1d,0xe1,0x40,0x03,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 32561 0x7f31 "缱" */
+0x10,0x14,0x22,0x22,0x48,0xf9,0x10,0x2e,0x42,0xfa,0x42,0x02,0x1a,0xe2,0x45,0x08,
+0x10,0xfe,0x92,0xfe,0x10,0xfe,0x00,0xfe,0x82,0xfe,0x80,0xfe,0x82,0xfe,0x00,0xfe,
+/* 32562 0x7f32 "缲" */
+0x11,0x11,0x21,0x21,0x48,0xfb,0x12,0x22,0x43,0xf8,0x47,0x00,0x18,0xe1,0x46,0x00,
+0xfc,0x04,0x04,0xfc,0x00,0xde,0x52,0x52,0xde,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 32563 0x7f33 "缳" */
+0x10,0x13,0x22,0x22,0x4b,0xf8,0x17,0x20,0x43,0xfa,0x43,0x00,0x19,0xe3,0x4d,0x01,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 32564 0x7f34 "缴" */
+0x21,0x22,0x27,0x44,0x57,0xf4,0x27,0x22,0x41,0xf7,0x42,0x03,0x32,0xc4,0x05,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 32565 0x7f35 "缵" */
+0x21,0x25,0x27,0x49,0x57,0xf3,0x25,0x29,0x40,0xf3,0x42,0x02,0x32,0xc0,0x01,0x06,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0x00,0xf8,0x08,0x48,0x48,0xb0,0x08,0x04,
+/* 32566 0x7f36 "缶" */
+0x08,0x08,0x10,0x1f,0x21,0x41,0x01,0x01,0xff,0x01,0x21,0x21,0x21,0x21,0x3f,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 32567 0x7f37 "缷" */
+0x20,0x20,0x3f,0x48,0x88,0x08,0xff,0x08,0x08,0x49,0x49,0x49,0x4f,0x79,0x00,0x00,
+0x00,0x00,0x3e,0x22,0x22,0x22,0xa2,0x22,0x22,0x22,0x2a,0x24,0x20,0x20,0x20,0x20,
+/* 32568 0x7f38 "缸" */
+0x20,0x20,0x3f,0x48,0x88,0x08,0xff,0x08,0x08,0x49,0x49,0x49,0x4f,0x79,0x01,0x00,
+0x00,0x00,0x7e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 32569 0x7f39 "缹" */
+0x08,0x08,0x1f,0x21,0x41,0x01,0xff,0x01,0x21,0x21,0x21,0x3f,0x00,0x48,0x44,0x84,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x08,0x08,0x08,0xf8,0x00,0x88,0x44,0x44,
+/* 32570 0x7f3a "缺" */
+0x20,0x20,0x3c,0x51,0x90,0x10,0xfe,0x10,0x13,0x54,0x54,0x54,0x5c,0x64,0x05,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32571 0x7f3b "缻" */
+0x20,0x20,0x3d,0x50,0x90,0x10,0xfe,0x10,0x10,0x54,0x54,0x54,0x5c,0x64,0x04,0x00,
+0x00,0x00,0xfe,0x40,0x40,0x78,0x48,0x48,0x68,0x98,0x98,0x88,0x8a,0xaa,0xca,0x86,
+/* 32572 0x7f3c "缼" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x11,0x10,0x54,0x54,0x54,0x5c,0x64,0x05,0x02,
+0x40,0x40,0x40,0x7c,0x44,0x88,0xa0,0x20,0x20,0x50,0x50,0x48,0x88,0x84,0x04,0x02,
+/* 32573 0x7f3d "缽" */
+0x20,0x20,0x3c,0x50,0x91,0x10,0xfe,0x10,0x11,0x55,0x56,0x54,0x5c,0x64,0x04,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0xf8,0x20,0x20,0x20,0x20,
+/* 32574 0x7f3e "缾" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x11,0x54,0x54,0x54,0x5c,0x64,0x04,0x01,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 32575 0x7f3f "缿" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x10,0x54,0x54,0x54,0x5c,0x65,0x05,0x02,
+0x08,0x1c,0xe0,0x80,0x80,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xa4,0xa4,0x3c,0x24,0x00,
+/* 32576 0x7f40 "罀" */
+0x20,0x20,0x3c,0x51,0x90,0x10,0xfe,0x10,0x10,0x55,0x56,0x54,0x5c,0x64,0x05,0x02,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 32577 0x7f41 "罁" */
+0x40,0x43,0x7a,0xa2,0x22,0x23,0xfa,0x22,0x22,0xaa,0xaa,0xaa,0xba,0xca,0x02,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 32578 0x7f42 "罂" */
+0x3e,0x22,0x2a,0x2a,0x2a,0x14,0x22,0x49,0x1f,0x21,0x01,0xff,0x01,0x21,0x3f,0x00,
+0xf8,0x88,0xa8,0xa8,0xa8,0x50,0x88,0x04,0xf8,0x00,0x00,0xfe,0x00,0x08,0xf8,0x08,
+/* 32579 0x7f43 "罃" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x88,0x1f,0x21,0x01,0xff,0x01,0x21,0x21,0x3f,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x00,0x08,0x08,0xf8,
+/* 32580 0x7f44 "罄" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0x90,0x1f,0x21,0xff,0x01,0x21,0x3f,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x86,0xf0,0x00,0xfe,0x00,0x08,0xf8,
+/* 32581 0x7f45 "罅" */
+0x40,0x40,0x78,0xa3,0x22,0x22,0xfb,0x22,0x22,0xaa,0xab,0xaa,0xbd,0xcc,0x08,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 32582 0x7f46 "罆" */
+0x20,0x21,0x3d,0x53,0x91,0x11,0xfe,0x11,0x11,0x55,0x55,0x55,0x5d,0x65,0x04,0x01,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32583 0x7f47 "罇" */
+0x41,0x40,0x7b,0xa0,0x23,0x22,0xfb,0x22,0x23,0xaa,0xab,0xa8,0xbb,0xc9,0x00,0x00,
+0x08,0x90,0xfe,0x90,0xfc,0x94,0x1c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x08,0xa8,0x10,
+/* 32584 0x7f48 "罈" */
+0x40,0x43,0x78,0xa3,0x22,0x23,0xf8,0x21,0x21,0xa9,0xa9,0xa9,0xb8,0xcb,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 32585 0x7f49 "罉" */
+0x41,0x40,0x7b,0xa2,0x20,0x20,0xf8,0x20,0x21,0xa8,0xa9,0xa8,0xbb,0xc8,0x00,0x00,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 32586 0x7f4a "罊" */
+0x08,0x7f,0x08,0x3e,0x2b,0x3e,0x2a,0xff,0x49,0x7f,0x20,0x3f,0x41,0xff,0x21,0x3f,
+0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x90,0x28,0x46,0x00,0xf8,0x00,0xfe,0x08,0xf8,
+/* 32587 0x7f4b "罋" */
+0x01,0xff,0x10,0x24,0x79,0x10,0x22,0x7c,0x08,0x30,0xc8,0x3f,0x41,0xff,0x21,0x3f,
+0x00,0xfe,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xf8,0x00,0xfe,0x08,0xf8,
+/* 32588 0x7f4c "罌" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x22,0x10,0x1f,0x21,0xff,0x01,0x21,0x3f,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0x00,0xf0,0x00,0xfe,0x00,0x08,0xf8,
+/* 32589 0x7f4d "罍" */
+0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0x3e,0x10,0x1f,0x21,0xff,0x01,0x21,0x3f,
+0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xf0,0x00,0xfe,0x00,0x08,0xf8,
+/* 32590 0x7f4e "罎" */
+0x41,0x41,0x79,0xa1,0x23,0x20,0xfb,0x22,0x21,0xa8,0xa9,0xa8,0xbb,0xc8,0x00,0x01,
+0xfc,0x04,0xfc,0x04,0xfe,0x20,0xfe,0x22,0xac,0x20,0xfc,0x00,0xfe,0x40,0x88,0xfc,
+/* 32591 0x7f4f "罏" */
+0x40,0x40,0x78,0xa3,0x22,0x23,0xfa,0x22,0x22,0xaa,0xaa,0xaa,0xba,0xcd,0x05,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 32592 0x7f50 "罐" */
+0x40,0x43,0x78,0xa3,0x22,0x23,0xf8,0x20,0x21,0xa9,0xab,0xad,0xb9,0xc9,0x01,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 32593 0x7f51 "网" */
+0x00,0x7f,0x40,0x40,0x42,0x52,0x4a,0x44,0x44,0x4a,0x4a,0x52,0x61,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x14,0x94,0x54,0x24,0x24,0x54,0x54,0x94,0x04,0x04,0x14,0x08,
+/* 32594 0x7f52 "罒" */
+0x00,0x3f,0x24,0x24,0x24,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x48,0x48,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 32595 0x7f53 "罓" */
+0x00,0x3f,0x20,0x24,0x22,0x21,0x22,0x24,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x48,0x88,0x08,0x88,0x48,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 32596 0x7f54 "罔" */
+0x00,0x7f,0x40,0x48,0x44,0x5f,0x41,0x40,0x5f,0x44,0x44,0x44,0x47,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x24,0x44,0xf4,0x04,0x84,0xf4,0x04,0x04,0x04,0xe4,0x04,0x14,0x08,
+/* 32597 0x7f55 "罕" */
+0x00,0x7f,0x40,0x88,0x10,0x20,0x1f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x00,0xfe,0x02,0x24,0x10,0x08,0xf0,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 32598 0x7f56 "罖" */
+0x00,0x3f,0x24,0x24,0x24,0x3f,0x01,0x02,0x04,0x08,0x30,0xc2,0x01,0x00,0x00,0x00,
+0x00,0xf8,0x48,0x48,0x48,0xf8,0x00,0x80,0x40,0x20,0x18,0x06,0x00,0x80,0x80,0x00,
+/* 32599 0x7f57 "罗" */
+0x00,0x3f,0x24,0x24,0x24,0x3f,0x02,0x04,0x0f,0x10,0x68,0x04,0x02,0x03,0x1c,0xe0,
+0x00,0xf8,0x48,0x48,0x48,0xf8,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 32600 0x7f58 "罘" */
+0x00,0x3f,0x24,0x24,0x3f,0x00,0x00,0x7f,0x01,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x00,0xf8,0x48,0x48,0xf8,0x00,0x00,0xfc,0x00,0x00,0x70,0x0c,0x02,0x00,0x00,0x00,
+/* 32601 0x7f59 "罙" */
+0x00,0x7f,0x40,0x88,0x10,0x21,0x01,0x01,0xff,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x00,0xfe,0x02,0x24,0x10,0x08,0x00,0x00,0xfe,0x80,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 32602 0x7f5a "罚" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x20,0x10,0x00,0xf0,0x10,0x10,0x14,0x18,0x10,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x28,0x10,
+/* 32603 0x7f5b "罛" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x22,0x43,0x82,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x78,0xa0,0x20,0x20,0x10,0x90,0x48,0xa8,0x24,0x02,
+/* 32604 0x7f5c "罜" */
+0x00,0x7f,0x44,0x44,0x7f,0x02,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 32605 0x7f5d "罝" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 32606 0x7f5e "罞" */
+0x00,0x7f,0x44,0x7f,0x00,0x3f,0x00,0x06,0x01,0xff,0x02,0x04,0x08,0x30,0xc2,0x01,
+0x00,0xfc,0x44,0xfc,0x00,0xf0,0x20,0x40,0x80,0xfe,0x82,0x84,0x80,0x80,0x80,0x00,
+/* 32607 0x7f5f "罟" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x01,0xff,0x01,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 32608 0x7f60 "罠" */
+0x7f,0x44,0x44,0x7f,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x2c,0x30,
+0xfc,0x44,0x44,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfc,0x80,0x44,0x24,0x1c,
+/* 32609 0x7f61 "罡" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x00,0x7f,0x01,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 32610 0x7f62 "罢" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x04,0x08,0x10,0x3f,0x10,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x20,0x10,0xf8,0x08,
+/* 32611 0x7f63 "罣" */
+0x00,0x7f,0x44,0x44,0x7f,0x01,0x3f,0x01,0x01,0xff,0x00,0x01,0x3f,0x01,0x01,0xff,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 32612 0x7f64 "罤" */
+0x00,0x7f,0x44,0x44,0x7f,0x08,0x04,0x7f,0x01,0x3f,0x21,0x3f,0x03,0x05,0x19,0x61,
+0x00,0xfc,0x44,0x44,0xfc,0x20,0x40,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x14,0x08,0x00,
+/* 32613 0x7f65 "罥" */
+0x7f,0x44,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x20,0x20,
+0xfc,0x44,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 32614 0x7f66 "罦" */
+0x7f,0x44,0x7f,0x00,0x00,0x7f,0x22,0x11,0x3f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0xfc,0x44,0xfc,0x00,0xf8,0x00,0x10,0x20,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 32615 0x7f67 "罧" */
+0x00,0x7f,0x44,0x44,0x7f,0x08,0x08,0x7e,0x08,0x1c,0x1a,0x2a,0x48,0x89,0x08,0x08,
+0x00,0xfc,0x44,0x44,0xfc,0x20,0x20,0xfc,0x20,0x30,0x70,0x68,0xa4,0x22,0x20,0x20,
+/* 32616 0x7f68 "罨" */
+0x3f,0x24,0x24,0x3f,0x02,0x7f,0x04,0x09,0x3f,0xd1,0x1f,0x11,0x1f,0x01,0x01,0x00,
+0xf8,0x48,0x48,0xf8,0x00,0xfc,0x40,0x20,0xf8,0x16,0xf0,0x10,0xf4,0x04,0x04,0xfc,
+/* 32617 0x7f69 "罩" */
+0x00,0x7f,0x44,0x7f,0x01,0x01,0x01,0x3f,0x20,0x3f,0x20,0x3f,0x01,0xff,0x01,0x01,
+0x00,0xfc,0x44,0xfc,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,
+/* 32618 0x7f6a "罪" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x04,0x7c,0x04,0x04,0x7c,0x04,0x04,0xfc,0x04,0x04,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x40,0x7c,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,
+/* 32619 0x7f6b "罫" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x08,0x7f,0x08,0xff,0x08,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0x20,0x20,0x20,0x30,0x28,0x24,0x24,0x20,0x20,0x20,
+/* 32620 0x7f6c "罬" */
+0x7f,0x44,0x7f,0x00,0x3e,0x02,0x14,0x08,0x14,0x62,0x3e,0x02,0x14,0x08,0x34,0xc2,
+0xfc,0x44,0xfc,0x00,0xf8,0x08,0xd0,0x20,0x50,0x88,0xf8,0x88,0x50,0x20,0x58,0x86,
+/* 32621 0x7f6d "罭" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x00,0xff,0x00,0x3e,0x22,0x3e,0x00,0x0e,0x70,0x03,
+0x00,0xfc,0x44,0x44,0xfc,0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x02,
+/* 32622 0x7f6e "置" */
+0x7f,0x44,0x44,0x7f,0x01,0xff,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,
+0xfc,0x44,0x44,0xfc,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,
+/* 32623 0x7f6f "罯" */
+0x00,0x7f,0x44,0x7f,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0xfc,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 32624 0x7f70 "罰" */
+0x7f,0x44,0x44,0x7f,0x08,0x04,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x21,0x3f,0x21,
+0xfc,0x44,0x44,0xfc,0x00,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 32625 0x7f71 "罱" */
+0x7f,0x44,0x44,0x7f,0x01,0xff,0x01,0x3f,0x24,0x22,0x2f,0x21,0x3f,0x21,0x21,0x20,
+0xfc,0x44,0x44,0xfc,0x00,0xfe,0x00,0xf8,0x48,0x88,0xe8,0x08,0xf8,0x08,0x28,0x10,
+/* 32626 0x7f72 "署" */
+0x00,0x3f,0x24,0x24,0x3f,0x02,0x1f,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,0x08,
+0x00,0xf8,0x48,0x48,0xf8,0x00,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 32627 0x7f73 "罳" */
+0x7f,0x44,0x44,0x7f,0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x01,0x48,0x48,0x87,
+0xfc,0x44,0x44,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x84,0x12,0xf2,
+/* 32628 0x7f74 "罴" */
+0x3f,0x24,0x24,0x3f,0x01,0x01,0x3f,0x01,0xff,0x04,0x08,0x1f,0x00,0x48,0x44,0x84,
+0xf8,0x48,0x48,0xf8,0x00,0x00,0xf8,0x00,0xfe,0x00,0x20,0xf0,0x10,0x88,0x44,0x44,
+/* 32629 0x7f75 "罵" */
+0x7f,0x44,0x44,0x7f,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x00,0x29,0x44,0x00,
+0xfc,0x44,0x44,0xfc,0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 32630 0x7f76 "罶" */
+0x7f,0x44,0x44,0x7f,0x04,0x79,0x40,0x48,0x54,0x62,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0xfc,0x44,0x44,0xfc,0x00,0xfc,0x44,0x44,0x54,0x88,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 32631 0x7f77 "罷" */
+0x7f,0x44,0x44,0x7f,0x10,0x24,0x42,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,
+0xfc,0x44,0x44,0xfc,0x80,0x98,0xe0,0x84,0x84,0x7c,0x80,0x98,0xe0,0x84,0x84,0x7c,
+/* 32632 0x7f78 "罸" */
+0x7f,0x44,0x44,0x7f,0x10,0x08,0xff,0x00,0x7e,0x00,0x7e,0x00,0x7e,0x42,0x7e,0x42,
+0xfc,0x44,0x44,0xfc,0x08,0x08,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 32633 0x7f79 "罹" */
+0x00,0x7f,0x44,0x44,0x7f,0x10,0x10,0x19,0x55,0x53,0x95,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x44,0x44,0xfc,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 32634 0x7f7a "罺" */
+0x7f,0x44,0x7f,0x11,0x22,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x7f,0x05,0x19,0xe1,
+0xfc,0x44,0xfc,0x10,0x20,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x40,0x30,0x0e,
+/* 32635 0x7f7b "罻" */
+0x7f,0x44,0x44,0x7f,0x00,0x3f,0x21,0x3f,0x20,0x2e,0x20,0x3f,0x44,0x55,0xa4,0x0c,
+0xfc,0x44,0x44,0xfc,0x00,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0xa8,0x10,
+/* 32636 0x7f7c "罼" */
+0x7f,0x44,0x7f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x09,0xff,0x09,0x3f,0x01,0x7f,0x01,
+0xfc,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfe,0x20,0xf8,0x00,0xfc,0x00,
+/* 32637 0x7f7d "罽" */
+0x7f,0x44,0x44,0x7f,0x00,0x7f,0x42,0x4a,0x52,0x45,0x48,0x52,0x4a,0x53,0x44,0x98,
+0xfc,0x44,0x44,0xfc,0x00,0xfe,0x00,0x44,0xa4,0x24,0xa4,0x24,0xa4,0x04,0x94,0x48,
+/* 32638 0x7f7e "罾" */
+0x3f,0x24,0x24,0x3f,0x08,0x04,0x3f,0x29,0x25,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0xf8,0x48,0x48,0xf8,0x20,0x40,0xf8,0x28,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 32639 0x7f7f "罿" */
+0x00,0x7f,0x44,0x7f,0x01,0x3f,0x04,0xff,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,
+0x00,0xfc,0x44,0xfc,0x00,0xf8,0x40,0xfe,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 32640 0x7f80 "羀" */
+0x3f,0x2a,0x24,0x2a,0x00,0xff,0x02,0x3e,0x22,0x3e,0x02,0x3f,0x21,0x3f,0x21,0x3f,
+0xf8,0xa8,0x48,0xa8,0x00,0xfe,0x80,0xf8,0x88,0xf8,0x80,0xf8,0x08,0xf8,0x08,0xf8,
+/* 32641 0x7f81 "羁" */
+0x00,0x7f,0x44,0x7f,0x22,0x7f,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x00,0xfc,0x44,0xfc,0x00,0x78,0x08,0x48,0x48,0x7c,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 32642 0x7f82 "羂" */
+0x7f,0x44,0x44,0x7f,0x10,0x11,0x25,0x7d,0x08,0x11,0x25,0x7d,0x01,0x55,0x55,0x81,
+0xfc,0x44,0x44,0xfc,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 32643 0x7f83 "羃" */
+0x7f,0x44,0x7f,0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0xff,0x09,0x3f,0xd1,0x11,0x01,
+0xfc,0x44,0xfc,0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfe,0x20,0xf8,0x16,0x30,0x00,
+/* 32644 0x7f84 "羄" */
+0x7f,0x44,0x44,0x7f,0x10,0x10,0x24,0x7d,0x09,0x11,0x25,0x7d,0x00,0x55,0x54,0x80,
+0xfc,0x44,0x44,0xfc,0x20,0x3c,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 32645 0x7f85 "羅" */
+0x00,0x7f,0x44,0x44,0x7f,0x10,0x14,0x25,0x7a,0x10,0x24,0x7e,0x00,0x54,0x4a,0x8a,
+0x00,0xfc,0x44,0x44,0xfc,0x50,0x88,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,
+/* 32646 0x7f86 "羆" */
+0x7f,0x44,0x7f,0x10,0x24,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,0x24,0x42,
+0xfc,0x44,0xfc,0x80,0x98,0xe0,0x84,0x7c,0x00,0x98,0xe0,0x84,0x84,0x7c,0x88,0x44,
+/* 32647 0x7f87 "羇" */
+0x7f,0x44,0x44,0x7f,0x28,0xfd,0x28,0x38,0x10,0x7d,0x54,0x7d,0x11,0xfd,0x10,0x10,
+0xfc,0x44,0x44,0xfc,0x20,0xfc,0x20,0x50,0x88,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x18,
+/* 32648 0x7f88 "羈" */
+0x00,0x7f,0x44,0x44,0x7f,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x7d,0x10,0xfe,0x10,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xaa,0x04,
+/* 32649 0x7f89 "羉" */
+0x7f,0x44,0x44,0x7f,0x00,0x21,0x23,0x48,0x73,0x20,0x4b,0x78,0x03,0xaa,0xab,0x82,
+0xfc,0x44,0x44,0xfc,0x00,0x08,0x90,0x24,0xb8,0x10,0xa4,0x3e,0x88,0xac,0xca,0x98,
+/* 32650 0x7f8a "羊" */
+0x08,0x04,0x04,0x7f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x20,0x20,0x40,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 32651 0x7f8b "羋" */
+0x09,0x09,0x09,0xf9,0x09,0x09,0x08,0x01,0x7f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x00,0xfc,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 32652 0x7f8c "羌" */
+0x08,0x04,0x04,0x7f,0x01,0x01,0x3f,0x02,0x02,0xff,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x20,0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x80,0x80,0x82,0x82,0x7e,
+/* 32653 0x7f8d "羍" */
+0x02,0x02,0x7f,0x04,0x08,0x30,0xc8,0x04,0x7f,0x01,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x40,0x20,0x18,0x26,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 32654 0x7f8e "美" */
+0x10,0x08,0x04,0x7f,0x01,0x01,0x3f,0x01,0xff,0x01,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x10,0x10,0x20,0xfc,0x00,0x00,0xf8,0x00,0xfe,0x00,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 32655 0x7f8f "羏" */
+0x22,0x12,0x14,0xff,0x08,0x08,0x7f,0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x20,0xc1,
+0x04,0x04,0x08,0x90,0x20,0x44,0x04,0x08,0x10,0xa2,0x42,0x04,0x08,0x10,0x60,0x80,
+/* 32656 0x7f90 "羐" */
+0x08,0x08,0xf8,0x08,0x01,0x3f,0x01,0x01,0xff,0x04,0x0f,0x10,0x60,0x03,0x1c,0xe0,
+0x20,0x20,0x3e,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0xe0,0x40,0x80,0x40,0x30,0x0e,
+/* 32657 0x7f91 "羑" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x04,0x07,0x08,0x10,0x60,0x01,0x06,0x18,0xe0,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xe0,0x20,0x40,0x80,0x40,0x20,0x18,0x06,
+/* 32658 0x7f92 "羒" */
+0x44,0x24,0x28,0xfe,0x10,0x10,0x7d,0x12,0x10,0xfe,0x10,0x10,0x20,0x20,0x41,0x82,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 32659 0x7f93 "羓" */
+0x44,0x24,0x29,0xfd,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x21,0x40,0x80,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32660 0x7f94 "羔" */
+0x08,0x04,0x04,0x7f,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,0x48,0x44,0x84,
+0x20,0x20,0x40,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x88,0x44,0x44,
+/* 32661 0x7f95 "羕" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x01,0x00,0x1f,0x01,0x7d,0x09,0x11,0x25,0xc2,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0x80,0x00,0x04,0x88,0x50,0x20,0x18,0x06,
+/* 32662 0x7f96 "羖" */
+0x44,0x24,0x28,0xfe,0x10,0x11,0x7e,0x11,0x10,0xfe,0x10,0x10,0x20,0x20,0x40,0x83,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 32663 0x7f97 "羗" */
+0x08,0x04,0x04,0x7f,0x01,0x01,0x3f,0x02,0x02,0xff,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x20,0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x90,0xa4,0xbc,0x82,0x82,0x7e,
+/* 32664 0x7f98 "羘" */
+0x01,0x3c,0x24,0x24,0x27,0x3c,0x24,0x25,0x24,0x3c,0x27,0x24,0x24,0x44,0x54,0x88,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32665 0x7f99 "羙" */
+0x08,0x04,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x01,0x11,0x11,0x22,0x04,0x18,0xe0,
+0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x10,0x20,0x80,0x40,0x30,0x0e,
+/* 32666 0x7f9a "羚" */
+0x44,0x24,0x28,0xfc,0x10,0x11,0x7e,0x10,0x11,0xfc,0x10,0x10,0x20,0x20,0x40,0x80,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 32667 0x7f9b "羛" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x04,0x7f,0x04,0x3f,0x24,0x3f,0x08,0x10,0x20,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0x48,
+/* 32668 0x7f9c "羜" */
+0x44,0x24,0x28,0xfd,0x11,0x12,0x7c,0x10,0x11,0xfc,0x10,0x10,0x20,0x20,0x40,0x80,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32669 0x7f9d "羝" */
+0x44,0x24,0x29,0xfd,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x21,0x41,0x81,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 32670 0x7f9e "羞" */
+0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x04,0x0f,0x11,0x21,0xcf,0x02,0x02,0x3f,0x00,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 32671 0x7f9f "羟" */
+0x44,0x25,0x28,0xfc,0x10,0x10,0x7c,0x13,0x10,0xfd,0x10,0x10,0x20,0x20,0x43,0x80,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32672 0x7fa0 "羠" */
+0x44,0x24,0x2b,0xfc,0x11,0x10,0x7d,0x11,0x11,0xfc,0x10,0x10,0x20,0x20,0x41,0x82,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 32673 0x7fa1 "羡" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x40,0x20,0x09,0x12,0x24,0xe0,0x20,0x23,0x2c,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,
+/* 32674 0x7fa2 "羢" */
+0x44,0x24,0x28,0xfd,0x10,0x10,0x7c,0x10,0x13,0xfc,0x10,0x10,0x20,0x21,0x41,0x82,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xf2,0x94,0x94,0x88,0x8a,0x1a,0x26,0x42,
+/* 32675 0x7fa3 "羣" */
+0x3f,0x02,0xff,0x04,0x3f,0x08,0x1f,0x28,0xcf,0x04,0x7f,0x01,0x3f,0x01,0xff,0x01,
+0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,
+/* 32676 0x7fa4 "群" */
+0x00,0x7e,0x12,0x12,0xff,0x12,0x12,0x7e,0x20,0x20,0x7e,0x62,0xa2,0x22,0x3e,0x22,
+0x82,0x44,0x28,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 32677 0x7fa5 "羥" */
+0x44,0x25,0x28,0xfc,0x11,0x12,0x7d,0x10,0x10,0xfd,0x10,0x10,0x20,0x20,0x43,0x80,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32678 0x7fa6 "羦" */
+0x44,0x24,0x29,0xfd,0x12,0x10,0x7c,0x10,0x11,0xfc,0x10,0x10,0x20,0x20,0x41,0x82,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 32679 0x7fa7 "羧" */
+0x44,0x24,0x28,0xfd,0x13,0x10,0x7c,0x11,0x12,0xfc,0x11,0x12,0x20,0x20,0x41,0x86,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 32680 0x7fa8 "羨" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x00,0x20,0x11,0x82,0x54,0x20,0xe0,0x23,0x2c,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x80,0x80,0xfc,0x04,0x48,0x40,0xa0,0x18,0x06,
+/* 32681 0x7fa9 "義" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x02,0x3c,0x08,0xff,0x08,0x0e,0x78,0x08,0x19,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x50,0x48,0xfe,0x48,0x50,0x24,0x54,0x8c,
+/* 32682 0x7faa "羪" */
+0x44,0x24,0x29,0xfd,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x21,0x41,0x81,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 32683 0x7fab "羫" */
+0x44,0x24,0x29,0xfd,0x12,0x10,0x7c,0x11,0x10,0xfd,0x10,0x10,0x20,0x20,0x43,0x80,
+0x40,0x20,0xfe,0x02,0x04,0x50,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32684 0x7fac "羬" */
+0x88,0x48,0x50,0xfb,0x22,0x22,0xfa,0x22,0x22,0xfa,0x22,0x22,0x22,0x42,0x42,0x84,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 32685 0x7fad "羭" */
+0x88,0x48,0x51,0xfa,0x25,0x20,0xfb,0x22,0x22,0xfb,0x22,0x22,0x23,0x42,0x42,0x82,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 32686 0x7fae "羮" */
+0x04,0x7f,0x01,0x3f,0x01,0xff,0x24,0x42,0x3f,0x01,0x1f,0x01,0xff,0x02,0x0c,0x70,
+0x40,0xfc,0x00,0xf8,0x00,0xfe,0x88,0x44,0xf8,0x00,0xf0,0x00,0xfe,0x80,0x60,0x1c,
+/* 32687 0x7faf "羯" */
+0x44,0x25,0x29,0xfd,0x11,0x11,0x7c,0x11,0x12,0xfd,0x11,0x11,0x21,0x20,0x40,0x80,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 32688 0x7fb0 "羰" */
+0x44,0x25,0x29,0xfd,0x11,0x10,0x7c,0x13,0x10,0xfd,0x11,0x12,0x22,0x24,0x48,0x80,
+0x20,0x24,0x24,0x24,0xfc,0x80,0x80,0xfe,0x90,0x10,0x52,0x54,0xa8,0x28,0x44,0x82,
+/* 32689 0x7fb1 "羱" */
+0x44,0x25,0x29,0xfd,0x11,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x22,0x42,0x84,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 32690 0x7fb2 "羲" */
+0x04,0x7f,0x01,0x3f,0x01,0xff,0x00,0x3e,0x08,0xff,0x2a,0x7d,0x90,0x1e,0x02,0x0c,
+0x40,0xfc,0x00,0xf8,0x00,0xfe,0x28,0x24,0x24,0xfe,0x20,0x24,0xa8,0x12,0x2a,0x46,
+/* 32691 0x7fb3 "羳" */
+0x44,0x27,0x29,0xfc,0x13,0x10,0x7d,0x12,0x11,0xfd,0x11,0x11,0x21,0x21,0x41,0x81,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 32692 0x7fb4 "羴" */
+0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x45,0x29,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x20,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,
+/* 32693 0x7fb5 "羵" */
+0x44,0x25,0x28,0xfc,0x13,0x10,0x7d,0x11,0x11,0xfd,0x11,0x11,0x21,0x20,0x41,0x82,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 32694 0x7fb6 "羶" */
+0x88,0x4b,0x50,0xfb,0x22,0x22,0xfa,0x23,0x20,0xf9,0x21,0x21,0x21,0x41,0x40,0x83,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 32695 0x7fb7 "羷" */
+0x44,0x24,0x28,0xfc,0x11,0x12,0x7c,0x10,0x11,0xfd,0x11,0x11,0x20,0x20,0x41,0x82,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 32696 0x7fb8 "羸" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x04,0x72,0x57,0x71,0x53,0x71,0x57,0xb1,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x40,0x9c,0xd4,0x14,0x9c,0x16,0xd6,0x22,
+/* 32697 0x7fb9 "羹" */
+0x04,0x7f,0x01,0x3f,0x01,0xff,0x48,0x82,0x3f,0x01,0x1f,0x01,0xff,0x02,0x0c,0x70,
+0x40,0xfc,0x00,0xf8,0x00,0xfe,0x24,0x82,0xf8,0x00,0xf0,0x00,0xfe,0x80,0x60,0x1c,
+/* 32698 0x7fba "羺" */
+0x88,0x49,0x50,0xfb,0x22,0x21,0xf8,0x21,0x20,0xfb,0x20,0x21,0x21,0x41,0x41,0x81,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 32699 0x7fbb "羻" */
+0x88,0x4b,0x52,0xfb,0x22,0x23,0xfa,0x23,0x22,0xfb,0x22,0x22,0x22,0x45,0x44,0x89,
+0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfe,0x92,0x48,0x3a,0x40,0xfc,0x48,0x30,0xce,
+/* 32700 0x7fbc "羼" */
+0x3f,0x20,0x3f,0x22,0x2f,0x20,0x27,0x20,0x3f,0x2a,0x3f,0x24,0x5f,0x44,0xbf,0x08,
+0xfc,0x04,0xfc,0x20,0xf8,0x80,0xf0,0x80,0xfc,0xa8,0x7c,0x10,0x7c,0x10,0x7e,0x10,
+/* 32701 0x7fbd "羽" */
+0x00,0x7e,0x02,0x02,0x22,0x12,0x12,0x02,0x0a,0x12,0x62,0x22,0x02,0x02,0x14,0x08,
+0x00,0xfc,0x04,0x04,0x44,0x24,0x24,0x04,0x14,0x24,0xc4,0x44,0x04,0x04,0x28,0x10,
+/* 32702 0x7fbe "羾" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 32703 0x7fbf "羿" */
+0x00,0x7e,0x22,0x12,0x06,0x1a,0x62,0x02,0x04,0x04,0x7f,0x04,0x04,0x08,0x10,0x20,
+0x00,0xfc,0x44,0x24,0x0c,0x34,0xc4,0x04,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32704 0x7fc0 "翀" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x10,0x10,0x10,0x10,0x10,
+/* 32705 0x7fc1 "翁" */
+0x04,0x08,0x12,0x24,0xc8,0x1f,0x00,0x00,0x7e,0x22,0x12,0x0a,0x12,0x22,0x4a,0x04,
+0x40,0x20,0x10,0x08,0x26,0xf0,0x10,0x00,0xfc,0x44,0x24,0x14,0x24,0x44,0x94,0x08,
+/* 32706 0x7fc2 "翂" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x23,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x45,
+0x08,0x28,0x28,0x28,0x44,0x44,0x82,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 32707 0x7fc3 "翃" */
+0x08,0x08,0x08,0x7e,0x10,0x10,0x20,0x28,0x48,0x48,0x90,0x14,0x22,0x7e,0x22,0x00,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32708 0x7fc4 "翄" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32709 0x7fc5 "翅" */
+0x10,0x11,0x10,0xfe,0x11,0x10,0xfc,0x44,0x45,0x28,0x28,0x11,0x18,0x24,0x43,0x80,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0x44,0x54,0x88,0x00,0xfe,0x00,
+/* 32710 0x7fc6 "翆" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x04,0x3f,0x04,0x08,0x11,0x21,0xff,0x01,0x01,0x01,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x00,0xc0,0x40,0x44,0x3c,0x00,0xfe,0x00,0x00,0x00,
+/* 32711 0x7fc7 "翇" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x02,0x01,0x7f,0x02,0x07,0x0a,0x11,0x60,0x03,0x1c,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x24,0x10,0xfe,0x00,0xf0,0x10,0x20,0xc0,0x30,0x0e,
+/* 32712 0x7fc8 "翈" */
+0x00,0x7d,0x54,0x54,0x55,0x7c,0x54,0x54,0x54,0x7c,0x55,0x10,0x10,0x10,0x11,0x10,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32713 0x7fc9 "翉" */
+0x10,0x11,0x10,0xfc,0x11,0x30,0x38,0x54,0x52,0x90,0x11,0x7c,0x10,0x10,0x11,0x10,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32714 0x7fca "翊" */
+0x20,0x13,0x10,0xfc,0x02,0x09,0x89,0x88,0x48,0x49,0x52,0x50,0x1c,0xe0,0x41,0x00,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 32715 0x7fcb "翋" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x20,0x10,0x10,0xfe,0x00,0x04,0x44,0x44,0x24,0x24,0x28,0x28,0x08,0x10,0xfe,0x00,
+/* 32716 0x7fcc "翌" */
+0x00,0x7e,0x22,0x12,0x06,0x1a,0x62,0x01,0x00,0x7f,0x00,0x10,0x08,0x04,0xff,0x00,
+0x00,0xfc,0x44,0x24,0x0c,0x34,0xc4,0x00,0x80,0xfc,0x00,0x10,0x20,0x40,0xfe,0x00,
+/* 32717 0x7fcd "翍" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x23,0xaa,0x44,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 32718 0x7fce "翎" */
+0x10,0x11,0x28,0x24,0x43,0x90,0x08,0x00,0xfc,0x04,0x09,0x50,0x20,0x10,0x11,0x00,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32719 0x7fcf "翏" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x03,0x06,0x18,0xe3,0x0c,0x31,0x06,0x38,0x07,0x38,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0xc0,0x30,0x0e,0x40,0x80,0x30,0xc0,0x00,0x00,
+/* 32720 0x7fd0 "翐" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x23,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x10,0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 32721 0x7fd1 "翑" */
+0x00,0xee,0x22,0x22,0xab,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x28,0x10,
+/* 32722 0x7fd2 "習" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x01,0x02,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 32723 0x7fd3 "翓" */
+0x10,0x11,0x10,0xfe,0x11,0x10,0x7c,0x00,0x00,0x7c,0x45,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32724 0x7fd4 "翔" */
+0x44,0x25,0x28,0xfe,0x11,0x10,0x7c,0x10,0x10,0xfe,0x11,0x10,0x20,0x20,0x41,0x80,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32725 0x7fd5 "翕" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x00,0x7e,0x22,0x12,0x0a,0x12,0x6a,0x04,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x44,0x24,0x14,0x24,0xd4,0x08,
+/* 32726 0x7fd6 "翖" */
+0x10,0x11,0x28,0x24,0x43,0x80,0x7c,0x00,0x00,0x7c,0x45,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32727 0x7fd7 "翗" */
+0x10,0x10,0x3e,0x42,0xa4,0x18,0x10,0x24,0xc8,0x1f,0x21,0xd2,0x0c,0x08,0x30,0xc0,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32728 0x7fd8 "翘" */
+0x20,0x21,0xfe,0x24,0x29,0x12,0x2a,0xc6,0x01,0xfc,0x28,0x29,0x28,0x48,0x47,0x80,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0x44,0x54,0x8a,0x02,0xfe,0x00,
+/* 32729 0x7fd9 "翙" */
+0x10,0x92,0x92,0x92,0xfe,0x20,0x20,0x3e,0x42,0x42,0xa4,0x14,0x08,0x10,0x20,0xc0,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32730 0x7fda "翚" */
+0x7e,0x22,0x12,0x1a,0x62,0x00,0x7f,0x42,0x9f,0x04,0x09,0x1f,0x01,0x7f,0x01,0x01,
+0xfc,0x44,0x24,0x34,0xc4,0x00,0xfe,0x02,0xf4,0x00,0x00,0xf0,0x00,0xfc,0x00,0x00,
+/* 32731 0x7fdb "翛" */
+0x10,0x10,0x11,0x22,0x28,0x69,0x6e,0xab,0x28,0x2a,0x29,0x29,0x2a,0x28,0x22,0x21,
+0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xb8,0x88,0xa8,0x98,0x98,0xa8,0x88,0xa8,0x10,
+/* 32732 0x7fdc "翜" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x02,0x01,0x7f,0x09,0x09,0x15,0x22,0x04,0x18,0xe0,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0x00,0xfc,0x20,0x20,0x50,0x88,0x40,0x30,0x0e,
+/* 32733 0x7fdd "翝" */
+0x10,0x08,0x7f,0x41,0x92,0x10,0x7f,0x10,0x14,0x24,0x24,0x28,0x4a,0x51,0xbf,0x11,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32734 0x7fde "翞" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x20,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x10,0x54,0x52,0x92,0x10,0x50,0x20,
+/* 32735 0x7fdf "翟" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x02,0x09,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 32736 0x7fe0 "翠" */
+0x00,0x7e,0x22,0x12,0x1a,0x62,0x02,0x01,0x7f,0x08,0x14,0x22,0x01,0xff,0x01,0x01,
+0x00,0xfc,0x44,0x24,0x34,0xc4,0x04,0x00,0xfc,0x20,0x50,0x88,0x00,0xfe,0x00,0x00,
+/* 32737 0x7fe1 "翡" */
+0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,0x00,0x7e,0x22,0x12,0x0a,0x12,0x6a,0x04,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,0x00,0xfc,0x44,0x24,0x14,0x24,0xd4,0x08,
+/* 32738 0x7fe2 "翢" */
+0x00,0x7f,0x49,0x49,0x5d,0x49,0x7f,0x41,0x5d,0x55,0x55,0x5d,0x41,0x41,0x45,0x82,
+0x00,0x6e,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0x2a,0x64,
+/* 32739 0x7fe3 "翣" */
+0x7e,0x22,0x1a,0x62,0x02,0x01,0x3f,0x08,0xff,0x04,0x7f,0x08,0x1c,0x03,0x0c,0x70,
+0xfc,0x44,0x34,0xc4,0x04,0x00,0xf8,0x20,0xfe,0x00,0xfc,0x20,0x40,0x80,0x70,0x08,
+/* 32740 0x7fe4 "翤" */
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0xa2,0x86,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32741 0x7fe5 "翥" */
+0x01,0x1f,0x01,0x7f,0x02,0x0f,0x38,0xcf,0x08,0x0f,0x00,0x7e,0x22,0x1a,0x62,0x06,
+0x08,0xd0,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x44,0x34,0xc4,0x0c,
+/* 32742 0x7fe6 "翦" */
+0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,0x00,0x7e,0x22,0x1a,0x62,0x06,
+0x20,0xfe,0x00,0x08,0x48,0x48,0x48,0x48,0x08,0x18,0x00,0xfc,0x44,0x34,0xc4,0x0c,
+/* 32743 0x7fe7 "翧" */
+0x20,0x11,0xfe,0x82,0x01,0x7c,0x00,0x7c,0x44,0x7c,0x45,0x7c,0x00,0x1c,0xe1,0x40,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32744 0x7fe8 "翨" */
+0x7e,0x22,0x1a,0x62,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x11,0x11,0x29,0x47,
+0xfc,0x44,0x34,0xc4,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,
+/* 32745 0x7fe9 "翩" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x40,0x7f,0x55,0x55,0x7f,0xd5,0x55,0x55,0x43,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32746 0x7fea "翪" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x28,0x92,0xaa,0x82,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 32747 0x7feb "翫" */
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x22,0x10,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x43,
+0x00,0x7c,0x00,0x00,0x00,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 32748 0x7fec "翬" */
+0x7c,0x24,0x14,0x24,0x7f,0x41,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0xf8,0x48,0x28,0x48,0xfc,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 32749 0x7fed "翭" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x23,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+0x40,0x5c,0x44,0x84,0xbe,0x90,0x90,0x9e,0xa8,0x88,0xbe,0x88,0x88,0x94,0x94,0xa2,
+/* 32750 0x7fee "翮" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32751 0x7fef "翯" */
+0x7c,0x24,0x14,0x25,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,
+0xf8,0x48,0x28,0x48,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x0c,
+/* 32752 0x7ff0 "翰" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x45,0x7c,0x45,0x7c,0x10,0xfe,0x11,0x10,0x11,0x10,
+0x20,0x20,0x50,0x88,0x06,0x00,0xdc,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0x54,0x88,
+/* 32753 0x7ff1 "翱" */
+0x10,0x21,0x7c,0x44,0x7d,0x44,0x7c,0x10,0xfe,0x28,0x55,0x92,0x7c,0x10,0x11,0x10,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32754 0x7ff2 "翲" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x20,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32755 0x7ff3 "翳" */
+0x00,0x7f,0x48,0x5f,0x64,0x5f,0x44,0x4a,0x51,0x7f,0x00,0x7e,0x22,0x1a,0x62,0x06,
+0x00,0x78,0x48,0x4c,0x80,0x78,0x48,0x48,0x30,0x4c,0x00,0xfc,0x44,0x34,0xc4,0x0c,
+/* 32756 0x7ff4 "翴" */
+0x00,0xec,0x26,0x25,0xb5,0x6c,0x24,0x27,0x25,0x6d,0xb5,0x25,0x25,0x26,0xb4,0x48,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 32757 0x7ff5 "翵" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xab,0x44,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 32758 0x7ff6 "翶" */
+0x10,0x21,0x7c,0x44,0x7d,0x44,0x7c,0x10,0x54,0x38,0x55,0x10,0xfe,0x10,0x11,0x10,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32759 0x7ff7 "翷" */
+0x08,0x49,0x2a,0x08,0xff,0x2a,0x49,0x88,0x42,0x77,0x92,0x5a,0x2f,0x22,0x42,0x82,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32760 0x7ff8 "翸" */
+0x10,0x7e,0x10,0x24,0xfe,0x24,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,0x81,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32761 0x7ff9 "翹" */
+0x10,0x7d,0x10,0xfe,0x45,0xee,0x44,0xee,0x01,0xfc,0x28,0x29,0x28,0x48,0x47,0x80,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0x44,0x54,0x8a,0x02,0xfe,0x00,
+/* 32762 0x7ffa "翺" */
+0x20,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x10,0x92,0x54,0x92,0x10,0xfe,0x10,0x10,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32763 0x7ffb "翻" */
+0x0e,0xf1,0x92,0x54,0xff,0x38,0x54,0x82,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7d,0x44,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0x44,0x4c,0xd4,0x64,0x44,0x44,0x44,0x54,0x88,
+/* 32764 0x7ffc "翼" */
+0x7e,0x22,0x1a,0x62,0x02,0x3f,0x21,0x3f,0x21,0x3f,0x04,0x3f,0x04,0xff,0x08,0x10,
+0xfc,0x44,0x34,0xc4,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xf8,0x40,0xfe,0x20,0x10,
+/* 32765 0x7ffd "翽" */
+0x08,0x4e,0x48,0xff,0x04,0x05,0x7f,0x44,0x7c,0x55,0x55,0x75,0x5a,0x92,0x25,0xc8,
+0x00,0x76,0x12,0x12,0x5a,0x36,0x92,0x12,0x12,0x36,0x5a,0x12,0x12,0x92,0xda,0xa4,
+/* 32766 0x7ffe "翾" */
+0x00,0xfe,0xaa,0xaa,0xfe,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x2a,0x64,0xa2,0x31,0x20,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32767 0x7fff "翿" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x02,0x7c,0x10,0xfe,0x00,0xff,0x02,0xff,0xaa,0xe6,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 32768 0x8000 "耀" */
+0x10,0x11,0x90,0x55,0x58,0x11,0xfc,0x28,0x28,0x29,0x2a,0x28,0x2a,0x4c,0x48,0x80,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x00,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,
+/* 32769 0x8001 "老" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x0c,0x18,0x2f,0x48,0x88,0x08,0x07,0x00,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0x10,0xe0,0x00,0x08,0x08,0x08,0xf8,0x00,
+/* 32770 0x8002 "耂" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x00,0x01,0x02,0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,
+0x00,0x08,0xc8,0x10,0x20,0xfe,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 32771 0x8003 "考" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x0f,0x12,0x24,0x47,0x80,0x00,0x00,0x00,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 32772 0x8004 "耄" */
+0x02,0x3f,0x02,0xff,0x02,0x0f,0x34,0xc3,0x00,0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,
+0x20,0xc0,0x80,0xfe,0x20,0xc0,0x08,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,
+/* 32773 0x8005 "者" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x0f,0x18,0x28,0x4f,0x88,0x08,0x0f,0x08,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 32774 0x8006 "耆" */
+0x02,0x3f,0x02,0xff,0x02,0x0c,0x3f,0xc8,0x07,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x08,0xd0,0x20,0xfe,0x00,0x70,0x84,0x04,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 32775 0x8007 "耇" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x03,0x1c,0xef,0x10,0x2f,0xc8,0x0f,0x00,0x00,0x00,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0x50,0x20,
+/* 32776 0x8008 "耈" */
+0x02,0x3f,0x02,0xff,0x02,0x0f,0x34,0xc3,0x10,0x3f,0x40,0x9f,0x10,0x1f,0x00,0x00,
+0x20,0xc0,0x80,0xfe,0x20,0xc0,0x08,0xf8,0x00,0xf8,0x08,0x88,0x88,0x88,0x50,0x20,
+/* 32777 0x8009 "耉" */
+0x02,0x02,0x3f,0x02,0xff,0x01,0x07,0x1c,0xe7,0x00,0x1f,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x10,0xe0,0x40,0xfe,0x00,0xf8,0x00,0xf8,0x08,0x88,0x88,0x88,0x88,0x50,0x20,
+/* 32778 0x800a "耊" */
+0x02,0x02,0x3f,0x02,0xff,0x01,0x06,0x1f,0xe4,0x08,0x1f,0x01,0x1f,0x01,0x7f,0x00,
+0x00,0x10,0xe0,0x40,0xfe,0x00,0x00,0xf0,0x00,0x20,0xf0,0x00,0xf0,0x00,0xfc,0x00,
+/* 32779 0x800b "耋" */
+0x02,0x3f,0x02,0xff,0x02,0x0f,0x34,0xc3,0x00,0x7f,0x08,0x1f,0x01,0x1f,0x01,0x7f,
+0x20,0xc0,0x80,0xfe,0x20,0xc0,0x08,0xf8,0x00,0xfc,0x20,0xf0,0x00,0xf0,0x00,0xfc,
+/* 32780 0x800c "而" */
+0x00,0x7f,0x01,0x01,0x02,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x20,0x20,
+0x00,0xfc,0x00,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x28,0x10,
+/* 32781 0x800d "耍" */
+0x00,0xff,0x02,0x04,0x3f,0x24,0x24,0x24,0x22,0x02,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0xa8,0x10,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 32782 0x800e "耎" */
+0x00,0xff,0x02,0x04,0x3f,0x24,0x24,0x24,0x24,0x21,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xa8,0x10,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 32783 0x800f "耏" */
+0x00,0xff,0x04,0x04,0x08,0x7f,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x48,0x41,0x40,
+0x02,0xe2,0x04,0x08,0x10,0xc2,0x42,0x44,0x48,0x50,0x42,0x42,0x44,0x48,0x50,0xa0,
+/* 32784 0x8010 "耐" */
+0x00,0xff,0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x41,0x43,
+0x08,0x88,0x08,0x08,0xfe,0x08,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x28,0x10,
+/* 32785 0x8011 "耑" */
+0x01,0x21,0x21,0x21,0x3f,0x00,0x00,0xff,0x02,0x04,0x3f,0x24,0x24,0x24,0x24,0x20,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xa8,0x10,
+/* 32786 0x8012 "耒" */
+0x01,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 32787 0x8013 "耓" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x38,0x34,0x54,0x50,0x90,0x10,0x10,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 32788 0x8014 "耔" */
+0x10,0x10,0x10,0xfc,0x10,0x78,0x10,0xfd,0x10,0x38,0x34,0x54,0x90,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 32789 0x8015 "耕" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x10,0xfe,0x13,0x38,0x34,0x54,0x50,0x91,0x11,0x12,
+0x88,0x88,0x88,0x88,0xfc,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 32790 0x8016 "耖" */
+0x10,0x10,0x10,0xfc,0x10,0x78,0x11,0xfd,0x12,0x38,0x34,0x54,0x90,0x10,0x10,0x13,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 32791 0x8017 "耗" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x38,0x35,0x54,0x50,0x90,0x10,0x10,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 32792 0x8018 "耘" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x11,0xfe,0x10,0x38,0x34,0x54,0x50,0x91,0x10,0x10,
+0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x48,0x84,0x84,0xfe,0x82,0x02,
+/* 32793 0x8019 "耙" */
+0x10,0x10,0x11,0xfd,0x11,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x91,0x11,0x10,0x10,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32794 0x801a "耚" */
+0x10,0x10,0x10,0xfd,0x11,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x91,0x12,0x12,0x14,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 32795 0x801b "耛" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x11,0xfe,0x10,0x38,0x34,0x54,0x50,0x90,0x10,0x10,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 32796 0x801c "耜" */
+0x10,0x11,0x11,0xfd,0x11,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x91,0x11,0x11,0x11,
+0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32797 0x801d "耝" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x38,0x34,0x54,0x50,0x90,0x13,0x10,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 32798 0x801e "耞" */
+0x11,0x11,0x11,0xfd,0x13,0x79,0x11,0xfd,0x11,0x39,0x35,0x55,0x91,0x12,0x13,0x14,
+0x00,0x00,0x00,0x1c,0xd4,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x54,0x80,
+/* 32799 0x801f "耟" */
+0x10,0x11,0x11,0xff,0x11,0x7d,0x11,0xff,0x11,0x39,0x35,0x55,0x51,0x91,0x11,0x10,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 32800 0x8020 "耠" */
+0x10,0x10,0x10,0xfc,0x11,0x7a,0x11,0xfc,0x10,0x39,0x35,0x55,0x91,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32801 0x8021 "耡" */
+0x10,0x10,0x13,0xfe,0x12,0x7a,0x13,0xfe,0x12,0x3b,0x36,0x52,0x52,0x93,0x16,0x10,
+0x08,0x08,0xc8,0x48,0x5e,0x4a,0xca,0x4a,0x4a,0xca,0x4a,0x4a,0x6a,0xd2,0x12,0x26,
+/* 32802 0x8022 "耢" */
+0x10,0x10,0x13,0xfc,0x10,0x7b,0x12,0xfc,0x10,0x3b,0x34,0x54,0x90,0x11,0x12,0x14,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x44,0x40,0xfc,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 32803 0x8023 "耣" */
+0x10,0x10,0x10,0xfc,0x11,0x7a,0x10,0xfd,0x11,0x39,0x35,0x55,0x91,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 32804 0x8024 "耤" */
+0x10,0x10,0x10,0xfd,0x10,0x78,0x11,0xfc,0x10,0x38,0x34,0x54,0x90,0x10,0x10,0x10,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 32805 0x8025 "耥" */
+0x10,0x11,0x10,0xfc,0x10,0x7b,0x12,0xfe,0x12,0x3a,0x36,0x52,0x52,0x92,0x12,0x12,
+0x20,0x24,0xa4,0xa8,0x20,0xfe,0x02,0x02,0xfa,0x8a,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 32806 0x8026 "耦" */
+0x11,0x11,0x11,0xfd,0x11,0x79,0x11,0xfc,0x10,0x3b,0x36,0x52,0x52,0x92,0x12,0x12,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 32807 0x8027 "耧" */
+0x10,0x11,0x10,0xfc,0x13,0x78,0x11,0xfe,0x10,0x3b,0x34,0x51,0x51,0x90,0x11,0x16,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 32808 0x8028 "耨" */
+0x10,0x11,0x11,0xfd,0x11,0x79,0x11,0xfd,0x11,0x39,0x35,0x51,0x51,0x92,0x12,0x14,
+0x00,0xfe,0x00,0x7e,0x00,0xfe,0x54,0x48,0x64,0x42,0x08,0xfe,0x48,0x28,0x08,0x18,
+/* 32809 0x8029 "耩" */
+0x10,0x10,0x13,0xfc,0x11,0x78,0x13,0xfc,0x11,0x39,0x35,0x51,0x53,0x91,0x11,0x11,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 32810 0x802a "耪" */
+0x10,0x10,0x13,0xfd,0x10,0x7b,0x12,0xfc,0x10,0x3b,0x34,0x54,0x90,0x11,0x11,0x12,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 32811 0x802b "耫" */
+0x10,0x13,0x10,0xfd,0x10,0x7b,0x10,0xfd,0x11,0x39,0x35,0x55,0x91,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32812 0x802c "耬" */
+0x10,0x11,0x11,0xff,0x11,0x79,0x10,0xfd,0x11,0x39,0x34,0x55,0x90,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 32813 0x802d "耭" */
+0x11,0x11,0x12,0xff,0x11,0x7a,0x13,0xfd,0x13,0x39,0x35,0x51,0x52,0x92,0x12,0x14,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 32814 0x802e "耮" */
+0x10,0x11,0x10,0xfe,0x10,0x7d,0x11,0xff,0x10,0x38,0x34,0x54,0x50,0x90,0x10,0x11,
+0x48,0x6a,0xdc,0x48,0xb4,0x22,0xfe,0x02,0x20,0x20,0xfc,0x24,0x44,0x44,0x94,0x08,
+/* 32815 0x802f "耯" */
+0x10,0x13,0x10,0xfc,0x11,0x7b,0x11,0xfd,0x11,0x39,0x35,0x55,0x93,0x10,0x10,0x13,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 32816 0x8030 "耰" */
+0x13,0x10,0x11,0xfd,0x11,0x79,0x17,0xfc,0x12,0x3a,0x34,0x50,0x51,0x92,0x10,0x13,
+0xfc,0x40,0xf8,0x08,0xf8,0x08,0xfe,0x42,0xa4,0x8a,0x7a,0x80,0xf8,0x88,0x70,0x8e,
+/* 32817 0x8031 "耱" */
+0x10,0x10,0x13,0xfe,0x13,0x7a,0x12,0xff,0x12,0x3b,0x36,0x52,0x52,0x93,0x14,0x18,
+0x40,0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0xfe,0x20,0x7c,0xc4,0x44,0x7c,0x44,
+/* 32818 0x8032 "耲" */
+0x10,0x10,0x13,0xfc,0x11,0x79,0x11,0xfc,0x11,0x38,0x35,0x54,0x90,0x11,0x12,0x10,
+0x40,0x20,0xfe,0x00,0xfc,0x54,0xfc,0x20,0x22,0x8c,0x22,0x54,0xc8,0x44,0x52,0x60,
+/* 32819 0x8033 "耳" */
+0x00,0x7f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x17,0xf8,0x00,0x00,0x00,
+0x00,0xfc,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x3e,0xd0,0x10,0x10,0x10,0x10,
+/* 32820 0x8034 "耴" */
+0x00,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x27,0xfa,0x42,0x02,0x02,0x02,
+0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x22,0x22,0x22,0x1e,0x00,
+/* 32821 0x8035 "耵" */
+0x00,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x27,0xfa,0x42,0x02,0x02,0x02,
+0x00,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x08,0x08,0x08,0x28,0x10,
+/* 32822 0x8036 "耶" */
+0x00,0xff,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x27,0xfa,0x42,0x02,0x02,0x02,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0xa2,0x34,0x28,0x20,0x20,0x20,
+/* 32823 0x8037 "耷" */
+0x01,0x01,0x7f,0x02,0x04,0x08,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x09,0x7e,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x20,0xf8,0x26,0xe0,0x20,0xe0,0x20,0xf8,0x20,0x20,0x20,
+/* 32824 0x8038 "耸" */
+0x08,0x08,0x14,0x22,0x41,0x00,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,0x00,
+0x20,0x20,0x50,0x88,0x04,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x3e,0xd0,0x10,0x10,
+/* 32825 0x8039 "耹" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x25,0x3e,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 32826 0x803a "耺" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x25,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x05,0x04,0x04,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x84,0xfe,0x82,0x00,
+/* 32827 0x803b "耻" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x05,0x04,
+0x10,0x10,0x10,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 32828 0x803c "耼" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x00,0x7c,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0x44,0x54,0x48,
+/* 32829 0x803d "耽" */
+0x00,0xfc,0x48,0x4b,0x7a,0x4c,0x48,0x78,0x48,0x48,0x4c,0x79,0xc9,0x0a,0x0c,0x08,
+0x40,0x40,0x40,0xfc,0x44,0x48,0x40,0x40,0xa0,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 32830 0x803e "耾" */
+0x00,0xff,0x24,0x24,0x3d,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf5,0x45,0x06,0x04,0x04,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x50,0x90,0x90,0xa0,0x28,0x44,0x44,0xfe,0x42,
+/* 32831 0x803f "耿" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3d,0x24,0x24,0x2e,0xf4,0x44,0x04,0x05,0x06,
+0x20,0x20,0x20,0x24,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32832 0x8040 "聀" */
+0x00,0xff,0x24,0x24,0x3c,0x25,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x05,0x04,
+0x48,0x44,0x44,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 32833 0x8041 "聁" */
+0x00,0xfc,0x48,0x48,0x79,0x49,0x4a,0x7d,0x48,0x48,0x4c,0x78,0xc9,0x09,0x0a,0x0c,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 32834 0x8042 "聂" */
+0x00,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,0x3e,0x02,0x22,0x14,0x08,0x34,0xc3,
+0x00,0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 32835 0x8043 "聃" */
+0x00,0xff,0x24,0x25,0x3d,0x25,0x25,0x3d,0x25,0x25,0x2f,0xf5,0x45,0x05,0x05,0x05,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 32836 0x8044 "聄" */
+0x00,0xfc,0x48,0x48,0x79,0x4a,0x48,0x78,0x49,0x48,0x4c,0x78,0xc9,0x08,0x08,0x0b,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 32837 0x8045 "聅" */
+0x00,0xfc,0x48,0x48,0x79,0x4a,0x48,0x78,0x4b,0x48,0x4c,0x78,0xc8,0x08,0x09,0x0a,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32838 0x8046 "聆" */
+0x00,0xff,0x24,0x24,0x3c,0x25,0x26,0x3c,0x25,0x24,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 32839 0x8047 "聇" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x07,0x04,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 32840 0x8048 "聈" */
+0x00,0xfc,0x48,0x49,0x79,0x4a,0x4b,0x78,0x49,0x49,0x4e,0x7b,0xc8,0x08,0x08,0x08,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 32841 0x8049 "聉" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,
+/* 32842 0x804a "聊" */
+0x00,0xfc,0x4b,0x4a,0x7a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4f,0x7a,0xc8,0x08,0x09,0x0a,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 32843 0x804b "聋" */
+0x04,0x04,0xff,0x09,0x11,0x66,0x00,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,0x00,
+0x80,0x40,0xfe,0x40,0x84,0xfc,0x00,0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32844 0x804c "职" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x05,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 32845 0x804d "聍" */
+0x00,0xfc,0x48,0x4b,0x7a,0x4c,0x48,0x78,0x4b,0x48,0x4c,0x78,0xc8,0x08,0x08,0x08,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 32846 0x804e "聎" */
+0x00,0xff,0x24,0x25,0x3c,0x24,0x24,0x3c,0x24,0x25,0x2e,0xf4,0x44,0x04,0x05,0x06,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 32847 0x804f "聏" */
+0x00,0xfd,0x48,0x48,0x78,0x49,0x49,0x79,0x49,0x49,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x00,0xfc,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 32848 0x8050 "聐" */
+0x00,0xfc,0x48,0x4b,0x78,0x48,0x49,0x78,0x48,0x49,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32849 0x8051 "聑" */
+0x00,0xfd,0x48,0x48,0x78,0x48,0x48,0x78,0x48,0x48,0x4c,0x78,0xcb,0x08,0x08,0x08,
+0x00,0xfe,0x88,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x9e,0xe8,0x08,0x08,0x08,
+/* 32850 0x8052 "聒" */
+0x00,0xff,0x24,0x24,0x3c,0x25,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x04,
+0x08,0x1c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 32851 0x8053 "聓" */
+0x00,0x7d,0x11,0x11,0x1d,0xf2,0x04,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,0x00,
+0x00,0xf0,0x10,0x90,0x52,0x0e,0x00,0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32852 0x8054 "联" */
+0x00,0xfc,0x48,0x48,0x79,0x48,0x48,0x78,0x4b,0x48,0x4c,0x78,0xc8,0x08,0x09,0x0a,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32853 0x8055 "聕" */
+0x00,0xfd,0x49,0x49,0x79,0x4a,0x48,0x7b,0x48,0x48,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 32854 0x8056 "聖" */
+0x00,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0x02,0x7f,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x00,0x7c,0x44,0x44,0x44,0xc4,0x7c,0x44,0x00,0xfc,0x00,0xf8,0x00,0x00,0xfe,
+/* 32855 0x8057 "聗" */
+0x00,0xfc,0x48,0x4b,0x78,0x48,0x49,0x79,0x49,0x4a,0x4c,0x78,0xc8,0x08,0x09,0x0a,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 32856 0x8058 "聘" */
+0x00,0xfc,0x49,0x49,0x79,0x49,0x49,0x78,0x4b,0x48,0x4d,0x79,0xc8,0x08,0x08,0x08,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 32857 0x8059 "聙" */
+0x00,0xfc,0x4b,0x48,0x79,0x48,0x4b,0x78,0x49,0x49,0x4d,0x79,0xc9,0x09,0x09,0x09,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 32858 0x805a "聚" */
+0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0x00,0x7f,0x09,0x11,0x63,0x05,0x19,0xe1,
+0x00,0x7c,0x04,0x28,0x10,0xa8,0x44,0x00,0xf8,0x00,0x04,0x88,0x50,0x20,0x18,0x06,
+/* 32859 0x805b "聛" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf5,0x44,0x04,0x04,0x04,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 32860 0x805c "聜" */
+0x00,0xff,0x24,0x25,0x3d,0x26,0x24,0x3d,0x24,0x24,0x2e,0xf4,0x44,0x04,0x05,0x04,
+0x20,0x10,0x10,0xfe,0x02,0x54,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32861 0x805d "聝" */
+0x00,0xfc,0x48,0x49,0x78,0x48,0x49,0x79,0x49,0x49,0x4d,0x78,0xc8,0x0b,0x08,0x08,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xca,0x1a,0x26,0x42,
+/* 32862 0x805e "聞" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x44,0x47,0x44,0x47,0x44,0x5f,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x44,0xc4,0x44,0xc4,0x74,0xc4,0x54,0x48,
+/* 32863 0x805f "聟" */
+0x20,0x3e,0x48,0xff,0x14,0x22,0x40,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32864 0x8060 "聠" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x25,0x24,0x2e,0xf4,0x44,0x04,0x04,0x05,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 32865 0x8061 "聡" */
+0x00,0xfc,0x49,0x49,0x7a,0x4c,0x49,0x7b,0x48,0x48,0x4c,0x7a,0xca,0x0a,0x0c,0x08,
+0x90,0x90,0x08,0x48,0x44,0x92,0x08,0xfc,0x44,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 32866 0x8062 "聢" */
+0x00,0xff,0x24,0x24,0x3d,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x05,0x06,
+0x20,0x10,0xfe,0x82,0x04,0x00,0xfe,0x10,0x10,0x90,0x9e,0x90,0x90,0xd0,0x3e,0x00,
+/* 32867 0x8063 "聣" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x05,
+0x00,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 32868 0x8064 "聤" */
+0x00,0xfc,0x4b,0x48,0x79,0x49,0x49,0x78,0x4b,0x4a,0x4d,0x78,0xc8,0x08,0x08,0x08,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 32869 0x8065 "聥" */
+0x00,0xfc,0x4b,0x48,0x79,0x49,0x49,0x79,0x48,0x4b,0x4e,0x7a,0xca,0x0a,0x0a,0x0a,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 32870 0x8066 "聦" */
+0x00,0xfc,0x48,0x49,0x7a,0x48,0x49,0x7a,0x48,0x49,0x4c,0x78,0xca,0x0a,0x0c,0x08,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 32871 0x8067 "聧" */
+0x00,0xfd,0x48,0x4a,0x79,0x48,0x49,0x7a,0x48,0x48,0x4d,0x78,0xc8,0x08,0x09,0x0a,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 32872 0x8068 "聨" */
+0x01,0xfd,0x4a,0x4b,0x79,0x4a,0x4b,0x78,0x48,0x48,0x4f,0x78,0xc8,0x09,0x09,0x0a,
+0x08,0x4a,0x52,0x9c,0x08,0x52,0xde,0x42,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,
+/* 32873 0x8069 "聩" */
+0x00,0xfc,0x49,0x49,0x79,0x48,0x4b,0x78,0x49,0x49,0x4d,0x79,0xc9,0x08,0x08,0x0b,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 32874 0x806a "聪" */
+0x00,0xfc,0x48,0x49,0x79,0x49,0x49,0x79,0x48,0x48,0x4c,0x79,0xc9,0x09,0x0a,0x08,
+0x88,0x48,0x50,0xfc,0x04,0x04,0x04,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 32875 0x806b "聫" */
+0x01,0xfd,0x4a,0x4b,0x79,0x4a,0x4b,0x78,0x48,0x48,0x4f,0x78,0xc8,0x08,0x09,0x0a,
+0x08,0x4a,0x52,0x9c,0x08,0x52,0xde,0x42,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 32876 0x806c "聬" */
+0x00,0xfc,0x49,0x4a,0x7c,0x49,0x48,0x78,0x4b,0x48,0x4e,0x79,0xca,0x08,0x09,0x08,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 32877 0x806d "聭" */
+0x00,0xff,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x2e,0xf4,0x44,0x04,0x04,0x05,
+0x10,0x20,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x20,0x24,0x5a,0x5e,0x90,0x92,0x0e,
+/* 32878 0x806e "聮" */
+0x00,0xfc,0x49,0x49,0x7a,0x4b,0x48,0x79,0x49,0x4b,0x4c,0x78,0xc9,0x09,0x0a,0x08,
+0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x4a,0xde,0x42,0x00,0x54,0x2a,0x2a,0x00,
+/* 32879 0x806f "聯" */
+0x01,0xfd,0x4a,0x4b,0x79,0x4a,0x4b,0x78,0x48,0x4a,0x4e,0x7b,0xc8,0x08,0x08,0x09,
+0x08,0x4a,0x52,0x9c,0x08,0x52,0xde,0x42,0x90,0x92,0x92,0x9e,0x90,0x90,0x90,0x10,
+/* 32880 0x8070 "聰" */
+0x00,0xfc,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x4c,0x78,0xca,0x0a,0x0c,0x08,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 32881 0x8071 "聱" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x7f,0x88,0x0f,0x08,0xff,0x00,0x00,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0xfe,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32882 0x8072 "聲" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x40,0xff,0x08,0x0f,0x08,0xff,0x00,0x00,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xfe,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32883 0x8073 "聳" */
+0x11,0x21,0xca,0x14,0x32,0xd2,0x15,0x18,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,
+0x10,0x10,0xa8,0x44,0x78,0x40,0xfc,0x00,0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,
+/* 32884 0x8074 "聴" */
+0x00,0xfc,0x4b,0x48,0x78,0x49,0x49,0x79,0x49,0x48,0x4c,0x7a,0xca,0x0c,0x08,0x08,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x54,0x54,0xfc,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 32885 0x8075 "聵" */
+0x00,0xfd,0x49,0x49,0x78,0x4b,0x48,0x79,0x49,0x49,0x4d,0x79,0xc9,0x09,0x08,0x09,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 32886 0x8076 "聶" */
+0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,0x7e,0x24,0x3c,0x24,0x3c,0x26,0xfd,0x04,
+0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,0xfc,0x48,0x78,0x48,0x78,0x4e,0xf8,0x08,
+/* 32887 0x8077 "職" */
+0x01,0xfc,0x4b,0x48,0x7a,0x49,0x4f,0x78,0x4b,0x4a,0x4e,0x7b,0xca,0x0a,0x0b,0x08,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 32888 0x8078 "聸" */
+0x00,0xfc,0x49,0x4b,0x79,0x49,0x49,0x79,0x49,0x49,0x4d,0x79,0xc9,0x0a,0x0a,0x0c,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 32889 0x8079 "聹" */
+0x00,0xfc,0x4b,0x4a,0x79,0x49,0x4a,0x78,0x49,0x49,0x4f,0x78,0xc9,0x08,0x08,0x08,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 32890 0x807a "聺" */
+0x00,0xfc,0x4b,0x4a,0x79,0x49,0x4a,0x7d,0x4a,0x49,0x4e,0x79,0xc8,0x09,0x0a,0x08,
+0x40,0x20,0xfe,0x02,0x10,0xde,0x52,0x54,0x88,0x74,0x02,0xfc,0x20,0x24,0x22,0x60,
+/* 32891 0x807b "聻" */
+0x42,0x3f,0x8a,0x4f,0x2a,0x5f,0x82,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,0x00,
+0x04,0xd8,0x90,0x9e,0x94,0xd4,0x24,0xfc,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32892 0x807c "聼" */
+0x00,0x78,0x0b,0x10,0xfd,0x49,0x49,0x79,0x48,0x7b,0x48,0x5c,0xea,0x4a,0x0c,0x08,
+0x20,0x20,0xfe,0x20,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 32893 0x807d "聽" */
+0x00,0xfc,0x4b,0x78,0x49,0x79,0x49,0xf9,0x08,0xfb,0x28,0x78,0x2a,0xfa,0x0c,0x08,
+0x20,0x20,0xfe,0x20,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 32894 0x807e "聾" */
+0x08,0x3e,0x14,0xff,0x22,0x3e,0x22,0x26,0x00,0x7f,0x08,0x0f,0x08,0xff,0x00,0x00,
+0x40,0x7c,0x40,0x78,0x08,0x78,0x42,0x3e,0x00,0xfc,0x20,0xe0,0x3e,0xe0,0x20,0x20,
+/* 32895 0x807f "聿" */
+0x01,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x01,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 32896 0x8080 "肀" */
+0x01,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 32897 0x8081 "肁" */
+0x01,0x00,0x3f,0x20,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x20,0x4f,0x40,0xbf,0x00,
+0x00,0x80,0xfc,0x04,0xfc,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x80,0xfc,0x80,0xfe,0x80,
+/* 32898 0x8082 "肂" */
+0x00,0x00,0xfd,0x20,0x23,0x3c,0x45,0x44,0x64,0x95,0x08,0x08,0x13,0x20,0x40,0x80,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 32899 0x8083 "肃" */
+0x01,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x21,0x25,0x25,0x25,0x29,0x41,0x41,0x81,
+0x00,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x08,0x48,0x28,0x28,0x28,0x08,0x08,0x08,
+/* 32900 0x8084 "肄" */
+0x40,0x4c,0x70,0x44,0x45,0x3c,0x40,0x7c,0x90,0x11,0xfe,0x10,0x29,0x24,0x44,0x80,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 32901 0x8085 "肅" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x05,0x25,0x3d,0x21,0x3f,0x21,0x3d,0x25,0x45,0x81,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x40,0x48,0x78,0x08,0xf8,0x08,0x78,0x48,0x48,0x08,
+/* 32902 0x8086 "肆" */
+0x00,0x3e,0x20,0x20,0x3d,0x20,0x20,0x3c,0x20,0x21,0xfe,0x20,0x25,0x42,0xfe,0x42,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 32903 0x8087 "肇" */
+0x08,0x3e,0x22,0x3e,0x20,0x41,0x9f,0x01,0xff,0x01,0x1f,0x01,0x3f,0x01,0xff,0x01,
+0x40,0x7e,0xa8,0x10,0x6e,0x00,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,
+/* 32904 0x8088 "肈" */
+0x08,0x3e,0x22,0x3e,0x20,0x41,0x9f,0x01,0xff,0x01,0x1f,0x01,0x3f,0x01,0xff,0x01,
+0x24,0x3e,0xe8,0x12,0x2a,0x46,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,
+/* 32905 0x8089 "肉" */
+0x01,0x01,0x01,0x7f,0x41,0x42,0x44,0x49,0x51,0x41,0x42,0x42,0x44,0x48,0x40,0x40,
+0x00,0x00,0x00,0xfc,0x04,0x84,0x44,0x24,0x04,0x04,0x84,0x44,0x44,0x04,0x14,0x08,
+/* 32906 0x808a "肊" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x42,0x4a,0x84,
+0x00,0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0x40,0x40,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 32907 0x808b "肋" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x42,0x4a,0x85,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x22,0x42,0x42,0x42,0x82,0x94,0x08,
+/* 32908 0x808c "肌" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 32909 0x808d "肍" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x8a,0x8a,0x06,0x00,
+/* 32910 0x808e "肎" */
+0x00,0x7f,0x40,0x80,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x02,0x04,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32911 0x808f "肏" */
+0x06,0x01,0x02,0x0c,0x31,0xc1,0x3f,0x22,0x24,0x29,0x21,0x22,0x24,0x20,0x20,0x20,
+0x00,0x00,0x80,0x60,0x18,0x06,0xf8,0x88,0x48,0x28,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 32912 0x8090 "肐" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x24,0x3c,0x24,0x24,0x25,0x45,0x54,0x88,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 32913 0x8091 "肑" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 32914 0x8092 "肒" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0xc8,0x48,0x68,0x5a,0x8a,0x8a,0x06,0x02,
+/* 32915 0x8093 "肓" */
+0x02,0x01,0xff,0x10,0x10,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32916 0x8094 "肔" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x27,0x25,0x3d,0x25,0x25,0x25,0x45,0x54,0x88,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 32917 0x8095 "肕" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 32918 0x8096 "肖" */
+0x01,0x21,0x11,0x09,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,
+0x00,0x08,0x10,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 32919 0x8097 "肗" */
+0x00,0x3c,0x24,0x24,0x27,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x8b,
+0x40,0x40,0x40,0x40,0xfe,0x88,0x88,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x88,0x04,
+/* 32920 0x8098 "肘" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x28,0x10,
+/* 32921 0x8099 "肙" */
+0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,
+0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 32922 0x809a "肚" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x57,0x88,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32923 0x809b "肛" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x57,0x88,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32924 0x809c "肜" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x42,0x4a,0x84,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x20,0xc0,
+/* 32925 0x809d "肝" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x27,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 32926 0x809e "肞" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 32927 0x809f "肟" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 32928 0x80a0 "肠" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x25,0x25,0x26,0x44,0x54,0x89,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 32929 0x80a1 "股" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x26,0x25,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x8b,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 32930 0x80a2 "肢" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8e,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 32931 0x80a3 "肣" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 32932 0x80a4 "肤" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x27,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32933 0x80a5 "肥" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x54,0x88,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 32934 0x80a6 "肦" */
+0x00,0x3c,0x24,0x24,0x34,0x2c,0x25,0x26,0x2c,0x34,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 32935 0x80a7 "肧" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x44,0x54,0x88,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 32936 0x80a8 "肨" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x25,0x24,0x3c,0x24,0x27,0x24,0x44,0x54,0x88,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 32937 0x80a9 "肩" */
+0x01,0x00,0x1f,0x10,0x10,0x1f,0x10,0x17,0x14,0x17,0x14,0x27,0x24,0x44,0x84,0x04,
+0x00,0x80,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 32938 0x80aa "肪" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 32939 0x80ab "肫" */
+0x00,0x78,0x48,0x4b,0x48,0x7a,0x4a,0x4a,0x4a,0x7b,0x48,0x48,0x48,0x48,0x48,0x98,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 32940 0x80ac "肬" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 32941 0x80ad "肭" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 32942 0x80ae "肮" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 32943 0x80af "肯" */
+0x01,0x01,0x11,0x11,0x11,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32944 0x80b0 "肰" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32945 0x80b1 "肱" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x48,0x48,0x79,0x49,0x4a,0x4a,0x4c,0x49,0x98,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 32946 0x80b2 "育" */
+0x02,0x01,0xff,0x08,0x10,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x00,0x10,0xf8,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32947 0x80b3 "肳" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x44,0x55,0x88,
+0x80,0x80,0x80,0xfc,0x54,0x54,0x54,0x94,0x94,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 32948 0x80b4 "肴" */
+0x18,0x06,0x01,0x06,0x3a,0x02,0xff,0x04,0x0f,0x18,0x2f,0x48,0x8f,0x08,0x08,0x08,
+0x18,0x60,0x80,0x60,0x18,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 32949 0x80b5 "肵" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 32950 0x80b6 "肶" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x88,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 32951 0x80b7 "肷" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32952 0x80b8 "肸" */
+0x00,0x3c,0x24,0x24,0x25,0x3d,0x26,0x24,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x88,
+0x10,0x90,0x90,0x88,0x08,0x04,0x24,0x22,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 32953 0x80b9 "肹" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x48,0x48,0x84,0x84,0x02,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 32954 0x80ba "肺" */
+0x00,0x3c,0x24,0x27,0x24,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x44,0x54,0x88,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 32955 0x80bb "肻" */
+0x01,0x01,0x01,0x01,0x3f,0x20,0x40,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x00,0x00,0xfc,0x04,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32956 0x80bc "肼" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x48,0x4f,0x78,0x48,0x48,0x48,0x49,0x49,0x9a,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 32957 0x80bd "肽" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 32958 0x80be "肾" */
+0x04,0x25,0x24,0x24,0x24,0x24,0x27,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 32959 0x80bf "肿" */
+0x00,0x3c,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 32960 0x80c0 "胀" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x27,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x84,0x84,0x88,0x90,0xa0,0x80,0xfe,0xa0,0x90,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 32961 0x80c1 "胁" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x4a,0x4a,0x7c,0x48,0x48,0x49,0x49,0x4a,0x9c,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x98,0x94,0x92,0x92,0x90,0x10,0x10,0x50,0x20,
+/* 32962 0x80c2 "胂" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x44,0x54,0x88,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 32963 0x80c3 "胃" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32964 0x80c4 "胄" */
+0x01,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 32965 0x80c5 "胅" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x26,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 32966 0x80c6 "胆" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x88,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 32967 0x80c7 "胇" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x25,0x25,0x25,0x3d,0x24,0x24,0x24,0x44,0x54,0x89,
+0x50,0x50,0x50,0xfc,0x54,0x54,0xfc,0x50,0x50,0xfe,0x52,0x52,0x5a,0x94,0x90,0x10,
+/* 32968 0x80c8 "胈" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x3c,0x24,0x25,0x25,0x46,0x54,0x88,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 32969 0x80c9 "胉" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x10,0x10,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 32970 0x80ca "胊" */
+0x00,0x3c,0x25,0x25,0x36,0x2c,0x25,0x25,0x2d,0x35,0x25,0x25,0x24,0x44,0x54,0x88,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 32971 0x80cb "胋" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 32972 0x80cc "背" */
+0x04,0x04,0x7c,0x04,0x1c,0xe4,0x40,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x80,0x98,0xe0,0x84,0x84,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 32973 0x80cd "胍" */
+0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 32974 0x80ce "胎" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 32975 0x80cf "胏" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x24,0x3c,0x24,0x25,0x26,0x44,0x54,0x88,
+0x20,0x20,0x2e,0xf0,0x20,0x20,0x20,0xfe,0x22,0x62,0xa2,0x2a,0x24,0x20,0x20,0x20,
+/* 32976 0x80d0 "胐" */
+0x00,0x3c,0x25,0x25,0x35,0x2d,0x25,0x24,0x2c,0x35,0x25,0x25,0x25,0x45,0x55,0x88,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 32977 0x80d1 "胑" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x89,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 32978 0x80d2 "胒" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x80,0xa0,0xa2,0xa4,0xb8,0xa0,0xa2,0x22,0x1e,0x00,
+/* 32979 0x80d3 "胓" */
+0x00,0x3d,0x24,0x24,0x25,0x3c,0x24,0x24,0x27,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 32980 0x80d4 "胔" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x01,0x3f,0x22,0x24,0x29,0x21,0x22,0x24,0x20,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0x00,0xf8,0x88,0x48,0x28,0x08,0x88,0x48,0x18,
+/* 32981 0x80d5 "胕" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x44,0x44,0x44,0x84,0xbe,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 32982 0x80d6 "胖" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x27,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 32983 0x80d7 "胗" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x25,0x3c,0x24,0x24,0x25,0x44,0x54,0x8b,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 32984 0x80d8 "胘" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x45,0x54,0x88,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 32985 0x80d9 "胙" */
+0x00,0x3c,0x24,0x24,0x25,0x3d,0x26,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 32986 0x80da "胚" */
+0x00,0x7b,0x48,0x48,0x48,0x78,0x48,0x49,0x4a,0x7c,0x48,0x48,0x48,0x48,0x4f,0x98,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 32987 0x80db "胛" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 32988 0x80dc "胜" */
+0x00,0x78,0x49,0x49,0x49,0x79,0x4a,0x48,0x48,0x79,0x48,0x48,0x48,0x48,0x4b,0x98,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 32989 0x80dd "胝" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 32990 0x80de "胞" */
+0x00,0x78,0x49,0x49,0x4a,0x7d,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x48,0x98,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 32991 0x80df "胟" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x27,0x25,0x3d,0x25,0x25,0x25,0x44,0x54,0x88,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 32992 0x80e0 "胠" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x24,0x27,0x24,0x3c,0x24,0x24,0x24,0x45,0x54,0x88,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 32993 0x80e1 "胡" */
+0x08,0x08,0x08,0x08,0x7f,0x08,0x08,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x01,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x84,0x84,0x14,0x08,
+/* 32994 0x80e2 "胢" */
+0x00,0x3c,0x25,0x24,0x24,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x44,0x54,0x88,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 32995 0x80e3 "胣" */
+0x00,0x78,0x48,0x49,0x4a,0x79,0x49,0x49,0x4b,0x79,0x49,0x49,0x49,0x49,0x48,0x98,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 32996 0x80e4 "胤" */
+0x01,0x22,0x24,0x27,0x21,0x22,0x27,0x20,0x27,0x24,0x27,0x24,0x27,0x44,0x44,0x84,
+0x00,0x08,0x48,0x88,0x08,0x48,0xc8,0x08,0xc8,0x48,0xc8,0x48,0xca,0x4a,0x4a,0xc6,
+/* 32997 0x80e5 "胥" */
+0x7f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0xfc,0x04,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 32998 0x80e6 "胦" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x3f,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 32999 0x80e7 "胧" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x48,0x48,0x78,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0xa8,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 33000 0x80e8 "胨" */
+0x00,0x78,0x48,0x4f,0x48,0x79,0x49,0x4a,0x4b,0x78,0x49,0x49,0x4a,0x4c,0x48,0x98,
+0x40,0x40,0x40,0xfe,0x80,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 33001 0x80e9 "胩" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x27,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x40,0x40,0x50,0x48,0x44,0x40,0x40,0x40,
+/* 33002 0x80ea "胪" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x45,0x55,0x8a,
+0x20,0x20,0x3c,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,0x80,0x80,0x00,0x00,0x00,
+/* 33003 0x80eb "胫" */
+0x00,0x79,0x48,0x48,0x48,0x78,0x48,0x4b,0x48,0x79,0x48,0x48,0x48,0x48,0x4b,0x98,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33004 0x80ec "胬" */
+0x10,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,0x01,0x3f,0x22,0x24,0x21,0x22,0x24,0x20,
+0x00,0x00,0xfc,0x44,0x28,0x10,0x28,0xc6,0x00,0xf8,0x88,0x48,0x08,0x88,0x48,0x18,
+/* 33005 0x80ed "胭" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 33006 0x80ee "胮" */
+0x00,0x78,0x48,0x49,0x4a,0x78,0x49,0x4e,0x48,0x79,0x48,0x4a,0x4b,0x48,0x48,0x98,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 33007 0x80ef "胯" */
+0x00,0x3c,0x25,0x24,0x24,0x3d,0x26,0x24,0x27,0x3c,0x24,0x25,0x24,0x44,0x54,0x88,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 33008 0x80f0 "胰" */
+0x00,0x78,0x4f,0x48,0x4b,0x78,0x4b,0x4a,0x4b,0x78,0x48,0x48,0x48,0x49,0x4a,0x9c,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xa8,0xa0,0x10,0x08,0x06,
+/* 33009 0x80f1 "胱" */
+0x00,0x78,0x4a,0x49,0x49,0x78,0x4f,0x48,0x48,0x78,0x48,0x48,0x49,0x49,0x4a,0x9c,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 33010 0x80f2 "胲" */
+0x00,0x78,0x4b,0x48,0x48,0x78,0x49,0x4b,0x48,0x78,0x48,0x49,0x4a,0x48,0x48,0x9b,
+0x40,0x20,0xfe,0x40,0x90,0x90,0x24,0xe4,0x44,0x48,0x88,0x10,0x30,0x48,0x84,0x04,
+/* 33011 0x80f3 "胳" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 33012 0x80f4 "胴" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 33013 0x80f5 "胵" */
+0x00,0x3d,0x24,0x24,0x24,0x3d,0x25,0x24,0x24,0x3c,0x25,0x24,0x24,0x44,0x57,0x88,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 33014 0x80f6 "胶" */
+0x00,0x78,0x48,0x4b,0x48,0x78,0x49,0x4a,0x48,0x78,0x48,0x48,0x48,0x48,0x48,0x9b,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 33015 0x80f7 "胷" */
+0x10,0x1f,0x20,0x54,0x93,0x14,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x54,0x94,0x54,0xf4,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 33016 0x80f8 "胸" */
+0x01,0x79,0x49,0x49,0x4a,0x7a,0x4d,0x48,0x4a,0x7a,0x4b,0x4a,0x4b,0x48,0x48,0x98,
+0x00,0x00,0x00,0xfe,0x02,0x02,0x12,0xa2,0x4a,0xaa,0x1a,0x0a,0xfa,0x02,0x14,0x08,
+/* 33017 0x80f9 "胹" */
+0x00,0x3d,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfc,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 33018 0x80fa "胺" */
+0x00,0x78,0x48,0x4b,0x4a,0x7c,0x48,0x4b,0x48,0x78,0x49,0x48,0x48,0x48,0x48,0x9b,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 33019 0x80fb "胻" */
+0x00,0x78,0x49,0x4a,0x4c,0x78,0x49,0x4b,0x4d,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x80,0x80,0x3c,0x00,0x80,0x80,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 33020 0x80fc "胼" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x54,0x89,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 33021 0x80fd "能" */
+0x10,0x24,0x42,0xff,0x01,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x4a,0x44,
+0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,
+/* 33022 0x80fe "胾" */
+0x08,0x08,0x7f,0x08,0xff,0x00,0x08,0x7f,0x49,0x55,0x6b,0x49,0x55,0x63,0x45,0x42,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 33023 0x80ff "胿" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x27,0x24,0x24,0x3c,0x25,0x24,0x24,0x44,0x57,0x88,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 33024 0x8100 "脀" */
+0x1f,0x00,0x7d,0x05,0x09,0x35,0xc2,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33025 0x8101 "脁" */
+0x00,0x3c,0x24,0x25,0x34,0x2c,0x24,0x24,0x2c,0x35,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 33026 0x8102 "脂" */
+0x01,0x3d,0x25,0x25,0x25,0x3d,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0x04,0x38,0xc0,0x02,0x02,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 33027 0x8103 "脃" */
+0x00,0x3c,0x24,0x25,0x26,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x54,0x88,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 33028 0x8104 "脄" */
+0x00,0x78,0x48,0x4b,0x48,0x78,0x48,0x49,0x49,0x79,0x4a,0x4a,0x4c,0x48,0x48,0x99,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x90,0x12,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 33029 0x8105 "脅" */
+0x02,0x1f,0x04,0x08,0x10,0x7e,0x12,0x2a,0x44,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x00,0xf0,0x10,0x50,0x20,0xfc,0x24,0x54,0x88,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33030 0x8106 "脆" */
+0x00,0x3c,0x24,0x25,0x26,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 33031 0x8107 "脇" */
+0x00,0x78,0x49,0x48,0x48,0x78,0x49,0x4a,0x49,0x7b,0x49,0x49,0x49,0x4a,0x4b,0x9c,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 33032 0x8108 "脈" */
+0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x04,0x1e,0xe0,0x00,0x06,0x78,0x50,0x50,0x52,0x54,0x48,0x48,0x44,0x54,0x62,0x40,
+/* 33033 0x8109 "脉" */
+0x00,0x78,0x48,0x49,0x48,0x78,0x4b,0x48,0x48,0x78,0x49,0x49,0x4a,0x4c,0x48,0x98,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 33034 0x810a "脊" */
+0x21,0x11,0x09,0x12,0x24,0x08,0x3f,0xc8,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0x08,
+0x08,0x10,0x20,0x90,0x48,0x20,0xf8,0x26,0x20,0xe0,0x20,0x20,0xe0,0x20,0xa0,0x40,
+/* 33035 0x810b "脋" */
+0x00,0x1f,0x04,0x04,0x08,0x7e,0x12,0x2a,0x45,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x00,0xf0,0x10,0x50,0x20,0xfc,0x44,0x94,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33036 0x810c "脌" */
+0x00,0x3c,0x24,0x25,0x26,0x3c,0x24,0x24,0x24,0x3c,0x27,0x24,0x24,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x10,0x10,0x10,0xfc,0x90,0x90,0x90,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 33037 0x810d "脍" */
+0x00,0x78,0x48,0x48,0x49,0x7a,0x48,0x48,0x48,0x7b,0x48,0x48,0x48,0x49,0x4b,0x99,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 33038 0x810e "脎" */
+0x00,0x79,0x48,0x48,0x48,0x78,0x49,0x48,0x4b,0x78,0x48,0x48,0x49,0x4a,0x48,0x98,
+0x04,0x88,0x50,0x20,0x50,0x88,0x24,0x20,0xfe,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 33039 0x810f "脏" */
+0x00,0x78,0x48,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 33040 0x8110 "脐" */
+0x00,0x78,0x4b,0x49,0x48,0x78,0x48,0x48,0x4b,0x78,0x48,0x48,0x48,0x49,0x49,0x9a,
+0x40,0x20,0xfe,0x04,0x88,0x50,0x20,0xd8,0x06,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 33041 0x8111 "脑" */
+0x00,0x78,0x48,0x4f,0x48,0x78,0x48,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x98,
+0x40,0x20,0x20,0xfe,0x00,0x00,0x90,0x54,0x24,0x24,0x54,0x94,0x04,0x04,0xfc,0x04,
+/* 33042 0x8112 "脒" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x24,0x27,0x24,0x3c,0x24,0x25,0x25,0x46,0x54,0x88,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 33043 0x8113 "脓" */
+0x00,0x78,0x48,0x4b,0x4a,0x7c,0x48,0x48,0x49,0x7a,0x4c,0x48,0x48,0x48,0x48,0x98,
+0x20,0x20,0x20,0xfe,0x42,0x44,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 33044 0x8114 "脔" */
+0x02,0x01,0xff,0x04,0x14,0x25,0x41,0x3f,0x22,0x24,0x29,0x21,0x22,0x24,0x20,0x20,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x04,0xf8,0x88,0x48,0x28,0x08,0x88,0x48,0x08,0x18,
+/* 33045 0x8115 "脕" */
+0x00,0x3c,0x24,0x25,0x26,0x3d,0x25,0x25,0x25,0x3d,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 33046 0x8116 "脖" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x4a,0x4c,0x49,0x78,0x48,0x4b,0x48,0x48,0x48,0x98,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 33047 0x8117 "脗" */
+0x00,0x3c,0x24,0x25,0x26,0x3c,0x25,0x26,0x24,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 33048 0x8118 "脘" */
+0x00,0x78,0x4b,0x4a,0x4c,0x79,0x48,0x48,0x4b,0x78,0x48,0x48,0x49,0x49,0x4a,0x9c,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 33049 0x8119 "脙" */
+0x00,0x3c,0x24,0x24,0x27,0x3c,0x25,0x24,0x24,0x3c,0x24,0x25,0x26,0x44,0x54,0x88,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 33050 0x811a "脚" */
+0x01,0x79,0x49,0x4b,0x49,0x79,0x49,0x4f,0x49,0x79,0x4a,0x4a,0x4f,0x4a,0x48,0x98,
+0x00,0x00,0x1e,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0x1a,0x94,0xd0,0x50,0x10,0x10,
+/* 33051 0x811b "脛" */
+0x00,0x7b,0x48,0x49,0x4a,0x7c,0x4a,0x49,0x48,0x7b,0x48,0x48,0x48,0x48,0x4f,0x98,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 33052 0x811c "脜" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 33053 0x811d "脝" */
+0x00,0x78,0x4b,0x48,0x49,0x79,0x49,0x49,0x48,0x7b,0x48,0x48,0x48,0x48,0x48,0x98,
+0x40,0x20,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x08,0x30,0x20,0x20,0xa0,0x40,
+/* 33054 0x811e "脞" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x26,0x24,0x24,0x3d,0x24,0x24,0x24,0x44,0x57,0x88,
+0x20,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33055 0x811f "脟" */
+0x00,0x3c,0x25,0x24,0x25,0x3c,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 33056 0x8120 "脠" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x49,0x4b,0x48,0x7a,0x4a,0x49,0x49,0x4a,0x4c,0x98,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 33057 0x8121 "脡" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x49,0x4b,0x48,0x7a,0x4a,0x49,0x49,0x4a,0x4c,0x98,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 33058 0x8122 "脢" */
+0x00,0x3c,0x24,0x25,0x26,0x3c,0x24,0x24,0x27,0x3c,0x25,0x25,0x25,0x44,0x54,0x88,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 33059 0x8123 "脣" */
+0x3f,0x20,0x2f,0x20,0x3f,0x24,0x24,0x26,0x2f,0x28,0x2f,0x48,0x4f,0x88,0x08,0x08,
+0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 33060 0x8124 "脤" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 33061 0x8125 "脥" */
+0x00,0x78,0x48,0x4b,0x48,0x78,0x49,0x49,0x49,0x7a,0x48,0x48,0x48,0x48,0x49,0x9a,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 33062 0x8126 "脦" */
+0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x48,0x48,0x78,0x48,0x4a,0x4a,0x4a,0x4c,0x98,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x90,0x50,0x48,0x08,0x88,0xa8,0x9a,0xaa,0x66,0x02,
+/* 33063 0x8127 "脧" */
+0x00,0x3c,0x24,0x25,0x37,0x2c,0x24,0x25,0x2e,0x34,0x25,0x26,0x24,0x44,0x55,0x8e,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 33064 0x8128 "脨" */
+0x00,0x3c,0x27,0x24,0x24,0x3d,0x25,0x25,0x25,0x3c,0x24,0x24,0x25,0x46,0x54,0x88,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 33065 0x8129 "脩" */
+0x10,0x10,0x11,0x21,0x2a,0x6c,0xa9,0x2e,0x29,0x29,0x29,0x29,0x29,0x21,0x21,0x21,
+0x80,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 33066 0x812a "脪" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x25,0x24,0x24,0x3d,0x26,0x24,0x24,0x44,0x54,0x88,
+0xc2,0x34,0x18,0x64,0x82,0x20,0xfe,0x50,0x90,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 33067 0x812b "脫" */
+0x00,0x78,0x48,0x49,0x4a,0x7d,0x49,0x49,0x49,0x79,0x48,0x48,0x48,0x49,0x4a,0x9c,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 33068 0x812c "脬" */
+0x00,0x78,0x4b,0x48,0x4a,0x79,0x48,0x4b,0x48,0x78,0x4f,0x48,0x48,0x48,0x48,0x98,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 33069 0x812d "脭" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x48,0x48,0x4b,0x78,0x48,0x49,0x48,0x48,0x4b,0x98,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 33070 0x812e "脮" */
+0x00,0x78,0x4b,0x48,0x4a,0x79,0x49,0x48,0x4b,0x78,0x49,0x4b,0x48,0x48,0x49,0x9e,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 33071 0x812f "脯" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4b,0x4a,0x4a,0x4a,0x9a,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 33072 0x8130 "脰" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x88,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 33073 0x8131 "脱" */
+0x01,0x78,0x48,0x48,0x49,0x79,0x49,0x49,0x49,0x78,0x48,0x48,0x48,0x49,0x4a,0x9c,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 33074 0x8132 "脲" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4d,0x4d,0x4a,0x98,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x20,0x22,0xb2,0xb4,0xa8,0xa8,0x24,0x24,0xa2,0x40,
+/* 33075 0x8133 "脳" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4b,0x4a,0x4b,0x98,
+0x42,0x22,0x24,0x04,0x08,0x00,0x0a,0x8a,0x52,0x22,0x52,0x8a,0x0a,0x02,0xfe,0x02,
+/* 33076 0x8134 "脴" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 33077 0x8135 "脵" */
+0x00,0x79,0x49,0x49,0x49,0x78,0x48,0x49,0x48,0x78,0x4b,0x48,0x48,0x48,0x49,0x9a,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 33078 0x8136 "脶" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x48,0x48,0x4b,0x7a,0x4a,0x4a,0x4b,0x4a,0x4a,0x9a,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 33079 0x8137 "脷" */
+0x00,0x78,0x4b,0x48,0x48,0x78,0x4f,0x48,0x49,0x79,0x4a,0x4a,0x4c,0x48,0x48,0x98,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 33080 0x8138 "脸" */
+0x00,0x78,0x48,0x48,0x48,0x79,0x4a,0x48,0x48,0x78,0x49,0x48,0x48,0x48,0x4b,0x98,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x44,0x24,0x24,0xa8,0x88,0x10,0xfe,0x00,
+/* 33081 0x8139 "脹" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x27,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 33082 0x813a "脺" */
+0x00,0x78,0x4b,0x48,0x48,0x78,0x49,0x4a,0x48,0x78,0x4b,0x48,0x48,0x48,0x48,0x98,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 33083 0x813b "脻" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x48,0x49,0x78,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 33084 0x813c "脼" */
+0x00,0x7b,0x48,0x48,0x4b,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 33085 0x813d "脽" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 33086 0x813e "脾" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x78,0x49,0x4f,0x48,0x48,0x48,0x98,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 33087 0x813f "脿" */
+0x00,0x3c,0x27,0x24,0x24,0x3d,0x24,0x24,0x27,0x3c,0x24,0x25,0x26,0x44,0x54,0x88,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 33088 0x8140 "腀" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 33089 0x8141 "腁" */
+0x00,0x78,0x49,0x4f,0x49,0x79,0x49,0x49,0x4f,0x79,0x49,0x49,0x49,0x4a,0xaa,0x94,
+0x84,0x8c,0x08,0xbe,0x08,0x08,0x08,0x08,0xbe,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+/* 33090 0x8142 "腂" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x3f,0x24,0x24,0x25,0x46,0x54,0x88,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 33091 0x8143 "腃" */
+0x00,0x3d,0x24,0x24,0x25,0x3c,0x27,0x24,0x25,0x3e,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 33092 0x8144 "腄" */
+0x00,0x3c,0x25,0x24,0x27,0x3c,0x24,0x24,0x27,0x3c,0x24,0x27,0x24,0x44,0x55,0x88,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 33093 0x8145 "腅" */
+0x00,0x3c,0x24,0x25,0x24,0x3c,0x27,0x24,0x24,0x3c,0x24,0x25,0x24,0x44,0x55,0x8a,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 33094 0x8146 "腆" */
+0x00,0x78,0x48,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x49,0x4b,0x48,0x48,0x49,0x9a,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x88,0x04,0x02,
+/* 33095 0x8147 "腇" */
+0x00,0x79,0x48,0x48,0x4b,0x78,0x49,0x4a,0x48,0x7b,0x48,0x49,0x48,0x48,0x48,0x99,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 33096 0x8148 "腈" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 33097 0x8149 "腉" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x78,0x48,0x48,0x48,0x49,0x4a,0x9c,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 33098 0x814a "腊" */
+0x00,0x78,0x48,0x4b,0x48,0x78,0x4f,0x48,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x88,0x88,0x88,0xfe,0x88,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 33099 0x814b "腋" */
+0x00,0x78,0x4f,0x49,0x49,0x7a,0x4a,0x4e,0x4a,0x7b,0x4a,0x4a,0x4a,0x4a,0x4a,0x9b,
+0x80,0x40,0xfe,0x20,0x20,0x3c,0x44,0x64,0x94,0x48,0x48,0x30,0x20,0x50,0x88,0x06,
+/* 33100 0x814c "腌" */
+0x00,0x78,0x4b,0x49,0x4a,0x7c,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x48,0x48,0x98,
+0x40,0x80,0xfc,0x10,0x48,0x46,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x42,0x42,0x3e,
+/* 33101 0x814d "腍" */
+0x00,0x78,0x48,0x48,0x49,0x7a,0x49,0x48,0x48,0x78,0x48,0x4a,0x4a,0x4a,0x4c,0x98,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 33102 0x814e "腎" */
+0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 33103 0x814f "腏" */
+0x00,0x7b,0x48,0x49,0x48,0x79,0x4a,0x4c,0x48,0x7b,0x48,0x49,0x48,0x49,0x4a,0x9c,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 33104 0x8150 "腐" */
+0x00,0x3f,0x22,0x22,0x25,0x2c,0x34,0x24,0x20,0x2f,0x29,0x2a,0x48,0x49,0x8a,0x08,
+0x80,0xfe,0x08,0x08,0xfe,0x88,0x48,0x58,0x80,0xfc,0x44,0xa4,0x84,0x44,0x24,0x0c,
+/* 33105 0x8151 "腑" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4c,0x4c,0x48,0x98,
+0x20,0x10,0xfe,0x00,0x44,0x44,0x84,0xbe,0x84,0xa4,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 33106 0x8152 "腒" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 33107 0x8153 "腓" */
+0x00,0x78,0x48,0x4f,0x48,0x78,0x48,0x4b,0x48,0x78,0x48,0x4f,0x48,0x48,0x48,0x98,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 33108 0x8154 "腔" */
+0x00,0x78,0x48,0x4b,0x4a,0x7c,0x49,0x4a,0x48,0x79,0x48,0x48,0x48,0x48,0x4f,0x98,
+0x40,0x20,0x20,0xfe,0x02,0x94,0x08,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33109 0x8155 "腕" */
+0x00,0x78,0x4b,0x4a,0x4d,0x79,0x49,0x4a,0x4a,0x7b,0x4c,0x48,0x49,0x49,0x4a,0x9c,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 33110 0x8156 "腖" */
+0x00,0x78,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x78,0x48,0x48,0x49,0x4e,0x48,0x98,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 33111 0x8157 "腗" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3c,0x27,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 33112 0x8158 "腘" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x9a,
+0x00,0xfe,0x02,0x02,0xfe,0x22,0x22,0xfa,0x22,0x32,0x2a,0xfe,0x02,0x02,0xfe,0x02,
+/* 33113 0x8159 "腙" */
+0x00,0x78,0x4b,0x4a,0x48,0x79,0x48,0x48,0x4b,0x78,0x49,0x49,0x4a,0x4c,0x48,0x98,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 33114 0x815a "腚" */
+0x00,0x78,0x4b,0x4a,0x4c,0x78,0x4b,0x48,0x48,0x79,0x49,0x49,0x4a,0x4a,0x4c,0x98,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 33115 0x815b "腛" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x56,0x89,
+0x00,0xfe,0x02,0x02,0xfe,0x00,0xfc,0x20,0x44,0xfe,0x12,0x10,0xfc,0x10,0x10,0xfe,
+/* 33116 0x815c "腜" */
+0x00,0x3c,0x27,0x24,0x24,0x3c,0x24,0x24,0x24,0x3c,0x27,0x24,0x24,0x45,0x56,0x88,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 33117 0x815d "腝" */
+0x00,0x3d,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x3d,0x24,0x27,0x24,0x44,0x55,0x8a,
+0x00,0xfc,0x20,0x40,0xfc,0x54,0x54,0x54,0x44,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 33118 0x815e "腞" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x24,0x24,0x25,0x3c,0x24,0x25,0x24,0x44,0x55,0x88,
+0x40,0x7c,0x84,0xf8,0x08,0xfe,0x40,0xa4,0x38,0x58,0x94,0x34,0x54,0x92,0x50,0x20,
+/* 33119 0x815f "腟" */
+0x00,0x3c,0x25,0x25,0x26,0x3d,0x24,0x24,0x25,0x3c,0x24,0x25,0x24,0x44,0x57,0x88,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 33120 0x8160 "腠" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x48,0x49,0x7a,0x48,0x49,0x48,0x48,0x48,0x9b,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x20,0xfc,0x20,0x50,0x88,0x04,
+/* 33121 0x8161 "腡" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xfe,0x02,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 33122 0x8162 "腢" */
+0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x48,0x48,0x7b,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 33123 0x8163 "腣" */
+0x00,0x78,0x49,0x48,0x48,0x78,0x4b,0x4a,0x4c,0x79,0x49,0x49,0x49,0x49,0x48,0x98,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 33124 0x8164 "腤" */
+0x00,0x3c,0x25,0x24,0x24,0x3c,0x25,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x10,0xfe,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 33125 0x8165 "腥" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7b,0x48,0x4a,0x4b,0x7c,0x48,0x4b,0x48,0x48,0x4f,0x98,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 33126 0x8166 "腦" */
+0x00,0x79,0x4a,0x49,0x48,0x78,0x48,0x4b,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x9a,
+0x92,0x24,0x48,0x24,0x92,0x40,0x80,0xfe,0x02,0x8a,0x52,0x22,0x52,0x8a,0xfe,0x02,
+/* 33127 0x8167 "腧" */
+0x00,0x78,0x49,0x4a,0x4d,0x78,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x4a,0x4a,0x9a,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 33128 0x8168 "腨" */
+0x00,0x3d,0x25,0x25,0x25,0x3c,0x27,0x24,0x24,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 33129 0x8169 "腩" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 33130 0x816a "腪" */
+0x00,0x7b,0x4a,0x48,0x4b,0x78,0x49,0x49,0x49,0x79,0x49,0x48,0x4b,0x48,0x48,0x98,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 33131 0x816b "腫" */
+0x00,0x3c,0x25,0x24,0x27,0x3c,0x25,0x25,0x25,0x3d,0x25,0x24,0x25,0x44,0x57,0x88,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 33132 0x816c "腬" */
+0x00,0x3c,0x24,0x24,0x25,0x3c,0x24,0x25,0x26,0x3c,0x25,0x24,0x24,0x45,0x56,0x88,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 33133 0x816d "腭" */
+0x00,0x3d,0x25,0x25,0x25,0x3c,0x25,0x24,0x25,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,
+/* 33134 0x816e "腮" */
+0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x48,0x78,0x48,0x4a,0x4a,0x4c,0x48,0x98,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 33135 0x816f "腯" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x04,0x1e,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 33136 0x8170 "腰" */
+0x00,0x7b,0x48,0x48,0x4b,0x7a,0x4a,0x4b,0x48,0x78,0x4f,0x48,0x49,0x48,0x48,0x9b,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 33137 0x8171 "腱" */
+0x00,0x78,0x48,0x4b,0x49,0x79,0x4a,0x4a,0x4f,0x79,0x49,0x4d,0x4a,0x4b,0x4c,0x98,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 33138 0x8172 "腲" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x3f,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 33139 0x8173 "腳" */
+0x00,0x7a,0x4a,0x4a,0x4d,0x79,0x4a,0x4a,0x4c,0x7b,0x4a,0x4a,0x4a,0x4a,0x4b,0x9a,
+0x00,0x9e,0x52,0x52,0x52,0x12,0x92,0x52,0x32,0xd2,0x5a,0x54,0x50,0x50,0xd0,0x50,
+/* 33140 0x8174 "腴" */
+0x00,0x3c,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x24,0x50,0x50,0x88,0x04,0x02,
+/* 33141 0x8175 "腵" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4b,0x4a,0x4a,0x4a,0x9a,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 33142 0x8176 "腶" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x27,0x45,0x55,0x89,
+0x20,0xdc,0x14,0x14,0x14,0xd4,0x26,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 33143 0x8177 "腷" */
+0x00,0x3d,0x24,0x24,0x24,0x3c,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfc,0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 33144 0x8178 "腸" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x25,0x24,0x3c,0x25,0x26,0x24,0x45,0x54,0x88,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 33145 0x8179 "腹" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x24,0x3c,0x24,0x24,0x25,0x44,0x54,0x89,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 33146 0x817a "腺" */
+0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x48,0x48,0x7b,0x48,0x49,0x49,0x4a,0x4c,0x98,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 33147 0x817b "腻" */
+0x00,0x78,0x4f,0x48,0x4b,0x78,0x4b,0x48,0x4b,0x7a,0x4a,0x4a,0x4a,0x49,0x4a,0x9c,
+0x18,0x14,0xfe,0x10,0xd0,0x10,0xf0,0x10,0xe8,0x28,0xa8,0xa8,0xaa,0x4a,0x26,0x22,
+/* 33148 0x817c "腼" */
+0x00,0x3d,0x24,0x24,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x89,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x74,0x54,0x54,0x74,0x54,0x54,0x54,0xfc,0x04,
+/* 33149 0x817d "腽" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x45,0x57,0x88,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 33150 0x817e "腾" */
+0x02,0x79,0x49,0x4f,0x48,0x7f,0x49,0x4a,0x4d,0x78,0x49,0x49,0x48,0x4b,0x48,0x98,
+0x48,0x48,0x50,0xfc,0x40,0xfe,0x10,0x08,0xf6,0x10,0x10,0xfc,0x04,0xe4,0x14,0x08,
+/* 33151 0x817f "腿" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x4f,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x4a,0x9c,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x50,0x4a,0x44,0x54,0x62,0x42,0x80,0x7e,
+/* 33152 0x8180 "膀" */
+0x00,0x78,0x4b,0x49,0x48,0x7b,0x4a,0x4c,0x48,0x7b,0x48,0x48,0x48,0x49,0x49,0x9a,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 33153 0x8181 "膁" */
+0x00,0x3c,0x24,0x25,0x24,0x3d,0x24,0x27,0x24,0x3d,0x24,0x24,0x25,0x46,0x54,0x88,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 33154 0x8182 "膂" */
+0x20,0xfe,0x21,0x3c,0x24,0x44,0x54,0x88,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x40,0xfe,0x00,0x1c,0xe0,0x94,0xa8,0xc6,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 33155 0x8183 "膃" */
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x45,0x57,0x88,
+0x00,0xf8,0xa8,0xa8,0xd8,0x88,0xf8,0x00,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 33156 0x8184 "膄" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x24,0x3d,0x24,0x24,0x24,0x44,0x54,0x8b,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 33157 0x8185 "膅" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 33158 0x8186 "膆" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x48,0x48,0x79,0x48,0x4b,0x48,0x49,0x4a,0x98,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 33159 0x8187 "膇" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x4b,0x49,0x49,0x79,0x49,0x49,0x49,0x4a,0x4c,0x98,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 33160 0x8188 "膈" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x48,0x4b,0x7a,0x4a,0x4b,0x4a,0x4a,0x4a,0x9a,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 33161 0x8189 "膉" */
+0x01,0x3c,0x24,0x24,0x27,0x3c,0x24,0x25,0x26,0x3d,0x25,0x25,0x25,0x45,0x57,0x88,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 33162 0x818a "膊" */
+0x00,0x78,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x79,0x48,0x4b,0x48,0x48,0x48,0x98,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 33163 0x818b "膋" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 33164 0x818c "膌" */
+0x00,0x3d,0x24,0x25,0x24,0x3d,0x26,0x24,0x24,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x24,0xa8,0x54,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x98,
+/* 33165 0x818d "膍" */
+0x00,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x3c,0x25,0x25,0x25,0x45,0x55,0x89,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 33166 0x818e "膎" */
+0x00,0x7b,0x49,0x48,0x48,0x78,0x49,0x48,0x48,0x79,0x48,0x48,0x4b,0x48,0x48,0x9b,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 33167 0x818f "膏" */
+0x01,0x7f,0x08,0x0f,0x00,0x7f,0x48,0x8f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x00,0xfc,0x20,0xe0,0x00,0xfe,0x22,0xe4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33168 0x8190 "膐" */
+0x20,0xfe,0x21,0x3c,0x24,0x44,0x54,0x88,0x01,0x3f,0x22,0x24,0x21,0x22,0x24,0x20,
+0x40,0xfe,0x00,0x1c,0xe0,0x94,0xa8,0xc6,0x00,0xf8,0x88,0x48,0x08,0x88,0x48,0x18,
+/* 33169 0x8191 "膑" */
+0x00,0x78,0x4b,0x4a,0x4c,0x79,0x49,0x49,0x49,0x79,0x49,0x4f,0x48,0x48,0x49,0x9a,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 33170 0x8192 "膒" */
+0x00,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4b,0x98,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 33171 0x8193 "膓" */
+0x01,0x79,0x4a,0x4d,0x49,0x79,0x49,0x49,0x48,0x7f,0x49,0x4b,0x4c,0x49,0x4a,0x98,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 33172 0x8194 "膔" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9c,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 33173 0x8195 "膕" */
+0x00,0x77,0x54,0x54,0x57,0x74,0x57,0x56,0x57,0x74,0x55,0x56,0x54,0x54,0x57,0xb4,
+0x00,0xfe,0x2a,0x26,0xfe,0x22,0xaa,0xaa,0xaa,0x32,0x96,0x2e,0x46,0x82,0xfe,0x02,
+/* 33174 0x8196 "膖" */
+0x00,0x7a,0x49,0x48,0x48,0x78,0x4b,0x49,0x49,0x79,0x49,0x49,0x49,0x49,0x4a,0x9c,
+0x20,0x20,0x7c,0xa4,0x18,0xe6,0x10,0x7e,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 33175 0x8197 "膗" */
+0x00,0x7a,0x4b,0x48,0x48,0x79,0x4b,0x4d,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 33176 0x8198 "膘" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x48,0x49,0x78,0x4b,0x48,0x48,0x49,0x4a,0x98,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 33177 0x8199 "膙" */
+0x00,0x7b,0x48,0x48,0x48,0x7b,0x4a,0x4a,0x4a,0x7b,0x48,0x48,0x48,0x48,0x4d,0x9a,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 33178 0x819a "膚" */
+0x01,0x01,0x01,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x24,0x27,0x24,0x47,0x44,0x84,
+0x00,0xfc,0x00,0xfe,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 33179 0x819b "膛" */
+0x00,0x79,0x48,0x4b,0x4a,0x78,0x48,0x48,0x48,0x78,0x48,0x49,0x48,0x48,0x4b,0x98,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 33180 0x819c "膜" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x49,0x49,0x49,0x79,0x48,0x4b,0x48,0x48,0x49,0x9a,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 33181 0x819d "膝" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x48,0x48,0x49,0x7a,0x49,0x48,0x49,0x4a,0x48,0x98,
+0x20,0x20,0xfe,0x70,0xac,0x22,0x50,0x88,0x24,0x22,0x24,0xa8,0x24,0x22,0xa0,0x40,
+/* 33182 0x819e "膞" */
+0x00,0x3d,0x24,0x25,0x25,0x3d,0x25,0x25,0x24,0x3d,0x24,0x25,0x25,0x44,0x54,0x88,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 33183 0x819f "膟" */
+0x00,0x78,0x4b,0x48,0x48,0x7a,0x49,0x4a,0x48,0x78,0x48,0x4b,0x48,0x48,0x48,0x98,
+0x40,0x20,0xfe,0x20,0x48,0xf2,0x24,0x52,0xf8,0x08,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 33184 0x81a0 "膠" */
+0x00,0x7b,0x48,0x4a,0x49,0x7a,0x48,0x48,0x4b,0x78,0x49,0x48,0x49,0x48,0x48,0x9b,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 33185 0x81a1 "膡" */
+0x00,0x79,0x48,0x49,0x48,0x7b,0x48,0x49,0x4b,0x7d,0x49,0x49,0x49,0x49,0x49,0x99,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x04,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 33186 0x81a2 "膢" */
+0x00,0x79,0x49,0x4b,0x49,0x79,0x48,0x49,0x49,0x79,0x48,0x4b,0x48,0x49,0x48,0x9b,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 33187 0x81a3 "膣" */
+0x00,0x78,0x4b,0x4a,0x49,0x7b,0x48,0x48,0x49,0x78,0x48,0x49,0x48,0x48,0x4b,0x98,
+0x40,0x20,0xfe,0x8a,0x04,0xfe,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 33188 0x81a4 "膤" */
+0x00,0x79,0x48,0x4b,0x4a,0x79,0x48,0x49,0x48,0x79,0x48,0x49,0x48,0x48,0x49,0x98,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 33189 0x81a5 "膥" */
+0x10,0x10,0xfd,0x11,0x7d,0x39,0x55,0x92,0x11,0x3f,0x22,0x24,0x21,0x22,0x24,0x20,
+0x14,0x10,0xfe,0x10,0xd4,0x48,0x4a,0x96,0x22,0xf8,0x88,0x48,0x08,0x88,0x48,0x18,
+/* 33190 0x81a6 "膦" */
+0x00,0x79,0x48,0x4b,0x48,0x79,0x4a,0x49,0x49,0x79,0x4a,0x4d,0x48,0x49,0x4a,0x9c,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 33191 0x81a7 "膧" */
+0x00,0x3d,0x24,0x24,0x37,0x2c,0x25,0x25,0x2d,0x35,0x25,0x24,0x25,0x44,0x57,0x88,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 33192 0x81a8 "膨" */
+0x00,0x78,0x4f,0x48,0x48,0x7b,0x48,0x4b,0x4a,0x7a,0x4b,0x4a,0x49,0x48,0x4f,0x9a,
+0x82,0x82,0xf4,0x88,0x80,0xe2,0x02,0xe4,0x28,0x20,0xe0,0x22,0x42,0x74,0x88,0x10,
+/* 33193 0x81a9 "膩" */
+0x00,0x7b,0x48,0x4b,0x48,0x7b,0x48,0x4b,0x4a,0x7b,0x4a,0x4b,0x4a,0x4b,0x49,0x9a,
+0x14,0xfe,0x10,0xd0,0x10,0xd0,0x10,0xd0,0x50,0xd0,0x50,0xc8,0x4a,0xca,0x86,0x42,
+/* 33194 0x81aa "膪" */
+0x00,0x78,0x49,0x48,0x48,0x7b,0x4a,0x4c,0x49,0x79,0x49,0x48,0x49,0x49,0x49,0x99,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x2c,0x20,0xfc,0x04,0xfc,0x04,
+/* 33195 0x81ab "膫" */
+0x00,0x3c,0x25,0x24,0x25,0x3c,0x25,0x26,0x24,0x3c,0x24,0x24,0x24,0x44,0x55,0x88,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 33196 0x81ac "膬" */
+0x00,0x7b,0x48,0x4b,0x48,0x7b,0x48,0x48,0x48,0x7b,0x49,0x4f,0x49,0x4f,0x49,0x99,
+0x38,0xc0,0x78,0xc0,0x78,0xc4,0x3c,0x00,0xc6,0x38,0xce,0x38,0xce,0x38,0x4a,0x86,
+/* 33197 0x81ad "膭" */
+0x00,0x3d,0x25,0x25,0x24,0x3f,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x54,0x89,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 33198 0x81ae "膮" */
+0x00,0x78,0x49,0x48,0x4b,0x79,0x4b,0x49,0x49,0x7e,0x48,0x4b,0x48,0x48,0x49,0x9a,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 33199 0x81af "膯" */
+0x00,0x7b,0x48,0x49,0x48,0x79,0x4a,0x4c,0x49,0x79,0x49,0x49,0x49,0x48,0x4f,0x98,
+0x10,0xd2,0x54,0x48,0x8a,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 33200 0x81b0 "膰" */
+0x00,0x7b,0x49,0x48,0x4b,0x78,0x49,0x4a,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x99,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 33201 0x81b1 "膱" */
+0x01,0x78,0x4b,0x48,0x4a,0x79,0x4f,0x48,0x4b,0x7a,0x4a,0x4b,0x4a,0x4a,0x4b,0x98,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 33202 0x81b2 "膲" */
+0x00,0x78,0x49,0x49,0x4b,0x7d,0x49,0x49,0x49,0x79,0x49,0x49,0x49,0x4a,0x4a,0x9c,
+0xa0,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 33203 0x81b3 "膳" */
+0x00,0x78,0x4b,0x48,0x49,0x78,0x4b,0x49,0x48,0x7b,0x48,0x49,0x49,0x49,0x49,0x99,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 33204 0x81b4 "膴" */
+0x00,0x3c,0x25,0x27,0x25,0x3d,0x27,0x25,0x25,0x3d,0x27,0x24,0x25,0x45,0x56,0x88,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 33205 0x81b5 "膵" */
+0x00,0x3c,0x27,0x24,0x24,0x3f,0x24,0x24,0x25,0x3e,0x24,0x27,0x24,0x44,0x54,0x88,
+0x88,0x88,0xfe,0x88,0x20,0xfe,0x88,0x88,0x54,0x22,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 33206 0x81b6 "膶" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4a,0x9a,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x22,0x72,0x22,0x22,0xfa,0x02,0x0a,0x04,
+/* 33207 0x81b7 "膷" */
+0x02,0x72,0x54,0x55,0x59,0x7e,0x52,0x54,0x55,0x7f,0x52,0x52,0x54,0x54,0x58,0xb0,
+0x80,0x4e,0xea,0xaa,0xaa,0xea,0xac,0xaa,0xea,0x8a,0x8a,0xaa,0xac,0xe8,0xa8,0x08,
+/* 33208 0x81b8 "膸" */
+0x00,0x79,0x4c,0x4a,0x49,0x7a,0x48,0x4e,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4d,0x98,
+0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,0x00,0xfe,
+/* 33209 0x81b9 "膹" */
+0x00,0x3d,0x24,0x24,0x27,0x3c,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x44,0x55,0x8a,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 33210 0x81ba "膺" */
+0x00,0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x20,0x27,0x24,0x27,0x44,0x47,0x84,0x04,
+0x80,0xfe,0x50,0xfc,0x90,0xfc,0x90,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 33211 0x81bb "膻" */
+0x00,0x7b,0x48,0x4b,0x4a,0x7a,0x4a,0x4b,0x48,0x79,0x49,0x49,0x49,0x49,0x48,0x9b,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 33212 0x81bc "膼" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x4e,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4a,0x4d,0x98,
+0x00,0x7c,0x44,0x74,0x54,0x54,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,0x00,0xfe,
+/* 33213 0x81bd "膽" */
+0x00,0x3c,0x25,0x27,0x25,0x3d,0x25,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 33214 0x81be "膾" */
+0x00,0x3c,0x24,0x25,0x26,0x3d,0x25,0x25,0x25,0x3d,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 33215 0x81bf "膿" */
+0x00,0x3d,0x25,0x25,0x25,0x3d,0x24,0x25,0x25,0x3d,0x25,0x25,0x25,0x45,0x55,0x8a,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfe,0x00,0x7c,0x00,0xfe,0x50,0x54,0x48,0x66,
+/* 33216 0x81c0 "臀" */
+0x7e,0x42,0x7e,0x54,0x7e,0x54,0x7e,0x94,0x62,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x78,0x48,0x48,0x86,0x78,0x48,0x30,0xce,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33217 0x81c1 "臁" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4b,0x7a,0x4a,0x4a,0x4a,0x4d,0x4e,0x98,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 33218 0x81c2 "臂" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33219 0x81c3 "臃" */
+0x00,0x78,0x4f,0x48,0x4a,0x7a,0x4c,0x4f,0x49,0x7a,0x4c,0x4f,0x49,0x4a,0x4c,0x98,
+0x40,0x20,0xfe,0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x7e,0x40,
+/* 33220 0x81c4 "臄" */
+0x00,0x78,0x48,0x4b,0x4a,0x7a,0x4b,0x4a,0x4a,0x7b,0x4a,0x4b,0x4a,0x4d,0x4c,0x99,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 33221 0x81c5 "臅" */
+0x00,0x3d,0x25,0x25,0x25,0x3c,0x25,0x26,0x25,0x3d,0x25,0x25,0x24,0x47,0x54,0x88,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfe,0x42,0xf2,0x52,0x52,0xf2,0x4a,0xfa,0x0a,0x04,
+/* 33222 0x81c6 "臆" */
+0x00,0x78,0x49,0x48,0x48,0x7b,0x48,0x49,0x49,0x79,0x49,0x49,0x48,0x4a,0x4a,0x9c,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 33223 0x81c7 "臇" */
+0x00,0x78,0x49,0x4b,0x49,0x79,0x49,0x49,0x49,0x79,0x4b,0x4a,0x4a,0x4a,0x4a,0x9a,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xde,0x52,0x52,0x72,0x02,0x06,
+/* 33224 0x81c8 "臈" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x49,0x48,0x79,0x4a,0x4d,0x49,0x49,0x48,0x98,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 33225 0x81c9 "臉" */
+0x00,0x3c,0x24,0x24,0x25,0x3e,0x24,0x24,0x25,0x3d,0x25,0x25,0x24,0x44,0x55,0x8a,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 33226 0x81ca "臊" */
+0x00,0x3c,0x24,0x24,0x24,0x3d,0x25,0x25,0x25,0x3c,0x27,0x24,0x24,0x45,0x56,0x88,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 33227 0x81cb "臋" */
+0x7e,0x42,0x7e,0x54,0x7e,0x54,0x7e,0x94,0x63,0x3f,0x22,0x24,0x21,0x22,0x24,0x20,
+0x78,0x48,0x48,0x86,0x78,0x48,0x30,0xce,0x00,0xf8,0x88,0x48,0x08,0x88,0x48,0x18,
+/* 33228 0x81cc "臌" */
+0x00,0x78,0x4f,0x48,0x48,0x7b,0x48,0x4b,0x4a,0x7a,0x4b,0x4a,0x49,0x48,0x4f,0x9a,
+0x88,0x88,0xc8,0xbe,0x88,0xc8,0x1c,0xd4,0x54,0x54,0xd4,0x48,0x88,0xd4,0x14,0x22,
+/* 33229 0x81cd "臍" */
+0x00,0x70,0x57,0x51,0x50,0x7f,0x55,0x55,0x5b,0x70,0x52,0x53,0x52,0x53,0x52,0xb4,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 33230 0x81ce "臎" */
+0x03,0x78,0x4a,0x49,0x4a,0x78,0x4b,0x48,0x48,0x79,0x4a,0x48,0x4b,0x48,0x48,0x98,
+0xde,0x42,0x52,0x4a,0x52,0x20,0xfe,0x88,0x88,0x54,0x22,0x20,0xfe,0x20,0x20,0x20,
+/* 33231 0x81cf "臏" */
+0x00,0x78,0x4b,0x4a,0x49,0x79,0x4a,0x49,0x4b,0x79,0x49,0x49,0x49,0x49,0x48,0x99,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 33232 0x81d0 "臐" */
+0x00,0x3d,0x24,0x27,0x24,0x3d,0x25,0x25,0x25,0x3c,0x25,0x24,0x27,0x44,0x55,0x8a,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 33233 0x81d1 "臑" */
+0x00,0x79,0x48,0x4b,0x4a,0x79,0x48,0x49,0x48,0x7b,0x48,0x49,0x49,0x49,0x49,0x99,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 33234 0x81d2 "臒" */
+0x00,0x7b,0x48,0x48,0x49,0x7b,0x49,0x49,0x49,0x79,0x49,0x49,0x4b,0x48,0x48,0x9b,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 33235 0x81d3 "臓" */
+0x00,0x70,0x57,0x50,0x50,0x77,0x54,0x55,0x55,0x75,0x55,0x55,0x55,0x55,0x54,0xb8,
+0x90,0x90,0xfe,0x94,0x0a,0xfe,0x08,0xe8,0x4a,0xea,0x2a,0xea,0x4c,0xea,0x16,0x62,
+/* 33236 0x81d4 "臔" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x4b,0x48,0x49,0x79,0x49,0x49,0x49,0x49,0x49,0x98,
+0xde,0x92,0xd2,0x54,0xc8,0x94,0xe2,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,
+/* 33237 0x81d5 "臕" */
+0x00,0x78,0x4b,0x4a,0x4b,0x7a,0x4b,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4c,0x49,0x9a,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 33238 0x81d6 "臖" */
+0x2f,0x48,0x4b,0x68,0x4b,0x6a,0x4b,0xff,0x10,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x10,
+0xec,0x24,0xa4,0x2c,0xa4,0xac,0xa4,0xfe,0x10,0xf8,0x16,0xf0,0x10,0xf0,0x10,0x30,
+/* 33239 0x81d7 "臗" */
+0x00,0x7b,0x4a,0x49,0x48,0x79,0x49,0x49,0x49,0x79,0x49,0x49,0x48,0x48,0x49,0x9a,
+0x20,0xfe,0x8a,0xfc,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x94,0x12,0x0e,
+/* 33240 0x81d8 "臘" */
+0x01,0x7a,0x49,0x48,0x4b,0x7a,0x4a,0x4a,0x4b,0x7a,0x4b,0x4a,0x4b,0x4a,0x4a,0x9b,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 33241 0x81d9 "臙" */
+0x01,0x71,0x57,0x51,0x51,0x72,0x52,0x56,0x52,0x72,0x56,0x5a,0x50,0x52,0x52,0xb4,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 33242 0x81da "臚" */
+0x00,0x78,0x48,0x4b,0x4a,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x4d,0x49,0x9b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 33243 0x81db "臛" */
+0x01,0x78,0x4b,0x4a,0x4d,0x78,0x49,0x48,0x49,0x7b,0x4d,0x49,0x49,0x49,0x49,0x99,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 33244 0x81dc "臜" */
+0x01,0x75,0x57,0x59,0x57,0x73,0x55,0x59,0x50,0x73,0x52,0x52,0x52,0x50,0x51,0xb6,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0x00,0xf8,0x08,0x48,0x48,0xb0,0x08,0x04,
+/* 33245 0x81dd "臝" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x05,0x77,0x55,0x77,0x51,0x7f,0x55,0xb9,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x40,0xdc,0x54,0xd4,0x1c,0xf6,0x56,0x22,
+/* 33246 0x81de "臞" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x4b,0x48,0x49,0x79,0x4b,0x4d,0x49,0x49,0x49,0x99,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 33247 0x81df "臟" */
+0x00,0x70,0x57,0x50,0x50,0x71,0x55,0x57,0x51,0x71,0x5f,0x55,0x55,0x59,0x52,0xb4,
+0x90,0x90,0xfe,0x94,0x0a,0xfe,0x08,0xe8,0x4a,0xea,0x2a,0xea,0x4c,0xea,0x16,0x62,
+/* 33248 0x81e0 "臠" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x3f,0x22,0x24,0x21,0x22,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf8,0x88,0x48,0x08,0x98,
+/* 33249 0x81e1 "臡" */
+0x24,0xff,0x24,0x3d,0x08,0x7e,0x52,0x7e,0x24,0x42,0xbf,0x22,0x24,0x29,0x22,0x24,
+0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xf8,0x88,0x48,0x28,0x88,0x58,
+/* 33250 0x81e2 "臢" */
+0x05,0x77,0x59,0x57,0x53,0x75,0x59,0x53,0x52,0x73,0x52,0x53,0x52,0x53,0x51,0xb2,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 33251 0x81e3 "臣" */
+0x00,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x3f,0x21,0x21,0x21,0x3f,0x00,
+0x00,0xfc,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,0xfc,0x00,
+/* 33252 0x81e4 "臤" */
+0x00,0x7e,0x48,0x48,0x48,0x7e,0x42,0x42,0x42,0x7e,0x48,0x48,0x48,0x48,0x7e,0x01,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 33253 0x81e5 "臥" */
+0x00,0x7e,0x48,0x48,0x48,0x7e,0x42,0x42,0x42,0x7e,0x48,0x48,0x48,0x48,0x7e,0x01,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x50,0x48,0x88,0x84,0x02,
+/* 33254 0x81e6 "臦" */
+0x00,0xfe,0x12,0x12,0x12,0x7e,0x42,0x42,0x42,0x42,0x7e,0x12,0x12,0x12,0xfe,0x00,
+0x00,0x7e,0x48,0x48,0x48,0x7e,0x42,0x42,0x42,0x42,0x7e,0x48,0x48,0x48,0x7e,0x00,
+/* 33255 0x81e7 "臧" */
+0x00,0x00,0x5f,0x50,0x57,0x75,0x15,0x17,0xf4,0x54,0x57,0x55,0x95,0x27,0x20,0x40,
+0x28,0x24,0xfe,0x20,0xa0,0x20,0x20,0xa4,0xa4,0xa8,0xa8,0x10,0x12,0xaa,0x46,0x82,
+/* 33256 0x81e8 "臨" */
+0x00,0x7e,0x48,0x48,0x49,0x7e,0x42,0x42,0x42,0x7e,0x48,0x48,0x48,0x48,0x7e,0x00,
+0x40,0x40,0x7e,0x80,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0xaa,
+/* 33257 0x81e9 "臩" */
+0x00,0xfe,0x12,0x7e,0x42,0x7e,0x12,0xfe,0x02,0x7f,0x04,0x18,0xe4,0x04,0x08,0x10,
+0x00,0xfe,0x90,0xfc,0x84,0xfc,0x90,0xfe,0x00,0xfc,0x40,0x30,0x4e,0x40,0x40,0x40,
+/* 33258 0x81ea "自" */
+0x01,0x02,0x04,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33259 0x81eb "臫" */
+0x08,0x08,0x10,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x41,0x41,0x7f,0x41,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 33260 0x81ec "臬" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 33261 0x81ed "臭" */
+0x02,0x04,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x01,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0xfe,0x80,0x40,0x30,0x0e,
+/* 33262 0x81ee "臮" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x00,0x7f,0x11,0x11,0x29,0x45,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0x10,0x10,0x28,0x44,0x00,
+/* 33263 0x81ef "臯" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x21,0x11,0x09,0x11,0x21,0xff,0x01,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x10,0x20,0x10,0x08,0xfe,0x00,0x00,
+/* 33264 0x81f0 "臰" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,0x08,0x1f,0x62,0x14,0x18,0xe0,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x40,0x48,0x50,0x62,0x42,0x3e,
+/* 33265 0x81f1 "臱" */
+0x02,0x1f,0x14,0x12,0x11,0x1f,0x01,0x7f,0x4a,0x91,0x3f,0x04,0x07,0x08,0x10,0x20,
+0x00,0xf0,0x90,0x50,0x30,0xf0,0x00,0xfe,0x22,0x14,0xf8,0x00,0xf0,0x10,0x50,0x20,
+/* 33266 0x81f2 "臲" */
+0x10,0x20,0x7e,0x42,0x7f,0x42,0x7e,0x42,0x7e,0x10,0xfe,0x18,0x34,0x53,0x91,0x12,
+0x20,0x20,0x7c,0x84,0x08,0xfe,0x80,0xbc,0xa4,0xa4,0xb4,0xa8,0xa2,0x22,0x1e,0x00,
+/* 33267 0x81f3 "至" */
+0x00,0x7f,0x02,0x04,0x08,0x10,0x3f,0x00,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0xfc,0x00,0x00,0x20,0x10,0xf8,0x08,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 33268 0x81f4 "致" */
+0x00,0xfe,0x10,0x20,0x28,0x45,0xfe,0x12,0x10,0x10,0x7c,0x10,0x10,0x1e,0xf1,0x42,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 33269 0x81f5 "臵" */
+0x00,0xfe,0x10,0x20,0x29,0x44,0xfe,0x12,0x11,0x10,0x7c,0x10,0x10,0x1e,0xf0,0x40,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 33270 0x81f6 "臶" */
+0x00,0xfe,0x10,0x21,0x28,0x44,0xfe,0x12,0x11,0x12,0x7c,0x10,0x10,0x1e,0xf0,0x40,
+0x20,0x20,0x20,0xfe,0x40,0x40,0xbc,0x84,0x88,0x88,0xfe,0x88,0x88,0x88,0xa8,0x90,
+/* 33271 0x81f7 "臷" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x7f,0x10,0x22,0x7f,0x09,0x3e,0x08,0x0f,0xf0,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 33272 0x81f8 "臸" */
+0x00,0xfe,0x10,0x20,0x28,0x44,0xfe,0x12,0x10,0x10,0x7c,0x10,0x10,0x1e,0xf1,0x40,
+0x00,0xfe,0x10,0x20,0x44,0x82,0xfe,0x12,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 33273 0x81f9 "臹" */
+0x00,0xf8,0x20,0x40,0x53,0x8a,0xfa,0x2a,0x23,0xfa,0x22,0x22,0x3a,0xe5,0x44,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 33274 0x81fa "臺" */
+0x01,0xff,0x01,0x3f,0x00,0x1f,0x10,0x7f,0x40,0x9f,0x08,0x1f,0x01,0x3f,0x01,0xff,
+0x00,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xfe,0x02,0xf4,0x20,0xf0,0x00,0xf8,0x00,0xfe,
+/* 33275 0x81fb "臻" */
+0x00,0xf8,0x23,0x40,0x51,0x88,0xfb,0x28,0x21,0xfa,0x20,0x21,0x38,0xe0,0x43,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 33276 0x81fc "臼" */
+0x00,0x04,0x38,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x3f,0x20,0x00,
+0x00,0x00,0x78,0x08,0x08,0x08,0x08,0x78,0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 33277 0x81fd "臽" */
+0x04,0x04,0x0f,0x10,0x20,0x40,0x8c,0x30,0x20,0x20,0x3c,0x20,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xf0,0x10,0x20,0x40,0x00,0x78,0x08,0x08,0x78,0x08,0x08,0x08,0xf8,0x08,
+/* 33278 0x81fe "臾" */
+0x01,0x05,0x39,0x21,0x21,0x3d,0x21,0x21,0x21,0x3f,0x21,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x00,0x78,0x08,0x08,0x78,0x08,0x08,0x08,0xf8,0x08,0x80,0x40,0x20,0x18,0x06,
+/* 33279 0x81ff "臿" */
+0x00,0x01,0x3f,0x01,0xff,0x01,0x0d,0x31,0x21,0x21,0x3d,0x21,0x21,0x21,0x3f,0x20,
+0x10,0xf8,0x00,0x00,0xfe,0x00,0x00,0x78,0x08,0x08,0x78,0x08,0x08,0x08,0xf8,0x08,
+/* 33280 0x8200 "舀" */
+0x00,0x7f,0x02,0x21,0x11,0x10,0x0c,0x30,0x20,0x20,0x3c,0x20,0x20,0x20,0x3f,0x20,
+0xfc,0x00,0x08,0x08,0x10,0x20,0x00,0x78,0x08,0x08,0x78,0x08,0x08,0x08,0xf8,0x08,
+/* 33281 0x8201 "舁" */
+0x06,0x38,0x20,0x20,0x3e,0x20,0x20,0x3f,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 33282 0x8202 "舂" */
+0x01,0x01,0x7f,0x01,0x3f,0x02,0xff,0x04,0x08,0x34,0xd8,0x10,0x1c,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x40,0x20,0x18,0x76,0x10,0x70,0x10,0xf0,0x10,
+/* 33283 0x8203 "舃" */
+0x06,0x38,0x20,0x20,0x3e,0x20,0x20,0x3f,0x10,0x1f,0x20,0x3f,0x00,0x49,0x84,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 33284 0x8204 "舄" */
+0x06,0x38,0x20,0x20,0x3e,0x20,0x20,0x3f,0x10,0x3f,0x40,0x89,0x24,0x24,0x40,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x04,0x24,0x94,0x94,0x28,0x10,
+/* 33285 0x8205 "舅" */
+0x3e,0x20,0x3c,0x20,0x3f,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x02,0x7f,0x04,0x18,0x60,
+0x78,0x08,0x78,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x28,0x10,
+/* 33286 0x8206 "舆" */
+0x11,0x61,0x47,0x42,0x75,0x47,0x41,0x77,0x41,0x41,0xff,0x00,0x08,0x10,0x20,0x40,
+0x00,0x1c,0xc4,0x04,0x1c,0xc4,0x04,0xdc,0x04,0x04,0xfe,0x00,0x20,0x10,0x08,0x04,
+/* 33287 0x8207 "與" */
+0x0a,0x32,0x23,0x22,0x3a,0x23,0x20,0x3a,0x22,0x22,0xff,0x00,0x08,0x10,0x20,0x40,
+0x00,0x38,0x88,0x08,0x38,0x88,0x88,0xb8,0x88,0x88,0xfe,0x00,0x20,0x10,0x08,0x04,
+/* 33288 0x8208 "興" */
+0x00,0x2f,0x48,0x4b,0x68,0x4b,0x4a,0x6a,0x4b,0x48,0xff,0x00,0x08,0x10,0x20,0x40,
+0x00,0xec,0x24,0xa4,0x2c,0xa4,0xa4,0xac,0xa4,0x24,0xfe,0x00,0x20,0x10,0x08,0x04,
+/* 33289 0x8209 "舉" */
+0x0a,0x33,0x22,0x3b,0x20,0x3a,0x22,0xff,0x08,0x11,0x2f,0xc1,0x1f,0x01,0x01,0x01,
+0x00,0xb8,0x08,0xb8,0x88,0xb8,0x88,0xfe,0x20,0x10,0xe8,0x06,0xf0,0x00,0x00,0x00,
+/* 33290 0x820a "舊" */
+0x08,0xff,0x09,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x02,0x1c,0x10,0x1e,0x10,0x1f,
+0x20,0xfe,0x20,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x78,0x08,0x78,0x08,0xf8,
+/* 33291 0x820b "舋" */
+0x2f,0x48,0x4b,0x68,0x4b,0x6a,0x4b,0xff,0x80,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,
+0xec,0x24,0xa4,0x2c,0xa4,0xac,0xa4,0xfe,0x02,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,
+/* 33292 0x820c "舌" */
+0x00,0x00,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x10,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 33293 0x820d "舍" */
+0x01,0x02,0x04,0x08,0x30,0xcf,0x01,0x01,0x3f,0x01,0x01,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 33294 0x820e "舎" */
+0x01,0x02,0x04,0x09,0x31,0xcf,0x01,0x01,0x3f,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 33295 0x820f "舏" */
+0x04,0x0e,0x78,0x08,0x08,0xff,0x08,0x08,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x54,0x64,0x44,0x04,0x04,0x04,0x04,
+/* 33296 0x8210 "舐" */
+0x08,0x1c,0x71,0x11,0x11,0xfd,0x11,0x11,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 33297 0x8211 "舑" */
+0x08,0x1c,0x70,0x11,0x11,0xfd,0x11,0x11,0x7d,0x45,0x47,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 33298 0x8212 "舒" */
+0x10,0x11,0x28,0x44,0x82,0x7c,0x13,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x7c,0x44,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 33299 0x8213 "舓" */
+0x08,0x1d,0x71,0x11,0x11,0xfd,0x10,0x10,0x7d,0x46,0x44,0x44,0x45,0x7e,0x44,0x01,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0x80,0xfe,0x4a,0x4a,0x92,0x22,0x42,0x94,0x08,
+/* 33300 0x8214 "舔" */
+0x08,0x1d,0x70,0x10,0x11,0xfc,0x10,0x10,0x7d,0x46,0x44,0x44,0x44,0x7d,0x44,0x00,
+0x00,0xfc,0x20,0x20,0xfe,0x50,0x50,0x88,0x24,0x22,0x24,0xb2,0xaa,0x2a,0xa0,0x40,
+/* 33301 0x8215 "舕" */
+0x08,0x1c,0x70,0x11,0x10,0xfc,0x13,0x10,0x7c,0x44,0x44,0x45,0x44,0x7c,0x45,0x02,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 33302 0x8216 "舖" */
+0x10,0x10,0x2b,0x44,0x82,0x7d,0x11,0x11,0xff,0x11,0x11,0x7d,0x45,0x45,0x7d,0x45,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 33303 0x8217 "舗" */
+0x10,0x10,0x2b,0x54,0x92,0x7d,0x11,0x11,0xfd,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 33304 0x8218 "舘" */
+0x10,0x10,0x29,0x45,0x82,0x7c,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x10,0xfe,0x02,0x00,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 33305 0x8219 "舙" */
+0x00,0x3f,0x01,0xff,0x01,0x1f,0x10,0x1f,0x0c,0x70,0x10,0xfe,0x10,0x7c,0x44,0x7c,
+0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x0c,0x70,0x10,0xfe,0x10,0x7c,0x44,0x7c,
+/* 33306 0x821a "舚" */
+0x08,0x1c,0x71,0x13,0x11,0xfd,0x11,0x11,0x7d,0x45,0x45,0x45,0x45,0x7d,0x45,0x02,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 33307 0x821b "舛" */
+0x10,0x10,0x10,0x1e,0x12,0x22,0x22,0x52,0x8a,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x90,0x90,0x90,0x90,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 33308 0x821c "舜" */
+0x00,0x3f,0x01,0x10,0x08,0x7f,0x48,0x08,0x1e,0x22,0x52,0x0c,0x08,0x10,0x20,0x40,
+0x7c,0x80,0x08,0x88,0x90,0xfe,0x12,0x10,0xfc,0x10,0x90,0x90,0xfe,0x10,0x10,0x10,
+/* 33309 0x821d "舝" */
+0x02,0x3f,0x04,0xff,0x11,0x22,0x11,0x7f,0x44,0x88,0x1f,0x01,0x1f,0x21,0x3f,0x01,
+0x00,0xf0,0x10,0xfe,0x10,0x20,0x10,0xfe,0x02,0x24,0xf0,0x00,0xf0,0x00,0xf8,0x00,
+/* 33310 0x821e "舞" */
+0x10,0x3f,0x4a,0x0a,0x7f,0x0a,0x0a,0x7f,0x10,0x10,0x3e,0x42,0x14,0x08,0x30,0xc0,
+0x00,0xfc,0xa0,0xa0,0xfc,0xa0,0xa0,0xfc,0x10,0x10,0xfc,0x10,0x90,0xfe,0x10,0x10,
+/* 33311 0x821f "舟" */
+0x02,0x04,0x1f,0x10,0x12,0x11,0x11,0xff,0x10,0x12,0x11,0x11,0x20,0x20,0x40,0x80,
+0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 33312 0x8220 "舠" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4b,0x86,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 33313 0x8221 "舡" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 33314 0x8222 "舢" */
+0x10,0x20,0x7c,0x44,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x54,0x88,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 33315 0x8223 "舣" */
+0x10,0x20,0x7d,0x45,0x65,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x40,0x24,0x24,0x04,0x04,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 33316 0x8224 "舤" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x85,
+0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x58,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 33317 0x8225 "舥" */
+0x10,0x20,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x54,0x88,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 33318 0x8226 "舦" */
+0x10,0x20,0x7c,0x44,0x64,0x55,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 33319 0x8227 "舧" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x85,
+0x10,0x20,0x78,0x48,0x48,0x48,0x48,0x68,0x58,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 33320 0x8228 "舨" */
+0x10,0x20,0x7c,0x44,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x45,0x45,0x56,0x88,
+0x04,0x0e,0xf0,0x80,0x80,0xfc,0xa4,0xa4,0xa4,0xa8,0xa8,0x90,0x10,0x28,0x44,0x82,
+/* 33321 0x8229 "舩" */
+0x10,0x20,0x7c,0x44,0x64,0x55,0x55,0xfe,0x44,0x64,0x54,0x54,0x44,0x45,0x54,0x88,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x20,0x40,0x48,0x44,0x84,0xfe,0x82,0x00,
+/* 33322 0x822a "航" */
+0x10,0x20,0x7c,0x45,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x45,0x55,0x8a,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 33323 0x822b "舫" */
+0x10,0x20,0x7c,0x45,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 33324 0x822c "般" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x85,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 33325 0x822d "舭" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x88,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 33326 0x822e "舮" */
+0x10,0x20,0x7c,0x44,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x45,0x55,0x8a,
+0x20,0x10,0x10,0xfe,0x82,0x82,0x82,0xfe,0x82,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 33327 0x822f "舯" */
+0x10,0x20,0x7c,0x44,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x54,0x44,0x44,0x54,0x88,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 33328 0x8230 "舰" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 33329 0x8231 "舱" */
+0x10,0x20,0x7c,0x44,0x64,0x55,0x56,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x54,0x88,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 33330 0x8232 "舲" */
+0x08,0x10,0x3e,0x22,0x32,0x2b,0x2a,0xfe,0x23,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 33331 0x8233 "舳" */
+0x10,0x20,0x7c,0x44,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x89,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 33332 0x8234 "舴" */
+0x10,0x20,0x7c,0x44,0x65,0x55,0x56,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x54,0x88,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 33333 0x8235 "舵" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x10,0x10,0xfe,0x82,0x84,0x40,0x44,0x48,0x50,0x60,0x42,0x42,0x42,0x3e,0x00,
+/* 33334 0x8236 "舶" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x10,0x10,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 33335 0x8237 "舷" */
+0x10,0x20,0x7c,0x45,0x64,0x54,0x54,0xfc,0x45,0x64,0x54,0x54,0x44,0x45,0x54,0x88,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 33336 0x8238 "舸" */
+0x10,0x20,0x7d,0x44,0x64,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x44,0x44,0x54,0x88,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 33337 0x8239 "船" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xff,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x00,0x78,0x48,0x48,0x48,0x48,0x8e,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 33338 0x823a "舺" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x54,0x44,0x44,0x54,0x88,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 33339 0x823b "舻" */
+0x10,0x20,0x7c,0x44,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x45,0x55,0x8a,
+0x20,0x20,0x3c,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,0x80,0x80,0x00,0x00,0x00,
+/* 33340 0x823c "舼" */
+0x10,0x20,0x7c,0x44,0x65,0x54,0x54,0xfc,0x44,0x65,0x54,0x54,0x44,0x44,0x54,0x89,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0xfe,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 33341 0x823d "舽" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0xd6,0x10,0xfc,0x10,0x90,0xfe,0x10,0x10,0x10,
+/* 33342 0x823e "舾" */
+0x10,0x23,0x7c,0x44,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x89,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x54,0x8c,0x04,0x04,0x04,0xfc,0x04,
+/* 33343 0x823f "舿" */
+0x10,0x20,0x7b,0x48,0x68,0x59,0x4a,0xf8,0x4b,0x48,0x68,0x59,0x48,0x48,0x48,0x98,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 33344 0x8240 "艀" */
+0x10,0x20,0x7d,0x44,0x65,0x54,0x54,0xfd,0x44,0x64,0x57,0x54,0x44,0x44,0x54,0x88,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 33345 0x8241 "艁" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x10,0x50,0x50,0x7c,0x50,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 33346 0x8242 "艂" */
+0x10,0x20,0x7c,0x44,0x65,0x54,0x54,0xff,0x44,0x64,0x54,0x54,0x47,0x44,0x54,0x88,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 33347 0x8243 "艃" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x44,0x64,0x55,0x54,0x44,0x44,0x57,0x88,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 33348 0x8244 "艄" */
+0x10,0x21,0x7c,0x44,0x64,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x89,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 33349 0x8245 "艅" */
+0x10,0x20,0x7c,0x44,0x65,0x56,0x54,0xfc,0x47,0x64,0x55,0x55,0x46,0x44,0x54,0x88,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 33350 0x8246 "艆" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 33351 0x8247 "艇" */
+0x10,0x20,0x7b,0x48,0x68,0x59,0x49,0xfb,0x48,0x4a,0x6a,0x59,0x49,0x4a,0x4c,0x98,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 33352 0x8248 "艈" */
+0x10,0x20,0x7d,0x44,0x64,0x54,0x55,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x55,0x8a,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 33353 0x8249 "艉" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x8a,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x1c,0x70,0x1c,0x70,0x1e,0xf0,0x10,0x12,0x12,0x0e,
+/* 33354 0x824a "艊" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x22,0x42,0x4a,0x84,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0xfe,0x92,0x92,0x92,0x96,0x10,0x10,
+/* 33355 0x824b "艋" */
+0x10,0x21,0x7c,0x44,0x64,0x57,0x54,0xfc,0x44,0x65,0x55,0x55,0x45,0x45,0x57,0x88,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 33356 0x824c "艌" */
+0x10,0x20,0x78,0x48,0x69,0x5a,0x49,0xf8,0x48,0x48,0x68,0x5a,0x4a,0x4a,0x4c,0x98,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 33357 0x824d "艍" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x8a,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 33358 0x824e "艎" */
+0x10,0x20,0x7d,0x45,0x65,0x55,0x55,0xfc,0x47,0x64,0x54,0x55,0x44,0x44,0x57,0x88,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 33359 0x824f "艏" */
+0x10,0x20,0x7d,0x44,0x64,0x54,0x54,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x54,0x88,
+0x84,0x48,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 33360 0x8250 "艐" */
+0x10,0x21,0x7d,0x45,0x65,0x54,0x54,0xfd,0x44,0x64,0x54,0x55,0x44,0x44,0x54,0x89,
+0x50,0x24,0x54,0x04,0xfc,0x50,0x88,0x44,0x78,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 33361 0x8251 "艑" */
+0x10,0x20,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x56,0x54,0x44,0x44,0x54,0x88,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 33362 0x8252 "艒" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfc,0x44,0x64,0x54,0x54,0x44,0x44,0x54,0x88,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 33363 0x8253 "艓" */
+0x10,0x21,0x7d,0x47,0x65,0x55,0x55,0xfd,0x45,0x64,0x57,0x54,0x44,0x45,0x56,0x88,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 33364 0x8254 "艔" */
+0x10,0x20,0x7d,0x45,0x65,0x55,0x55,0xfd,0x45,0x65,0x55,0x55,0x45,0x45,0x55,0x8a,
+0x40,0x20,0xfe,0x48,0x48,0xfe,0x48,0x78,0x00,0xfc,0x44,0x48,0x28,0x10,0x28,0xc6,
+/* 33365 0x8255 "艕" */
+0x10,0x20,0x7d,0x44,0x64,0x55,0x55,0xfe,0x44,0x65,0x54,0x54,0x44,0x44,0x54,0x89,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 33366 0x8256 "艖" */
+0x10,0x20,0x7c,0x45,0x64,0x54,0x54,0xfd,0x44,0x64,0x54,0x55,0x46,0x44,0x55,0x88,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 33367 0x8257 "艗" */
+0x11,0x20,0x7c,0x44,0x67,0x54,0x54,0xfd,0x46,0x65,0x55,0x55,0x45,0x45,0x57,0x88,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 33368 0x8258 "艘" */
+0x10,0x21,0x7d,0x45,0x65,0x55,0x55,0xfd,0x44,0x65,0x54,0x54,0x44,0x44,0x54,0x8b,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 33369 0x8259 "艙" */
+0x10,0x20,0x7c,0x44,0x64,0x55,0x56,0xfc,0x44,0x64,0x54,0x54,0x45,0x45,0x56,0x88,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 33370 0x825a "艚" */
+0x10,0x20,0x7d,0x44,0x65,0x55,0x55,0xfd,0x45,0x64,0x54,0x54,0x44,0x44,0x54,0x88,
+0x50,0x50,0xfe,0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,
+/* 33371 0x825b "艛" */
+0x10,0x21,0x7d,0x47,0x65,0x55,0x54,0xfd,0x45,0x65,0x54,0x57,0x44,0x45,0x54,0x8b,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 33372 0x825c "艜" */
+0x11,0x21,0x7b,0x49,0x69,0x5a,0x4c,0xfb,0x4a,0x48,0x69,0x59,0x49,0x49,0x49,0x98,
+0x54,0x54,0xfe,0x54,0x54,0x72,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x24,0x2c,0x20,
+/* 33373 0x825d "艝" */
+0x10,0x21,0x78,0x4b,0x6a,0x59,0x48,0xf9,0x48,0x49,0x68,0x59,0x48,0x48,0x49,0x98,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 33374 0x825e "艞" */
+0x11,0x21,0x7d,0x46,0x64,0x54,0x55,0xfc,0x44,0x64,0x55,0x56,0x44,0x44,0x55,0x8a,
+0x10,0x10,0xde,0xa8,0x44,0x50,0x54,0xd8,0x50,0xd8,0x54,0x52,0x90,0x92,0x12,0x0e,
+/* 33375 0x825f "艟" */
+0x10,0x21,0x7c,0x44,0x67,0x54,0x55,0xfd,0x45,0x65,0x55,0x54,0x45,0x44,0x57,0x88,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 33376 0x8260 "艠" */
+0x10,0x23,0x78,0x49,0x68,0x59,0x4a,0xfc,0x49,0x49,0x69,0x59,0x49,0x48,0x4f,0x98,
+0x10,0xd2,0x54,0x48,0x8a,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 33377 0x8261 "艡" */
+0x10,0x21,0x78,0x4b,0x6a,0x58,0x48,0xf8,0x48,0x48,0x69,0x59,0x49,0x49,0x49,0x99,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 33378 0x8262 "艢" */
+0x10,0x20,0x7b,0x49,0x69,0x5a,0x4f,0xf8,0x49,0x49,0x69,0x59,0x49,0x49,0x49,0x99,
+0x20,0x20,0xfe,0x24,0x24,0xaa,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 33379 0x8263 "艣" */
+0x10,0x20,0x78,0x4b,0x6a,0x5b,0x4a,0xfa,0x4a,0x4a,0x6a,0x5a,0x4a,0x4d,0x48,0x99,
+0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x20,0xfc,0x44,0x8c,
+/* 33380 0x8264 "艤" */
+0x11,0x20,0x7b,0x48,0x69,0x58,0x4b,0xf8,0x49,0x48,0x6b,0x58,0x48,0x4b,0x48,0x99,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 33381 0x8265 "艥" */
+0x10,0x23,0x7a,0x4a,0x6b,0x58,0x4f,0xfa,0x4b,0x4a,0x6b,0x5a,0x4a,0x4f,0x48,0x98,
+0x10,0xd4,0x52,0x52,0xd0,0x10,0xfe,0x50,0xd2,0x52,0xd4,0x54,0xea,0x4a,0x56,0x62,
+/* 33382 0x8266 "艦" */
+0x10,0x23,0x7a,0x4b,0x6a,0x5b,0x4a,0xfb,0x48,0x49,0x69,0x59,0x49,0x49,0x4f,0x98,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 33383 0x8267 "艧" */
+0x10,0x23,0x7c,0x44,0x65,0x57,0x55,0xfd,0x45,0x65,0x55,0x55,0x47,0x44,0x54,0x8b,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 33384 0x8268 "艨" */
+0x10,0x23,0x78,0x4b,0x6a,0x59,0x48,0xfb,0x48,0x48,0x6b,0x58,0x4b,0x48,0x4b,0x98,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 33385 0x8269 "艩" */
+0x10,0x20,0x7b,0x48,0x68,0x5f,0x4a,0xfa,0x4d,0x48,0x69,0x59,0x49,0x49,0x49,0x9a,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 33386 0x826a "艪" */
+0x10,0x21,0x7e,0x45,0x65,0x55,0x55,0xfd,0x45,0x66,0x55,0x55,0x45,0x45,0x55,0x89,
+0x80,0xf8,0x08,0xfc,0x24,0xfc,0x24,0xfc,0x54,0x2a,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 33387 0x826b "艫" */
+0x10,0x20,0x78,0x4b,0x6a,0x5b,0x4a,0xfa,0x4a,0x4a,0x6a,0x5a,0x4a,0x4d,0x49,0x9b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 33388 0x826c "艬" */
+0x11,0x22,0x7b,0x4e,0x6b,0x5a,0x4b,0xfa,0x49,0x4a,0x6f,0x5a,0x4b,0x48,0x49,0x9a,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 33389 0x826d "艭" */
+0x11,0x22,0x7b,0x4e,0x6b,0x5a,0x4b,0xfa,0x4b,0x4a,0x6f,0x59,0x48,0x48,0x49,0x9e,
+0x08,0x94,0xde,0xb4,0xde,0x94,0xde,0x94,0xde,0x10,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 33390 0x826e "艮" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x22,0x22,0x21,0x20,0x24,0x28,0x30,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x08,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 33391 0x826f "良" */
+0x02,0x01,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x22,0x21,0x20,0x20,0x24,0x28,0x30,
+0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x08,0x10,0xa0,0x40,0x20,0x18,0x06,
+/* 33392 0x8270 "艰" */
+0x00,0x01,0xfd,0x05,0x45,0x45,0x29,0x29,0x11,0x11,0x29,0x29,0x45,0x45,0x81,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 33393 0x8271 "艱" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x14,0x22,0x41,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x52,0x52,0x54,0x48,0x48,0x44,0x62,0x40,
+/* 33394 0x8272 "色" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0x08,0xf8,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 33395 0x8273 "艳" */
+0x10,0x10,0x10,0xfd,0x12,0x15,0x11,0x7d,0x11,0x11,0x11,0xfd,0x11,0x11,0x10,0x10,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 33396 0x8274 "艴" */
+0x28,0x28,0x28,0xfe,0x2a,0x2a,0xfe,0xa8,0xa8,0xff,0x29,0x29,0x2d,0x4a,0x48,0x88,
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x54,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 33397 0x8275 "艵" */
+0x42,0x24,0x00,0x7e,0x25,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x40,0x40,0xfc,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 33398 0x8276 "艶" */
+0x28,0x28,0xfe,0xaa,0xff,0xaa,0xfe,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x48,0x3e,0xc0,
+0x40,0x40,0xf8,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 33399 0x8277 "艷" */
+0x2a,0x7f,0xaa,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0x00,0x7f,0x41,0x7f,0x22,0xff,
+0x10,0x10,0x9c,0xa4,0xc8,0xbe,0xaa,0xaa,0x2a,0xbe,0x20,0x20,0x22,0x22,0x22,0x9e,
+/* 33400 0x8278 "艸" */
+0x10,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0xfe,0x12,0x10,0x10,0x20,0x20,0x40,0x80,
+0x10,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0xfe,0x12,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 33401 0x8279 "艹" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 33402 0x827a "艺" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x00,0x03,0x04,0x08,0x10,0x20,0x20,0x1f,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xe0,0xc0,0x00,0x00,0x00,0x00,0x04,0x04,0xfc,0x00,
+/* 33403 0x827b "艻" */
+0x08,0x08,0xff,0x08,0x0a,0x02,0x02,0x7f,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 33404 0x827c "艼" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 33405 0x827d "艽" */
+0x08,0x08,0xff,0x08,0x08,0x04,0x04,0x7f,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 33406 0x827e "艾" */
+0x04,0x04,0xff,0x04,0x00,0x08,0x08,0x04,0x04,0x02,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 33407 0x827f "艿" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x10,0x20,0x7c,0x04,0x04,0x04,0x44,0x28,0x10,
+/* 33408 0x8280 "芀" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 33409 0x8281 "芁" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x0f,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 33410 0x8282 "节" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x7f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0x08,0x50,0x20,0x00,0x00,0x00,
+/* 33411 0x8283 "芃" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x0f,0x08,0x08,0x0a,0x09,0x09,0x10,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 33412 0x8284 "芄" */
+0x08,0x08,0xff,0x08,0x08,0x02,0x02,0x7f,0x02,0x0a,0x04,0x06,0x09,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 33413 0x8285 "芅" */
+0x08,0x08,0xff,0x08,0x0a,0x02,0x02,0x02,0xff,0x02,0x01,0x01,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x10,0x10,0xfe,0x00,0x00,0x00,0x00,0x80,0x42,0x32,0x0e,
+/* 33414 0x8286 "芆" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x12,0x11,0x08,0x04,0x02,0x01,0x02,0x04,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x30,0x0e,
+/* 33415 0x8287 "芇" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x21,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x00,
+/* 33416 0x8288 "芈" */
+0x09,0x09,0xf9,0x09,0x09,0x01,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x20,0x20,0x3e,0x20,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 33417 0x8289 "芉" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 33418 0x828a "芊" */
+0x04,0x04,0xff,0x04,0x00,0x00,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 33419 0x828b "芋" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 33420 0x828c "芌" */
+0x08,0xff,0x08,0x00,0x3f,0x00,0x00,0xff,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xa0,0x40,
+/* 33421 0x828d "芍" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x1f,0x20,0x40,0x88,0x04,0x02,0x02,0x00,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 33422 0x828e "芎" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 33423 0x828f "芏" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 33424 0x8290 "芐" */
+0x08,0x08,0xff,0x08,0x08,0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0x40,0x20,0x10,0x08,0x00,0x00,0x00,
+/* 33425 0x8291 "芑" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0x10,0xf0,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 33426 0x8292 "芒" */
+0x08,0x08,0xff,0x08,0x08,0x02,0x01,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 33427 0x8293 "芓" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x1f,0x00,0x00,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xe0,0x40,0x80,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 33428 0x8294 "芔" */
+0x01,0x21,0x21,0x21,0x3f,0x01,0x11,0x10,0x92,0x92,0x92,0xfe,0x22,0x20,0x40,0x80,
+0x00,0x08,0x08,0x08,0xf8,0x00,0x10,0x10,0x92,0x92,0x92,0xfe,0x12,0x10,0x10,0x10,
+/* 33429 0x8295 "芕" */
+0x08,0x08,0xff,0x08,0x0a,0x02,0x07,0x08,0x10,0x64,0x02,0x02,0x01,0x06,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 33430 0x8296 "芖" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x01,0xff,0x01,0x02,0x02,0x04,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfe,0x00,0x80,0x80,0x40,0x20,0x10,0x08,0x06,
+/* 33431 0x8297 "芗" */
+0x08,0x08,0xff,0x0a,0x04,0x08,0x1f,0x00,0x03,0x0c,0x3f,0x10,0x00,0x01,0x0e,0x70,
+0x20,0x20,0xfe,0x20,0x00,0x10,0xe0,0xc0,0x04,0x08,0xf0,0x20,0x40,0x80,0x00,0x00,
+/* 33432 0x8298 "芘" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x24,0x28,0x30,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x80,0x88,0x90,0xa0,0xc0,0x84,0x84,0x84,0x7c,0x00,
+/* 33433 0x8299 "芙" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x01,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 33434 0x829a "芚" */
+0x08,0x08,0xff,0x08,0x09,0x01,0xff,0x01,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x08,0x08,0x08,0xf8,0x0a,0x02,0x02,0xfe,
+/* 33435 0x829b "芛" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x02,0x02,0xff,0x02,0x04,0x3f,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xf0,0x10,0x00,0x00,0x00,
+/* 33436 0x829c "芜" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x02,0x02,0x7f,0x02,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x00,0x00,0xfc,0x80,0x80,0x80,0x84,0x84,0x7c,0x00,
+/* 33437 0x829d "芝" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x01,0x7f,0x00,0x00,0x03,0x0c,0x30,0x48,0x87,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xf8,0x30,0xc0,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 33438 0x829e "芞" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x20,0x5f,0x80,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x00,0xf8,0x00,0xf0,0x10,0x10,0x10,0x0a,0x06,0x02,
+/* 33439 0x829f "芟" */
+0x08,0x08,0xff,0x08,0x00,0x0f,0x08,0x10,0x60,0x00,0x1f,0x08,0x04,0x03,0x1c,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0xe0,0x20,0x20,0x1c,0x00,0xe0,0x20,0x40,0x80,0x70,0x0e,
+/* 33440 0x82a0 "芠" */
+0x08,0x08,0xff,0x08,0x08,0x02,0x01,0x7f,0x08,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfc,0x20,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 33441 0x82a1 "芡" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x0f,0x10,0x21,0x41,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xfc,0x04,0x08,0x00,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 33442 0x82a2 "芢" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x08,0x13,0x30,0x50,0x90,0x10,0x10,0x17,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 33443 0x82a3 "芣" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x7f,0x00,0x01,0x03,0x05,0x09,0x31,0xc1,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x80,0x00,0x00,0x60,0x18,0x04,0x02,0x00,0x00,
+/* 33444 0x82a4 "芤" */
+0x04,0x04,0xff,0x04,0x00,0x7f,0x02,0x04,0x08,0x0f,0xf8,0x48,0x08,0x08,0x28,0x10,
+0x40,0x40,0xfe,0x40,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 33445 0x82a5 "芥" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x04,0x08,0x34,0xc4,0x04,0x04,0x08,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x40,0x20,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 33446 0x82a6 "芦" */
+0x08,0x08,0xff,0x08,0x09,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x40,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x20,0x80,0xf8,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 33447 0x82a7 "芧" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x00,0x06,0x01,0xff,0x00,0x00,0x00,0x00,0x02,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x20,0x40,0x80,0xfe,0x82,0x84,0x80,0x80,0x80,0x00,
+/* 33448 0x82a8 "芨" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x08,0x08,0x0c,0x0a,0x11,0x10,0x20,0x20,0x43,0x8c,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x20,0x40,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,
+/* 33449 0x82a9 "芩" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x04,0x0a,0x31,0xc1,0x1f,0x00,0x00,0x00,0x00,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x40,0x20,0x18,0x06,0xe0,0x20,0x40,0x40,0x80,0x00,
+/* 33450 0x82aa "芪" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x28,0x30,0x20,
+0x20,0x20,0xfe,0x20,0x78,0x80,0x80,0x80,0x80,0xfe,0x40,0x40,0x24,0x14,0x0c,0x04,
+/* 33451 0x82ab "芫" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x00,0x00,0xfc,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 33452 0x82ac "芬" */
+0x08,0x08,0xff,0x08,0x00,0x04,0x08,0x10,0x20,0xdf,0x04,0x04,0x08,0x10,0x21,0x40,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x20,0x10,0x08,0xe6,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 33453 0x82ad "芭" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x02,0x02,0x02,0xfe,0x00,
+/* 33454 0x82ae "芮" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x21,0x21,0x22,0x24,0x28,0x20,0x20,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x88,0x48,0x28,0x08,0x08,0x28,0x10,
+/* 33455 0x82af "芯" */
+0x08,0x08,0xff,0x08,0x08,0x02,0x01,0x00,0x04,0x24,0x24,0x44,0x84,0x04,0x03,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x80,0x08,0x04,0x02,0x02,0x10,0x10,0xf0,0x00,
+/* 33456 0x82b0 "芰" */
+0x08,0x08,0xff,0x09,0x01,0x7f,0x01,0x01,0x3f,0x08,0x04,0x02,0x01,0x06,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf0,0x20,0x40,0x80,0x00,0xc0,0x30,0x0e,
+/* 33457 0x82b1 "花" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x08,0x10,0x30,0x50,0x91,0x12,0x14,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x88,0x90,0xa0,0xc0,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 33458 0x82b2 "芲" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x0c,0x30,0xc8,0x08,0x0f,0x78,0x08,0x08,0x07,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x60,0x18,0x06,0xe0,0x00,0x08,0x08,0x08,0xf8,0x00,
+/* 33459 0x82b3 "芳" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0xff,0x04,0x04,0x07,0x04,0x08,0x08,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xa0,0x40,
+/* 33460 0x82b4 "芴" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x1f,0x22,0x42,0x84,0x08,0x11,0x22,0x44,0x08,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xf8,0x48,0x48,0x88,0x88,0x08,0x08,0x08,0x50,0x20,
+/* 33461 0x82b5 "芵" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x01,0x01,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf0,0x10,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 33462 0x82b6 "芶" */
+0x08,0x08,0xff,0x08,0x10,0x1f,0x20,0x44,0x84,0x09,0x10,0x3f,0x10,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0x08,0x08,0x88,0xc8,0x48,0x08,0x50,0x20,
+/* 33463 0x82b7 "芷" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x11,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 33464 0x82b8 "芸" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x00,0x00,0xff,0x02,0x04,0x08,0x10,0x3f,0x10,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0xf8,0x08,
+/* 33465 0x82b9 "芹" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x20,0x20,0x40,0x80,
+0x20,0x20,0xfe,0x20,0x38,0xc0,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 33466 0x82ba "芺" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x01,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0xf0,0x00,0x00,0x00,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 33467 0x82bb "芻" */
+0x08,0x08,0x1f,0x22,0x52,0x1f,0x04,0x08,0x30,0x1f,0x22,0x52,0x9f,0x04,0x08,0x30,
+0x00,0x00,0xf8,0x08,0x48,0xc8,0x08,0x50,0x20,0xf8,0x08,0x48,0xc8,0x08,0x50,0x20,
+/* 33468 0x82bc "芼" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x01,0x01,0x3f,0x01,0x01,0x7f,0x01,0x01,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfc,0x02,0x02,0x02,0xfe,
+/* 33469 0x82bd "芽" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x00,0x10,0x20,0x3f,0x01,0x02,0x0c,0x30,0xc0,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 33470 0x82be "芾" */
+0x08,0x08,0xff,0x08,0x09,0x01,0xff,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x21,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0x28,0x10,0x00,
+/* 33471 0x82bf "芿" */
+0x08,0x08,0xff,0x08,0x10,0x17,0x21,0x21,0x61,0xa1,0x21,0x21,0x22,0x22,0x24,0x28,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x10,0x20,0x3c,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 33472 0x82c0 "苀" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x7f,0x00,0x00,0x0f,0x08,0x08,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,0x00,
+/* 33473 0x82c1 "苁" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x08,0x08,0x08,0x08,0x08,0x14,0x12,0x22,0x41,0x82,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 33474 0x82c2 "苂" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x11,0x11,0x11,0x21,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x08,0x08,0x10,0x20,0x80,0x80,0x40,0x20,0x18,0x06,
+/* 33475 0x82c3 "苃" */
+0x08,0x08,0xff,0x08,0x0a,0x02,0xff,0x04,0x04,0x0f,0x08,0x14,0x22,0x41,0x86,0x38,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x70,0x0e,
+/* 33476 0x82c4 "苄" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x01,0xff,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfe,0x00,0x00,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 33477 0x82c5 "苅" */
+0x08,0x08,0xff,0x08,0x08,0x02,0x42,0x24,0x14,0x08,0x08,0x14,0x24,0x42,0x82,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x14,0x08,
+/* 33478 0x82c6 "苆" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x21,0x2c,0xf0,0x20,0x20,0x24,0x28,0x31,0x22,0x04,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 33479 0x82c7 "苇" */
+0x08,0x08,0xff,0x09,0x01,0x7f,0x01,0x01,0x1f,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf0,0x00,0x00,0xfc,0x04,0x04,0x14,0x08,
+/* 33480 0x82c8 "苈" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x2f,0x21,0x21,0x22,0x22,0x44,0x48,0x90,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 33481 0x82c9 "苉" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x22,0x22,0x22,0x22,0x24,0x24,0x28,0x20,0x3f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x40,0x40,0x40,0x44,0x44,0x3c,0x00,0x00,0xfc,0x00,
+/* 33482 0x82ca "苊" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x44,0x44,0x83,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xe0,0x20,0x20,0xa0,0x44,0x04,0x04,0xfc,
+/* 33483 0x82cb "苋" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x80,0x82,0x82,0x7e,
+/* 33484 0x82cc "苌" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x09,0x0e,0x08,0xff,0x09,0x08,0x08,0x0a,0x0c,0x08,
+0x40,0x40,0xfe,0x40,0x00,0x30,0xc0,0x00,0x00,0xfe,0x00,0x80,0x40,0x30,0x0e,0x00,
+/* 33485 0x82cd "苍" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x04,0x08,0x30,0xcf,0x08,0x08,0x08,0x08,0x08,0x07,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x40,0x20,0x18,0xe6,0x20,0x20,0xa8,0x48,0x08,0xf8,
+/* 33486 0x82ce "苎" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x7f,0x40,0x80,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,
+/* 33487 0x82cf "苏" */
+0x08,0x08,0xff,0x08,0x0a,0x02,0x7f,0x02,0x02,0x22,0x22,0x24,0x44,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf0,0x10,0x14,0x12,0x12,0x12,0x10,0x10,0xa0,0x40,
+/* 33488 0x82d0 "苐" */
+0x08,0xff,0x08,0x00,0x3f,0x01,0x01,0x3f,0x21,0x21,0x3f,0x03,0x05,0x19,0xe1,0x01,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0x28,0x10,0x00,
+/* 33489 0x82d1 "苑" */
+0x04,0x04,0xff,0x04,0x10,0x1e,0x12,0x22,0x22,0x52,0x8c,0x04,0x08,0x10,0x20,0x40,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x88,0x88,0x88,0xa8,0x90,0x82,0x82,0x82,0x7e,0x00,
+/* 33490 0x82d2 "苒" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0xff,0x20,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x08,0x28,0x10,
+/* 33491 0x82d3 "苓" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x0a,0x31,0xc1,0x1f,0x00,0x00,0x0c,0x03,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0x18,0x06,0xe0,0x20,0x40,0x80,0x00,0x80,0x40,
+/* 33492 0x82d4 "苔" */
+0x08,0x08,0xff,0x08,0x04,0x08,0x10,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x20,0x10,0xf8,0x08,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33493 0x82d5 "苕" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x04,0x08,0x10,0x20,0xdf,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0x50,0x20,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33494 0x82d6 "苖" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33495 0x82d7 "苗" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x21,0x21,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33496 0x82d8 "苘" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x27,0x20,0x20,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 33497 0x82d9 "苙" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x00,0x7f,0x00,0x10,0x08,0x04,0x04,0x00,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfc,0x10,0x10,0x20,0x40,0x80,0x00,0xfe,0x00,
+/* 33498 0x82da "苚" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x41,0x41,0x80,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 33499 0x82db "苛" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x00,0x00,0x1f,0x11,0x11,0x1f,0x11,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 33500 0x82dc "苜" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 33501 0x82dd "苝" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x04,0x04,0x7c,0x04,0x04,0x04,0x0c,0x34,0xc4,0x04,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 33502 0x82de "苞" */
+0x04,0x04,0xff,0x04,0x08,0x1f,0x20,0x5f,0x10,0x10,0x1f,0x10,0x10,0x10,0x0f,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x10,0x90,0x90,0x90,0x90,0x50,0x24,0x04,0xfc,0x00,
+/* 33503 0x82df "苟" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x20,0x40,0x9f,0x10,0x10,0x1f,0x10,0x00,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0x08,0x50,0x20,
+/* 33504 0x82e0 "苠" */
+0x08,0x08,0xff,0x08,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x24,0x28,0x30,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfc,0x40,0x24,0x14,0x0c,0x04,
+/* 33505 0x82e1 "苡" */
+0x08,0x08,0xff,0x08,0x00,0x24,0x22,0x21,0x21,0x20,0x20,0x24,0x28,0x30,0x21,0x06,
+0x20,0x20,0xfe,0x20,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 33506 0x82e2 "苢" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 33507 0x82e3 "苣" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0x00,0xfc,
+/* 33508 0x82e4 "苤" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x00,0x01,0x03,0x05,0x19,0x61,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x80,0x00,0x60,0x10,0x08,0x04,0x00,0x00,0xfe,0x00,
+/* 33509 0x82e5 "若" */
+0x08,0x08,0xff,0x08,0x0a,0x02,0xff,0x04,0x08,0x1f,0x28,0x48,0x88,0x08,0x0f,0x08,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 33510 0x82e6 "苦" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x01,0xff,0x01,0x01,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33511 0x82e7 "苧" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x7f,0x40,0x80,0x3f,0x01,0x01,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 33512 0x82e8 "苨" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x10,0x1f,0x10,0x12,0x12,0x13,0x22,0x22,0x41,0x80,
+0x40,0x40,0xfe,0x40,0xf8,0x08,0x08,0xf8,0x00,0x00,0x38,0xc0,0x04,0x04,0xfc,0x00,
+/* 33513 0x82e9 "苩" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33514 0x82ea "苪" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x01,0x3f,0x21,0x22,0x24,0x28,0x20,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf8,0x08,0x88,0x48,0x28,0x08,0x28,0x10,
+/* 33515 0x82eb "苫" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33516 0x82ec "苬" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x21,0x21,0x22,0x24,0x28,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0x08,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 33517 0x82ed "苭" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x21,0x24,0x44,0xf8,0x10,0x20,0x48,0xfc,0x45,0x02,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 33518 0x82ee "苮" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x08,0x10,0x31,0x51,0x91,0x11,0x11,0x11,0x11,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 33519 0x82ef "苯" */
+0x08,0x08,0xff,0x08,0x01,0x01,0x7f,0x03,0x05,0x09,0x11,0x2f,0xc1,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfc,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0x00,0x00,
+/* 33520 0x82f0 "苰" */
+0x08,0x08,0xff,0x08,0x00,0x7e,0x02,0x02,0x3e,0x20,0x40,0x7e,0x02,0x02,0x14,0x08,
+0x20,0x20,0xfe,0x20,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 33521 0x82f1 "英" */
+0x08,0x08,0xff,0x08,0x01,0x01,0x1f,0x11,0x11,0x11,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xf0,0x10,0x10,0x10,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 33522 0x82f2 "苲" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x1f,0x24,0x44,0x87,0x04,0x04,0x07,0x04,0x04,0x04,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xfc,0x00,0x00,0xf0,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 33523 0x82f3 "苳" */
+0x08,0x08,0xff,0x08,0x04,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe3,0x00,0x0e,0x01,0x00,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xc0,0x00,0x80,0x40,
+/* 33524 0x82f4 "苴" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 33525 0x82f5 "苵" */
+0x08,0x08,0xff,0x08,0x01,0x11,0x1f,0x21,0x01,0xff,0x01,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x80,0x40,0x20,0x18,0x06,
+/* 33526 0x82f6 "苶" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x04,0x09,0x31,0xc1,0x01,0x09,0x11,0x21,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x40,0x20,0x18,0x06,0x00,0x20,0x10,0x08,0x00,0x00,
+/* 33527 0x82f7 "苷" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xff,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x40,0x40,0xfe,0x40,0x10,0x10,0xfe,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33528 0x82f8 "苸" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x3f,0x11,0x09,0x01,0xff,0x01,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x10,0xf8,0x00,0x10,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 33529 0x82f9 "苹" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x11,0x09,0x09,0x01,0xff,0x01,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x10,0x10,0x20,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 33530 0x82fa "苺" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x12,0x11,0xff,0x10,0x22,0x21,0x3f,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0x10,0xfc,0x10,0xa0,0x40,
+/* 33531 0x82fb "苻" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x10,0x13,0x30,0x51,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x10,0x10,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 33532 0x82fc "苼" */
+0x08,0x08,0xff,0x09,0x11,0x11,0x3f,0x41,0x81,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfc,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 33533 0x82fd "苽" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x1f,0x12,0x12,0x12,0x12,0x12,0x22,0x22,0x43,0x82,
+0x20,0x20,0xfe,0x20,0x00,0x78,0xa0,0x20,0x20,0x20,0x10,0x90,0x48,0xa8,0x24,0x02,
+/* 33534 0x82fe "苾" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x00,0x08,0x48,0x48,0x48,0x89,0x0e,0x18,0xe7,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x90,0x90,0x24,0x42,0x82,0x02,0x10,0x10,0xf0,0x00,
+/* 33535 0x82ff "苿" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x01,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 33536 0x8300 "茀" */
+0x08,0x08,0xff,0x08,0x04,0x3f,0x04,0x04,0x1f,0x14,0x24,0x3f,0x08,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x40,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0x44,0x54,0x48,0x40,
+/* 33537 0x8301 "茁" */
+0x08,0x08,0xff,0x08,0x09,0x21,0x21,0x21,0x3f,0x01,0x01,0x41,0x41,0x41,0x7f,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x08,0x08,0x08,0xf8,0x08,0x00,0x04,0x04,0x04,0xfc,0x04,
+/* 33538 0x8302 "茂" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x41,0x86,
+0x20,0x20,0xfe,0x20,0x90,0x88,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 33539 0x8303 "范" */
+0x04,0x04,0xff,0x04,0x10,0x09,0x49,0x21,0x25,0x05,0x09,0x71,0x11,0x11,0x10,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0x08,0x28,0x10,0x02,0x02,0x02,0xfe,0x00,
+/* 33540 0x8304 "茄" */
+0x08,0x08,0xff,0x08,0x00,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x20,0x20,0xfe,0x20,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 33541 0x8305 "茅" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x00,0x06,0x01,0xff,0x02,0x04,0x08,0x30,0xc2,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x20,0x40,0x80,0xfe,0x82,0x84,0x80,0x80,0x80,0x00,
+/* 33542 0x8306 "茆" */
+0x08,0x08,0xff,0x08,0x00,0x0c,0x70,0x40,0x44,0x44,0x5c,0x64,0x48,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,
+/* 33543 0x8307 "茇" */
+0x04,0x04,0xff,0x04,0x02,0x02,0xff,0x04,0x04,0x0f,0x08,0x14,0x22,0x41,0x86,0x38,
+0x40,0x40,0xfe,0x40,0x10,0x08,0xfe,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x70,0x0e,
+/* 33544 0x8308 "茈" */
+0x08,0x08,0xff,0x08,0x04,0x04,0x24,0x24,0x27,0x24,0x24,0x24,0x24,0x2f,0xf0,0x40,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x44,0x48,0x50,0x60,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 33545 0x8309 "茉" */
+0x08,0x08,0xff,0x09,0x01,0x01,0xff,0x01,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfe,0x00,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 33546 0x830a "茊" */
+0x04,0x04,0xff,0x04,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0xff,0x00,
+0x40,0x40,0xfe,0x40,0x10,0x78,0x80,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 33547 0x830b "茋" */
+0x08,0x08,0xff,0x08,0x08,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x22,0x29,0x30,0x20,
+0x20,0x20,0xfe,0x20,0x78,0x80,0x80,0x80,0x80,0xfe,0x40,0x40,0x24,0x14,0x8c,0x84,
+/* 33548 0x830c "茌" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x10,0x10,0x37,0x50,0x90,0x10,0x10,0x10,0x13,0x10,
+0x40,0x40,0xfe,0x40,0x00,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0xfc,0x00,
+/* 33549 0x830d "茍" */
+0x04,0x04,0xfc,0x04,0x14,0x10,0x1f,0x20,0x40,0x9f,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x40,0x40,0x7e,0x40,0x40,0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0x88,0x08,0x50,0x20,
+/* 33550 0x830e "茎" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x00,0x01,0x0e,0x70,0x1f,0x01,0x01,0x01,0xff,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x60,0x80,0x70,0x0c,0xf0,0x00,0x00,0x00,0xfe,0x00,
+/* 33551 0x830f "茏" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x04,0x7f,0x04,0x04,0x08,0x08,0x10,0x23,0x4c,0x80,
+0x20,0x20,0xfe,0x20,0x20,0x40,0x20,0xfc,0x80,0x88,0x90,0xa0,0xc2,0x82,0x82,0x7e,
+/* 33552 0x8310 "茐" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x1f,0x22,0x4a,0x84,0x0a,0x11,0x22,0x44,0x08,0x10,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xf8,0x48,0x48,0x88,0x88,0x08,0x88,0x08,0x50,0x20,
+/* 33553 0x8311 "茑" */
+0x08,0x08,0xff,0x09,0x02,0x1f,0x12,0x11,0x11,0x10,0x1f,0x00,0x7f,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0x50,0x20,0xfc,0x04,0xe4,0x04,0x28,0x10,
+/* 33554 0x8312 "茒" */
+0x04,0x04,0xff,0x04,0x10,0x1e,0x12,0x22,0x22,0x52,0x8c,0x04,0x08,0x10,0x20,0x40,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x48,0x50,0x48,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 33555 0x8313 "茓" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x7f,0x40,0x80,0x04,0x04,0x08,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfe,0x02,0x04,0x40,0x40,0x20,0x20,0x10,0x08,0x06,
+/* 33556 0x8314 "茔" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x81,0x01,0x3f,0x01,0x01,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 33557 0x8315 "茕" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x80,0x1f,0x04,0x04,0x3f,0x04,0x04,0x04,0x04,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xe0,0x20,0x20,0xa0,0x20,0x14,0x0c,0x04,
+/* 33558 0x8316 "茖" */
+0x04,0x04,0xff,0x04,0x08,0x0f,0x10,0x2c,0x03,0x1c,0xe0,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x10,
+/* 33559 0x8317 "茗" */
+0x08,0x08,0xff,0x08,0x02,0x07,0x08,0x34,0x02,0x01,0x0f,0x18,0xe8,0x08,0x0f,0x08,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x10,0x20,0x40,0x80,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33560 0x8318 "茘" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x04,0x08,0x30,0x00,0x7e,0x12,0x12,0x22,0x4a,0x85,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x50,0x20,0x00,0xfc,0x24,0x24,0x44,0x94,0x08,
+/* 33561 0x8319 "茙" */
+0x08,0x08,0xff,0x08,0x00,0x00,0xff,0x00,0x10,0x10,0x7e,0x10,0x10,0x20,0x41,0x86,
+0x20,0x20,0xfe,0x20,0x90,0x88,0xfe,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 33562 0x831a "茚" */
+0x08,0x08,0xff,0x08,0x06,0x78,0x40,0x40,0x7e,0x40,0x40,0x40,0x4e,0x70,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x94,0x88,0x80,0x80,0x80,
+/* 33563 0x831b "茛" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x22,0x21,0x20,0x24,0x28,0x30,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0x10,0xa0,0x40,0x30,0x0e,
+/* 33564 0x831c "茜" */
+0x04,0x04,0xff,0x04,0x00,0xff,0x04,0x04,0x3f,0x24,0x24,0x28,0x30,0x20,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xfe,0x40,0x40,0xf8,0x48,0x48,0x48,0x38,0x08,0xf8,0x08,
+/* 33565 0x831d "茝" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x80,0x80,0xf8,0x08,0x08,0xf8,0x80,0x80,0xfe,0x00,
+/* 33566 0x831e "茞" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x3f,0x21,0x21,0x3f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x00,
+/* 33567 0x831f "茟" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x3f,0x01,0xff,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,0x00,
+/* 33568 0x8320 "茠" */
+0x04,0x04,0xff,0x04,0x00,0x08,0x08,0x10,0x37,0x50,0x91,0x11,0x12,0x14,0x18,0x10,
+0x40,0x40,0xfe,0x40,0x00,0x40,0x40,0x40,0xfc,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 33569 0x8321 "茡" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x04,0x08,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 33570 0x8322 "茢" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x08,0x08,0x1f,0x21,0x51,0x0a,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 33571 0x8323 "茣" */
+0x04,0x04,0xff,0x04,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 33572 0x8324 "茤" */
+0x08,0xff,0x08,0x02,0x07,0x18,0x64,0x03,0x0c,0x71,0x06,0x1a,0x01,0x00,0x07,0x78,
+0x20,0xfe,0x20,0x00,0xe0,0x40,0x80,0x20,0x40,0xf8,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 33573 0x8325 "茥" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x01,0x01,0xff,0x00,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 33574 0x8326 "茦" */
+0x08,0x08,0xff,0x09,0x01,0xff,0x01,0x3f,0x21,0x21,0x21,0x23,0x05,0x19,0xe1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0xf8,0x08,0x08,0x28,0x90,0x60,0x18,0x06,0x00,
+/* 33575 0x8327 "茧" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x3f,0x21,0x21,0x21,0x3f,0x01,0x01,0x01,0x7f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x10,0xf8,0x04,0x04,
+/* 33576 0x8328 "茨" */
+0x08,0x08,0xff,0x08,0x40,0x20,0x20,0x09,0x12,0x14,0x20,0xe0,0x20,0x21,0x22,0x2c,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0x04,0x48,0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 33577 0x8329 "茩" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x17,0x24,0x24,0x47,0x84,
+0x20,0x20,0xfe,0x20,0x78,0x80,0x00,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 33578 0x832a "茪" */
+0x08,0x08,0xff,0x08,0x01,0x11,0x09,0x09,0xff,0x04,0x04,0x04,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0x10,0x10,0x20,0xfe,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 33579 0x832b "茫" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x10,0x87,0x49,0x09,0x11,0xe1,0x21,0x21,0x21,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x40,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,
+/* 33580 0x832c "茬" */
+0x08,0x08,0xff,0x0a,0x02,0x04,0xff,0x08,0x10,0x30,0x53,0x90,0x10,0x10,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfe,0x00,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 33581 0x832d "茭" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x7f,0x08,0x10,0x24,0x44,0x02,0x01,0x06,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x20,0x10,0x48,0x44,0x80,0x00,0xc0,0x30,0x0e,
+/* 33582 0x832e "茮" */
+0x08,0x08,0xff,0x0a,0x02,0x03,0x02,0x02,0xff,0x00,0x01,0x11,0x11,0x21,0x45,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x10,0x08,0x04,0x04,0x00,
+/* 33583 0x832f "茯" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x08,0x10,0x37,0x50,0x90,0x10,0x11,0x11,0x12,0x14,
+0x20,0x20,0xfe,0x20,0x00,0x50,0x48,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 33584 0x8330 "茰" */
+0x08,0xff,0x09,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x11,0x0a,0x06,0x19,0xe0,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0x00,0xc0,0x3e,
+/* 33585 0x8331 "茱" */
+0x04,0x04,0xff,0x05,0x11,0x11,0x3f,0x41,0x01,0xff,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xf8,0x00,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 33586 0x8332 "茲" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x20,0x24,0x44,0x78,0x08,0x10,0x14,0x22,0x7e,0x02,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x40,0x48,0x88,0xf0,0x10,0x20,0x28,0x44,0xfc,0x04,
+/* 33587 0x8333 "茳" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x17,0x90,0x40,0x48,0x08,0x10,0xe0,0x20,0x2f,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 33588 0x8334 "茴" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x08,0x08,0xf8,0x08,
+/* 33589 0x8335 "茵" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x21,0x21,0x2f,0x21,0x22,0x24,0x28,0x20,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xe8,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 33590 0x8336 "茶" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x04,0x09,0x31,0xdf,0x01,0x09,0x11,0x21,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x40,0x20,0x18,0xf6,0x00,0x20,0x10,0x08,0x00,0x00,
+/* 33591 0x8337 "茷" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfe,0x20,0x00,0xa0,0x90,0x80,0xfc,0x80,0x48,0x50,0x24,0x54,0x8c,0x04,
+/* 33592 0x8338 "茸" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x3e,0xd0,0x10,0x10,0x10,
+/* 33593 0x8339 "茹" */
+0x08,0x08,0xff,0x08,0x10,0x10,0xfe,0x12,0x22,0x22,0x64,0x14,0x08,0x14,0x22,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 33594 0x833a "茺" */
+0x08,0x08,0xff,0x0a,0x01,0xff,0x04,0x08,0x10,0x3f,0x04,0x04,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0x20,0x10,0xf8,0x48,0x40,0x40,0x44,0x44,0x3c,
+/* 33595 0x833b "茻" */
+0x10,0x92,0x92,0x92,0xfe,0x20,0x40,0x80,0x10,0x92,0x92,0x92,0xfe,0x22,0x20,0x40,
+0x10,0x92,0x92,0x92,0xfe,0x10,0x10,0x00,0x10,0x92,0x92,0x92,0xfe,0x12,0x10,0x10,
+/* 33596 0x833c "茼" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x2f,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xe8,0x08,0xc8,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 33597 0x833d "茽" */
+0x08,0x08,0xff,0x08,0x00,0x10,0x10,0x27,0x64,0xa4,0x24,0x27,0x24,0x20,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x00,0x40,0x40,0xfc,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,
+/* 33598 0x833e "茾" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x7f,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 33599 0x833f "茿" */
+0x08,0x08,0xff,0x08,0x08,0x00,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe2,0x42,0x04,0x08,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xf0,0x10,0x10,0x90,0x50,0x12,0x12,0x12,0x0e,0x00,
+/* 33600 0x8340 "荀" */
+0x04,0x04,0xff,0x14,0x10,0x1f,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x00,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xc8,0x48,0x08,0x50,0x20,
+/* 33601 0x8341 "荁" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x00,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x00,0xfe,0x00,
+/* 33602 0x8342 "荂" */
+0x08,0xff,0x0a,0x02,0x7f,0x04,0x08,0x37,0xc0,0x3f,0x08,0x0f,0x00,0x00,0x01,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x40,0x20,0xd8,0x06,0xf8,0x00,0xe0,0x20,0x20,0x40,0x80,
+/* 33603 0x8343 "荃" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x08,0x30,0xcf,0x01,0x01,0x1f,0x01,0x01,0x7f,0x00,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0x18,0xe6,0x00,0x00,0xf0,0x00,0x00,0xfc,0x00,
+/* 33604 0x8344 "荄" */
+0x08,0x08,0xff,0x08,0x0a,0x01,0x7f,0x04,0x08,0x1f,0x01,0x06,0x38,0x01,0x0e,0x70,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x00,0x40,0x80,0x10,0x20,0x40,0xa0,0x10,0x08,
+/* 33605 0x8345 "荅" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x0c,0x30,0xcf,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x60,0x18,0xe6,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33606 0x8346 "荆" */
+0x12,0x12,0xff,0x12,0x00,0x7f,0x12,0x12,0x12,0xff,0x12,0x12,0x22,0x22,0x42,0x82,
+0x04,0x04,0xc4,0x24,0x24,0xa4,0x24,0x24,0x24,0xe4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 33607 0x8347 "荇" */
+0x04,0x04,0xff,0x04,0x10,0x21,0x40,0x88,0x13,0x30,0x50,0x90,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 33608 0x8348 "荈" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x3e,0x22,0x42,0xa4,0x14,0x08,0x10,0x20,0x40,0x80,
+0x40,0x40,0xfe,0x40,0x10,0x10,0x10,0xfc,0x10,0x90,0x90,0xfe,0x10,0x10,0x10,0x10,
+/* 33609 0x8349 "草" */
+0x04,0x04,0xff,0x04,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 33610 0x834a "荊" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x12,0x12,0x12,0xff,0x12,0x12,0x22,0x22,0x42,0x82,
+0x20,0x20,0xfe,0x20,0x04,0x84,0x24,0x24,0x24,0xe4,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 33611 0x834b "荋" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x02,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 33612 0x834c "荌" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x82,0x02,0xff,0x04,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x40,0x80,0x70,0x08,
+/* 33613 0x834d "荍" */
+0x08,0x08,0xff,0x08,0x04,0x44,0x44,0x44,0x45,0x46,0x5c,0x64,0x44,0x04,0x04,0x05,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x80,0xfe,0x08,0x88,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 33614 0x834e "荎" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x04,0x08,0x1f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x20,0xf0,0x10,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 33615 0x834f "荏" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x13,0x30,0x50,0x9f,0x10,0x10,0x10,0x10,0x17,0x10,
+0x40,0x40,0xfe,0x40,0x10,0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0xfc,0x00,
+/* 33616 0x8350 "荐" */
+0x08,0x08,0xff,0x0a,0x02,0x7f,0x04,0x09,0x08,0x18,0x2b,0x48,0x88,0x08,0x08,0x08,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 33617 0x8351 "荑" */
+0x08,0x08,0xff,0x08,0x01,0xff,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x02,0x04,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x84,0x4c,0x30,0x0e,
+/* 33618 0x8352 "荒" */
+0x08,0x08,0xff,0x0a,0x01,0xff,0x10,0x10,0x1f,0x00,0x11,0x11,0x11,0x21,0x41,0x81,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0x00,0xf8,0x00,0x10,0x10,0x10,0x12,0x12,0x0e,
+/* 33619 0x8353 "荓" */
+0x04,0x04,0xff,0x04,0x10,0x08,0x7f,0x08,0x08,0x08,0xff,0x08,0x08,0x10,0x20,0x40,
+0x40,0x40,0xfe,0x40,0x10,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 33620 0x8354 "荔" */
+0x08,0xff,0x0a,0x02,0x3f,0x04,0x18,0x60,0x10,0x10,0x7e,0x12,0x22,0x22,0x4a,0x85,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xa0,0x40,0x20,0x20,0xfc,0x24,0x44,0x44,0x94,0x08,
+/* 33621 0x8355 "荕" */
+0x08,0x08,0xff,0x08,0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x42,0x4a,0x85,
+0x20,0x20,0xfe,0x20,0x00,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 33622 0x8356 "荖" */
+0x08,0x08,0xff,0x0a,0x02,0x3f,0x02,0x02,0xff,0x01,0x06,0x18,0x2f,0xc8,0x08,0x07,
+0x20,0x20,0xfe,0x20,0x08,0xd0,0x20,0x40,0xfe,0x00,0x10,0xe0,0x00,0x08,0x08,0xf8,
+/* 33623 0x8357 "荗" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x3f,0x20,0x20,0x30,0x28,0x24,0x20,0x40,0x41,0x86,
+0x20,0x20,0xfe,0x20,0x90,0x88,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 33624 0x8358 "荘" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x48,0x28,0x28,0x0b,0x08,0x18,0x28,0xc8,0x09,0x08,
+0x20,0x20,0xfe,0x20,0x00,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 33625 0x8359 "荙" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x10,0x07,0x70,0x10,0x10,0x11,0x12,0x14,0x28,0x47,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x40,0xfc,0x40,0xa0,0x90,0x08,0x04,0x04,0x00,0xfe,
+/* 33626 0x835a "荚" */
+0x08,0x08,0xff,0x08,0x01,0x01,0x3f,0x01,0x11,0x09,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xf8,0x00,0x10,0x20,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 33627 0x835b "荛" */
+0x08,0x08,0xff,0x0a,0x02,0x7f,0x01,0x00,0x07,0x38,0x00,0x7f,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0x40,0x84,0x64,0x1c,0x00,0xfc,0x40,0x42,0x42,0x3e,
+/* 33628 0x835c "荜" */
+0x08,0x08,0xff,0x08,0x20,0x20,0x3e,0x20,0x20,0x26,0x39,0x01,0xff,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x80,0x88,0xb0,0xc4,0x84,0x7c,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 33629 0x835d "荝" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x41,0x49,0x49,0x49,0x49,0x49,0x14,0x22,0x41,0x80,
+0x20,0x20,0xfe,0x20,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x88,
+/* 33630 0x835e "荞" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x02,0xff,0x04,0x08,0x34,0xc4,0x04,0x04,0x08,0x10,
+0x20,0x20,0xfe,0x20,0xf0,0x00,0x00,0xfe,0x40,0x20,0x58,0x46,0x40,0x40,0x40,0x40,
+/* 33631 0x835f "荟" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x08,0x37,0xc0,0x00,0x3f,0x02,0x04,0x08,0x1f,0x08,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0xd8,0x06,0x00,0xf8,0x00,0x40,0x20,0xf0,0x10,
+/* 33632 0x8360 "荠" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x08,0x04,0x03,0x0c,0x30,0xc4,0x04,0x04,0x08,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x20,0x40,0x80,0x60,0x18,0x46,0x40,0x40,0x40,0x40,
+/* 33633 0x8361 "荡" */
+0x08,0x08,0xff,0x08,0x00,0x23,0x10,0x10,0x80,0x4b,0x48,0x11,0xe2,0x24,0x21,0x22,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x20,0x40,0x80,0xfc,0xa4,0x24,0x44,0x84,0x28,0x10,
+/* 33634 0x8362 "荢" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x3f,0x01,0x01,0xff,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 33635 0x8363 "荣" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x81,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 33636 0x8364 "荤" */
+0x08,0xff,0x08,0x00,0x7f,0x42,0x82,0x3f,0x09,0x11,0x1f,0x01,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0xf0,0x00,0x00,0xfe,0x00,0x00,
+/* 33637 0x8365 "荥" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x81,0x01,0x7d,0x05,0x09,0x11,0x21,0xc5,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0x04,0x88,0x50,0x20,0x10,0x08,0x06,0x00,
+/* 33638 0x8366 "荦" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x81,0x11,0x1f,0x21,0x01,0xff,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 33639 0x8367 "荧" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x81,0x11,0x11,0x22,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0x10,0x10,0xa0,0x80,0x40,0x20,0x18,0x06,
+/* 33640 0x8368 "荨" */
+0x08,0x08,0xff,0x08,0x3f,0x00,0x1f,0x00,0x3f,0x00,0xff,0x08,0x04,0x04,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 33641 0x8369 "荩" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x10,0x1f,0x10,0x10,0x16,0x21,0x20,0x46,0x81,0x00,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0x10,0xf0,0x80,0x40,0x20,0x10,0x88,0x06,0x80,0x40,
+/* 33642 0x836a "荪" */
+0x04,0x04,0xff,0x04,0x00,0x7c,0x04,0x08,0x10,0x10,0x1d,0xf1,0x12,0x10,0x50,0x20,
+0x40,0x40,0xfe,0x40,0x00,0x20,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 33643 0x836b "荫" */
+0x04,0x04,0xff,0x04,0x00,0x7c,0x44,0x48,0x50,0x48,0x44,0x44,0x54,0x48,0x41,0x42,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x14,0x08,
+/* 33644 0x836c "荬" */
+0x04,0x04,0xff,0x04,0x00,0x7f,0x04,0x02,0x12,0x08,0x09,0xff,0x02,0x04,0x18,0x60,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x04,0x88,0x80,0x80,0x00,0xfe,0x40,0x20,0x10,0x08,
+/* 33645 0x836d "荭" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x21,0x44,0xf8,0x10,0x20,0xfc,0x40,0x1c,0xe3,0x40,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33646 0x836e "荮" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x20,0x45,0xf8,0x10,0x20,0xfc,0x40,0x1c,0xe0,0x40,
+0x40,0x40,0xfe,0x40,0x08,0x08,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 33647 0x836f "药" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x20,0x45,0xfa,0x10,0x20,0xfc,0x00,0x1c,0xe0,0x40,
+0x40,0x40,0xfe,0x40,0x80,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x28,0x10,
+/* 33648 0x8370 "荰" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x10,0xfc,0x31,0x38,0x54,0x50,0x90,0x10,0x13,0x10,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33649 0x8371 "荱" */
+0x08,0x08,0xff,0x08,0x3f,0x20,0x3f,0x20,0x20,0x2f,0x20,0x2f,0x20,0x5f,0x40,0x80,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x00,0x70,0x80,0xf0,0x80,0xf8,0x82,0x82,0x7e,
+/* 33650 0x8372 "荲" */
+0x04,0xff,0x04,0x00,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x01,0x3f,0x01,0x01,0xff,
+0x40,0xfe,0x40,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,
+/* 33651 0x8373 "荳" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x00,0x08,0x04,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x00,0x20,0x40,0xfe,0x00,
+/* 33652 0x8374 "荴" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xfd,0x10,0x14,0x18,0x33,0xd0,0x10,0x10,0x51,0x22,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x50,0x50,0x88,0x04,0x02,
+/* 33653 0x8375 "荵" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x02,0x12,0x24,0x08,0x31,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0x28,0x10,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 33654 0x8376 "荶" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x78,0x49,0x4a,0x4c,0x48,0x4b,0x78,0x48,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xa0,0x10,0x88,0x46,0x40,0xf0,0x10,0x20,0x20,0x40,
+/* 33655 0x8377 "荷" */
+0x04,0x04,0xff,0x04,0x10,0x17,0x20,0x60,0xa7,0x24,0x24,0x24,0x27,0x20,0x20,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x28,0x10,
+/* 33656 0x8378 "荸" */
+0x08,0x08,0xff,0x09,0x01,0x3f,0x01,0x7f,0x40,0x9f,0x00,0x01,0xff,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0xfe,0x02,0xe4,0x40,0x80,0xfe,0x00,0x00,0x00,
+/* 33657 0x8379 "荹" */
+0x08,0x08,0xff,0x08,0x01,0x11,0x11,0x11,0xff,0x01,0x09,0x11,0x60,0x01,0x0e,0xf0,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x00,0x08,0x10,0x60,0x80,0x00,0x00,
+/* 33658 0x837a "荺" */
+0x08,0x08,0xff,0x08,0x08,0x10,0x10,0x7d,0x12,0x10,0x10,0x1c,0xe0,0x41,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x80,0xfc,0x04,0x04,0x84,0x54,0x24,0x44,0x84,0x28,0x10,
+/* 33659 0x837b "荻" */
+0x04,0x04,0xff,0x04,0x44,0x28,0x10,0x28,0x48,0x99,0x28,0x48,0x88,0x08,0x51,0x22,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 33660 0x837c "荼" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x08,0x37,0xc1,0x01,0x3f,0x01,0x11,0x21,0x45,0x02,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0xd8,0x06,0x00,0xf8,0x00,0x10,0x08,0x04,0x00,
+/* 33661 0x837d "荽" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x02,0xff,0x04,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x20,0xfe,0x20,0xf8,0x00,0x10,0x20,0x00,0xfe,0x20,0x20,0x40,0x80,0x70,0x08,
+/* 33662 0x837e "荾" */
+0x08,0xff,0x08,0x04,0x08,0x10,0x3f,0x04,0x08,0x12,0x67,0x08,0x14,0x03,0x1c,0xe0,
+0x20,0xfe,0x20,0x00,0x20,0x10,0xf8,0x48,0x20,0x10,0xe8,0x20,0x40,0x80,0x70,0x0e,
+/* 33663 0x837f "荿" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x2a,0x44,0x41,0x86,
+0x20,0x20,0xfe,0x20,0x90,0x88,0xfc,0x80,0x88,0x88,0x50,0x50,0x24,0x54,0x8c,0x04,
+/* 33664 0x8380 "莀" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x24,0x44,0x45,0x86,0x04,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0xf0,0x00,0xfc,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 33665 0x8381 "莁" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x01,0x11,0x11,0x11,0x29,0x45,0x85,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0x10,0x10,0x10,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 33666 0x8382 "莂" */
+0x08,0x08,0xff,0x08,0x3f,0x21,0x21,0x3f,0x08,0x08,0x7f,0x08,0x10,0x10,0x22,0x41,
+0x20,0x20,0xfe,0x20,0x04,0x04,0x24,0x24,0x24,0x24,0xa4,0xa4,0xa4,0x84,0x94,0x08,
+/* 33667 0x8383 "莃" */
+0x04,0xff,0x04,0x30,0x0c,0x03,0x0c,0x32,0xff,0x08,0x11,0x3f,0xd1,0x11,0x11,0x01,
+0x40,0xfe,0x40,0x10,0xe0,0x00,0xc0,0x30,0xfe,0x00,0x00,0xf0,0x10,0x50,0x20,0x00,
+/* 33668 0x8384 "莄" */
+0x08,0xff,0x08,0x00,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x1a,0x06,0x19,0x60,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0x00,0xc0,0x3e,
+/* 33669 0x8385 "莅" */
+0x08,0x08,0xff,0x08,0x08,0x08,0x10,0x33,0x50,0x90,0x12,0x11,0x11,0x10,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x40,0xfc,0x00,0x08,0x08,0x10,0x10,0x20,0xfe,0x00,
+/* 33670 0x8386 "莆" */
+0x08,0x08,0xff,0x09,0x01,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,0x21,0x21,
+0x20,0x20,0xfe,0x20,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 33671 0x8387 "莇" */
+0x04,0x04,0xff,0x04,0x00,0x3e,0x22,0x22,0x3e,0x22,0x3e,0x22,0x22,0x2f,0xf0,0x41,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 33672 0x8388 "莈" */
+0x08,0x08,0xff,0x08,0x21,0x11,0x11,0x82,0x44,0x53,0x11,0x21,0xe0,0x20,0x21,0x2e,
+0x20,0x20,0xfe,0x20,0xf0,0x10,0x10,0x0c,0x00,0xf0,0x10,0x10,0xa0,0x40,0xb0,0x0e,
+/* 33673 0x8389 "莉" */
+0x04,0x04,0xff,0x04,0x00,0x06,0x78,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x40,0x40,0xfe,0x40,0x00,0x08,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 33674 0x838a "莊" */
+0x04,0x04,0xff,0x04,0x00,0x24,0x24,0x24,0x3c,0x07,0x04,0xfc,0x24,0x24,0x25,0x44,
+0x40,0x40,0xfe,0x40,0x00,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 33675 0x838b "莋" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x10,0x11,0x32,0x54,0x90,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x80,0x80,0xfe,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 33676 0x838c "莌" */
+0x04,0x04,0xff,0x04,0x08,0x04,0x1f,0x10,0x10,0x10,0x1f,0x04,0x04,0x08,0x10,0x60,
+0x40,0x40,0xfe,0x40,0x20,0x40,0xf0,0x10,0x10,0x10,0xf0,0x40,0x40,0x42,0x42,0x3e,
+/* 33677 0x838d "莍" */
+0x04,0x04,0xff,0x04,0x01,0x01,0x7f,0x01,0x21,0x11,0x07,0x19,0xe1,0x41,0x05,0x02,
+0x40,0x40,0xfe,0x40,0x10,0x08,0xfc,0x00,0x18,0xa0,0x40,0x20,0x18,0x06,0x00,0x00,
+/* 33678 0x838e "莎" */
+0x08,0x08,0xff,0x08,0x00,0x10,0x08,0x40,0x24,0x05,0x09,0x72,0x10,0x10,0x11,0x06,
+0x20,0x20,0xfe,0x20,0x00,0x20,0x20,0xa8,0xa4,0x22,0x22,0x28,0x10,0x60,0x80,0x00,
+/* 33679 0x838f "莏" */
+0x08,0x08,0xff,0x08,0x10,0x10,0xfc,0x10,0x14,0x19,0x31,0xd2,0x10,0x10,0x51,0x26,
+0x20,0x20,0xfe,0x20,0x00,0x20,0x20,0xa8,0xa4,0x22,0x22,0x28,0x10,0x60,0x80,0x00,
+/* 33680 0x8390 "莐" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x13,0x82,0x44,0x10,0x10,0xe1,0x21,0x22,0x24,0x28,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xfc,0x44,0x48,0xa0,0xa0,0x20,0x20,0x22,0x22,0x1e,
+/* 33681 0x8391 "莑" */
+0x04,0xff,0x04,0x08,0x1f,0x28,0x07,0x18,0xe1,0x1f,0x01,0x1f,0x01,0x7f,0x01,0x01,
+0x40,0xfe,0x40,0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x00,0xf0,0x00,0xfc,0x00,0x00,
+/* 33682 0x8392 "莒" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33683 0x8393 "莓" */
+0x04,0x04,0xff,0x14,0x10,0x3f,0x40,0x9f,0x12,0x11,0xff,0x22,0x21,0x3f,0x00,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x00,0xf0,0x10,0x10,0xfe,0x10,0x10,0xfc,0x10,0x60,
+/* 33684 0x8394 "莔" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x24,0x28,0x30,0x27,0x24,0x24,0x24,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x48,0x28,0x18,0xc8,0x48,0x48,0x48,0xf8,0x08,
+/* 33685 0x8395 "莕" */
+0x08,0x08,0xff,0x09,0x01,0x7f,0x05,0x09,0x31,0xc1,0x1f,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33686 0x8396 "莖" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x08,0x11,0x22,0x11,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x88,0x10,0x20,0x10,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 33687 0x8397 "莗" */
+0x08,0x08,0xff,0x08,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x00,
+/* 33688 0x8398 "莘" */
+0x08,0x08,0xff,0x0a,0x01,0x3f,0x00,0x08,0x04,0xff,0x01,0x01,0x7f,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 33689 0x8399 "莙" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x04,0xff,0x04,0x3f,0x08,0x1f,0x28,0x48,0x8f,0x08,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 33690 0x839a "莚" */
+0x04,0x04,0xff,0x04,0x00,0x7b,0x08,0x10,0x22,0x7a,0x0a,0x2b,0x10,0x28,0x47,0x80,
+0x40,0x40,0xfe,0x40,0x18,0xe0,0x40,0x40,0x78,0x40,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 33691 0x839b "莛" */
+0x04,0x04,0xff,0x04,0x00,0x7b,0x08,0x10,0x23,0x78,0x08,0x2b,0x10,0x28,0x47,0x80,
+0x40,0x40,0xfe,0x40,0x38,0xc0,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 33692 0x839c "莜" */
+0x08,0x08,0xff,0x08,0x00,0x10,0x10,0x24,0x24,0x64,0xa5,0x24,0x24,0x20,0x20,0x23,
+0x20,0x20,0xfe,0x20,0x00,0x40,0x40,0x7e,0x88,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 33693 0x839d "莝" */
+0x08,0x08,0xff,0x08,0x01,0x11,0x11,0x11,0x29,0x45,0x81,0x3f,0x01,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0x10,0x10,0x10,0x28,0x44,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 33694 0x839e "莞" */
+0x08,0x08,0xff,0x0a,0x01,0x3f,0x20,0x40,0x1f,0x00,0x7f,0x04,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x04,0x08,0xe0,0x00,0xfc,0x40,0x40,0x44,0x44,0x3c,
+/* 33695 0x839f "莟" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x09,0x30,0xcf,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0x98,0xe6,0x40,0x80,0xf0,0x10,0x10,0xf0,0x10,
+/* 33696 0x83a0 "莠" */
+0x04,0x04,0xff,0x04,0x1f,0x01,0x7f,0x05,0x09,0x31,0xcf,0x04,0x04,0x08,0x10,0x60,
+0x40,0x40,0xfe,0x70,0x80,0x00,0xfc,0x40,0x20,0x18,0xc6,0x40,0xf0,0x10,0x50,0x20,
+/* 33697 0x83a1 "莡" */
+0x04,0x04,0xff,0x04,0x00,0x1f,0x10,0x10,0x1f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 33698 0x83a2 "莢" */
+0x08,0x08,0xff,0x08,0x09,0x01,0x7f,0x11,0x11,0x29,0x45,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x20,0x00,0xfc,0x10,0x10,0x28,0x44,0x80,0x40,0x20,0x18,0x06,
+/* 33699 0x83a3 "莣" */
+0x08,0x08,0xff,0x09,0x00,0x7f,0x08,0x08,0x0f,0x00,0x01,0x08,0x48,0x48,0x87,0x00,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x00,0x00,0xf8,0x00,0x00,0x84,0x92,0x12,0xf0,0x00,
+/* 33700 0x83a4 "莤" */
+0x08,0x08,0xff,0x08,0x00,0xff,0x04,0x3f,0x24,0x24,0x28,0x30,0x3f,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x40,0xf8,0x48,0x48,0x38,0x08,0xf8,0x08,0xf8,0x08,
+/* 33701 0x83a5 "莥" */
+0x08,0x08,0xff,0x08,0x44,0x2b,0x10,0x28,0x48,0x9b,0x28,0x48,0x88,0x08,0x57,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x48,0x48,0x48,0xf8,0x48,0x88,0x88,0x88,0xfe,0x00,
+/* 33702 0x83a6 "莦" */
+0x08,0x08,0xff,0x08,0x01,0x11,0x09,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x00,0x10,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 33703 0x83a7 "莧" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x42,0x42,0x3e,
+/* 33704 0x83a8 "莨" */
+0x08,0x08,0xff,0x0a,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x11,0x10,0x10,0x12,0x14,0x18,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x04,0x88,0x50,0x20,0x18,0x06,
+/* 33705 0x83a9 "莩" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x3f,0x00,0x00,0xff,0x01,0x01,0x05,0x02,
+0x20,0x20,0xfe,0x20,0xf8,0x00,0x10,0x20,0xe0,0x40,0x80,0xfe,0x00,0x00,0x00,0x00,
+/* 33706 0x83aa "莪" */
+0x08,0x08,0xff,0x08,0x06,0x38,0x08,0xff,0x08,0x08,0x0e,0x78,0x08,0x08,0x28,0x13,
+0x20,0x20,0xfe,0x20,0x40,0x50,0x48,0xfe,0x40,0x40,0x24,0x28,0x12,0x2a,0xc6,0x02,
+/* 33707 0x83ab "莫" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x7f,0x02,0x04,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x80,0x40,0x30,0x0e,
+/* 33708 0x83ac "莬" */
+0x08,0x08,0xff,0x08,0x04,0x07,0x08,0x10,0x3f,0x51,0x11,0x1f,0x02,0x04,0x18,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x80,0x82,0x82,0x7e,
+/* 33709 0x83ad "莭" */
+0x08,0x08,0xff,0x08,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x40,0x50,0x48,0x54,0x62,0x40,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x40,
+/* 33710 0x83ae "莮" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x02,0x7f,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 33711 0x83af "莯" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x10,0x97,0x40,0x41,0x11,0x22,0xe4,0x28,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x20,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,0x40,
+/* 33712 0x83b0 "莰" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x10,0x7d,0x12,0x10,0x10,0x1c,0xe0,0x41,0x02,0x0c,
+0x40,0x40,0xfe,0x40,0x80,0x80,0xfc,0x04,0x48,0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 33713 0x83b1 "莱" */
+0x08,0x08,0xff,0x09,0x01,0x3f,0x01,0x11,0x09,0x7f,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0x10,0x20,0xfc,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 33714 0x83b2 "莲" */
+0x08,0x08,0xff,0x08,0x20,0x17,0x11,0x02,0x73,0x10,0x10,0x17,0x10,0x28,0x47,0x00,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x40,0x40,0xfc,0x40,0x40,0xfe,0x40,0x40,0xfe,0x00,
+/* 33715 0x83b3 "莳" */
+0x04,0x04,0xff,0x04,0x00,0x7c,0x44,0x45,0x44,0x7d,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x40,0xfe,0x40,0x10,0x10,0x10,0xfe,0x10,0x10,0x90,0x90,0x10,0x10,0x50,0x20,
+/* 33716 0x83b4 "莴" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x10,0x1f,0x01,0x7f,0x41,0x42,0x44,0x48,0x40,0x40,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x04,0x84,0x44,0x44,0x14,0x08,
+/* 33717 0x83b5 "莵" */
+0x08,0x08,0xff,0x09,0x02,0x3f,0x21,0x21,0x21,0x3f,0x22,0x04,0x08,0x10,0x20,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0x08,0xf8,0x88,0x90,0x88,0x8a,0x82,0x7e,
+/* 33718 0x83b6 "莶" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x04,0x08,0x37,0xc0,0x02,0x11,0x09,0x08,0x7f,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x40,0x20,0xd8,0x06,0x10,0x10,0x20,0x40,0xfc,0x00,
+/* 33719 0x83b7 "获" */
+0x08,0x08,0xff,0x08,0x44,0x28,0x10,0x28,0x4f,0x98,0x28,0x48,0x89,0x09,0x52,0x24,
+0x20,0x20,0xfe,0x20,0x40,0x50,0x48,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x10,0x08,0x06,
+/* 33720 0x83b8 "莸" */
+0x04,0x04,0xff,0x04,0x44,0x28,0x10,0x2b,0x48,0x98,0x28,0x49,0x89,0x0a,0x52,0x24,
+0x40,0x40,0xfe,0x40,0x90,0x88,0x88,0xfe,0xa0,0xa0,0xa0,0x20,0x20,0x22,0x22,0x1e,
+/* 33721 0x83b9 "莹" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x40,0x80,0x3f,0x01,0x01,0x1f,0x01,0x01,0x01,0x7f,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf8,0x00,0x00,0xf0,0x00,0x40,0x20,0xfc,
+/* 33722 0x83ba "莺" */
+0x08,0x08,0xff,0x08,0x7f,0x42,0x9f,0x10,0x12,0x11,0x10,0x1f,0x00,0x00,0x7f,0x00,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0xf4,0x10,0x10,0x50,0x20,0xfc,0x04,0x04,0xd4,0x08,
+/* 33723 0x83bb "莻" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x04,0x04,0x08,0x30,0xc0,0x3e,0x22,0x22,0x3e,0x22,
+0x40,0x40,0xfe,0x40,0x00,0xe0,0x20,0x7c,0x04,0x14,0x08,0x44,0x58,0x62,0x42,0x3e,
+/* 33724 0x83bc "莼" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x23,0x44,0x79,0x11,0x21,0x7d,0x00,0x1c,0xe0,0x40,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x22,0x22,0x22,0x1e,
+/* 33725 0x83bd "莽" */
+0x08,0xff,0x08,0x02,0x02,0x7f,0x04,0x08,0x30,0xc8,0x08,0x7f,0x08,0x10,0x20,0x40,
+0x20,0xfe,0x20,0x40,0x20,0xfc,0x40,0x20,0x18,0x26,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 33726 0x83be "莾" */
+0x08,0xff,0x0a,0x02,0x7f,0x04,0x09,0x37,0xc1,0x09,0x08,0x7f,0x08,0x08,0x10,0x20,
+0x20,0xfe,0x20,0x00,0xfc,0x40,0x20,0xd8,0x06,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 33727 0x83bf "莿" */
+0x04,0x04,0xff,0x04,0x08,0x08,0xff,0x08,0x7f,0x49,0x4b,0x1c,0x2a,0x49,0x88,0x08,
+0x40,0x40,0xfe,0x40,0x00,0x04,0xa4,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 33728 0x83c0 "菀" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x90,0x1e,0x22,0x24,0x54,0x08,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf8,0x88,0x88,0xa8,0x90,0x84,0x84,0x7c,
+/* 33729 0x83c1 "菁" */
+0x08,0xff,0x09,0x3f,0x01,0x1f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x20,0xfe,0x20,0xf8,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33730 0x83c2 "菂" */
+0x08,0x08,0xff,0x08,0x10,0x20,0x7e,0x42,0x43,0x42,0x7e,0x42,0x42,0x42,0x7e,0x42,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x7c,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x28,0x10,
+/* 33731 0x83c3 "菃" */
+0x08,0x08,0xff,0x08,0x20,0x13,0x92,0x42,0x4b,0x0a,0x12,0xe3,0x22,0x22,0x23,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x00,
+/* 33732 0x83c4 "菄" */
+0x08,0x08,0xff,0x08,0x01,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x03,0x0d,0x31,0xc1,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x60,0x18,0x06,
+/* 33733 0x83c5 "菅" */
+0x08,0x08,0xff,0x08,0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0xe4,0x20,0xe0,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 33734 0x83c6 "菆" */
+0x08,0x08,0xff,0x08,0x7f,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x27,0xfa,0x42,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x90,0x28,0x44,0x82,
+/* 33735 0x83c7 "菇" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xfe,0x12,0x22,0x22,0x64,0x14,0x08,0x14,0x22,0xc0,
+0x40,0x40,0xfe,0x40,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 33736 0x83c8 "菈" */
+0x08,0x08,0xff,0x08,0x10,0x10,0xfc,0x11,0x14,0x18,0x31,0xd0,0x10,0x10,0x53,0x20,
+0x20,0x20,0xfe,0x20,0x40,0x20,0x20,0xfc,0x00,0x08,0x08,0x90,0x90,0x20,0xfe,0x00,
+/* 33737 0x83c9 "菉" */
+0x08,0x08,0xff,0x08,0x3f,0x00,0x1f,0x00,0xff,0x11,0x09,0x05,0x19,0xe1,0x05,0x02,
+0x20,0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xa0,0x40,0x30,0x0e,0x00,0x00,
+/* 33738 0x83ca "菊" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x22,0x52,0x8a,0x02,0x7f,0x07,0x0a,0x12,0x62,0x02,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x04,0x44,0x84,0x04,0xf4,0x04,0x84,0x44,0x14,0x08,
+/* 33739 0x83cb "菋" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x7b,0x48,0x48,0x4f,0x48,0x79,0x4a,0x04,0x08,0x00,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xf8,0x40,0x40,0xfc,0xe0,0x50,0x48,0x44,0x42,0x40,
+/* 33740 0x83cc "菌" */
+0x08,0xff,0x08,0x00,0x3f,0x20,0x20,0x27,0x21,0x2f,0x23,0x25,0x29,0x21,0x3f,0x20,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0xc8,0x08,0x08,0xe8,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 33741 0x83cd "菍" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x09,0x30,0xcf,0x00,0x02,0x01,0x48,0x48,0x87,0x00,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0x98,0xe6,0x40,0x80,0x00,0x84,0x12,0xf2,0x00,
+/* 33742 0x83ce "菎" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x20,0x3e,0x20,0x26,0x38,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x8c,0xf0,0x82,0x82,0x7e,
+/* 33743 0x83cf "菏" */
+0x04,0x04,0xff,0x04,0x20,0x17,0x10,0x80,0x4b,0x4a,0x12,0xe3,0x22,0x20,0x20,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0xc8,0x48,0x08,0x28,0x10,
+/* 33744 0x83d0 "菐" */
+0x04,0x24,0x14,0x04,0xff,0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x02,0x04,0x18,0xe0,
+0x40,0x48,0x50,0x40,0xfe,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x80,0x40,0x30,0x0e,
+/* 33745 0x83d1 "菑" */
+0x08,0x08,0xff,0x08,0x08,0x11,0x22,0x11,0x08,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x88,0x10,0x20,0x10,0x88,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 33746 0x83d2 "菒" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 33747 0x83d3 "菓" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 33748 0x83d4 "菔" */
+0x08,0x08,0xff,0x08,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x22,0x4a,0x84,
+0x20,0x20,0xfe,0x20,0xfc,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,
+/* 33749 0x83d5 "菕" */
+0x08,0x08,0xff,0x09,0x02,0x0c,0x37,0xc0,0x3f,0x24,0x24,0x3f,0x24,0x24,0x24,0x20,
+0x20,0x20,0xfe,0x20,0x80,0x60,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,0x88,0xa8,0x10,
+/* 33750 0x83d6 "菖" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 33751 0x83d7 "菗" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x11,0xfd,0x11,0x11,0x1d,0xf1,0x11,0x11,0x51,0x21,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 33752 0x83d8 "菘" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x10,0xfd,0x31,0x3a,0x54,0x50,0x90,0x11,0x13,0x11,
+0x40,0x40,0xfe,0x40,0x10,0x90,0x90,0x08,0x48,0x44,0x42,0x90,0x88,0x08,0xfc,0x04,
+/* 33753 0x83d9 "菙" */
+0x08,0xff,0x08,0x00,0x3f,0x01,0x7f,0x09,0x09,0xff,0x09,0x09,0x7f,0x01,0x01,0x3f,
+0x20,0xfe,0x20,0xf8,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xf8,
+/* 33754 0x83da "菚" */
+0x08,0x08,0xff,0x08,0x02,0x02,0x7f,0x00,0x07,0x78,0x02,0x02,0x7f,0x00,0x07,0x78,
+0x20,0x20,0xfe,0x20,0x10,0xfc,0x40,0x84,0x64,0x1c,0x10,0xfc,0x40,0x84,0x64,0x1c,
+/* 33755 0x83db "菛" */
+0x08,0x08,0xff,0x08,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 33756 0x83dc "菜" */
+0x08,0x08,0xff,0x08,0x00,0x00,0x3f,0x11,0x08,0x01,0x7f,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x10,0xf8,0x00,0x10,0x20,0x00,0xfc,0x40,0x20,0x18,0x06,0x00,
+/* 33757 0x83dd "菝" */
+0x08,0x08,0xff,0x08,0x10,0x10,0xfd,0x10,0x14,0x18,0x30,0xd1,0x11,0x12,0x54,0x20,
+0x20,0x20,0xfe,0x20,0x48,0x44,0xfe,0x40,0x40,0xfc,0xa4,0x28,0x28,0x10,0x28,0xc6,
+/* 33758 0x83de "菞" */
+0x08,0x08,0xff,0x08,0x0c,0x70,0x10,0x11,0xfd,0x32,0x38,0x54,0x50,0x91,0x12,0x10,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0x24,0x24,0x24,0x44,0x44,0x84,0x04,0x28,0x10,
+/* 33759 0x83df "菟" */
+0x04,0xff,0x04,0x08,0x0f,0x10,0x20,0x5f,0x11,0x11,0x1f,0x02,0x04,0x08,0x10,0x60,
+0x40,0xfe,0x40,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x80,0xa0,0x92,0x82,0x7e,
+/* 33760 0x83e0 "菠" */
+0x04,0x04,0xff,0x04,0x20,0x10,0x13,0x82,0x42,0x4b,0x0a,0x12,0xe2,0x24,0x24,0x29,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x24,0x20,0xf8,0x88,0x88,0x50,0x20,0x50,0x8c,
+/* 33761 0x83e1 "菡" */
+0x04,0x04,0xff,0x04,0x00,0x1f,0x40,0x51,0x49,0x43,0x45,0x49,0x55,0x42,0x7f,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xe0,0x44,0x94,0x24,0xc4,0x44,0x24,0x14,0x04,0xfc,0x04,
+/* 33762 0x83e2 "菢" */
+0x08,0x08,0xff,0x08,0x10,0x10,0xfd,0x12,0x15,0x11,0x1d,0xf1,0x11,0x11,0x51,0x20,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x0c,0x02,0x02,0xfe,
+/* 33763 0x83e3 "菣" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x48,0x48,0x7f,0x41,0x41,0x7f,0x48,0x48,0x7f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 33764 0x83e4 "菤" */
+0x04,0x04,0xff,0x05,0x11,0x09,0x3f,0x02,0x7f,0x08,0x10,0x2f,0xc8,0x08,0x08,0x07,
+0x40,0x40,0xfe,0x40,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0xe8,0x26,0x68,0x08,0xf8,
+/* 33765 0x83e5 "菥" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x92,0x12,0x14,
+0x40,0x40,0xfe,0x40,0x00,0x0c,0xf0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 33766 0x83e6 "菦" */
+0x04,0x04,0xff,0x04,0x20,0x13,0x12,0x02,0x73,0x12,0x12,0x12,0x14,0x28,0x47,0x00,
+0x40,0x40,0xfe,0x40,0x18,0xe0,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33767 0x83e7 "菧" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x20,0x20,0x2f,0x28,0x28,0x2f,0x28,0x48,0x4a,0x8c,
+0x20,0x20,0xfe,0x20,0x80,0xfe,0x00,0x78,0x80,0x80,0x80,0xfc,0x40,0x24,0x94,0x4c,
+/* 33768 0x83e8 "菨" */
+0x08,0x08,0xff,0x0a,0x01,0x3f,0x08,0x04,0xff,0x04,0x7f,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x20,0x40,0xfe,0x00,0xfc,0x20,0x40,0x80,0x70,0x08,
+/* 33769 0x83e9 "菩" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x08,0x04,0xff,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x20,0x40,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,
+/* 33770 0x83ea "菪" */
+0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x3f,0x04,0x08,0x1f,0x28,0x48,0x08,0x0f,0x08,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,
+/* 33771 0x83eb "菫" */
+0x08,0x08,0xff,0x08,0x7f,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x01,0x3f,0x01,0xff,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,
+/* 33772 0x83ec "菬" */
+0x08,0x08,0xff,0x08,0x23,0x10,0x10,0x80,0x49,0x4a,0x15,0xe1,0x21,0x21,0x21,0x21,
+0x20,0x20,0xfe,0x20,0xfc,0x84,0x84,0x84,0x14,0x08,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 33773 0x83ed "菭" */
+0x08,0x08,0xff,0x08,0x20,0x11,0x12,0x87,0x42,0x50,0x13,0x22,0xe2,0x22,0x23,0x22,
+0x20,0x20,0xfe,0x20,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 33774 0x83ee "菮" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x21,0x42,0x4c,0xb0,
+0x20,0x20,0xfe,0x20,0x80,0xfe,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x40,0x20,0x18,0x06,
+/* 33775 0x83ef "華" */
+0x04,0x04,0xff,0x04,0x7f,0x11,0x11,0xff,0x11,0x11,0x7f,0x01,0xff,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x40,0xfc,0x10,0x10,0xfe,0x10,0x10,0xfc,0x00,0xfe,0x00,0x00,0x00,
+/* 33776 0x83f0 "菰" */
+0x08,0x08,0xff,0x08,0x00,0x7d,0x09,0x11,0x11,0x1d,0x31,0xd1,0x11,0x12,0x52,0x24,
+0x20,0x20,0xfe,0x20,0x1c,0xf0,0x50,0x50,0x50,0x50,0x48,0x48,0x44,0x54,0x5a,0x68,
+/* 33777 0x83f1 "菱" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x01,0xff,0x10,0x22,0x47,0x08,0x14,0x03,0x1c,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x00,0xfe,0x10,0x08,0xe4,0x20,0x40,0x80,0x70,0x0e,
+/* 33778 0x83f2 "菲" */
+0x08,0x08,0xff,0x08,0x08,0x04,0x7c,0x04,0x04,0x7c,0x04,0x04,0xfc,0x04,0x04,0x04,
+0x20,0x20,0xfe,0x20,0x20,0x40,0x7c,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 33779 0x83f3 "菳" */
+0x08,0x08,0xff,0x08,0x09,0x02,0x0c,0x30,0xcf,0x01,0x01,0x3f,0x11,0x09,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x80,0x60,0x18,0xe6,0x00,0x00,0xf8,0x10,0x20,0xfe,0x00,
+/* 33780 0x83f4 "菴" */
+0x08,0x08,0xff,0x0a,0x02,0x7f,0x04,0x09,0x3f,0xd1,0x1f,0x11,0x1f,0x01,0x01,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x40,0x20,0xf8,0x16,0xf0,0x10,0xf4,0x04,0x04,0xfc,
+/* 33781 0x83f5 "菵" */
+0x04,0x04,0xff,0x04,0x7f,0x48,0x44,0x5f,0x41,0x40,0x5f,0x44,0x44,0x47,0x40,0x40,
+0x40,0x40,0xfe,0x40,0xfc,0x24,0x44,0xf4,0x04,0x84,0xf4,0x04,0x04,0xe4,0x14,0x08,
+/* 33782 0x83f6 "菶" */
+0x04,0x04,0xff,0x04,0x01,0x7f,0x01,0x3f,0x02,0xff,0x09,0x17,0x21,0xdf,0x01,0x01,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xd0,0x08,0xf6,0x00,0x00,
+/* 33783 0x83f7 "菷" */
+0x08,0xff,0x08,0x1f,0x00,0x0f,0x00,0x1f,0x00,0x7f,0x41,0x9f,0x11,0x11,0x11,0x01,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x10,0x50,0x20,0x00,
+/* 33784 0x83f8 "菸" */
+0x04,0x04,0xff,0x04,0x10,0x08,0x7e,0x10,0x10,0x1f,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x50,0x50,0x88,0x06,0x60,0x10,0x00,0xc0,0x30,0x08,
+/* 33785 0x83f9 "菹" */
+0x04,0x04,0xff,0x04,0x10,0x09,0x09,0x41,0x21,0x29,0x09,0x11,0x71,0x11,0x17,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 33786 0x83fa "菺" */
+0x08,0xff,0x09,0x00,0x1f,0x10,0x1f,0x10,0x17,0x14,0x17,0x24,0x27,0x44,0x84,0x04,
+0x20,0xfe,0x20,0x80,0xfc,0x04,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 33787 0x83fb "菻" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x08,0x7e,0x08,0x1c,0x1a,0x2a,0x48,0x89,0x08,0x08,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0xfc,0x20,0x30,0x70,0x68,0xa4,0x22,0x20,0x20,
+/* 33788 0x83fc "菼" */
+0x08,0x08,0xff,0x08,0x01,0x09,0x09,0x12,0x04,0x19,0x69,0x09,0x12,0x04,0x18,0x60,
+0x20,0x20,0xfe,0x20,0x00,0x10,0x20,0xc0,0x30,0x08,0x14,0x10,0xa0,0x40,0x30,0x0c,
+/* 33789 0x83fd "菽" */
+0x04,0x04,0xff,0x04,0x08,0x0f,0x08,0x08,0xff,0x00,0x08,0x2a,0x49,0x89,0x28,0x10,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 33790 0x83fe "菾" */
+0x04,0x04,0xff,0x04,0x3f,0x01,0x02,0xff,0x08,0x31,0xc1,0x09,0x11,0x21,0x05,0x02,
+0x40,0x40,0xfe,0x40,0xf8,0x00,0x00,0xfe,0x20,0x18,0x06,0x90,0x48,0x48,0x00,0x00,
+/* 33791 0x83ff "菿" */
+0x08,0x08,0xff,0x08,0x7f,0x10,0x22,0x7f,0x09,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x20,0x20,0xfe,0x20,0x84,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 33792 0x8400 "萀" */
+0x08,0x08,0xff,0x09,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x27,0x44,0x48,0xb0,
+0x20,0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xe0,0x22,0x22,0x1e,
+/* 33793 0x8401 "萁" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x08,0x10,0x20,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x20,0x10,0x08,
+/* 33794 0x8402 "萂" */
+0x04,0x04,0xff,0x04,0x0e,0x78,0x08,0x08,0xff,0x18,0x1c,0x2a,0x4a,0x88,0x08,0x08,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 33795 0x8403 "萃" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x08,0x08,0x14,0x22,0x01,0xff,0x01,0x01,0x01,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x20,0x20,0x50,0x88,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 33796 0x8404 "萄" */
+0x08,0xff,0x08,0x20,0x3f,0x48,0x9f,0x22,0x02,0xff,0x02,0x22,0x22,0x3f,0x00,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x04,0xe4,0x04,0x04,0xfc,0x04,0x24,0x24,0xe4,0x28,0x10,
+/* 33797 0x8405 "萅" */
+0x08,0xff,0x08,0x01,0xff,0x01,0x21,0x3f,0x01,0x00,0x00,0x3f,0x20,0x3f,0x20,0x3f,
+0x20,0xfe,0x20,0x00,0xfe,0x00,0x08,0xfa,0x02,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 33798 0x8406 "萆" */
+0x08,0x08,0xff,0x0a,0x04,0x3f,0x21,0x3f,0x22,0x3f,0x08,0x10,0xff,0x00,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x80,0x80,0xfe,0x80,0x80,0x80,
+/* 33799 0x8407 "萇" */
+0x04,0x04,0xff,0x04,0x0f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x11,0x10,0x14,0x18,0x10,
+0x40,0x40,0xfe,0x40,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfe,0x10,0xa0,0x40,0x30,0x0e,
+/* 33800 0x8408 "萈" */
+0x08,0x08,0xff,0x08,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x50,0x4a,0x42,0x3e,
+/* 33801 0x8409 "萉" */
+0x08,0x08,0xff,0x08,0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x4a,0x84,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 33802 0x840a "萊" */
+0x08,0x08,0xff,0x09,0x01,0x7f,0x11,0x11,0x29,0x45,0x03,0x05,0x09,0x31,0xc1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x10,0x10,0x28,0x44,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 33803 0x840b "萋" */
+0x08,0xff,0x09,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x02,0xff,0x08,0x1c,0x03,0x7c,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 33804 0x840c "萌" */
+0x08,0x08,0xff,0x08,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x45,0x01,0x02,0x0c,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x04,0x04,0x14,0x08,
+/* 33805 0x840d "萍" */
+0x08,0x08,0xff,0x08,0x20,0x17,0x90,0x42,0x49,0x08,0x17,0xe0,0x20,0x20,0x20,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x40,0x48,0x50,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 33806 0x840e "萎" */
+0x08,0xff,0x08,0x00,0x1f,0x01,0x7f,0x05,0x19,0xe1,0x04,0x7f,0x08,0x1c,0x03,0x7c,
+0x20,0xfe,0x20,0x70,0x80,0x00,0xfc,0x40,0x30,0x0e,0x00,0xfc,0x20,0x40,0x80,0x78,
+/* 33807 0x840f "萏" */
+0x04,0x04,0xff,0x04,0x08,0x1f,0x20,0x44,0xb8,0x20,0x20,0x3c,0x20,0x20,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xe0,0x20,0x40,0x78,0x08,0x08,0x78,0x08,0x08,0xf8,0x08,
+/* 33808 0x8410 "萐" */
+0x08,0xff,0x08,0x01,0x7f,0x01,0x3f,0x01,0xff,0x01,0x3f,0x11,0x11,0x29,0x47,0x80,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x00,0xfe,0x00,
+/* 33809 0x8411 "萑" */
+0x08,0x08,0xff,0x09,0x08,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,
+/* 33810 0x8412 "萒" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x08,0x12,0x24,0x08,0x1f,0x04,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x20,0x10,0x48,0x20,0xf0,0x40,0x40,0x44,0x44,0x3c,
+/* 33811 0x8413 "萓" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,
+/* 33812 0x8414 "萔" */
+0x04,0x04,0xff,0x04,0x10,0x11,0xfc,0x10,0x14,0x19,0x32,0xd0,0x10,0x10,0x50,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x44,0x44,0x94,0x08,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 33813 0x8415 "萕" */
+0x08,0xff,0x0a,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe8,0x0f,0x08,0x0f,0x08,0x10,0x20,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0x40,0x80,0x70,0x2e,0xe0,0x20,0xe0,0x20,0x20,0x20,
+/* 33814 0x8416 "萖" */
+0x08,0xff,0x08,0x06,0x38,0x20,0x20,0x3c,0x20,0x20,0x3f,0x04,0x04,0x08,0x30,0xc0,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0x40,0x42,0x42,0x3e,
+/* 33815 0x8417 "萗" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x1f,0x00,0x00,0x7f,0x11,0x21,0x45,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0xfc,0x10,0x08,0x04,0x00,
+/* 33816 0x8418 "萘" */
+0x08,0x08,0xff,0x0a,0x02,0x7f,0x04,0x08,0x37,0xc0,0x3f,0x01,0x09,0x11,0x25,0x02,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x40,0x20,0xd8,0x06,0xf8,0x00,0x20,0x10,0x08,0x00,
+/* 33817 0x8419 "萙" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xfd,0x11,0x32,0x38,0x54,0x54,0x90,0x11,0x12,0x14,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfe,0x22,0x24,0x50,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 33818 0x841a "萚" */
+0x08,0x08,0xff,0x08,0x10,0x11,0x10,0xfc,0x13,0x10,0x1d,0x30,0xd3,0x10,0x50,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x88,0x70,0x8e,0x20,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 33819 0x841b "萛" */
+0x08,0x08,0xff,0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0xff,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 33820 0x841c "萜" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 33821 0x841d "萝" */
+0x08,0xff,0x08,0x00,0x3f,0x24,0x24,0x3f,0x02,0x07,0x08,0x34,0x02,0x01,0x0e,0x70,
+0x20,0xfe,0x20,0x00,0xf8,0x48,0x48,0xf8,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x00,
+/* 33822 0x841e "萞" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x22,0x24,0x00,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x88,0x48,0x00,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 33823 0x841f "萟" */
+0x08,0x08,0xff,0x08,0x06,0x38,0x09,0x08,0x7e,0x18,0x1c,0x2a,0x28,0x48,0x09,0x0a,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0x68,0x9a,0x8a,0x06,0x02,
+/* 33824 0x8420 "萠" */
+0x08,0x08,0xff,0x08,0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x22,0x4a,0x85,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x94,0x08,
+/* 33825 0x8421 "萡" */
+0x04,0x04,0xff,0x04,0x00,0x10,0x09,0x49,0x21,0x25,0x05,0x09,0x71,0x11,0x11,0x11,
+0x40,0x40,0xfe,0x40,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 33826 0x8422 "萢" */
+0x08,0x08,0xff,0x08,0x21,0x11,0x13,0x84,0x4b,0x52,0x12,0x23,0xe2,0x22,0x22,0x21,
+0x20,0x20,0xfe,0x20,0x00,0x00,0xf8,0x08,0xe8,0x28,0x28,0xe8,0x18,0x04,0x04,0xfc,
+/* 33827 0x8423 "萣" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x1f,0x01,0x11,0x11,0x11,0x29,0x47,0x80,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf0,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,
+/* 33828 0x8424 "萤" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x41,0x81,0x1f,0x11,0x11,0x1f,0x01,0x01,0x7f,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 33829 0x8425 "营" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0x9f,0x10,0x10,0x1f,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0xf4,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 33830 0x8426 "萦" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x44,0x88,0x1f,0x03,0x0c,0x3f,0x01,0x11,0x25,0x42,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x44,0x80,0x20,0x10,0xf8,0x08,0x20,0x10,0x08,
+/* 33831 0x8427 "萧" */
+0x08,0x08,0xff,0x08,0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x25,0x25,0x29,0x41,0x81,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x48,0x28,0x28,0x08,0x08,
+/* 33832 0x8428 "萨" */
+0x04,0x04,0xff,0x04,0x00,0x7d,0x44,0x48,0x51,0x49,0x45,0x45,0x55,0x49,0x42,0x44,
+0x40,0x40,0xfe,0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 33833 0x8429 "萩" */
+0x04,0x04,0xff,0x04,0x0c,0x70,0x10,0x10,0xfc,0x31,0x38,0x54,0x50,0x90,0x11,0x12,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 33834 0x842a "萪" */
+0x08,0x08,0xff,0x08,0x0c,0x70,0x10,0x10,0xfc,0x30,0x38,0x55,0x50,0x90,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x10,0x90,0x50,0x10,0x90,0x50,0x1e,0xf0,0x10,0x10,0x10,0x10,
+/* 33835 0x842b "萫" */
+0x08,0xff,0x08,0x00,0x3f,0x01,0xff,0x05,0x09,0x31,0xdf,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0xfe,0x20,0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x10,
+/* 33836 0x842c "萬" */
+0x04,0x04,0xff,0x04,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x21,0x21,0x2f,0x24,0x20,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x48,0xe8,0x28,0x10,
+/* 33837 0x842d "萭" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x01,0x1f,0x11,0x1f,0x01,0x7f,0x41,0x41,0x5e,0x40,
+0x20,0x20,0xfe,0x20,0xf0,0x00,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x24,0xf4,0x14,0x08,
+/* 33838 0x842e "萮" */
+0x08,0x08,0xff,0x09,0x02,0x0c,0x37,0xc0,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0x26,
+0x20,0x20,0xfe,0x20,0x80,0x60,0xd8,0x06,0x08,0x48,0x48,0x48,0x48,0x08,0x28,0x10,
+/* 33839 0x842f "萯" */
+0x08,0xff,0x08,0x04,0x0f,0x10,0x3f,0x50,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,
+0x20,0xfe,0x20,0x00,0xe0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 33840 0x8430 "萰" */
+0x08,0x08,0xff,0x09,0x01,0x7f,0x01,0x3f,0x29,0x25,0x3f,0x03,0x05,0x19,0xe1,0x01,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x28,0x48,0xf8,0x80,0x60,0x18,0x06,0x00,
+/* 33841 0x8431 "萱" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x9f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x00,0xff,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0xf4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 33842 0x8432 "萲" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x3f,0x02,0xff,0x04,0x0f,0x12,0x21,0xce,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0x08,0x10,0xf8,0x00,0xfe,0x00,0xf0,0x20,0xc0,0x3c,
+/* 33843 0x8433 "萳" */
+0x08,0x08,0xff,0x08,0x01,0xff,0x01,0x3f,0x24,0x22,0x2f,0x21,0x3f,0x21,0x21,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0xf8,0x48,0x88,0xe8,0x08,0xf8,0x08,0x28,0x10,
+/* 33844 0x8434 "萴" */
+0x08,0xff,0x08,0x3f,0x21,0x21,0x3f,0x21,0x3f,0x21,0x21,0x3f,0x00,0x12,0x21,0x40,
+0x20,0xfe,0x20,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x88,
+/* 33845 0x8435 "萵" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x1f,0x10,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0x90,0x90,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 33846 0x8436 "萶" */
+0x08,0xff,0x08,0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x1f,0x28,0xcf,0x08,0x0f,0x08,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf0,0x28,0xe6,0x20,0xe0,0x20,
+/* 33847 0x8437 "萷" */
+0x04,0x04,0xff,0x04,0x08,0x49,0x2a,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x41,0x45,0x42,
+0x40,0x40,0xfe,0x40,0x00,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 33848 0x8438 "萸" */
+0x08,0x08,0xff,0x08,0x05,0x39,0x21,0x21,0x3d,0x21,0x21,0x3f,0x02,0x04,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0x00,0x78,0x08,0x08,0x78,0x08,0x08,0xf8,0x80,0x40,0x30,0x0e,
+/* 33849 0x8439 "萹" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x20,0x3f,0x20,0x2f,0x29,0x29,0x2f,0x49,0x49,0x88,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x04,0xfc,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0x0c,
+/* 33850 0x843a "萺" */
+0x08,0xff,0x08,0x7f,0x40,0x5f,0x40,0x5f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0xfe,0x20,0xfc,0x04,0xf4,0x04,0xf4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,
+/* 33851 0x843b "萻" */
+0x08,0x08,0xff,0x0a,0x01,0x3f,0x08,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 33852 0x843c "萼" */
+0x08,0xff,0x08,0x00,0x3e,0x22,0x3e,0x00,0x3f,0x00,0xff,0x08,0x0f,0x00,0x00,0x00,
+0x20,0xfe,0x20,0x00,0xf8,0x88,0xf8,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xa0,0x40,
+/* 33853 0x843d "落" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x11,0x82,0x48,0x49,0x16,0xe1,0x21,0x21,0x21,0x21,
+0x20,0x20,0xfe,0x20,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 33854 0x843e "萾" */
+0x08,0xff,0x08,0x00,0x3f,0x08,0x0b,0x0a,0x11,0x22,0x5f,0x12,0x12,0x12,0xff,0x00,
+0x20,0xfe,0x20,0x00,0xe0,0x20,0xf8,0x88,0x28,0x90,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 33855 0x843f "萿" */
+0x04,0x04,0xff,0x04,0x20,0x13,0x10,0x80,0x47,0x50,0x10,0x23,0xe2,0x22,0x23,0x22,
+0x40,0x40,0xfe,0x40,0x38,0xc0,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 33856 0x8440 "葀" */
+0x04,0x04,0xff,0x04,0x10,0x13,0xfc,0x10,0x17,0x18,0x30,0xd3,0x12,0x12,0x53,0x22,
+0x40,0x40,0xfe,0x40,0x38,0xc0,0x40,0x40,0xfc,0x40,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 33857 0x8441 "葁" */
+0x04,0xff,0x04,0x08,0x04,0x7f,0x01,0x3f,0x01,0xff,0x02,0xff,0x08,0x1c,0x03,0x3c,
+0x40,0xfe,0x40,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 33858 0x8442 "葂" */
+0x04,0x04,0xff,0x04,0x20,0x3e,0x44,0x88,0x7f,0x49,0x49,0x7f,0x14,0x24,0x45,0x83,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x44,0x54,0x8a,0x02,0xfe,
+/* 33859 0x8443 "葃" */
+0x08,0x08,0xff,0x08,0x00,0x7c,0x44,0x45,0x46,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfe,0x40,0x40,0x7c,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 33860 0x8444 "葄" */
+0x08,0x08,0xff,0x08,0x00,0x3e,0x22,0x22,0x3e,0x23,0x22,0x3e,0x22,0x22,0x4a,0x84,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x7e,0xa0,0xa0,0x3c,0x20,0x20,0x3e,0x20,0x20,0x20,
+/* 33861 0x8445 "葅" */
+0x04,0x04,0xff,0x04,0x00,0x11,0x11,0x29,0x45,0x91,0x11,0x29,0x25,0x41,0x87,0x00,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 33862 0x8446 "葆" */
+0x04,0x04,0xff,0x04,0x08,0x0b,0x12,0x32,0x53,0x90,0x17,0x10,0x11,0x12,0x1c,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x08,0x08,0xf8,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 33863 0x8447 "葇" */
+0x04,0xff,0x04,0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x01,0xff,0x05,0x19,0xe1,0x01,
+0x40,0xfe,0x40,0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 33864 0x8448 "葈" */
+0x04,0x04,0xff,0x14,0x20,0x7f,0x00,0x3f,0x20,0x3f,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x40,0x40,0xfe,0x40,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 33865 0x8449 "葉" */
+0x04,0x04,0xff,0x04,0x12,0x7f,0x12,0x13,0x10,0x1f,0x01,0xff,0x05,0x19,0xe1,0x01,
+0x40,0x40,0xfe,0x40,0x20,0xfc,0x20,0xe0,0x00,0xf8,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 33866 0x844a "葊" */
+0x08,0x08,0xff,0x09,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x08,0xff,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x20,0xfe,0x20,0x20,0x20,
+/* 33867 0x844b "葋" */
+0x08,0x08,0xff,0x08,0x00,0x3c,0x24,0x25,0x3e,0x24,0x24,0x3c,0x24,0x24,0x54,0x88,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x94,0x04,0x28,0x10,
+/* 33868 0x844c "葌" */
+0x08,0xff,0x08,0x04,0xff,0x08,0x1e,0x03,0x3c,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,
+0x20,0xfe,0x20,0x00,0xfe,0x20,0x40,0xc0,0x38,0x10,0xfe,0x24,0x64,0x18,0x34,0xc2,
+/* 33869 0x844d "葍" */
+0x04,0x04,0xff,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 33870 0x844e "葎" */
+0x08,0x08,0xff,0x08,0x00,0x13,0x20,0x47,0x88,0x13,0x30,0x53,0x90,0x17,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,
+/* 33871 0x844f "葏" */
+0x08,0x08,0xff,0x08,0x20,0x13,0x90,0x4f,0x40,0x13,0x20,0xe3,0x20,0x2f,0x20,0x20,
+0x20,0x20,0xfe,0x20,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x40,
+/* 33872 0x8450 "葐" */
+0x08,0x08,0xff,0x08,0x04,0x08,0x30,0xcf,0x04,0x18,0x60,0x3f,0x24,0x24,0x24,0xff,
+0x20,0x20,0xfe,0x20,0x40,0x20,0x18,0xe6,0x20,0xa0,0x40,0xf8,0x48,0x48,0x48,0xfe,
+/* 33873 0x8451 "葑" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x7f,0x08,0xff,0x08,0x08,0x7f,0x08,0x0f,0xf0,0x40,
+0x40,0x40,0xfe,0x40,0x00,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 33874 0x8452 "葒" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x25,0x7c,0x08,0x10,0x24,0x7e,0x00,0x54,0x4b,0x8a,
+0x40,0x40,0xfe,0x40,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 33875 0x8453 "葓" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x10,0x13,0x80,0x48,0x48,0x17,0xe0,0x20,0x21,0x22,
+0x20,0x20,0xfe,0x20,0x20,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x00,0x90,0x08,0x04,
+/* 33876 0x8454 "葔" */
+0x08,0xff,0x08,0x00,0x09,0x08,0x10,0x37,0x51,0x91,0x12,0x10,0x17,0x10,0x11,0x12,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0xfc,0x00,0xf8,0x40,0x40,0xfc,0xa0,0x10,0x0c,
+/* 33877 0x8455 "葕" */
+0x08,0x08,0xff,0x08,0x12,0x21,0x49,0x94,0x24,0x61,0xa2,0x2e,0x22,0x22,0x22,0x20,
+0x20,0x20,0xfe,0x20,0x00,0x3c,0x00,0x00,0x7e,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 33878 0x8456 "葖" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x48,0x91,0x21,0x01,0x7f,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x22,0x14,0x28,0x10,0xfc,0x80,0x40,0x20,0x18,0x06,
+/* 33879 0x8457 "著" */
+0x08,0xff,0x08,0x02,0x3f,0x02,0x02,0xff,0x03,0x0c,0x3f,0xc8,0x0f,0x08,0x0f,0x08,
+0x20,0xfe,0x20,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 33880 0x8458 "葘" */
+0x04,0x04,0xff,0x04,0x08,0x11,0xff,0x11,0x08,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x40,0x40,0xfe,0x40,0x88,0x10,0xfe,0x10,0x88,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 33881 0x8459 "葙" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x7e,0x08,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 33882 0x845a "葚" */
+0x04,0x04,0xff,0x04,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x12,0x14,0x10,0x1f,
+0x40,0x40,0xfe,0x40,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x40,0x20,0x00,0xf8,
+/* 33883 0x845b "葛" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x1f,0x21,0x52,0x94,0x10,0x1f,0x00,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x84,0x44,0x04,0xa8,0x10,
+/* 33884 0x845c "葜" */
+0x04,0xff,0x04,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x01,0xff,0x02,0x0c,0x30,0xc0,
+0x40,0xfe,0x40,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xfe,0x80,0x60,0x18,0x06,
+/* 33885 0x845d "葝" */
+0x04,0x04,0xff,0x04,0x00,0x7f,0x2a,0x54,0x2a,0x00,0x7e,0x08,0x08,0x0e,0xf0,0x41,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 33886 0x845e "葞" */
+0x08,0xff,0x08,0x00,0x7d,0x04,0x04,0x7c,0x40,0x40,0x7c,0x04,0x04,0x05,0x28,0x10,
+0x20,0xfe,0x20,0x00,0xfc,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 33887 0x845f "葟" */
+0x08,0x08,0xff,0x09,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x01,0x3f,0x01,0xff,
+0x20,0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xf8,0x00,0xfe,
+/* 33888 0x8460 "葠" */
+0x04,0x04,0xff,0x04,0x0b,0x08,0x11,0x30,0x53,0x90,0x17,0x14,0x13,0x11,0x10,0x17,
+0x40,0x40,0xfe,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 33889 0x8461 "葡" */
+0x04,0x04,0xff,0x24,0x3f,0x42,0x7f,0x82,0x3f,0x22,0x3f,0x22,0x3f,0x22,0x22,0x20,
+0x40,0x40,0xfe,0x40,0xfc,0x24,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xa4,0x4c,
+/* 33890 0x8462 "葢" */
+0x08,0x08,0xff,0x09,0x01,0x7f,0x04,0x0a,0x31,0xc0,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x80,0x60,0x18,0x06,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 33891 0x8463 "董" */
+0x08,0xff,0x08,0x1f,0x01,0x7f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,
+0x20,0xfe,0x20,0xf0,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 33892 0x8464 "葤" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x24,0x7d,0x08,0x10,0x24,0x7e,0x00,0x54,0x4a,0x8a,
+0x40,0x40,0xfe,0x40,0x08,0x08,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 33893 0x8465 "葥" */
+0x04,0x04,0xff,0x04,0x10,0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2a,0x24,
+0x40,0x40,0xfe,0x40,0x10,0x20,0xfe,0x00,0x48,0x48,0x48,0x48,0x08,0x08,0x28,0x10,
+/* 33894 0x8466 "葦" */
+0x08,0xff,0x08,0x02,0x3f,0x04,0xff,0x00,0x1f,0x10,0x1f,0x01,0x1f,0x21,0x3f,0x01,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf0,0x00,0xf8,0x00,
+/* 33895 0x8467 "葧" */
+0x04,0x04,0xff,0x04,0x08,0x7f,0x08,0x7f,0x41,0x3e,0x04,0x0f,0x78,0x08,0x28,0x10,
+0x40,0x40,0xfe,0x40,0x10,0x10,0x10,0x7e,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,
+/* 33896 0x8468 "葨" */
+0x04,0x04,0xff,0x04,0x1f,0x11,0x1f,0x11,0x1f,0x00,0xff,0x11,0x10,0x14,0x18,0x10,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xa0,0x40,0x30,0x0e,
+/* 33897 0x8469 "葩" */
+0x04,0x04,0xff,0x04,0x10,0x21,0x7d,0x45,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x44,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 33898 0x846a "葪" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x24,0x42,0x81,
+0x40,0x40,0xfe,0x40,0x04,0x04,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x08,
+/* 33899 0x846b "葫" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x7f,0x08,0x08,0x3e,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x84,0x94,0x08,
+/* 33900 0x846c "葬" */
+0x08,0xff,0x08,0xff,0x10,0x3e,0x42,0x24,0x18,0xe0,0x08,0x08,0xff,0x08,0x10,0x20,
+0x20,0xfe,0x20,0xfe,0x80,0x98,0xe0,0x84,0x84,0x7c,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 33901 0x846d "葭" */
+0x08,0xff,0x08,0x00,0x7c,0x44,0x44,0x7c,0x40,0x41,0x7c,0x40,0x40,0x7c,0x40,0x43,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x00,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 33902 0x846e "葮" */
+0x08,0xff,0x08,0x06,0x38,0x20,0x20,0x3d,0x22,0x21,0x3c,0x20,0x2c,0xf0,0x20,0x27,
+0x20,0xfe,0x20,0x00,0xf8,0x88,0x88,0x06,0x00,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 33903 0x846f "葯" */
+0x08,0x08,0xff,0x08,0x10,0x14,0x24,0x78,0x11,0x24,0x7e,0x00,0x54,0x4a,0x8a,0x00,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x7c,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x28,0x10,
+/* 33904 0x8470 "葰" */
+0x04,0x04,0xff,0x04,0x09,0x0a,0x17,0x31,0x52,0x94,0x11,0x13,0x14,0x10,0x11,0x16,
+0x40,0x40,0xfe,0x40,0x10,0x08,0xfc,0x10,0x08,0x84,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 33905 0x8471 "葱" */
+0x04,0x04,0xff,0x04,0x08,0x1f,0x2a,0x44,0x0a,0x11,0x22,0x04,0x01,0x48,0x48,0x87,
+0x40,0x40,0xfe,0x40,0x00,0xf8,0x48,0x48,0x88,0x08,0xa8,0x10,0x00,0x84,0x12,0xf2,
+/* 33906 0x8472 "葲" */
+0x08,0xff,0x0a,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x7d,0x09,0x11,0x21,0xc5,0x02,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 33907 0x8473 "葳" */
+0x04,0x04,0xff,0x04,0x00,0x00,0x3f,0x20,0x2f,0x22,0x2f,0x24,0x2d,0x42,0x45,0x88,
+0x40,0x40,0xfe,0x40,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x12,0x2a,0x46,0x82,
+/* 33908 0x8474 "葴" */
+0x04,0x04,0xff,0x04,0x00,0x00,0x3f,0x20,0x2f,0x20,0x2f,0x28,0x28,0x4f,0x40,0x80,
+0x40,0x40,0xfe,0x40,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x92,0xaa,0x46,0x82,
+/* 33909 0x8475 "葵" */
+0x08,0xff,0x08,0x00,0x7e,0x04,0x28,0x10,0x2f,0xc1,0x01,0x7f,0x01,0x02,0x0c,0x70,
+0x20,0xfe,0x20,0x90,0xa0,0x44,0x28,0x10,0xe8,0x06,0x00,0xfc,0x00,0xc0,0x30,0x08,
+/* 33910 0x8476 "葶" */
+0x08,0xff,0x09,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x9f,0x01,0x01,0x05,0x02,
+0x20,0xfe,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0x00,0x00,0x00,
+/* 33911 0x8477 "葷" */
+0x08,0xff,0x08,0x7f,0x41,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0xfc,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 33912 0x8478 "葸" */
+0x08,0xff,0x08,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x02,0x51,0x51,0x90,0x0f,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x04,0x12,0x12,0xf0,
+/* 33913 0x8479 "葹" */
+0x08,0x08,0xff,0x08,0x20,0x10,0xfe,0x21,0x20,0x3c,0x25,0x24,0x24,0x44,0x54,0x88,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xfe,0x20,0xac,0xb4,0xe4,0xac,0xa0,0xa2,0x82,0x7e,
+/* 33914 0x847a "葺" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x00,0x7f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x00,0x00,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x3e,0xd0,0x10,0x10,
+/* 33915 0x847b "葻" */
+0x04,0x04,0xff,0x04,0x00,0x1f,0x10,0x10,0x17,0x11,0x17,0x15,0x27,0x21,0x4f,0x80,
+0x40,0x40,0xfe,0x40,0x00,0xf0,0x10,0xd0,0x10,0x10,0xd0,0x50,0xca,0x2a,0xe6,0x22,
+/* 33916 0x847c "葼" */
+0x08,0x08,0xff,0x08,0x24,0x23,0x24,0x3f,0x10,0x22,0x47,0x08,0x14,0x03,0x1c,0xe0,
+0x20,0x20,0xfe,0x20,0x48,0x88,0x48,0xf8,0x10,0x08,0xe4,0x20,0x40,0x80,0x70,0x0e,
+/* 33917 0x847d "葽" */
+0x08,0x08,0xff,0x08,0x7f,0x04,0x3f,0x24,0x3f,0x04,0xff,0x08,0x1c,0x03,0x0c,0x30,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 33918 0x847e "葾" */
+0x08,0x08,0xff,0x08,0x10,0x1e,0x22,0x62,0x94,0x08,0x30,0xc1,0x08,0x48,0x48,0x87,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x88,0xa8,0x92,0x82,0x7e,0x00,0x84,0x92,0x12,0xf0,
+/* 33919 0x847f "葿" */
+0x08,0x08,0xff,0x08,0x3f,0x21,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x4f,0x48,0x8f,0x08,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 33920 0x8480 "蒀" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 33921 0x8481 "蒁" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x17,0x00,0x01,0xf1,0x12,0x14,0x10,0x28,0x47,0x00,
+0x20,0x20,0xfe,0x20,0x50,0x48,0xfc,0xc0,0x60,0x50,0x48,0x44,0x40,0x00,0xfe,0x00,
+/* 33922 0x8482 "蒂" */
+0x08,0xff,0x0a,0x01,0x3f,0x08,0x04,0x7f,0x41,0x81,0x1f,0x11,0x11,0x11,0x01,0x01,
+0x20,0xfe,0x20,0x00,0xf8,0x20,0x40,0xfe,0x02,0x04,0xf0,0x10,0x50,0x20,0x00,0x00,
+/* 33923 0x8483 "蒃" */
+0x04,0xff,0x04,0x08,0x0f,0x10,0x1f,0x00,0xff,0x06,0x3b,0x04,0x19,0x62,0x0c,0x73,
+0x40,0xfe,0x40,0x00,0xe0,0x20,0xc0,0x40,0xfe,0x00,0x08,0xb0,0xc0,0xa0,0x98,0x06,
+/* 33924 0x8484 "蒄" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0x80,0x3e,0x00,0x7e,0x14,0x14,0x14,0x24,0x24,0x43,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0x04,0x08,0x08,0xfe,0x48,0x28,0x0a,0x2a,0x12,0xfe,
+/* 33925 0x8485 "蒅" */
+0x04,0xff,0x04,0x10,0x08,0x43,0x28,0x11,0x72,0x14,0x11,0xff,0x05,0x19,0xe1,0x01,
+0x40,0xfe,0x40,0x80,0x80,0xf0,0x90,0x12,0x12,0x0e,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 33926 0x8486 "蒆" */
+0x08,0xff,0x08,0x00,0x7d,0x11,0x11,0x1d,0xf2,0x04,0xff,0x08,0x1c,0x03,0x0c,0x70,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0x90,0x52,0x0e,0x00,0xfe,0x20,0x40,0x80,0x70,0x08,
+/* 33927 0x8487 "蒇" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x2f,0x28,0x2a,0x2a,0x2a,0x2a,0x45,0x49,0x90,
+0x40,0x40,0xfe,0x48,0x24,0xfe,0x20,0xa4,0xa4,0xa8,0xa8,0x90,0x92,0x2a,0x46,0x82,
+/* 33928 0x8488 "蒈" */
+0x04,0x04,0xff,0x04,0x20,0x3c,0x20,0x2c,0x30,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x40,0x40,0xfe,0x40,0x88,0x90,0xe4,0x84,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 33929 0x8489 "蒉" */
+0x08,0xff,0x08,0x01,0x1f,0x11,0x1f,0x01,0xff,0x00,0x1f,0x10,0x11,0x02,0x0c,0x70,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0x10,0xc0,0x30,0x08,
+/* 33930 0x848a "蒊" */
+0x04,0x04,0xff,0x04,0x08,0x10,0x30,0x57,0x90,0x10,0x00,0x7c,0x44,0x44,0x7c,0x44,
+0x40,0x40,0xfe,0x40,0x80,0x98,0xe0,0x84,0x84,0x7c,0x00,0x88,0xb0,0xc4,0x84,0x7c,
+/* 33931 0x848b "蒋" */
+0x08,0x08,0xff,0x08,0x00,0x08,0x49,0x2a,0x28,0x08,0x1b,0x29,0x48,0x88,0x08,0x08,
+0x20,0x20,0xfe,0x20,0x80,0xf8,0x10,0xa0,0x50,0x90,0xfe,0x10,0x90,0x90,0x10,0x30,
+/* 33932 0x848c "蒌" */
+0x04,0x04,0xff,0x04,0x11,0x09,0x7f,0x05,0x19,0x61,0x04,0xff,0x08,0x1e,0x03,0x3c,
+0x40,0x40,0xfe,0x40,0x10,0x20,0xfc,0x40,0x30,0x0c,0x00,0xfe,0x20,0x40,0xc0,0x38,
+/* 33933 0x848d "蒍" */
+0x08,0xff,0x08,0x24,0x14,0x7f,0x04,0x08,0x0f,0x08,0x10,0x1f,0x20,0x25,0x49,0x80,
+0x20,0xfe,0x20,0x00,0x00,0xe0,0x20,0x20,0xf8,0x08,0x08,0xfe,0x02,0x52,0x54,0x08,
+/* 33934 0x848e "蒎" */
+0x04,0x04,0xff,0x04,0x20,0x13,0x92,0x42,0x4a,0x0a,0x12,0xe2,0x22,0x24,0x24,0x28,
+0x40,0x40,0xfe,0x40,0x1c,0xe0,0x0e,0xf0,0x90,0x90,0x92,0x94,0x88,0x88,0xa4,0xc2,
+/* 33935 0x848f "蒏" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0xbf,0x04,0x3f,0x24,0x28,0x30,0x3f,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0xf4,0x80,0xf8,0x88,0x78,0x08,0xf8,0x08,0xf8,0x08,
+/* 33936 0x8490 "蒐" */
+0x08,0x08,0xff,0x0a,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x02,0x02,0x04,0x08,0x30,0xc0,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x90,0xa8,0xb8,0x8a,0x82,0x7e,
+/* 33937 0x8491 "蒑" */
+0x08,0xff,0x08,0x06,0x38,0x20,0x3e,0x22,0x3f,0x22,0x3e,0x20,0x3e,0x22,0x4a,0x84,
+0x20,0xfe,0x20,0x00,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 33938 0x8492 "蒒" */
+0x04,0xff,0x04,0x10,0x23,0x7c,0x44,0x45,0x7d,0x41,0x7d,0x45,0x45,0x7d,0x44,0x00,
+0x40,0xfe,0x40,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 33939 0x8493 "蒓" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x25,0x7c,0x09,0x11,0x25,0x7d,0x00,0x54,0x54,0x80,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x22,0x22,0x22,0x1e,
+/* 33940 0x8494 "蒔" */
+0x08,0x08,0xff,0x08,0x00,0x78,0x4b,0x48,0x4f,0x78,0x4f,0x48,0x4a,0x79,0x48,0x00,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xfc,0x40,0xfe,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 33941 0x8495 "蒕" */
+0x04,0x04,0xff,0x04,0x1f,0x11,0x12,0x14,0x1f,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0x90,0x50,0xf0,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 33942 0x8496 "蒖" */
+0x08,0xff,0x09,0x7f,0x01,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0xff,0x08,0x10,
+0x20,0xfe,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x10,
+/* 33943 0x8497 "蒗" */
+0x08,0x08,0xff,0x08,0x20,0x13,0x92,0x43,0x4a,0x0b,0x12,0xe2,0x22,0x22,0x23,0x22,
+0x20,0x20,0xfe,0xa0,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x42,0x44,0x28,0x90,0x08,0x06,
+/* 33944 0x8498 "蒘" */
+0x04,0xff,0x04,0x08,0x7f,0x11,0x32,0x0c,0x32,0xdf,0x01,0x3f,0x01,0x7f,0x01,0x03,
+0x40,0xfe,0x40,0x00,0x7c,0x44,0x44,0x7c,0x20,0xc0,0x00,0xf8,0x00,0xfc,0x00,0x00,
+/* 33945 0x8499 "蒙" */
+0x08,0xff,0x08,0x7f,0x40,0x8f,0x00,0x7f,0x06,0x3b,0x04,0x19,0x62,0x0c,0x72,0x01,
+0x20,0xfe,0x20,0xfe,0x02,0xe4,0x00,0xfc,0x00,0x08,0xb0,0xc0,0xa0,0x98,0x86,0x00,
+/* 33946 0x849a "蒚" */
+0x08,0xff,0x08,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x48,0x44,0x5f,0x41,0x41,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x24,0x44,0xf4,0x04,0x0c,
+/* 33947 0x849b "蒛" */
+0x04,0x04,0xff,0x04,0x20,0x20,0x3d,0x50,0x10,0xfc,0x11,0x54,0x54,0x5c,0x74,0x05,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x06,
+/* 33948 0x849c "蒜" */
+0x08,0x08,0xff,0x08,0x00,0x7c,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 33949 0x849d "蒝" */
+0x04,0xff,0x04,0x00,0x3f,0x20,0x21,0x27,0x24,0x27,0x24,0x27,0x40,0x44,0x8a,0x11,
+0x40,0xfe,0x40,0x00,0xfc,0x80,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x80,0x90,0x88,0x04,
+/* 33950 0x849e "蒞" */
+0x08,0x08,0xff,0x08,0x21,0x11,0x12,0x82,0x46,0x5a,0x12,0x22,0xe2,0x22,0x22,0x22,
+0x20,0x20,0xfe,0x20,0x40,0x20,0x00,0xfc,0x00,0x88,0x48,0x48,0x50,0x00,0xfc,0x00,
+/* 33951 0x849f "蒟" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x10,0xfd,0x02,0x48,0x48,0x48,0x10,0x1e,0xf0,0x40,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x94,0x04,0x28,0x10,
+/* 33952 0x84a0 "蒠" */
+0x08,0xff,0x08,0x02,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x01,0x08,0x48,0x48,0x87,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x84,0x92,0x12,0xf0,
+/* 33953 0x84a1 "蒡" */
+0x08,0xff,0x08,0x01,0x3f,0x08,0x04,0x7f,0x42,0x81,0x3f,0x04,0x07,0x08,0x10,0x20,
+0x20,0xfe,0x20,0x00,0xf8,0x20,0x40,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0x50,0x20,
+/* 33954 0x84a2 "蒢" */
+0x08,0x08,0xff,0x08,0x78,0x48,0x51,0x62,0x55,0x48,0x4b,0x68,0x51,0x42,0x45,0x40,
+0x20,0x20,0xfe,0x20,0x40,0xa0,0x10,0x08,0xf6,0x40,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 33955 0x84a3 "蒣" */
+0x08,0x08,0xff,0x08,0x10,0x20,0x41,0x8a,0x15,0x30,0x53,0x90,0x11,0x12,0x15,0x10,
+0x20,0x20,0xfe,0x20,0x40,0xa0,0x10,0x08,0xf6,0x40,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 33956 0x84a4 "蒤" */
+0x08,0x08,0xff,0x08,0x20,0x10,0x91,0x42,0x4d,0x10,0x27,0xe0,0x22,0x24,0x29,0x20,
+0x20,0x20,0xfe,0x20,0x40,0xa0,0x10,0x08,0xf6,0x40,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 33957 0x84a5 "蒥" */
+0x08,0x08,0xff,0x08,0x04,0x79,0x40,0x48,0x54,0x62,0x3f,0x21,0x3f,0x21,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x44,0x44,0x54,0x88,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 33958 0x84a6 "蒦" */
+0x04,0xff,0x04,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3f,0x0c,0x03,0x7c,
+0x40,0xfe,0x40,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xf0,0x60,0x80,0x7c,
+/* 33959 0x84a7 "蒧" */
+0x04,0x04,0xff,0x04,0x00,0x00,0x3f,0x22,0x23,0x22,0x2f,0x28,0x28,0x4f,0x40,0x80,
+0x40,0x40,0xfe,0x40,0x28,0x24,0xfe,0x20,0xa4,0x24,0xa8,0x98,0x92,0xaa,0x46,0x82,
+/* 33960 0x84a8 "蒨" */
+0x04,0xff,0x04,0x13,0x10,0x23,0x20,0x6f,0xa0,0x23,0x22,0x23,0x22,0x23,0x22,0x22,
+0x40,0xfe,0x40,0xf8,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 33961 0x84a9 "蒩" */
+0x08,0x08,0xff,0x08,0x0c,0x71,0x11,0x11,0xfd,0x31,0x39,0x55,0x51,0x91,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 33962 0x84aa "蒪" */
+0x08,0xff,0x09,0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x00,0xff,0x08,0x04,
+0x20,0xfe,0x20,0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x20,0xfe,0x20,0x60,
+/* 33963 0x84ab "蒫" */
+0x04,0xff,0x04,0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x08,0x17,0x20,0x40,0x9f,0x00,
+0x40,0xfe,0x40,0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x80,0x80,0xfc,0x00,
+/* 33964 0x84ac "蒬" */
+0x08,0x08,0xff,0x08,0x7f,0x44,0x8f,0x10,0x3f,0x51,0x11,0x1f,0x02,0x04,0x18,0xe0,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0xe4,0x20,0xf8,0x08,0x08,0xf8,0x80,0x92,0x8a,0x7e,
+/* 33965 0x84ad "蒭" */
+0x08,0xff,0x08,0x10,0x1f,0x21,0x51,0x1f,0x02,0x14,0x1f,0x21,0x51,0x1f,0x04,0x38,
+0x20,0xfe,0x20,0x00,0xfc,0x04,0x14,0xf4,0x08,0x00,0xfc,0x04,0x14,0xf4,0x14,0x08,
+/* 33966 0x84ae "蒮" */
+0x08,0x08,0xff,0x08,0x04,0x7f,0x45,0x08,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x10,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x04,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 33967 0x84af "蒯" */
+0x11,0x11,0xff,0x11,0x00,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0x7b,0x4a,0x4a,0xab,0x14,
+0x02,0x02,0xe2,0x0a,0x0a,0xca,0x4a,0x4a,0xca,0x4a,0x4a,0xca,0x42,0x42,0x4a,0x84,
+/* 33968 0x84b0 "蒰" */
+0x08,0x08,0xff,0x08,0x10,0x3e,0x22,0x2a,0x23,0xfe,0x22,0x2a,0x22,0x42,0x4a,0x84,
+0x20,0x20,0xfe,0x20,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 33969 0x84b1 "蒱" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xfd,0x10,0x15,0x19,0x31,0xd1,0x11,0x11,0x51,0x21,
+0x40,0x40,0xfe,0x40,0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x0c,
+/* 33970 0x84b2 "蒲" */
+0x08,0x08,0xff,0x08,0x40,0x27,0x20,0x87,0x44,0x57,0x14,0xe7,0x24,0x24,0x24,0x04,
+0x20,0x20,0xfe,0x28,0x44,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 33971 0x84b3 "蒳" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x25,0x7d,0x09,0x11,0x25,0x7d,0x01,0x55,0x55,0x81,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x24,0x24,0x54,0x4c,0x84,0x04,0x04,0x14,0x08,
+/* 33972 0x84b4 "蒴" */
+0x08,0x08,0xff,0x08,0x41,0x22,0xff,0x08,0x49,0x49,0x49,0x7f,0x11,0x20,0x40,0x81,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0xc4,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x94,0x08,
+/* 33973 0x84b5 "蒵" */
+0x04,0xff,0x04,0x00,0x7f,0x22,0x15,0x08,0x1f,0x01,0x1f,0x02,0x7f,0x04,0x18,0xe0,
+0x40,0xfe,0x40,0x38,0xc0,0x08,0x10,0x40,0x80,0x20,0xf0,0x10,0xfc,0x40,0x30,0x0e,
+/* 33974 0x84b6 "蒶" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x24,0x7d,0x0a,0x11,0x24,0x7c,0x00,0x54,0x55,0x82,
+0x40,0x40,0xfe,0x40,0x10,0x90,0x88,0x04,0x02,0xf8,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 33975 0x84b7 "蒷" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,
+/* 33976 0x84b8 "蒸" */
+0x08,0x08,0xff,0x08,0x1f,0x00,0x7d,0x05,0x09,0x31,0xc5,0x02,0x3f,0x00,0x24,0x42,
+0x20,0x20,0xfe,0x20,0xc0,0x44,0x88,0x50,0x20,0x18,0x06,0x00,0xf8,0x00,0x88,0x44,
+/* 33977 0x84b9 "蒹" */
+0x08,0xff,0x08,0x10,0x08,0xff,0x04,0x3f,0x04,0xff,0x04,0x3f,0x0c,0x34,0xc4,0x04,
+0x20,0xfe,0x20,0x10,0x20,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x60,0x58,0x46,0x40,
+/* 33978 0x84ba "蒺" */
+0x08,0xff,0x09,0x00,0x1f,0x10,0x92,0x53,0x54,0x10,0x3f,0x50,0x90,0x21,0x22,0x4c,
+0x20,0xfe,0x20,0x80,0xfc,0x00,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 33979 0x84bb "蒻" */
+0x08,0x08,0xff,0x08,0x00,0x7e,0x02,0x7e,0x40,0x7e,0x02,0x22,0x1a,0x62,0x14,0x08,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x04,0xfc,0x80,0xfc,0x04,0x44,0x34,0xc4,0x28,0x10,
+/* 33980 0x84bc "蒼" */
+0x08,0x08,0xff,0x09,0x06,0x1a,0xe1,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x2f,0x48,0x8f,
+0x20,0x20,0xfe,0x20,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,
+/* 33981 0x84bd "蒽" */
+0x08,0xff,0x08,0x00,0x3f,0x21,0x2f,0x22,0x24,0x28,0x3f,0x01,0x08,0x48,0x48,0x87,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0xe8,0x88,0x48,0x28,0xf8,0x00,0x84,0x92,0x12,0xf0,
+/* 33982 0x84be "蒾" */
+0x08,0x08,0xff,0x08,0x20,0x12,0x11,0x00,0xf7,0x10,0x11,0x12,0x14,0x10,0x28,0x47,
+0x20,0x20,0xfe,0x20,0x40,0x48,0x50,0x40,0xfc,0xe0,0x50,0x48,0x44,0x40,0x00,0xfe,
+/* 33983 0x84bf "蒿" */
+0x08,0xff,0x08,0x02,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x4f,0x48,0x4f,0x40,
+0x20,0xfe,0x20,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xe4,0x24,0xe4,0x0c,
+/* 33984 0x84c0 "蓀" */
+0x04,0x04,0xff,0x04,0x00,0x7d,0x04,0x08,0x11,0x10,0x1c,0xf3,0x10,0x11,0x52,0x20,
+0x40,0x40,0xfe,0x40,0x0c,0xf0,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 33985 0x84c1 "蓁" */
+0x08,0xff,0x08,0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x17,0x21,0xdf,0x05,0x09,0x11,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xd0,0x08,0xf6,0x40,0x20,0x10,
+/* 33986 0x84c2 "蓂" */
+0x08,0x08,0xff,0x08,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x10,0x08,
+/* 33987 0x84c3 "蓃" */
+0x08,0xff,0x08,0x05,0x39,0x21,0x3d,0x21,0x3f,0x01,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x20,0xfe,0x20,0x00,0x78,0x08,0x78,0x08,0xf8,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 33988 0x84c4 "蓄" */
+0x08,0xff,0x08,0x01,0xff,0x08,0x1f,0x03,0x0c,0x3f,0x00,0x3f,0x21,0x3f,0x21,0x3f,
+0x20,0xfe,0x20,0x00,0xfe,0x20,0xc0,0x10,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x08,0xf8,
+/* 33989 0x84c5 "蓅" */
+0x04,0x04,0xff,0x04,0x20,0x17,0x10,0x81,0x43,0x50,0x11,0x21,0xe1,0x22,0x22,0x24,
+0x40,0x40,0xfe,0x40,0x20,0xfe,0x80,0x08,0xfc,0x04,0x50,0x50,0x50,0x52,0x52,0x4e,
+/* 33990 0x84c6 "蓆" */
+0x08,0xff,0x09,0x00,0x3f,0x22,0x22,0x3f,0x22,0x23,0x20,0x2f,0x48,0x48,0x88,0x00,
+0x20,0xfe,0x20,0x80,0xfc,0x20,0x20,0xfc,0x20,0xe0,0x80,0xf8,0x88,0xa8,0x90,0x80,
+/* 33991 0x84c7 "蓇" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,
+0x20,0xfe,0x20,0xf0,0x10,0x90,0x90,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x30,
+/* 33992 0x84c8 "蓈" */
+0x08,0x08,0xff,0x08,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x28,0x24,0x2a,0x32,0x20,0x00,
+0x20,0x20,0xfe,0x20,0x00,0x7c,0x44,0x48,0x50,0x48,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 33993 0x84c9 "蓉" */
+0x08,0x08,0xff,0x0a,0x01,0x7f,0x40,0x89,0x12,0x24,0x08,0x3f,0xc8,0x08,0x0f,0x08,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x24,0x90,0x48,0x20,0xf8,0x26,0x20,0xe0,0x20,
+/* 33994 0x84ca "蓊" */
+0x08,0xff,0x08,0x04,0x08,0x32,0xc4,0x0f,0x00,0x7e,0x22,0x12,0x0a,0x12,0x2a,0x44,
+0x20,0xfe,0x20,0x40,0x20,0x18,0x46,0xe0,0x20,0xfc,0x44,0x24,0x14,0x24,0x54,0x88,
+/* 33995 0x84cb "蓋" */
+0x08,0xff,0x08,0x01,0x3f,0x01,0x7f,0x08,0x10,0x3f,0x00,0x3f,0x24,0x24,0xff,0x00,
+0x20,0xfe,0x20,0x00,0xf8,0x00,0xfc,0x00,0x10,0xf8,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 33996 0x84cc "蓌" */
+0x04,0xff,0x04,0x11,0x11,0x29,0x7f,0x01,0xff,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe0,
+0x40,0xfe,0x40,0x10,0x10,0x28,0xfc,0x00,0xfe,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 33997 0x84cd "蓍" */
+0x08,0xff,0x0a,0x3f,0x02,0xff,0x02,0x0f,0x34,0xc3,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0xfe,0x20,0xc0,0x80,0xfe,0x20,0xc0,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 33998 0x84ce "蓎" */
+0x08,0xff,0x09,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x20,0x2f,0x20,0x4f,0x48,0x8f,0x08,
+0x20,0xfe,0x20,0x80,0xfc,0x80,0xf8,0x88,0xfe,0x88,0xf8,0x80,0xf8,0x08,0xf8,0x08,
+/* 33999 0x84cf "蓏" */
+0x08,0x08,0xff,0x08,0x00,0x06,0x38,0x28,0x2c,0x2a,0x2a,0x2a,0x28,0x55,0x5d,0x82,
+0x20,0x20,0xfe,0x20,0x00,0x1c,0xe8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa4,0x54,0x74,0x12,
+/* 34000 0x84d0 "蓐" */
+0x08,0xff,0x08,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x24,0x26,0x20,0x5f,0x44,0x82,0x00,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,0x20,0xfc,0x20,0xa0,0x40,
+/* 34001 0x84d1 "蓑" */
+0x08,0xff,0x08,0x01,0x7f,0x00,0x1f,0x10,0xff,0x10,0x1f,0x04,0x08,0x38,0xcb,0x0c,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf0,0x10,0xfe,0x10,0xf0,0x88,0x50,0x20,0x18,0x06,
+/* 34002 0x84d2 "蓒" */
+0x04,0x04,0xff,0x04,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x90,0x10,0x10,
+/* 34003 0x84d3 "蓓" */
+0x08,0x08,0xff,0x08,0x10,0x17,0x20,0x62,0xa1,0x2f,0x20,0x23,0x22,0x22,0x23,0x22,
+0x20,0x20,0xfe,0xa0,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 34004 0x84d4 "蓔" */
+0x04,0x04,0xff,0x04,0x08,0x04,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x24,0x22,0x42,
+0x40,0x40,0xfe,0x40,0x20,0x40,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x88,0x44,0x44,
+/* 34005 0x84d5 "蓕" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x11,0xfc,0x10,0x33,0x38,0x54,0x51,0x90,0x10,0x13,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 34006 0x84d6 "蓖" */
+0x08,0xff,0x08,0x02,0x3f,0x24,0x23,0x24,0x3f,0x00,0x20,0x3e,0x20,0x20,0x26,0x38,
+0x20,0xfe,0x20,0x00,0xf8,0x48,0x88,0x48,0xf8,0x00,0x84,0x98,0xe0,0x84,0x84,0x7c,
+/* 34007 0x84d7 "蓗" */
+0x08,0x08,0xff,0x08,0x10,0x23,0x40,0x88,0x17,0x30,0x52,0x92,0x12,0x15,0x18,0x10,
+0x20,0x20,0xfe,0x20,0x40,0xf8,0x40,0x40,0xfc,0x40,0x40,0x78,0x40,0x40,0xfe,0x00,
+/* 34008 0x84d8 "蓘" */
+0x08,0xff,0x0a,0x01,0x7f,0x08,0x12,0x24,0x48,0x1f,0x05,0x08,0x18,0x29,0xca,0x0c,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0x10,0x48,0x24,0xf0,0x10,0x88,0x50,0x20,0x18,0x06,
+/* 34009 0x84d9 "蓙" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x20,0x24,0x24,0x2a,0x31,0x20,0x2f,0x40,0x40,0x9f,
+0x20,0x20,0xfe,0x20,0x80,0xfe,0x80,0x90,0x90,0xa8,0xc4,0x80,0xf8,0x80,0x80,0xfe,
+/* 34010 0x84da "蓚" */
+0x08,0x08,0xff,0x08,0x10,0x11,0x22,0x28,0x6b,0xa8,0x28,0x29,0x28,0x29,0x20,0x21,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x88,0x70,0x8e,0x20,0x48,0x90,0x64,0x88,0x30,0xc0,
+/* 34011 0x84db "蓛" */
+0x04,0x04,0xff,0x04,0x08,0x08,0xff,0x08,0x7f,0x49,0x4b,0x1c,0x2a,0x49,0x88,0x08,
+0x40,0x40,0xfe,0x40,0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34012 0x84dc "蓜" */
+0x08,0x08,0xff,0x08,0x7f,0x14,0x14,0x7f,0x55,0x57,0x61,0x7f,0x41,0x41,0x7f,0x41,
+0x20,0x20,0xfe,0x20,0x7c,0x04,0x04,0x04,0x7c,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 34013 0x84dd "蓝" */
+0x08,0x08,0xff,0x08,0x04,0x24,0x24,0x24,0x25,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x20,0x20,0xfe,0x20,0x80,0x80,0xfc,0xa0,0x10,0x00,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 34014 0x84de "蓞" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x0c,0x30,0x20,0x3c,0x20,0x20,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0x08,0x10,0x20,0x78,0x08,0x78,0x08,0x08,0xf8,0x08,
+/* 34015 0x84df "蓟" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x00,0x07,0x78,0x20,
+0x40,0x40,0xfe,0x40,0x04,0x04,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0x04,0x84,0x14,0x08,
+/* 34016 0x84e0 "蓠" */
+0x08,0x08,0xff,0x09,0x00,0xff,0x04,0x13,0x14,0x1f,0x01,0x7f,0x44,0x4f,0x44,0x40,
+0x20,0x20,0xfe,0x20,0x80,0xfe,0x40,0x90,0x50,0xf0,0x00,0xfc,0x44,0xe4,0x24,0x0c,
+/* 34017 0x84e1 "蓡" */
+0x08,0x08,0xff,0x08,0x23,0x10,0x11,0x80,0x43,0x50,0x17,0x24,0xe3,0x21,0x20,0x27,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x04,0xf8,0x10,0xe0,0x1c,
+/* 34018 0x84e2 "蓢" */
+0x04,0x04,0xff,0x14,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x28,0x24,0x2a,0x32,0x21,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x94,0x08,
+/* 34019 0x84e3 "蓣" */
+0x08,0xff,0x08,0x00,0x7d,0x04,0x28,0x11,0xfd,0x15,0x11,0x11,0x11,0x10,0x50,0x23,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 34020 0x84e4 "蓤" */
+0x08,0x08,0xff,0x08,0x40,0x23,0x20,0x0f,0x11,0x12,0x24,0xe1,0x22,0x20,0x21,0x2e,
+0x20,0x20,0xfe,0x20,0x40,0xf8,0x40,0xfe,0x10,0x88,0xf4,0x10,0xa0,0x40,0xb0,0x0e,
+/* 34021 0x84e5 "蓥" */
+0x08,0x08,0xff,0x08,0x00,0x7f,0x41,0x82,0x0c,0x30,0xdf,0x01,0x3f,0x11,0x09,0x7f,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x02,0x84,0x60,0x18,0xf6,0x00,0xf8,0x10,0x20,0xfc,
+/* 34022 0x84e6 "蓦" */
+0x04,0xff,0x04,0x1f,0x10,0x1f,0x10,0xff,0x10,0x2f,0xc0,0x08,0x0f,0x00,0x7f,0x00,
+0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xfe,0x10,0xc8,0x46,0x40,0xf8,0x08,0xa8,0x10,
+/* 34023 0x84e7 "蓧" */
+0x08,0x08,0xff,0x08,0x10,0x11,0x22,0x68,0xab,0x28,0x29,0x28,0x28,0x29,0x22,0x20,
+0x20,0x20,0xfe,0x20,0x80,0xf8,0x88,0x70,0xae,0x20,0xfc,0x20,0xa8,0x24,0xa4,0x40,
+/* 34024 0x84e8 "蓨" */
+0x04,0xff,0x04,0x10,0x11,0x22,0x28,0x6b,0xa8,0x29,0x29,0x29,0x29,0x29,0x21,0x21,
+0x40,0xfe,0x40,0x80,0xfc,0x88,0x70,0x8e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x0c,
+/* 34025 0x84e9 "蓩" */
+0x08,0xff,0x08,0x00,0x7c,0x05,0x2a,0x10,0xfd,0x16,0x30,0x53,0x90,0x10,0x51,0x26,
+0x20,0xfe,0x20,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0x40,0xf8,0x48,0x88,0x50,0x20,
+/* 34026 0x84ea "蓪" */
+0x08,0x08,0xff,0x08,0x47,0x21,0x20,0x07,0xe4,0x27,0x24,0x27,0x24,0x24,0x54,0x8f,
+0x20,0x20,0xfe,0x20,0xf8,0x10,0xa0,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x54,0x08,0xfe,
+/* 34027 0x84eb "蓫" */
+0x08,0xff,0x08,0x23,0x10,0x11,0x06,0x70,0x11,0x16,0x10,0x11,0x16,0x28,0x47,0x00,
+0x20,0xfe,0x20,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x24,0xa0,0x40,0xfe,0x00,
+/* 34028 0x84ec "蓬" */
+0x08,0xff,0x08,0x01,0x23,0x15,0x10,0x07,0x70,0x13,0x10,0x11,0x10,0x17,0x28,0x47,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xe0,0x1c,0x40,0xf8,0x40,0xf0,0x40,0xfc,0x40,0xfe,
+/* 34029 0x84ed "蓭" */
+0x08,0xff,0x09,0x00,0x3f,0x20,0x3f,0x22,0x24,0x2f,0x34,0x27,0x24,0x47,0x40,0x80,
+0x20,0xfe,0x20,0x80,0xfc,0x80,0xfc,0x20,0x90,0xf8,0x94,0xf0,0x90,0xf2,0x82,0x7e,
+/* 34030 0x84ee "蓮" */
+0x08,0xff,0x08,0x00,0x27,0x10,0x13,0x02,0x73,0x12,0x13,0x10,0x17,0x28,0x47,0x00,
+0x20,0xfe,0x20,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x00,
+/* 34031 0x84ef "蓯" */
+0x04,0x04,0xff,0x04,0x11,0x21,0x41,0x8a,0x14,0x30,0x52,0x92,0x12,0x15,0x14,0x18,
+0x40,0x40,0xfe,0x40,0x10,0x10,0x10,0xa8,0x44,0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,
+/* 34032 0x84f0 "蓰" */
+0x04,0x04,0xff,0x04,0x10,0x21,0x41,0x89,0x17,0x30,0x50,0x91,0x11,0x11,0x12,0x14,
+0x40,0x40,0xfe,0x40,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x20,0x3e,0x20,0xa0,0x7e,
+/* 34033 0x84f1 "蓱" */
+0x08,0x08,0xff,0x08,0x21,0x10,0x93,0x40,0x48,0x08,0x17,0xe0,0x20,0x21,0x21,0x02,
+0x20,0x20,0xfe,0x20,0x08,0x90,0xfc,0x90,0x90,0x90,0xfe,0x90,0x90,0x10,0x10,0x10,
+/* 34034 0x84f2 "蓲" */
+0x08,0xff,0x08,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x29,0x2f,0x20,0x3f,0x00,
+0x20,0xfe,0x20,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x00,0x78,0x48,0x78,0x00,0xfc,0x00,
+/* 34035 0x84f3 "蓳" */
+0x04,0xff,0x04,0x08,0x7f,0x08,0x0f,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x01,0xff,0x00,
+0x40,0xfe,0x40,0x20,0xfc,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xfe,0x00,
+/* 34036 0x84f4 "蓴" */
+0x08,0xff,0x09,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x7f,0x00,0xff,0x08,0x04,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x04,0xfc,0x20,0xfe,0x20,0x60,
+/* 34037 0x84f5 "蓵" */
+0x04,0x04,0xff,0x04,0x10,0x13,0x10,0xfd,0x10,0x13,0x1c,0xf1,0x10,0x11,0x51,0x22,
+0x40,0x40,0xfe,0x40,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x3c,0x20,0xfe,
+/* 34038 0x84f6 "蓶" */
+0x04,0x04,0xff,0x04,0x00,0x00,0x79,0x49,0x4b,0x4d,0x49,0x49,0x79,0x49,0x01,0x01,
+0x40,0x40,0xfe,0x40,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34039 0x84f7 "蓷" */
+0x04,0x04,0xff,0x04,0x10,0x10,0xf9,0x11,0x1b,0x15,0x31,0xd1,0x11,0x11,0x51,0x21,
+0x40,0x40,0xfe,0x40,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34040 0x84f8 "蓸" */
+0x04,0xff,0x04,0x7f,0x04,0x3f,0x24,0x3f,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x40,0xfe,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 34041 0x84f9 "蓹" */
+0x04,0x04,0xff,0x04,0x14,0x27,0x49,0x81,0x17,0x21,0x61,0xa5,0x25,0x25,0x2e,0x24,
+0x40,0x40,0xfe,0x40,0x00,0xde,0x12,0x12,0xd2,0x12,0x12,0xd2,0x1a,0xd4,0x10,0x10,
+/* 34042 0x84fa "蓺" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x7c,0x10,0xfe,0x44,0x92,0x7c,0x10,0x1c,0xe1,0x42,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,
+/* 34043 0x84fb "蓻" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x7c,0x11,0xfe,0x44,0x28,0x7c,0x10,0xfe,0x11,0x12,
+0x20,0x20,0xfe,0x20,0x40,0x40,0x40,0xf8,0x48,0x48,0xc8,0x48,0xaa,0xaa,0x06,0x02,
+/* 34044 0x84fc "蓼" */
+0x08,0xff,0x08,0x3c,0x24,0x14,0x25,0x06,0x18,0xe3,0x0c,0x31,0x06,0x38,0x07,0x38,
+0x20,0xfe,0x20,0xf8,0x48,0x28,0x48,0xc0,0x30,0x0e,0x40,0x80,0x30,0xc0,0x00,0x00,
+/* 34045 0x84fd "蓽" */
+0x08,0xff,0x08,0x3f,0x21,0x3f,0x21,0x3f,0x09,0xff,0x09,0x3f,0x01,0x7f,0x01,0x01,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xfe,0x20,0xf8,0x00,0xfc,0x00,0x00,
+/* 34046 0x84fe "蓾" */
+0x08,0x08,0xff,0x09,0x01,0x01,0x3f,0x29,0x24,0x22,0x29,0x22,0x24,0x29,0x3f,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xf8,0x28,0x48,0x88,0x28,0x88,0x48,0x28,0xf8,0x08,
+/* 34047 0x84ff "蓿" */
+0x08,0xff,0x08,0x01,0x7f,0x48,0x8b,0x10,0x33,0x52,0x92,0x13,0x12,0x12,0x13,0x12,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0xf4,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 34048 0x8500 "蔀" */
+0x04,0x04,0xff,0x04,0x10,0x08,0x7f,0x22,0x14,0xff,0x00,0x3e,0x22,0x22,0x3e,0x22,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x48,0x50,0xc8,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 34049 0x8501 "蔁" */
+0x08,0xff,0x09,0x3f,0x04,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0xf8,0x40,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 34050 0x8502 "蔂" */
+0x08,0xff,0x08,0x1f,0x11,0x1f,0x11,0x1f,0x04,0x08,0x1f,0x03,0x3f,0x11,0x25,0x42,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x20,0xc0,0x10,0xf8,0x20,0x10,0x08,
+/* 34051 0x8503 "蔃" */
+0x08,0x08,0xff,0x08,0x7c,0x04,0x04,0x7c,0x41,0x41,0x7d,0x05,0x04,0x04,0x2b,0x10,
+0x20,0x20,0xfe,0x20,0xf8,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0x24,0xfe,0x02,
+/* 34052 0x8504 "蔄" */
+0x08,0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x20,0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 34053 0x8505 "蔅" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x41,0x4f,0x42,0x46,0x41,0x42,0x4c,0x40,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x44,0x44,0x84,0x44,0x24,0x0c,
+/* 34054 0x8506 "蔆" */
+0x08,0x08,0xff,0x08,0x20,0x13,0x10,0x87,0x41,0x52,0x14,0x21,0xe2,0x20,0x21,0x2e,
+0x20,0x20,0xfe,0x20,0x40,0xf8,0x40,0xfe,0x10,0x88,0xf4,0x10,0xa0,0x40,0xb0,0x0e,
+/* 34055 0x8507 "蔇" */
+0x08,0x08,0xff,0x08,0x00,0x7d,0x44,0x7d,0x45,0x45,0x7c,0x50,0x48,0x54,0x61,0x42,
+0x20,0x20,0xfe,0x20,0x00,0xfc,0x20,0x20,0x20,0xfe,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 34056 0x8508 "蔈" */
+0x08,0xff,0x08,0x00,0x7f,0x04,0x3f,0x24,0x3f,0x00,0x3f,0x00,0xff,0x11,0x25,0x02,
+0x20,0xfe,0x20,0x00,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x10,0x08,0x00,
+/* 34057 0x8509 "蔉" */
+0x08,0xff,0x08,0x01,0xff,0x10,0x20,0x5f,0x10,0x10,0x1f,0x04,0x08,0x38,0xcb,0x0c,
+0x20,0xfe,0x20,0x00,0xfe,0x10,0x08,0xf4,0x10,0x10,0xf0,0x88,0x50,0x20,0x18,0x06,
+/* 34058 0x850a "蔊" */
+0x04,0x04,0xff,0x04,0x11,0x11,0x15,0x55,0x59,0x50,0x91,0x10,0x2b,0x24,0x44,0x80,
+0x40,0x40,0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 34059 0x850b "蔋" */
+0x08,0x08,0xff,0x08,0x22,0x13,0x92,0x42,0x5f,0x10,0x22,0xea,0x32,0x22,0x2a,0x24,
+0x20,0x20,0xfe,0x20,0x00,0xbe,0x12,0x12,0xd2,0x14,0x14,0x88,0x48,0x14,0x24,0x42,
+/* 34060 0x850c "蔌" */
+0x08,0xff,0x08,0x00,0x08,0xff,0x08,0x7f,0x49,0x49,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x20,0xfe,0x20,0x00,0x20,0xa0,0x3e,0x42,0x94,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 34061 0x850d "蔍" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x28,0x2f,0x48,0x4b,0x8c,
+0x20,0x20,0xfe,0x20,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x48,0x70,0x44,0x44,0x3c,
+/* 34062 0x850e "蔎" */
+0x04,0x04,0xff,0x24,0x10,0xfc,0x00,0x79,0x02,0x79,0x00,0x78,0x48,0x48,0x78,0x4b,
+0x40,0x40,0xfe,0x40,0xf8,0x88,0x88,0x06,0x00,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 34063 0x850f "蔏" */
+0x08,0xff,0x0a,0x01,0x7f,0x08,0x04,0x7f,0x44,0x48,0x57,0x64,0x44,0x47,0x40,0x40,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0x40,0xfc,0x44,0x24,0xd4,0x4c,0x44,0xc4,0x14,0x08,
+/* 34064 0x8510 "蔐" */
+0x08,0xff,0x0a,0x01,0x7f,0x08,0x04,0x7f,0x41,0x5f,0x41,0x4f,0x48,0x4f,0x40,0x40,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0x40,0xfc,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x04,0x0c,
+/* 34065 0x8511 "蔑" */
+0x08,0xff,0x08,0x00,0x3f,0x24,0x24,0x3f,0x00,0x3f,0x20,0x30,0x28,0x24,0x40,0x83,
+0x20,0xfe,0x20,0x00,0xf8,0x48,0x48,0xf8,0x90,0xfc,0x80,0x48,0x50,0x24,0xd4,0x0c,
+/* 34066 0x8512 "蔒" */
+0x08,0xff,0x08,0x00,0x3f,0x02,0xff,0x04,0x3f,0x08,0x1f,0x28,0xcf,0x00,0x24,0x42,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x44,0x22,
+/* 34067 0x8513 "蔓" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0x7f,0x44,0x7f,0x00,0x3f,0x08,0x07,0x18,0xe0,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfc,0x44,0xfc,0x00,0xf0,0x20,0xc0,0x30,0x0e,
+/* 34068 0x8514 "蔔" */
+0x08,0xff,0x28,0x3f,0x40,0xbf,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x22,0x3f,0x22,0x3f,
+0x20,0xfe,0x20,0xfc,0x04,0xe4,0x04,0xc4,0x44,0xc4,0x04,0xe4,0x24,0xe4,0x24,0xec,
+/* 34069 0x8515 "蔕" */
+0x08,0xff,0x08,0x14,0x14,0x7f,0x24,0x47,0x80,0x7f,0x41,0x1f,0x11,0x11,0x11,0x01,
+0x20,0xfe,0x20,0x50,0x50,0xfc,0x52,0xce,0x00,0xfc,0x04,0xf0,0x10,0x50,0x20,0x00,
+/* 34070 0x8516 "蔖" */
+0x08,0xff,0x09,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x47,0x44,0x9f,
+0x20,0xfe,0x20,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xfc,
+/* 34071 0x8517 "蔗" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x23,0x20,0x4a,0x49,0x91,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x20,0x20,0xfc,0x20,0x20,0xe0,0x00,0x48,0x24,0x24,
+/* 34072 0x8518 "蔘" */
+0x04,0xff,0x04,0x08,0x1f,0x10,0x25,0x7e,0x04,0x19,0xe6,0x19,0x06,0x18,0x07,0x38,
+0x40,0xfe,0x40,0x20,0xf0,0x20,0x48,0xfc,0x40,0x30,0x4e,0x90,0x20,0xc0,0x00,0x00,
+/* 34073 0x8519 "蔙" */
+0x08,0x08,0xff,0x08,0x20,0x10,0xfe,0x21,0x20,0x3d,0x24,0x24,0x24,0x44,0x55,0x8a,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xfe,0x00,0x00,0xfe,0x22,0x20,0xbc,0xa0,0x60,0x3e,
+/* 34074 0x851a "蔚" */
+0x08,0x08,0xff,0x08,0x00,0x3f,0x21,0x3f,0x20,0x2e,0x20,0x3f,0x44,0x55,0xa4,0x0c,
+0x20,0x20,0xfe,0x20,0x00,0x08,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0xa8,0x10,
+/* 34075 0x851b "蔛" */
+0x08,0x08,0xff,0x08,0x10,0x1f,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x24,0x42,0x81,
+0x20,0x20,0xfe,0x20,0x04,0x24,0x14,0x84,0xa4,0x94,0x86,0xbc,0x84,0x84,0x84,0x04,
+/* 34076 0x851c "蔜" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x7f,0x08,0x3e,0x08,0xff,0x10,0x1e,0x22,0x4a,0x84,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34077 0x851d "蔝" */
+0x04,0x04,0xff,0x04,0x00,0x79,0x48,0x48,0x7b,0x48,0x78,0x48,0x49,0x7a,0x48,0x00,
+0x40,0x40,0xfe,0x40,0x20,0x24,0xa8,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 34078 0x851e "蔞" */
+0x08,0xff,0x08,0x01,0x3f,0x21,0xff,0x21,0x3f,0x11,0x1f,0x04,0xff,0x08,0x07,0x78,
+0x20,0xfe,0x20,0x00,0xf8,0x08,0xfe,0x08,0xf8,0x10,0xf0,0x00,0xfe,0x20,0xc0,0x38,
+/* 34079 0x851f "蔟" */
+0x08,0x08,0xff,0x08,0x20,0x10,0xfe,0x21,0x20,0x3c,0x25,0x24,0x25,0x44,0x54,0x89,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xfe,0x20,0x40,0xfc,0x20,0x20,0xfe,0x50,0x88,0x06,
+/* 34080 0x8520 "蔠" */
+0x08,0x08,0xff,0x08,0x10,0x10,0x24,0x7d,0x08,0x10,0x27,0x7c,0x00,0x54,0x54,0x80,
+0x20,0x20,0xfe,0x20,0x40,0xfc,0x88,0x50,0x20,0xd8,0x06,0x60,0x10,0xc0,0x30,0x08,
+/* 34081 0x8521 "蔡" */
+0x04,0xff,0x04,0x10,0x1e,0x22,0x54,0x28,0x17,0x20,0xdf,0x01,0x11,0x21,0x45,0x02,
+0x40,0xfe,0x40,0x80,0xf8,0x88,0x50,0x20,0xd8,0x06,0xf0,0x00,0x10,0x08,0x04,0x00,
+/* 34082 0x8522 "蔢" */
+0x04,0xff,0x04,0x20,0x13,0x82,0x4b,0x12,0x24,0xe4,0x29,0x24,0xff,0x08,0x07,0x78,
+0x40,0xfe,0x40,0x20,0xfc,0x24,0xf8,0x88,0x50,0x70,0x8c,0x00,0xfe,0x20,0xc0,0x38,
+/* 34083 0x8523 "蔣" */
+0x08,0x08,0xff,0x08,0x04,0x24,0x24,0x3d,0x04,0x04,0x7d,0x24,0x24,0x24,0x44,0x84,
+0x20,0x20,0xfe,0x20,0x40,0x7c,0xa8,0x50,0x28,0x48,0xfe,0x88,0x48,0x48,0x08,0x18,
+/* 34084 0x8524 "蔤" */
+0x08,0xff,0x0a,0x01,0x7f,0x42,0x89,0x28,0x49,0x0e,0x77,0x01,0x21,0x21,0x3f,0x00,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0x24,0x48,0x94,0x10,0xf0,0x00,0x08,0x08,0xf8,0x08,
+/* 34085 0x8525 "蔥" */
+0x08,0x08,0xff,0x09,0x02,0x3f,0x22,0x27,0x2a,0x21,0x26,0x3f,0x01,0x48,0x48,0x87,
+0x20,0x20,0xfe,0x20,0x00,0xf8,0x08,0xe8,0x48,0x88,0x48,0xf8,0x00,0x84,0x12,0xf2,
+/* 34086 0x8526 "蔦" */
+0x08,0xff,0x08,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x84,0x00,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x94,0x08,
+/* 34087 0x8527 "蔧" */
+0x08,0xff,0x08,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x3f,0x00,0x1f,0x00,0x3f,0x00,
+0x20,0xfe,0x20,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 34088 0x8528 "蔨" */
+0x08,0xff,0x08,0x7f,0x45,0x5f,0x42,0x7f,0x48,0x57,0x64,0x44,0x44,0x43,0x40,0x7f,
+0x20,0xfe,0x20,0xfc,0x44,0xf4,0x04,0xfc,0x24,0xd4,0x4c,0xc4,0x24,0xe4,0x04,0xfc,
+/* 34089 0x8529 "蔩" */
+0x08,0xff,0x0a,0x01,0x7f,0x40,0xbf,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x10,0x20,0x40,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0x04,
+/* 34090 0x852a "蔪" */
+0x04,0x04,0xff,0x04,0x08,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x09,
+0x40,0x40,0xfe,0x40,0x06,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 34091 0x852b "蔫" */
+0x08,0xff,0x08,0x7f,0x01,0x11,0x11,0xff,0x10,0x1f,0x20,0x3f,0x00,0x49,0x84,0x00,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 34092 0x852c "蔬" */
+0x08,0xff,0x08,0x00,0x7d,0x04,0x18,0x51,0x50,0x5c,0x50,0x50,0x5d,0x71,0xc2,0x04,
+0x20,0xfe,0x20,0x10,0xfe,0x20,0x48,0xfe,0x02,0xa8,0xa8,0xa8,0x2a,0x2a,0x2a,0x06,
+/* 34093 0x852d "蔭" */
+0x08,0xff,0x08,0x00,0x78,0x49,0x52,0x65,0x50,0x48,0x4b,0x68,0x57,0x40,0x41,0x43,
+0x20,0xfe,0x20,0x40,0xa0,0x10,0x48,0xf4,0x20,0x40,0xf8,0x00,0xfc,0x80,0x10,0xf8,
+/* 34094 0x852e "蔮" */
+0x04,0x04,0xff,0x04,0x7f,0x40,0x7f,0x40,0x5e,0x52,0x5e,0x40,0x46,0x59,0x7f,0x40,
+0x40,0x40,0xfe,0x40,0xfc,0xa4,0xfc,0x84,0x94,0x94,0x64,0x54,0xb4,0x14,0xfc,0x04,
+/* 34095 0x852f "蔯" */
+0x04,0x04,0xff,0x04,0x00,0x7b,0x48,0x51,0x61,0x51,0x49,0x49,0x68,0x50,0x41,0x46,
+0x40,0x40,0xfe,0x40,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x70,0xa8,0x24,0x22,
+/* 34096 0x8530 "蔰" */
+0x08,0xff,0x09,0x3f,0x20,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x28,0x4f,0x48,0x87,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x88,0xf8,0x02,0xfe,
+/* 34097 0x8531 "蔱" */
+0x08,0xff,0x08,0x22,0x14,0x08,0x14,0x2a,0x09,0x7e,0x08,0x2a,0x49,0x89,0x28,0x10,
+0x20,0xfe,0x20,0x00,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 34098 0x8532 "蔲" */
+0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x3e,0x00,0x7e,0x15,0x14,0x14,0x24,0x43,0x80,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0x44,0x40,0x7c,0x88,0x50,0x20,0x52,0x8a,0xfe,0x00,
+/* 34099 0x8533 "蔳" */
+0x04,0xff,0x04,0x23,0x10,0x13,0x80,0x47,0x50,0x13,0x22,0xe3,0x22,0x23,0x22,0x22,
+0x40,0xfe,0x40,0xf8,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 34100 0x8534 "蔴" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x24,0x24,0x3f,0x24,0x2e,0x2d,0x34,0x45,0x44,0x84,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x20,0x20,0x7c,0x20,0x70,0x68,0xa4,0x22,0x20,0x20,
+/* 34101 0x8535 "蔵" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x2f,0x2a,0x2f,0x28,0x2f,0x2a,0x4f,0x40,0x80,
+0x40,0x40,0xfe,0x48,0x24,0xfe,0x20,0xa4,0x24,0xa8,0xa8,0x90,0x12,0xaa,0x46,0x82,
+/* 34102 0x8536 "蔶" */
+0x08,0xff,0x09,0x7f,0x01,0x3f,0x01,0xff,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x00,0xfe,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 34103 0x8537 "蔷" */
+0x08,0xff,0x08,0x01,0x3f,0x11,0x09,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,
+0x20,0xfe,0x20,0x00,0xf8,0x10,0x20,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,
+/* 34104 0x8538 "蔸" */
+0x08,0x08,0xff,0x09,0x12,0x67,0x44,0x47,0x44,0x57,0x60,0x04,0x04,0x08,0x10,0x60,
+0x20,0x20,0xfe,0x20,0x00,0xdc,0x44,0xc4,0x44,0xdc,0x00,0x40,0x40,0x42,0x42,0x3e,
+/* 34105 0x8539 "蔹" */
+0x04,0x04,0xff,0x04,0x08,0x08,0x14,0x22,0x5d,0x80,0x11,0x09,0x4a,0x27,0xf8,0x40,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0xa8,0x44,0x82,
+/* 34106 0x853a "蔺" */
+0x08,0xff,0x08,0x20,0x17,0x05,0x44,0x4f,0x59,0x6f,0x49,0x4f,0x49,0x4f,0x48,0x40,
+0x20,0xfe,0x20,0x00,0xfc,0x04,0x84,0xf4,0x04,0xe4,0x04,0xe4,0x04,0xf4,0x14,0x08,
+/* 34107 0x853b "蔻" */
+0x08,0xff,0x0a,0x01,0x7f,0x40,0x80,0x3e,0x00,0x7e,0x14,0x14,0x14,0x24,0x24,0x43,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0x24,0x38,0x20,0xf8,0x08,0x50,0x24,0x54,0x84,0xfc,
+/* 34108 0x853c "蔼" */
+0x08,0xff,0x08,0x43,0x22,0x23,0x02,0xe3,0x21,0x23,0x24,0x22,0x2a,0x33,0x20,0x00,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0x04,0xf4,0x14,0x08,
+/* 34109 0x853d "蔽" */
+0x04,0x04,0xff,0x04,0x08,0x49,0x2a,0x7f,0x49,0x49,0x5d,0x6b,0x49,0x41,0x45,0x42,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34110 0x853e "蔾" */
+0x08,0xff,0x08,0x06,0x38,0x08,0x7e,0x1c,0x2a,0x49,0x01,0xff,0x05,0x09,0x31,0xc1,
+0x20,0xfe,0x20,0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0x00,0xfe,0x40,0x20,0x18,0x06,
+/* 34111 0x853f "蔿" */
+0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x2a,0x4a,0x80,
+0x20,0xfe,0x20,0xf8,0x00,0x10,0x20,0xe0,0x20,0xf0,0x10,0xfc,0x04,0xa4,0xa4,0x0c,
+/* 34112 0x8540 "蕀" */
+0x04,0xff,0x04,0x10,0x10,0xfe,0x10,0xfe,0x92,0x92,0x96,0x38,0x54,0x92,0x10,0x10,
+0x40,0xfe,0x40,0x10,0x10,0xfe,0x10,0xfe,0x92,0x92,0x96,0x38,0x54,0x92,0x10,0x10,
+/* 34113 0x8541 "蕁" */
+0x08,0xff,0x08,0x3f,0x00,0x1f,0x00,0x3f,0x00,0x3e,0x08,0x7f,0x00,0xff,0x08,0x04,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf0,0x00,0x7c,0x44,0x7c,0x20,0xfe,0x20,0x60,
+/* 34114 0x8542 "蕂" */
+0x04,0xff,0x04,0x00,0x3d,0x24,0x25,0x3c,0x27,0x24,0x3d,0x26,0x24,0x44,0x54,0x89,
+0x40,0xfe,0x40,0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x24,0xfa,0x48,0x48,0xa8,0x10,
+/* 34115 0x8543 "蕃" */
+0x08,0xff,0x08,0x00,0x3f,0x11,0x09,0xff,0x09,0x30,0xdf,0x11,0x1f,0x11,0x1f,0x10,
+0x20,0xfe,0x20,0xf8,0x00,0x10,0x20,0xfe,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x10,
+/* 34116 0x8544 "蕄" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x41,0x40,0x4a,0x4a,0x4a,0x51,0x40,0x40,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x84,0xa4,0x14,0x54,0xc4,0x14,0x08,
+/* 34117 0x8545 "蕅" */
+0x08,0x08,0xff,0x08,0x23,0x12,0x93,0x42,0x4b,0x08,0x17,0xe4,0x24,0x25,0x24,0x04,
+0x20,0x20,0xfe,0x20,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0xf4,0x14,0x0c,
+/* 34118 0x8546 "蕆" */
+0x04,0x04,0xff,0x04,0x00,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x4f,0x45,0x88,
+0x40,0x40,0xfe,0x48,0x24,0xfe,0x20,0xa4,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 34119 0x8547 "蕇" */
+0x08,0xff,0x08,0x3e,0x22,0x3e,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0xf8,0x88,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 34120 0x8548 "蕈" */
+0x08,0xff,0x08,0x7f,0x04,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,
+0x20,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 34121 0x8549 "蕉" */
+0x08,0x08,0xff,0x09,0x08,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x10,0x24,0x22,0x42,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x88,0x44,0x44,
+/* 34122 0x854a "蕊" */
+0x08,0x08,0xff,0x08,0x08,0x01,0x24,0x24,0x43,0x00,0x24,0x12,0xa0,0xa4,0x1c,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x88,0x24,0xe4,0x00,0x24,0x12,0xa0,0xa4,0x1c,0x00,
+/* 34123 0x854b "蕋" */
+0x08,0xff,0x08,0x01,0x11,0x11,0x11,0xff,0x08,0x08,0x4e,0x48,0x48,0x4e,0xf1,0x00,
+0x20,0xfe,0x20,0x00,0xf8,0x00,0x00,0xfe,0x10,0x10,0x9c,0x90,0x90,0x90,0xfe,0x00,
+/* 34124 0x854c "蕌" */
+0x04,0x04,0xff,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x40,0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 34125 0x854d "蕍" */
+0x04,0xff,0x04,0x20,0x11,0x12,0x85,0x40,0x57,0x14,0x27,0xe4,0x27,0x24,0x24,0x25,
+0x40,0xfe,0x40,0xa0,0x10,0x08,0xf6,0x00,0x84,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x88,
+/* 34126 0x854e "蕎" */
+0x08,0xff,0x08,0x00,0x1f,0x02,0xff,0x08,0x37,0xc4,0x3f,0x20,0x27,0x24,0x27,0x20,
+0x20,0xfe,0x20,0x70,0x80,0x00,0xfe,0x20,0xd8,0x46,0xf8,0x08,0xc8,0x48,0xc8,0x18,
+/* 34127 0x854f "蕏" */
+0x08,0x08,0xff,0x08,0x00,0x53,0x20,0x50,0x97,0x10,0x31,0x53,0x95,0x19,0x51,0x21,
+0x20,0x20,0xfe,0x20,0x44,0xf4,0x48,0x50,0xfe,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 34128 0x8550 "蕐" */
+0x04,0xff,0x04,0x7f,0x11,0x29,0x45,0x11,0x29,0x45,0x7f,0x01,0xff,0x01,0x01,0x01,
+0x40,0xfe,0x40,0xfc,0x10,0x28,0x44,0x10,0x28,0x44,0xfc,0x00,0xfe,0x00,0x00,0x00,
+/* 34129 0x8551 "蕑" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x47,0x44,0x47,0x44,0x47,0x44,0x48,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x44,0xc4,0x44,0xc4,0x54,0xc8,
+/* 34130 0x8552 "蕒" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 34131 0x8553 "蕓" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x00,0xff,0x10,0x3f,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x00,0xfe,0x10,0xf8,
+/* 34132 0x8554 "蕔" */
+0x04,0xff,0x04,0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0x7c,0x10,0xfe,0x10,0x10,0x10,
+0x40,0xfe,0x40,0x00,0xfc,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,
+/* 34133 0x8555 "蕕" */
+0x08,0x08,0xff,0x08,0x22,0x14,0x0b,0x14,0x25,0x4d,0x15,0x25,0x45,0x85,0x29,0x11,
+0x20,0x20,0xfe,0x20,0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x04,0xfc,0x04,0xfc,0x04,
+/* 34134 0x8556 "蕖" */
+0x08,0xff,0x08,0x23,0x12,0x43,0x2a,0x0b,0x72,0x13,0x11,0xff,0x05,0x19,0xe1,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 34135 0x8557 "蕗" */
+0x08,0x08,0xff,0x08,0x00,0x78,0x49,0x4a,0x78,0x11,0x12,0x5d,0x51,0x51,0x5d,0xe1,
+0x20,0x20,0xfe,0x20,0x80,0xf8,0x08,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0xf8,0x08,
+/* 34136 0x8558 "蕘" */
+0x08,0xff,0x08,0x01,0x3f,0x01,0xff,0x08,0x3e,0x08,0x7e,0x00,0x7f,0x04,0x18,0xe0,
+0x20,0xfe,0x20,0x00,0xf8,0x00,0xfe,0x20,0xf8,0x20,0xfc,0x00,0xfc,0x40,0x42,0x3e,
+/* 34137 0x8559 "蕙" */
+0x08,0xff,0x09,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x7f,0x02,0x49,0x48,0x87,
+0x20,0xfe,0x20,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x08,0xfc,0x04,0x08,0x24,0xe4,
+/* 34138 0x855a "蕚" */
+0x08,0xff,0x08,0x1f,0x10,0x7f,0x44,0x7c,0x00,0x3f,0x00,0xff,0x10,0x1f,0x00,0x00,
+0x20,0xfe,0x20,0xf0,0x10,0xfc,0x44,0x7c,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x08,0x70,
+/* 34139 0x855b "蕛" */
+0x08,0x08,0xff,0x08,0x0c,0x70,0x11,0x10,0xfd,0x31,0x39,0x54,0x50,0x91,0x12,0x10,
+0x20,0x20,0xfe,0x20,0x88,0x50,0xfc,0x24,0xfc,0x20,0xfe,0x62,0xaa,0x24,0x20,0x20,
+/* 34140 0x855c "蕜" */
+0x08,0x08,0xff,0x08,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x02,0x09,0x49,0x48,0x87,
+0x20,0x20,0xfe,0x20,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x00,0x08,0x24,0x24,0xe0,
+/* 34141 0x855d "蕝" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x25,0x7e,0x09,0x11,0x25,0x7d,0x01,0x55,0x55,0x80,
+0x40,0x40,0xfe,0x40,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x00,0x02,0x02,0xfe,
+/* 34142 0x855e "蕞" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0xff,0x22,0x3e,0x22,0x3e,0x22,0x2f,0xf2,0x42,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfe,0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 34143 0x855f "蕟" */
+0x08,0xff,0x08,0x3e,0x04,0x28,0x10,0x3e,0xc2,0x1e,0x11,0x20,0x3e,0x02,0x14,0x09,
+0x20,0xfe,0xa0,0x90,0x64,0x28,0x10,0xf8,0x96,0x90,0x0c,0xf0,0x90,0x60,0x90,0x08,
+/* 34144 0x8560 "蕠" */
+0x04,0xff,0x04,0x08,0x7f,0x11,0x32,0x0c,0x36,0xc8,0x1f,0x02,0x3f,0x01,0x15,0x22,
+0x40,0xfe,0x40,0x00,0x7c,0x44,0x44,0x44,0x7c,0x80,0x00,0x10,0xf8,0x08,0x20,0x10,
+/* 34145 0x8561 "蕡" */
+0x04,0xff,0x05,0x7f,0x09,0xff,0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,
+0x40,0xfe,0x40,0xfc,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,
+/* 34146 0x8562 "蕢" */
+0x08,0xff,0x09,0x1f,0x11,0x1f,0x01,0xff,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 34147 0x8563 "蕣" */
+0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x7f,0x40,0x90,0x3d,0x44,0xa9,0x11,0x20,0xc0,
+0x20,0xfe,0x20,0xfc,0x00,0x08,0x10,0xfe,0x02,0x24,0xf8,0x20,0x20,0xfc,0x20,0x20,
+/* 34148 0x8564 "蕤" */
+0x08,0xff,0x08,0x00,0xff,0x10,0x29,0x4e,0x96,0x25,0xcd,0x14,0x24,0xc4,0x14,0x08,
+0x20,0xfe,0x20,0x10,0x50,0x7c,0x90,0x10,0x7c,0x10,0x10,0xfe,0x40,0x30,0x0e,0x00,
+/* 34149 0x8565 "蕥" */
+0x08,0xff,0x08,0x00,0x7e,0x04,0x24,0x25,0x44,0x7e,0x0c,0x14,0x24,0x44,0x94,0x08,
+0x20,0xfe,0x20,0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 34150 0x8566 "蕦" */
+0x08,0xff,0x08,0x00,0x0b,0x10,0x21,0x49,0x11,0x21,0x45,0x09,0x11,0x20,0xc0,0x01,
+0x20,0xfe,0x20,0x00,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,
+/* 34151 0x8567 "蕧" */
+0x08,0xff,0x08,0x02,0x13,0x24,0x43,0x8a,0x13,0x32,0x53,0x91,0x13,0x15,0x10,0x17,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x10,0xe0,0x1c,
+/* 34152 0x8568 "蕨" */
+0x08,0xff,0x08,0x00,0x3f,0x28,0x25,0x2f,0x22,0x2a,0x2a,0x2f,0x22,0x44,0x44,0x88,
+0x20,0xfe,0x20,0x00,0xfe,0x90,0x10,0xbe,0x22,0xd4,0x90,0x90,0x28,0x28,0x44,0x82,
+/* 34153 0x8569 "蕩" */
+0x08,0x08,0xff,0x08,0x23,0x12,0x93,0x42,0x43,0x10,0x2f,0xe2,0x27,0x29,0x22,0x04,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x24,0x54,0x88,
+/* 34154 0x856a "蕪" */
+0x04,0x04,0xff,0x04,0x10,0x3f,0x4a,0x0a,0x7f,0x0a,0x0a,0x7f,0x00,0x24,0x22,0x42,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0xa0,0xa0,0xfc,0xa0,0xa0,0xfc,0x00,0x88,0x44,0x44,
+/* 34155 0x856b "蕫" */
+0x08,0xff,0x09,0x1f,0x04,0x7f,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,
+0x20,0xfe,0x20,0xf0,0x40,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 34156 0x856c "蕬" */
+0x04,0x04,0xff,0x04,0x10,0x10,0x24,0x7c,0x09,0x10,0x24,0x7d,0x00,0x54,0x55,0x80,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x40,0x88,0xf0,0x20,0x48,0xfc,0x20,0xa8,0x24,0x60,
+/* 34157 0x856d "蕭" */
+0x08,0xff,0x09,0x3f,0x01,0xff,0x01,0x3f,0x25,0x3d,0x21,0x3f,0x21,0x3d,0x25,0x45,
+0x20,0xfe,0x20,0xf8,0x08,0xfe,0x08,0xf8,0x48,0x78,0x08,0xf8,0x08,0x78,0x48,0x48,
+/* 34158 0x856e "蕮" */
+0x08,0xff,0x08,0x02,0x1c,0x10,0x1e,0x10,0x1f,0x08,0x1f,0x20,0x49,0x24,0x24,0x40,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0x24,0x94,0x94,0x08,
+/* 34159 0x856f "蕯" */
+0x08,0xff,0x08,0x01,0x79,0x4a,0x50,0x61,0x56,0x49,0x4a,0x6b,0x54,0x43,0x40,0x47,
+0x20,0xfe,0x20,0x00,0xf0,0x90,0x60,0x98,0x06,0xf0,0x40,0xf8,0x40,0xf8,0x40,0xfc,
+/* 34160 0x8570 "蕰" */
+0x04,0x04,0xff,0x04,0x23,0x12,0x93,0x42,0x4b,0x08,0x17,0xe5,0x25,0x25,0x2f,0x00,
+0x40,0x40,0xfe,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfe,0x00,
+/* 34161 0x8571 "蕱" */
+0x04,0x04,0xff,0x04,0x0c,0x71,0x10,0x10,0xfd,0x31,0x39,0x55,0x51,0x91,0x11,0x11,
+0x40,0x40,0xfe,0x40,0x20,0x24,0xa8,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 34162 0x8572 "蕲" */
+0x08,0xff,0x08,0x22,0x14,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x09,
+0x20,0xfe,0x20,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 34163 0x8573 "蕳" */
+0x08,0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x40,
+0x20,0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x0c,
+/* 34164 0x8574 "蕴" */
+0x04,0x04,0xff,0x04,0x21,0x21,0x45,0x89,0xf1,0x20,0x43,0xfa,0x02,0x1a,0xe7,0x40,
+0x40,0x40,0xfe,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 34165 0x8575 "蕵" */
+0x04,0xff,0x04,0x20,0x20,0x21,0x3a,0x4d,0x49,0x49,0xa9,0x11,0x11,0x21,0x41,0x81,
+0x40,0xfe,0x40,0x40,0xa0,0x58,0x26,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x28,0x50,0x88,
+/* 34166 0x8576 "蕶" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x06,0x19,0xef,0x00,0x06,0x01,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0xc0,0x30,0xee,0x40,0x80,0x00,
+/* 34167 0x8577 "蕷" */
+0x08,0xff,0x08,0x00,0x7d,0x04,0x28,0x10,0xfe,0x12,0x14,0x10,0x10,0x10,0x50,0x20,
+0x20,0xfe,0x20,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 34168 0x8578 "蕸" */
+0x08,0xff,0x08,0x00,0x47,0x24,0x27,0x04,0xe7,0x24,0x27,0x24,0x24,0x54,0x8f,0x00,
+0x20,0xfe,0x20,0x00,0xbc,0x84,0xbc,0x00,0xbc,0x04,0xa8,0x10,0x28,0x44,0xfe,0x00,
+/* 34169 0x8579 "蕹" */
+0x08,0xff,0x0a,0x01,0xff,0x10,0x20,0x45,0x7b,0x11,0x25,0x7d,0x09,0x11,0x21,0xc1,
+0x20,0xfe,0x20,0x00,0xfe,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34170 0x857a "蕺" */
+0x04,0xff,0x04,0x3e,0x22,0x3e,0x00,0xff,0x22,0x3e,0x22,0x3e,0x22,0x2f,0xf2,0x42,
+0x40,0xfe,0x40,0x28,0x24,0x24,0x20,0xfe,0x20,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 34171 0x857b "蕻" */
+0x08,0x08,0xff,0x08,0x00,0x3e,0x20,0x3c,0x20,0x3c,0x20,0xfe,0x20,0x44,0xfe,0x43,
+0x20,0x20,0xfe,0x20,0x48,0x48,0x48,0xfc,0x48,0x48,0x48,0xfe,0x00,0x48,0x84,0x02,
+/* 34172 0x857c "蕼" */
+0x04,0xff,0x04,0x00,0x3e,0x20,0x3d,0x20,0x3c,0x20,0xfe,0x10,0x25,0x7e,0x22,0x00,
+0x40,0xfe,0x40,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 34173 0x857d "蕽" */
+0x08,0xff,0x08,0x02,0x1f,0x12,0x1f,0x12,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x45,0x86,
+0x20,0xfe,0x20,0x40,0xf8,0x48,0xf8,0x48,0xfc,0x00,0xf8,0x00,0xfe,0x48,0x30,0x0e,
+/* 34174 0x857e "蕾" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x21,0x3f,0x21,0x3f,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 34175 0x857f "蕿" */
+0x04,0xff,0x04,0x10,0x13,0x15,0x54,0x5b,0x50,0x97,0x10,0x11,0x2a,0x24,0x44,0x81,
+0x40,0xfe,0x40,0x1e,0xe0,0x22,0x94,0xfc,0x40,0xfe,0x80,0xfc,0x48,0x30,0x48,0x86,
+/* 34176 0x8580 "薀" */
+0x08,0x08,0xff,0x08,0x23,0x12,0x92,0x42,0x4b,0x08,0x17,0xe4,0x24,0x24,0x2f,0x00,
+0x20,0x20,0xfe,0x20,0xf8,0x48,0x48,0xa8,0xf8,0x00,0xfc,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 34177 0x8581 "薁" */
+0x08,0xff,0x08,0x04,0x3f,0x29,0x25,0x2f,0x25,0x28,0x01,0xff,0x02,0x0c,0x30,0xc0,
+0x20,0xfe,0x20,0x00,0xf8,0x28,0x48,0xe8,0x48,0x28,0x00,0xfe,0x80,0x60,0x18,0x06,
+/* 34178 0x8582 "薂" */
+0x08,0xff,0x08,0x10,0x3e,0x22,0x3e,0x22,0x3e,0x08,0x7f,0x10,0x1e,0x22,0x2a,0x44,
+0x20,0xfe,0x20,0x00,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34179 0x8583 "薃" */
+0x04,0xff,0x04,0x20,0x17,0x10,0x81,0x41,0x51,0x10,0x27,0xe4,0x25,0x25,0x25,0x24,
+0x40,0xfe,0x40,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x02,0xfa,0x0a,0xfa,0x06,
+/* 34180 0x8584 "薄" */
+0x08,0xff,0x08,0x00,0x27,0x10,0x13,0x82,0x43,0x4a,0x0b,0x12,0xf0,0x27,0x22,0x21,
+0x20,0xfe,0x20,0x48,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x48,0x10,0xfc,0x10,0x30,
+/* 34181 0x8585 "薅" */
+0x08,0xff,0x08,0x23,0x22,0xfa,0x4a,0x4b,0x4a,0x92,0x52,0x22,0x53,0x4a,0x84,0x08,
+0x20,0xfe,0x20,0xfe,0x00,0xfc,0x00,0xfe,0xa4,0x98,0xc6,0x08,0xfe,0x88,0x48,0x18,
+/* 34182 0x8586 "薆" */
+0x08,0xff,0x08,0x00,0x7f,0x22,0x11,0x7f,0x42,0x29,0x47,0x08,0x1f,0x28,0x07,0xf8,
+0x20,0xfe,0x20,0xf8,0x00,0x10,0x20,0xfc,0x04,0x28,0xe4,0x00,0xf0,0x20,0xc0,0x3e,
+/* 34183 0x8587 "薇" */
+0x04,0x04,0xff,0x04,0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x29,0x29,0x29,0x30,
+0x40,0x40,0xfe,0x40,0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0x28,0x10,0xa8,0x44,0x82,
+/* 34184 0x8588 "薈" */
+0x08,0xff,0x09,0x02,0x0c,0x37,0xc0,0x3f,0x29,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x20,0xfe,0x20,0x80,0x60,0xd8,0x06,0xf8,0x28,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 34185 0x8589 "薉" */
+0x08,0xff,0x09,0x11,0x11,0xff,0x00,0x3f,0x20,0x2f,0x22,0x2a,0x2a,0x51,0x46,0x98,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x24,0xfe,0x20,0xa4,0x24,0x18,0x90,0x2a,0x46,0x82,
+/* 34186 0x858a "薊" */
+0x04,0x04,0xff,0x04,0x10,0x1f,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x00,0x2a,0x45,0x00,
+0x40,0x40,0xfe,0x40,0x04,0x04,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0x04,0x84,0x54,0x08,
+/* 34187 0x858b "薋" */
+0x08,0xff,0x49,0x21,0x0a,0xf0,0x23,0x3f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfe,0x20,0xfc,0x44,0xb0,0x0e,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 34188 0x858c "薌" */
+0x08,0x08,0xff,0x08,0x21,0x27,0x54,0x97,0xe4,0x24,0x57,0x95,0xf4,0x25,0x46,0x84,
+0x20,0x20,0xfe,0x20,0x00,0xde,0x52,0xd4,0x58,0x54,0xd2,0x12,0x9a,0x54,0x10,0x10,
+/* 34189 0x858d "薍" */
+0x04,0xff,0x04,0x7f,0x2a,0x7f,0x12,0x0c,0x7f,0x4a,0x5e,0x40,0x5e,0x4a,0x44,0x4b,
+0x40,0xfe,0x40,0x10,0x10,0x10,0x10,0x10,0x90,0x90,0x90,0x90,0x92,0x92,0x92,0x8e,
+/* 34190 0x858e "薎" */
+0x08,0xff,0x08,0x7f,0x44,0x7f,0x00,0x7f,0x49,0x91,0x31,0x5f,0x90,0x10,0x11,0x16,
+0x20,0xfe,0x20,0xfc,0x44,0xfc,0x00,0xfe,0x22,0x14,0xfc,0x10,0xa0,0x44,0xa4,0x1c,
+/* 34191 0x858f "薏" */
+0x08,0xff,0x08,0x01,0x3f,0x08,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x49,0x48,0x87,
+0x20,0xfe,0x20,0x00,0xf8,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x04,0x92,0xf2,
+/* 34192 0x8590 "薐" */
+0x04,0x04,0xff,0x04,0x0c,0x71,0x10,0x13,0xfc,0x31,0x3a,0x54,0x51,0x90,0x10,0x17,
+0x40,0x40,0xfe,0x40,0x20,0xfc,0x20,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 34193 0x8591 "薑" */
+0x08,0xff,0x08,0x7f,0x00,0x3f,0x21,0x3f,0x21,0xff,0x00,0x3f,0x21,0x3f,0x21,0xff,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfe,
+/* 34194 0x8592 "薒" */
+0x04,0xff,0x04,0x08,0x0f,0x28,0x7f,0xa1,0x16,0x38,0xd1,0x09,0x7f,0x05,0x19,0x61,
+0x40,0xfe,0x40,0x00,0x78,0x08,0x28,0x10,0x28,0xc4,0x10,0x20,0xfc,0x40,0x30,0x0c,
+/* 34195 0x8593 "薓" */
+0x08,0xff,0x08,0x23,0x10,0x13,0x80,0x47,0x54,0x13,0x22,0xe0,0x27,0x21,0x20,0x2f,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xfc,0x44,0xf8,0x48,0x40,0xf8,0x10,0xe0,0x1e,
+/* 34196 0x8594 "薔" */
+0x08,0xff,0x09,0x7f,0x11,0x29,0x45,0xff,0x00,0x3f,0x20,0x27,0x24,0x27,0x20,0x3f,
+0x20,0xfe,0x20,0xfc,0x10,0x28,0x44,0xfe,0x00,0xf8,0x08,0xc8,0x48,0xc8,0x08,0xf8,
+/* 34197 0x8595 "薕" */
+0x08,0xff,0x08,0x01,0x3f,0x22,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x46,0x4a,0xb2,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0xfc,0x40,0xf8,0x48,0xfc,0x48,0xf8,0x60,0x50,0x4c,
+/* 34198 0x8596 "薖" */
+0x08,0x08,0xff,0x08,0x21,0x11,0x11,0x01,0x73,0x12,0x12,0x12,0x12,0x12,0x2a,0x47,
+0x20,0x20,0xfe,0x20,0xf8,0x08,0xe8,0x28,0xfc,0x04,0xf4,0x94,0xf4,0x14,0x08,0xfe,
+/* 34199 0x8597 "薗" */
+0x08,0xff,0x08,0x7f,0x41,0x4f,0x41,0x5f,0x40,0x4f,0x48,0x4f,0x46,0x4a,0x52,0x7f,
+0x20,0xfe,0x20,0xfc,0x04,0xe4,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x94,0x64,0x14,0xfc,
+/* 34200 0x8598 "薘" */
+0x08,0xff,0x08,0x00,0x23,0x10,0x17,0x01,0xf7,0x10,0x13,0x10,0x17,0x10,0x28,0x47,
+0x20,0xfe,0x20,0x40,0xf8,0x40,0xfc,0x10,0xfc,0x40,0xf8,0x40,0xfc,0x40,0x40,0xfe,
+/* 34201 0x8599 "薙" */
+0x04,0x04,0xff,0x04,0x20,0x20,0x7d,0x91,0x13,0x11,0xfd,0x11,0x29,0x25,0x41,0x81,
+0x40,0x40,0xfe,0x40,0xa0,0x90,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34202 0x859a "薚" */
+0x08,0xff,0x08,0x00,0x7e,0x10,0x10,0x3c,0x24,0x47,0xa4,0x19,0x0a,0x10,0x21,0x40,
+0x20,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x52,0x92,0x2a,0x44,
+/* 34203 0x859b "薛" */
+0x08,0x08,0xff,0x08,0x10,0x7c,0x45,0x44,0x7c,0x43,0x40,0x7c,0x45,0x44,0x7c,0x44,
+0x20,0x20,0xfe,0x20,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,
+/* 34204 0x859c "薜" */
+0x08,0xff,0x08,0x00,0x3e,0x22,0x22,0x3e,0x21,0x20,0x3e,0x52,0x52,0x9e,0x12,0x00,
+0x20,0xfe,0x20,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,
+/* 34205 0x859d "薝" */
+0x08,0xff,0x08,0x1f,0x20,0x7f,0xa4,0x2b,0x20,0x27,0x20,0x27,0x20,0x47,0x44,0x87,
+0x20,0xfe,0x20,0xf0,0x20,0xfe,0x88,0xf4,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 34206 0x859e "薞" */
+0x08,0xff,0x08,0x00,0x7e,0x11,0x12,0x3d,0x25,0x45,0xa5,0x19,0x09,0x11,0x21,0x41,
+0x20,0xfe,0x20,0x40,0xa0,0x98,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x28,0x90,0x08,
+/* 34207 0x859f "薟" */
+0x08,0x08,0xff,0x09,0x02,0x04,0x18,0x67,0x00,0x3e,0x22,0x22,0x3e,0x08,0x14,0x22,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x30,0xcc,0x00,0xf8,0x88,0x88,0xf8,0x20,0x50,0x88,
+/* 34208 0x85a0 "薠" */
+0x08,0x08,0xff,0x08,0x13,0x10,0x15,0x55,0x59,0x51,0x91,0x11,0x29,0x24,0x45,0x82,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,0x04,
+/* 34209 0x85a1 "薡" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0x5f,0x50,0x5f,0x40,0x7c,0x04,0xfc,0x24,0x44,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf4,0x14,0xf4,0x04,0x7c,0x40,0x7c,0x44,0x44,
+/* 34210 0x85a2 "薢" */
+0x04,0x04,0xff,0x04,0x20,0x3c,0x44,0xbe,0x2a,0x3e,0x2a,0x3e,0x2a,0x2a,0x42,0x86,
+0x40,0x40,0xfe,0x40,0xfc,0x24,0x44,0x8c,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,0x10,
+/* 34211 0x85a3 "薣" */
+0x04,0xff,0x04,0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x24,0x0e,0xf0,0x41,
+0x40,0xfe,0x40,0x10,0x10,0xfe,0x10,0x10,0xfe,0x42,0x44,0x28,0x10,0x28,0x44,0x82,
+/* 34212 0x85a4 "薤" */
+0x08,0xff,0x08,0x00,0x7e,0x11,0x10,0x3c,0x25,0x64,0x94,0x09,0x08,0x10,0x23,0x40,
+0x20,0xfe,0x20,0x50,0x50,0xdc,0x50,0x50,0xdc,0x50,0x50,0xdc,0x50,0x50,0xfe,0x00,
+/* 34213 0x85a5 "薥" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x08,0x1f,0x22,0xdf,0x12,0x1f,0x02,0x3f,0x10,0x00,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xfc,0x04,0xc4,0x44,0xc4,0x24,0xe4,0x28,0x10,
+/* 34214 0x85a6 "薦" */
+0x08,0xff,0x09,0x3f,0x24,0x3f,0x24,0x3f,0x24,0x27,0x28,0x2f,0x20,0x4a,0x51,0x80,
+0x20,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x00,0xfc,0x04,0xa4,0x54,0x08,
+/* 34215 0x85a7 "薧" */
+0x08,0xff,0x09,0x7f,0x00,0x1f,0x10,0x7f,0x40,0xbf,0x08,0x1f,0x62,0x14,0x18,0xe0,
+0x20,0xfe,0x20,0xfc,0x00,0xf0,0x10,0xfe,0x02,0xf4,0x40,0x48,0x50,0x62,0x42,0x3e,
+/* 34216 0x85a8 "薨" */
+0x08,0xff,0x08,0x7f,0x44,0x7f,0x00,0x7f,0x40,0xbf,0x08,0x1f,0x62,0x14,0x18,0xe0,
+0x20,0xfe,0x20,0xfc,0x44,0xfc,0x00,0xfe,0x02,0xf4,0x40,0x48,0x50,0x62,0x42,0x3e,
+/* 34217 0x85a9 "薩" */
+0x04,0xff,0x04,0x00,0x79,0x48,0x50,0x63,0x52,0x4a,0x4a,0x6b,0x52,0x44,0x44,0x49,
+0x40,0xfe,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xa0,0xfc,0x20,0xfc,0x20,0x20,0xfe,
+/* 34218 0x85aa "薪" */
+0x08,0xff,0x08,0x10,0x08,0x7f,0x22,0x14,0xff,0x08,0x7f,0x08,0x2a,0x49,0xa8,0x11,
+0x20,0xfe,0x20,0x00,0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 34219 0x85ab "薫" */
+0x08,0xff,0x08,0x3f,0x01,0xff,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,0x24,0x42,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x88,0x44,
+/* 34220 0x85ac "薬" */
+0x08,0xff,0x09,0x02,0x47,0x24,0x17,0x24,0x47,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x20,0xfe,0x20,0x00,0xc4,0x48,0xd0,0x48,0xc4,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 34221 0x85ad "薭" */
+0x04,0xff,0x04,0x00,0x0c,0x71,0x11,0x11,0xfd,0x31,0x38,0x54,0x51,0x90,0x10,0x10,
+0x40,0xfe,0x40,0x20,0x40,0xfc,0x24,0xfc,0x44,0xfc,0x50,0x90,0xfe,0x10,0x10,0x10,
+/* 34222 0x85ae "薮" */
+0x04,0xff,0x04,0x00,0x49,0x2a,0xff,0x2a,0x49,0x10,0xfe,0x22,0x64,0x18,0x24,0xc2,
+0x40,0xfe,0x40,0x00,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34223 0x85af "薯" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x02,0x1f,0x02,0xff,0x03,0x0f,0x38,0xcf,0x08,0x0f,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 34224 0x85b0 "薰" */
+0x08,0xff,0x08,0x3f,0x01,0xff,0x01,0x3f,0x29,0x3f,0x01,0x3f,0x01,0xff,0x24,0x42,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x00,0xf8,0x28,0xf8,0x00,0xf8,0x00,0xfe,0x48,0x24,
+/* 34225 0x85b1 "薱" */
+0x08,0x08,0xff,0x08,0x14,0x55,0x36,0x14,0x7f,0x14,0x7f,0x08,0x3e,0x08,0x0f,0x78,
+0x20,0x20,0xfe,0x20,0x08,0x08,0x08,0x7e,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 34226 0x85b2 "薲" */
+0x08,0xff,0x09,0x7f,0x40,0x9f,0x09,0x11,0x06,0x1f,0x68,0x0f,0x08,0x0f,0x04,0x08,
+0x20,0xfe,0x20,0xfe,0x02,0xf4,0x20,0xc0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 34227 0x85b3 "薳" */
+0x08,0xff,0x08,0x00,0x23,0x10,0x17,0x00,0x73,0x12,0x13,0x10,0x11,0x12,0x2c,0x47,
+0x20,0xfe,0x20,0x40,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0xc4,0xa8,0x90,0x88,0xfe,
+/* 34228 0x85b4 "薴" */
+0x08,0xff,0x09,0x7f,0x42,0xa9,0x47,0x00,0x3f,0x24,0xff,0x00,0x7f,0x01,0x05,0x02,
+0x20,0xfe,0x20,0xfc,0x04,0x28,0xe4,0x00,0xf8,0x48,0xfe,0x00,0xfc,0x00,0x00,0x00,
+/* 34229 0x85b5 "薵" */
+0x08,0xff,0x09,0x7f,0x01,0x3f,0x00,0xff,0x00,0x3f,0x01,0xff,0x00,0x7d,0x44,0x7c,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x00,0xfe,0x02,0xf0,0x00,0xfe,0x10,0xfc,0x90,0x30,
+/* 34230 0x85b6 "薶" */
+0x04,0xff,0x04,0x08,0x31,0xcb,0x2d,0x31,0xc9,0x15,0x25,0xcc,0x15,0x24,0xd4,0x0b,
+0x40,0xfe,0x40,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfc,0x20,0x20,0xfe,
+/* 34231 0x85b7 "薷" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7f,0x02,0x3f,0x24,0x24,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x00,0xf8,0x48,0x58,
+/* 34232 0x85b8 "薸" */
+0x08,0xff,0x08,0x20,0x17,0x10,0x87,0x44,0x57,0x10,0x27,0xe0,0x2f,0x20,0x22,0x24,
+0x20,0xfe,0x20,0x00,0xfc,0xa0,0xfc,0xa4,0xfc,0x00,0xfc,0x00,0xfe,0x40,0x48,0xc4,
+/* 34233 0x85b9 "薹" */
+0x08,0xff,0x09,0xff,0x01,0x3f,0x00,0x1f,0x10,0x7f,0x48,0x9f,0x01,0x3f,0x01,0xff,
+0x20,0xfe,0x20,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xfe,0x22,0xf4,0x00,0xf8,0x00,0xfe,
+/* 34234 0x85ba "薺" */
+0x08,0xff,0x08,0x01,0xff,0x02,0x7d,0x25,0x4d,0x90,0x1f,0x10,0x1f,0x10,0x20,0x40,
+0x20,0xfe,0x20,0x00,0xfe,0x88,0x70,0x48,0x66,0x10,0xf0,0x10,0xf0,0x10,0x10,0x10,
+/* 34235 0x85bb "薻" */
+0x08,0xff,0x08,0x22,0x14,0x12,0x83,0x42,0x53,0x12,0x23,0xe0,0x2f,0x21,0x22,0x24,
+0x20,0xfe,0x20,0x48,0x90,0x48,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfe,0x50,0x48,0x44,
+/* 34236 0x85bc "薼" */
+0x08,0xff,0x09,0x3f,0x24,0x3f,0x24,0x3f,0x28,0x2f,0x28,0x2f,0x20,0x4f,0x40,0x9f,
+0x20,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xf8,0x40,0x78,0x44,0x3c,0x80,0xf8,0x80,0xfc,
+/* 34237 0x85bd "薽" */
+0x08,0xff,0x08,0x00,0x7f,0x14,0x7f,0x55,0x55,0x7f,0x08,0x08,0x7f,0x08,0x0f,0xf0,
+0x20,0xfe,0x20,0x00,0x7c,0x20,0x20,0x38,0x28,0x48,0x68,0x58,0x4a,0x4a,0x6a,0x46,
+/* 34238 0x85be "薾" */
+0x08,0xff,0x08,0x7f,0x11,0x21,0x7f,0xb5,0x29,0x35,0x21,0x35,0x29,0x35,0x20,0x20,
+0x20,0xfe,0x20,0xfc,0x10,0x08,0xfc,0x5a,0x28,0x58,0x08,0x58,0x28,0x58,0x08,0x18,
+/* 34239 0x85bf "薿" */
+0x08,0x08,0xff,0x08,0x24,0x3a,0x22,0x1e,0x20,0x3e,0x48,0x08,0x7f,0x14,0x22,0x41,
+0x20,0x20,0xfe,0x20,0x7c,0x04,0x28,0x10,0xfe,0x12,0x50,0x5e,0x50,0xb0,0x9e,0x00,
+/* 34240 0x85c0 "藀" */
+0x04,0xff,0x04,0x08,0x2a,0x4d,0x14,0x22,0x7f,0x41,0x91,0x11,0x22,0x04,0x18,0xe0,
+0x40,0xfe,0x40,0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x14,0x20,0x80,0x40,0x30,0x0e,
+/* 34241 0x85c1 "藁" */
+0x08,0xff,0x08,0x01,0x7f,0x08,0x0f,0x00,0x7f,0x48,0x4f,0x01,0x7f,0x05,0x19,0xe1,
+0x20,0xfe,0x20,0x00,0xfc,0x20,0xe0,0x00,0xfc,0x24,0xec,0x00,0xfc,0x40,0x30,0x0e,
+/* 34242 0x85c2 "藂" */
+0x08,0xff,0x08,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x03,0x7f,0x11,0x63,0x0d,0xf1,
+0x20,0xfe,0x20,0x00,0x7c,0x04,0x28,0x10,0xa8,0x44,0xf8,0x04,0x88,0x70,0x18,0x06,
+/* 34243 0x85c3 "藃" */
+0x04,0xff,0x04,0x08,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x43,
+0x40,0xfe,0x40,0x20,0x20,0x20,0x3e,0x42,0x84,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 34244 0x85c4 "藄" */
+0x04,0xff,0x04,0x08,0x7f,0x08,0x0f,0x08,0xff,0x14,0x2f,0x41,0x1f,0x01,0x09,0x13,
+0x40,0xfe,0x40,0x20,0xfc,0x20,0xe0,0x20,0xfe,0x50,0x88,0x24,0xf0,0x10,0x20,0x10,
+/* 34245 0x85c5 "藅" */
+0x08,0xff,0x08,0x7f,0x44,0x7f,0x08,0xff,0x00,0x7f,0x00,0x7f,0x00,0x7f,0x41,0x7f,
+0x20,0xfe,0x20,0xfc,0x44,0xfc,0x00,0x84,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 34246 0x85c6 "藆" */
+0x08,0xff,0x0a,0x01,0x7f,0x44,0xbf,0x04,0xff,0x08,0x31,0xcf,0x01,0x7f,0x01,0x03,
+0x20,0xfe,0x20,0x00,0xfe,0x42,0xfc,0x40,0xfe,0x20,0xd8,0x06,0x00,0xfc,0x00,0x00,
+/* 34247 0x85c7 "藇" */
+0x04,0x04,0xff,0x04,0x0a,0x33,0x22,0x3a,0x23,0x20,0x3a,0x22,0xff,0x08,0x10,0x20,
+0x40,0x40,0xfe,0x40,0x00,0xb8,0x08,0x38,0x88,0x88,0xb8,0x88,0xfe,0x20,0x10,0x08,
+/* 34248 0x85c8 "藈" */
+0x04,0xff,0x04,0x00,0xf7,0x90,0x92,0xf1,0x92,0x95,0xf8,0x93,0x90,0xf0,0x91,0x06,
+0x40,0xfe,0x40,0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x42,0xf8,0x40,0xa0,0x10,0x08,
+/* 34249 0x85c9 "藉" */
+0x08,0x08,0xff,0x08,0x10,0x7c,0x10,0x7c,0x11,0xfe,0x10,0x38,0x54,0x94,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x48,0xfc,0x48,0x48,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 34250 0x85ca "藊" */
+0x04,0xff,0x04,0x00,0x0d,0x71,0x11,0x11,0xfd,0x31,0x39,0x56,0x52,0x94,0x10,0x10,
+0x40,0xfe,0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xa2,0x86,
+/* 34251 0x85cb "藋" */
+0x08,0xff,0x08,0x3e,0x12,0x0a,0x12,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x20,0xfe,0x20,0xf8,0x48,0x28,0x48,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 34252 0x85cc "藌" */
+0x08,0xff,0x0a,0x01,0x7f,0x42,0x2b,0x4c,0x37,0xc1,0x1f,0x11,0x1f,0x01,0x7f,0x20,
+0x20,0xfe,0x20,0x00,0xfc,0x44,0x90,0x28,0xe0,0x00,0xf0,0x10,0xf0,0x08,0xfc,0x04,
+/* 34253 0x85cd "藍" */
+0x08,0xff,0x08,0x00,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x3f,0x24,0x24,0xff,
+0x20,0xfe,0x20,0x00,0x20,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xf8,0x48,0x48,0xfe,
+/* 34254 0x85ce "藎" */
+0x08,0xff,0x09,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7f,0x24,0x42,0x3f,0x24,0x24,0xff,
+0x20,0xfe,0x20,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x88,0x44,0xf8,0x48,0x48,0xfe,
+/* 34255 0x85cf "藏" */
+0x04,0xff,0x04,0x00,0x1f,0x50,0x57,0x75,0x17,0xf4,0x57,0x55,0x95,0x27,0x20,0x40,
+0x40,0xfe,0x48,0x24,0xfe,0x20,0xa0,0x24,0xa4,0xa8,0xa8,0x10,0x12,0xaa,0x46,0x82,
+/* 34256 0x85d0 "藐" */
+0x08,0xff,0x08,0x08,0x30,0xca,0x2c,0x30,0xc8,0x14,0x24,0xcc,0x14,0x24,0xd4,0x09,
+0x20,0xfe,0x20,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x48,0x4a,0x8a,0x06,
+/* 34257 0x85d1 "藑" */
+0x04,0xff,0x14,0x1f,0x20,0x7f,0xa3,0x24,0x1f,0x11,0x1f,0x08,0x1f,0x28,0x07,0xf8,
+0x40,0xfe,0x40,0xe0,0x20,0xf8,0x08,0x88,0xf0,0x10,0xf0,0x00,0xf0,0x20,0xc0,0x3e,
+/* 34258 0x85d2 "藒" */
+0x08,0x08,0xff,0x08,0x0d,0x71,0x11,0x11,0xfd,0x30,0x39,0x56,0x55,0x91,0x11,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x06,
+/* 34259 0x85d3 "藓" */
+0x08,0x08,0xff,0x08,0x20,0x3e,0x44,0xff,0x49,0x7f,0x49,0x7f,0x00,0x0f,0xf0,0x40,
+0x20,0x20,0xfe,0x20,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,
+/* 34260 0x85d4 "藔" */
+0x08,0xff,0x0a,0x7f,0x41,0xbf,0x04,0x28,0x1f,0x28,0xcf,0x08,0x0f,0x01,0x15,0x22,
+0x20,0xfe,0x20,0xfc,0x04,0xf8,0x40,0x28,0xf0,0x28,0xe6,0x20,0xe0,0x00,0x10,0x08,
+/* 34261 0x85d5 "藕" */
+0x08,0xff,0x08,0x10,0x11,0x7d,0x11,0x7d,0x11,0xfc,0x13,0x3a,0x56,0x92,0x12,0x12,
+0x20,0xfe,0x20,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 34262 0x85d6 "藖" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfe,0x20,0x7c,0x44,0x28,0x10,0x28,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 34263 0x85d7 "藗" */
+0x04,0xff,0x04,0x42,0x2f,0x22,0x0f,0x0a,0xea,0x2f,0x22,0x27,0x2a,0x32,0x52,0x8f,
+0x40,0xfe,0x40,0x10,0x90,0x10,0x9e,0xa2,0x88,0x88,0x08,0x14,0x94,0x22,0x42,0xfe,
+/* 34264 0x85d8 "藘" */
+0x08,0xff,0x09,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x47,0x4a,0x93,
+0x20,0xfe,0x20,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x90,0xf0,0x90,0xf4,0x4a,0xfa,
+/* 34265 0x85d9 "藙" */
+0x04,0xff,0x04,0x10,0x08,0x7f,0x22,0x14,0x7f,0x10,0x69,0x16,0x6d,0x14,0x64,0x18,
+0x40,0xfe,0x40,0x00,0x78,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x90,0x28,0xc6,
+/* 34266 0x85da "藚" */
+0x08,0xff,0x09,0x7f,0x01,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfe,0x20,0xfc,0x00,0xf8,0x48,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 34267 0x85db "藛" */
+0x08,0xff,0x0a,0x01,0x7f,0x42,0x9c,0x10,0x1e,0x10,0x1f,0x08,0x1f,0x20,0x0a,0x12,
+0x20,0xfe,0x20,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x04,0xa4,0xac,
+/* 34268 0x85dc "藜" */
+0x08,0xff,0x08,0x06,0x38,0x08,0x7e,0x1c,0x2a,0x49,0x02,0x1d,0xe9,0x05,0x09,0x13,
+0x20,0xfe,0x20,0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0xc0,0x30,0x2e,0x40,0x20,0x10,
+/* 34269 0x85dd "藝" */
+0x08,0xff,0x08,0x3e,0x08,0x7f,0x2a,0x5d,0x08,0x3e,0x00,0x3f,0x00,0xff,0x10,0x3f,
+0x20,0xfe,0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xf8,0x00,0xfe,0x10,0xf8,
+/* 34270 0x85de "藞" */
+0x08,0xff,0x08,0x00,0x7f,0x08,0x1f,0x28,0xcf,0x00,0x7e,0x20,0x7e,0xa3,0x3e,0x22,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x40,0xfc,0x44,0x7c,0x44,
+/* 34271 0x85df "藟" */
+0x04,0x04,0xff,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x82,
+0x40,0x40,0xfe,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x82,
+/* 34272 0x85e0 "藠" */
+0x08,0xff,0x09,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x20,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 34273 0x85e1 "藡" */
+0x08,0xff,0x08,0x40,0x27,0x21,0x00,0x07,0xe4,0x27,0x24,0x25,0x25,0x25,0x54,0x8f,
+0x20,0xfe,0xa0,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xfc,0x44,0xf4,0x14,0xf4,0x0c,0xfe,
+/* 34274 0x85e2 "藢" */
+0x04,0x04,0xff,0x04,0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x22,0x2f,0x22,0x2f,
+0x40,0x40,0xfe,0x40,0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0xa8,0x10,0xa8,0x44,0x82,
+/* 34275 0x85e3 "藣" */
+0x08,0xff,0x08,0x7f,0x44,0x7f,0x24,0x7e,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,
+0x20,0xfe,0x20,0xfc,0x44,0xfc,0x98,0xe0,0x84,0x7c,0x00,0x98,0xe0,0x84,0x84,0x7c,
+/* 34276 0x85e4 "藤" */
+0x04,0xff,0x04,0x00,0x3d,0x24,0x25,0x3c,0x27,0x24,0x3d,0x26,0x24,0x44,0x55,0x8a,
+0x40,0xfe,0x40,0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x62,
+/* 34277 0x85e5 "藥" */
+0x04,0x04,0xff,0x04,0x21,0x4b,0x72,0x23,0x4a,0x7b,0x01,0xff,0x05,0x19,0xe1,0x01,
+0x40,0x40,0xfe,0x40,0x10,0xa4,0xb8,0x90,0xa4,0xbc,0x00,0xfe,0x40,0x30,0x0e,0x00,
+/* 34278 0x85e6 "藦" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x2f,0x20,0x27,0x20,0x5f,0x40,0x81,
+0x20,0xfe,0xa0,0xfe,0x10,0x7c,0x38,0x54,0x12,0xf8,0x80,0xf8,0x80,0xfe,0x80,0x80,
+/* 34279 0x85e7 "藧" */
+0x04,0x04,0xff,0x04,0x10,0x13,0x25,0x7c,0x09,0x10,0x27,0x7c,0x00,0x55,0x56,0x80,
+0x40,0x40,0xfe,0x40,0x3c,0xc0,0x44,0xa8,0xfc,0x40,0xfe,0x80,0xf8,0x48,0x30,0xce,
+/* 34280 0x85e8 "藨" */
+0x08,0x08,0xff,0x09,0x3f,0x24,0x3f,0x24,0x3f,0x28,0x2f,0x28,0x2f,0x40,0x4a,0x91,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xf8,0x40,0x78,0x44,0x3c,0x00,0x48,0x24,
+/* 34281 0x85e9 "藩" */
+0x08,0xff,0x08,0x20,0x17,0x12,0x81,0x47,0x52,0x14,0x2b,0xe2,0x23,0x22,0x23,0x22,
+0x20,0xfe,0x20,0x38,0xc0,0x48,0x50,0xfc,0x48,0x04,0xfa,0x48,0xf8,0x48,0xf8,0x08,
+/* 34282 0x85ea "藪" */
+0x04,0xff,0x04,0x08,0x7f,0x49,0xff,0x49,0x7f,0x2a,0x3e,0x10,0xff,0x22,0x1c,0x62,
+0x40,0xfe,0x40,0x00,0x20,0x20,0xbe,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34283 0x85eb "藫" */
+0x08,0xff,0x08,0x00,0x27,0x10,0x17,0x84,0x47,0x52,0x13,0x22,0xe3,0x20,0x27,0x20,
+0x20,0xfe,0x20,0x00,0xfc,0xa0,0xfc,0xa4,0xfc,0x08,0xf8,0x08,0xf8,0x40,0xfc,0x40,
+/* 34284 0x85ec "藬" */
+0x08,0xff,0x08,0x7d,0x45,0x49,0x48,0x53,0x49,0x45,0x45,0x55,0x49,0x41,0x40,0x41,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 34285 0x85ed "藭" */
+0x08,0xff,0x09,0x7f,0x50,0xa8,0x3e,0x22,0x3e,0x22,0x3e,0x22,0xfe,0x12,0x22,0xce,
+0x20,0xfe,0x20,0xfe,0x22,0x14,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 34286 0x85ee "藮" */
+0x04,0xff,0x04,0x10,0x10,0x11,0xfd,0x13,0x31,0x39,0x55,0x51,0x90,0x12,0x12,0x14,
+0x40,0xfe,0x40,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,
+/* 34287 0x85ef "藯" */
+0x08,0xff,0x08,0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2c,0x01,0x48,0x87,
+0x20,0xfe,0x20,0x08,0x08,0x7e,0x08,0x48,0x28,0xa8,0x08,0x28,0x90,0x00,0x94,0xf2,
+/* 34288 0x85f0 "藰" */
+0x08,0xff,0x08,0x77,0x42,0x62,0x54,0x69,0x14,0x22,0xdd,0x08,0x7f,0x4a,0x2f,0xf0,
+0x20,0xfe,0x20,0x84,0x84,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x24,0x24,0x04,0x94,0x08,
+/* 34289 0x85f1 "藱" */
+0x08,0x08,0xff,0x09,0x00,0x3f,0x21,0xaf,0x68,0x2f,0x68,0xaf,0x21,0x42,0x4c,0xb0,
+0x20,0x20,0xfe,0x20,0x80,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x50,0xf8,0x8a,0x7e,
+/* 34290 0x85f2 "藲" */
+0x04,0x04,0xff,0x04,0x10,0x13,0x12,0xfe,0x12,0x32,0x3a,0x56,0x52,0x92,0x12,0x13,
+0x40,0x40,0xfe,0x40,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xee,0xaa,0xee,0x00,0xfe,
+/* 34291 0x85f3 "藳" */
+0x04,0xff,0x05,0x7f,0x08,0x0f,0x00,0x7f,0x48,0x4f,0x00,0x3f,0x01,0xff,0x09,0x71,
+0x40,0xfe,0x40,0xfc,0x20,0xe0,0x00,0xfc,0x24,0xec,0x00,0xf8,0x00,0xfe,0x20,0x1c,
+/* 34292 0x85f4 "藴" */
+0x04,0x04,0xff,0x14,0x10,0x24,0x7c,0x08,0x10,0x24,0x7d,0x01,0x55,0x55,0x83,0x00,
+0x40,0x40,0xfe,0x40,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 34293 0x85f5 "藵" */
+0x08,0xff,0x08,0x0b,0x12,0x33,0x50,0x97,0x11,0x12,0x01,0xff,0x06,0x1c,0xe5,0x06,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x40,0xfe,0x50,0x48,0x00,0xfe,0x80,0x48,0x30,0x0e,
+/* 34294 0x85f6 "藶" */
+0x08,0xff,0x08,0x3f,0x21,0x2e,0x22,0x2f,0x27,0x2a,0x32,0x20,0x24,0x44,0x44,0x9f,
+0x20,0xfe,0x20,0xfe,0x04,0x38,0x10,0xbc,0x18,0xb4,0x52,0x40,0x7c,0x40,0x40,0xfe,
+/* 34295 0x85f7 "藷" */
+0x04,0x04,0xff,0x04,0x20,0x10,0xfd,0x00,0x7b,0x00,0x79,0x06,0x78,0x48,0x78,0x48,
+0x40,0x40,0xfe,0x40,0x20,0x22,0xfc,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 34296 0x85f8 "藸" */
+0x04,0x04,0xff,0x04,0x00,0xfc,0x20,0x60,0x95,0x34,0x58,0x94,0x35,0x56,0x90,0x20,
+0x40,0x40,0xfe,0x40,0x22,0xfa,0x24,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 34297 0x85f9 "藹" */
+0x04,0x04,0xff,0x04,0x20,0x11,0xfd,0x01,0x79,0x01,0x78,0x01,0x7a,0x4d,0x79,0x48,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0xfa,0x06,
+/* 34298 0x85fa "藺" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x4f,0x59,0x4f,0x49,0x4f,0x49,0x4f,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x84,0xe4,0x04,0xc4,0x04,0xc4,0x04,0xec,
+/* 34299 0x85fb "藻" */
+0x08,0xff,0x08,0x23,0x12,0x13,0x80,0x47,0x54,0x17,0x20,0xef,0x21,0x22,0x2c,0x20,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x00,0xbc,0xa4,0xbc,0x40,0xfe,0x50,0x48,0x46,0x40,
+/* 34300 0x85fc "藼" */
+0x08,0xff,0x09,0x7f,0x41,0x3f,0x01,0x1f,0x01,0x7f,0x24,0x3f,0x01,0x48,0x48,0x87,
+0x20,0xfe,0x20,0xfc,0x04,0xf8,0x00,0xf0,0x00,0xfc,0x48,0xf8,0x00,0x84,0x92,0xf2,
+/* 34301 0x85fd "藽" */
+0x04,0x04,0xff,0x04,0x08,0x7f,0x22,0x14,0xff,0x08,0x7f,0x08,0x2a,0x49,0xa9,0x10,
+0x40,0x40,0xfe,0x40,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x2a,0x4a,0x86,
+/* 34302 0x85fe "藾" */
+0x04,0x04,0xff,0x14,0x10,0xfe,0x11,0x7e,0x54,0x54,0x7c,0x10,0x38,0x54,0x90,0x10,
+0x40,0x40,0xfe,0x40,0x80,0xf8,0x08,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 34303 0x85ff "藿" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,
+/* 34304 0x8600 "蘀" */
+0x08,0x08,0xff,0x08,0x11,0x11,0xfd,0x10,0x15,0x18,0x33,0xd0,0x11,0x10,0x53,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0xfc,0x20,0xfe,0x20,
+/* 34305 0x8601 "蘁" */
+0x08,0xff,0x08,0x7f,0x01,0x3d,0x25,0x3d,0x01,0x7f,0x01,0x3d,0x25,0x3d,0x01,0xff,
+0x20,0xfe,0x20,0xfc,0x00,0x78,0x48,0x78,0x00,0xfc,0x00,0x78,0x48,0x78,0x00,0xfe,
+/* 34306 0x8602 "蘂" */
+0x08,0xff,0x09,0x24,0x24,0x43,0x24,0x12,0xa0,0xa4,0x1c,0x01,0xff,0x05,0x19,0xe1,
+0x20,0xfe,0x20,0x88,0x24,0xe4,0x28,0x14,0xa0,0xa4,0x1c,0x00,0xfe,0x40,0x30,0x0e,
+/* 34307 0x8603 "蘃" */
+0x08,0xff,0x09,0x11,0x11,0xff,0x08,0x2e,0x28,0x2e,0xf0,0x01,0x7f,0x05,0x19,0xe1,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x10,0x5c,0x50,0x50,0xfe,0x00,0xfc,0x40,0x30,0x0e,
+/* 34308 0x8604 "蘄" */
+0x08,0xff,0x08,0x77,0x55,0x77,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x09,
+0x20,0xfe,0x20,0x0c,0x70,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 34309 0x8605 "蘅" */
+0x08,0xff,0x08,0x22,0x47,0x88,0x17,0x25,0x67,0xa5,0x27,0x21,0x2f,0x21,0x22,0x24,
+0x20,0xfe,0x20,0x00,0xdc,0x80,0xc0,0x7e,0xc8,0x48,0xc8,0x08,0xe8,0x08,0xa8,0x50,
+/* 34310 0x8606 "蘆" */
+0x08,0xff,0x09,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x4f,0x49,0x9f,
+0x20,0xfe,0x20,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x90,0xf0,0x90,0xf8,0x48,0xfc,
+/* 34311 0x8607 "蘇" */
+0x04,0x04,0xff,0x04,0x20,0x3e,0x44,0xff,0x49,0x7f,0x49,0x7f,0x00,0x55,0x8a,0x00,
+0x40,0x40,0xfe,0x40,0x0c,0x70,0x10,0x10,0xfe,0x10,0x38,0x34,0x54,0x52,0x90,0x10,
+/* 34312 0x8608 "蘈" */
+0x08,0xff,0x08,0x06,0x38,0x08,0x7f,0x1c,0x2a,0x49,0x1c,0x14,0x15,0x26,0x24,0x40,
+0x20,0xfe,0x20,0x00,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x82,
+/* 34313 0x8609 "蘉" */
+0x08,0xff,0x08,0x3f,0x24,0xff,0x90,0x13,0x20,0x2f,0x68,0xa7,0x22,0x21,0x20,0x27,
+0x20,0xfe,0x20,0xf8,0x48,0xfe,0x12,0xf0,0x10,0xfc,0x04,0xf0,0x10,0x20,0xc0,0x38,
+/* 34314 0x860a "蘊" */
+0x04,0xff,0x04,0x10,0x10,0x24,0x7c,0x08,0x10,0x24,0x7d,0x01,0x55,0x55,0x83,0x00,
+0x40,0xfe,0x40,0x00,0xf8,0xa8,0xa8,0xd8,0xf8,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 34315 0x860b "蘋" */
+0x04,0x04,0xff,0x04,0x09,0x28,0x2e,0x28,0xfe,0x08,0x28,0x2a,0x44,0x08,0x30,0xc0,
+0x40,0x40,0xfe,0x40,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 34316 0x860c "蘌" */
+0x08,0xff,0x0a,0x27,0x49,0x97,0x21,0x65,0xa5,0x2f,0x00,0x3f,0x00,0xff,0x11,0x23,
+0x20,0xfe,0x20,0xde,0x12,0xd2,0x12,0xda,0x14,0xd0,0x00,0xf8,0x00,0xfe,0x10,0x08,
+/* 34317 0x860d "蘍" */
+0x08,0xff,0x08,0x3f,0x04,0x7f,0x04,0x7f,0x55,0x7f,0x04,0x7f,0x04,0xff,0x2a,0x45,
+0x20,0xfe,0xa0,0x10,0x10,0xd0,0x3e,0xd2,0x52,0xd2,0x12,0xd2,0x12,0xe2,0xaa,0x44,
+/* 34318 0x860e "蘎" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x42,0x86,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0xa8,0xa8,0xf8,0x84,0x84,0x7c,
+/* 34319 0x860f "蘏" */
+0x08,0xff,0x08,0x40,0x49,0x74,0x44,0x3c,0x00,0x7c,0x00,0xfe,0x10,0x54,0xd2,0x20,
+0x20,0xfe,0x20,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 34320 0x8610 "蘐" */
+0x04,0x04,0xff,0x04,0x20,0x13,0xfd,0x00,0x79,0x00,0x7b,0x00,0x78,0x49,0x7a,0x48,
+0x40,0x40,0xfe,0x40,0x3c,0xc0,0x44,0xa8,0xfc,0x40,0xfe,0x80,0xf8,0x48,0x30,0xce,
+/* 34321 0x8611 "蘑" */
+0x08,0xff,0x08,0x3f,0x22,0x2f,0x23,0x26,0x2a,0x20,0x3f,0x44,0x4f,0x94,0x27,0x04,
+0x20,0xfe,0xa0,0xfe,0x10,0xbc,0x18,0xb4,0x52,0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,
+/* 34322 0x8612 "蘒" */
+0x08,0xff,0x08,0x1c,0xf1,0x12,0x10,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x10,0x10,
+0x20,0xfe,0xa0,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x1e,
+/* 34323 0x8613 "蘓" */
+0x08,0x08,0xff,0x08,0x0c,0x70,0x11,0x12,0xfd,0x31,0x39,0x55,0x51,0x90,0x11,0x12,
+0x20,0x20,0xfe,0x20,0x80,0xf8,0x08,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x54,0x2a,
+/* 34324 0x8614 "蘔" */
+0x04,0xff,0x04,0x48,0x75,0x44,0x3c,0x00,0x0c,0x70,0x10,0xfe,0x10,0x38,0x54,0x90,
+0x40,0xfe,0x40,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 34325 0x8615 "蘕" */
+0x04,0xff,0x04,0x20,0x24,0x4a,0xf8,0x10,0x26,0x4a,0xfa,0x02,0xaa,0xaa,0x05,0x08,
+0x40,0xfe,0x40,0x20,0x7c,0xa4,0x18,0xe6,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x10,0xfe,
+/* 34326 0x8616 "蘖" */
+0x04,0xff,0x04,0x20,0x7d,0x44,0x7c,0x41,0x7c,0x45,0x7c,0x01,0x7f,0x05,0x19,0xe1,
+0x40,0xfe,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x00,0xfc,0x40,0x30,0x0e,
+/* 34327 0x8617 "蘗" */
+0x08,0xff,0x08,0x00,0x7c,0x45,0x7c,0x43,0x7c,0xa5,0x3c,0x01,0x7f,0x05,0x19,0xe1,
+0x20,0xfe,0x20,0x40,0x20,0xfc,0x50,0xfe,0x20,0xfc,0x20,0x00,0xfc,0x40,0x30,0x0e,
+/* 34328 0x8618 "蘘" */
+0x08,0xff,0x08,0x01,0x7f,0x00,0x3e,0x22,0x3e,0x04,0x3f,0x04,0xff,0x04,0x1c,0x67,
+0x20,0xfe,0x20,0x00,0xfc,0x00,0xf8,0x88,0xf8,0x40,0xf8,0x40,0xfe,0x90,0x60,0x1c,
+/* 34329 0x8619 "蘙" */
+0x08,0xff,0x08,0x7f,0x48,0x5e,0x64,0x5f,0x4a,0x7f,0x00,0x7e,0x22,0x1a,0x62,0x06,
+0x20,0xfe,0x20,0x78,0x48,0x86,0x78,0x48,0x30,0x4c,0x00,0xfc,0x44,0x34,0xc4,0x0c,
+/* 34330 0x861a "蘚" */
+0x08,0x08,0xff,0x08,0x20,0x3e,0x44,0xff,0x49,0x7f,0x49,0x7f,0x00,0x55,0x4a,0x8a,
+0x20,0x20,0xfe,0x20,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x10,0x90,0x90,
+/* 34331 0x861b "蘛" */
+0x08,0xff,0x08,0x24,0x24,0xff,0x24,0x3c,0x24,0x3c,0x24,0xff,0x54,0x62,0x40,0x7e,
+0x20,0xfe,0x20,0x10,0xfe,0x20,0x44,0xfe,0x02,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x4c,
+/* 34332 0x861c "蘜" */
+0x04,0x04,0xff,0x04,0x29,0x7d,0x29,0x3a,0x11,0x7c,0x55,0x7c,0x10,0xfd,0x10,0x10,
+0x40,0x40,0xfe,0x40,0x00,0xfc,0x04,0x44,0x54,0xe4,0xf4,0x44,0xe4,0x54,0x54,0x08,
+/* 34333 0x861d "蘝" */
+0x04,0x04,0xff,0x04,0x08,0x14,0x22,0x5d,0x80,0x77,0x55,0x77,0x22,0x22,0x55,0x88,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x42,0x84,0x10,0x10,0x10,0x28,0x28,0x44,0x82,
+/* 34334 0x861e "蘞" */
+0x04,0x04,0xff,0x04,0x08,0x14,0x22,0x5d,0x80,0x77,0x55,0x77,0x22,0x22,0x55,0x88,
+0x40,0x40,0xfe,0x40,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34335 0x861f "蘟" */
+0x04,0xff,0x04,0x01,0x7c,0x45,0x48,0x51,0x48,0x45,0x44,0x55,0x48,0x42,0x42,0x44,
+0x40,0xfe,0x40,0xfc,0xa8,0xfc,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 34336 0x8620 "蘠" */
+0x08,0xff,0x08,0x10,0x57,0x52,0x55,0x7f,0x10,0x17,0xf4,0x55,0x55,0x55,0x94,0x17,
+0x20,0xfe,0x20,0x40,0xfc,0x48,0x54,0xfe,0x00,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,
+/* 34337 0x8621 "蘡" */
+0x08,0xff,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x22,0xff,0x08,0x07,0x78,
+0x20,0xfe,0x20,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0xfe,0x20,0xc0,0x38,
+/* 34338 0x8622 "蘢" */
+0x04,0xff,0x04,0x10,0x08,0x7e,0x24,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x46,
+0x40,0xfe,0x40,0x00,0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,
+/* 34339 0x8623 "蘣" */
+0x04,0x04,0xff,0x04,0x22,0x7f,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x22,0x41,
+0x40,0x40,0xfe,0x40,0x20,0x10,0x7e,0x90,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 34340 0x8624 "蘤" */
+0x04,0xff,0x04,0x10,0x27,0x7a,0x49,0x4b,0x4a,0x7b,0x4a,0x4b,0x7a,0x4c,0x04,0x09,
+0x40,0xfe,0x40,0x3c,0xc0,0x44,0x28,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x06,
+/* 34341 0x8625 "蘥" */
+0x08,0xff,0x09,0x02,0x0c,0x37,0xc0,0x3b,0x2a,0x3b,0x00,0x3f,0x24,0x3f,0x24,0x24,
+0x20,0xfe,0x20,0x80,0x60,0xd8,0x06,0xb8,0xa8,0xb8,0x00,0xf8,0x88,0xf8,0x88,0xb8,
+/* 34342 0x8626 "蘦" */
+0x04,0x04,0xff,0x04,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3b,0x2a,0x3b,0x2a,
+0x40,0x40,0xfe,0x40,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xb8,0xa8,0xb8,0xa8,
+/* 34343 0x8627 "蘧" */
+0x08,0xff,0x08,0x00,0x40,0x2f,0x28,0x0b,0xe8,0x2b,0x29,0x2a,0x31,0x22,0x51,0x8f,
+0x20,0xfe,0xa0,0xf8,0x80,0xfc,0x84,0xf0,0x88,0xf8,0x40,0xa8,0x70,0xa8,0x60,0xfe,
+/* 34344 0x8628 "蘨" */
+0x08,0xff,0x08,0x07,0xf8,0x51,0x2a,0x20,0x3e,0x48,0xff,0x08,0x49,0x4f,0x71,0x00,
+0x20,0xfe,0x20,0x0c,0x70,0x10,0x24,0x78,0x10,0x24,0x7e,0x12,0x54,0x52,0x92,0x30,
+/* 34345 0x8629 "蘩" */
+0x08,0xff,0x28,0x3f,0x40,0xbe,0x2a,0xff,0x4a,0x7f,0x08,0x1f,0x02,0x3f,0x11,0x23,
+0x20,0xfe,0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0x28,0x46,0x80,0x10,0xf8,0x10,0x08,
+/* 34346 0x862a "蘪" */
+0x08,0xff,0x09,0x3f,0x24,0x3f,0x24,0x3f,0x28,0x2f,0x28,0x2f,0x44,0x5f,0x82,0x1c,
+0x20,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xf8,0x40,0x78,0x44,0x3c,0x90,0xfc,0xa0,0x9c,
+/* 34347 0x862b "蘫" */
+0x08,0x08,0xff,0x08,0x27,0x15,0x17,0x84,0x47,0x55,0x17,0x20,0xe7,0x25,0x25,0x2f,
+0x20,0x20,0xfe,0x20,0xd0,0x10,0x9e,0xa0,0xa8,0x44,0xc4,0x00,0xf8,0x28,0x28,0xfe,
+/* 34348 0x862c "蘬" */
+0x04,0xff,0x04,0x10,0x7d,0x44,0x7c,0x40,0x7d,0x44,0x7d,0x11,0x5c,0x50,0x5e,0xf0,
+0x40,0xfe,0x40,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x22,0xfc,0xa4,0xac,0x20,
+/* 34349 0x862d "蘭" */
+0x08,0xff,0x08,0x7c,0x44,0x7c,0x44,0x7c,0x41,0x5f,0x41,0x5f,0x55,0x5f,0x45,0x59,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xf4,0x54,0xf4,0x44,0x2c,
+/* 34350 0x862e "蘮" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x00,0x3f,0x22,0x2a,0x25,0x28,0x22,0x4a,0x45,0x88,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0x00,0xfe,0x04,0x94,0x14,0x94,0x54,0x84,0x14,0x88,
+/* 34351 0x862f "蘯" */
+0x08,0xff,0x08,0x21,0x11,0x41,0x21,0x0b,0x09,0x73,0x14,0x11,0x12,0x3f,0x24,0xff,
+0x20,0xfe,0x20,0xf8,0x08,0xf8,0x08,0xfe,0x00,0xfc,0xa4,0x54,0x88,0xf8,0x48,0xfe,
+/* 34352 0x8630 "蘰" */
+0x04,0x04,0xff,0x04,0x21,0x21,0x49,0xf9,0x13,0x22,0x4b,0xf8,0x01,0xa8,0xa8,0x03,
+0x40,0x40,0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfe,0x52,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 34353 0x8631 "蘱" */
+0x04,0xff,0x04,0x10,0x93,0x54,0xfe,0x38,0x54,0x92,0x00,0x14,0xfe,0x28,0x44,0x80,
+0x40,0xfe,0x40,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,
+/* 34354 0x8632 "蘲" */
+0x04,0xff,0x04,0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0x3e,0x01,0x3f,0x01,0xff,
+0x40,0xfe,0x40,0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xf8,0x00,0xfe,
+/* 34355 0x8633 "蘳" */
+0x08,0x08,0xff,0x08,0x22,0x7f,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x22,0x41,
+0x20,0x20,0xfe,0x20,0x10,0x7c,0x10,0x90,0x7e,0x00,0x10,0x10,0x7c,0x10,0x7e,0x00,
+/* 34356 0x8634 "蘴" */
+0x08,0xff,0x08,0x1d,0x49,0x5d,0x49,0x5d,0x49,0x7f,0x00,0x7f,0x10,0x1f,0x08,0xff,
+0x20,0xfe,0x20,0x70,0x24,0x74,0x24,0x74,0x24,0xfc,0x00,0xfc,0x10,0xf0,0x20,0xfe,
+/* 34357 0x8635 "蘵" */
+0x08,0xff,0x08,0x00,0xfd,0x48,0x49,0x7b,0x48,0x49,0x79,0x49,0x4f,0xf9,0x09,0x08,
+0x20,0xfe,0x20,0x94,0xd2,0x12,0x50,0xfe,0x10,0xd4,0x54,0xd4,0x48,0xca,0x56,0x22,
+/* 34358 0x8636 "蘶" */
+0x04,0xff,0x04,0x0c,0x70,0x11,0xfd,0x39,0x55,0x93,0xfc,0x24,0x68,0x10,0x29,0xc6,
+0x40,0xfe,0x40,0x20,0x40,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x5a,0x5e,0x90,0x12,0x0e,
+/* 34359 0x8637 "蘷" */
+0x04,0xff,0x04,0xff,0x11,0x13,0x5a,0x53,0x52,0x5b,0xe4,0x0f,0x54,0x83,0x1c,0xe0,
+0x40,0xfe,0x40,0xfe,0x00,0xde,0x52,0xde,0x50,0xd2,0x0e,0xe0,0x44,0x82,0x70,0x0e,
+/* 34360 0x8638 "蘸" */
+0x08,0xff,0x08,0x00,0xfe,0x10,0x11,0x7c,0x54,0x54,0x6c,0x44,0x7c,0x45,0x7d,0x46,
+0x20,0xfe,0x20,0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0x54,0x2a,0x2a,
+/* 34361 0x8639 "蘹" */
+0x08,0xff,0x08,0x10,0x17,0x10,0x5b,0x56,0x53,0x92,0x11,0x12,0x10,0x11,0x16,0x10,
+0x20,0xfe,0xa0,0x40,0xfc,0x00,0xf8,0xa8,0xf8,0x44,0x58,0x44,0xa8,0x90,0xa8,0xc6,
+/* 34362 0x863a "蘺" */
+0x04,0xff,0x04,0x10,0x08,0x7f,0x14,0x49,0x55,0x7f,0x08,0x7f,0x51,0x55,0x5d,0x43,
+0x40,0xfe,0x40,0x00,0x28,0x24,0x7e,0x48,0xc8,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x40,
+/* 34363 0x863b "蘻" */
+0x08,0xff,0x08,0x7f,0x2a,0x3e,0x2a,0xff,0x49,0x7f,0x08,0x1f,0x02,0x3f,0x11,0x23,
+0x20,0xfe,0x20,0x3c,0x24,0x42,0x3c,0xa4,0x18,0x66,0x40,0x80,0x10,0xf8,0x10,0x08,
+/* 34364 0x863c "蘼" */
+0x08,0xff,0x08,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x21,0x3f,0x21,0x2f,0x41,0x5f,0x81,
+0x20,0xfe,0xa0,0xfe,0x10,0x7c,0x38,0x54,0x12,0x20,0x3e,0x20,0x3c,0x20,0x3e,0x20,
+/* 34365 0x863d "蘽" */
+0x08,0xff,0x08,0x1f,0x11,0x1f,0x11,0x3f,0x2a,0x3e,0x2a,0x3e,0x01,0x7f,0x09,0x71,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x20,0x1c,
+/* 34366 0x863e "蘾" */
+0x08,0xff,0x08,0x20,0x27,0x20,0x23,0xfa,0x23,0x22,0x21,0x22,0x38,0xe1,0x46,0x00,
+0x20,0xfe,0xa0,0x40,0xfc,0x00,0xf8,0xa8,0xf8,0x44,0x18,0x44,0xa8,0x90,0xa8,0xc6,
+/* 34367 0x863f "蘿" */
+0x08,0xff,0x08,0x7f,0x44,0x7f,0x10,0x20,0x45,0x79,0x13,0x25,0x7d,0x01,0x55,0x81,
+0x20,0xfe,0x20,0xfc,0x44,0xfc,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 34368 0x8640 "虀" */
+0x08,0xff,0x09,0xff,0x02,0x7d,0x25,0x4d,0x82,0x7e,0x02,0x3e,0x02,0x7e,0x02,0xff,
+0x20,0xfe,0x20,0xfe,0x88,0x70,0x48,0x66,0x80,0xfc,0x80,0xf8,0x80,0xfc,0x80,0xfe,
+/* 34369 0x8641 "虁" */
+0x04,0xff,0x04,0xff,0x11,0x13,0x5a,0x53,0x52,0x5b,0xe6,0x0f,0x54,0x83,0x1c,0xe0,
+0x40,0xfe,0x40,0xfe,0x00,0xde,0x52,0xde,0x50,0xd2,0x4e,0xe0,0x44,0x82,0x70,0x0e,
+/* 34370 0x8642 "虂" */
+0x08,0xff,0x08,0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3e,0x23,0x3e,0x09,0x2e,0x28,0x7e,
+0x20,0xfe,0x20,0xf8,0x00,0xfe,0x02,0x74,0x40,0xfc,0x48,0x30,0xce,0x78,0x48,0x78,
+/* 34371 0x8643 "虃" */
+0x08,0xff,0x08,0x22,0x12,0x15,0x8f,0x42,0x5e,0x12,0x2e,0xe2,0x2e,0x22,0x22,0x2f,
+0x20,0xfe,0x20,0x94,0x92,0x50,0xfe,0x90,0xf4,0x94,0xf4,0x94,0xe8,0x8a,0xf6,0x22,
+/* 34372 0x8644 "虄" */
+0x08,0xff,0x08,0x21,0x22,0x20,0xfb,0xa8,0xa8,0xfb,0x22,0x2a,0x3b,0xca,0x04,0x09,
+0x20,0xfe,0xa0,0xf8,0x88,0x70,0xae,0xf8,0x50,0xfe,0xa0,0xfc,0x20,0x78,0x20,0xfe,
+/* 34373 0x8645 "虅" */
+0x08,0xff,0x08,0x01,0x3c,0x25,0x24,0x3f,0x24,0x25,0x3e,0x24,0x24,0x44,0x54,0x8a,
+0x20,0xfe,0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0xfc,0xa2,0xf8,0xa0,0xfc,0x04,0xac,
+/* 34374 0x8646 "虆" */
+0x08,0xff,0x08,0x1f,0x11,0x1f,0x11,0x7f,0x4a,0x7e,0x4a,0x7e,0x20,0x7f,0x11,0x23,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfc,0xa4,0xfc,0xa4,0xfc,0x08,0xfc,0x10,0x08,
+/* 34375 0x8647 "虇" */
+0x08,0xff,0x08,0x7b,0x08,0x0b,0x7a,0x43,0x40,0x79,0x09,0x0b,0x0d,0x09,0x51,0x21,
+0x20,0xfe,0xa8,0xfe,0x88,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,
+/* 34376 0x8648 "虈" */
+0x08,0xff,0x08,0x00,0x7b,0x48,0x49,0x4b,0x7a,0x03,0x7a,0x4b,0x4a,0x4b,0x79,0x4a,
+0x20,0xfe,0x20,0x00,0xde,0x92,0x12,0xd2,0x5e,0xc0,0x5e,0xd2,0x52,0xd2,0x9e,0x52,
+/* 34377 0x8649 "虉" */
+0x08,0xff,0x08,0x7f,0x00,0x3e,0x22,0x3e,0x00,0x7f,0x55,0x49,0x7f,0x49,0x49,0x43,
+0x20,0xfe,0x20,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0x06,
+/* 34378 0x864a "虊" */
+0x08,0xff,0x08,0x21,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x01,0x7f,0x05,0x19,0xe1,
+0x20,0xfe,0x20,0x08,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0x00,0xfc,0x40,0x30,0x0e,
+/* 34379 0x864b "虋" */
+0x08,0xff,0x08,0x77,0x44,0x77,0x44,0xff,0x92,0x1c,0x10,0x1f,0x08,0x1f,0x64,0x08,
+0x20,0xfe,0x20,0xdc,0x44,0xdc,0x44,0xfe,0x92,0x70,0x10,0xf0,0x20,0xf0,0x2c,0x60,
+/* 34380 0x864c "虌" */
+0x08,0xff,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x5f,0x12,0x3e,0x22,0x3e,0x22,0x3d,
+0x20,0xfe,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0xf6,0x90,0xf8,0x88,0xf8,0x8a,0xfe,
+/* 34381 0x864d "虍" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x21,0x21,0x21,0x21,0x2f,0x21,0x41,0x40,0x80,
+0x00,0x00,0xf8,0x00,0x00,0xfc,0x04,0x08,0x00,0x18,0xe0,0x00,0x04,0x04,0xfc,0x00,
+/* 34382 0x864e "虎" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x20,0x23,0x22,0x22,0x44,0x48,0x90,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x00,0xe0,0x20,0x20,0x24,0x24,0x1c,
+/* 34383 0x864f "虏" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x21,0x2f,0x21,0x21,0x42,0x44,0x98,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x00,0xf8,0x08,0x08,0x08,0x50,0x20,
+/* 34384 0x8650 "虐" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x20,0x27,0x24,0x3f,0x44,0x47,0x80,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x00,
+/* 34385 0x8651 "虑" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x20,0x20,0x20,0x2a,0x4a,0x52,0x81,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x00,0x80,0x44,0x42,0x12,0x10,0xf0,
+/* 34386 0x8652 "虒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x2f,0x28,0x28,0x2f,0x28,0x28,0x4b,0x52,0x94,0x28,
+0x08,0x7c,0x80,0x80,0xf8,0x80,0xfe,0x82,0xf0,0x84,0x7c,0x00,0xe0,0x22,0x22,0x1e,
+/* 34387 0x8653 "虓" */
+0x20,0x20,0x20,0x21,0xf9,0x29,0x29,0x29,0x29,0x29,0x2b,0x2d,0x49,0x42,0x82,0x04,
+0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x48,0x4a,0x4a,0x86,
+/* 34388 0x8654 "虔" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x21,0x20,0x2f,0x22,0x21,0x40,0x43,0x8c,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0x80,0xf8,0x20,0x40,0x80,0x60,0x1c,
+/* 34389 0x8655 "處" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x24,0x24,0x27,0x28,0x35,0x42,0x45,0x98,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0x38,0xa8,0xaa,0x2a,0x46,0x80,0x7e,
+/* 34390 0x8656 "虖" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x27,0x22,0x21,0x2f,0x40,0x41,0x80,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x10,0xe0,0x48,0x50,0xfe,0x40,0x40,0x80,
+/* 34391 0x8657 "虗" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x20,0x27,0x24,0x27,0x44,0x44,0x9f,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0x1c,0xe0,0x00,0xfe,0x20,0x20,0xfe,
+/* 34392 0x8658 "虘" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x27,0x24,0x27,0x24,0x47,0x44,0xbf,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,
+/* 34393 0x8659 "虙" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x21,0x20,0x2a,0x2a,0x53,0x46,0x99,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x00,0x88,0x24,0x44,0x80,0x08,0xf8,
+/* 34394 0x865a "虚" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x21,0x20,0x22,0x32,0x2a,0x2a,0x42,0x5f,0x80,
+0x00,0xf8,0x00,0xfc,0x04,0x60,0x88,0x08,0xf8,0x40,0x48,0x48,0x50,0x40,0xfc,0x00,
+/* 34395 0x865b "虛" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x21,0x29,0x29,0x2f,0x21,0x41,0x5f,0x80,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x20,0x24,0x24,0x3c,0x20,0x20,0xfe,0x00,
+/* 34396 0x865c "虜" */
+0x01,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x24,0x27,0x41,0x5f,0x84,0x08,
+0x00,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x90,0xf0,0x90,0xf0,0x00,0xf8,0x08,0x18,
+/* 34397 0x865d "虝" */
+0x08,0x0f,0x08,0x7f,0x49,0x4e,0x78,0x49,0x47,0x40,0x4e,0x4a,0x4a,0x52,0x91,0x20,
+0x20,0x20,0x20,0x7e,0x6a,0xaa,0x2a,0x2a,0x4a,0x92,0x22,0x54,0x0a,0x02,0xfe,0x00,
+/* 34398 0x865e "虞" */
+0x01,0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x27,0x20,0x2f,0x20,0x5f,0x42,0x9c,
+0x00,0xf8,0x00,0xfc,0x04,0xe0,0x08,0xf8,0x10,0xf0,0x00,0xf8,0x80,0xfc,0x20,0x1c,
+/* 34399 0x865f "號" */
+0x00,0x78,0x48,0x49,0x49,0x79,0x01,0xfd,0x21,0x41,0x79,0x09,0x09,0x0a,0x52,0x24,
+0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x48,0x4a,0x4a,0x86,
+/* 34400 0x8660 "虠" */
+0x20,0x10,0x00,0xfe,0x00,0x28,0x44,0x82,0x04,0x44,0x28,0x10,0x28,0x45,0x85,0x02,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0x2a,0x2a,0x46,
+/* 34401 0x8661 "虡" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x21,0x29,0x25,0x21,0x5f,0x42,0x84,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0x20,0x24,0x28,0x20,0xfe,0x10,0x08,
+/* 34402 0x8662 "虢" */
+0x04,0x1e,0xe0,0x22,0x92,0x54,0x40,0x04,0xff,0x04,0x44,0x24,0x24,0x05,0x15,0x0a,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0x2a,0x2a,0x46,
+/* 34403 0x8663 "虣" */
+0x08,0x0c,0xea,0x0a,0x08,0xfe,0x28,0x28,0xb8,0xa8,0xaa,0xaa,0xb6,0xc3,0x81,0x02,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0x2a,0x2a,0x46,
+/* 34404 0x8664 "虤" */
+0x10,0x1e,0x10,0x7e,0x52,0x5c,0x70,0x52,0x4e,0x40,0x5c,0x54,0x54,0x97,0x95,0x22,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0x2a,0x2a,0x46,
+/* 34405 0x8665 "虥" */
+0x10,0x1e,0x10,0x7e,0x52,0x5c,0x70,0x52,0x4e,0x40,0x5c,0x54,0x54,0x56,0x94,0x20,
+0x28,0x24,0x2e,0xf0,0x28,0x12,0x2a,0xd6,0x28,0x2e,0xf0,0x24,0x28,0x12,0x2a,0xc6,
+/* 34406 0x8666 "虦" */
+0x28,0x24,0x2e,0xf0,0x28,0x12,0x2a,0xd6,0x28,0x2e,0xf0,0x24,0x28,0x12,0x2b,0xc6,
+0x10,0x1e,0x10,0xfe,0x92,0x9c,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xa8,0xaa,0x2a,0x46,
+/* 34407 0x8667 "虧" */
+0x08,0x0f,0x08,0x7f,0x48,0x4f,0x78,0x47,0x52,0x5f,0x72,0x5f,0x52,0x5f,0x52,0x9f,
+0x00,0xbc,0x00,0xc0,0x40,0x3e,0x90,0x90,0x20,0xbe,0x02,0x82,0x02,0x82,0x14,0x88,
+/* 34408 0x8668 "虨" */
+0x08,0x0f,0x08,0x7f,0x48,0x4f,0x78,0x47,0x40,0x48,0x7d,0x48,0x5d,0x6a,0x48,0x88,
+0x02,0x82,0x04,0xc8,0x50,0x02,0x82,0x84,0x08,0x90,0xe2,0x82,0xc4,0xa8,0x90,0xa0,
+/* 34409 0x8669 "虩" */
+0x10,0x92,0x52,0x55,0x11,0x7d,0x45,0x7d,0x45,0x7d,0x11,0x59,0x55,0x96,0x52,0x24,
+0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x48,0x4a,0x4a,0x86,
+/* 34410 0x866a "虪" */
+0x21,0x21,0x39,0x23,0xfa,0xaa,0xb2,0xe6,0xaa,0x9a,0x82,0xba,0xaa,0xae,0x2a,0x42,
+0x20,0x3c,0x64,0x18,0x66,0xbe,0xaa,0xbe,0xaa,0xbe,0x88,0xbe,0x88,0x7e,0x00,0xaa,
+/* 34411 0x866b "虫" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x01,0x01,0x7e,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x10,0x08,0xfc,0x04,0x00,
+/* 34412 0x866c "虬" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,0x00,
+/* 34413 0x866d "虭" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x41,0x02,
+0x00,0x00,0xfe,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x42,0x42,0x82,0x14,0x08,
+/* 34414 0x866e "虮" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 34415 0x866f "虯" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x74,0x44,0x04,0x04,0x04,0x04,
+/* 34416 0x8670 "虰" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 34417 0x8671 "虱" */
+0x00,0x7f,0x00,0x03,0x7c,0x04,0x3f,0x24,0x24,0x24,0x3f,0x04,0x04,0x07,0x78,0x20,
+0x00,0xf0,0x90,0xd0,0x10,0x10,0x90,0x90,0x90,0x90,0x90,0x12,0x8a,0xca,0x46,0x02,
+/* 34418 0x8672 "虲" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x20,0x20,0x20,0x20,0x20,0x30,0x28,0x24,0x22,0x22,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 34419 0x8673 "虳" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x20,0x20,0x20,0x7c,0x44,0x84,0x04,0x44,0x24,0x14,0x14,0x04,0x04,0x04,0x28,0x10,
+/* 34420 0x8674 "虴" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x08,0x1c,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 34421 0x8675 "虵" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x57,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x40,0x00,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 34422 0x8676 "虶" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x57,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 34423 0x8677 "虷" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x48,0x08,0x0a,0x0f,0xf1,0x40,0x00,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 34424 0x8678 "虸" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x57,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 34425 0x8679 "虹" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x43,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 34426 0x867a "虺" */
+0x00,0x00,0xfe,0x25,0x25,0x25,0x25,0x25,0x24,0x24,0x24,0x25,0x24,0x44,0x43,0x80,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x20,0x20,0x28,0xfc,0x04,0x02,0xfe,0x00,
+/* 34427 0x867b "虻" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 34428 0x867c "虼" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe5,0x40,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 34429 0x867d "虽" */
+0x00,0x1f,0x10,0x10,0x1f,0x01,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x01,0x7f,0x20,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0x00,0xf8,0x08,0x08,0xf8,0x20,0x10,0xf8,0x04,0x04,
+/* 34430 0x867e "虾" */
+0x10,0x13,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 34431 0x867f "虿" */
+0x00,0xff,0x04,0x07,0x08,0x10,0x20,0x41,0x3f,0x21,0x21,0x3f,0x01,0x01,0x7f,0x20,
+0x00,0xfe,0x00,0xf0,0x10,0x10,0xa0,0x40,0xf8,0x08,0x08,0xf8,0x00,0x08,0xfc,0x04,
+/* 34432 0x8680 "蚀" */
+0x20,0x20,0x20,0x3d,0x45,0x49,0xa1,0x21,0x21,0x21,0x20,0x20,0x28,0x33,0x21,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x02,0x00,
+/* 34433 0x8681 "蚁" */
+0x10,0x10,0x11,0x7d,0x55,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe4,0x41,0x06,
+0x40,0x24,0x24,0x04,0x04,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 34434 0x8682 "蚂" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x15,0x1c,0xe4,0x40,0x00,
+0x00,0xf8,0x08,0x08,0x88,0x88,0x88,0xfe,0x02,0x02,0x02,0xfa,0x02,0x02,0x14,0x08,
+/* 34435 0x8683 "蚃" */
+0x04,0x08,0x1f,0x03,0x0c,0x3f,0x00,0x07,0x79,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x00,0x40,0x80,0x08,0x10,0xe0,0xc0,0x00,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34436 0x8684 "蚄" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 34437 0x8685 "蚅" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x04,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 34438 0x8686 "蚆" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x40,0x00,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 34439 0x8687 "蚇" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe5,0x42,0x04,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0xa0,0xa0,0xa0,0x90,0x90,0x08,0x08,0x04,0x02,
+/* 34440 0x8688 "蚈" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x57,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x00,0xfc,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 34441 0x8689 "蚉" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe1,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34442 0x868a "蚊" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x01,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x06,
+/* 34443 0x868b "蚋" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 34444 0x868c "蚌" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x55,0x7c,0x50,0x10,0x17,0x1c,0xe4,0x40,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 34445 0x868d "蚍" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x00,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 34446 0x868e "蚎" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 34447 0x868f "蚏" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 34448 0x8690 "蚐" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe4,0x40,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 34449 0x8691 "蚑" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x55,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 34450 0x8692 "蚒" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x00,0xfc,0x84,0x84,0xa4,0x94,0x94,0x84,0xfe,0x84,0x84,0x84,0x84,0x04,0x14,0x08,
+/* 34451 0x8693 "蚓" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x10,0x14,0x1c,0xe4,0x41,0x00,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 34452 0x8694 "蚔" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 34453 0x8695 "蚕" */
+0x00,0x3f,0x01,0x02,0xff,0x04,0x08,0x31,0xdf,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x00,0xf8,0x00,0x00,0xfe,0x40,0x20,0x18,0xf6,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34454 0x8696 "蚖" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x57,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe5,0x42,0x04,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 34455 0x8697 "蚗" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34456 0x8698 "蚘" */
+0x10,0x10,0x10,0x7c,0x57,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x48,0x44,0x44,0x40,0xfe,0x50,0x50,0x50,0x50,0x50,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 34457 0x8699 "蚙" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7c,0x51,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 34458 0x869a "蚚" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe5,0x42,0x04,
+0x08,0x1c,0xe0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 34459 0x869b "蚛" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 34460 0x869c "蚜" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x55,0x55,0x7c,0x50,0x10,0x14,0x1d,0xe6,0x40,0x00,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 34461 0x869d "蚝" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x55,0x54,0x7c,0x50,0x13,0x14,0x1e,0xe2,0x40,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 34462 0x869e "蚞" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7c,0x50,0x11,0x15,0x1e,0xe4,0x40,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 34463 0x869f "蚟" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 34464 0x86a0 "蚠" */
+0x04,0x08,0x30,0xdf,0x04,0x04,0x08,0x10,0x21,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x40,0x20,0x18,0xe6,0x20,0x20,0xa0,0x40,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34465 0x86a1 "蚡" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x56,0x55,0x7c,0x50,0x10,0x14,0x1d,0xe5,0x42,0x04,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 34466 0x86a2 "蚢" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 34467 0x86a3 "蚣" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x55,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x40,0x00,
+0x08,0x48,0x48,0x48,0x44,0x84,0xa4,0x22,0x20,0x40,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 34468 0x86a4 "蚤" */
+0x00,0x3f,0x12,0x09,0x04,0x03,0x1c,0xe1,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x00,0xf0,0x10,0x20,0x40,0x80,0x70,0x0e,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34469 0x86a5 "蚥" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x10,0x88,0x84,0x84,0x02,0x02,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 34470 0x86a6 "蚦" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x54,0x54,0x7c,0x51,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfc,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 34471 0x86a7 "蚧" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 34472 0x86a8 "蚨" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34473 0x86a9 "蚩" */
+0x01,0x21,0x21,0x3f,0x01,0xff,0x00,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x7f,0x20,
+0x00,0x08,0x08,0xf8,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x08,0xfc,0x04,
+/* 34474 0x86aa "蚪" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x54,0x54,0x7c,0x50,0x13,0x14,0x1e,0xe2,0x40,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 34475 0x86ab "蚫" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 34476 0x86ac "蚬" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x14,0x1c,0xe5,0x42,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 34477 0x86ad "蚭" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 34478 0x86ae "蚮" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x55,0x56,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x50,0x54,0x52,0x92,0x90,0x9e,0xf0,0x90,0x90,0x90,0x90,0x90,0x8a,0x8a,0x86,0x82,
+/* 34479 0x86af "蚯" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 34480 0x86b0 "蚰" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 34481 0x86b1 "蚱" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x56,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 34482 0x86b2 "蚲" */
+0x10,0x11,0x10,0x7c,0x55,0x54,0x54,0x54,0x7f,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 34483 0x86b3 "蚳" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 34484 0x86b4 "蚴" */
+0x20,0x20,0x20,0xf9,0xa9,0xaa,0xab,0xa8,0xf9,0xa1,0x22,0x2b,0x38,0xe8,0x40,0x00,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 34485 0x86b5 "蚵" */
+0x10,0x10,0x13,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe4,0x40,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 34486 0x86b6 "蚶" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 34487 0x86b7 "蚷" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 34488 0x86b8 "蚸" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 34489 0x86b9 "蚹" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x44,0x44,0x44,0x84,0xbe,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 34490 0x86ba "蚺" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x17,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 34491 0x86bb "蚻" */
+0x04,0x04,0x7f,0x0e,0x15,0x24,0x44,0x01,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x20,0x20,0xa0,0x20,0x22,0xa2,0x1e,0x00,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34492 0x86bc "蚼" */
+0x10,0x10,0x10,0x7d,0x55,0x56,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe4,0x40,0x00,
+0x80,0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 34493 0x86bd "蚽" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x52,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 34494 0x86be "蚾" */
+0x10,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34495 0x86bf "蚿" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1c,0xe5,0x40,0x00,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 34496 0x86c0 "蛀" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 34497 0x86c1 "蛁" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 34498 0x86c2 "蛂" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7c,0x50,0x10,0x15,0x1d,0xe6,0x40,0x00,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 34499 0x86c3 "蛃" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 34500 0x86c4 "蛄" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34501 0x86c5 "蛅" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34502 0x86c6 "蛆" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfe,0x00,
+/* 34503 0x86c7 "蛇" */
+0x10,0x10,0x10,0x7d,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 34504 0x86c8 "蛈" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x56,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34505 0x86c9 "蛉" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 34506 0x86ca "蛊" */
+0x01,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x7f,0x00,0x3f,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x08,0xfc,0x04,0xf8,0x48,0x48,0x48,0xfe,0x00,
+/* 34507 0x86cb "蛋" */
+0x7f,0x01,0x11,0x11,0x11,0x29,0x47,0x81,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0xfc,0x04,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34508 0x86cc "蛌" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 34509 0x86cd "蛍" */
+0x22,0x11,0x00,0x7f,0x40,0x81,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,0x01,0x7f,0x20,
+0x08,0x10,0x20,0xfe,0x02,0x04,0x00,0xf8,0x08,0x08,0xf8,0x20,0x10,0xf8,0x04,0x04,
+/* 34510 0x86ce "蛎" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x00,0xfe,0x00,0x00,0x00,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x44,0x54,0x88,
+/* 34511 0x86cf "蛏" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x7f,0x50,0x11,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x26,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 34512 0x86d0 "蛐" */
+0x10,0x10,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x50,0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0x54,0xfc,0x04,
+/* 34513 0x86d1 "蛑" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7c,0x51,0x10,0x17,0x1c,0xe4,0x40,0x00,
+0x20,0x20,0x48,0x84,0xfe,0x12,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 34514 0x86d2 "蛒" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 34515 0x86d3 "蛓" */
+0x08,0x08,0x7f,0x08,0xff,0x00,0x08,0x7f,0x49,0x49,0x7f,0x48,0x09,0x0f,0xf0,0x40,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0xaa,0x46,0x82,
+/* 34516 0x86d4 "蛔" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x00,
+0x00,0x00,0xfe,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0xfe,0x02,0x00,
+/* 34517 0x86d5 "蛕" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x55,0x7e,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 34518 0x86d6 "蛖" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7c,0x50,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x90,0x88,0x80,0xfe,0xa0,0xa8,0xb0,0xa4,0xa8,0xb0,0x24,0x2a,0x32,0x22,0xde,0x00,
+/* 34519 0x86d7 "蛗" */
+0x04,0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34520 0x86d8 "蛘" */
+0x11,0x10,0x10,0x7c,0x57,0x54,0x54,0x55,0x7c,0x50,0x13,0x14,0x1e,0xe2,0x40,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 34521 0x86d9 "蛙" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x57,0x54,0x7c,0x50,0x11,0x14,0x1c,0xe4,0x43,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 34522 0x86da "蛚" */
+0x20,0x20,0x23,0xf9,0xa9,0xa9,0xa9,0xaa,0xfb,0xa2,0x24,0x28,0x38,0xe9,0x42,0x04,
+0x02,0x02,0xe2,0x0a,0x0a,0xea,0x2a,0x2a,0x2a,0xaa,0x4a,0x4a,0x82,0x02,0x0a,0x04,
+/* 34523 0x86db "蛛" */
+0x10,0x11,0x11,0x7d,0x55,0x56,0x54,0x57,0x7c,0x50,0x10,0x15,0x1d,0xe6,0x40,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 34524 0x86dc "蛜" */
+0x21,0x21,0x21,0xfa,0xaa,0xae,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x00,0x7c,0x24,0x24,0x24,0xfe,0x24,0x24,0x24,0x7c,0x24,0x20,0x20,0x20,0x40,0x80,
+/* 34525 0x86dd "蛝" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 34526 0x86de "蛞" */
+0x10,0x10,0x11,0x7c,0x54,0x57,0x54,0x54,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34527 0x86df "蛟" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x55,0x56,0x7c,0x50,0x10,0x14,0x1c,0xe4,0x40,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 34528 0x86e0 "蛠" */
+0x20,0x20,0x21,0xf8,0xa8,0xa8,0xa9,0xaa,0xf9,0xa3,0x21,0x29,0x39,0xea,0x43,0x04,
+0x40,0x40,0xfc,0x44,0x84,0x84,0x28,0x10,0x08,0xde,0x4a,0x4a,0x4a,0x52,0x5a,0xa4,
+/* 34529 0x86e1 "蛡" */
+0x10,0x13,0x10,0x7c,0x56,0x55,0x55,0x54,0x7c,0x51,0x12,0x14,0x1c,0xe4,0x41,0x00,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 34530 0x86e2 "蛢" */
+0x11,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7c,0x53,0x10,0x14,0x1d,0xe5,0x42,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 34531 0x86e3 "蛣" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 34532 0x86e4 "蛤" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 34533 0x86e5 "蛥" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x54,0x7d,0x50,0x10,0x15,0x1e,0xe2,0x40,0x01,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 34534 0x86e6 "蛦" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x55,0x55,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 34535 0x86e7 "蛧" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xac,0x54,0x54,0x54,0x54,0xac,0x04,0x04,0x04,0x14,0x08,
+/* 34536 0x86e8 "蛨" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 34537 0x86e9 "蛩" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x45,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34538 0x86ea "蛪" */
+0x08,0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x09,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x00,0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34539 0x86eb "蛫" */
+0x10,0x10,0x10,0x7d,0x56,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x02,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 34540 0x86ec "蛬" */
+0x04,0x04,0x7f,0x04,0x04,0xff,0x08,0x10,0x21,0xdf,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x40,0x40,0xfc,0x40,0x40,0xfe,0x20,0x10,0x08,0xf6,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34541 0x86ed "蛭" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x55,0x54,0x7c,0x50,0x11,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 34542 0x86ee "蛮" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x44,0x01,0x1f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x00,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34543 0x86ef "蛯" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x57,0x54,0x7c,0x51,0x12,0x14,0x1c,0xe4,0x40,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 34544 0x86f0 "蛰" */
+0x10,0x10,0xfb,0x10,0x19,0xf0,0x11,0x52,0x25,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x80,0x80,0xf0,0x90,0x90,0x94,0x54,0x0c,0x04,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34545 0x86f1 "蛱" */
+0x10,0x10,0x10,0x7d,0x54,0x55,0x54,0x54,0x7c,0x53,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34546 0x86f2 "蛲" */
+0x20,0x20,0x20,0xfb,0xa8,0xa8,0xa8,0xab,0xf8,0xa3,0x20,0x28,0x39,0xe9,0x42,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 34547 0x86f3 "蛳" */
+0x20,0x20,0x20,0xfa,0xaa,0xaa,0xaa,0xaa,0xfa,0xa2,0x22,0x28,0x39,0xe9,0x42,0x04,
+0x80,0xbe,0x88,0x88,0xbe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0x2e,0x08,0x08,0x08,
+/* 34548 0x86f4 "蛴" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1c,0xe5,0x41,0x02,
+0x40,0x20,0xfe,0x88,0x50,0x20,0x50,0x88,0x06,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 34549 0x86f5 "蛵" */
+0x10,0x11,0x10,0x7c,0x55,0x56,0x55,0x54,0x7c,0x51,0x10,0x14,0x1c,0xe4,0x43,0x00,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 34550 0x86f6 "蛶" */
+0x10,0x10,0x11,0x7c,0x55,0x54,0x54,0x54,0x7d,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 34551 0x86f7 "蛷" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x55,0x54,0x7c,0x50,0x10,0x15,0x1e,0xe4,0x40,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 34552 0x86f8 "蛸" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 34553 0x86f9 "蛹" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 34554 0x86fa "蛺" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x54,0x7d,0x52,0x10,0x14,0x1e,0xe2,0x41,0x02,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34555 0x86fb "蛻" */
+0x10,0x10,0x10,0x7d,0x56,0x55,0x55,0x55,0x7d,0x51,0x10,0x14,0x1c,0xe5,0x42,0x04,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 34556 0x86fc "蛼" */
+0x10,0x10,0x11,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x14,0x1d,0xe4,0x40,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 34557 0x86fd "蛽" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x48,0x44,0x82,0x02,
+/* 34558 0x86fe "蛾" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xa8,0xa8,0xf8,0xa0,0x23,0x28,0x38,0xe8,0x42,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 34559 0x86ff "蛿" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x50,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 34560 0x8700 "蜀" */
+0x00,0x3f,0x24,0x24,0x3f,0x10,0x1f,0x22,0x5f,0x92,0x12,0x1f,0x02,0x03,0x7c,0x20,
+0x00,0xf8,0x48,0x48,0xf8,0x00,0xfc,0x04,0xc4,0x44,0x44,0xc4,0x24,0xf4,0x14,0x08,
+/* 34561 0x8701 "蜁" */
+0x21,0x21,0x21,0xfa,0xac,0xa9,0xa8,0xa8,0xf9,0xa1,0x21,0x29,0x39,0xea,0x44,0x08,
+0x00,0x00,0xfe,0x00,0x00,0xfe,0x22,0x24,0x20,0x3c,0x20,0x20,0x20,0xa0,0x7e,0x00,
+/* 34562 0x8702 "蜂" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x57,0x7c,0x50,0x10,0x14,0x1f,0xe4,0x40,0x00,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 34563 0x8703 "蜃" */
+0x3f,0x20,0x2f,0x20,0x3f,0x24,0x24,0x26,0x20,0x2f,0x28,0x48,0x4f,0x80,0x1f,0x08,
+0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,0x80,0xf8,0x88,0x88,0xf8,0x84,0xfe,0x02,
+/* 34564 0x8704 "蜄" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 34565 0x8705 "蜅" */
+0x10,0x10,0x13,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 34566 0x8706 "蜆" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x14,0x1c,0xe4,0x41,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 34567 0x8707 "蜇" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34568 0x8708 "蜈" */
+0x10,0x11,0x11,0x7d,0x55,0x54,0x54,0x55,0x7c,0x50,0x13,0x14,0x1c,0xe4,0x41,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 34569 0x8709 "蜉" */
+0x10,0x10,0x11,0x7c,0x55,0x54,0x54,0x55,0x7c,0x50,0x13,0x14,0x1e,0xe2,0x40,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 34570 0x870a "蜊" */
+0x20,0x21,0x27,0xf9,0xa9,0xa9,0xaf,0xa9,0xfb,0xa3,0x25,0x2d,0x39,0xe9,0x41,0x01,
+0x84,0xc4,0x04,0x14,0x14,0x14,0xd4,0x14,0x14,0x94,0x54,0x04,0x04,0x04,0x14,0x08,
+/* 34571 0x870b "蜋" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 34572 0x870c "蜌" */
+0x11,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x50,0x11,0x14,0x1c,0xe4,0x43,0x00,
+0x10,0x12,0x14,0xd8,0x10,0x12,0x52,0x8e,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 34573 0x870d "蜍" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x53,0x10,0x15,0x1d,0xe6,0x40,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfe,0x20,0x24,0x22,0x22,0xa0,0x40,
+/* 34574 0x870e "蜎" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x8a,0x84,
+/* 34575 0x870f "蜏" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x56,0x7d,0x50,0x10,0x14,0x1d,0xe5,0x42,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 34576 0x8710 "蜐" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x54,0x57,0x7c,0x50,0x11,0x15,0x1f,0xe5,0x40,0x00,
+0x88,0x88,0x88,0xc8,0x9e,0x8a,0x8a,0xea,0x8a,0x8a,0x0a,0x4a,0xea,0x12,0x2a,0x44,
+/* 34577 0x8711 "蜑" */
+0x00,0x7b,0x10,0x22,0x7a,0x0a,0x2b,0x10,0x2f,0x41,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x18,0xe0,0x40,0x78,0x40,0x40,0xfc,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34578 0x8712 "蜒" */
+0x20,0x20,0x23,0xf8,0xa8,0xa9,0xa9,0xab,0xf8,0xa2,0x22,0x29,0x39,0xea,0x44,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 34579 0x8713 "蜓" */
+0x20,0x20,0x23,0xf8,0xa8,0xa9,0xa9,0xab,0xf8,0xa2,0x22,0x29,0x39,0xea,0x44,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 34580 0x8714 "蜔" */
+0x10,0x10,0x10,0x7d,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x80,0x80,0xfe,0x02,0x02,0xfa,0xaa,0xaa,0xfa,0xaa,0xaa,0xfa,0x8a,0x02,0x14,0x08,
+/* 34581 0x8715 "蜕" */
+0x11,0x10,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x50,0x10,0x14,0x1c,0xe5,0x42,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 34582 0x8716 "蜖" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x00,
+0x00,0xfe,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x4a,0x4a,0xfe,0x02,0x00,
+/* 34583 0x8717 "蜗" */
+0x20,0x21,0x21,0xf9,0xa9,0xa9,0xa8,0xa8,0xfb,0xa2,0x22,0x2a,0x3b,0xea,0x42,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 34584 0x8718 "蜘" */
+0x21,0x21,0x21,0xfb,0xaa,0xac,0xa8,0xa8,0xfb,0xa0,0x20,0x29,0x39,0xea,0x44,0x08,
+0x00,0x00,0x00,0xde,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x52,0x5e,0x20,0x20,0x00,
+/* 34585 0x8719 "蜙" */
+0x21,0x21,0x21,0xf9,0xaf,0xa9,0xa9,0xab,0xfb,0xa5,0x25,0x29,0x39,0xe9,0x41,0x01,
+0x04,0x14,0x14,0x14,0xd2,0x22,0x2a,0x48,0x88,0x50,0x10,0x14,0x22,0x7e,0x22,0x00,
+/* 34586 0x871a "蜚" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34587 0x871b "蜛" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 34588 0x871c "蜜" */
+0x02,0x01,0x7f,0x42,0x89,0x28,0x49,0x0e,0x77,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x00,0x00,0xfe,0x02,0x24,0x48,0x94,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34589 0x871d "蜝" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x10,0x21,0xdf,0x11,0x1f,0x01,0x7f,0x00,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x08,0xfc,0x04,
+/* 34590 0x871e "蜞" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x15,0x1c,0xe4,0x41,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 34591 0x871f "蜟" */
+0x10,0x10,0x11,0x7c,0x54,0x55,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x10,0xfe,0x40,0x84,0xfe,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 34592 0x8720 "蜠" */
+0x20,0x23,0x22,0xfa,0xaa,0xaa,0xaa,0xab,0xfa,0xa2,0x22,0x2b,0x3a,0xea,0x43,0x02,
+0x00,0xfe,0x02,0x1a,0xe2,0x22,0x22,0xfe,0x22,0x72,0xaa,0x26,0x22,0x22,0xfe,0x02,
+/* 34593 0x8721 "蜡" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x55,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 34594 0x8722 "蜢" */
+0x10,0x11,0x10,0x7c,0x54,0x57,0x54,0x54,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x43,0x00,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 34595 0x8723 "蜣" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x55,0x54,0x7c,0x53,0x10,0x14,0x1c,0xe4,0x41,0x02,
+0x88,0x48,0x50,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 34596 0x8724 "蜤" */
+0x08,0x08,0x7e,0x18,0x2c,0x2a,0x48,0x88,0x09,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x88,0x08,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34597 0x8725 "蜥" */
+0x21,0x21,0x21,0xf9,0xaf,0xa9,0xa9,0xab,0xfb,0xa5,0x25,0x29,0x39,0xe9,0x41,0x01,
+0x00,0x06,0x38,0x20,0xa0,0x20,0x3e,0x24,0xa4,0x64,0x24,0x24,0x24,0x24,0x24,0x44,
+/* 34598 0x8726 "蜦" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 34599 0x8727 "蜧" */
+0x20,0x20,0x23,0xfa,0xaa,0xab,0xaa,0xaa,0xfa,0xa3,0x22,0x2a,0x3a,0xec,0x45,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 34600 0x8728 "蜨" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x57,0x54,0x7d,0x50,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 34601 0x8729 "蜩" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 34602 0x872a "蜪" */
+0x10,0x10,0x10,0x7d,0x56,0x54,0x55,0x54,0x7f,0x50,0x11,0x15,0x1d,0xe4,0x40,0x00,
+0x80,0x80,0xfe,0x02,0x82,0xf2,0x42,0x42,0xfa,0x42,0x52,0x52,0xf2,0x02,0x14,0x08,
+/* 34603 0x872b "蜫" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 34604 0x872c "蜬" */
+0x20,0x21,0x20,0xf8,0xaa,0xaa,0xaa,0xaa,0xfa,0xa2,0x23,0x2a,0x3a,0xea,0x43,0x00,
+0x00,0xfc,0x08,0x10,0x22,0xaa,0x72,0x22,0x72,0xaa,0x26,0xa2,0x42,0x02,0xfe,0x02,
+/* 34605 0x872d "蜭" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 34606 0x872e "蜮" */
+0x20,0x20,0x20,0xfb,0xa8,0xa8,0xab,0xaa,0xfa,0xa2,0x23,0x28,0x38,0xeb,0x41,0x00,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x0c,0x6a,0x8a,0x16,0x22,
+/* 34607 0x872f "蜯" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x55,0x54,0x7d,0x52,0x10,0x14,0x1d,0xe4,0x40,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0x22,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 34608 0x8730 "蜰" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0x4a,0x85,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x80,0x82,0x82,0x7e,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34609 0x8731 "蜱" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x50,0x11,0x17,0x1c,0xe4,0x40,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 34610 0x8732 "蜲" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x56,0x7c,0x53,0x10,0x15,0x1c,0xe4,0x40,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 34611 0x8733 "蜳" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x15,0x1e,0xe2,0x40,0x00,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 34612 0x8734 "蜴" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x50,0x11,0x14,0x1c,0xe5,0x40,0x00,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 34613 0x8735 "蜵" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x04,
+0x50,0x54,0x54,0x54,0xdc,0x04,0x04,0xfc,0x04,0x04,0xdc,0x54,0x54,0x54,0x54,0x04,
+/* 34614 0x8736 "蜶" */
+0x10,0x10,0x11,0x7c,0x54,0x54,0x55,0x56,0x7c,0x50,0x13,0x14,0x1e,0xe2,0x40,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 34615 0x8737 "蜷" */
+0x10,0x11,0x10,0x7c,0x55,0x54,0x57,0x54,0x7d,0x52,0x14,0x14,0x1c,0xe4,0x40,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 34616 0x8738 "蜸" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34617 0x8739 "蜹" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x54,0x4c,0x84,0x04,0x04,0x14,0x08,
+/* 34618 0x873a "蜺" */
+0x20,0x20,0x23,0xfa,0xaa,0xab,0xaa,0xaa,0xfb,0xa0,0x20,0x28,0x38,0xe9,0x42,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 34619 0x873b "蜻" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x57,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 34620 0x873c "蜼" */
+0x10,0x10,0x10,0x7d,0x55,0x57,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 34621 0x873d "蜽" */
+0x20,0x23,0x20,0xf8,0xab,0xaa,0xaa,0xab,0xfa,0xa2,0x23,0x2a,0x3a,0xea,0x42,0x02,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 34622 0x873e "蜾" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7c,0x53,0x10,0x14,0x1d,0xe6,0x40,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 34623 0x873f "蜿" */
+0x20,0x20,0x23,0xfa,0xad,0xa9,0xa9,0xaa,0xfa,0xa3,0x24,0x28,0x39,0xe9,0x42,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 34624 0x8740 "蝀" */
+0x10,0x10,0x13,0x7c,0x55,0x55,0x55,0x55,0x7d,0x50,0x10,0x14,0x1d,0xe6,0x40,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 34625 0x8741 "蝁" */
+0x00,0x7f,0x04,0x3c,0x20,0x3c,0x04,0xff,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x00,0xfc,0x40,0x78,0x08,0x78,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34626 0x8742 "蝂" */
+0x20,0x22,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xec,0x44,0x08,
+0x80,0x86,0xb8,0xa0,0xe0,0x3e,0x2a,0x2a,0xaa,0xaa,0xa4,0xa4,0xa4,0xca,0x8a,0x92,
+/* 34627 0x8743 "蝃" */
+0x10,0x13,0x10,0x7d,0x54,0x55,0x56,0x54,0x7c,0x53,0x10,0x15,0x1c,0xe5,0x42,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 34628 0x8744 "蝄" */
+0x20,0x23,0x22,0xfa,0xaa,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 34629 0x8745 "蝅" */
+0x3e,0x08,0x08,0x7e,0x08,0x14,0x22,0x41,0x9f,0x11,0x11,0x1f,0x11,0x01,0x7f,0x20,
+0xf8,0x20,0x20,0xfc,0x20,0x50,0x88,0x04,0xf2,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34630 0x8746 "蝆" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x55,0x54,0x7c,0x50,0x13,0x14,0x1e,0xe2,0x40,0x00,
+0xa8,0xa8,0xae,0xa8,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 34631 0x8747 "蝇" */
+0x20,0x21,0x21,0xf9,0xa9,0xa8,0xab,0xaa,0xfa,0xa3,0x22,0x2a,0x3b,0xe8,0x40,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x40,0xf8,0x48,0x48,0xf8,0x48,0x48,0xfa,0x42,0x42,0x3e,
+/* 34632 0x8748 "蝈" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xfa,0xa2,0x22,0x2b,0x3a,0xea,0x43,0x02,
+0x00,0xfe,0x02,0x02,0xfe,0x22,0x22,0xfa,0x22,0x32,0x2a,0xfe,0x02,0x02,0xfe,0x02,
+/* 34633 0x8749 "蝉" */
+0x11,0x10,0x10,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x14,0x1d,0xe4,0x40,0x00,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 34634 0x874a "蝊" */
+0x20,0x20,0x23,0xfa,0xac,0xa8,0xab,0xa8,0xf8,0xa1,0x21,0x29,0x3a,0xea,0x44,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 34635 0x874b "蝋" */
+0x20,0x24,0x22,0xfa,0xa8,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2b,0x3a,0xec,0x44,0x08,
+0x00,0x84,0x44,0x48,0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x4a,0x4a,0x46,0x02,
+/* 34636 0x874c "蝌" */
+0x20,0x27,0x21,0xf9,0xa9,0xaf,0xa9,0xa9,0xfb,0xa3,0x25,0x2d,0x39,0xe9,0x41,0x01,
+0xc4,0x04,0x24,0x14,0x14,0x84,0x24,0x14,0x94,0x46,0x3c,0x04,0x04,0x04,0x04,0x04,
+/* 34637 0x874d "蝍" */
+0x20,0x23,0x22,0xfa,0xaa,0xab,0xaa,0xaa,0xfa,0xa3,0x22,0x2a,0x3a,0xea,0x43,0x00,
+0x00,0xde,0x52,0x52,0x52,0xd2,0x52,0x52,0x52,0xd2,0x1a,0x94,0x50,0xb0,0x10,0x10,
+/* 34638 0x874e "蝎" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x55,0x7e,0x51,0x11,0x15,0x1d,0xe4,0x40,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 34639 0x874f "蝏" */
+0x20,0x20,0x23,0xf8,0xa9,0xa9,0xa9,0xa8,0xfb,0xa2,0x21,0x28,0x38,0xe8,0x40,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 34640 0x8750 "蝐" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 34641 0x8751 "蝑" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x56,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 34642 0x8752 "蝒" */
+0x10,0x13,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x74,0x54,0x54,0x74,0x54,0x54,0x54,0xfc,0x04,
+/* 34643 0x8753 "蝓" */
+0x20,0x20,0x21,0xfa,0xad,0xa8,0xab,0xaa,0xfa,0xa3,0x22,0x2a,0x3b,0xea,0x42,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 34644 0x8754 "蝔" */
+0x11,0x11,0x11,0x7d,0x55,0x55,0x55,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 34645 0x8755 "蝕" */
+0x10,0x10,0x28,0x25,0x53,0xfd,0x45,0x7d,0x45,0x7d,0x40,0x50,0x48,0x55,0x64,0x40,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x82,0x00,
+/* 34646 0x8756 "蝖" */
+0x10,0x10,0x13,0x7e,0x54,0x55,0x54,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe4,0x43,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 34647 0x8757 "蝗" */
+0x20,0x20,0x21,0xf9,0xa9,0xa9,0xa9,0xa8,0xfb,0xa0,0x20,0x29,0x38,0xe8,0x43,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34648 0x8758 "蝘" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x24,0x64,0x18,0x24,0x42,0xfe,
+/* 34649 0x8759 "蝙" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x12,0x14,0x1c,0xe4,0x40,0x00,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 34650 0x875a "蝚" */
+0x10,0x10,0x10,0x7c,0x55,0x54,0x54,0x55,0x7e,0x50,0x11,0x14,0x1c,0xe5,0x42,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 34651 0x875b "蝛" */
+0x20,0x20,0x20,0xfb,0xaa,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xeb,0x42,0x04,
+0x0c,0x0a,0x08,0xfe,0x08,0xf8,0x4a,0x4a,0xea,0xac,0xac,0x4c,0xaa,0x0a,0x16,0x22,
+/* 34652 0x875c "蝜" */
+0x10,0x10,0x10,0x7d,0x56,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe4,0x41,0x02,
+0x40,0x40,0xf8,0x08,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 34653 0x875d "蝝" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x54,0x54,0x7d,0x50,0x10,0x15,0x1c,0xe4,0x41,0x00,
+0x40,0x7c,0x84,0xf8,0x08,0xfe,0x40,0xa4,0x38,0x58,0x94,0x34,0x54,0x92,0x50,0x20,
+/* 34654 0x875e "蝞" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 34655 0x875f "蝟" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 34656 0x8760 "蝠" */
+0x10,0x11,0x10,0x7c,0x54,0x54,0x54,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 34657 0x8761 "蝡" */
+0x10,0x13,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x15,0x1c,0xe4,0x41,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 34658 0x8762 "蝢" */
+0x10,0x13,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe4,0x40,0x01,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 34659 0x8763 "蝣" */
+0x21,0x20,0x20,0xfb,0xa9,0xa9,0xa9,0xa9,0xf9,0xa1,0x21,0x29,0x3a,0xea,0x44,0x08,
+0x08,0x88,0x88,0xde,0x10,0x20,0xde,0x42,0x44,0x44,0x5e,0x44,0x44,0x44,0xd4,0x08,
+/* 34660 0x8764 "蝤" */
+0x10,0x10,0x10,0x7d,0x54,0x54,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 34661 0x8765 "蝥" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34662 0x8766 "蝦" */
+0x20,0x23,0x22,0xfa,0xaa,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2b,0x3a,0xea,0x42,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 34663 0x8767 "蝧" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x55,0x55,0x7d,0x51,0x13,0x14,0x1e,0xe2,0x41,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 34664 0x8768 "蝨" */
+0x00,0x3f,0x02,0x02,0x7f,0x02,0x02,0x08,0x7e,0x4a,0x4a,0x7e,0x08,0x0a,0xfe,0x02,
+0x00,0xf0,0x10,0x10,0xea,0x06,0x02,0x20,0xfc,0xa4,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34665 0x8769 "蝩" */
+0x10,0x10,0x11,0x7c,0x57,0x54,0x55,0x55,0x7d,0x51,0x11,0x14,0x1d,0xe4,0x43,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 34666 0x876a "蝪" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x55,0x7c,0x50,0x11,0x16,0x1c,0xe5,0x40,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 34667 0x876b "蝫" */
+0x10,0x10,0x11,0x7c,0x54,0x57,0x54,0x54,0x7c,0x51,0x12,0x14,0x1e,0xe2,0x40,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 34668 0x876c "蝬" */
+0x20,0x20,0x22,0xfa,0xaa,0xaa,0xaa,0xab,0xf8,0xa1,0x22,0x28,0x39,0xe8,0x40,0x07,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 34669 0x876d "蝭" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7c,0x53,0x10,0x15,0x1d,0xe5,0x42,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 34670 0x876e "蝮" */
+0x10,0x10,0x10,0x7c,0x55,0x56,0x54,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe4,0x40,0x01,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 34671 0x876f "蝯" */
+0x10,0x13,0x10,0x7d,0x54,0x55,0x54,0x54,0x7d,0x50,0x10,0x15,0x1d,0xe6,0x40,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 34672 0x8770 "蝰" */
+0x10,0x10,0x13,0x7c,0x54,0x57,0x55,0x54,0x7c,0x53,0x10,0x14,0x1d,0xe4,0x40,0x03,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 34673 0x8771 "蝱" */
+0x02,0x01,0xff,0x10,0x10,0x1f,0x00,0x08,0x7e,0x4a,0x4a,0x7e,0x08,0x0a,0xfe,0x02,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x20,0xfc,0xa4,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34674 0x8772 "蝲" */
+0x20,0x20,0x27,0xf8,0xa8,0xab,0xaa,0xaa,0xfb,0xa0,0x21,0x2a,0x3c,0xe8,0x40,0x00,
+0x82,0x82,0xf2,0x82,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xaa,0xa2,0x82,0x8a,0x84,
+/* 34675 0x8773 "蝳" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x54,0x54,0x7c,0x50,0x11,0x14,0x1d,0xe5,0x40,0x00,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0xa4,0x94,0xfe,0xa4,0x14,0xfe,0x04,0x18,
+/* 34676 0x8774 "蝴" */
+0x21,0x21,0x21,0xfb,0xa9,0xa9,0xa9,0xab,0xfa,0xa2,0x22,0x2a,0x3b,0xe8,0x40,0x00,
+0x00,0x3c,0x24,0xa4,0x24,0x3c,0x24,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0x44,0x54,0x88,
+/* 34677 0x8775 "蝵" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x09,0x01,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34678 0x8776 "蝶" */
+0x20,0x21,0x21,0xfb,0xa9,0xa9,0xa9,0xa9,0xf9,0xa0,0x23,0x28,0x38,0xe9,0x46,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 34679 0x8777 "蝷" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x00,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x10,0x54,0x54,0x54,0x7c,0x14,0x20,0x40,0x80,
+/* 34680 0x8778 "蝸" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x00,0xfc,0x84,0x84,0xf4,0x94,0x94,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 34681 0x8779 "蝹" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x43,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 34682 0x877a "蝺" */
+0x20,0x20,0x23,0xf8,0xa9,0xa9,0xa9,0xa9,0xf8,0xa3,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 34683 0x877b "蝻" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 34684 0x877c "蝼" */
+0x20,0x21,0x20,0xf8,0xab,0xa8,0xa9,0xaa,0xf8,0xa7,0x20,0x29,0x39,0xe8,0x41,0x06,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 34685 0x877d "蝽" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x57,0x54,0x7d,0x52,0x10,0x14,0x1c,0xe4,0x40,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 34686 0x877e "蝾" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xaa,0xac,0xf8,0xa3,0x20,0x28,0x38,0xe9,0x42,0x00,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x24,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,
+/* 34687 0x877f "蝿" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe4,0x40,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x22,0x22,0x1e,
+/* 34688 0x8780 "螀" */
+0x08,0x49,0x2a,0x28,0x08,0x1f,0x2a,0xc9,0x09,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x80,0xf8,0x90,0x60,0x90,0xfe,0x10,0x50,0x20,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34689 0x8781 "螁" */
+0x10,0x12,0x11,0x7d,0x54,0x54,0x57,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x04,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x50,0x4a,0x44,0x54,0x62,0x42,0x80,0x7e,
+/* 34690 0x8782 "螂" */
+0x21,0x20,0x23,0xfa,0xaa,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xeb,0x42,0x00,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 34691 0x8783 "螃" */
+0x20,0x20,0x23,0xf9,0xa8,0xab,0xaa,0xac,0xf8,0xa3,0x20,0x28,0x38,0xe9,0x41,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 34692 0x8784 "螄" */
+0x21,0x22,0x23,0xfa,0xaa,0xaa,0xab,0xaa,0xfa,0xa3,0x22,0x2a,0x3a,0xeb,0x42,0x00,
+0x00,0x7e,0x88,0x88,0xbe,0xaa,0xaa,0x2a,0x2a,0xaa,0xaa,0xae,0x88,0x88,0x88,0x08,
+/* 34693 0x8785 "螅" */
+0x20,0x20,0x21,0xf9,0xa9,0xa9,0xa9,0xa9,0xf9,0xa0,0x20,0x28,0x3a,0xea,0x44,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 34694 0x8786 "螆" */
+0x20,0x20,0x20,0xfb,0xa8,0xa8,0xa9,0xa9,0xfa,0xa3,0x20,0x29,0x39,0xea,0x43,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 34695 0x8787 "螇" */
+0x10,0x13,0x11,0x7c,0x54,0x54,0x55,0x54,0x7c,0x51,0x10,0x14,0x1f,0xe4,0x40,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 34696 0x8788 "螈" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1f,0xe2,0x42,0x04,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 34697 0x8789 "螉" */
+0x20,0x20,0x21,0xfa,0xac,0xa9,0xa8,0xa8,0xfb,0xa0,0x22,0x29,0x3a,0xe8,0x41,0x00,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 34698 0x878a "螊" */
+0x10,0x10,0x10,0x7d,0x54,0x55,0x54,0x57,0x7c,0x51,0x10,0x14,0x1d,0xe6,0x40,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 34699 0x878b "螋" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7c,0x51,0x10,0x14,0x1e,0xe2,0x40,0x03,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 34700 0x878c "螌" */
+0x10,0x3e,0x22,0x2a,0xff,0x22,0x2a,0x42,0x4a,0x85,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x10,0x28,0x46,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34701 0x878d "融" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x20,0x20,0x20,0xfc,0xa4,0xa4,0xa4,0xa4,0xfc,0xa4,0x20,0x28,0x24,0xfe,0x42,0x00,
+/* 34702 0x878e "螎" */
+0x20,0x23,0x20,0xf9,0xa9,0xa9,0xa9,0xa8,0xfb,0xa2,0x22,0x2b,0x3a,0xea,0x42,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 34703 0x878f "螏" */
+0x20,0x20,0x21,0xf9,0xa9,0xad,0xab,0xa9,0xf9,0xa3,0x25,0x29,0x39,0xea,0x42,0x04,
+0x20,0x10,0xfe,0x00,0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 34704 0x8790 "螐" */
+0x20,0x20,0x21,0xf9,0xa9,0xa9,0xa9,0xa9,0xf9,0xa1,0x20,0x2a,0x3a,0xec,0x40,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 34705 0x8791 "螑" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x50,0x10,0x15,0x1c,0xe4,0x41,0x02,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x28,0x24,0xfe,0x50,0x88,0x04,0x02,
+/* 34706 0x8792 "螒" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x45,0x7d,0x45,0x7d,0x11,0xfe,0x10,0x10,0x13,0x11,
+0x20,0x20,0x50,0x88,0x26,0x20,0xfc,0x24,0x24,0x24,0xfc,0x20,0x28,0x3c,0xc4,0x04,
+/* 34707 0x8793 "螓" */
+0x20,0x20,0x27,0xf8,0xab,0xa8,0xaf,0xa9,0xfa,0xa5,0x20,0x2b,0x38,0xe9,0x46,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfc,0x10,0x68,0xc6,0x40,0xf8,0xe0,0x58,0x44,0x40,
+/* 34708 0x8794 "螔" */
+0x20,0x20,0x23,0xfa,0xaa,0xaa,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xec,0x45,0x0a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 34709 0x8795 "螕" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x50,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 34710 0x8796 "螖" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x55,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x00,0xfc,0x84,0xf4,0x94,0xfe,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 34711 0x8797 "螗" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe6,0x42,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 34712 0x8798 "螘" */
+0x10,0x11,0x11,0x7d,0x55,0x54,0x57,0x54,0x7d,0x51,0x11,0x15,0x1c,0xe4,0x43,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 34713 0x8799 "螙" */
+0x01,0x01,0x7f,0x03,0x05,0x19,0xe1,0x08,0x7e,0x4a,0x4a,0x7e,0x08,0x0a,0xfe,0x02,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0e,0x20,0xfc,0xa4,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34714 0x879a "螚" */
+0x20,0x42,0xff,0x01,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x44,0x58,0x62,0x42,0x3e,0x00,0x4c,0x72,0x42,0x3e,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34715 0x879b "螛" */
+0x20,0x20,0x23,0xfa,0xac,0xa9,0xa8,0xa9,0xf8,0xa3,0x20,0x29,0x39,0xe9,0x41,0x01,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 34716 0x879c "螜" */
+0x08,0x7f,0x08,0x3e,0x00,0x7f,0x41,0x00,0x3e,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0xce,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34717 0x879d "螝" */
+0x20,0x20,0x23,0xfa,0xaa,0xab,0xaa,0xaa,0xfb,0xa0,0x20,0x28,0x39,0xe9,0x42,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 34718 0x879e "螞" */
+0x20,0x21,0x21,0xf9,0xa9,0xa9,0xa9,0xa9,0xf9,0xa0,0x22,0x2a,0x3a,0xea,0x40,0x00,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 34719 0x879f "螟" */
+0x20,0x23,0x22,0xf8,0xa9,0xa9,0xa9,0xa9,0xf9,0xa0,0x20,0x2b,0x38,0xe8,0x41,0x02,
+0x00,0xfe,0x02,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xfe,0x00,0x88,0x04,0x02,
+/* 34720 0x87a0 "螠" */
+0x21,0x20,0x20,0xf8,0xab,0xa8,0xa8,0xa9,0xfa,0xa1,0x21,0x29,0x39,0xe9,0x47,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 34721 0x87a1 "螡" */
+0x02,0x01,0x7f,0x08,0x07,0x18,0xe0,0x08,0x7e,0x4a,0x4a,0x7e,0x08,0x0a,0xfe,0x02,
+0x00,0x00,0xfc,0x20,0xc0,0x30,0x0e,0x20,0xfc,0xa4,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34722 0x87a2 "螢" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x41,0x81,0x1f,0x11,0x11,0x1f,0x01,0x01,0x7f,0x00,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0xf0,0x10,0x10,0xf0,0x00,0x08,0xfc,0x04,
+/* 34723 0x87a3 "螣" */
+0x00,0x3d,0x24,0x24,0x25,0x3c,0x27,0x24,0x25,0x3e,0x24,0x24,0x24,0x44,0x55,0x88,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0xa8,0x24,0xfa,0xa8,0xa8,0xf8,0x24,0xfc,0x04,
+/* 34724 0x87a4 "螤" */
+0x20,0x10,0xfe,0x05,0x69,0x11,0x29,0xd5,0x11,0x7d,0x55,0x7c,0x10,0x1c,0xe5,0x42,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x50,0x50,0x88,0x04,0x02,
+/* 34725 0x87a5 "螥" */
+0x10,0x10,0x10,0x7c,0x54,0x55,0x56,0x54,0x7c,0x50,0x10,0x14,0x1d,0xe5,0x42,0x00,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 34726 0x87a6 "螦" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x57,0x54,0x7c,0x51,0x10,0x17,0x1c,0xe5,0x42,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x88,0xf0,0x24,0xfe,0x22,0x24,0xa2,0x40,
+/* 34727 0x87a7 "螧" */
+0x10,0x10,0x11,0x7c,0x57,0x54,0x54,0x55,0x7e,0x54,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 34728 0x87a8 "螨" */
+0x10,0x10,0x11,0x7c,0x54,0x55,0x54,0x54,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x48,0x48,0xfe,0x48,0x00,0xfe,0x48,0x48,0xfe,0x4a,0x4a,0xb6,0x22,0x02,0x0a,0x04,
+/* 34729 0x87a9 "螩" */
+0x21,0x21,0x21,0xfa,0xaa,0xae,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x10,0x1e,0x22,0x54,0x08,0x94,0xe2,0x88,0x88,0xbe,0x88,0xac,0x2a,0x4a,0x28,0x10,
+/* 34730 0x87aa "螪" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x52,0x8a,0x06,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 34731 0x87ab "螫" */
+0x08,0x7f,0x08,0xff,0x14,0x56,0xa5,0x4c,0x81,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x20,0x20,0x3e,0x44,0xa8,0x10,0x28,0x46,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34732 0x87ac "螬" */
+0x20,0x20,0x27,0xf8,0xab,0xaa,0xab,0xaa,0xfb,0xa0,0x21,0x29,0x39,0xe9,0x41,0x01,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 34733 0x87ad "螭" */
+0x20,0x20,0x23,0xf8,0xa9,0xa9,0xa9,0xa9,0xf8,0xa3,0x22,0x2a,0x3a,0xea,0x42,0x02,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 34734 0x87ae "螮" */
+0x21,0x21,0x23,0xf9,0xa9,0xaa,0xac,0xab,0xfa,0xa0,0x21,0x29,0x39,0xe9,0x41,0x00,
+0x54,0x54,0xfe,0x54,0x54,0x72,0x00,0xfe,0x22,0x20,0xfc,0x24,0x24,0x24,0x2c,0x20,
+/* 34735 0x87af "螯" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x81,0x3f,0x21,0x3f,0x01,0x7f,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34736 0x87b0 "螰" */
+0x20,0x20,0x23,0xfa,0xaa,0xab,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xec,0x44,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 34737 0x87b1 "螱" */
+0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2c,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x08,0x08,0x7e,0x08,0x48,0x28,0xa8,0x08,0x28,0x90,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34738 0x87b2 "螲" */
+0x20,0x20,0x23,0xfa,0xa9,0xab,0xa8,0xa8,0xf9,0xa0,0x20,0x29,0x38,0xe8,0x43,0x00,
+0x40,0x20,0xfe,0x8a,0x04,0xfe,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34739 0x87b3 "螳" */
+0x20,0x21,0x20,0xfb,0xaa,0xa8,0xa8,0xa8,0xf8,0xa0,0x20,0x29,0x38,0xe8,0x43,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34740 0x87b4 "螴" */
+0x00,0x7b,0x48,0x51,0x61,0x51,0x49,0x49,0x68,0x50,0x41,0x3f,0x21,0x3f,0x01,0x7f,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x70,0xa8,0x24,0xfa,0x08,0xf8,0x04,0xfe,
+/* 34741 0x87b5 "螵" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x55,0x54,0x7d,0x50,0x13,0x14,0x1c,0xe5,0x42,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 34742 0x87b6 "螶" */
+0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34743 0x87b7 "螷" */
+0x00,0x3f,0x22,0x2f,0x28,0x2f,0x29,0x2f,0x22,0x3f,0x20,0x2f,0x48,0x4f,0x80,0x3f,
+0x80,0xfe,0x00,0xf8,0x88,0xf8,0x08,0xf8,0x20,0xfc,0xa0,0xf8,0x88,0xf8,0x84,0xfe,
+/* 34744 0x87b8 "螸" */
+0x14,0x22,0x49,0x14,0x22,0x41,0xbe,0x22,0x22,0x3e,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x20,0x20,0x3e,0x42,0x94,0x10,0x28,0x28,0x44,0x82,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34745 0x87b9 "螹" */
+0x20,0x20,0x20,0xfb,0xa8,0xab,0xaa,0xab,0xfa,0xa3,0x20,0x2b,0x38,0xe8,0x40,0x00,
+0x80,0x80,0x8e,0xe8,0x88,0xe8,0xae,0xea,0xaa,0xea,0x8a,0xea,0x8a,0x92,0x92,0xa2,
+/* 34746 0x87ba "螺" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x54,0x54,0x7d,0x50,0x10,0x17,0x1c,0xe5,0x42,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 34747 0x87bb "螻" */
+0x20,0x21,0x21,0xfb,0xa9,0xa9,0xa8,0xa9,0xf9,0xa1,0x20,0x2b,0x38,0xe9,0x40,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 34748 0x87bc "螼" */
+0x10,0x10,0x13,0x7c,0x54,0x54,0x55,0x55,0x7d,0x50,0x13,0x14,0x1d,0xe4,0x43,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 34749 0x87bd "螽" */
+0x08,0x1f,0x28,0x07,0x18,0xe1,0x0c,0x03,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0x00,0xf0,0x20,0xc0,0x30,0x8e,0x40,0x00,0xa0,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34750 0x87be "螾" */
+0x10,0x10,0x13,0x7e,0x54,0x55,0x54,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe4,0x41,0x02,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 34751 0x87bf "螿" */
+0x04,0x24,0x24,0x3d,0x04,0x7d,0x24,0x44,0x84,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x48,0x18,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34752 0x87c0 "蟀" */
+0x20,0x20,0x23,0xf8,0xa8,0xaa,0xa9,0xaa,0xf8,0xa0,0x20,0x2b,0x38,0xe8,0x40,0x00,
+0x40,0x20,0xfe,0x20,0x48,0xf2,0x24,0x52,0xf8,0x08,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 34753 0x87c1 "蟁" */
+0x3f,0x20,0x3f,0x21,0x3f,0x20,0x2c,0x30,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0xf8,0x08,0xf8,0x00,0xfc,0x80,0x64,0x1c,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34754 0x87c2 "蟂" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x15,0x1c,0xe4,0x43,0x00,
+0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x22,0xfa,0x76,0xa8,0x26,0x20,
+/* 34755 0x87c3 "蟃" */
+0x20,0x21,0x21,0xf9,0xa9,0xa9,0xa8,0xab,0xfa,0xa3,0x20,0x29,0x38,0xe8,0x41,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 34756 0x87c4 "蟄" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x08,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34757 0x87c5 "蟅" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x11,0x15,0x1d,0xe6,0x42,0x05,0x08,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0xd4,0xaa,0x2a,0x00,
+/* 34758 0x87c6 "蟆" */
+0x10,0x10,0x13,0x7c,0x54,0x55,0x55,0x55,0x7d,0x51,0x10,0x17,0x1c,0xe4,0x41,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 34759 0x87c7 "蟇" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x11,0x3f,0xd1,0x1f,0x01,0x7f,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xf8,0x16,0xf0,0x08,0xfc,
+/* 34760 0x87c8 "蟈" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3b,0xea,0x43,0x02,
+0x00,0xfe,0x1a,0x16,0xfe,0x12,0xea,0xaa,0xaa,0xea,0x0e,0x6a,0x9a,0x26,0xfe,0x02,
+/* 34761 0x87c9 "蟉" */
+0x20,0x23,0x20,0xfa,0xa9,0xaa,0xa8,0xa8,0xfb,0xa0,0x21,0x28,0x39,0xe8,0x40,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 34762 0x87ca "蟊" */
+0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x01,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34763 0x87cb "蟋" */
+0x20,0x21,0x20,0xf9,0xa8,0xab,0xa8,0xa8,0xf9,0xa2,0x20,0x28,0x3a,0xea,0x44,0x00,
+0x1c,0xe0,0x20,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 34764 0x87cc "蟌" */
+0x10,0x10,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x51,0x10,0x14,0x1d,0xe5,0x41,0x02,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 34765 0x87cd "蟍" */
+0x20,0x23,0x20,0xff,0xa8,0xa9,0xaa,0xac,0xf8,0xa0,0x23,0x28,0x38,0xe9,0x42,0x00,
+0x62,0x8a,0x8a,0xea,0x8a,0xca,0xa2,0x8a,0xa4,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 34766 0x87ce "蟎" */
+0x20,0x20,0x23,0xf8,0xa8,0xa8,0xa8,0xab,0xfa,0xa3,0x22,0x2b,0x3a,0xea,0x42,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 34767 0x87cf "蟏" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xa8,0xaf,0xf8,0xa3,0x20,0x2a,0x3a,0xeb,0x42,0x04,
+0x88,0x88,0xfe,0x88,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xb4,0xac,0x2c,0x24,0x24,
+/* 34768 0x87d0 "蟐" */
+0x20,0x21,0x20,0xfb,0xaa,0xa8,0xa8,0xa8,0xf8,0xa0,0x21,0x29,0x39,0xe9,0x41,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 34769 0x87d1 "蟑" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x55,0x7d,0x51,0x11,0x14,0x1f,0xe4,0x40,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 34770 0x87d2 "蟒" */
+0x20,0x20,0x23,0xf8,0xa8,0xab,0xa8,0xa8,0xf9,0xa2,0x20,0x2b,0x38,0xe8,0x41,0x02,
+0x88,0x88,0xfe,0x88,0x24,0xfe,0x50,0x88,0x04,0x8a,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 34771 0x87d3 "蟓" */
+0x20,0x20,0x21,0xfb,0xad,0xa9,0xa9,0xa8,0xf8,0xa3,0x20,0x2b,0x38,0xe8,0x43,0x00,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 34772 0x87d4 "蟔" */
+0x20,0x21,0x21,0xf9,0xa9,0xa9,0xa9,0xa8,0xf9,0xa0,0x23,0x28,0x3a,0xea,0x44,0x00,
+0x00,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,
+/* 34773 0x87d5 "蟕" */
+0x20,0x22,0x22,0xfa,0xaa,0xaf,0xa9,0xaa,0xff,0xaa,0x23,0x2a,0x3b,0xec,0x44,0x08,
+0x90,0x94,0xd8,0x92,0xd2,0x0e,0xf0,0x10,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x54,0x08,
+/* 34774 0x87d6 "蟖" */
+0x21,0x21,0x21,0xfb,0xa9,0xa9,0xa9,0xa9,0xf9,0xa1,0x23,0x28,0x39,0xea,0x44,0x00,
+0x40,0x44,0x58,0xf0,0x50,0xd0,0x5e,0xd4,0x54,0x54,0xf4,0x14,0x54,0x34,0x14,0x24,
+/* 34775 0x87d7 "蟗" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x91,0x1f,0x41,0x7f,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x12,0xf0,0x04,0xfc,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34776 0x87d8 "蟘" */
+0x10,0x10,0x11,0x7e,0x54,0x54,0x54,0x54,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x00,
+0x54,0x92,0x9e,0xf0,0x8a,0x86,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 34777 0x87d9 "蟙" */
+0x21,0x20,0x23,0xf8,0xaa,0xa9,0xaf,0xa8,0xfb,0xa2,0x22,0x2b,0x3a,0xea,0x43,0x00,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 34778 0x87da "蟚" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x22,0x3e,0x14,0x7f,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x04,0x08,0x10,0x64,0x08,0x10,0x64,0x08,0x10,0x60,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34779 0x87db "蟛" */
+0x20,0x20,0x27,0xf8,0xa8,0xab,0xa8,0xab,0xfa,0xa2,0x23,0x2a,0x39,0xe8,0x47,0x02,
+0x82,0x82,0xf4,0x88,0x80,0xe2,0x02,0xe4,0x28,0x20,0xe0,0x22,0x42,0x74,0x88,0x10,
+/* 34780 0x87dc "蟜" */
+0x10,0x11,0x10,0x7f,0x54,0x55,0x56,0x54,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x41,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 34781 0x87dd "蟝" */
+0x22,0x21,0x20,0xfc,0xaa,0xa8,0xa9,0xae,0xfa,0xa0,0x23,0x28,0x38,0xe9,0x42,0x00,
+0x00,0x7e,0x40,0x7c,0x44,0xfc,0x40,0x7e,0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 34782 0x87de "蟞" */
+0x08,0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x20,0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34783 0x87df "蟟" */
+0x10,0x10,0x11,0x7c,0x55,0x54,0x55,0x56,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x41,0x00,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 34784 0x87e0 "蟠" */
+0x20,0x23,0x21,0xf8,0xab,0xa8,0xa9,0xaa,0xf9,0xa1,0x21,0x29,0x39,0xe9,0x41,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 34785 0x87e1 "蟡" */
+0x20,0x23,0x20,0xfa,0xa9,0xab,0xaa,0xab,0xfa,0xa3,0x22,0x2a,0x3a,0xed,0x44,0x08,
+0x0e,0xf0,0x44,0x24,0x08,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 34786 0x87e2 "蟢" */
+0x10,0x13,0x10,0x7d,0x54,0x55,0x55,0x55,0x7c,0x53,0x10,0x15,0x1d,0xe5,0x41,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 34787 0x87e3 "蟣" */
+0x21,0x21,0x22,0xfb,0xa9,0xaa,0xab,0xa9,0xfb,0xa1,0x21,0x29,0x3a,0xea,0x42,0x04,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 34788 0x87e4 "蟤" */
+0x20,0x23,0x22,0xfb,0xaa,0xaa,0xa9,0xa8,0xf8,0xa3,0x20,0x28,0x3b,0xe8,0x41,0x02,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 34789 0x87e5 "蟥" */
+0x10,0x10,0x11,0x7c,0x54,0x57,0x54,0x55,0x7d,0x51,0x11,0x15,0x1c,0xe4,0x41,0x02,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 34790 0x87e6 "蟦" */
+0x10,0x11,0x10,0x7c,0x57,0x54,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe4,0x41,0x02,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 34791 0x87e7 "蟧" */
+0x20,0x22,0x22,0xfc,0xa9,0xaa,0xa8,0xab,0xfa,0xa4,0x23,0x28,0x38,0xe8,0x41,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 34792 0x87e8 "蟨" */
+0x3f,0x28,0x25,0x3f,0x22,0x2a,0x2f,0x22,0x24,0x28,0x27,0x24,0x27,0x40,0x4f,0x80,
+0xfe,0x90,0x10,0xde,0x22,0x88,0x88,0x94,0x22,0x40,0xfc,0x44,0xfc,0x44,0xfe,0x02,
+/* 34793 0x87e9 "蟩" */
+0x20,0x2f,0x28,0xfa,0xa9,0xab,0xa8,0xa8,0xfa,0xaa,0x2b,0x28,0x38,0xe9,0x49,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 34794 0x87ea "蟪" */
+0x20,0x20,0x23,0xf8,0xa9,0xa9,0xa9,0xa9,0xf9,0xa0,0x23,0x28,0x38,0xea,0x42,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 34795 0x87eb "蟫" */
+0x20,0x23,0x20,0xfb,0xaa,0xab,0xa8,0xa9,0xf9,0xa1,0x21,0x29,0x38,0xeb,0x40,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 34796 0x87ec "蟬" */
+0x20,0x23,0x22,0xfa,0xab,0xa8,0xa9,0xa9,0xf9,0xa1,0x21,0x28,0x3b,0xe8,0x40,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 34797 0x87ed "蟭" */
+0x10,0x10,0x11,0x7d,0x57,0x55,0x55,0x55,0x7d,0x11,0x15,0x1d,0xe5,0x42,0x02,0x04,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 34798 0x87ee "蟮" */
+0x10,0x10,0x13,0x7c,0x55,0x54,0x57,0x55,0x7c,0x53,0x10,0x15,0x1d,0xe5,0x41,0x01,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 34799 0x87ef "蟯" */
+0x20,0x20,0x21,0xf8,0xab,0xa9,0xab,0xa9,0xf9,0xa6,0x20,0x2b,0x38,0xe8,0x41,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 34800 0x87f0 "蟰" */
+0x20,0x21,0x20,0xfb,0xa8,0xa9,0xa8,0xaa,0xfb,0xa2,0x23,0x2a,0x3b,0xea,0x42,0x04,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 34801 0x87f1 "蟱" */
+0x20,0x20,0x21,0xfb,0xad,0xa9,0xab,0xa9,0xf9,0xa1,0x27,0x28,0x39,0xe9,0x42,0x00,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 34802 0x87f2 "蟲" */
+0x01,0x01,0x3f,0x21,0x3f,0x01,0x7f,0x00,0x10,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0x00,0x00,0xf8,0x08,0xf8,0x08,0xfc,0x04,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34803 0x87f3 "蟳" */
+0x10,0x11,0x10,0x7c,0x54,0x55,0x54,0x55,0x7c,0x53,0x10,0x17,0x1d,0xe4,0x40,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xdc,0x94,0xdc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 34804 0x87f4 "蟴" */
+0x24,0xff,0x24,0x3c,0x24,0x3c,0x24,0xff,0x24,0x42,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x0c,0x70,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34805 0x87f5 "蟵" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xea,0x45,0x00,
+0x00,0xfe,0x00,0x04,0xf4,0x04,0xee,0xa4,0xa4,0xec,0x04,0xa4,0x44,0x74,0x94,0x08,
+/* 34806 0x87f6 "蟶" */
+0x20,0x27,0x22,0xfb,0xaa,0xab,0xaa,0xaf,0xf8,0xa3,0x20,0x29,0x38,0xe8,0x43,0x00,
+0x00,0xe0,0x5e,0xd2,0x52,0xd2,0x72,0xde,0x40,0xfe,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 34807 0x87f7 "蟷" */
+0x20,0x21,0x20,0xfb,0xaa,0xa8,0xa8,0xa8,0xf8,0xa0,0x21,0x29,0x39,0xe9,0x41,0x01,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 34808 0x87f8 "蟸" */
+0x7f,0x06,0x3b,0x04,0x19,0x62,0x0c,0x72,0x11,0x7e,0x52,0x7e,0x10,0x14,0xfe,0x02,
+0xfc,0x00,0x08,0xb0,0xc0,0xa0,0x98,0x86,0x20,0xfc,0xa4,0xfc,0x20,0x24,0xfe,0x02,
+/* 34809 0x87f9 "蟹" */
+0x20,0x3e,0x44,0xbe,0x2a,0x3e,0x2a,0x3e,0x2a,0x2a,0x45,0x3f,0x21,0x3f,0x01,0x7f,
+0x00,0xfc,0x24,0x54,0x98,0x50,0xfc,0x10,0xfe,0x10,0x10,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34810 0x87fa "蟺" */
+0x10,0x11,0x10,0x7d,0x55,0x55,0x55,0x55,0x7c,0x50,0x10,0x14,0x1e,0xe2,0x40,0x01,
+0x10,0xfe,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 34811 0x87fb "蟻" */
+0x21,0x20,0x23,0xf8,0xa9,0xa8,0xab,0xa8,0xf9,0xa0,0x23,0x28,0x38,0xeb,0x40,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 34812 0x87fc "蟼" */
+0x24,0xff,0x24,0x7e,0x82,0x7a,0x4a,0x7a,0x05,0x1f,0x11,0x11,0x1f,0x01,0x7f,0x20,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0x10,0xf0,0x08,0xfc,0x04,
+/* 34813 0x87fd "蟽" */
+0x10,0x12,0x11,0x7c,0x54,0x54,0x57,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x42,0x04,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 34814 0x87fe "蟾" */
+0x10,0x10,0x11,0x7f,0x55,0x55,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x41,0x02,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 34815 0x87ff "蟿" */
+0x08,0xff,0x08,0x3e,0x2b,0x3e,0x2a,0xff,0x49,0x7f,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x78,0xc8,0x48,0x86,0x78,0x48,0x28,0x90,0x28,0x46,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34816 0x8800 "蠀" */
+0x12,0x11,0x10,0x7c,0x57,0x55,0x54,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x40,0x01,
+0x20,0x3e,0x42,0x94,0x10,0x28,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 34817 0x8801 "蠁" */
+0x11,0x2b,0x4a,0x73,0x2a,0x4b,0x7a,0x12,0x23,0xc2,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x00,0xde,0x52,0xd4,0x52,0xd2,0x1a,0x94,0x50,0x40,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34818 0x8802 "蠂" */
+0x10,0x13,0x10,0x7c,0x55,0x57,0x55,0x55,0x7d,0x51,0x10,0x17,0x1c,0xe4,0x43,0x00,
+0x88,0xfe,0x88,0x00,0x48,0xfe,0x48,0x78,0x00,0xfc,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 34819 0x8803 "蠃" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x71,0x57,0x75,0x57,0x71,0x57,0xb0,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x1c,0xd4,0x54,0xdc,0x56,0xd6,0x62,
+/* 34820 0x8804 "蠄" */
+0x20,0x20,0x20,0xf9,0xae,0xa8,0xa9,0xa9,0xf9,0xa0,0x23,0x2a,0x3a,0xea,0x42,0x02,
+0x20,0x50,0x88,0x24,0xfa,0x50,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x06,
+/* 34821 0x8805 "蠅" */
+0x10,0x11,0x11,0x7d,0x55,0x54,0x55,0x55,0x7d,0x51,0x11,0x15,0x1d,0xe5,0x40,0x00,
+0x00,0xfc,0x54,0x54,0xdc,0x50,0xdc,0x54,0x54,0xdc,0x54,0x54,0xdc,0x50,0x52,0x3e,
+/* 34822 0x8806 "蠆" */
+0x08,0xff,0x08,0x1f,0x11,0x1f,0x11,0x7f,0x41,0x5f,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfc,0x24,0xec,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34823 0x8807 "蠇" */
+0x20,0x20,0x23,0xf8,0xa9,0xa9,0xa9,0xa9,0xf9,0xa0,0x23,0x2a,0x3a,0xea,0x42,0x02,
+0x88,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 34824 0x8808 "蠈" */
+0x00,0x7c,0x45,0x7c,0x44,0x7d,0x44,0x7c,0x29,0x45,0x3f,0x21,0x3f,0x01,0x7f,0x00,
+0x10,0x14,0xfe,0x90,0x94,0xd4,0x8a,0x8a,0x16,0x22,0xf8,0x08,0xf8,0x08,0xfc,0x04,
+/* 34825 0x8809 "蠉" */
+0x10,0x11,0x11,0x7d,0x55,0x54,0x57,0x54,0x7d,0x51,0x11,0x14,0x1c,0xe5,0x42,0x00,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 34826 0x880a "蠊" */
+0x20,0x23,0x22,0xfa,0xab,0xaa,0xaa,0xaa,0xfb,0xa2,0x22,0x2a,0x3a,0xed,0x46,0x08,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 34827 0x880b "蠋" */
+0x10,0x11,0x11,0x7d,0x55,0x54,0x55,0x56,0x7d,0x51,0x11,0x15,0x1c,0xe5,0x40,0x00,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 34828 0x880c "蠌" */
+0x10,0x11,0x11,0x7d,0x54,0x55,0x54,0x57,0x7c,0x50,0x11,0x14,0x1f,0xe4,0x40,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 34829 0x880d "蠍" */
+0x20,0x23,0x22,0xfb,0xaa,0xab,0xa9,0xab,0xfc,0xa2,0x23,0x2a,0x3b,0xe8,0x41,0x00,
+0x08,0xc8,0x48,0xce,0x4a,0xd2,0x04,0xe4,0xa4,0xa4,0x64,0x2a,0xea,0x2a,0x4a,0x90,
+/* 34830 0x880e "蠎" */
+0x10,0x13,0x10,0x7c,0x57,0x54,0x54,0x57,0x7c,0x50,0x10,0x15,0x1c,0xe4,0x41,0x02,
+0x88,0xfe,0x88,0x20,0xfe,0x50,0x88,0x26,0xf8,0x20,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 34831 0x880f "蠏" */
+0x21,0x21,0x22,0xfc,0xab,0xaa,0xaa,0xab,0xfa,0xa2,0x23,0x2a,0x3a,0xea,0x42,0x04,
+0x00,0xde,0x4a,0x8a,0xea,0xb6,0xa4,0xf4,0xbe,0xa4,0xe4,0xbe,0xa4,0xa4,0x24,0x64,
+/* 34832 0x8810 "蠐" */
+0x20,0x20,0x23,0xf8,0xa8,0xaf,0xaa,0xaa,0xfd,0xa0,0x21,0x29,0x39,0xe9,0x41,0x02,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 34833 0x8811 "蠑" */
+0x20,0x22,0x22,0xfc,0xa9,0xaa,0xa8,0xab,0xfa,0xa0,0x23,0x28,0x38,0xe9,0x46,0x00,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x22,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 34834 0x8812 "蠒" */
+0x7f,0x21,0x7f,0xb5,0x29,0x35,0x21,0x35,0x29,0x35,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0xfc,0x08,0xfc,0x5a,0x28,0x58,0x08,0x58,0x28,0x58,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34835 0x8813 "蠓" */
+0x20,0x23,0x20,0xfb,0xaa,0xa9,0xa8,0xab,0xf8,0xa0,0x23,0x28,0x3b,0xe8,0x43,0x00,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 34836 0x8814 "蠔" */
+0x20,0x23,0x20,0xf9,0xa9,0xa9,0xa8,0xab,0xfa,0xa1,0x20,0x2b,0x38,0xeb,0x40,0x03,
+0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x40,0xa4,0xd8,0x34,0xd2,0x30,
+/* 34837 0x8815 "蠕" */
+0x20,0x21,0x20,0xfb,0xaa,0xa9,0xa8,0xa9,0xf8,0xa3,0x20,0x29,0x39,0xe9,0x41,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 34838 0x8816 "蠖" */
+0x10,0x13,0x10,0x7c,0x55,0x57,0x55,0x55,0x7d,0x51,0x11,0x15,0x1f,0xe4,0x40,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 34839 0x8817 "蠗" */
+0x20,0x23,0x20,0xfa,0xa9,0xaa,0xa8,0xa9,0xfb,0xa5,0x21,0x29,0x39,0xe9,0x41,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 34840 0x8818 "蠘" */
+0x21,0x21,0x23,0xf9,0xaf,0xaa,0xaa,0xaf,0xfa,0xa3,0x22,0x2b,0x3a,0xeb,0x42,0x00,
+0x10,0x14,0xf2,0x10,0xfe,0x90,0x50,0xf4,0x94,0xf4,0x94,0xe8,0x8a,0xfa,0x26,0x42,
+/* 34841 0x8819 "蠙" */
+0x20,0x20,0x23,0xfa,0xa9,0xa9,0xaa,0xa9,0xfb,0xa1,0x21,0x29,0x39,0xe9,0x40,0x01,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 34842 0x881a "蠚" */
+0x08,0x7f,0x08,0x02,0xff,0x08,0x1f,0x28,0xc8,0x0f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x20,0xfc,0x20,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34843 0x881b "蠛" */
+0x10,0x11,0x10,0x7c,0x55,0x55,0x55,0x55,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x41,0x02,
+0x48,0xfe,0x48,0x00,0xfe,0x4a,0x4a,0xfe,0x14,0xfe,0x10,0x92,0x4c,0x4a,0x16,0x22,
+/* 34844 0x881c "蠜" */
+0x22,0x21,0xfa,0x20,0x72,0xa9,0x22,0xff,0x08,0x30,0xc1,0x3f,0x21,0x3f,0x01,0x7f,
+0x88,0x08,0xbe,0x08,0x9c,0x2a,0x88,0xfe,0x20,0x18,0x06,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34845 0x881d "蠝" */
+0x20,0x21,0x21,0xf9,0xa9,0xa9,0xa9,0xa8,0xfb,0xa2,0x22,0x2b,0x3a,0xea,0x43,0x02,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xfe,0x22,
+/* 34846 0x881e "蠞" */
+0x20,0x3f,0x48,0xbf,0x21,0x3f,0x21,0x3f,0x24,0x3a,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x40,0x7e,0x90,0x7c,0x44,0x44,0x44,0x54,0x48,0x40,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34847 0x881f "蠟" */
+0x21,0x22,0x21,0xf8,0xab,0xaa,0xaa,0xaa,0xfb,0xa2,0x23,0x2a,0x3b,0xea,0x42,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 34848 0x8820 "蠠" */
+0x00,0x7f,0x02,0x3f,0x24,0x27,0x24,0x27,0x24,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xfc,0x00,0xf8,0x48,0xc8,0x48,0xc8,0x48,0xf8,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34849 0x8821 "蠡" */
+0x0f,0x10,0x1f,0x00,0xff,0x0c,0x73,0x0d,0x72,0x0c,0xf3,0x7c,0x54,0x7c,0x12,0xfe,
+0xe0,0x20,0xc0,0x40,0xfe,0x10,0x20,0xc0,0xb0,0x8e,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34850 0x8822 "蠢" */
+0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x3f,0xc8,0x0f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf8,0x26,0xe0,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34851 0x8823 "蠣" */
+0x10,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x7d,0x11,0x15,0x1d,0xe5,0x42,0x02,0x04,
+0x00,0xfe,0x28,0xfe,0x28,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x92,0xba,0x8a,0x84,
+/* 34852 0x8824 "蠤" */
+0x08,0x04,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x20,0x40,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34853 0x8825 "蠥" */
+0x52,0x7e,0x28,0x7e,0xa2,0x3e,0x20,0x3e,0x22,0x3e,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34854 0x8826 "蠦" */
+0x20,0x20,0x20,0xfb,0xaa,0xab,0xaa,0xaa,0xfa,0xa2,0x22,0x2a,0x3a,0xed,0x45,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 34855 0x8827 "蠧" */
+0x01,0x7f,0x01,0x1f,0x00,0x7f,0x48,0x9f,0x28,0xcf,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xfc,0x00,0xf0,0x00,0xfe,0x02,0xf4,0x10,0xf0,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34856 0x8828 "蠨" */
+0x20,0x23,0x20,0xf9,0xa8,0xab,0xa8,0xa9,0xfa,0xa3,0x22,0x2b,0x3a,0xeb,0x42,0x04,
+0x88,0xfe,0xa8,0xfc,0x24,0xfe,0x24,0xfc,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,
+/* 34857 0x8829 "蠩" */
+0x22,0x21,0x20,0xfb,0xa8,0xab,0xa8,0xab,0xf8,0xa3,0x22,0x2a,0x3a,0xeb,0x42,0x00,
+0x10,0x10,0x3a,0x92,0x14,0xbe,0x08,0x90,0x3c,0xe4,0xa4,0xbc,0xa4,0xa4,0xbc,0x24,
+/* 34858 0x882a "蠪" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34859 0x882b "蠫" */
+0x07,0x78,0x25,0x1e,0x64,0x1a,0x65,0x19,0x65,0x02,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x14,0x08,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34860 0x882c "蠬" */
+0x21,0x20,0x23,0xf8,0xaa,0xa9,0xab,0xa8,0xfb,0xa2,0x23,0x2a,0x3b,0xea,0x42,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 34861 0x882d "蠭" */
+0x21,0x13,0x15,0x00,0x77,0x11,0x10,0x13,0x28,0x47,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xf0,0x10,0xe0,0x5c,0xf0,0x40,0xfc,0x40,0xfe,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34862 0x882e "蠮" */
+0x23,0x22,0x22,0xfb,0xab,0xaa,0xaa,0xab,0xf8,0xa3,0x20,0x2a,0x39,0xea,0x41,0x00,
+0xee,0x8a,0xea,0x50,0xee,0x4a,0xa4,0xea,0x00,0xde,0x42,0x52,0x4a,0x52,0x4a,0x84,
+/* 34863 0x882f "蠯" */
+0x00,0x7f,0x42,0x4f,0x48,0x4f,0x49,0x4f,0x42,0x7f,0x44,0x5f,0x55,0x5f,0x44,0xbf,
+0x80,0xfe,0x00,0xf8,0x88,0xf8,0x08,0xf8,0x80,0xfc,0x90,0x7c,0x54,0x7c,0x92,0xfe,
+/* 34864 0x8830 "蠰" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x54,0x57,0x7c,0x53,0x10,0x17,0x1c,0xe5,0x42,0x00,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 34865 0x8831 "蠱" */
+0x01,0x1f,0x11,0x1f,0x01,0x7f,0x10,0x7c,0x54,0x7c,0x12,0xfe,0x00,0x3f,0x24,0xff,
+0x00,0xf0,0x10,0xf0,0x08,0xfc,0x20,0xf8,0xa8,0xf8,0x24,0xfc,0x00,0xf8,0x48,0xfe,
+/* 34866 0x8832 "蠲" */
+0x44,0x24,0x28,0x00,0xfe,0x00,0x28,0x45,0x82,0x00,0xfe,0xaa,0xaa,0xaa,0xaf,0xf8,
+0x00,0xfe,0xaa,0xaa,0xfe,0x40,0xfe,0x22,0xfa,0xaa,0xaa,0xfa,0x22,0xfa,0x0a,0x04,
+/* 34867 0x8833 "蠳" */
+0x23,0x22,0x23,0xfa,0xab,0xaa,0xab,0xa9,0xfa,0xa0,0x27,0x28,0x39,0xe8,0x40,0x03,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x8c,0x52,0x40,0xfe,0x88,0x90,0x60,0xd8,0x04,
+/* 34868 0x8834 "蠴" */
+0x10,0x13,0x10,0x7d,0x55,0x55,0x54,0x55,0x7c,0x53,0x10,0x15,0x1e,0xe4,0x40,0x00,
+0x88,0xfe,0x88,0xfc,0x54,0xfc,0x22,0xfc,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,
+/* 34869 0x8835 "蠵" */
+0x22,0x23,0x20,0xf9,0xab,0xad,0xa9,0xa9,0xf9,0xa1,0x21,0x2b,0x3a,0xeb,0x42,0x02,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 34870 0x8836 "蠶" */
+0x3e,0x48,0x7e,0x14,0x66,0x3f,0x20,0x3f,0x20,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x7c,0x90,0xfc,0x2a,0xc6,0xf8,0x08,0xf8,0x08,0xf8,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34871 0x8837 "蠷" */
+0x23,0x22,0x23,0xfa,0xab,0xaa,0xab,0xa8,0xf9,0xa1,0x23,0x2d,0x39,0xe9,0x41,0x01,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 34872 0x8838 "蠸" */
+0x20,0x23,0x20,0xfb,0xaa,0xab,0xa8,0xa8,0xf9,0xa1,0x23,0x2d,0x39,0xe9,0x41,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 34873 0x8839 "蠹" */
+0x01,0x7f,0x11,0x1f,0x01,0xff,0x88,0x1f,0x68,0x0f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x00,0xfc,0x10,0xf0,0x00,0xfe,0x02,0xf0,0x10,0xf0,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34874 0x883a "蠺" */
+0x7c,0x10,0xfd,0x28,0x44,0xbf,0x20,0x3f,0x20,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0xf8,0x20,0xfc,0x50,0x88,0xf6,0x10,0xf0,0x10,0xf0,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34875 0x883b "蠻" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x01,0x3f,0x21,0x3f,0x01,0x7f,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf8,0x08,0xf8,0x04,0xfe,
+/* 34876 0x883c "蠼" */
+0x23,0x22,0x23,0xfa,0xab,0xa8,0xa9,0xab,0xfd,0xa1,0x21,0x28,0x39,0xe8,0x40,0x07,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 34877 0x883d "蠽" */
+0x08,0x2a,0x4d,0x08,0x14,0x3f,0x64,0xbf,0x24,0x3f,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x28,0x24,0x2e,0x70,0x24,0x24,0x28,0x12,0x2a,0x46,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34878 0x883e "蠾" */
+0x23,0x22,0x23,0xfa,0xaa,0xaa,0xaa,0xaa,0xfa,0xa3,0x22,0x2a,0x3a,0xea,0x45,0x00,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 34879 0x883f "蠿" */
+0x24,0x79,0x14,0x7d,0x00,0xff,0x24,0x79,0x14,0xff,0x10,0x7c,0x54,0x7c,0x12,0xfe,
+0x90,0xe4,0x54,0xfc,0x04,0xfc,0x94,0xe4,0x54,0xfc,0x20,0xf8,0xa8,0xf8,0x24,0xfc,
+/* 34880 0x8840 "血" */
+0x01,0x01,0x02,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 34881 0x8841 "衁" */
+0x02,0x01,0xff,0x10,0x10,0x10,0x1f,0x01,0x02,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 34882 0x8842 "衂" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x01,
+0x00,0x00,0x7e,0x12,0x12,0x52,0x52,0x52,0x52,0x92,0x12,0x22,0xa2,0x42,0x94,0x08,
+/* 34883 0x8843 "衃" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x30,0x58,0x54,0x92,0x12,0x10,0x90,0x10,0x10,0x10,
+/* 34884 0x8844 "衄" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x01,0x00,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x44,0x44,0x44,0x44,0xc4,0x44,0xfe,0x00,
+/* 34885 0x8845 "衅" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x10,0x10,0x94,0x54,0x58,0x10,0xfc,0x10,0x10,0x10,0xfe,0x10,0x90,0x10,0x10,0x10,
+/* 34886 0x8846 "衆" */
+0x04,0x08,0x3f,0x24,0x24,0xff,0x00,0x00,0x7f,0x09,0x11,0x63,0x05,0x19,0xe1,0x01,
+0x00,0x00,0xf8,0x48,0x48,0xfe,0x00,0xf8,0x00,0x04,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 34887 0x8847 "衇" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x01,
+0x04,0x0e,0x70,0x40,0x46,0x58,0x54,0x54,0x56,0x54,0x54,0x54,0xd2,0x92,0x98,0x10,
+/* 34888 0x8848 "衈" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x00,0x7e,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x26,0x7c,0x84,0x04,0x04,0x04,
+/* 34889 0x8849 "衉" */
+0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x57,0xfc,0x00,0x00,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0xc4,0x44,0x7c,0x44,
+/* 34890 0x884a "衊" */
+0x10,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaf,0xf8,0x00,0x01,
+0x24,0xfe,0x24,0x00,0xfe,0xaa,0xaa,0xfe,0x14,0xfe,0x90,0xd2,0xac,0xaa,0x96,0x22,
+/* 34891 0x884b "衋" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7d,0x11,0x7d,0x44,0x7c,0x45,0x7f,0x24,0xff,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0x7c,0x10,0x7c,0x44,0x7c,0x44,0xfc,0x48,0xfe,
+/* 34892 0x884c "行" */
+0x08,0x09,0x10,0x20,0x48,0x08,0x13,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x00,0x00,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 34893 0x884d "衍" */
+0x10,0x12,0x21,0x41,0x80,0x14,0x22,0x62,0xa0,0x21,0x27,0x21,0x21,0x21,0x21,0x20,
+0x00,0x00,0x1c,0x00,0x00,0x00,0x3e,0x88,0x88,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 34894 0x884e "衎" */
+0x10,0x10,0x27,0x41,0x81,0x11,0x21,0x61,0xaf,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
+0x00,0x00,0xdc,0x00,0x00,0x00,0x3e,0x08,0xe8,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 34895 0x884f "衏" */
+0x10,0x10,0x2f,0x40,0x80,0x1f,0x25,0x65,0xa5,0x25,0x25,0x29,0x29,0x30,0x20,0x20,
+0x00,0x00,0x9c,0x00,0x00,0xc0,0x3e,0x08,0x08,0x08,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 34896 0x8850 "衐" */
+0x10,0x10,0x27,0x44,0x84,0x17,0x24,0x64,0xa4,0x27,0x24,0x24,0x27,0x20,0x20,0x20,
+0x00,0x00,0xdc,0x00,0x00,0x80,0xbe,0x88,0x88,0x88,0x08,0x08,0xc8,0x08,0x28,0x10,
+/* 34897 0x8851 "衑" */
+0x11,0x11,0x22,0x42,0x84,0x19,0x20,0x60,0xaf,0x20,0x20,0x25,0x22,0x21,0x21,0x20,
+0x00,0x00,0x9c,0x40,0x20,0x00,0xbe,0x08,0xc8,0x48,0x88,0x08,0x08,0x08,0x28,0x10,
+/* 34898 0x8852 "衒" */
+0x12,0x11,0x20,0x4f,0x82,0x14,0x24,0x68,0xaf,0x21,0x22,0x22,0x24,0x2f,0x20,0x20,
+0x00,0x00,0x1c,0xc0,0x00,0x00,0xbe,0x88,0x08,0x08,0x08,0x08,0x88,0x88,0xa8,0x10,
+/* 34899 0x8853 "術" */
+0x11,0x11,0x21,0x41,0x81,0x17,0x21,0x63,0xa3,0x23,0x25,0x25,0x29,0x21,0x21,0x21,
+0x00,0x80,0x5c,0x40,0x00,0xc0,0x3e,0x08,0x88,0x48,0x48,0x08,0x08,0x08,0x28,0x10,
+/* 34900 0x8854 "衔" */
+0x12,0x12,0x23,0x42,0x84,0x17,0x2a,0x62,0xaf,0x22,0x22,0x22,0x22,0x23,0x22,0x20,
+0x00,0x00,0x9c,0x00,0x00,0x80,0x3e,0x08,0x88,0x08,0x08,0x08,0x88,0x08,0x28,0x10,
+/* 34901 0x8855 "衕" */
+0x20,0x2f,0x48,0x48,0x8b,0x18,0x28,0x6b,0xaa,0x2a,0x2a,0x2b,0x28,0x28,0x28,0x28,
+0x00,0xe0,0x2e,0x20,0xa0,0x20,0x3e,0xa4,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0xb4,0x48,
+/* 34902 0x8856 "衖" */
+0x14,0x14,0x24,0x44,0x9f,0x14,0x24,0x64,0xa4,0x2f,0x20,0x24,0x24,0x28,0x30,0x20,
+0x80,0x80,0x9c,0x80,0xe0,0x80,0xbe,0x88,0x88,0xe8,0x08,0x88,0x48,0x48,0x08,0x18,
+/* 34903 0x8857 "街" */
+0x11,0x11,0x27,0x41,0x81,0x17,0x20,0x61,0xa1,0x27,0x21,0x21,0x21,0x2e,0x24,0x20,
+0x00,0x00,0xdc,0x00,0x00,0xc0,0x3e,0x08,0x08,0xc8,0x08,0x08,0xc8,0x08,0x28,0x10,
+/* 34904 0x8858 "衘" */
+0x14,0x14,0x27,0x49,0x91,0x11,0x2f,0x61,0xa1,0x25,0x25,0x25,0x25,0x3e,0x28,0x20,
+0x00,0x00,0xee,0x00,0x00,0x00,0xde,0x04,0x04,0xc4,0x04,0x04,0xc4,0x04,0x14,0x08,
+/* 34905 0x8859 "衙" */
+0x10,0x1f,0x22,0x42,0x8f,0x14,0x24,0x6f,0xa0,0x20,0x27,0x24,0x24,0x24,0x27,0x24,
+0x00,0xc0,0x1c,0x00,0x80,0x80,0xbe,0xc8,0x08,0x08,0x88,0x88,0x88,0x88,0xa8,0x90,
+/* 34906 0x885a "衚" */
+0x14,0x14,0x24,0x4e,0x84,0x14,0x24,0x6e,0xaa,0x2a,0x2a,0x2a,0x2e,0x21,0x21,0x22,
+0x00,0xe0,0xae,0xa0,0xa0,0xe0,0xbe,0xa4,0xa4,0xe4,0xa4,0xa4,0xa4,0x24,0x34,0x68,
+/* 34907 0x885b "衛" */
+0x12,0x12,0x2f,0x44,0x9f,0x10,0x2f,0x68,0xaf,0x21,0x2f,0x21,0x29,0x2f,0x21,0x21,
+0x00,0x00,0xce,0x40,0xe0,0x00,0xde,0x44,0xc4,0x04,0xc4,0x04,0x04,0xe4,0x14,0x08,
+/* 34908 0x885c "衜" */
+0x14,0x12,0x2f,0x41,0x82,0x17,0x24,0x64,0xa7,0x24,0x24,0x27,0x24,0x24,0x27,0x24,
+0x40,0x80,0xee,0x00,0x00,0xc0,0x5e,0x44,0xc4,0x44,0x44,0xc4,0x44,0x44,0xd4,0x48,
+/* 34909 0x885d "衝" */
+0x10,0x11,0x27,0x41,0x87,0x11,0x27,0x65,0xa7,0x25,0x27,0x21,0x27,0x21,0x2f,0x20,
+0x80,0xc0,0x1c,0x00,0xc0,0x00,0xfe,0x48,0xc8,0x48,0xc8,0x08,0xc8,0x08,0xe8,0x10,
+/* 34910 0x885e "衞" */
+0x11,0x17,0x22,0x4f,0x80,0x17,0x24,0x67,0xa0,0x2f,0x21,0x2f,0x29,0x29,0x29,0x21,
+0x00,0xc0,0x4e,0xe0,0x00,0xc0,0x5e,0xc4,0x04,0xe4,0x04,0xe4,0x24,0x24,0x74,0x08,
+/* 34911 0x885f "衟" */
+0x15,0x15,0x2a,0x45,0x85,0x10,0x2f,0x61,0xa7,0x24,0x27,0x24,0x27,0x24,0x27,0x24,
+0x40,0x40,0x8e,0x40,0x40,0x00,0xde,0x04,0xc4,0x44,0xc4,0x44,0xc4,0x44,0xd4,0x48,
+/* 34912 0x8860 "衠" */
+0x11,0x11,0x2f,0x41,0x87,0x14,0x27,0x64,0xa7,0x24,0x27,0x24,0x2f,0x22,0x24,0x28,
+0x00,0x00,0xee,0x00,0xc0,0x40,0xde,0x44,0xc4,0x44,0xc4,0x44,0xe4,0x84,0x54,0x28,
+/* 34913 0x8861 "衡" */
+0x12,0x13,0x24,0x48,0x87,0x15,0x25,0x67,0xa5,0x25,0x27,0x21,0x2f,0x21,0x22,0x24,
+0x00,0xc0,0x4e,0x80,0xc0,0x40,0x5e,0xc4,0x44,0x44,0xc4,0x04,0xe4,0x04,0x94,0x48,
+/* 34914 0x8862 "衢" */
+0x2e,0x2a,0x4e,0x4a,0x8e,0x1a,0x2e,0x64,0xaf,0x34,0x27,0x24,0x27,0x24,0x27,0x24,
+0xe0,0xa0,0xee,0xa0,0xe0,0xa0,0xfe,0x44,0xf4,0x84,0xe4,0x84,0xe4,0x84,0xf4,0x08,
+/* 34915 0x8863 "衣" */
+0x02,0x01,0x01,0xff,0x02,0x02,0x05,0x05,0x08,0x18,0x28,0x48,0x88,0x0a,0x0c,0x08,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x08,0x90,0xa0,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 34916 0x8864 "衤" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 34917 0x8865 "补" */
+0x10,0x08,0x00,0x7e,0x02,0x04,0x08,0x1a,0x2c,0x4a,0x0a,0x08,0x08,0x08,0x08,0x08,
+0x40,0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 34918 0x8866 "衦" */
+0x20,0x11,0x00,0xf8,0x08,0x10,0x14,0x3b,0x54,0x90,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 34919 0x8867 "衧" */
+0x20,0x11,0x00,0xf8,0x08,0x10,0x14,0x3b,0x54,0x90,0x10,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 34920 0x8868 "表" */
+0x01,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x05,0x08,0x18,0x28,0xc9,0x0a,0x0c,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x88,0x50,0x20,0x18,0x06,0x00,
+/* 34921 0x8869 "衩" */
+0x20,0x13,0x01,0xf9,0x09,0x10,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x11,0x16,
+0x00,0xfc,0x04,0x44,0x24,0xa8,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 34922 0x886a "衪" */
+0x20,0x10,0x00,0xf9,0x09,0x11,0x11,0x37,0x59,0x95,0x15,0x11,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 34923 0x886b "衫" */
+0x10,0x08,0x00,0x7e,0x02,0x04,0x08,0x1a,0x2c,0x4a,0x0a,0x08,0x08,0x08,0x08,0x08,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x20,0xc0,
+/* 34924 0x886c "衬" */
+0x20,0x10,0x00,0xfc,0x09,0x10,0x10,0x34,0x59,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 34925 0x886d "衭" */
+0x20,0x10,0x00,0xfc,0x09,0x10,0x10,0x34,0x5b,0x94,0x14,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34926 0x886e "衮" */
+0x02,0x01,0xff,0x00,0x08,0x12,0x24,0x48,0x1f,0x02,0x04,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x00,0x20,0x10,0x48,0x24,0xf0,0x90,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 34927 0x886f "衯" */
+0x20,0x10,0x00,0xfc,0x09,0x11,0x12,0x35,0x58,0x94,0x14,0x10,0x11,0x11,0x12,0x14,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 34928 0x8870 "衰" */
+0x02,0x01,0xff,0x00,0x1f,0x10,0xff,0x10,0x1f,0x02,0x04,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x00,0xf0,0x10,0xfe,0x10,0xf0,0x80,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 34929 0x8871 "衱" */
+0x20,0x13,0x00,0xf8,0x08,0x10,0x10,0x34,0x59,0x95,0x15,0x11,0x12,0x12,0x14,0x11,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34930 0x8872 "衲" */
+0x20,0x10,0x00,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 34931 0x8873 "衳" */
+0x20,0x10,0x00,0xf8,0x08,0x11,0x15,0x3a,0x54,0x90,0x10,0x10,0x11,0x13,0x11,0x10,
+0x10,0x90,0x90,0x88,0x88,0x24,0x24,0x22,0x40,0x40,0x88,0x84,0x04,0xfe,0x02,0x00,
+/* 34932 0x8874 "衴" */
+0x20,0x10,0x00,0xfd,0x09,0x12,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 34933 0x8875 "衵" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34934 0x8876 "衶" */
+0x20,0x10,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 34935 0x8877 "衷" */
+0x02,0x01,0xff,0x01,0x3f,0x21,0x21,0x3f,0x01,0x02,0x04,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x00,0x80,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 34936 0x8878 "衸" */
+0x20,0x10,0x00,0xf8,0x09,0x12,0x14,0x31,0x55,0x99,0x15,0x11,0x11,0x12,0x12,0x14,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 34937 0x8879 "衹" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0x86,0x02,
+/* 34938 0x887a "衺" */
+0x02,0x01,0xff,0x00,0x7f,0x20,0x3f,0x02,0x0d,0x70,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0x00,0xfe,0x00,0xfc,0x40,0xfe,0x40,0x40,0x80,0x08,0x90,0x60,0x18,0x06,0x00,
+/* 34939 0x887b "衻" */
+0x20,0x10,0x00,0xfc,0x08,0x11,0x10,0x34,0x58,0x95,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0xfe,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 34940 0x887c "衼" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x10,0x35,0x58,0x94,0x14,0x10,0x10,0x10,0x11,0x16,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 34941 0x887d "衽" */
+0x20,0x10,0x01,0xfc,0x08,0x10,0x10,0x35,0x58,0x94,0x14,0x10,0x10,0x10,0x11,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 34942 0x887e "衾" */
+0x01,0x02,0x04,0x09,0x30,0xcf,0x00,0x02,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x80,0x40,0x20,0x98,0xe6,0x40,0x80,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34943 0x887f "衿" */
+0x20,0x10,0x00,0xfc,0x08,0x11,0x12,0x34,0x58,0x95,0x14,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 34944 0x8880 "袀" */
+0x20,0x10,0x00,0xfc,0x09,0x12,0x10,0x34,0x58,0x94,0x14,0x10,0x11,0x10,0x10,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 34945 0x8881 "袁" */
+0x01,0x01,0x3f,0x01,0xff,0x00,0x1f,0x10,0x10,0x1f,0x05,0x08,0x38,0xca,0x0c,0x08,
+0x00,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x04,0x88,0x50,0x20,0x18,0x06,
+/* 34946 0x8882 "袂" */
+0x20,0x10,0x00,0xf9,0x08,0x10,0x14,0x38,0x55,0x90,0x10,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34947 0x8883 "袃" */
+0x20,0x21,0x2c,0xf0,0x20,0x24,0x29,0x32,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0xfc,0x44,0x44,0x84,0x84,0x14,0x08,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34948 0x8884 "袄" */
+0x20,0x10,0x01,0xfc,0x08,0x10,0x11,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x11,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34949 0x8885 "袅" */
+0x04,0x1f,0x14,0x12,0x10,0x1f,0x00,0x02,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0xe0,0x20,0xa0,0x40,0xfc,0x04,0x14,0x08,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34950 0x8886 "袆" */
+0x20,0x10,0x00,0xfd,0x08,0x10,0x10,0x34,0x58,0x95,0x14,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 34951 0x8887 "袇" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x10,0x34,0x59,0x94,0x14,0x10,0x10,0x11,0x11,0x12,
+0x00,0xfc,0x84,0x84,0xa4,0x94,0x94,0x84,0xfe,0x84,0x84,0x84,0x84,0x04,0x14,0x08,
+/* 34952 0x8888 "袈" */
+0x08,0x08,0x7f,0x09,0x11,0x11,0x25,0x42,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34953 0x8889 "袉" */
+0x20,0x10,0x00,0xf9,0x09,0x12,0x10,0x34,0x58,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 34954 0x888a "袊" */
+0x20,0x10,0x00,0xf8,0x08,0x11,0x12,0x30,0x55,0x98,0x14,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 34955 0x888b "袋" */
+0x08,0x10,0x30,0x57,0x90,0x10,0x10,0x12,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0xa0,0x90,0xbe,0xc0,0x40,0x24,0x14,0x0c,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34956 0x888c "袌" */
+0x01,0xff,0x08,0x1f,0x20,0x5f,0x10,0x1f,0x10,0x0f,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf0,0x10,0x90,0xd0,0xa0,0x04,0xfc,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34957 0x888d "袍" */
+0x20,0x10,0x01,0xf9,0x0a,0x15,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 34958 0x888e "袎" */
+0x20,0x11,0x01,0xf2,0x12,0x24,0x27,0x69,0xb2,0x2a,0x24,0x27,0x20,0x20,0x20,0x21,
+0x20,0x20,0x20,0x20,0xfc,0xa4,0x24,0x24,0x24,0x24,0xa4,0xa4,0xc4,0x44,0x94,0x08,
+/* 34959 0x888f "袏" */
+0x20,0x10,0x00,0xfc,0x0b,0x10,0x10,0x34,0x58,0x95,0x15,0x12,0x12,0x14,0x11,0x10,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x80,0xfe,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 34960 0x8890 "袐" */
+0x20,0x10,0x00,0xf8,0x08,0x10,0x14,0x3a,0x56,0x92,0x14,0x10,0x11,0x12,0x14,0x10,
+0x00,0x40,0x20,0x28,0x08,0x88,0x90,0x94,0xa2,0xa2,0xc2,0x88,0x88,0x88,0x78,0x00,
+/* 34961 0x8891 "袑" */
+0x20,0x13,0x00,0xf8,0x08,0x11,0x15,0x3a,0x54,0x91,0x11,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34962 0x8892 "袒" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x10,0x10,0x13,0x10,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 34963 0x8893 "袓" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x17,0x10,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 34964 0x8894 "袔" */
+0x20,0x10,0x03,0xf8,0x08,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 34965 0x8895 "袕" */
+0x20,0x10,0x00,0xfb,0x0a,0x14,0x10,0x34,0x58,0x94,0x14,0x11,0x11,0x11,0x12,0x14,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 34966 0x8896 "袖" */
+0x20,0x10,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 34967 0x8897 "袗" */
+0x20,0x10,0x00,0xfc,0x09,0x12,0x10,0x34,0x59,0x94,0x14,0x10,0x11,0x10,0x10,0x13,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 34968 0x8898 "袘" */
+0x20,0x10,0x00,0xfd,0x0a,0x11,0x11,0x35,0x5b,0x95,0x15,0x11,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 34969 0x8899 "袙" */
+0x20,0x10,0x00,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34970 0x889a "袚" */
+0x20,0x10,0x00,0xfc,0x0b,0x10,0x10,0x34,0x59,0x95,0x15,0x11,0x12,0x12,0x14,0x11,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34971 0x889b "袛" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 34972 0x889c "袜" */
+0x20,0x10,0x00,0xfd,0x08,0x10,0x10,0x35,0x58,0x94,0x14,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 34973 0x889d "袝" */
+0x20,0x10,0x00,0xf9,0x09,0x13,0x15,0x31,0x55,0x99,0x15,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 34974 0x889e "袞" */
+0x02,0x01,0xff,0x08,0x10,0x20,0x5f,0x10,0x10,0x1f,0x04,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x20,0x10,0x08,0xf4,0x10,0x10,0xf0,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 34975 0x889f "袟" */
+0x20,0x10,0x01,0xf9,0x09,0x11,0x12,0x30,0x55,0x98,0x14,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 34976 0x88a0 "袠" */
+0x02,0x01,0xff,0x11,0x1f,0x22,0x7f,0x04,0x08,0x32,0xc4,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x00,0xf8,0x00,0xfc,0x80,0x60,0x98,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 34977 0x88a1 "袡" */
+0x20,0x10,0x00,0xf9,0x09,0x11,0x15,0x39,0x55,0x91,0x13,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0xfe,0x04,0x04,0x04,0x14,0x08,
+/* 34978 0x88a2 "袢" */
+0x20,0x10,0x01,0xf8,0x08,0x10,0x15,0x38,0x54,0x90,0x13,0x10,0x10,0x10,0x10,0x10,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 34979 0x88a3 "袣" */
+0x20,0x11,0x01,0xf9,0x09,0x13,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x10,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 34980 0x88a4 "袤" */
+0x01,0xff,0x00,0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34981 0x88a5 "袥" */
+0x20,0x10,0x03,0xf8,0x08,0x10,0x14,0x38,0x55,0x92,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 34982 0x88a6 "袦" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x34,0x58,0x95,0x15,0x11,0x11,0x11,0x11,0x10,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 34983 0x88a7 "袧" */
+0x20,0x10,0x01,0xf9,0x0a,0x14,0x11,0x35,0x59,0x95,0x15,0x11,0x10,0x10,0x10,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 34984 0x88a8 "袨" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x10,0x35,0x5b,0x94,0x14,0x10,0x11,0x13,0x11,0x10,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x88,0x08,0xf0,0x20,0x40,0x88,0x04,0xfc,0x04,0x00,
+/* 34985 0x88a9 "袩" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x10,0x34,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 34986 0x88aa "袪" */
+0x20,0x10,0x00,0xf9,0x08,0x10,0x14,0x3b,0x54,0x90,0x10,0x10,0x11,0x13,0x11,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 34987 0x88ab "被" */
+0x20,0x10,0x00,0xf9,0x09,0x11,0x15,0x39,0x55,0x91,0x11,0x11,0x11,0x12,0x12,0x14,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 34988 0x88ac "袬" */
+0x02,0x01,0xff,0x08,0x10,0x3f,0x00,0x1f,0x10,0x10,0x1f,0x04,0x08,0x38,0xcb,0x0c,
+0x00,0x00,0xfe,0x00,0x10,0xf8,0x08,0xf0,0x10,0x10,0xf0,0x88,0x50,0x20,0x18,0x06,
+/* 34989 0x88ad "袭" */
+0x04,0x04,0xff,0x09,0x11,0x21,0x4f,0x82,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x40,0x20,0xfe,0x10,0x60,0x84,0x04,0xfc,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34990 0x88ae "袮" */
+0x20,0x10,0x00,0xf9,0x09,0x12,0x14,0x30,0x55,0x99,0x16,0x12,0x14,0x10,0x10,0x10,
+0x80,0x80,0x80,0xfe,0x00,0x00,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 34991 0x88af "袯" */
+0x20,0x10,0x02,0xfa,0x0b,0x10,0x14,0x38,0x55,0x91,0x11,0x12,0x12,0x14,0x18,0x13,
+0x40,0x48,0x44,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 34992 0x88b0 "袰" */
+0x1f,0x12,0x11,0xff,0x12,0x21,0x3f,0x00,0x02,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0xf0,0x10,0x10,0xfe,0x10,0x10,0xfc,0x10,0xa0,0x40,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 34993 0x88b1 "袱" */
+0x20,0x10,0x00,0xf9,0x09,0x13,0x15,0x31,0x55,0x99,0x15,0x11,0x11,0x11,0x11,0x11,
+0x90,0x94,0x92,0x12,0x10,0x7e,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 34994 0x88b2 "袲" */
+0x01,0xff,0x02,0x0f,0x34,0x07,0x38,0x03,0x1d,0x01,0x3f,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xe0,0xc0,0x00,0x80,0xf8,0x30,0xc0,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 34995 0x88b3 "袳" */
+0x20,0x10,0x00,0xfc,0x09,0x10,0x10,0x34,0x59,0x94,0x14,0x11,0x10,0x10,0x10,0x11,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 34996 0x88b4 "袴" */
+0x20,0x10,0x03,0xfc,0x08,0x11,0x12,0x34,0x5b,0x94,0x14,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 34997 0x88b5 "袵" */
+0x20,0x10,0x00,0xf9,0x09,0x13,0x15,0x31,0x55,0x99,0x15,0x11,0x11,0x11,0x11,0x11,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 34998 0x88b6 "袶" */
+0x20,0x10,0x00,0xf9,0x0a,0x10,0x11,0x36,0x58,0x95,0x14,0x12,0x13,0x10,0x10,0x10,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 34999 0x88b7 "袷" */
+0x20,0x10,0x00,0xf8,0x09,0x12,0x11,0x34,0x58,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35000 0x88b8 "袸" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x11,0x35,0x5b,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x40,0x40,0x40,0xfe,0x80,0x80,0x78,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 35001 0x88b9 "袹" */
+0x20,0x13,0x00,0xfc,0x08,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35002 0x88ba "袺" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x11,0x34,0x58,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35003 0x88bb "袻" */
+0x20,0x13,0x00,0xfc,0x08,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 35004 0x88bc "袼" */
+0x20,0x10,0x00,0xf9,0x0b,0x14,0x10,0x34,0x59,0x96,0x15,0x11,0x11,0x11,0x11,0x11,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 35005 0x88bd "袽" */
+0x41,0x21,0x21,0x01,0xf7,0x12,0x22,0x6a,0xb2,0x2c,0x22,0x21,0x22,0x22,0x24,0x28,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x12,0x92,0x5e,0x52,0x00,
+/* 35006 0x88be "袾" */
+0x20,0x11,0x01,0xf9,0x09,0x12,0x10,0x33,0x54,0x98,0x14,0x11,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 35007 0x88bf "袿" */
+0x20,0x10,0x01,0xf8,0x08,0x10,0x13,0x30,0x54,0x98,0x15,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35008 0x88c0 "裀" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x02,0x22,0x22,0x22,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0xfe,0x02,
+/* 35009 0x88c1 "裁" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x10,0x08,0xff,0x10,0x29,0x66,0xa2,0x29,0x30,0x20,
+0x40,0x48,0x44,0x44,0x40,0xfe,0x40,0x44,0x44,0x44,0x28,0x2a,0x12,0x2a,0x46,0x82,
+/* 35010 0x88c2 "裂" */
+0x00,0x7f,0x08,0x1f,0x21,0x52,0x0c,0x30,0xc2,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x04,0x0c,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35011 0x88c3 "裃" */
+0x20,0x10,0x00,0xfc,0x08,0x13,0x10,0x34,0x5b,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7c,0x40,0x40,0xfe,0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x40,0x40,0x40,
+/* 35012 0x88c4 "裄" */
+0x20,0x10,0x00,0xf9,0x0a,0x10,0x10,0x35,0x5a,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x40,0x40,0x9c,0x00,0x40,0x40,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0xa8,0x90,
+/* 35013 0x88c5 "装" */
+0x08,0x48,0x2b,0x08,0x18,0x28,0xc9,0x0a,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35014 0x88c6 "裆" */
+0x20,0x11,0x00,0xfc,0x08,0x10,0x13,0x34,0x58,0x94,0x15,0x10,0x10,0x10,0x13,0x10,
+0x20,0x24,0xa4,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35015 0x88c7 "裇" */
+0x20,0x10,0x00,0xf8,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x13,0x10,
+0x20,0x20,0x40,0x80,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35016 0x88c8 "裈" */
+0x20,0x13,0x02,0xfc,0x08,0x13,0x10,0x34,0x59,0x95,0x14,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35017 0x88c9 "裉" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 35018 0x88ca "裊" */
+0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3f,0x04,0x1c,0x65,0x06,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x04,0xec,0x80,0x48,0x30,0x0e,
+/* 35019 0x88cb "裋" */
+0x20,0x13,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x94,0x15,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x88,0x90,0x00,0xfe,0x00,
+/* 35020 0x88cc "裌" */
+0x20,0x10,0x00,0xfb,0x08,0x10,0x11,0x35,0x59,0x96,0x14,0x10,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 35021 0x88cd "裍" */
+0x20,0x13,0x02,0xfa,0x0a,0x13,0x16,0x3a,0x56,0x92,0x13,0x12,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x22,0x22,0x22,0xfe,0x22,0x62,0x72,0xaa,0x22,0x22,0x22,0x02,0xfe,0x02,
+/* 35022 0x88ce "裎" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x10,0x34,0x59,0x94,0x14,0x11,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 35023 0x88cf "裏" */
+0x01,0xff,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x1f,0x01,0x7f,0x04,0x0c,0x35,0xc6,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x00,0xfc,0x88,0x50,0x30,0x0e,
+/* 35024 0x88d0 "裐" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,
+/* 35025 0x88d1 "裑" */
+0x20,0x10,0x01,0xf9,0x09,0x11,0x15,0x39,0x55,0x93,0x10,0x10,0x10,0x11,0x16,0x10,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xfa,0x0a,0x0c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 35026 0x88d2 "裒" */
+0x02,0x01,0xff,0x04,0x38,0x20,0x3c,0x20,0x3f,0x02,0x04,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x00,0xfe,0x00,0x78,0x08,0x78,0x08,0xf8,0x80,0x44,0x28,0x10,0x08,0x06,0x00,
+/* 35027 0x88d3 "裓" */
+0x20,0x10,0x00,0xf8,0x0b,0x10,0x15,0x39,0x57,0x91,0x11,0x11,0x12,0x12,0x14,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x50,0x54,0xf4,0x54,0x54,0x48,0x4a,0x5a,0x26,0x42,
+/* 35028 0x88d4 "裔" */
+0x02,0x01,0xff,0x04,0x08,0x3a,0xcc,0x08,0x3f,0x24,0x28,0x37,0x24,0x27,0x20,0x20,
+0x00,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,0xf8,0x48,0x28,0xd8,0x48,0xc8,0x28,0x10,
+/* 35029 0x88d5 "裕" */
+0x20,0x10,0x00,0xfc,0x09,0x10,0x10,0x34,0x59,0x94,0x14,0x10,0x10,0x10,0x10,0x10,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 35030 0x88d6 "裖" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 35031 0x88d7 "裗" */
+0x20,0x10,0x03,0xf8,0x08,0x11,0x13,0x30,0x55,0x99,0x15,0x11,0x12,0x12,0x14,0x18,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 35032 0x88d8 "裘" */
+0x01,0x01,0x7f,0x11,0x09,0x05,0x19,0x62,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x20,0x10,0xfc,0x10,0xa0,0x40,0x30,0x08,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35033 0x88d9 "裙" */
+0x20,0x11,0x00,0xf8,0x0b,0x10,0x10,0x35,0x58,0x94,0x15,0x12,0x14,0x10,0x10,0x10,
+0x00,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x80,0x80,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 35034 0x88da "裚" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35035 0x88db "裛" */
+0x01,0xff,0x00,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x20,0x1f,0x04,0x18,0xeb,0x0c,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x02,0xfe,0x88,0x50,0x30,0x0e,
+/* 35036 0x88dc "補" */
+0x20,0x10,0x03,0xf8,0x08,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 35037 0x88dd "裝" */
+0x24,0x24,0x3c,0x05,0xfc,0x24,0x24,0x46,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xf8,0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35038 0x88de "裞" */
+0x21,0x10,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x94,0x14,0x10,0x10,0x11,0x12,0x14,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 35039 0x88df "裟" */
+0x10,0x08,0x40,0x24,0x09,0x72,0x10,0x10,0x07,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0x20,0x20,0xa8,0xa4,0x22,0x28,0x30,0xc0,0x00,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35040 0x88e0 "裠" */
+0x3f,0x02,0xff,0x04,0x3f,0x08,0x1f,0x28,0xcf,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0xf8,0x08,0xfe,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35041 0x88e1 "裡" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x58,0x94,0x15,0x10,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35042 0x88e2 "裢" */
+0x20,0x12,0x01,0xf9,0x08,0x10,0x17,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x14,0x10,
+0x10,0x10,0x10,0x7e,0x20,0x28,0x48,0x7e,0x08,0x08,0xfe,0x08,0x08,0x88,0x7e,0x00,
+/* 35043 0x88e3 "裣" */
+0x20,0x10,0x00,0xf8,0x09,0x12,0x11,0x34,0x58,0x94,0x11,0x10,0x10,0x10,0x13,0x10,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x44,0x24,0x24,0xa8,0x88,0x10,0xfe,0x00,
+/* 35044 0x88e4 "裤" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x10,0x08,0xfe,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x08,0xfe,0x08,0x08,0x08,
+/* 35045 0x88e5 "裥" */
+0x21,0x10,0x02,0xf2,0x12,0x22,0x22,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,
+0x00,0xbe,0x82,0x02,0x02,0xfa,0x8a,0x8a,0xfa,0x8a,0x8a,0xfa,0x02,0x02,0x0a,0x04,
+/* 35046 0x88e6 "裦" */
+0x01,0xff,0x00,0x19,0x60,0x40,0x7b,0x40,0x41,0x7a,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0x60,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35047 0x88e7 "裧" */
+0x20,0x10,0x00,0xf9,0x08,0x10,0x13,0x30,0x54,0x98,0x14,0x11,0x10,0x10,0x11,0x12,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 35048 0x88e8 "裨" */
+0x20,0x10,0x03,0xfa,0x0a,0x13,0x16,0x3a,0x57,0x90,0x11,0x17,0x10,0x10,0x10,0x10,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 35049 0x88e9 "裩" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x58,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 35050 0x88ea "裪" */
+0x20,0x10,0x00,0xfd,0x0a,0x10,0x11,0x34,0x5b,0x94,0x15,0x11,0x11,0x10,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x82,0xf2,0x42,0x42,0xfa,0x42,0x52,0x52,0xf2,0x02,0x14,0x08,
+/* 35051 0x88eb "裫" */
+0x20,0x12,0x02,0xf2,0x13,0x22,0x22,0x6b,0xb2,0x2a,0x23,0x22,0x22,0x22,0x24,0x28,
+0x50,0x52,0x52,0x52,0xde,0x02,0x02,0xfe,0x02,0x02,0xde,0x52,0x52,0x52,0x52,0x02,
+/* 35052 0x88ec "裬" */
+0x20,0x10,0x01,0xfc,0x08,0x13,0x10,0x35,0x5a,0x94,0x15,0x12,0x10,0x10,0x11,0x16,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 35053 0x88ed "裭" */
+0x20,0x10,0x00,0xfc,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x12,0x12,0x14,0x19,
+0x20,0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 35054 0x88ee "裮" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x10,0x34,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 35055 0x88ef "裯" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 35056 0x88f0 "裰" */
+0x20,0x17,0x00,0xf2,0x11,0x22,0x24,0x68,0xb0,0x2f,0x20,0x22,0x21,0x22,0x24,0x28,
+0x00,0xbc,0x84,0x94,0x08,0x94,0xa4,0x40,0x00,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 35057 0x88f1 "裱" */
+0x20,0x10,0x03,0xf8,0x08,0x11,0x10,0x34,0x5b,0x94,0x14,0x11,0x12,0x14,0x10,0x10,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 35058 0x88f2 "裲" */
+0x20,0x13,0x00,0xf0,0x13,0x22,0x22,0x6b,0xb2,0x2a,0x23,0x22,0x22,0x22,0x22,0x22,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 35059 0x88f3 "裳" */
+0x01,0x11,0x09,0x7f,0x40,0x9f,0x10,0x1f,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35060 0x88f4 "裴" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x06,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35061 0x88f5 "裵" */
+0x02,0x01,0xff,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0x00,0xfe,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x08,0x90,0x60,0x18,0x06,0x00,
+/* 35062 0x88f6 "裶" */
+0x20,0x10,0x00,0xf7,0x10,0x20,0x20,0x6b,0xb0,0x28,0x20,0x27,0x20,0x20,0x20,0x20,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 35063 0x88f7 "裷" */
+0x20,0x11,0x00,0xf8,0x09,0x10,0x17,0x38,0x55,0x92,0x14,0x10,0x10,0x10,0x10,0x10,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 35064 0x88f8 "裸" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x15,0x39,0x54,0x93,0x10,0x10,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 35065 0x88f9 "裹" */
+0x01,0xff,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x13,0x65,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0x88,0x50,0x30,0x0e,0x00,
+/* 35066 0x88fa "裺" */
+0x20,0x10,0x03,0xf8,0x08,0x11,0x12,0x31,0x55,0x99,0x15,0x11,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 35067 0x88fb "裻" */
+0x08,0x0e,0x08,0x7f,0x08,0x2a,0x49,0x1a,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x00,0x7c,0x04,0x44,0x28,0x10,0x28,0x44,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35068 0x88fc "裼" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x15,0x39,0x54,0x91,0x12,0x14,0x11,0x12,0x10,0x11,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x54,0x94,0x24,0x44,0x94,0x08,
+/* 35069 0x88fd "製" */
+0x24,0x3f,0x44,0xff,0x04,0x3f,0x24,0x25,0x02,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0x04,0xa4,0x24,0xa4,0x24,0x84,0x94,0x88,0x00,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35070 0x88fe "裾" */
+0x20,0x13,0x02,0xf2,0x13,0x22,0x22,0x6b,0xb2,0x2a,0x22,0x22,0x22,0x24,0x24,0x28,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 35071 0x88ff "裿" */
+0x20,0x10,0x01,0xfc,0x08,0x11,0x13,0x34,0x59,0x95,0x15,0x11,0x11,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 35072 0x8900 "褀" */
+0x20,0x10,0x03,0xfc,0x08,0x10,0x10,0x34,0x58,0x94,0x14,0x13,0x10,0x10,0x11,0x12,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 35073 0x8901 "褁" */
+0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x09,0x11,0x63,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x20,0x10,0x08,0x90,0x60,0x18,0x06,0x00,
+/* 35074 0x8902 "褂" */
+0x21,0x11,0x07,0xf1,0x11,0x21,0x2f,0x68,0xb1,0x29,0x27,0x21,0x21,0x21,0x2e,0x24,
+0x10,0x10,0xd0,0x10,0x10,0x18,0xf4,0x12,0x12,0x10,0xd0,0x10,0x10,0xd0,0x10,0x10,
+/* 35075 0x8903 "褃" */
+0x20,0x11,0x01,0xfd,0x09,0x13,0x10,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 35076 0x8904 "褄" */
+0x20,0x10,0x03,0xf8,0x09,0x10,0x13,0x34,0x59,0x94,0x17,0x10,0x11,0x10,0x10,0x13,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x40,0xfe,0x84,0xc8,0x30,0xcc,0x02,
+/* 35077 0x8905 "褅" */
+0x20,0x10,0x01,0xf8,0x08,0x10,0x13,0x32,0x54,0x99,0x15,0x11,0x11,0x11,0x10,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 35078 0x8906 "褆" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x11,0x35,0x58,0x97,0x14,0x11,0x11,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 35079 0x8907 "複" */
+0x21,0x11,0x01,0xfa,0x0d,0x11,0x11,0x35,0x59,0x94,0x14,0x11,0x12,0x10,0x11,0x16,
+0x00,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,
+/* 35080 0x8908 "褈" */
+0x20,0x10,0x01,0xf8,0x0b,0x10,0x11,0x35,0x59,0x95,0x15,0x10,0x11,0x10,0x13,0x10,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 35081 0x8909 "褉" */
+0x21,0x11,0x07,0xf1,0x13,0x21,0x27,0x69,0xb1,0x28,0x27,0x20,0x20,0x21,0x22,0x2c,
+0x00,0x3c,0xd4,0x14,0x94,0x14,0xd4,0x24,0x4c,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 35082 0x890a "褊" */
+0x20,0x10,0x03,0xf2,0x12,0x23,0x22,0x6a,0xb3,0x2b,0x23,0x25,0x25,0x25,0x29,0x21,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x44,0x0c,
+/* 35083 0x890b "褋" */
+0x20,0x11,0x01,0xfb,0x09,0x11,0x15,0x39,0x55,0x90,0x13,0x10,0x10,0x11,0x16,0x10,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35084 0x890c "褌" */
+0x20,0x13,0x02,0xf8,0x0b,0x10,0x11,0x35,0x59,0x95,0x15,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35085 0x890d "褍" */
+0x20,0x11,0x01,0xfd,0x09,0x10,0x13,0x34,0x58,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 35086 0x890e "褎" */
+0x02,0x01,0xff,0x00,0x0c,0x30,0x21,0x3c,0x21,0x3c,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0x00,0xfe,0x18,0xe0,0x20,0xfc,0xa8,0x24,0x20,0x08,0x90,0x60,0x18,0x06,0x00,
+/* 35087 0x890f "褏" */
+0x01,0xff,0x00,0x0c,0x31,0x21,0x3d,0x21,0x21,0x3d,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0xfc,0x24,0x24,0xfc,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35088 0x8910 "褐" */
+0x20,0x13,0x02,0xf3,0x12,0x23,0x21,0x6b,0xb4,0x2a,0x22,0x22,0x23,0x20,0x20,0x20,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 35089 0x8911 "褑" */
+0x20,0x13,0x00,0xfd,0x08,0x11,0x10,0x34,0x5b,0x94,0x14,0x11,0x11,0x12,0x10,0x11,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 35090 0x8912 "褒" */
+0x01,0xff,0x08,0x0b,0x12,0x33,0x50,0x97,0x11,0x12,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf8,0x08,0xf8,0x40,0xfe,0x50,0x48,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35091 0x8913 "褓" */
+0x21,0x11,0x01,0xf2,0x12,0x26,0x2a,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x23,0x22,0x22,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0xfe,0x38,0x54,0x54,0x94,0x12,0x10,0x10,
+/* 35092 0x8914 "褔" */
+0x20,0x13,0x00,0xf9,0x09,0x11,0x15,0x38,0x57,0x92,0x12,0x13,0x12,0x12,0x13,0x12,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 35093 0x8915 "褕" */
+0x20,0x10,0x01,0xf2,0x15,0x20,0x23,0x6a,0xb2,0x2b,0x22,0x22,0x23,0x22,0x22,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 35094 0x8916 "褖" */
+0x20,0x10,0x01,0xfd,0x08,0x13,0x10,0x34,0x5b,0x94,0x14,0x13,0x10,0x10,0x13,0x10,
+0x80,0xfc,0x04,0xf8,0x08,0xfe,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 35095 0x8917 "褗" */
+0x20,0x13,0x02,0xfa,0x0a,0x12,0x16,0x3a,0x56,0x93,0x12,0x12,0x12,0x12,0x12,0x13,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 35096 0x8918 "褘" */
+0x20,0x10,0x01,0xf8,0x0b,0x10,0x15,0x39,0x55,0x90,0x13,0x10,0x12,0x13,0x10,0x10,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 35097 0x8919 "褙" */
+0x20,0x10,0x03,0xf8,0x08,0x13,0x10,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x50,0x52,0xdc,0x50,0xd2,0x4e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 35098 0x891a "褚" */
+0x20,0x10,0x01,0xf8,0x08,0x13,0x14,0x38,0x54,0x91,0x12,0x10,0x10,0x10,0x10,0x10,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 35099 0x891b "褛" */
+0x20,0x11,0x00,0xf0,0x13,0x20,0x21,0x6a,0xb0,0x2b,0x20,0x21,0x21,0x20,0x21,0x26,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 35100 0x891c "褜" */
+0x00,0x79,0x4a,0x7d,0x49,0x79,0x49,0x49,0x9a,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0x80,0xf8,0x08,0xe8,0x28,0xe8,0x14,0x04,0xfc,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35101 0x891d "褝" */
+0x21,0x10,0x00,0xf9,0x09,0x11,0x11,0x35,0x59,0x95,0x14,0x10,0x13,0x10,0x10,0x10,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35102 0x891e "褞" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x15,0x39,0x54,0x93,0x12,0x12,0x12,0x12,0x17,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 35103 0x891f "褟" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x14,0x3b,0x54,0x92,0x11,0x10,0x13,0x10,0x11,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 35104 0x8920 "褠" */
+0x20,0x10,0x03,0xfc,0x09,0x10,0x13,0x34,0x59,0x95,0x15,0x11,0x13,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 35105 0x8921 "褡" */
+0x20,0x10,0x03,0xf8,0x08,0x10,0x14,0x39,0x56,0x90,0x10,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 35106 0x8922 "褢" */
+0x01,0xff,0x02,0x1f,0x11,0x1f,0x12,0x1f,0x04,0x08,0x33,0xc4,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0xa8,0xba,0x82,0xfe,0x50,0x30,0x0e,0x00,
+/* 35107 0x8923 "褣" */
+0x20,0x10,0x03,0xfa,0x08,0x10,0x15,0x38,0x54,0x91,0x12,0x10,0x10,0x10,0x10,0x10,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 35108 0x8924 "褤" */
+0x20,0x10,0x01,0xf8,0x0b,0x10,0x11,0x35,0x59,0x95,0x14,0x10,0x11,0x16,0x10,0x10,
+0x20,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x52,0x94,0x88,0xa4,0xc2,0x80,
+/* 35109 0x8925 "褥" */
+0x20,0x13,0x02,0xf2,0x12,0x23,0x22,0x6a,0xb2,0x2a,0x22,0x23,0x22,0x24,0x24,0x28,
+0x00,0xfe,0x00,0xfc,0x00,0xfe,0xa8,0x90,0xc8,0x86,0x08,0xfe,0x88,0x48,0x08,0x18,
+/* 35110 0x8926 "褦" */
+0x21,0x12,0x04,0xf7,0x10,0x20,0x27,0x6c,0xb4,0x2f,0x24,0x24,0x27,0x24,0x25,0x24,
+0x10,0x12,0x54,0xd8,0x10,0x12,0xd2,0x4e,0x40,0xd2,0x54,0x58,0xd0,0x52,0x52,0x8e,
+/* 35111 0x8927 "褧" */
+0x7e,0x24,0x3c,0x24,0x3c,0x27,0xfc,0x06,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x00,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35112 0x8928 "褨" */
+0x21,0x10,0x00,0xfb,0x08,0x11,0x14,0x3b,0x54,0x91,0x11,0x12,0x14,0x18,0x13,0x10,
+0x08,0x88,0x90,0xfc,0x40,0xf8,0x40,0xfe,0x80,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35113 0x8929 "褩" */
+0x10,0x3e,0x22,0x2a,0xfe,0x23,0x2a,0x42,0x4a,0x86,0x01,0xff,0x06,0x1c,0xe5,0x06,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0x00,0xfe,0x80,0x48,0x30,0x0e,
+/* 35114 0x892a "褪" */
+0x20,0x12,0x01,0xf9,0x08,0x10,0x17,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x12,0x14,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x50,0x4a,0x44,0x54,0x62,0x42,0x80,0x7e,
+/* 35115 0x892b "褫" */
+0x20,0x10,0x03,0xf2,0x12,0x22,0x22,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x24,0x25,0x2a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 35116 0x892c "褬" */
+0x21,0x10,0x00,0xf1,0x10,0x23,0x22,0x69,0xb2,0x28,0x23,0x20,0x20,0x21,0x26,0x20,
+0xf8,0x88,0x70,0x8c,0x00,0xde,0x52,0x8c,0x52,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35117 0x892d "褭" */
+0x01,0xff,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x29,0x44,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x22,0x96,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35118 0x892e "褮" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x82,0x01,0xff,0x05,0x0c,0x34,0xc5,0x06,0x04,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0x04,0x00,0xfe,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35119 0x892f "褯" */
+0x20,0x10,0x07,0xf4,0x14,0x27,0x24,0x6c,0xb4,0x2d,0x25,0x25,0x29,0x29,0x30,0x20,
+0x40,0x20,0xfe,0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 35120 0x8930 "褰" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x0a,0x11,0x2f,0xc2,0x04,0x1c,0x65,0x06,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0x10,0xe8,0x8e,0x50,0x20,0x18,0x06,
+/* 35121 0x8931 "褱" */
+0x02,0x01,0xff,0x00,0x3f,0x24,0x3f,0x11,0x09,0x11,0x23,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0x00,0xfe,0x00,0xf8,0x48,0xf8,0x10,0x20,0x10,0x08,0x90,0x60,0x18,0x06,0x00,
+/* 35122 0x8932 "褲" */
+0x20,0x10,0x01,0xfd,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 35123 0x8933 "褳" */
+0x20,0x10,0x02,0xf9,0x09,0x10,0x14,0x3b,0x55,0x91,0x11,0x11,0x11,0x12,0x14,0x10,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 35124 0x8934 "褴" */
+0x20,0x11,0x01,0xf9,0x09,0x11,0x11,0x34,0x58,0x95,0x15,0x11,0x11,0x11,0x17,0x10,
+0x48,0x48,0x4e,0x50,0x68,0x44,0x44,0x40,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35125 0x8935 "褵" */
+0x20,0x10,0x03,0xf8,0x09,0x11,0x15,0x39,0x54,0x93,0x12,0x12,0x12,0x12,0x12,0x12,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 35126 0x8936 "褶" */
+0x20,0x13,0x00,0xfa,0x09,0x12,0x10,0x34,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35127 0x8937 "褷" */
+0x22,0x12,0x04,0xf9,0x11,0x22,0x26,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x23,0x22,
+0x10,0x10,0x50,0x5c,0x50,0x50,0xfe,0x00,0x10,0x50,0x5c,0x50,0xb0,0x90,0x0e,0x00,
+/* 35128 0x8938 "褸" */
+0x20,0x11,0x01,0xfb,0x09,0x11,0x14,0x39,0x55,0x91,0x10,0x13,0x10,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 35129 0x8939 "褹" */
+0x21,0x11,0x07,0xf1,0x11,0x27,0x20,0x6a,0xb5,0x29,0x27,0x21,0x21,0x21,0x27,0x22,
+0x10,0x10,0xd0,0x10,0x3c,0xd4,0x14,0xb4,0x54,0x1c,0xd4,0x14,0x14,0xe4,0x26,0x42,
+/* 35130 0x893a "褺" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x0a,0x01,0xff,0x04,0x0c,0x34,0xc5,0x06,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0x00,0xfe,0x88,0x50,0x20,0x18,0x06,
+/* 35131 0x893b "褻" */
+0x01,0xff,0x08,0x3e,0x08,0x7f,0x2a,0x5d,0x08,0x3e,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x20,0x20,0xf8,0x28,0x68,0x2a,0x56,0x82,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35132 0x893c "褼" */
+0x40,0x23,0x20,0x03,0xf2,0x13,0x20,0x6f,0xb0,0x29,0x23,0x25,0x21,0x21,0x21,0x20,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x20,0xfe,0x88,0x04,0xfa,0x08,0xf8,0x02,0x02,0xfe,
+/* 35133 0x893d "褽" */
+0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2e,0x01,0xff,0x06,0x1c,0xe5,0x06,
+0x08,0x08,0x7e,0x08,0x48,0x28,0xa8,0x08,0x28,0x90,0x00,0xfe,0x80,0x48,0x30,0x0e,
+/* 35134 0x893e "褾" */
+0x20,0x13,0x00,0xfd,0x09,0x11,0x11,0x34,0x59,0x94,0x17,0x10,0x10,0x11,0x12,0x10,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 35135 0x893f "褿" */
+0x20,0x10,0x07,0xf8,0x0b,0x12,0x13,0x36,0x5b,0x94,0x15,0x11,0x11,0x11,0x11,0x11,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 35136 0x8940 "襀" */
+0x20,0x13,0x00,0xfd,0x08,0x13,0x10,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35137 0x8941 "襁" */
+0x20,0x13,0x00,0xf0,0x10,0x23,0x22,0x6a,0xb2,0x2b,0x20,0x20,0x20,0x20,0x25,0x22,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 35138 0x8942 "襂" */
+0x20,0x10,0x01,0xf9,0x0a,0x13,0x14,0x39,0x56,0x90,0x13,0x10,0x13,0x10,0x10,0x17,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 35139 0x8943 "襃" */
+0x01,0xff,0x00,0x0c,0x30,0x20,0x3c,0x21,0x20,0x3d,0x03,0x04,0x0c,0x35,0xc6,0x04,
+0x00,0xfe,0x00,0xf8,0x88,0xf8,0x20,0xfc,0xa8,0x24,0x00,0x88,0x50,0x30,0x0e,0x00,
+/* 35140 0x8944 "襄" */
+0x01,0xff,0x00,0x3e,0x22,0x3e,0x04,0x7f,0x04,0x3f,0x04,0xff,0x04,0x1c,0xe5,0x06,
+0x00,0xfe,0x00,0xf8,0x88,0xf8,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x44,0x28,0x18,0x06,
+/* 35141 0x8945 "襅" */
+0x20,0x11,0x01,0xfd,0x09,0x11,0x10,0x34,0x5b,0x94,0x14,0x11,0x10,0x13,0x10,0x10,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 35142 0x8946 "襆" */
+0x20,0x12,0x01,0xf8,0x0b,0x10,0x14,0x3b,0x54,0x91,0x10,0x13,0x10,0x10,0x11,0x16,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 35143 0x8947 "襇" */
+0x20,0x13,0x02,0xfb,0x0a,0x13,0x16,0x3a,0x56,0x92,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 35144 0x8948 "襈" */
+0x20,0x13,0x02,0xfb,0x0a,0x12,0x11,0x34,0x58,0x97,0x14,0x10,0x17,0x10,0x11,0x12,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 35145 0x8949 "襉" */
+0x27,0x14,0x07,0xf4,0x17,0x24,0x24,0x6c,0xb4,0x2c,0x24,0x24,0x24,0x25,0x24,0x24,
+0x9e,0x92,0x9e,0x92,0x9e,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 35146 0x894a "襊" */
+0x20,0x13,0x02,0xf3,0x12,0x23,0x20,0x6f,0xb4,0x2f,0x24,0x27,0x24,0x2f,0x20,0x20,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x80,0xbc,0x94,0x94,0xd4,0x88,0x94,0xa2,
+/* 35147 0x894b "襋" */
+0x42,0x22,0x0f,0xe2,0x22,0x2f,0x4a,0x5a,0xea,0x5b,0x42,0x47,0x4a,0x52,0x42,0x42,
+0x08,0x08,0xbe,0x08,0x08,0xbe,0xaa,0xaa,0xaa,0xae,0x08,0x1c,0xaa,0x48,0x08,0x08,
+/* 35148 0x894c "襌" */
+0x20,0x13,0x02,0xfa,0x0b,0x10,0x11,0x35,0x59,0x95,0x15,0x10,0x13,0x10,0x10,0x10,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35149 0x894d "襍" */
+0x20,0x10,0x01,0xfb,0x09,0x11,0x11,0x35,0x59,0x95,0x14,0x13,0x10,0x10,0x13,0x10,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 35150 0x894e "襎" */
+0x20,0x13,0x01,0xf8,0x0b,0x10,0x11,0x36,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x11,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 35151 0x894f "襏" */
+0x20,0x13,0x00,0xf5,0x12,0x24,0x23,0x68,0xb0,0x2b,0x22,0x23,0x20,0x20,0x22,0x21,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 35152 0x8950 "襐" */
+0x20,0x10,0x01,0xfb,0x0d,0x11,0x15,0x38,0x54,0x93,0x10,0x13,0x10,0x10,0x13,0x10,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 35153 0x8951 "襑" */
+0x20,0x11,0x00,0xfc,0x08,0x11,0x10,0x35,0x58,0x97,0x14,0x13,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xdc,0x94,0xdc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 35154 0x8952 "襒" */
+0x21,0x11,0x05,0xf3,0x11,0x27,0x25,0x6d,0xb5,0x2f,0x25,0x25,0x25,0x25,0x24,0x24,
+0x08,0x08,0x48,0x90,0x1e,0xd4,0x64,0x54,0x54,0x54,0xd4,0x48,0x48,0x54,0x64,0xc2,
+/* 35155 0x8953 "襓" */
+0x20,0x10,0x01,0xf8,0x0b,0x11,0x13,0x35,0x59,0x96,0x14,0x13,0x10,0x10,0x11,0x12,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 35156 0x8954 "襔" */
+0x20,0x10,0x03,0xf8,0x08,0x10,0x14,0x3b,0x56,0x93,0x12,0x13,0x12,0x12,0x12,0x12,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 35157 0x8955 "襕" */
+0x21,0x10,0x02,0xf2,0x12,0x22,0x22,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,
+0x00,0xbe,0x82,0x22,0xfa,0x22,0xfa,0xaa,0xba,0xea,0xaa,0xfa,0x72,0xaa,0x22,0x26,
+/* 35158 0x8956 "襖" */
+0x20,0x11,0x07,0xf4,0x15,0x24,0x27,0x6c,0xb5,0x2c,0x20,0x2f,0x20,0x21,0x22,0x2c,
+0x80,0x00,0xfc,0x44,0x54,0x44,0xfc,0xe4,0x54,0x04,0x40,0xfe,0xa0,0x10,0x08,0x06,
+/* 35159 0x8957 "襗" */
+0x20,0x11,0x01,0xf9,0x08,0x11,0x14,0x3b,0x54,0x90,0x11,0x10,0x13,0x10,0x10,0x10,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35160 0x8958 "襘" */
+0x20,0x10,0x00,0xfd,0x0a,0x11,0x11,0x35,0x59,0x95,0x14,0x10,0x10,0x10,0x10,0x10,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 35161 0x8959 "襙" */
+0x20,0x10,0x00,0xfc,0x08,0x11,0x11,0x35,0x59,0x94,0x15,0x10,0x10,0x11,0x12,0x10,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35162 0x895a "襚" */
+0x20,0x12,0x01,0xfc,0x08,0x10,0x13,0x35,0x59,0x95,0x15,0x11,0x11,0x11,0x12,0x14,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 35163 0x895b "襛" */
+0x20,0x13,0x02,0xfb,0x0a,0x13,0x14,0x3b,0x56,0x92,0x12,0x13,0x15,0x15,0x15,0x19,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 35164 0x895c "襜" */
+0x20,0x10,0x01,0xfb,0x09,0x11,0x11,0x35,0x59,0x95,0x15,0x11,0x11,0x12,0x12,0x14,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 35165 0x895d "襝" */
+0x20,0x10,0x00,0xfc,0x09,0x12,0x10,0x34,0x59,0x95,0x15,0x11,0x10,0x10,0x11,0x12,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 35166 0x895e "襞" */
+0x00,0x7c,0x45,0x44,0x7c,0x43,0x7c,0xa5,0x24,0x3e,0x01,0xff,0x06,0x1c,0xe5,0x06,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x00,0xfe,0x80,0x48,0x30,0x0e,
+/* 35167 0x895f "襟" */
+0x21,0x11,0x07,0xf1,0x13,0x25,0x29,0x68,0xb3,0x28,0x27,0x20,0x22,0x24,0x29,0x20,
+0x10,0x10,0xbc,0x10,0xb8,0x54,0x12,0x00,0xf8,0x00,0xfc,0x40,0x48,0x44,0x42,0x80,
+/* 35168 0x8960 "襠" */
+0x20,0x11,0x00,0xfb,0x0a,0x10,0x10,0x34,0x58,0x94,0x15,0x11,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 35169 0x8961 "襡" */
+0x20,0x13,0x02,0xf2,0x13,0x21,0x23,0x6c,0xb3,0x2a,0x22,0x23,0x20,0x27,0x20,0x20,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xfc,0x84,0xe4,0xa4,0xa4,0xe4,0x94,0xf4,0x14,0x08,
+/* 35170 0x8962 "襢" */
+0x20,0x13,0x00,0xfb,0x0a,0x12,0x12,0x37,0x58,0x95,0x15,0x11,0x11,0x11,0x10,0x13,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 35171 0x8963 "襣" */
+0x20,0x10,0x00,0xfc,0x08,0x10,0x10,0x35,0x59,0x95,0x15,0x11,0x10,0x13,0x10,0x11,
+0x40,0xf8,0x88,0xf8,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x88,0x08,
+/* 35172 0x8964 "襤" */
+0x20,0x13,0x02,0xfb,0x0a,0x13,0x16,0x3b,0x54,0x91,0x11,0x11,0x11,0x11,0x17,0x10,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35173 0x8965 "襥" */
+0x21,0x11,0x01,0xf2,0x12,0x26,0x26,0x6a,0xb2,0x2a,0x22,0x22,0x22,0x22,0x22,0x22,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 35174 0x8966 "襦" */
+0x20,0x11,0x00,0xfb,0x0a,0x11,0x14,0x39,0x54,0x93,0x10,0x11,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 35175 0x8967 "襧" */
+0x20,0x17,0x02,0xf4,0x1f,0x24,0x26,0x6d,0xb6,0x2c,0x26,0x25,0x26,0x24,0x24,0x24,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 35176 0x8968 "襨" */
+0x21,0x11,0x05,0xf3,0x11,0x27,0x20,0x6a,0xb1,0x2b,0x20,0x23,0x20,0x20,0x27,0x20,
+0x44,0x44,0x54,0x64,0x5e,0xe4,0x04,0x34,0x4c,0xe4,0x84,0xe4,0x84,0xe4,0x14,0x08,
+/* 35177 0x8969 "襩" */
+0x20,0x13,0x00,0xfd,0x08,0x13,0x12,0x37,0x59,0x95,0x15,0x11,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35178 0x896a "襪" */
+0x21,0x17,0x01,0xf0,0x13,0x22,0x22,0x6b,0xb0,0x2b,0x22,0x23,0x22,0x22,0x24,0x28,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 35179 0x896b "襫" */
+0x20,0x10,0x07,0xf0,0x13,0x21,0x23,0x6a,0xb3,0x2a,0x23,0x20,0x20,0x20,0x21,0x26,
+0x20,0x20,0xfe,0x20,0xae,0x24,0xae,0xaa,0xae,0xaa,0xae,0x50,0x50,0x88,0x04,0x02,
+/* 35180 0x896c "襬" */
+0x20,0x13,0x02,0xf2,0x13,0x21,0x22,0x6b,0xb0,0x2b,0x22,0x23,0x22,0x23,0x22,0x22,
+0x00,0xfc,0x94,0x94,0xfc,0x10,0x52,0xdc,0x12,0xce,0x40,0xd2,0x5c,0xd0,0x52,0xce,
+/* 35181 0x896d "襭" */
+0x21,0x11,0x01,0xf7,0x11,0x21,0x23,0x68,0xb0,0x2b,0x22,0x22,0x22,0x23,0x22,0x20,
+0x00,0x3e,0x08,0xd0,0x3e,0x22,0xa2,0x3e,0x22,0xbe,0xa2,0xa2,0xbe,0x80,0x94,0x22,
+/* 35182 0x896e "襮" */
+0x21,0x11,0x01,0xfd,0x09,0x10,0x11,0x34,0x5b,0x94,0x15,0x12,0x10,0x10,0x11,0x10,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 35183 0x896f "襯" */
+0x42,0x21,0x27,0x00,0xf4,0x13,0x27,0x69,0xb1,0x2f,0x21,0x25,0x25,0x29,0x25,0x22,
+0x00,0x3c,0xa4,0x24,0xbc,0x24,0xa4,0x3c,0x24,0xa4,0x3c,0x90,0x58,0x68,0x2a,0x46,
+/* 35184 0x8970 "襰" */
+0x21,0x11,0x07,0xf1,0x11,0x27,0x25,0x6d,0xb7,0x29,0x23,0x25,0x29,0x21,0x21,0x21,
+0x08,0x08,0xce,0x12,0x24,0xde,0x52,0x5e,0xd2,0x1e,0x92,0x5e,0x40,0x14,0x12,0x22,
+/* 35185 0x8971 "襱" */
+0x22,0x11,0x07,0xf0,0x14,0x22,0x27,0x68,0xb7,0x2c,0x27,0x24,0x27,0x24,0x24,0x24,
+0x10,0x10,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 35186 0x8972 "襲" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x01,0xff,0x06,0x1c,0xe5,0x06,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,0x00,0xfe,0x80,0x48,0x30,0x0e,
+/* 35187 0x8973 "襳" */
+0x41,0x21,0x22,0x00,0xf7,0x11,0x23,0x69,0xb3,0x29,0x23,0x21,0x21,0x23,0x20,0x20,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4c,0x6c,0x48,0x6a,0x9a,0x26,0x42,
+/* 35188 0x8974 "襴" */
+0x27,0x14,0x07,0xf4,0x17,0x24,0x25,0x6c,0xb5,0x2d,0x25,0x25,0x25,0x24,0x25,0x24,
+0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xf4,0x44,0xf4,0x54,0xf4,0x54,0xf4,0xe4,0x54,0x4c,
+/* 35189 0x8975 "襵" */
+0x23,0x11,0x01,0xf1,0x11,0x21,0x27,0x68,0xb7,0x2a,0x23,0x22,0x23,0x22,0x27,0x20,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 35190 0x8976 "襶" */
+0x41,0x27,0x21,0x0f,0xf0,0x17,0x25,0x6f,0xb5,0x2f,0x22,0x27,0x22,0x2f,0x22,0x24,
+0x14,0xd2,0x10,0xfe,0x10,0xd0,0x52,0xd2,0x52,0xd4,0x94,0xc8,0x8a,0xfa,0xa6,0x42,
+/* 35191 0x8977 "襷" */
+0x21,0x12,0x02,0xf3,0x12,0x23,0x22,0x6f,0xb1,0x2a,0x24,0x23,0x20,0x27,0x20,0x20,
+0x40,0x6c,0x44,0x6c,0xa4,0xac,0xa4,0xfe,0x08,0xf4,0x42,0xf8,0x40,0xfc,0x40,0xc0,
+/* 35192 0x8978 "襸" */
+0x25,0x17,0x09,0xf7,0x13,0x25,0x29,0x6b,0xb2,0x2b,0x22,0x23,0x22,0x23,0x21,0x22,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 35193 0x8979 "襹" */
+0x27,0x10,0x07,0xf4,0x16,0x24,0x20,0x6f,0xb4,0x2f,0x24,0x27,0x25,0x29,0x29,0x31,
+0xbe,0x00,0xbc,0xa4,0xb4,0xa4,0x40,0xfe,0xa0,0xfc,0xa4,0xfc,0x12,0xdc,0x12,0xce,
+/* 35194 0x897a "襺" */
+0x21,0x17,0x01,0xf0,0x17,0x25,0x25,0x6e,0xb7,0x2d,0x26,0x27,0x24,0x25,0x25,0x24,
+0x10,0xfe,0x10,0x00,0xfe,0x4a,0x4a,0xfe,0xea,0x6a,0x7e,0xca,0x4e,0x72,0x42,0x06,
+/* 35195 0x897b "襻" */
+0x22,0x12,0x07,0xf2,0x17,0x2a,0x22,0x6f,0xb2,0x2d,0x28,0x23,0x20,0x27,0x20,0x20,
+0xa8,0x48,0xbe,0xa8,0x5c,0xaa,0x88,0xfe,0x18,0xe4,0x42,0xf8,0x40,0xfc,0x40,0xc0,
+/* 35196 0x897c "襼" */
+0x21,0x17,0x01,0xf3,0x11,0x27,0x22,0x6d,0xb3,0x29,0x23,0x20,0x27,0x20,0x21,0x23,
+0x08,0xfe,0x08,0x90,0x3c,0xd4,0xb4,0x5c,0x96,0x22,0xfc,0x00,0xfe,0x80,0x04,0xfe,
+/* 35197 0x897d "襽" */
+0x21,0x17,0x01,0xf7,0x14,0x27,0x24,0x6f,0xb4,0x2f,0x25,0x25,0x24,0x24,0x25,0x24,
+0x10,0xfe,0x10,0xbc,0xa4,0xbc,0xa4,0xbc,0x44,0xfc,0x54,0xf4,0x44,0xe4,0x54,0x48,
+/* 35198 0x897e "襾" */
+0x00,0xff,0x04,0x04,0x04,0x7f,0x44,0x44,0x44,0x44,0x47,0x44,0x40,0x40,0x40,0x40,
+0x00,0xfe,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xc4,0x44,0x04,0x04,0x04,0x04,
+/* 35199 0x897f "西" */
+0x00,0xff,0x04,0x04,0x04,0x3f,0x24,0x24,0x24,0x24,0x28,0x30,0x20,0x20,0x3f,0x20,
+0x00,0xfe,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x38,0x08,0x08,0x08,0xf8,0x08,
+/* 35200 0x8980 "覀" */
+0x00,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 35201 0x8981 "要" */
+0x00,0x7f,0x04,0x04,0x3f,0x24,0x24,0x3f,0x02,0x7f,0x04,0x08,0x1c,0x03,0x06,0x38,
+0x00,0xfc,0x40,0x40,0xf8,0x48,0x48,0xf8,0x00,0xfc,0x20,0x40,0x80,0x80,0x70,0x08,
+/* 35202 0x8982 "覂" */
+0xff,0x04,0x3f,0x24,0x3f,0x00,0x01,0x3e,0x01,0x7f,0x00,0x01,0x06,0x18,0xe7,0x00,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0xf0,0x00,0x00,0xf8,0x60,0x80,0x00,0x00,0xfe,0x00,
+/* 35203 0x8983 "覃" */
+0xff,0x04,0x3f,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x01,0xff,0x01,0x01,0x01,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,0x00,
+/* 35204 0x8984 "覄" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x08,0x10,0x37,0x50,0x90,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x50,0x48,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 35205 0x8985 "覅" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xfe,0x10,0xfe,0x25,0x44,0x28,0x10,0x28,0xc4,
+0x40,0x40,0x40,0x7e,0xaa,0x2a,0x2a,0x4a,0x4a,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 35206 0x8986 "覆" */
+0xff,0x04,0x3f,0x24,0x3f,0x12,0x27,0x42,0x8b,0x12,0x33,0x51,0x93,0x15,0x10,0x17,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x10,0xe0,0x1e,
+/* 35207 0x8987 "覇" */
+0xff,0x04,0x3f,0x24,0x3f,0x22,0x7f,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0xff,0x08,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x54,0x88,
+/* 35208 0x8988 "覈" */
+0xff,0x04,0x3f,0x24,0x3f,0x10,0x7e,0x52,0x4a,0x7e,0x10,0xff,0x20,0x3e,0x42,0x86,
+0xfe,0x40,0xf8,0x48,0xf8,0x20,0x20,0x3e,0x44,0xa4,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 35209 0x8989 "覉" */
+0xff,0x04,0x3f,0x24,0x3f,0x28,0x7d,0x28,0x38,0x13,0x7c,0x55,0x7d,0x11,0xfe,0x10,
+0xfe,0x40,0xf8,0x48,0xf8,0x20,0xfc,0x50,0x88,0xfe,0x08,0xe8,0x28,0xe8,0x08,0x18,
+/* 35210 0x898a "覊" */
+0xff,0x04,0x3f,0x24,0x3f,0x28,0xfd,0x29,0x39,0x11,0x7d,0x55,0x7d,0x10,0xfe,0x10,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xaa,0x04,
+/* 35211 0x898b "見" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x04,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x40,0x40,0x42,0x42,0x3e,
+/* 35212 0x898c "覌" */
+0x00,0x01,0xfd,0x05,0x05,0x49,0x29,0x11,0x11,0x29,0x25,0x44,0x80,0x01,0x02,0x0c,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 35213 0x898d "覍" */
+0x01,0x09,0x11,0x21,0x41,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,0x60,
+0x00,0x20,0x10,0x08,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x42,0x42,0x3e,
+/* 35214 0x898e "覎" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x24,0x24,0x24,0x43,0x80,
+0x00,0x7c,0x04,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x22,0x02,0xfe,0x00,
+/* 35215 0x898f "規" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x28,0x24,0x44,0x80,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35216 0x8990 "覐" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x24,0x24,0x24,0x43,0x80,
+0x00,0x88,0x50,0x20,0x50,0x88,0x00,0x88,0x50,0x20,0x50,0x88,0x02,0x02,0xfe,0x00,
+/* 35217 0x8991 "覑" */
+0x08,0x48,0x48,0x48,0x48,0x7e,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x44,0x85,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35218 0x8992 "覒" */
+0x04,0x0e,0x70,0x10,0x10,0x1c,0x70,0x10,0x10,0x1e,0xf0,0x10,0x14,0x18,0x10,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35219 0x8993 "覓" */
+0x00,0x01,0x7e,0x22,0x11,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x08,0xfc,0x10,0x10,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 35220 0x8994 "覔" */
+0x00,0x7f,0x01,0x03,0x0d,0x71,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x00,0xfc,0x00,0x60,0x18,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 35221 0x8995 "覕" */
+0x10,0x08,0x0a,0x02,0x12,0x13,0x54,0x54,0x54,0x98,0x19,0x11,0x31,0x4f,0x80,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0xc4,0xfc,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35222 0x8996 "視" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x10,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 35223 0x8997 "覗" */
+0x00,0x7f,0x01,0x01,0x7d,0x01,0x01,0x7d,0x45,0x45,0x7d,0x45,0x01,0x01,0x0a,0x04,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35224 0x8998 "覘" */
+0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35225 0x8999 "覙" */
+0x20,0x20,0x20,0x7e,0x42,0x44,0x90,0x10,0x54,0x54,0x52,0x52,0x92,0x10,0x50,0x21,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35226 0x899a "覚" */
+0x22,0x11,0x00,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x08,0x10,0x60,
+0x08,0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x42,0x42,0x3e,
+/* 35227 0x899b "覛" */
+0x02,0x07,0x38,0x20,0x23,0x2c,0x28,0x28,0x2d,0x2a,0x2a,0x29,0x29,0x49,0x4c,0x88,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0xfc,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35228 0x899c "覜" */
+0x28,0x28,0x28,0x28,0xaa,0x6c,0x28,0x28,0x6c,0xaa,0x28,0x28,0x2a,0x4c,0x48,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35229 0x899d "覝" */
+0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x00,0x10,0x52,0x52,0x94,0x28,0x24,0x44,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35230 0x899e "覞" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x2a,0x2c,0x48,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35231 0x899f "覟" */
+0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x7e,0x10,0x08,0x2a,0xa1,0xa1,0xa5,0x1c,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35232 0x89a0 "覠" */
+0x00,0x7e,0x12,0x12,0xff,0x12,0x12,0x7e,0x20,0x20,0x7e,0x62,0xa2,0x22,0x3e,0x22,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35233 0x89a1 "覡" */
+0x00,0x00,0x7f,0x08,0x08,0x2a,0x2a,0x2a,0x5d,0x49,0x88,0x08,0x0f,0xf0,0x40,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35234 0x89a2 "覢" */
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x10,0x52,0x54,0x90,0x28,0x24,0x42,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35235 0x89a3 "覣" */
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x92,0x00,0x10,0xfc,0x24,0x44,0x28,0x10,0x28,0xc5,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35236 0x89a4 "覤" */
+0x10,0x1e,0x10,0x7e,0x52,0x5c,0x70,0x52,0x4e,0x40,0x5c,0x54,0x54,0x96,0x94,0x21,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35237 0x89a5 "覥" */
+0x14,0x14,0x14,0x7f,0x55,0x55,0x55,0x7f,0x55,0x55,0x55,0xff,0x24,0x22,0x42,0x80,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0xa8,0x28,0x4a,0x4a,0x86,
+/* 35238 0x89a6 "覦" */
+0x10,0x28,0x44,0x82,0x7d,0x00,0xf1,0x95,0x95,0xf5,0x95,0x95,0xf5,0x91,0x95,0xb2,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35239 0x89a7 "覧" */
+0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x20,0x20,0x3e,0x40,0x50,0x88,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 35240 0x89a8 "覨" */
+0x00,0x77,0x55,0x55,0x77,0x00,0x7f,0x00,0xff,0x20,0x3f,0x01,0x01,0x01,0x0a,0x04,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0xc4,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35241 0x89a9 "覩" */
+0x10,0x10,0x7d,0x12,0x14,0xff,0x10,0x20,0x7e,0xa2,0x22,0x3e,0x22,0x22,0x3e,0x22,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35242 0x89aa "親" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0xff,0x08,0x08,0x7f,0x08,0x2a,0x49,0x88,0x28,0x10,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0xca,0x4a,0x86,
+/* 35243 0x89ab "覫" */
+0x10,0x08,0x7f,0x00,0x22,0x14,0x7f,0x51,0x08,0x7f,0x10,0x1e,0x12,0x22,0x2a,0x44,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35244 0x89ac "覬" */
+0x08,0x49,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x42,0x24,0x0f,0xf0,0x40,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35245 0x89ad "覭" */
+0x00,0xff,0x81,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x10,0x08,0xff,0x00,0x24,0x42,0x81,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35246 0x89ae "覮" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0xf0,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x3e,
+/* 35247 0x89af "覯" */
+0x22,0x22,0xff,0x22,0x7f,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0xff,0x41,0x45,0x42,
+0x00,0x7c,0xc4,0x44,0x7c,0x44,0xc4,0x7c,0x44,0x44,0x7c,0x28,0xe8,0x4a,0x4a,0x86,
+/* 35248 0x89b0 "覰" */
+0x10,0x1e,0x10,0x7f,0x51,0x5c,0x72,0x4e,0x40,0x5e,0x52,0x5e,0x52,0x5e,0x52,0xbf,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35249 0x89b1 "覱" */
+0x08,0x7f,0x08,0x3e,0x2a,0x3e,0x2a,0xff,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x78,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x3e,
+/* 35250 0x89b2 "覲" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0x7c,0xc4,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35251 0x89b3 "観" */
+0x20,0x20,0x3f,0x48,0x88,0x7f,0x14,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x20,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35252 0x89b4 "覴" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x5d,0x80,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35253 0x89b5 "覵" */
+0xe7,0xa5,0xe7,0xa5,0xe7,0x81,0xbd,0xa5,0xbd,0xa5,0xbd,0xa5,0xa5,0xcd,0x81,0x83,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35254 0x89b6 "覶" */
+0x0f,0xf0,0x49,0x22,0xfe,0x14,0x08,0xff,0x95,0xbd,0x83,0xbd,0x95,0x89,0x95,0xa3,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35255 0x89b7 "覷" */
+0x10,0x1e,0x10,0x7f,0x51,0x5c,0x72,0x4e,0x40,0x4a,0x6a,0x5b,0x4a,0x8f,0x78,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0xfc,0x28,0x28,0x4a,0x4a,0x86,
+/* 35256 0x89b8 "覸" */
+0x00,0x77,0x55,0x77,0x55,0x77,0x41,0x5d,0x55,0x5d,0x55,0x5d,0x55,0x41,0x45,0x42,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35257 0x89b9 "覹" */
+0x01,0xf9,0x8b,0x8d,0xf8,0x89,0x8a,0xfe,0x8a,0x8a,0xfa,0x52,0x52,0x56,0x5b,0x92,
+0x44,0x54,0x54,0xf8,0x0e,0x12,0xea,0x0a,0x0a,0xea,0xaa,0xa4,0xb4,0xaa,0x0a,0x10,
+/* 35258 0x89ba "覺" */
+0x3a,0x21,0x3a,0x22,0x39,0x22,0x7f,0x50,0x9f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0xb8,0x08,0xb8,0x88,0x38,0x88,0xfe,0x12,0xf4,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 35259 0x89bb "覻" */
+0x08,0x0f,0x08,0x7f,0x49,0x4c,0x79,0x47,0x40,0x5f,0x40,0x5f,0x51,0x5f,0x8a,0x3f,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35260 0x89bc "覼" */
+0x00,0xff,0x52,0x91,0xff,0x91,0xdb,0xb5,0xdb,0x91,0xdb,0xb5,0xdb,0x91,0x95,0x82,
+0x00,0x7c,0x44,0x44,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35261 0x89bd "覽" */
+0x7e,0x48,0x7e,0x43,0x7e,0x48,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x04,0x18,0xe0,
+0x40,0x7e,0x90,0x08,0xfe,0xaa,0xfe,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x42,0x42,0x3e,
+/* 35262 0x89be "覾" */
+0x10,0x08,0x7f,0x41,0x86,0x78,0x49,0x2a,0xff,0x2a,0x41,0xbe,0x2a,0x3e,0x2a,0x3e,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35263 0x89bf "覿" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0xaa,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x45,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x92,0x92,0x0e,
+/* 35264 0x89c0 "觀" */
+0x22,0x22,0xff,0x22,0x77,0x55,0x77,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x00,0x7c,0xc4,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x4a,0x4a,0x86,
+/* 35265 0x89c1 "见" */
+0x00,0x1f,0x10,0x10,0x11,0x11,0x11,0x11,0x11,0x12,0x12,0x04,0x04,0x08,0x30,0xc0,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x90,0x80,0x80,0x82,0x82,0x7e,
+/* 35266 0x89c2 "观" */
+0x00,0x01,0x01,0xfd,0x05,0x05,0x49,0x29,0x11,0x11,0x28,0x24,0x44,0x81,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 35267 0x89c3 "觃" */
+0x00,0x3e,0x22,0x22,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x08,0x14,0x14,0x24,0x43,0x80,
+0x00,0x7c,0x04,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x22,0x02,0xfe,0x00,
+/* 35268 0x89c4 "规" */
+0x10,0x11,0x11,0x7d,0x11,0x11,0x11,0xff,0x11,0x11,0x10,0x28,0x24,0x45,0x82,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 35269 0x89c5 "觅" */
+0x01,0x7e,0x12,0x09,0x09,0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0xf8,0x00,0x10,0x10,0x20,0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x80,0x82,0x82,0x7e,
+/* 35270 0x89c6 "视" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x10,0x10,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 35271 0x89c7 "觇" */
+0x10,0x11,0x11,0x1f,0x11,0x11,0x11,0x11,0x7d,0x45,0x44,0x44,0x44,0x7d,0x46,0x04,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x54,0x50,0x90,0x90,0x12,0x12,0x0e,
+/* 35272 0x89c8 "览" */
+0x04,0x24,0x24,0x24,0x25,0x04,0x1f,0x10,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0x40,0x40,0x7c,0x90,0x08,0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x80,0x84,0x84,0x7c,
+/* 35273 0x89c9 "觉" */
+0x22,0x11,0x00,0x7f,0x40,0x80,0x1f,0x10,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0x08,0x10,0x20,0xfe,0x02,0x04,0xf0,0x10,0x10,0x10,0x10,0x90,0x80,0x84,0x84,0x7c,
+/* 35274 0x89ca "觊" */
+0x08,0x49,0x49,0x49,0x7f,0x00,0x7f,0x01,0x01,0x3f,0x20,0x20,0x23,0x2c,0x30,0x01,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x8a,0x06,
+/* 35275 0x89cb "觋" */
+0x00,0x00,0x7f,0x08,0x08,0x2a,0x2a,0x2a,0x5d,0x49,0x88,0x08,0x0f,0xf0,0x40,0x01,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x8a,0x06,
+/* 35276 0x89cc "觌" */
+0x08,0x08,0x7e,0x08,0x08,0xff,0x01,0x2a,0x18,0x48,0x28,0xff,0x14,0x22,0x41,0x81,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x4a,0x86,
+/* 35277 0x89cd "觍" */
+0x14,0x14,0x14,0x7f,0x55,0x55,0x55,0x7f,0x55,0x55,0x55,0xff,0x24,0x22,0x42,0x81,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0xa8,0x28,0x4a,0x8a,0x06,
+/* 35278 0x89ce "觎" */
+0x10,0x28,0x44,0x82,0x7d,0x00,0xf1,0x95,0x95,0xf5,0x95,0x95,0xf5,0x91,0x95,0xb2,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x4a,0x86,
+/* 35279 0x89cf "觏" */
+0x24,0x24,0xff,0x24,0x7e,0x24,0xff,0x08,0x7e,0x4a,0x7e,0x4a,0xff,0x42,0x4a,0x44,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x4a,0x86,
+/* 35280 0x89d0 "觐" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0x7c,0xc4,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x28,0x28,0x4a,0x4a,0x86,
+/* 35281 0x89d1 "觑" */
+0x10,0x1e,0x10,0x7f,0x51,0x5c,0x72,0x4e,0x40,0x4a,0x6a,0x5b,0x4a,0x8f,0x78,0x00,
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x90,0x28,0x28,0x4a,0x4a,0x86,
+/* 35282 0x89d2 "角" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x41,0x41,0x80,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 35283 0x89d3 "觓" */
+0x10,0x10,0x1f,0x21,0x42,0xbf,0x24,0x24,0x3f,0x24,0x24,0x3f,0x24,0x44,0x42,0x81,
+0x04,0x04,0x24,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0xac,0xb4,0xa4,0x84,0x84,0x84,0x04,
+/* 35284 0x89d4 "觔" */
+0x10,0x10,0x1f,0x21,0x42,0xbf,0x24,0x24,0x3f,0x24,0x24,0x3f,0x24,0x44,0x42,0x81,
+0x10,0x10,0x10,0x10,0x7e,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xa2,0xaa,0x44,
+/* 35285 0x89d5 "觕" */
+0x10,0x10,0x50,0x51,0x7e,0x55,0x91,0x11,0x1d,0xf1,0x51,0x11,0x11,0x12,0x12,0x14,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x14,0x08,
+/* 35286 0x89d6 "觖" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x54,0x54,0x45,0x8e,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 35287 0x89d7 "觗" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xc6,0x82,
+/* 35288 0x89d8 "觘" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 35289 0x89d9 "觙" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x43,0x86,
+0x00,0xfc,0x44,0x48,0x48,0x50,0x5c,0x44,0x44,0x44,0x68,0xa8,0x90,0x98,0x24,0x42,
+/* 35290 0x89da "觚" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x55,0x56,0x46,0x8c,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 35291 0x89db "觛" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x43,0x86,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 35292 0x89dc "觜" */
+0x08,0x28,0x2e,0x28,0x2e,0xf0,0x08,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x11,0x21,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x00,0xc0,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 35293 0x89dd "觝" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xd6,0x8a,
+/* 35294 0x89de "觞" */
+0x10,0x10,0x3c,0x24,0x49,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2b,0x4a,0x42,0x86,
+0x40,0x40,0x7e,0x80,0x7c,0x08,0x10,0x20,0xfe,0x4a,0x4a,0x92,0x12,0x22,0x54,0x88,
+/* 35295 0x89df "觟" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 35296 0x89e0 "觠" */
+0x11,0x09,0x7f,0x02,0xff,0x08,0x38,0xcf,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x11,0x21,
+0x10,0x20,0xfc,0x00,0xfe,0x20,0x18,0xc6,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 35297 0x89e1 "觡" */
+0x10,0x10,0x3c,0x24,0x49,0xbe,0x2a,0x2a,0x3f,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 35298 0x89e2 "觢" */
+0x08,0x7f,0x08,0x3e,0x08,0x7f,0x08,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x11,0x21,
+0x00,0x7c,0x24,0x24,0x44,0x54,0x88,0xc0,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 35299 0x89e3 "解" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x00,0xfc,0x24,0x24,0x54,0x88,0x10,0x50,0x7c,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 35300 0x89e4 "觤" */
+0x20,0x20,0x78,0x49,0x92,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x55,0x55,0x45,0x8e,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 35301 0x89e5 "觥" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x55,0x55,0x46,0x8c,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 35302 0x89e6 "触" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7c,0x54,0x57,0x45,0x8c,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x02,0x00,
+/* 35303 0x89e7 "觧" */
+0x10,0x10,0x3c,0x24,0x49,0xbe,0x2a,0x2a,0x3e,0x2a,0x2b,0x3e,0x2a,0x4a,0x42,0x86,
+0x88,0x48,0x50,0x00,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 35304 0x89e8 "觨" */
+0x20,0x21,0x78,0x48,0x93,0x7c,0x54,0x54,0x7f,0x54,0x54,0x7d,0x55,0x56,0x44,0x8c,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0x20,0x22,0xb2,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 35305 0x89e9 "觩" */
+0x20,0x20,0x78,0x48,0x93,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7d,0x56,0x54,0x44,0x8c,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 35306 0x89ea "觪" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2b,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 35307 0x89eb "觫" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x55,0x55,0x7d,0x54,0x54,0x7c,0x55,0x56,0x44,0x8c,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 35308 0x89ec "觬" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x54,0x54,0x7c,0x54,0x54,0x45,0x8e,
+0x00,0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 35309 0x89ed "觭" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x57,0x54,0x7d,0x55,0x55,0x7d,0x55,0x54,0x44,0x8c,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 35310 0x89ee "觮" */
+0x10,0x10,0x3c,0x24,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x00,0xfc,0x04,0x04,0x7c,0x04,0x04,0xfe,0x10,0x92,0x54,0x38,0x54,0x92,0x50,0x20,
+/* 35311 0x89ef "觯" */
+0x21,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7c,0x57,0x54,0x44,0x8c,
+0x04,0x88,0x50,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35312 0x89f0 "觰" */
+0x10,0x10,0x3c,0x24,0x48,0xbf,0x2a,0x2a,0x3e,0x2b,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 35313 0x89f1 "觱" */
+0x00,0x3f,0x20,0x2f,0x20,0x2f,0x48,0x4f,0x90,0x3f,0x51,0x1f,0x11,0x1f,0x11,0x21,
+0x28,0xfe,0x20,0xa4,0x28,0x90,0xaa,0xc6,0x82,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 35314 0x89f2 "觲" */
+0x20,0x20,0x7b,0x48,0x91,0x7c,0x57,0x54,0x7c,0x54,0x55,0x7c,0x57,0x54,0x44,0x8c,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35315 0x89f3 "觳" */
+0x08,0xff,0x08,0x7f,0x00,0xff,0xa0,0x3e,0x42,0xff,0x49,0x7f,0x49,0x7f,0x49,0x8b,
+0x00,0xb8,0x28,0x28,0x28,0xc6,0x80,0x7c,0x24,0x24,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 35316 0x89f4 "觴" */
+0x10,0x10,0x3c,0x25,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2b,0x4a,0x42,0x86,
+0x40,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0xfe,0x2a,0x4a,0x92,0x26,
+/* 35317 0x89f5 "觵" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x54,0x55,0x7d,0x55,0x55,0x7d,0x54,0x54,0x44,0x8d,
+0x48,0x48,0xfc,0x48,0x48,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x48,0x84,0x02,
+/* 35318 0x89f6 "觶" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7c,0x57,0x54,0x44,0x8c,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35319 0x89f7 "觷" */
+0x0a,0x31,0x22,0x39,0x22,0xff,0x88,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x11,0x21,
+0x80,0x38,0x88,0x38,0x88,0xfe,0x02,0xc0,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 35320 0x89f8 "觸" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x55,0x56,0x7d,0x55,0x55,0x7d,0x54,0x55,0x44,0x8c,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 35321 0x89f9 "觹" */
+0x10,0x10,0x3c,0x25,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x4a,0x42,0x86,
+0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x00,0xee,0xaa,0xaa,0xba,0x82,0x86,
+/* 35322 0x89fa "觺" */
+0x48,0x70,0x44,0x3d,0x20,0x7c,0x90,0x7d,0x2a,0x4f,0x10,0x2f,0x48,0x0f,0x08,0x10,
+0xf8,0x50,0x20,0xfc,0x24,0xb8,0xa0,0x7e,0x00,0xf0,0x20,0xf8,0x88,0xf8,0x88,0x98,
+/* 35323 0x89fb "觻" */
+0x21,0x21,0x7a,0x4a,0x93,0x7d,0x56,0x57,0x7c,0x54,0x57,0x7c,0x54,0x55,0x46,0x8c,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35324 0x89fc "觼" */
+0x20,0x20,0x79,0x4b,0x91,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x54,0x55,0x44,0x8c,
+0x80,0xf8,0x08,0xfe,0x22,0x52,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfc,0x44,0x38,0xee,
+/* 35325 0x89fd "觽" */
+0x20,0x21,0x79,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x55,0x55,0x45,0x8d,
+0x10,0x12,0xfe,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xde,0x52,0x72,0x06,
+/* 35326 0x89fe "觾" */
+0x20,0x20,0x7b,0x48,0x90,0x7d,0x55,0x57,0x7d,0x55,0x57,0x7d,0x54,0x55,0x45,0x8e,
+0x88,0x88,0xfe,0x88,0xf8,0x04,0x74,0x56,0x54,0x54,0x74,0x06,0x00,0x54,0x2a,0x2a,
+/* 35327 0x89ff "觿" */
+0x22,0x23,0x78,0x49,0x93,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7d,0x55,0x55,0x45,0x8d,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x4a,0xf6,0x52,0x76,
+/* 35328 0x8a00 "言" */
+0x02,0x01,0xff,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 35329 0x8a01 "訁" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 35330 0x8a02 "訂" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 35331 0x8a03 "訃" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 35332 0x8a04 "訄" */
+0x20,0x20,0x23,0x20,0xfd,0x24,0x25,0x24,0x25,0x25,0x25,0x25,0x25,0x44,0x43,0x80,
+0x40,0x20,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0x08,0xfa,0x0a,0x02,0xfe,0x00,
+/* 35333 0x8a05 "訅" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x8a,0x8a,0x06,0x00,
+/* 35334 0x8a06 "訆" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x8c,0x94,0xe4,0x84,0x04,0x04,0x04,0x04,
+/* 35335 0x8a07 "訇" */
+0x10,0x10,0x1f,0x20,0x42,0xbf,0x00,0x1f,0x00,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x04,0xc4,0x04,0xc4,0x04,0xc4,0x44,0xc4,0x54,0x08,
+/* 35336 0x8a08 "計" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x03,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 35337 0x8a09 "訉" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 35338 0x8a0a "訊" */
+0x20,0x13,0x00,0xfc,0x00,0x78,0x00,0x7b,0x00,0x78,0x48,0x48,0x48,0x78,0x48,0x00,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 35339 0x8a0b "訋" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x40,0x40,0xfc,0x84,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 35340 0x8a0c "訌" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35341 0x8a0d "訍" */
+0x20,0x11,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 35342 0x8a0e "討" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x01,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 35343 0x8a0f "訏" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 35344 0x8a10 "訐" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 35345 0x8a11 "訑" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xa4,0xb4,0xa8,0xa2,0xa2,0x82,0x7e,0x00,
+/* 35346 0x8a12 "訒" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7d,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 35347 0x8a13 "訓" */
+0x21,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 35348 0x8a14 "訔" */
+0x01,0x21,0x21,0x3f,0x02,0x01,0xff,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x20,
+0x00,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x08,
+/* 35349 0x8a15 "訕" */
+0x20,0x10,0x10,0xfe,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x44,0x00,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 35350 0x8a16 "訖" */
+0x20,0x10,0x10,0xfe,0x01,0x7e,0x00,0x7c,0x00,0x7c,0x44,0x44,0x45,0x7d,0x44,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 35351 0x8a17 "託" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x00,0x7c,0x01,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 35352 0x8a18 "記" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x84,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 35353 0x8a19 "訙" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xa8,0x8a,0x0a,0x06,0x02,
+/* 35354 0x8a1a "訚" */
+0x20,0x17,0x02,0x41,0x5f,0x40,0x4f,0x40,0x4f,0x40,0x4f,0x48,0x48,0x4f,0x48,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0xe4,0x04,0xe4,0x04,0xe4,0x24,0x24,0xe4,0x24,0x0c,
+/* 35355 0x8a1b "訛" */
+0x20,0x10,0x00,0xfd,0x01,0x7b,0x05,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0xa0,0xa0,0xa0,0x24,0x24,0x28,0x30,0x20,0x60,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 35356 0x8a1c "訜" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7e,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 35357 0x8a1d "訝" */
+0x20,0x11,0x10,0xfe,0x00,0x7c,0x01,0x7d,0x00,0x7c,0x44,0x44,0x45,0x7e,0x44,0x00,
+0x00,0xfc,0x10,0x90,0x90,0x90,0x10,0xfe,0x30,0x50,0x50,0x90,0x10,0x10,0x50,0x20,
+/* 35358 0x8a1e "訞" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x03,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 35359 0x8a1f "訟" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7d,0x44,0x00,
+0x08,0x48,0x48,0x48,0x44,0x84,0xa4,0x22,0x20,0x40,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 35360 0x8a20 "訠" */
+0x20,0x11,0x00,0xfc,0x00,0x79,0x01,0x79,0x01,0x79,0x48,0x48,0x48,0x78,0x49,0x00,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 35361 0x8a21 "訡" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x02,0x7c,0x00,0x7d,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 35362 0x8a22 "訢" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 35363 0x8a23 "訣" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7c,0x03,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 35364 0x8a24 "訤" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x03,
+0x08,0x88,0x50,0x20,0x50,0x88,0x00,0x08,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 35365 0x8a25 "訥" */
+0x20,0x10,0x00,0xfc,0x03,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4b,0x4a,0x7a,0x4a,0x02,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 35366 0x8a26 "訦" */
+0x20,0x10,0x00,0xfd,0x01,0x7a,0x00,0x78,0x00,0x78,0x48,0x48,0x48,0x78,0x49,0x02,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 35367 0x8a27 "訧" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x45,0x02,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 35368 0x8a28 "訨" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x10,0x10,0x10,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 35369 0x8a29 "訩" */
+0x20,0x10,0x01,0xfc,0x02,0x7a,0x02,0x7a,0x02,0x7a,0x4b,0x4a,0x4a,0x7b,0x48,0x00,
+0x00,0x08,0x08,0x88,0x52,0x52,0x22,0x22,0x52,0x92,0x0a,0x0a,0x02,0xfe,0x02,0x00,
+/* 35370 0x8a2a "訪" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 35371 0x8a2b "訫" */
+0x20,0x10,0x00,0xfc,0x00,0x78,0x00,0x7a,0x02,0x7a,0x4a,0x4c,0x48,0x78,0x48,0x00,
+0x00,0x40,0x20,0x10,0x90,0x80,0x80,0x84,0x82,0x82,0x82,0x88,0x88,0x88,0x78,0x00,
+/* 35372 0x8a2c "訬" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7d,0x02,0x7c,0x44,0x44,0x44,0x7c,0x44,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 35373 0x8a2d "設" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x02,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x03,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 35374 0x8a2e "訮" */
+0x20,0x11,0x00,0xfc,0x00,0x78,0x00,0x7b,0x00,0x78,0x48,0x48,0x48,0x79,0x49,0x02,
+0x00,0xfc,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 35375 0x8a2f "訯" */
+0x20,0x13,0x00,0xfc,0x00,0x78,0x00,0x78,0x01,0x79,0x49,0x49,0x4a,0x7a,0x44,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 35376 0x8a30 "訰" */
+0x20,0x10,0x00,0xfb,0x00,0x79,0x01,0x79,0x01,0x79,0x48,0x48,0x48,0x78,0x48,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 35377 0x8a31 "許" */
+0x20,0x10,0x00,0xfd,0x01,0x7a,0x00,0x78,0x03,0x78,0x48,0x48,0x48,0x78,0x48,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 35378 0x8a32 "訲" */
+0x20,0x10,0x00,0xfc,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x48,0x48,0x78,0x48,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 35379 0x8a33 "訳" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x4a,0x7a,0x44,0x08,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 35380 0x8a34 "訴" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 35381 0x8a35 "訵" */
+0x20,0x10,0x03,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x02,
+0x00,0x00,0xfc,0x94,0x94,0x94,0x94,0x94,0x94,0x94,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 35382 0x8a36 "訶" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x48,0x78,0x48,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 35383 0x8a37 "訷" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x78,0x48,0x00,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 35384 0x8a38 "訸" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x00,0x7c,0x00,0x7c,0x44,0x45,0x46,0x7c,0x44,0x00,
+0x1c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,
+/* 35385 0x8a39 "訹" */
+0x20,0x10,0x10,0xfc,0x03,0x7c,0x00,0x7c,0x00,0x7c,0x45,0x46,0x44,0x7c,0x44,0x00,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,0x20,
+/* 35386 0x8a3a "診" */
+0x20,0x10,0x00,0xfc,0x01,0x7a,0x00,0x78,0x01,0x78,0x48,0x48,0x49,0x78,0x48,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 35387 0x8a3b "註" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x00,0x78,0x01,0x78,0x48,0x48,0x48,0x78,0x4b,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35388 0x8a3c "証" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x47,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35389 0x8a3d "訽" */
+0x20,0x10,0x01,0xfd,0x02,0x7c,0x01,0x79,0x01,0x79,0x49,0x49,0x48,0x78,0x48,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 35390 0x8a3e "訾" */
+0x08,0x28,0x2e,0x28,0x2e,0xf0,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35391 0x8a3f "訿" */
+0x20,0x10,0x00,0xfa,0x02,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7f,0x4a,0x00,
+0x90,0x90,0x90,0x90,0x92,0xd4,0x98,0x90,0x90,0x90,0x90,0x92,0xd2,0x12,0x0e,0x00,
+/* 35392 0x8a40 "詀" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35393 0x8a41 "詁" */
+0x20,0x10,0x00,0xfc,0x03,0x78,0x00,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35394 0x8a42 "詂" */
+0x20,0x10,0x00,0xfd,0x01,0x7b,0x05,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 35395 0x8a43 "詃" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7c,0x01,0x7c,0x44,0x44,0x44,0x7d,0x44,0x00,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 35396 0x8a44 "詄" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x02,0x78,0x03,0x78,0x48,0x48,0x48,0x78,0x49,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 35397 0x8a45 "詅" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x02,0x7c,0x01,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 35398 0x8a46 "詆" */
+0x20,0x10,0x11,0xff,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 35399 0x8a47 "詇" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x7b,0x48,0x48,0x48,0x78,0x49,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 35400 0x8a48 "詈" */
+0x00,0x3f,0x24,0x24,0x3f,0x01,0xff,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x20,
+0x00,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x08,
+/* 35401 0x8a49 "詉" */
+0x41,0x21,0x01,0xf9,0x07,0x72,0x02,0x72,0x02,0x74,0x52,0x51,0x52,0x74,0x58,0x00,
+0x00,0x00,0x3e,0x12,0xd2,0x52,0x52,0x54,0x54,0x94,0x88,0x08,0x94,0xa4,0x42,0x80,
+/* 35402 0x8a4a "詊" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x47,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 35403 0x8a4b "詋" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x78,0x00,0x78,0x48,0x48,0x48,0x79,0x4a,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 35404 0x8a4c "詌" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 35405 0x8a4d "詍" */
+0x20,0x11,0x01,0xfd,0x01,0x7b,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 35406 0x8a4e "詎" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 35407 0x8a4f "詏" */
+0x20,0x10,0x00,0xfd,0x01,0x7a,0x03,0x78,0x01,0x79,0x4a,0x4b,0x48,0x78,0x48,0x00,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 35408 0x8a50 "詐" */
+0x20,0x10,0x10,0xfc,0x01,0x7d,0x02,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 35409 0x8a51 "詑" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x10,0x10,0xfe,0x82,0x04,0x40,0x48,0x50,0x60,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 35410 0x8a52 "詒" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 35411 0x8a53 "詓" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x44,0x44,0x44,0x7d,0x44,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 35412 0x8a54 "詔" */
+0x20,0x11,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x01,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 35413 0x8a55 "評" */
+0x20,0x11,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x03,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 35414 0x8a56 "詖" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 35415 0x8a57 "詗" */
+0x20,0x11,0x11,0xff,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfe,0x02,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x0a,0x04,
+/* 35416 0x8a58 "詘" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x78,0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 35417 0x8a59 "詙" */
+0x20,0x10,0x00,0xfc,0x03,0x78,0x00,0x78,0x01,0x79,0x49,0x49,0x4a,0x7a,0x44,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 35418 0x8a5a "詚" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 35419 0x8a5b "詛" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 35420 0x8a5c "詜" */
+0x20,0x11,0x01,0xfd,0x01,0x78,0x00,0x7b,0x01,0x78,0x48,0x48,0x48,0x78,0x49,0x06,
+0x20,0x24,0x24,0x24,0xfc,0x20,0x20,0xfc,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 35421 0x8a5d "詝" */
+0x20,0x10,0x00,0xfd,0x01,0x7a,0x00,0x78,0x01,0x78,0x48,0x48,0x48,0x78,0x48,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 35422 0x8a5e "詞" */
+0x20,0x11,0x10,0xfe,0x01,0x7c,0x00,0x7d,0x01,0x7d,0x45,0x45,0x44,0x7c,0x44,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x04,0x04,0x28,0x10,
+/* 35423 0x8a5f "詟" */
+0x04,0x04,0xff,0x09,0x11,0x66,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x80,0x40,0xfe,0x40,0x84,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35424 0x8a60 "詠" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x03,0x78,0x00,0x78,0x49,0x49,0x4a,0x7c,0x48,0x00,
+0x40,0x20,0x10,0xe0,0x22,0x34,0xb8,0xb0,0xa8,0xa8,0x28,0x24,0x24,0x22,0xa0,0x40,
+/* 35425 0x8a61 "詡" */
+0x20,0x13,0x00,0xfc,0x02,0x79,0x01,0x78,0x00,0x79,0x4a,0x48,0x48,0x78,0x49,0x00,
+0x00,0xde,0x42,0x42,0x52,0x4a,0x4a,0x42,0xc6,0x4a,0x52,0x42,0x42,0x42,0x4a,0x84,
+/* 35426 0x8a62 "詢" */
+0x20,0x10,0x01,0xfd,0x02,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x78,0x48,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x04,0x28,0x10,
+/* 35427 0x8a63 "詣" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 35428 0x8a64 "詤" */
+0x20,0x11,0x11,0xff,0x01,0x7d,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x10,0x10,0x10,0x28,0x44,0x00,0xfe,0x00,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 35429 0x8a65 "詥" */
+0x20,0x10,0x10,0xfe,0x00,0x7d,0x02,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 35430 0x8a66 "試" */
+0x20,0x10,0x00,0xfc,0x03,0x78,0x00,0x79,0x00,0x78,0x48,0x48,0x48,0x7b,0x48,0x00,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x90,0x90,0x90,0x88,0xea,0x8a,0x06,0x02,
+/* 35431 0x8a67 "詧" */
+0x10,0x10,0x3e,0x62,0x94,0x48,0x31,0x2f,0xc0,0x1f,0x00,0x1f,0x00,0x1f,0x10,0x1f,
+0x80,0x80,0xfc,0x44,0x48,0x30,0x10,0xe8,0x06,0xf0,0x00,0xf0,0x00,0xf0,0x10,0xf0,
+/* 35432 0x8a68 "詨" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x01,0x7a,0x00,0x78,0x48,0x48,0x48,0x78,0x48,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 35433 0x8a69 "詩" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x03,0x78,0x00,0x79,0x48,0x48,0x48,0x78,0x48,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 35434 0x8a6a "詪" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 35435 0x8a6b "詫" */
+0x20,0x10,0x03,0xfa,0x00,0x78,0x03,0x78,0x00,0x78,0x4b,0x48,0x48,0x78,0x48,0x00,
+0x40,0x20,0xfe,0x02,0x00,0x38,0xc0,0x40,0x40,0x7c,0xc0,0x40,0x42,0x42,0x3e,0x00,
+/* 35436 0x8a6c "詬" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 35437 0x8a6d "詭" */
+0x20,0x10,0x00,0xfd,0x02,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 35438 0x8a6e "詮" */
+0x20,0x10,0x00,0xfc,0x01,0x7a,0x01,0x78,0x00,0x78,0x49,0x48,0x48,0x78,0x4b,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35439 0x8a6f "詯" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35440 0x8a70 "詰" */
+0x20,0x10,0x00,0xfb,0x00,0x78,0x01,0x78,0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35441 0x8a71 "話" */
+0x20,0x10,0x11,0xfe,0x00,0x7d,0x00,0x7c,0x00,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35442 0x8a72 "該" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x45,0x44,0x7c,0x44,0x01,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 35443 0x8a73 "詳" */
+0x21,0x10,0x00,0xfc,0x03,0x78,0x00,0x79,0x00,0x78,0x4b,0x48,0x48,0x78,0x48,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 35444 0x8a74 "詴" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x00,0x7d,0x02,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 35445 0x8a75 "詵" */
+0x20,0x11,0x01,0xfd,0x01,0x7a,0x00,0x7b,0x00,0x78,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 35446 0x8a76 "詶" */
+0x20,0x10,0x00,0xfc,0x00,0x78,0x02,0x7a,0x04,0x78,0x48,0x48,0x48,0x79,0x49,0x02,
+0x82,0x92,0x92,0x92,0x92,0x92,0xda,0xb6,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 35447 0x8a77 "詷" */
+0x20,0x11,0x11,0xff,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfe,0x02,0x02,0x7a,0x02,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x02,0x02,0x0a,0x04,
+/* 35448 0x8a78 "詸" */
+0x20,0x10,0x01,0xfc,0x00,0x78,0x00,0x7b,0x00,0x78,0x48,0x49,0x49,0x7a,0x48,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 35449 0x8a79 "詹" */
+0x08,0x0f,0x10,0x3f,0x65,0xa8,0x3f,0x20,0x27,0x20,0x27,0x20,0x27,0x44,0x47,0x84,
+0x00,0xf0,0x20,0xfe,0x08,0x84,0xfe,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x08,
+/* 35450 0x8a7a "詺" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x00,0x7c,0x45,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x20,0x7e,0x82,0x44,0x28,0x10,0x20,0x40,0xfe,0x42,0x42,0x42,0x42,0x7e,0x42,
+/* 35451 0x8a7b "詻" */
+0x20,0x10,0x00,0xfd,0x03,0x7c,0x00,0x78,0x01,0x7a,0x4d,0x49,0x49,0x79,0x49,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 35452 0x8a7c "詼" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x00,0x79,0x01,0x79,0x4a,0x4a,0x4c,0x78,0x48,0x01,
+0x40,0x40,0x40,0xfe,0x80,0x90,0x90,0x12,0x52,0x54,0x90,0x28,0x28,0x44,0x84,0x02,
+/* 35453 0x8a7d "詽" */
+0x20,0x11,0x00,0xfc,0x00,0x78,0x00,0x7b,0x00,0x78,0x48,0x48,0x48,0x79,0x49,0x02,
+0x00,0xdc,0x88,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 35454 0x8a7e "詾" */
+0x21,0x11,0x01,0xfd,0x02,0x7a,0x05,0x78,0x02,0x7a,0x4b,0x4a,0x4b,0x78,0x48,0x00,
+0x00,0x00,0x00,0xfe,0x02,0x02,0x12,0xa2,0x4a,0xaa,0x1a,0x0a,0xfa,0x02,0x14,0x08,
+/* 35455 0x8a7f "詿" */
+0x20,0x10,0x01,0xfc,0x00,0x78,0x03,0x78,0x00,0x78,0x49,0x48,0x48,0x78,0x4b,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35456 0x8a80 "誀" */
+0x20,0x13,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x47,0x44,0x7c,0x44,0x00,
+0x00,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x8e,0xf8,0x08,0x08,0x08,0x08,
+/* 35457 0x8a81 "誁" */
+0x21,0x10,0x00,0xfc,0x01,0x78,0x00,0x78,0x00,0x7b,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 35458 0x8a82 "誂" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7c,0x00,0x7d,0x46,0x44,0x44,0x7c,0x45,0x02,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 35459 0x8a83 "誃" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x01,0x7c,0x44,0x45,0x44,0x7c,0x44,0x01,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 35460 0x8a84 "誄" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x00,0x78,0x03,0x78,0x48,0x48,0x49,0x7a,0x44,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 35461 0x8a85 "誅" */
+0x20,0x11,0x01,0xfd,0x01,0x7a,0x00,0x7b,0x00,0x78,0x48,0x49,0x49,0x7a,0x48,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 35462 0x8a86 "誆" */
+0x20,0x13,0x02,0xfe,0x03,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 35463 0x8a87 "誇" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x02,0x78,0x03,0x78,0x48,0x49,0x48,0x78,0x48,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 35464 0x8a88 "誈" */
+0x20,0x11,0x00,0xfc,0x00,0x79,0x01,0x78,0x00,0x78,0x49,0x48,0x48,0x78,0x4b,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 35465 0x8a89 "誉" */
+0x22,0x11,0x11,0x00,0xff,0x08,0x11,0x2f,0xc0,0x1f,0x00,0x1f,0x00,0x1f,0x10,0x1f,
+0x08,0x08,0x10,0x20,0xfe,0x20,0x10,0xe8,0x06,0xf0,0x00,0xf0,0x00,0xf0,0x10,0xf0,
+/* 35466 0x8a8a "誊" */
+0x11,0x09,0x09,0x7f,0x02,0xff,0x09,0x3f,0xc0,0x1f,0x00,0x1f,0x00,0x1f,0x10,0x1f,
+0x10,0x10,0x20,0xfc,0x00,0xfe,0x20,0xf8,0x06,0xf0,0x00,0xf0,0x00,0xf0,0x10,0xf0,
+/* 35467 0x8a8b "誋" */
+0x20,0x11,0x00,0xfc,0x01,0x79,0x01,0x79,0x00,0x78,0x48,0x48,0x4a,0x7a,0x44,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x04,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 35468 0x8a8c "誌" */
+0x20,0x10,0x00,0xfb,0x00,0x78,0x00,0x79,0x00,0x78,0x48,0x4a,0x4a,0x7a,0x4c,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 35469 0x8a8d "認" */
+0x20,0x13,0x00,0xfd,0x01,0x7a,0x00,0x79,0x02,0x78,0x48,0x4a,0x4a,0x7a,0x44,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x84,0x94,0x08,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 35470 0x8a8e "誎" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x01,0x79,0x01,0x78,0x48,0x48,0x49,0x7a,0x48,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 35471 0x8a8f "誏" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 35472 0x8a90 "誐" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x00,0x78,0x00,0x78,0x4b,0x48,0x48,0x78,0x4a,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 35473 0x8a91 "誑" */
+0x40,0x24,0x02,0xf9,0x02,0x74,0x00,0x70,0x01,0x72,0x54,0x50,0x50,0x70,0x55,0x02,
+0x00,0x40,0xbe,0x08,0x88,0x88,0x88,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x3e,0x00,
+/* 35474 0x8a92 "誒" */
+0x20,0x10,0x00,0xfd,0x03,0x78,0x00,0x79,0x02,0x78,0x4b,0x48,0x48,0x78,0x49,0x06,
+0x20,0x40,0x88,0x04,0xfe,0x82,0x80,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 35475 0x8a93 "誓" */
+0x08,0x7e,0x08,0x0e,0x78,0x0a,0x19,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x0c,0xf0,0x80,0xfe,0x88,0x88,0x08,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35476 0x8a94 "誔" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x01,0x7b,0x00,0x7a,0x4a,0x49,0x49,0x7a,0x44,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 35477 0x8a95 "誕" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x01,0x7b,0x00,0x7a,0x4a,0x49,0x49,0x7a,0x44,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 35478 0x8a96 "誖" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x02,0x7c,0x01,0x78,0x48,0x4b,0x48,0x78,0x48,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 35479 0x8a97 "誗" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x03,0x78,0x01,0x79,0x4a,0x4a,0x4c,0x78,0x48,0x00,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 35480 0x8a98 "誘" */
+0x20,0x11,0x00,0xfc,0x03,0x78,0x01,0x7a,0x01,0x78,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 35481 0x8a99 "誙" */
+0x20,0x11,0x00,0xfc,0x01,0x7a,0x01,0x78,0x00,0x79,0x48,0x48,0x48,0x78,0x4b,0x00,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35482 0x8a9a "誚" */
+0x20,0x11,0x10,0xfe,0x00,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 35483 0x8a9b "誛" */
+0x20,0x11,0x00,0xfc,0x00,0x79,0x00,0x7b,0x02,0x79,0x48,0x48,0x48,0x78,0x48,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 35484 0x8a9c "誜" */
+0x20,0x10,0x00,0xfd,0x03,0x78,0x00,0x79,0x02,0x78,0x49,0x4a,0x48,0x78,0x49,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 35485 0x8a9d "誝" */
+0x20,0x10,0x10,0xfe,0x01,0x7e,0x00,0x7c,0x00,0x7c,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35486 0x8a9e "語" */
+0x20,0x13,0x00,0xfc,0x01,0x78,0x00,0x7b,0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xfc,0x40,0x40,0xf8,0x88,0x88,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 35487 0x8a9f "誟" */
+0x20,0x10,0x11,0xfe,0x00,0x7d,0x00,0x7c,0x01,0x7c,0x45,0x46,0x44,0x7c,0x44,0x00,
+0x20,0x22,0xfa,0x24,0x24,0xfe,0x10,0x20,0xfc,0x88,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 35488 0x8aa0 "誠" */
+0x20,0x10,0x00,0xfc,0x03,0x7a,0x02,0x7a,0x03,0x7a,0x4a,0x4a,0x4a,0x7d,0x44,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 35489 0x8aa1 "誡" */
+0x20,0x10,0x00,0xfc,0x03,0x78,0x01,0x79,0x07,0x79,0x49,0x49,0x4a,0x7a,0x44,0x00,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x50,0x54,0xf4,0x54,0x54,0x48,0x4a,0x5a,0x26,0x42,
+/* 35490 0x8aa2 "誢" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x48,0x48,0x79,0x4a,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 35491 0x8aa3 "誣" */
+0x20,0x11,0x00,0xfc,0x01,0x79,0x01,0x79,0x02,0x7a,0x4c,0x48,0x48,0x78,0x4b,0x00,
+0x00,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0xaa,0xaa,0xb2,0x20,0x20,0x20,0xfe,0x00,
+/* 35492 0x8aa4 "誤" */
+0x20,0x11,0x01,0xfd,0x01,0x78,0x00,0x79,0x00,0x78,0x4b,0x48,0x48,0x78,0x49,0x02,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 35493 0x8aa5 "誥" */
+0x20,0x11,0x01,0xfd,0x01,0x7a,0x00,0x7b,0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35494 0x8aa6 "誦" */
+0x20,0x11,0x10,0xfe,0x00,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 35495 0x8aa7 "誧" */
+0x20,0x10,0x11,0xfe,0x00,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 35496 0x8aa8 "誨" */
+0x20,0x10,0x10,0xfd,0x02,0x7c,0x00,0x7c,0x03,0x7c,0x45,0x45,0x45,0x7c,0x44,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 35497 0x8aa9 "誩" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 35498 0x8aaa "說" */
+0x20,0x10,0x00,0xfd,0x02,0x7d,0x01,0x79,0x01,0x79,0x48,0x48,0x48,0x79,0x4a,0x04,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 35499 0x8aab "誫" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 35500 0x8aac "説" */
+0x21,0x10,0x00,0xfc,0x01,0x79,0x01,0x79,0x01,0x78,0x48,0x48,0x48,0x79,0x4a,0x04,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 35501 0x8aad "読" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x7a,0x04,0x78,0x48,0x48,0x48,0x79,0x49,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0x04,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 35502 0x8aae "誮" */
+0x20,0x10,0x13,0xfc,0x00,0x7c,0x00,0x7c,0x01,0x7e,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x88,0x88,0xfe,0x88,0x88,0x50,0x50,0x94,0x94,0x98,0x90,0xb2,0xd2,0x92,0x8e,0x80,
+/* 35503 0x8aaf "誯" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7c,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 35504 0x8ab0 "誰" */
+0x20,0x10,0x00,0xfd,0x01,0x7b,0x05,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 35505 0x8ab1 "誱" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x01,0x78,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 35506 0x8ab2 "課" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x00,0x7b,0x48,0x48,0x49,0x7a,0x48,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 35507 0x8ab3 "誳" */
+0x40,0x23,0x02,0xfa,0x03,0x72,0x02,0x72,0x02,0x72,0x52,0x52,0x52,0x74,0x54,0x08,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 35508 0x8ab4 "誴" */
+0x20,0x10,0x03,0xfa,0x00,0x79,0x00,0x78,0x03,0x78,0x49,0x49,0x4a,0x7c,0x48,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 35509 0x8ab5 "誵" */
+0x21,0x10,0x00,0xfc,0x03,0x78,0x03,0x78,0x00,0x79,0x4a,0x48,0x48,0x78,0x48,0x00,
+0x84,0x68,0x30,0xc8,0x24,0x20,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 35510 0x8ab6 "誶" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x01,0x7a,0x00,0x78,0x4b,0x48,0x48,0x78,0x48,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 35511 0x8ab7 "誷" */
+0x20,0x13,0x02,0xfe,0x02,0x7b,0x02,0x7a,0x03,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 35512 0x8ab8 "誸" */
+0x20,0x13,0x00,0xfc,0x00,0x7b,0x02,0x7a,0x02,0x7b,0x48,0x48,0x48,0x78,0x4a,0x01,
+0x10,0x88,0x88,0xfe,0x90,0x90,0x24,0x24,0x38,0x88,0x90,0x90,0xa4,0xbe,0x82,0x00,
+/* 35513 0x8ab9 "誹" */
+0x20,0x10,0x00,0xfb,0x00,0x78,0x00,0x79,0x00,0x78,0x48,0x48,0x4b,0x78,0x48,0x00,
+0x50,0x50,0x50,0xde,0x50,0x50,0x50,0xdc,0x50,0x50,0x50,0x50,0xde,0x50,0x50,0x50,
+/* 35514 0x8aba "誺" */
+0x20,0x10,0x00,0xfb,0x00,0x79,0x01,0x79,0x02,0x78,0x48,0x48,0x49,0x7a,0x4c,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 35515 0x8abb "誻" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x02,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35516 0x8abc "誼" */
+0x20,0x10,0x01,0xfd,0x02,0x78,0x00,0x78,0x00,0x78,0x48,0x48,0x48,0x78,0x4b,0x00,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,
+/* 35517 0x8abd "誽" */
+0x20,0x10,0x03,0xfa,0x02,0x7b,0x02,0x7a,0x03,0x78,0x48,0x48,0x48,0x79,0x4a,0x04,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 35518 0x8abe "誾" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x5f,0x40,0x4f,0x40,0x4f,0x40,0x4f,0x48,0x4f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x04,0xe4,0x04,0xe4,0x24,0xe4,0x0c,
+/* 35519 0x8abf "調" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 35520 0x8ac0 "諀" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x78,0x49,0x4b,0x48,0x78,0x48,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 35521 0x8ac1 "諁" */
+0x20,0x13,0x00,0xfd,0x00,0x79,0x02,0x7c,0x00,0x7b,0x48,0x49,0x48,0x79,0x4a,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 35522 0x8ac2 "諂" */
+0x20,0x10,0x00,0xfc,0x01,0x7a,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 35523 0x8ac3 "諃" */
+0x20,0x10,0x00,0xfc,0x03,0x78,0x00,0x79,0x01,0x7a,0x4a,0x4c,0x48,0x78,0x48,0x00,
+0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x9c,0xdc,0xaa,0xaa,0xc8,0x88,0x88,0x88,0x88,
+/* 35524 0x8ac4 "諄" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x78,0x01,0x78,0x48,0x4b,0x48,0x78,0x48,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 35525 0x8ac5 "諅" */
+0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x11,0x3f,0xc0,0x1f,0x00,0x1f,0x10,0x1f,
+0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,0xfe,0x10,0xf8,0x06,0xf0,0x00,0xf0,0x10,0xf0,
+/* 35526 0x8ac6 "諆" */
+0x20,0x10,0x13,0xfc,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x47,0x44,0x7c,0x45,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 35527 0x8ac7 "談" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x03,0x78,0x00,0x78,0x48,0x49,0x48,0x78,0x49,0x02,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 35528 0x8ac8 "諈" */
+0x20,0x10,0x01,0xfc,0x03,0x78,0x00,0x78,0x03,0x78,0x48,0x4b,0x48,0x78,0x49,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 35529 0x8ac9 "諉" */
+0x20,0x11,0x00,0xfc,0x03,0x78,0x01,0x7a,0x00,0x7b,0x48,0x49,0x48,0x78,0x48,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 35530 0x8aca "諊" */
+0x20,0x10,0x00,0xfd,0x02,0x7a,0x01,0x78,0x03,0x78,0x48,0x49,0x4a,0x78,0x48,0x00,
+0x80,0x80,0xfe,0x02,0x42,0x4a,0x52,0x42,0xfe,0x42,0xe2,0x52,0x4a,0x42,0x54,0x08,
+/* 35531 0x8acb "請" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 35532 0x8acc "諌" */
+0x20,0x10,0x13,0xfc,0x01,0x7d,0x01,0x7d,0x01,0x7c,0x44,0x44,0x45,0x7e,0x44,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 35533 0x8acd "諍" */
+0x20,0x10,0x01,0xfd,0x02,0x7d,0x00,0x78,0x03,0x78,0x48,0x49,0x48,0x78,0x48,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 35534 0x8ace "諎" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 35535 0x8acf "諏" */
+0x20,0x17,0x02,0xfa,0x02,0x7b,0x02,0x7a,0x03,0x7a,0x4a,0x4a,0x4f,0x78,0x48,0x00,
+0x00,0xe0,0x5e,0x52,0x52,0xd2,0x52,0x54,0xd4,0x54,0x48,0xe8,0x54,0x54,0x62,0x40,
+/* 35536 0x8ad0 "諐" */
+0x17,0x24,0x67,0xa2,0x24,0x28,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0xf8,0x08,0xf8,0xa0,0xa4,0x9c,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35537 0x8ad1 "諑" */
+0x20,0x13,0x00,0xfc,0x01,0x7a,0x00,0x7a,0x01,0x7a,0x48,0x48,0x49,0x7a,0x48,0x00,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 35538 0x8ad2 "諒" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x01,0x79,0x01,0x79,0x48,0x48,0x49,0x7a,0x48,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 35539 0x8ad3 "諓" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7d,0x00,0x7c,0x45,0x44,0x44,0x7c,0x44,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 35540 0x8ad4 "諔" */
+0x41,0x21,0x01,0xf9,0x01,0x71,0x07,0x70,0x01,0x71,0x55,0x55,0x59,0x71,0x55,0x02,
+0x00,0x00,0xdc,0x14,0x14,0x14,0xd4,0x14,0x14,0x14,0x88,0x48,0x48,0x14,0x14,0x22,
+/* 35541 0x8ad5 "諕" */
+0x20,0x10,0x00,0xfc,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x4a,0x7a,0x44,0x09,
+0x20,0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 35542 0x8ad6 "論" */
+0x20,0x10,0x00,0xfc,0x01,0x7a,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 35543 0x8ad7 "諗" */
+0x20,0x10,0x00,0xfc,0x01,0x7a,0x01,0x78,0x00,0x78,0x48,0x4a,0x4a,0x7a,0x44,0x00,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 35544 0x8ad8 "諘" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x00,0x78,0x03,0x78,0x48,0x49,0x4a,0x7c,0x48,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 35545 0x8ad9 "諙" */
+0x20,0x13,0x02,0xfb,0x02,0x7a,0x03,0x7a,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35546 0x8ada "諚" */
+0x20,0x10,0x10,0xfe,0x01,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x02,
+0x20,0x10,0xfe,0x82,0x04,0x00,0xfe,0x10,0x10,0x90,0x9e,0x90,0x90,0xd0,0x3e,0x00,
+/* 35547 0x8adb "諛" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x48,0x48,0x78,0x49,0x02,
+0x20,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x24,0x50,0x50,0x88,0x04,0x02,
+/* 35548 0x8adc "諜" */
+0x20,0x11,0x01,0xfb,0x01,0x79,0x01,0x79,0x01,0x78,0x4b,0x48,0x48,0x79,0x4e,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35549 0x8add "諝" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x02,0x7c,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 35550 0x8ade "諞" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x4a,0x4a,0x7a,0x44,0x00,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 35551 0x8adf "諟" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x00,0x7b,0x48,0x49,0x49,0x79,0x4a,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 35552 0x8ae0 "諠" */
+0x20,0x10,0x03,0xfa,0x04,0x79,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x78,0x4b,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 35553 0x8ae1 "諡" */
+0x20,0x11,0x02,0xfc,0x00,0x78,0x00,0x78,0x00,0x79,0x49,0x49,0x49,0x79,0x4b,0x00,
+0x88,0x04,0xfa,0x40,0x80,0xf8,0x08,0x50,0x20,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35554 0x8ae2 "諢" */
+0x20,0x13,0x02,0xfc,0x03,0x78,0x01,0x79,0x01,0x79,0x49,0x48,0x4b,0x78,0x48,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35555 0x8ae3 "諣" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x00,0x7d,0x01,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,
+0x00,0xfc,0x84,0x84,0xf4,0x94,0x94,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 35556 0x8ae4 "諤" */
+0x20,0x13,0x02,0xfe,0x03,0x78,0x01,0x78,0x03,0x78,0x49,0x49,0x48,0x78,0x48,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 35557 0x8ae5 "諥" */
+0x20,0x10,0x01,0xfc,0x03,0x78,0x01,0x79,0x01,0x79,0x49,0x48,0x49,0x78,0x4b,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 35558 0x8ae6 "諦" */
+0x20,0x10,0x01,0xfc,0x00,0x78,0x03,0x7a,0x04,0x79,0x49,0x49,0x49,0x79,0x48,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 35559 0x8ae7 "諧" */
+0x21,0x11,0x01,0xfd,0x01,0x79,0x01,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35560 0x8ae8 "諨" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x01,0x78,0x03,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 35561 0x8ae9 "諩" */
+0x20,0x10,0x00,0xfd,0x00,0x78,0x00,0x7a,0x01,0x79,0x48,0x48,0x48,0x78,0x4b,0x00,
+0x84,0x48,0x00,0xfe,0x48,0x48,0x48,0x48,0x4a,0x4c,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 35562 0x8aea "諪" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x78,0x03,0x7a,0x49,0x48,0x48,0x78,0x48,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x20,0x20,0x20,0xa0,0x40,
+/* 35563 0x8aeb "諫" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x79,0x01,0x79,0x48,0x48,0x48,0x79,0x4a,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 35564 0x8aec "諬" */
+0x0c,0x70,0x11,0xfe,0x38,0x54,0x91,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x28,0x24,0xfe,0x50,0x52,0x8e,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35565 0x8aed "諭" */
+0x20,0x10,0x01,0xfa,0x05,0x78,0x03,0x7a,0x02,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 35566 0x8aee "諮" */
+0x20,0x11,0x00,0xfc,0x00,0x7b,0x01,0x79,0x01,0x78,0x48,0x48,0x48,0x78,0x48,0x00,
+0x20,0x20,0xbe,0x42,0x84,0x10,0x10,0x28,0x44,0x82,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 35567 0x8aef "諯" */
+0x20,0x11,0x01,0xfd,0x01,0x78,0x03,0x78,0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 35568 0x8af0 "諰" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x00,0x78,0x48,0x4a,0x4a,0x7c,0x48,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 35569 0x8af1 "諱" */
+0x20,0x10,0x01,0xfc,0x03,0x78,0x01,0x79,0x01,0x78,0x4b,0x48,0x4a,0x7b,0x48,0x00,
+0x40,0x40,0xfc,0x84,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 35570 0x8af2 "諲" */
+0x20,0x13,0x00,0xfc,0x01,0x79,0x01,0x79,0x01,0x78,0x48,0x49,0x48,0x78,0x4b,0x00,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 35571 0x8af3 "諳" */
+0x20,0x10,0x11,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x10,0xfe,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 35572 0x8af4 "諴" */
+0x20,0x10,0x00,0xfb,0x02,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x04,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 35573 0x8af5 "諵" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x8a,0x52,0xfa,0x22,0x22,0xfa,0x22,0x22,0x2a,0x04,
+/* 35574 0x8af6 "諶" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x00,0x78,0x00,0x7b,0x49,0x49,0x49,0x79,0x49,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 35575 0x8af7 "諷" */
+0x40,0x27,0x04,0xfc,0x05,0x74,0x05,0x75,0x05,0x75,0x54,0x54,0x55,0x74,0x58,0x10,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x94,0x06,0x02,
+/* 35576 0x8af8 "諸" */
+0x20,0x10,0x01,0xfc,0x00,0x7b,0x00,0x78,0x00,0x79,0x4a,0x48,0x48,0x78,0x48,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 35577 0x8af9 "諹" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x00,0x7b,0x01,0x79,0x4a,0x4c,0x49,0x7a,0x48,0x01,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x54,0x94,0x24,0x44,0xa8,0x10,
+/* 35578 0x8afa "諺" */
+0x20,0x10,0x01,0xfc,0x00,0x78,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x20,0x10,0xfe,0x00,0x84,0x48,0xfe,0x08,0x10,0x64,0x08,0x12,0x64,0x08,0x30,0xc0,
+/* 35579 0x8afb "諻" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x78,0x03,0x78,0x48,0x49,0x48,0x78,0x4b,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 35580 0x8afc "諼" */
+0x20,0x13,0x00,0xfd,0x00,0x79,0x00,0x78,0x03,0x78,0x48,0x49,0x49,0x7a,0x48,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 35581 0x8afd "諽" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x01,0x79,0x01,0x79,0x48,0x4b,0x48,0x78,0x48,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 35582 0x8afe "諾" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x03,0x78,0x00,0x78,0x49,0x4a,0x48,0x78,0x48,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 35583 0x8aff "諿" */
+0x20,0x10,0x10,0xfe,0x00,0x7c,0x01,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7d,0x44,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 35584 0x8b00 "謀" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x00,0x78,0x00,0x78,0x4b,0x48,0x48,0x79,0x4a,0x00,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35585 0x8b01 "謁" */
+0x20,0x11,0x11,0xfd,0x01,0x7d,0x00,0x7d,0x02,0x7d,0x45,0x45,0x45,0x7c,0x44,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 35586 0x8b02 "謂" */
+0x20,0x13,0x02,0xfb,0x02,0x7b,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xfe,0x22,0xfe,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 35587 0x8b03 "謃" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x00,0x79,0x01,0x7a,0x48,0x49,0x48,0x78,0x4b,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 35588 0x8b04 "謄" */
+0x02,0x79,0x4b,0x48,0x4f,0x79,0x4a,0x4f,0x48,0x7b,0x48,0x4b,0x48,0x4b,0x4a,0x9b,
+0x48,0x50,0xf8,0x80,0xfc,0x10,0x48,0xfc,0x02,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35589 0x8b05 "謅" */
+0x20,0x10,0x10,0xfd,0x00,0x7c,0x00,0x7c,0x01,0x7c,0x45,0x46,0x44,0x7c,0x44,0x01,
+0x40,0x40,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x48,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x08,
+/* 35590 0x8b06 "謆" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x66,
+/* 35591 0x8b07 "謇" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x09,0x1f,0x20,0xdf,0x00,0x1f,0x10,0x1f,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x08,0xf6,0x00,0xf0,0x10,0xf0,
+/* 35592 0x8b08 "謈" */
+0x1f,0x10,0x1f,0x10,0x1f,0x08,0x7f,0x08,0xff,0x0a,0x31,0xdf,0x00,0x0f,0x08,0x0f,
+0xf0,0x10,0xf0,0x10,0xf0,0x20,0xfc,0x20,0xfe,0x20,0x18,0xf6,0x00,0xe0,0x20,0xe0,
+/* 35593 0x8b09 "謉" */
+0x20,0x10,0x03,0xfe,0x02,0x7b,0x02,0x7a,0x03,0x78,0x48,0x48,0x49,0x79,0x4a,0x04,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 35594 0x8b0a "謊" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x00,0x78,0x00,0x78,0x48,0x48,0x48,0x78,0x49,0x02,
+0x88,0x88,0xfe,0xa8,0x10,0xfe,0x80,0x80,0xfc,0x00,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 35595 0x8b0b "謋" */
+0x42,0x22,0x03,0xf4,0x0a,0x71,0x02,0x74,0x08,0x77,0x50,0x51,0x52,0x7c,0x50,0x00,
+0x08,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x48,0x48,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 35596 0x8b0c "謌" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x00,0x7b,0x00,0x79,0x49,0x49,0x49,0x78,0x48,0x00,
+0x00,0xfe,0x08,0xe8,0x28,0xe8,0x00,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x08,0x28,0x10,
+/* 35597 0x8b0d "謍" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x41,0xbf,0x00,0x1f,0x00,0x1f,0x00,0x1f,0x10,0x1f,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x10,0xf0,
+/* 35598 0x8b0e "謎" */
+0x20,0x10,0x02,0xfd,0x01,0x78,0x00,0x7b,0x01,0x79,0x49,0x49,0x49,0x7a,0x4c,0x00,
+0x10,0x94,0x54,0x58,0x10,0x7e,0x10,0x30,0x38,0x54,0x94,0x10,0x10,0x80,0x7e,0x00,
+/* 35599 0x8b0f "謏" */
+0x20,0x11,0x11,0xfd,0x01,0x7d,0x01,0x7d,0x00,0x7d,0x44,0x44,0x44,0x7c,0x44,0x03,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 35600 0x8b10 "謐" */
+0x40,0x20,0x00,0xfa,0x02,0x74,0x01,0x76,0x00,0x73,0x52,0x52,0x52,0x72,0x57,0x00,
+0x40,0x28,0x90,0xa4,0xc2,0x8a,0x88,0x78,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 35601 0x8b11 "謑" */
+0x20,0x13,0x01,0xfc,0x00,0x78,0x01,0x78,0x00,0x79,0x48,0x48,0x4b,0x78,0x48,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 35602 0x8b12 "謒" */
+0x20,0x10,0x00,0xfc,0x00,0x79,0x02,0x78,0x00,0x78,0x48,0x48,0x49,0x79,0x4a,0x00,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 35603 0x8b13 "謓" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x4b,0x78,0x49,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 35604 0x8b14 "謔" */
+0x40,0x20,0x00,0xfb,0x02,0x72,0x03,0x72,0x02,0x72,0x52,0x52,0x53,0x74,0x54,0x08,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc0,0x44,0x3c,0x00,0xfc,0x80,0xfe,0x80,0x80,0xfc,
+/* 35605 0x8b15 "謕" */
+0x40,0x20,0x03,0xfa,0x02,0x72,0x02,0x72,0x02,0x72,0x52,0x52,0x52,0x74,0x55,0x0a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 35606 0x8b16 "謖" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x00,0x79,0x02,0x78,0x49,0x4a,0x48,0x78,0x49,0x06,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 35607 0x8b17 "謗" */
+0x20,0x10,0x03,0xfd,0x00,0x7b,0x02,0x7c,0x00,0x7b,0x48,0x48,0x48,0x79,0x49,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 35608 0x8b18 "謘" */
+0x20,0x13,0x02,0xfa,0x03,0x7a,0x02,0x7b,0x02,0x7a,0x4b,0x4a,0x4d,0x7c,0x48,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0x20,
+/* 35609 0x8b19 "謙" */
+0x20,0x10,0x00,0xfd,0x00,0x79,0x00,0x7b,0x00,0x79,0x48,0x48,0x49,0x7a,0x48,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 35610 0x8b1a "謚" */
+0x21,0x10,0x00,0xfc,0x03,0x78,0x00,0x79,0x02,0x79,0x49,0x49,0x49,0x79,0x47,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35611 0x8b1b "講" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x01,0x79,0x49,0x49,0x4b,0x79,0x49,0x01,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 35612 0x8b1c "謜" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 35613 0x8b1d "謝" */
+0x40,0x21,0x03,0xfa,0x03,0x72,0x03,0x72,0x02,0x77,0x50,0x51,0x52,0x74,0x51,0x00,
+0x84,0x04,0xc4,0x44,0xde,0x44,0xc4,0x64,0x54,0xd4,0xc4,0x44,0x44,0x44,0x54,0x88,
+/* 35614 0x8b1e "謞" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x78,0x03,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 35615 0x8b1f "謟" */
+0x20,0x13,0x00,0xfa,0x01,0x79,0x00,0x7b,0x02,0x7a,0x4b,0x4a,0x4a,0x7a,0x4b,0x02,
+0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 35616 0x8b20 "謠" */
+0x20,0x10,0x01,0xfa,0x01,0x78,0x03,0x79,0x02,0x78,0x4b,0x48,0x49,0x79,0x49,0x00,
+0x40,0x80,0xfc,0x48,0x30,0xc0,0x00,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0xfc,0x04,
+/* 35617 0x8b21 "謡" */
+0x20,0x10,0x03,0xf8,0x02,0x79,0x01,0x7a,0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 35618 0x8b22 "謢" */
+0x20,0x10,0x01,0xfb,0x01,0x79,0x01,0x79,0x01,0x79,0x4b,0x49,0x48,0x78,0x49,0x06,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf8,0x08,0x90,0x60,0x98,0x06,
+/* 35619 0x8b23 "謣" */
+0x21,0x10,0x03,0xfe,0x01,0x78,0x01,0x78,0x01,0x78,0x4b,0x48,0x48,0x78,0x48,0x00,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x28,0x10,
+/* 35620 0x8b24 "謤" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x01,0x78,0x01,0x78,0x4b,0x48,0x48,0x79,0x4a,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 35621 0x8b25 "謥" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x48,0x48,0x49,0x79,0x49,0x02,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 35622 0x8b26 "謦" */
+0x08,0xff,0x08,0x3e,0x2a,0x3e,0x41,0xff,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x78,0x48,0x86,0x78,0x48,0x30,0x48,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35623 0x8b27 "謧" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x79,0x00,0x7b,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0x40,0x20,0xfe,0x00,0x54,0x24,0x54,0xfc,0x20,0xfe,0x42,0x92,0xfa,0x0a,0x02,0x06,
+/* 35624 0x8b28 "謨" */
+0x20,0x10,0x03,0xfc,0x00,0x79,0x01,0x79,0x01,0x79,0x48,0x4b,0x48,0x78,0x49,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 35625 0x8b29 "謩" */
+0x04,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x04,0xff,0x11,0x2f,0xc0,0x0f,0x08,0x0f,
+0x40,0xfc,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x10,0xe8,0x06,0xe0,0x20,0xe0,
+/* 35626 0x8b2a "謪" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x02,0x7a,0x03,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x52,0x8a,0x06,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 35627 0x8b2b "謫" */
+0x20,0x10,0x03,0xfc,0x00,0x7b,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 35628 0x8b2c "謬" */
+0x20,0x13,0x00,0xfa,0x01,0x7a,0x00,0x78,0x03,0x78,0x49,0x48,0x49,0x78,0x48,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 35629 0x8b2d "謭" */
+0x21,0x10,0x07,0xf8,0x03,0x7a,0x03,0x7a,0x03,0x7a,0x4a,0x48,0x4b,0x78,0x49,0x06,
+0x08,0x90,0xfe,0x00,0xc4,0x54,0xd4,0x54,0xd4,0x44,0xcc,0x00,0xfc,0x84,0x14,0x08,
+/* 35630 0x8b2e "謮" */
+0x20,0x13,0x00,0xfd,0x00,0x7b,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35631 0x8b2f "謯" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x02,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,
+/* 35632 0x8b30 "謰" */
+0x20,0x10,0x02,0xfd,0x01,0x78,0x00,0x7b,0x01,0x79,0x49,0x49,0x49,0x7a,0x44,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 35633 0x8b31 "謱" */
+0x20,0x11,0x01,0xfb,0x01,0x79,0x00,0x79,0x01,0x79,0x48,0x4b,0x48,0x79,0x48,0x03,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 35634 0x8b32 "謲" */
+0x20,0x10,0x01,0xfd,0x02,0x7b,0x00,0x79,0x06,0x78,0x4b,0x48,0x4b,0x78,0x48,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 35635 0x8b33 "謳" */
+0x20,0x13,0x02,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4b,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 35636 0x8b34 "謴" */
+0x20,0x11,0x01,0xfb,0x01,0x79,0x00,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x01,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35637 0x8b35 "謵" */
+0x20,0x13,0x00,0xfa,0x01,0x7a,0x00,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35638 0x8b36 "謶" */
+0x20,0x10,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x4a,0x7a,0x45,0x08,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0xd4,0xaa,0x2a,0x00,
+/* 35639 0x8b37 "謷" */
+0x08,0x7e,0x08,0xfe,0x10,0x1e,0x22,0x46,0x81,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35640 0x8b38 "謸" */
+0x41,0x21,0x01,0xf7,0x01,0x77,0x01,0x7f,0x02,0x73,0x52,0x52,0x52,0x74,0x54,0x08,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 35641 0x8b39 "謹" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x01,0x79,0x01,0x78,0x4b,0x48,0x49,0x78,0x4b,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 35642 0x8b3a "謺" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x09,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35643 0x8b3b "謻" */
+0x40,0x21,0x06,0xfa,0x02,0x72,0x0f,0x72,0x02,0x77,0x5a,0x52,0x52,0x72,0x52,0x02,
+0x10,0x90,0x1e,0x22,0x54,0x08,0x90,0x64,0x08,0x1e,0xa2,0x42,0x14,0x08,0x10,0x60,
+/* 35644 0x8b3c "謼" */
+0x20,0x10,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x4a,0x7a,0x44,0x00,
+0x40,0x7c,0x40,0xfc,0x44,0x78,0xc4,0x3c,0x04,0x78,0x94,0x58,0xfe,0x10,0x50,0x20,
+/* 35645 0x8b3d "謽" */
+0x7c,0x04,0x7c,0x40,0x7d,0x05,0x15,0x0a,0xff,0x00,0x3f,0x00,0x1f,0x10,0x1f,0x10,
+0xf8,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x22,0xfe,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x10,
+/* 35646 0x8b3e "謾" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x00,0x7b,0x02,0x7b,0x48,0x49,0x48,0x78,0x49,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 35647 0x8b3f "謿" */
+0x41,0x21,0x07,0xf9,0x01,0x77,0x04,0x77,0x04,0x77,0x51,0x51,0x5f,0x71,0x51,0x01,
+0x00,0x1e,0xd2,0x12,0x12,0xde,0x52,0xd2,0x52,0xde,0x12,0x12,0xd2,0x22,0x2a,0x44,
+/* 35648 0x8b40 "譀" */
+0x20,0x13,0x00,0xf9,0x07,0x7a,0x02,0x7b,0x02,0x7b,0x4a,0x4a,0x4b,0x7e,0x48,0x00,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 35649 0x8b41 "譁" */
+0x20,0x13,0x00,0xfc,0x01,0x78,0x00,0x7b,0x00,0x78,0x49,0x48,0x4b,0x78,0x48,0x00,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35650 0x8b42 "譂" */
+0x20,0x13,0x02,0xfe,0x03,0x78,0x01,0x79,0x01,0x79,0x49,0x48,0x4b,0x78,0x48,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35651 0x8b43 "譃" */
+0x40,0x20,0x00,0xfb,0x02,0x72,0x03,0x72,0x02,0x72,0x52,0x53,0x54,0x74,0x59,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0x50,0x54,0x54,0xd8,0x50,0xfe,0x00,
+/* 35652 0x8b44 "譄" */
+0x21,0x10,0x00,0xfb,0x02,0x7a,0x02,0x7a,0x03,0x78,0x49,0x49,0x49,0x79,0x49,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 35653 0x8b45 "譅" */
+0x40,0x27,0x01,0xfb,0x05,0x72,0x02,0x74,0x00,0x70,0x52,0x52,0x52,0x72,0x57,0x00,
+0x00,0xde,0x4a,0x5a,0x6a,0x52,0xd6,0x20,0x84,0x84,0xd4,0x96,0x94,0xd4,0x3e,0x00,
+/* 35654 0x8b46 "譆" */
+0x20,0x13,0x00,0xfd,0x00,0x79,0x01,0x79,0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 35655 0x8b47 "譇" */
+0x20,0x10,0x03,0xfc,0x01,0x7a,0x01,0x78,0x03,0x78,0x49,0x4e,0x48,0x78,0x48,0x00,
+0x20,0x20,0xfe,0x88,0x24,0x22,0xfc,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 35656 0x8b48 "譈" */
+0x42,0x21,0x07,0xf8,0x07,0x74,0x07,0x70,0x07,0x70,0x51,0x51,0x57,0x71,0x55,0x02,
+0x08,0x08,0xc8,0x10,0x9e,0x94,0xa4,0x14,0x94,0x94,0x14,0xc8,0x08,0x14,0x24,0x42,
+/* 35657 0x8b49 "證" */
+0x20,0x17,0x00,0xfa,0x01,0x7a,0x05,0x78,0x03,0x7a,0x4a,0x4b,0x4a,0x79,0x4f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 35658 0x8b4a "譊" */
+0x20,0x10,0x01,0xfc,0x03,0x79,0x03,0x79,0x01,0x7e,0x48,0x4b,0x48,0x78,0x49,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 35659 0x8b4b "譋" */
+0x23,0x12,0x03,0xfe,0x03,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7b,0x4a,0x02,
+0x9c,0x94,0x9c,0x94,0x9c,0x04,0xf4,0x94,0xf4,0x94,0xf4,0x94,0x94,0x34,0x04,0x0c,
+/* 35660 0x8b4c "譌" */
+0x40,0x23,0x00,0xfa,0x01,0x73,0x02,0x73,0x02,0x73,0x52,0x52,0x52,0x75,0x54,0x08,
+0x0e,0xf0,0x44,0x24,0x08,0xf8,0x08,0xfc,0x04,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 35661 0x8b4d "譍" */
+0x00,0x3f,0x22,0x25,0x2e,0x34,0x24,0x24,0x24,0x2f,0x20,0x27,0x40,0x47,0x84,0x07,
+0x80,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x40,0xfe,0x00,0xfc,0x00,0xfc,0x04,0xfc,
+/* 35662 0x8b4e "譎" */
+0x20,0x13,0x00,0xfc,0x03,0x78,0x00,0x7b,0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 35663 0x8b4f "譏" */
+0x21,0x11,0x02,0xfb,0x01,0x7a,0x03,0x79,0x07,0x79,0x49,0x49,0x4a,0x7a,0x4a,0x04,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 35664 0x8b50 "譐" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x79,0x01,0x79,0x48,0x4b,0x49,0x78,0x48,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 35665 0x8b51 "譑" */
+0x20,0x11,0x00,0xfb,0x00,0x79,0x02,0x78,0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 35666 0x8b52 "譒" */
+0x20,0x13,0x01,0xfc,0x03,0x78,0x01,0x7a,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 35667 0x8b53 "譓" */
+0x20,0x10,0x03,0xfc,0x01,0x79,0x01,0x79,0x01,0x78,0x4b,0x48,0x48,0x7a,0x4a,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 35668 0x8b54 "譔" */
+0x20,0x13,0x02,0xfb,0x02,0x7a,0x01,0x78,0x00,0x7b,0x48,0x48,0x4b,0x78,0x49,0x02,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 35669 0x8b55 "譕" */
+0x20,0x10,0x01,0xfb,0x05,0x79,0x03,0x79,0x01,0x79,0x4f,0x48,0x49,0x79,0x4a,0x00,
+0x80,0x80,0xfe,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0xfe,0x00,0x54,0x2a,0x2a,0x00,
+/* 35670 0x8b56 "譖" */
+0x20,0x13,0x00,0xfa,0x03,0x79,0x02,0x7c,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 35671 0x8b57 "譗" */
+0x22,0x12,0x03,0xfa,0x05,0x78,0x01,0x7a,0x05,0x78,0x48,0x4b,0x4a,0x7a,0x4b,0x02,
+0x10,0x10,0xde,0x28,0x44,0xa0,0x10,0x08,0xf6,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 35672 0x8b58 "識" */
+0x21,0x10,0x03,0xf8,0x02,0x79,0x07,0x78,0x03,0x7a,0x4a,0x4b,0x4a,0x7a,0x4b,0x00,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 35673 0x8b59 "譙" */
+0x20,0x10,0x01,0xfd,0x03,0x7d,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 35674 0x8b5a "譚" */
+0x20,0x13,0x00,0xfb,0x02,0x7b,0x00,0x79,0x01,0x79,0x49,0x49,0x48,0x7b,0x48,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 35675 0x8b5b "譛" */
+0x20,0x10,0x03,0xf8,0x07,0x78,0x01,0x7a,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x88,0x88,0xde,0x88,0xfe,0x88,0x54,0x22,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35676 0x8b5c "譜" */
+0x21,0x10,0x03,0xf8,0x02,0x79,0x00,0x7b,0x00,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x08,0x90,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 35677 0x8b5d "譝" */
+0x40,0x27,0x04,0xfc,0x07,0x70,0x07,0x74,0x04,0x77,0x54,0x54,0x57,0x74,0x50,0x00,
+0x00,0xfc,0xa4,0xa4,0xbc,0xa0,0xbc,0xa4,0xa4,0xbc,0xa4,0xa4,0xbc,0xa2,0xa2,0x7e,
+/* 35678 0x8b5e "譞" */
+0x20,0x11,0x01,0xfd,0x01,0x78,0x03,0x78,0x01,0x79,0x49,0x48,0x48,0x79,0x4a,0x00,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 35679 0x8b5f "譟" */
+0x20,0x10,0x00,0xfc,0x00,0x79,0x01,0x79,0x01,0x78,0x4b,0x48,0x48,0x79,0x4a,0x00,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 35680 0x8b60 "譠" */
+0x20,0x17,0x00,0xfb,0x02,0x7a,0x02,0x7b,0x00,0x79,0x49,0x49,0x49,0x79,0x48,0x07,
+0x20,0xfe,0x00,0xfe,0x02,0xfa,0x8a,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,
+/* 35681 0x8b61 "譡" */
+0x20,0x11,0x00,0xfb,0x02,0x78,0x00,0x78,0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 35682 0x8b62 "譢" */
+0x20,0x12,0x01,0xfc,0x00,0x78,0x03,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x4a,0x04,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 35683 0x8b63 "譣" */
+0x20,0x10,0x00,0xfc,0x01,0x7a,0x00,0x78,0x01,0x79,0x49,0x49,0x48,0x78,0x49,0x02,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 35684 0x8b64 "譤" */
+0x41,0x22,0x07,0xf4,0x07,0x74,0x07,0x72,0x01,0x77,0x52,0x53,0x52,0x74,0x55,0x08,
+0x08,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x14,0xd4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 35685 0x8b65 "譥" */
+0x10,0x7e,0x4a,0x7e,0x10,0xff,0x20,0x3e,0x43,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35686 0x8b66 "警" */
+0x24,0xff,0x24,0x7e,0x82,0x7a,0x4a,0x7a,0x05,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35687 0x8b67 "譧" */
+0x40,0x23,0x02,0xfa,0x03,0x72,0x02,0x72,0x03,0x72,0x52,0x52,0x52,0x75,0x56,0x08,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 35688 0x8b68 "譨" */
+0x40,0x23,0x02,0xfb,0x02,0x73,0x00,0x73,0x02,0x72,0x52,0x53,0x55,0x75,0x55,0x09,
+0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0x14,0x48,0x86,
+/* 35689 0x8b69 "譩" */
+0x20,0x10,0x01,0xfc,0x00,0x7b,0x00,0x79,0x01,0x79,0x49,0x49,0x48,0x7a,0x4a,0x04,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 35690 0x8b6a "譪" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x01,0x79,0x00,0x79,0x4a,0x4d,0x49,0x79,0x48,0x00,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 35691 0x8b6b "譫" */
+0x20,0x10,0x01,0xfb,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 35692 0x8b6c "譬" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35693 0x8b6d "譭" */
+0x41,0x26,0x04,0xfc,0x06,0x74,0x04,0x77,0x00,0x70,0x57,0x51,0x51,0x71,0x57,0x02,
+0x00,0xdc,0x54,0x54,0xd4,0x54,0x66,0xc0,0x1c,0x14,0xd4,0x14,0x08,0xc8,0x14,0x22,
+/* 35694 0x8b6e "譮" */
+0x20,0x10,0x10,0xfd,0x02,0x7d,0x01,0x7d,0x01,0x7d,0x44,0x44,0x44,0x7c,0x44,0x00,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 35695 0x8b6f "譯" */
+0x20,0x11,0x01,0xfd,0x00,0x79,0x00,0x7b,0x00,0x78,0x49,0x48,0x4b,0x78,0x48,0x00,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35696 0x8b70 "議" */
+0x21,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x01,0x78,0x4b,0x48,0x48,0x7b,0x48,0x01,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 35697 0x8b71 "譱" */
+0x08,0x7f,0x01,0x3f,0x01,0xff,0x11,0x7d,0x01,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x7d,
+0x20,0xfc,0x00,0xf8,0x00,0xfe,0x10,0x7c,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,
+/* 35698 0x8b72 "譲" */
+0x40,0x20,0x07,0xf9,0x02,0x75,0x03,0x71,0x03,0x71,0x57,0x51,0x53,0x7d,0x51,0x01,
+0x80,0x40,0xfe,0x10,0x08,0x14,0xf8,0x10,0xf8,0x10,0xfc,0x28,0x10,0x48,0x86,0x00,
+/* 35699 0x8b73 "譳" */
+0x20,0x11,0x00,0xfb,0x02,0x79,0x00,0x79,0x00,0x7b,0x48,0x49,0x49,0x79,0x49,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 35700 0x8b74 "譴" */
+0x20,0x10,0x02,0xfd,0x01,0x78,0x00,0x7b,0x01,0x79,0x49,0x49,0x49,0x79,0x4a,0x04,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x40,0x7c,0x44,0x7c,0x80,0x7e,
+/* 35701 0x8b75 "譵" */
+0x41,0x21,0x05,0xfb,0x01,0x77,0x00,0x72,0x01,0x77,0x50,0x53,0x50,0x70,0x57,0x00,
+0x44,0x44,0x54,0x64,0x5e,0xe4,0x04,0x34,0x4c,0xe4,0x84,0xe4,0x84,0xe4,0x14,0x08,
+/* 35702 0x8b76 "譶" */
+0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,0x08,0xfe,0x00,0x7c,0x00,0x7c,0x44,0x7c,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x00,0xfc,0x00,0xfc,0x84,0xfc,
+/* 35703 0x8b77 "護" */
+0x20,0x13,0x00,0xfc,0x01,0x7b,0x01,0x79,0x01,0x79,0x49,0x49,0x4b,0x78,0x48,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 35704 0x8b78 "譸" */
+0x20,0x13,0x00,0xfd,0x00,0x7b,0x00,0x79,0x00,0x7b,0x48,0x4b,0x48,0x7b,0x4a,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 35705 0x8b79 "譹" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x00,0x7b,0x02,0x79,0x48,0x4b,0x48,0x7b,0x48,0x03,
+0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x40,0xa4,0xd8,0x34,0xd2,0x30,
+/* 35706 0x8b7a "譺" */
+0x22,0x12,0x03,0xfa,0x01,0x78,0x02,0x7b,0x05,0x79,0x4f,0x49,0x4a,0x7a,0x4c,0x00,
+0x00,0xbe,0x02,0x54,0xc8,0x3e,0x0a,0xca,0x28,0x28,0xee,0x28,0xa8,0x58,0x4e,0x80,
+/* 35707 0x8b7b "譻" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x22,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35708 0x8b7c "譼" */
+0x7e,0x48,0x7e,0x43,0x7e,0x48,0x7e,0x02,0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x40,0x7e,0x90,0x08,0xfe,0xaa,0xfe,0x00,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35709 0x8b7d "譽" */
+0x0a,0x33,0x22,0x3b,0x20,0x3a,0x22,0xff,0x11,0x3f,0x40,0x9f,0x00,0x1f,0x10,0x1f,
+0x00,0xb8,0x08,0xb8,0x88,0xb8,0x88,0xfe,0x10,0xf8,0x04,0xf2,0x00,0xf0,0x10,0xf0,
+/* 35710 0x8b7e "譾" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x48,0x4b,0x4a,0x79,0x4a,0x00,
+0x88,0xfe,0x00,0xe2,0x2a,0xea,0x2a,0xea,0x22,0x66,0x00,0xde,0x52,0x4a,0x52,0xc6,
+/* 35711 0x8b7f "譿" */
+0x20,0x13,0x00,0xfd,0x00,0x7b,0x00,0x7b,0x00,0x79,0x48,0x4b,0x48,0x7a,0x4a,0x04,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0x8a,0x7a,
+/* 35712 0x8b80 "讀" */
+0x20,0x13,0x00,0xfd,0x00,0x7b,0x02,0x7b,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35713 0x8b81 "讁" */
+0x40,0x20,0x04,0xfa,0x02,0x70,0x00,0x76,0x02,0x72,0x52,0x52,0x52,0x75,0x58,0x00,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x92,0xfe,0x92,0xba,0xaa,0xba,0x86,0x00,0xfe,0x00,
+/* 35714 0x8b82 "讂" */
+0x21,0x11,0x02,0xff,0x02,0x7a,0x01,0x79,0x01,0x79,0x49,0x48,0x49,0x7a,0x48,0x03,
+0x00,0xf8,0x08,0xfe,0x62,0x92,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xf8,0x88,0x70,0x8e,
+/* 35715 0x8b83 "讃" */
+0x20,0x11,0x00,0xfb,0x00,0x79,0x02,0x79,0x01,0x79,0x49,0x49,0x49,0x79,0x48,0x01,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35716 0x8b84 "讄" */
+0x83,0x42,0x02,0xe3,0x02,0xe2,0x03,0xe0,0x0f,0xea,0xaa,0xaf,0xaa,0xea,0xaf,0x08,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 35717 0x8b85 "讅" */
+0x20,0x13,0x02,0xfc,0x03,0x79,0x00,0x7b,0x01,0x7a,0x4d,0x49,0x49,0x79,0x49,0x01,
+0x20,0xfe,0x02,0x1c,0xe0,0x24,0xa8,0xfe,0x24,0x02,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 35718 0x8b86 "讆" */
+0x22,0x4f,0x94,0x2f,0x61,0xaf,0x25,0x27,0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x00,0x9c,0x80,0xde,0x08,0xc8,0x08,0xd8,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35719 0x8b87 "讇" */
+0x23,0x12,0x03,0xfe,0x03,0x7a,0x02,0x7a,0x03,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0xde,0x52,0xde,0x52,0xde,0x42,0x7a,0x8a,0x12,0xda,0x8a,0xda,0x8a,0xfa,0x0a,0x04,
+/* 35720 0x8b88 "讈" */
+0x40,0x27,0x04,0xfd,0x04,0x75,0x04,0x75,0x06,0x74,0x54,0x55,0x55,0x75,0x55,0x0b,
+0x00,0xfe,0x44,0x98,0x88,0xfe,0x88,0xdc,0xaa,0x88,0x20,0x20,0x3c,0x20,0x20,0xfe,
+/* 35721 0x8b89 "讉" */
+0x20,0x10,0x02,0xfd,0x01,0x78,0x00,0x7b,0x01,0x79,0x49,0x49,0x49,0x79,0x4a,0x04,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x80,0x7e,
+/* 35722 0x8b8a "變" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x08,0x1f,0x28,0x07,0x18,0xe0,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf8,0x20,0xc0,0x30,0x0e,
+/* 35723 0x8b8b "讋" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x23,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35724 0x8b8c "讌" */
+0x41,0x21,0x07,0xf9,0x01,0x72,0x02,0x76,0x02,0x72,0x56,0x5a,0x50,0x72,0x52,0x04,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 35725 0x8b8d "讍" */
+0x20,0x13,0x00,0xfb,0x02,0x7a,0x03,0x78,0x03,0x78,0x4b,0x4a,0x4a,0x7b,0x48,0x03,
+0x00,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,
+/* 35726 0x8b8e "讎" */
+0x32,0x29,0x40,0x7b,0xd0,0x53,0x78,0x53,0x50,0x7b,0x52,0x52,0x52,0x7b,0x42,0x40,
+0x18,0x14,0x20,0xbe,0x68,0xa8,0x3e,0xa8,0x28,0xbe,0xa8,0xa8,0xa8,0xbe,0xa0,0x20,
+/* 35727 0x8b8f "讏" */
+0x22,0x4f,0x94,0x2f,0x62,0xaf,0x2a,0x2a,0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x00,0x9c,0x80,0xde,0x08,0xc8,0x48,0xd8,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35728 0x8b90 "讐" */
+0x48,0x7e,0xc9,0x7e,0x48,0x7e,0x48,0x7e,0x01,0xff,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0x90,0xfc,0x90,0xfc,0x90,0xfc,0x90,0xfc,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 35729 0x8b91 "讑" */
+0x80,0x40,0x01,0xe2,0x0d,0xe0,0x0e,0xea,0x0e,0xe0,0xaf,0xa9,0xaf,0xe9,0xa9,0x08,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xee,0xaa,0xee,0x00,0xfe,0x22,0xfe,0x22,0x2a,0x04,
+/* 35730 0x8b92 "讒" */
+0x21,0x12,0x07,0xfa,0x03,0x7a,0x03,0x7a,0x01,0x7a,0x4f,0x4a,0x4b,0x78,0x49,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 35731 0x8b93 "讓" */
+0x20,0x13,0x00,0xfd,0x01,0x79,0x00,0x7b,0x00,0x7b,0x48,0x4b,0x48,0x79,0x4a,0x00,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 35732 0x8b94 "讔" */
+0x40,0x27,0x05,0xfd,0x05,0x76,0x05,0x75,0x05,0x75,0x55,0x56,0x54,0x74,0x54,0x04,
+0x0e,0x70,0x2a,0x14,0x3e,0x08,0x7e,0x00,0x7e,0x02,0x3e,0x02,0x7e,0x14,0xaa,0xba,
+/* 35733 0x8b95 "讕" */
+0x23,0x12,0x03,0xfe,0x03,0x7a,0x02,0x7a,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 35734 0x8b96 "讖" */
+0x21,0x11,0x02,0xfc,0x03,0x79,0x03,0x79,0x03,0x79,0x4b,0x49,0x49,0x7b,0x48,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4a,0x6c,0x4c,0x6a,0x8a,0x16,0x22,
+/* 35735 0x8b97 "讗" */
+0x22,0x13,0x00,0xf9,0x03,0x7d,0x01,0x79,0x01,0x79,0x49,0x4b,0x4a,0x7b,0x4a,0x02,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 35736 0x8b98 "讘" */
+0x43,0x21,0x01,0xf9,0x01,0x71,0x07,0x70,0x07,0x72,0x53,0x52,0x53,0x72,0x57,0x00,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 35737 0x8b99 "讙" */
+0x20,0x13,0x00,0xfb,0x02,0x7b,0x00,0x78,0x01,0x79,0x4b,0x4d,0x49,0x79,0x49,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 35738 0x8b9a "讚" */
+0x45,0x27,0x09,0xf7,0x03,0x75,0x09,0x73,0x02,0x73,0x52,0x53,0x52,0x73,0x51,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 35739 0x8b9b "讛" */
+0x41,0x27,0x01,0xfb,0x01,0x77,0x02,0x75,0x03,0x71,0x53,0x50,0x57,0x70,0x51,0x03,
+0x08,0xfe,0x08,0x90,0x3c,0xd4,0xb4,0x5c,0x96,0x22,0xfc,0x00,0xfe,0x80,0x04,0xfe,
+/* 35740 0x8b9c "讜" */
+0x42,0x21,0x07,0xf4,0x01,0x71,0x07,0x75,0x04,0x77,0x50,0x57,0x50,0x7f,0x52,0x04,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 35741 0x8b9d "讝" */
+0x23,0x12,0x03,0xfc,0x03,0x7a,0x02,0x7a,0x03,0x7a,0x4a,0x4a,0x4a,0x7a,0x45,0x08,
+0xde,0x52,0xde,0x00,0xfe,0x00,0xc8,0x4e,0xea,0xb2,0xea,0xaa,0xea,0xb4,0xe4,0x2a,
+/* 35742 0x8b9e "讞" */
+0x81,0x41,0x01,0xef,0x09,0xeb,0x09,0xef,0x09,0xeb,0xaa,0xab,0xaa,0xeb,0xaa,0x12,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 35743 0x8b9f "讟" */
+0x81,0x4f,0x01,0xe7,0x00,0xef,0x0a,0xef,0x04,0xe7,0xa4,0xa7,0xa4,0xe7,0xa2,0x04,
+0x08,0xe4,0x00,0xce,0x00,0xee,0xa0,0xee,0x40,0xce,0x4a,0xca,0x4a,0xce,0x8a,0x40,
+/* 35744 0x8ba0 "讠" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 35745 0x8ba1 "计" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf7,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 35746 0x8ba2 "订" */
+0x00,0x20,0x13,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 35747 0x8ba3 "讣" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x80,0x80,0x80,0x80,0x80,0xa0,0x90,0x88,0x84,0x84,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 35748 0x8ba4 "认" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x15,0x19,0x12,0x04,0x08,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 35749 0x8ba5 "讥" */
+0x00,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x12,0x02,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 35750 0x8ba6 "讦" */
+0x00,0x20,0x13,0x10,0x00,0x00,0xf0,0x10,0x17,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 35751 0x8ba7 "讧" */
+0x00,0x20,0x13,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x07,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35752 0x8ba8 "讨" */
+0x00,0x20,0x10,0x10,0x03,0x00,0xf0,0x10,0x11,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 35753 0x8ba9 "让" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x0f,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 35754 0x8baa "讪" */
+0x00,0x20,0x10,0x10,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 35755 0x8bab "讫" */
+0x00,0x20,0x11,0x11,0x02,0x04,0xf1,0x10,0x10,0x10,0x10,0x15,0x1a,0x12,0x01,0x00,
+0x80,0x80,0x00,0xfe,0x00,0x00,0xf8,0x08,0x10,0x60,0x80,0x00,0x02,0x02,0xfe,0x00,
+/* 35756 0x8bac "讬" */
+0x00,0x20,0x13,0x10,0x00,0x00,0xf0,0x10,0x17,0x10,0x10,0x14,0x18,0x10,0x00,0x00,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 35757 0x8bad "训" */
+0x01,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x12,0x02,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 35758 0x8bae "议" */
+0x00,0x20,0x12,0x12,0x02,0x01,0xf1,0x11,0x10,0x10,0x10,0x14,0x18,0x11,0x02,0x0c,
+0x80,0x48,0x48,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0xa0,0x10,0x08,0x06,
+/* 35759 0x8baf "讯" */
+0x00,0x27,0x11,0x11,0x01,0x01,0xf1,0x17,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xd0,0x10,0x10,0x10,0x12,0x0a,0x0a,0x06,0x02,
+/* 35760 0x8bb0 "记" */
+0x00,0x20,0x11,0x10,0x00,0x00,0xf0,0x11,0x11,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 35761 0x8bb1 "讱" */
+0x00,0x20,0x13,0x10,0x00,0x02,0xf2,0x12,0x14,0x10,0x10,0x15,0x19,0x12,0x04,0x08,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x04,0x28,0x10,
+/* 35762 0x8bb2 "讲" */
+0x01,0x21,0x11,0x11,0x07,0x01,0xf1,0x11,0x1f,0x11,0x11,0x15,0x19,0x12,0x02,0x04,
+0x10,0x10,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 35763 0x8bb3 "讳" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf3,0x10,0x10,0x17,0x10,0x10,0x14,0x18,0x10,0x00,
+0x40,0x40,0x40,0xfe,0x40,0x40,0xfc,0x40,0x40,0xfe,0x42,0x42,0x4a,0x44,0x40,0x40,
+/* 35764 0x8bb4 "讴" */
+0x00,0x23,0x12,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x17,0x1a,0x13,0x00,
+0x00,0xfc,0x00,0x08,0x88,0x50,0x50,0x20,0x20,0x50,0x50,0x88,0x08,0x00,0xfe,0x00,
+/* 35765 0x8bb5 "讵" */
+0x00,0x23,0x12,0x12,0x02,0x03,0xf2,0x12,0x12,0x12,0x13,0x12,0x16,0x1a,0x13,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 35766 0x8bb6 "讶" */
+0x00,0x23,0x10,0x11,0x01,0x01,0xf2,0x13,0x10,0x10,0x10,0x15,0x1a,0x14,0x00,0x00,
+0x00,0xfc,0x10,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 35767 0x8bb7 "讷" */
+0x00,0x20,0x10,0x10,0x03,0x02,0xf2,0x12,0x12,0x12,0x12,0x13,0x16,0x1a,0x12,0x02,
+0x20,0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 35768 0x8bb8 "许" */
+0x00,0x20,0x10,0x11,0x01,0x02,0xf0,0x10,0x13,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 35769 0x8bb9 "讹" */
+0x00,0x20,0x10,0x11,0x01,0x03,0xf5,0x11,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0xa0,0xa0,0xa0,0x24,0x24,0x28,0x30,0x20,0x60,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 35770 0x8bba "论" */
+0x00,0x20,0x10,0x10,0x01,0x02,0xf4,0x11,0x11,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 35771 0x8bbb "讻" */
+0x00,0x20,0x11,0x10,0x02,0x02,0xf2,0x12,0x12,0x12,0x13,0x16,0x1a,0x13,0x00,0x00,
+0x00,0x08,0x08,0x88,0x52,0x52,0x22,0x22,0x52,0x92,0x0a,0x0a,0x02,0xfe,0x02,0x00,
+/* 35772 0x8bbc "讼" */
+0x00,0x21,0x11,0x11,0x01,0x02,0xf2,0x14,0x18,0x10,0x11,0x15,0x1a,0x17,0x02,0x00,
+0x20,0x20,0x20,0x10,0x10,0x48,0x48,0x44,0x82,0x80,0x10,0x08,0x08,0xfc,0x04,0x00,
+/* 35773 0x8bbd "讽" */
+0x00,0x43,0x22,0x22,0x03,0x02,0xe2,0x22,0x22,0x22,0x22,0x2b,0x34,0x24,0x08,0x10,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 35774 0x8bbe "设" */
+0x00,0x21,0x11,0x11,0x01,0x02,0xf4,0x13,0x11,0x11,0x10,0x14,0x18,0x10,0x03,0x0c,
+0x00,0xf0,0x10,0x10,0x10,0x0e,0x00,0xf8,0x08,0x10,0x90,0xa0,0x40,0xa0,0x18,0x06,
+/* 35775 0x8bbf "访" */
+0x00,0x20,0x10,0x17,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,0x08,
+0x80,0x40,0x40,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 35776 0x8bc0 "诀" */
+0x00,0x20,0x10,0x13,0x00,0x00,0xf0,0x10,0x17,0x10,0x10,0x14,0x19,0x12,0x04,0x08,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 35777 0x8bc1 "证" */
+0x00,0x20,0x13,0x10,0x00,0x00,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x07,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35778 0x8bc2 "诂" */
+0x00,0x20,0x10,0x10,0x03,0x00,0xf0,0x10,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35779 0x8bc3 "诃" */
+0x00,0x20,0x17,0x10,0x00,0x03,0xf2,0x12,0x12,0x12,0x13,0x12,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xc8,0x48,0x48,0x48,0x48,0xc8,0x48,0x08,0x08,0x28,0x10,
+/* 35780 0x8bc4 "评" */
+0x00,0x23,0x10,0x10,0x02,0x01,0xf1,0x10,0x17,0x10,0x10,0x14,0x18,0x10,0x00,0x00,
+0x00,0xf8,0x40,0x40,0x48,0x48,0x50,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 35781 0x8bc5 "诅" */
+0x00,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 35782 0x8bc6 "识" */
+0x00,0x20,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x10,0x14,0x18,0x11,0x02,0x04,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 35783 0x8bc7 "诇" */
+0x00,0x23,0x12,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x12,0x16,0x1a,0x12,0x02,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 35784 0x8bc8 "诈" */
+0x01,0x21,0x11,0x11,0x02,0x02,0xf4,0x10,0x10,0x10,0x10,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x80,0x80,0x80,0x80,
+/* 35785 0x8bc9 "诉" */
+0x00,0x20,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x12,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 35786 0x8bca "诊" */
+0x00,0x40,0x20,0x21,0x02,0x04,0xe0,0x20,0x23,0x20,0x20,0x28,0x33,0x20,0x00,0x07,
+0x40,0x40,0xa0,0x10,0x08,0x26,0x40,0x80,0x10,0x20,0x40,0x88,0x10,0x20,0xc0,0x00,
+/* 35787 0x8bcb "诋" */
+0x00,0x20,0x13,0x12,0x02,0x02,0xf2,0x13,0x12,0x12,0x12,0x12,0x16,0x1a,0x13,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x10,0x10,0x12,0x0a,0x8a,0x26,0x12,
+/* 35788 0x8bcc "诌" */
+0x00,0x20,0x10,0x11,0x02,0x04,0xf3,0x10,0x10,0x10,0x11,0x10,0x14,0x18,0x13,0x00,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35789 0x8bcd "词" */
+0x00,0x23,0x10,0x10,0x07,0x00,0xf0,0x13,0x12,0x12,0x12,0x13,0x14,0x18,0x10,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 35790 0x8bce "诎" */
+0x00,0x20,0x11,0x11,0x01,0x01,0xf1,0x10,0x10,0x11,0x11,0x11,0x15,0x19,0x11,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 35791 0x8bcf "诏" */
+0x00,0x23,0x10,0x10,0x00,0x01,0xf1,0x12,0x14,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x04,0x14,0x08,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35792 0x8bd0 "诐" */
+0x00,0x20,0x10,0x13,0x02,0x02,0xf2,0x13,0x12,0x12,0x12,0x16,0x1a,0x14,0x04,0x09,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 35793 0x8bd1 "译" */
+0x00,0x23,0x11,0x10,0x00,0x00,0xf0,0x13,0x10,0x11,0x10,0x14,0x1b,0x10,0x00,0x00,
+0x00,0xfc,0x04,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35794 0x8bd2 "诒" */
+0x00,0x20,0x10,0x10,0x01,0x03,0xf0,0x10,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35795 0x8bd3 "诓" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x12,0x12,0x12,0x12,0x13,0x16,0x1a,0x13,0x00,
+0x00,0xfe,0x00,0x00,0xfc,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x00,0xfe,0x00,
+/* 35796 0x8bd4 "诔" */
+0x00,0x40,0x27,0x20,0x00,0x03,0xe0,0x20,0x27,0x20,0x21,0x29,0x32,0x24,0x08,0x00,
+0x40,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0xe0,0x50,0x50,0x48,0x44,0x42,0x40,
+/* 35797 0x8bd5 "试" */
+0x00,0x20,0x10,0x10,0x07,0x00,0xf0,0x17,0x11,0x11,0x11,0x15,0x19,0x17,0x02,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xe0,0x20,0x10,0x10,0x10,0xca,0x0a,0x06,0x02,
+/* 35798 0x8bd6 "诖" */
+0x00,0x20,0x11,0x10,0x00,0x00,0xf3,0x10,0x10,0x10,0x11,0x10,0x14,0x18,0x13,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35799 0x8bd7 "诗" */
+0x00,0x20,0x10,0x13,0x00,0x00,0xf7,0x10,0x10,0x17,0x10,0x12,0x15,0x19,0x10,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 35800 0x8bd8 "诘" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf3,0x10,0x10,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35801 0x8bd9 "诙" */
+0x00,0x20,0x10,0x17,0x01,0x01,0xf2,0x12,0x14,0x15,0x1a,0x10,0x14,0x19,0x12,0x04,
+0x80,0x80,0x80,0xfe,0x00,0x20,0x20,0xa4,0xa4,0x28,0x50,0x50,0x88,0x08,0x04,0x02,
+/* 35802 0x8bda "诚" */
+0x00,0x40,0x20,0x27,0x04,0x04,0xe4,0x27,0x24,0x24,0x24,0x2c,0x36,0x29,0x08,0x10,
+0x28,0x24,0x20,0xfe,0x20,0x20,0x24,0xa4,0xa4,0xa8,0xa8,0x90,0x92,0x2a,0x46,0x82,
+/* 35803 0x8bdb "诛" */
+0x00,0x21,0x11,0x11,0x01,0x02,0xf0,0x13,0x10,0x10,0x10,0x15,0x19,0x12,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 35804 0x8bdc "诜" */
+0x00,0x21,0x11,0x11,0x01,0x02,0xf0,0x13,0x10,0x10,0x10,0x10,0x15,0x19,0x12,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 35805 0x8bdd "话" */
+0x00,0x20,0x11,0x10,0x00,0x03,0xf0,0x10,0x10,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35806 0x8bde "诞" */
+0x00,0x40,0x2f,0x21,0x02,0x04,0xef,0x21,0x29,0x29,0x25,0x2a,0x33,0x24,0x08,0x10,
+0x08,0x1c,0x70,0x10,0x10,0x50,0x5c,0x50,0x50,0x50,0x50,0x7c,0x00,0x80,0x7e,0x00,
+/* 35807 0x8bdf "诟" */
+0x00,0x40,0x23,0x22,0x02,0x03,0xe2,0x22,0x22,0x22,0x22,0x2a,0x34,0x24,0x08,0x00,
+0x08,0x3c,0xc0,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 35808 0x8be0 "诠" */
+0x00,0x20,0x10,0x11,0x02,0x04,0xf3,0x10,0x10,0x10,0x13,0x10,0x14,0x18,0x17,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 35809 0x8be1 "诡" */
+0x01,0x41,0x23,0x22,0x04,0x0b,0xe2,0x22,0x22,0x22,0x22,0x22,0x2a,0x34,0x24,0x08,
+0x00,0x00,0xf8,0x08,0x10,0xfe,0x00,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 35810 0x8be2 "询" */
+0x02,0x42,0x23,0x24,0x04,0x0b,0xe2,0x22,0x23,0x22,0x22,0x23,0x2a,0x30,0x20,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x24,0x04,0x14,0x08,
+/* 35811 0x8be3 "诣" */
+0x01,0x21,0x11,0x11,0x01,0x01,0xf0,0x10,0x11,0x11,0x11,0x15,0x19,0x11,0x01,0x01,
+0x00,0x04,0x38,0xc0,0x02,0x02,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35812 0x8be4 "诤" */
+0x00,0x20,0x11,0x12,0x00,0x03,0xf0,0x10,0x17,0x10,0x10,0x13,0x14,0x18,0x11,0x00,
+0x80,0x80,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x80,
+/* 35813 0x8be5 "该" */
+0x00,0x40,0x2f,0x20,0x01,0x01,0xe2,0x27,0x20,0x20,0x21,0x2a,0x34,0x20,0x03,0x0c,
+0x80,0x40,0xfe,0x80,0x10,0x10,0x24,0xe4,0x48,0x88,0x10,0x20,0x50,0x88,0x04,0x04,
+/* 35814 0x8be6 "详" */
+0x02,0x21,0x11,0x10,0x07,0x00,0xf0,0x13,0x10,0x10,0x17,0x10,0x14,0x18,0x10,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 35815 0x8be7 "诧" */
+0x00,0x20,0x10,0x13,0x02,0x04,0xf0,0x13,0x10,0x10,0x10,0x17,0x14,0x18,0x10,0x00,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x38,0xc0,0x40,0x40,0x7e,0xc0,0x40,0x42,0x42,0x3e,
+/* 35816 0x8be8 "诨" */
+0x00,0x23,0x12,0x14,0x00,0x03,0xf0,0x10,0x11,0x11,0x10,0x14,0x1b,0x10,0x00,0x00,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35817 0x8be9 "诩" */
+0x00,0x47,0x20,0x20,0x04,0x02,0xe2,0x20,0x21,0x22,0x24,0x20,0x28,0x30,0x22,0x01,
+0x00,0xbc,0x84,0x84,0xa4,0x94,0x94,0x84,0x8c,0x94,0xa4,0x84,0x84,0x84,0x94,0x08,
+/* 35818 0x8bea "诪" */
+0x00,0x40,0x27,0x20,0x03,0x00,0xe7,0x20,0x21,0x21,0x22,0x2a,0x34,0x28,0x00,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x80,0xfe,0x90,0x10,0xfe,0x10,0x90,0x50,0x10,0x50,0x20,
+/* 35819 0x8beb "诫" */
+0x00,0x40,0x20,0x2f,0x00,0x02,0xe2,0x22,0x2f,0x22,0x22,0x2a,0x32,0x24,0x04,0x08,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xd2,0x94,0x94,0x88,0x8a,0x9a,0x26,0x42,
+/* 35820 0x8bec "诬" */
+0x00,0x47,0x20,0x20,0x02,0x02,0xe2,0x25,0x24,0x28,0x20,0x28,0x30,0x20,0x0f,0x00,
+0x00,0xfc,0x40,0x40,0x48,0x48,0x48,0x54,0xd2,0x62,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 35821 0x8bed "语" */
+0x00,0x47,0x20,0x20,0x03,0x00,0xe0,0x27,0x20,0x20,0x23,0x22,0x2a,0x32,0x23,0x02,
+0x00,0xfc,0x40,0x40,0xf8,0x88,0x88,0xfe,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 35822 0x8bee "诮" */
+0x00,0x21,0x10,0x10,0x00,0x01,0xf1,0x11,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 35823 0x8bef "误" */
+0x00,0x43,0x22,0x22,0x03,0x00,0xe7,0x20,0x20,0x2f,0x20,0x20,0x28,0x31,0x22,0x04,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x40,0x40,0xfe,0x40,0xa0,0xa0,0x10,0x08,0x06,
+/* 35824 0x8bf0 "诰" */
+0x00,0x21,0x11,0x11,0x02,0x04,0xf0,0x13,0x10,0x10,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35825 0x8bf1 "诱" */
+0x00,0x47,0x20,0x20,0x0f,0x01,0xe2,0x2c,0x23,0x21,0x21,0x21,0x2a,0x32,0x24,0x08,
+0x1c,0xe0,0x40,0x40,0xfe,0x50,0x48,0x46,0xf0,0x10,0x20,0x7c,0x04,0x04,0x28,0x10,
+/* 35826 0x8bf2 "诲" */
+0x01,0x21,0x11,0x12,0x05,0x01,0xf1,0x11,0x17,0x11,0x12,0x12,0x17,0x18,0x10,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x48,0x28,0xfe,0x08,0x48,0x28,0xfc,0x08,0x50,0x20,
+/* 35827 0x8bf3 "诳" */
+0x00,0x44,0x22,0x21,0x02,0x04,0xe0,0x20,0x21,0x22,0x24,0x20,0x28,0x30,0x25,0x02,
+0x00,0x40,0xbe,0x08,0x88,0x88,0x88,0xbe,0x88,0x88,0x88,0x88,0x88,0x88,0x3e,0x00,
+/* 35828 0x8bf4 "说" */
+0x02,0x21,0x11,0x10,0x03,0x02,0xf2,0x12,0x13,0x10,0x10,0x15,0x19,0x12,0x04,0x08,
+0x08,0x08,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0xa0,0xa0,0x20,0x22,0x22,0x1e,0x00,
+/* 35829 0x8bf5 "诵" */
+0x00,0x47,0x20,0x21,0x00,0x07,0xe4,0x24,0x27,0x24,0x24,0x27,0x2c,0x34,0x24,0x04,
+0x00,0xf8,0x10,0xa0,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 35830 0x8bf6 "诶" */
+0x00,0x40,0x21,0x22,0x07,0x01,0xe1,0x23,0x24,0x20,0x2f,0x20,0x28,0x31,0x22,0x0c,
+0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 35831 0x8bf7 "请" */
+0x00,0x40,0x27,0x20,0x03,0x00,0xe7,0x20,0x23,0x22,0x23,0x22,0x2b,0x32,0x22,0x02,
+0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,
+/* 35832 0x8bf8 "诸" */
+0x00,0x40,0x23,0x20,0x00,0x07,0xe0,0x20,0x21,0x23,0x25,0x21,0x29,0x31,0x21,0x01,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 35833 0x8bf9 "诹" */
+0x00,0x4f,0x24,0x24,0x04,0x07,0xe4,0x24,0x27,0x24,0x24,0x25,0x2e,0x30,0x20,0x00,
+0x00,0xc0,0xbc,0xa4,0xa4,0xa4,0xa4,0xa8,0xa8,0xa8,0x90,0xd0,0xa8,0xa8,0xc4,0x82,
+/* 35834 0x8bfa "诺" */
+0x01,0x41,0x27,0x21,0x01,0x00,0xe7,0x20,0x21,0x23,0x25,0x29,0x29,0x31,0x21,0x01,
+0x08,0x08,0xfe,0x08,0x48,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35835 0x8bfb "读" */
+0x00,0x20,0x11,0x10,0x00,0x03,0xf0,0x10,0x10,0x11,0x10,0x13,0x14,0x18,0x10,0x03,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x10,0x90,0xfe,0x28,0x44,0x82,0x02,
+/* 35836 0x8bfc "诼" */
+0x00,0x4f,0x20,0x21,0x02,0x04,0xea,0x21,0x22,0x24,0x28,0x21,0x2a,0x34,0x20,0x00,
+0x00,0xfe,0x80,0x84,0x44,0x68,0xb0,0x30,0xa8,0x68,0xa4,0x24,0x22,0x20,0xa0,0x40,
+/* 35837 0x8bfd "诽" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf0,0x13,0x10,0x10,0x10,0x17,0x18,0x10,0x00,0x00,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 35838 0x8bfe "课" */
+0x00,0x43,0x22,0x22,0x03,0x02,0xe2,0x23,0x20,0x27,0x20,0x29,0x32,0x24,0x00,0x00,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x40,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 35839 0x8bff "诿" */
+0x00,0x43,0x20,0x20,0x07,0x01,0xe2,0x24,0x20,0x27,0x21,0x2a,0x31,0x20,0x00,0x03,
+0x38,0xc0,0x40,0x40,0xfc,0x50,0x48,0x86,0x80,0xfc,0x10,0x10,0xa0,0x60,0x90,0x08,
+/* 35840 0x8c00 "谀" */
+0x00,0x41,0x26,0x24,0x04,0x07,0xe4,0x24,0x27,0x24,0x20,0x20,0x29,0x32,0x24,0x08,
+0x40,0x40,0x5c,0x44,0x44,0x5c,0x44,0x44,0xfc,0x44,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 35841 0x8c01 "谁" */
+0x01,0x41,0x21,0x23,0x02,0x06,0xeb,0x22,0x22,0x23,0x22,0x22,0x2a,0x33,0x22,0x02,
+0x40,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 35842 0x8c02 "谂" */
+0x00,0x40,0x20,0x21,0x02,0x04,0xe8,0x23,0x20,0x20,0x20,0x29,0x35,0x25,0x09,0x00,
+0x40,0x40,0xa0,0x10,0x88,0x46,0x00,0xf0,0x10,0x20,0x40,0x24,0x22,0x0a,0x08,0xf8,
+/* 35843 0x8c03 "调" */
+0x00,0x47,0x24,0x24,0x05,0x04,0xe4,0x27,0x24,0x25,0x25,0x2d,0x35,0x24,0x04,0x08,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0x44,0xfc,0x04,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 35844 0x8c04 "谄" */
+0x00,0x40,0x20,0x21,0x02,0x04,0xe0,0x23,0x22,0x22,0x23,0x22,0x2a,0x32,0x23,0x02,
+0x80,0x80,0xf8,0x08,0x10,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 35845 0x8c05 "谅" */
+0x00,0x20,0x13,0x10,0x00,0x01,0xf1,0x11,0x11,0x11,0x10,0x14,0x19,0x12,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 35846 0x8c06 "谆" */
+0x00,0x20,0x17,0x10,0x03,0x02,0xf3,0x10,0x13,0x10,0x10,0x17,0x18,0x10,0x01,0x00,
+0x80,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x10,0x20,0xfc,0x40,0x40,0x40,0x80,
+/* 35847 0x8c07 "谇" */
+0x00,0x40,0x27,0x20,0x01,0x01,0xe2,0x24,0x20,0x20,0x27,0x20,0x28,0x30,0x20,0x00,
+0x80,0x40,0xfc,0x00,0x10,0x10,0xa8,0x44,0x00,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,
+/* 35848 0x8c08 "谈" */
+0x00,0x22,0x12,0x14,0x00,0x01,0xf6,0x10,0x10,0x12,0x12,0x14,0x18,0x11,0x02,0x0c,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 35849 0x8c09 "谉" */
+0x00,0x20,0x13,0x12,0x00,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x10,0x00,0x00,
+0x40,0x20,0xfe,0x22,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 35850 0x8c0a "谊" */
+0x00,0x20,0x13,0x12,0x04,0x01,0xf1,0x11,0x11,0x11,0x11,0x15,0x19,0x11,0x07,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x00,
+/* 35851 0x8c0b "谋" */
+0x02,0x42,0x2f,0x22,0x02,0x03,0xe2,0x22,0x23,0x20,0x2f,0x20,0x29,0x32,0x2c,0x00,
+0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x08,0xf8,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 35852 0x8c0c "谌" */
+0x01,0x41,0x27,0x21,0x01,0x01,0xe1,0x21,0x21,0x27,0x22,0x22,0x2b,0x32,0x23,0x00,
+0x10,0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,0x90,0x08,0x00,0xfc,0x00,
+/* 35853 0x8c0d "谍" */
+0x00,0x42,0x22,0x27,0x02,0x02,0xe2,0x22,0x23,0x20,0x27,0x20,0x29,0x32,0x2c,0x00,
+0x90,0x90,0x90,0xfe,0x90,0x90,0xf0,0x00,0xfc,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 35854 0x8c0e "谎" */
+0x01,0x41,0x27,0x21,0x00,0x07,0xe2,0x22,0x23,0x20,0x22,0x22,0x2a,0x34,0x24,0x08,
+0x08,0x08,0xfe,0x48,0x20,0xfe,0x00,0x00,0xfc,0x00,0x48,0x48,0x48,0x4a,0x4a,0x46,
+/* 35855 0x8c0f "谏" */
+0x00,0x40,0x2f,0x20,0x07,0x04,0xe5,0x24,0x24,0x27,0x20,0x29,0x32,0x24,0x00,0x00,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0x54,0xe4,0x44,0xfc,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 35856 0x8c10 "谐" */
+0x02,0x22,0x13,0x12,0x02,0x03,0xf2,0x10,0x13,0x12,0x12,0x13,0x16,0x1a,0x13,0x02,
+0x20,0x24,0xa8,0x30,0xa2,0x22,0x5e,0x80,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 35857 0x8c11 "谑" */
+0x00,0x20,0x10,0x13,0x02,0x02,0xf3,0x12,0x12,0x12,0x12,0x16,0x1b,0x14,0x04,0x08,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc0,0x44,0x3c,0x00,0xfc,0x80,0xfe,0x80,0x80,0xfc,
+/* 35858 0x8c12 "谒" */
+0x00,0x43,0x22,0x23,0x02,0x03,0xe1,0x23,0x24,0x22,0x22,0x22,0x2b,0x30,0x20,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,
+/* 35859 0x8c13 "谓" */
+0x00,0x47,0x24,0x27,0x04,0x07,0xe0,0x23,0x22,0x23,0x22,0x23,0x2a,0x32,0x22,0x02,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x28,0x10,
+/* 35860 0x8c14 "谔" */
+0x00,0x47,0x24,0x24,0x07,0x00,0xe3,0x20,0x2f,0x21,0x22,0x23,0x28,0x30,0x20,0x00,
+0x00,0xbc,0xa4,0xa4,0xbc,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 35861 0x8c15 "谕" */
+0x00,0x20,0x11,0x12,0x05,0x00,0xf3,0x12,0x12,0x13,0x12,0x12,0x17,0x1a,0x12,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 35862 0x8c16 "谖" */
+0x00,0x47,0x22,0x21,0x00,0x03,0xe0,0x20,0x27,0x21,0x21,0x2a,0x32,0x24,0x08,0x03,
+0x3c,0xc0,0x44,0x28,0x00,0xfc,0x80,0x80,0xfe,0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,
+/* 35863 0x8c17 "谗" */
+0x01,0x21,0x12,0x14,0x03,0x02,0xf2,0x13,0x10,0x11,0x16,0x10,0x14,0x19,0x10,0x00,
+0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfc,0xa0,0x22,0x1e,0xc0,0x30,0x80,0x60,0x10,
+/* 35864 0x8c18 "谘" */
+0x00,0x22,0x11,0x10,0x01,0x06,0xf2,0x12,0x12,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x40,0x40,0x7c,0x84,0x08,0x20,0x20,0x50,0x88,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 35865 0x8c19 "谙" */
+0x00,0x40,0x27,0x20,0x02,0x01,0xef,0x20,0x23,0x22,0x22,0x23,0x2a,0x32,0x23,0x02,
+0x80,0x40,0xfc,0x00,0x08,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 35866 0x8c1a "谚" */
+0x00,0x20,0x13,0x10,0x01,0x00,0xf3,0x12,0x12,0x12,0x12,0x16,0x1a,0x14,0x04,0x09,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x10,0x20,0xc8,0x10,0x24,0xc8,0x10,0x60,0x80,
+/* 35867 0x8c1b "谛" */
+0x00,0x20,0x11,0x10,0x00,0x00,0xf3,0x12,0x14,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 35868 0x8c1c "谜" */
+0x00,0x40,0x24,0x22,0x02,0x00,0xe0,0x26,0x22,0x22,0x23,0x22,0x2a,0x35,0x28,0x00,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 35869 0x8c1d "谝" */
+0x00,0x40,0x27,0x24,0x04,0x07,0xe4,0x24,0x27,0x26,0x2a,0x2b,0x3a,0x2a,0x12,0x02,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xa4,0x0c,
+/* 35870 0x8c1e "谞" */
+0x00,0x23,0x10,0x11,0x01,0x01,0xf2,0x14,0x11,0x11,0x11,0x15,0x19,0x11,0x01,0x01,
+0x00,0xfe,0x22,0x20,0x3c,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 35871 0x8c1f "谟" */
+0x01,0x41,0x27,0x21,0x00,0x03,0xe2,0x23,0x22,0x23,0x20,0x27,0x28,0x31,0x22,0x0c,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 35872 0x8c20 "谠" */
+0x00,0x42,0x21,0x20,0x07,0x04,0xe8,0x23,0x22,0x22,0x23,0x20,0x29,0x31,0x22,0x04,
+0x40,0x48,0x50,0x40,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0xa0,0x20,0x24,0x24,0x1c,
+/* 35873 0x8c21 "谡" */
+0x00,0x47,0x24,0x27,0x04,0x07,0xe1,0x22,0x24,0x21,0x22,0x25,0x30,0x20,0x01,0x0e,
+0x00,0xfc,0x44,0xfc,0x44,0xfc,0x10,0x08,0x84,0xf8,0x08,0x08,0x90,0x60,0x98,0x06,
+/* 35874 0x8c22 "谢" */
+0x01,0x42,0x27,0x24,0x07,0x04,0xe7,0x24,0x24,0x2f,0x21,0x2a,0x34,0x28,0x02,0x01,
+0x08,0x08,0x88,0x88,0xbe,0x88,0x88,0xc8,0xa8,0xa8,0x88,0x88,0x88,0x88,0xa8,0x10,
+/* 35875 0x8c23 "谣" */
+0x00,0x20,0x13,0x10,0x02,0x01,0xf1,0x12,0x10,0x13,0x10,0x11,0x15,0x19,0x11,0x00,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 35876 0x8c24 "谤" */
+0x00,0x20,0x13,0x11,0x00,0x03,0xf2,0x14,0x10,0x13,0x10,0x10,0x14,0x19,0x11,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 35877 0x8c25 "谥" */
+0x02,0x41,0x21,0x20,0x07,0x00,0xe1,0x22,0x24,0x23,0x22,0x22,0x2a,0x32,0x2f,0x00,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 35878 0x8c26 "谦" */
+0x02,0x41,0x20,0x27,0x00,0x07,0xe0,0x2f,0x20,0x27,0x20,0x29,0x32,0x2c,0x00,0x00,
+0x08,0x10,0x00,0xfe,0xa0,0xfc,0xa4,0xfe,0xa4,0xfc,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 35879 0x8c27 "谧" */
+0x00,0x40,0x20,0x22,0x02,0x04,0xe1,0x26,0x20,0x23,0x22,0x22,0x2a,0x32,0x27,0x00,
+0x40,0x28,0x90,0xa4,0xc2,0x8a,0x88,0x78,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,
+/* 35880 0x8c28 "谨" */
+0x01,0x41,0x2f,0x21,0x01,0x00,0xe7,0x24,0x27,0x20,0x2f,0x20,0x2f,0x30,0x2f,0x00,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xfc,0x44,0xfc,0x40,0xfe,0x40,0xfc,0x40,0xfe,0x00,
+/* 35881 0x8c29 "谩" */
+0x03,0x42,0x23,0x22,0x03,0x00,0xe7,0x24,0x24,0x27,0x20,0x23,0x29,0x30,0x23,0x0c,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 35882 0x8c2a "谪" */
+0x00,0x40,0x27,0x21,0x00,0x07,0xe4,0x25,0x24,0x25,0x25,0x25,0x2d,0x34,0x24,0x04,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xf4,0x44,0xf4,0x14,0x14,0xf4,0x04,0x14,0x08,
+/* 35883 0x8c2b "谫" */
+0x01,0x20,0x17,0x10,0x03,0x02,0xf3,0x12,0x13,0x12,0x12,0x14,0x1b,0x10,0x01,0x06,
+0x08,0x90,0xfe,0x00,0xc4,0x54,0xd4,0x54,0xd4,0x44,0xcc,0x00,0xfc,0x84,0x14,0x08,
+/* 35884 0x8c2c "谬" */
+0x00,0x47,0x20,0x24,0x02,0x04,0xe0,0x21,0x26,0x20,0x23,0x20,0x2b,0x30,0x20,0x07,
+0x00,0xbc,0x84,0xa4,0x94,0xa4,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 35885 0x8c2d "谭" */
+0x00,0x23,0x10,0x13,0x02,0x03,0xf0,0x11,0x11,0x11,0x11,0x15,0x18,0x13,0x00,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 35886 0x8c2e "谮" */
+0x00,0x47,0x21,0x25,0x07,0x03,0xe5,0x29,0x20,0x23,0x22,0x22,0x2b,0x32,0x22,0x03,
+0x00,0xbc,0x08,0x28,0xbc,0x18,0xaa,0x46,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 35887 0x8c2f "谯" */
+0x01,0x41,0x23,0x22,0x06,0x0b,0xe2,0x22,0x23,0x22,0x22,0x2b,0x32,0x25,0x04,0x08,
+0x40,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x24,0x92,0x92,
+/* 35888 0x8c30 "谰" */
+0x02,0x41,0x25,0x24,0x05,0x04,0xe5,0x25,0x25,0x25,0x25,0x25,0x2c,0x35,0x24,0x04,
+0x00,0x7c,0x04,0x44,0xf4,0x44,0xf4,0x54,0x74,0xd4,0x54,0xf4,0xe4,0x54,0x44,0x4c,
+/* 35889 0x8c31 "谱" */
+0x02,0x41,0x27,0x20,0x04,0x02,0xef,0x20,0x23,0x22,0x22,0x23,0x2a,0x32,0x23,0x02,
+0x08,0x10,0xfc,0xa0,0xa4,0xa8,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 35890 0x8c32 "谲" */
+0x00,0x47,0x20,0x20,0x07,0x00,0xe1,0x26,0x20,0x27,0x24,0x25,0x2e,0x34,0x24,0x04,
+0x00,0xf8,0x90,0x60,0xfc,0xa4,0x28,0xa0,0x40,0xfc,0xa4,0x14,0xec,0xa4,0xe4,0x0c,
+/* 35891 0x8c33 "谳" */
+0x01,0x41,0x27,0x21,0x01,0x07,0xe4,0x26,0x25,0x27,0x25,0x27,0x2d,0x35,0x24,0x04,
+0x08,0x08,0xcc,0x0a,0x08,0xde,0x48,0xc8,0x48,0xc8,0x54,0xd4,0x54,0x54,0x54,0xe2,
+/* 35892 0x8c34 "谴" */
+0x00,0x44,0x22,0x22,0x00,0x01,0xe0,0x2e,0x22,0x22,0x22,0x22,0x2a,0x32,0x25,0x08,
+0x10,0xfe,0x92,0xfe,0x10,0xfe,0x00,0xfe,0x82,0xfe,0x80,0xfe,0x82,0xfe,0x00,0xfe,
+/* 35893 0x8c35 "谵" */
+0x02,0x43,0x24,0x27,0x0d,0x16,0xe7,0x24,0x25,0x24,0x25,0x2c,0x35,0x29,0x09,0x11,
+0x00,0xf8,0x10,0xfe,0x48,0x24,0xfe,0x00,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x04,
+/* 35894 0x8c36 "谶" */
+0x04,0x44,0x2a,0x20,0x0f,0x02,0xee,0x22,0x2e,0x22,0x2e,0x2a,0x32,0x2f,0x04,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x88,0xe8,0x8a,0xea,0x8c,0xec,0x88,0xea,0x1a,0x26,0x42,
+/* 35895 0x8c37 "谷" */
+0x08,0x08,0x11,0x21,0x42,0x04,0x08,0x30,0xc0,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,
+0x20,0x10,0x08,0x04,0x80,0x40,0x20,0x18,0x06,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,
+/* 35896 0x8c38 "谸" */
+0x08,0x1c,0xf1,0x12,0x10,0x10,0xfc,0x11,0x12,0x11,0x11,0x11,0x21,0x21,0x41,0x81,
+0x88,0x84,0x02,0x22,0x20,0x50,0x88,0x04,0x02,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35897 0x8c39 "谹" */
+0x00,0x48,0x44,0x94,0x13,0x28,0x44,0x80,0x78,0x49,0x49,0x4a,0x4a,0x7c,0x49,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 35898 0x8c3a "谺" */
+0x00,0x24,0x22,0x4a,0x88,0x14,0x22,0x41,0xbc,0x24,0x24,0x24,0x24,0x3d,0x24,0x00,
+0x00,0xfc,0x08,0x48,0x48,0x48,0x88,0xfe,0x18,0x28,0x28,0x48,0x88,0x08,0x28,0x10,
+/* 35899 0x8c3b "谻" */
+0x00,0x25,0x22,0x4a,0x88,0x15,0x22,0x41,0xbc,0x25,0x24,0x24,0x24,0x3c,0x25,0x02,
+0x00,0xf8,0x48,0x48,0x48,0xf8,0x48,0x48,0x48,0xf8,0x48,0x48,0x8a,0x8a,0x0a,0x06,
+/* 35900 0x8c3c "谼" */
+0x00,0x24,0x22,0x4a,0x89,0x14,0x22,0x41,0xbc,0x25,0x24,0x24,0x24,0x3c,0x24,0x01,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0xfe,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 35901 0x8c3d "谽" */
+0x00,0x48,0x44,0x94,0x11,0x2a,0x44,0x80,0x78,0x48,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 35902 0x8c3e "谾" */
+0x00,0x48,0x45,0x95,0x12,0x28,0x44,0x81,0x78,0x49,0x48,0x48,0x48,0x78,0x4b,0x00,
+0x40,0x20,0xfe,0x02,0x04,0x50,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35903 0x8c3f "谿" */
+0x0e,0xf0,0x22,0x92,0x45,0x20,0x44,0xf8,0x11,0x24,0xfe,0x10,0xfe,0x28,0x44,0x82,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 35904 0x8c40 "豀" */
+0x00,0x4b,0x45,0x94,0x10,0x28,0x45,0x80,0x78,0x49,0x48,0x48,0x4b,0x78,0x48,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 35905 0x8c41 "豁" */
+0x20,0x10,0xfe,0x82,0x11,0x7c,0x10,0x7c,0x11,0xfe,0x10,0x7c,0x44,0x44,0x7c,0x44,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 35906 0x8c42 "豂" */
+0x00,0x24,0x22,0x4a,0x88,0x14,0x22,0x41,0xbc,0x25,0x24,0x24,0x24,0x3c,0x24,0x00,
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x10,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x18,0xe0,
+/* 35907 0x8c43 "豃" */
+0x00,0x53,0x48,0x89,0x27,0x32,0x4a,0x87,0x7a,0x4b,0x4a,0x4a,0x4b,0x7e,0x48,0x00,
+0x08,0x88,0x88,0x10,0xde,0x94,0xa4,0x94,0x94,0x94,0x94,0xc8,0x88,0x94,0xa4,0xc2,
+/* 35908 0x8c44 "豄" */
+0x00,0x4b,0x44,0x95,0x10,0x2b,0x46,0x83,0x79,0x49,0x49,0x49,0x49,0x79,0x48,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 35909 0x8c45 "豅" */
+0x01,0x50,0x4b,0x88,0x22,0x31,0x4b,0x84,0x7b,0x4a,0x4b,0x4a,0x4b,0x7a,0x4a,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 35910 0x8c46 "豆" */
+0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x10,0x08,0x04,0xff,0x00,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x10,0x20,0x40,0xfe,0x00,
+/* 35911 0x8c47 "豇" */
+0x00,0xfe,0x01,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x43,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 35912 0x8c48 "豈" */
+0x01,0x21,0x21,0x3f,0x00,0x7f,0x00,0x1f,0x10,0x10,0x1f,0x00,0x08,0x04,0xff,0x00,
+0x00,0x08,0x08,0xf8,0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x00,0x20,0x40,0xfe,0x00,
+/* 35913 0x8c49 "豉" */
+0x00,0xfe,0x00,0x01,0x7c,0x44,0x44,0x45,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x41,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 35914 0x8c4a "豊" */
+0x04,0x3f,0x24,0x3f,0x24,0x3f,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x08,0x04,0xff,0x00,
+0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x20,0x40,0xfe,0x00,
+/* 35915 0x8c4b "豋" */
+0x10,0x10,0x3e,0x62,0x94,0x48,0x30,0x2f,0xc0,0x1f,0x10,0x1f,0x08,0x04,0xff,0x00,
+0x80,0x80,0xfc,0x44,0x48,0x30,0x10,0xe8,0x06,0xf0,0x10,0xf0,0x20,0x40,0xfe,0x00,
+/* 35916 0x8c4c "豌" */
+0x00,0xfc,0x03,0x02,0x7d,0x49,0x49,0x4a,0x7a,0x03,0x8c,0x48,0x51,0x19,0xe2,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 35917 0x8c4d "豍" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x29,0x2e,0xf0,0x40,0x00,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 35918 0x8c4e "豎" */
+0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x08,0x04,0xff,
+0xfc,0x44,0x44,0x28,0x10,0x28,0x44,0x82,0xfc,0x00,0xf0,0x10,0xf0,0x20,0x40,0xfe,
+/* 35919 0x8c4f "豏" */
+0x00,0xfe,0x00,0x01,0x7c,0x45,0x44,0x47,0x7c,0x01,0x44,0x28,0x2f,0xf2,0x40,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 35920 0x8c50 "豐" */
+0x08,0x1d,0x49,0x5d,0x49,0x5d,0x49,0x7f,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x04,0x7f,
+0x20,0x70,0x24,0x74,0x24,0x74,0x24,0xfc,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x40,0xfc,
+/* 35921 0x8c51 "豑" */
+0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x28,0x1e,0xe1,
+0x44,0x28,0x00,0xfc,0x14,0x14,0xfc,0x90,0x90,0xfe,0x32,0x32,0x5a,0x54,0x90,0x10,
+/* 35922 0x8c52 "豒" */
+0x2a,0x7f,0xaa,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0x00,0x7f,0x41,0x7f,0x22,0xff,
+0x22,0x14,0xbe,0x8a,0x8a,0xbe,0xa8,0xa8,0x3e,0x9a,0x1a,0x2a,0x2e,0x48,0x08,0x88,
+/* 35923 0x8c53 "豓" */
+0x2a,0x7f,0xaa,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0x00,0x7f,0x41,0x7f,0x22,0xff,
+0x10,0x10,0x90,0xbc,0x90,0xa8,0xa8,0xa4,0x54,0x82,0x7c,0x54,0x54,0x54,0x54,0xfe,
+/* 35924 0x8c54 "豔" */
+0x2a,0x7f,0xaa,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0x00,0x7f,0x41,0x7f,0x22,0xff,
+0x08,0x08,0x9c,0x88,0x88,0xbe,0x88,0x90,0x14,0xbe,0x00,0x3e,0x2a,0x2a,0x2a,0xfe,
+/* 35925 0x8c55 "豕" */
+0x00,0x7f,0x02,0x06,0x09,0x11,0x62,0x04,0x08,0x11,0x62,0x04,0x08,0x30,0xc2,0x01,
+0x00,0xfc,0x00,0x00,0x08,0x90,0xa0,0xc0,0xc0,0xa0,0x90,0x88,0x86,0x80,0x80,0x00,
+/* 35926 0x8c56 "豖" */
+0x00,0x7f,0x02,0x06,0x09,0x11,0x62,0x14,0x08,0x15,0x62,0x04,0x08,0x30,0xc2,0x01,
+0x00,0xfc,0x00,0x00,0x08,0x90,0xa0,0xc0,0xc0,0xa0,0x90,0x88,0x86,0x80,0x80,0x00,
+/* 35927 0x8c57 "豗" */
+0x00,0xfd,0x28,0x28,0x28,0x2b,0x28,0x28,0x2b,0x28,0x28,0x2b,0x28,0x48,0x47,0x80,
+0x00,0xfe,0x20,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x92,0x10,0x50,0x22,0xfe,0x00,
+/* 35928 0x8c58 "豘" */
+0x00,0xfc,0x10,0x23,0x60,0x95,0x39,0x51,0x99,0x35,0x54,0x90,0x10,0x10,0x50,0x20,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 35929 0x8c59 "豙" */
+0x02,0x01,0x3f,0x08,0x04,0xff,0x02,0x0d,0x71,0x02,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0x00,0xf8,0x20,0x40,0xfe,0x00,0x08,0x90,0xa0,0xc0,0xa0,0x98,0x86,0x80,0x00,
+/* 35930 0x8c5a "豚" */
+0x00,0x7b,0x48,0x48,0x49,0x7a,0x48,0x48,0x49,0x7a,0x48,0x48,0x49,0x4a,0x48,0x98,
+0x00,0xfe,0x40,0x80,0x44,0x24,0x68,0xb0,0x30,0x28,0x68,0xa4,0x22,0x20,0xa0,0x40,
+/* 35931 0x8c5b "豛" */
+0x00,0xfc,0x10,0x20,0x60,0x95,0x3a,0x51,0x98,0x34,0x54,0x90,0x10,0x10,0x50,0x23,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 35932 0x8c5c "豜" */
+0x00,0xfd,0x10,0x20,0x60,0x94,0x38,0x53,0x98,0x34,0x54,0x90,0x10,0x10,0x51,0x22,
+0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,0x08,
+/* 35933 0x8c5d "豝" */
+0x00,0xfd,0x11,0x21,0x61,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x11,0x50,0x20,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 35934 0x8c5e "豞" */
+0x00,0xfe,0x08,0x10,0x31,0x4a,0x9c,0x28,0x4c,0x9a,0x2a,0x48,0x88,0x08,0x28,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x28,0x10,
+/* 35935 0x8c5f "豟" */
+0x00,0xfc,0x11,0x21,0x61,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x12,0x52,0x24,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x08,0x10,0x20,0x42,0x82,0x7e,0x00,
+/* 35936 0x8c60 "豠" */
+0x00,0xfe,0x08,0x10,0x30,0x4a,0x9c,0x28,0x4c,0x9a,0x2a,0x48,0x88,0x08,0x2b,0x10,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 35937 0x8c61 "象" */
+0x08,0x1f,0x20,0x7f,0xa1,0x22,0x3f,0x06,0x19,0x62,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x00,0xe0,0x20,0xf8,0x08,0x08,0xf8,0x00,0x10,0xa0,0xc0,0xa0,0x90,0x88,0x86,0x00,
+/* 35938 0x8c62 "豢" */
+0x11,0x09,0x7f,0x04,0xff,0x10,0x2f,0xc6,0x19,0x62,0x0c,0x71,0x06,0x18,0xe2,0x01,
+0x10,0x20,0xfc,0x00,0xfe,0x10,0xc8,0x06,0x10,0xa0,0xc0,0xb0,0x88,0x84,0x80,0x00,
+/* 35939 0x8c63 "豣" */
+0x00,0xfd,0x10,0x20,0x60,0x94,0x38,0x53,0x98,0x34,0x54,0x90,0x10,0x11,0x51,0x22,
+0x00,0xdc,0x88,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 35940 0x8c64 "豤" */
+0x00,0xfd,0x11,0x21,0x61,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x11,0x51,0x21,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 35941 0x8c65 "豥" */
+0x00,0xfe,0x08,0x11,0x30,0x4a,0x9c,0x28,0x4c,0x9a,0x2a,0x49,0x88,0x08,0x28,0x11,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 35942 0x8c66 "豦" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x2f,0x23,0x2c,0x23,0x5c,0x43,0x9c,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xf8,0x00,0x90,0x60,0xd8,0x46,0xc0,
+/* 35943 0x8c67 "豧" */
+0x00,0xfc,0x13,0x20,0x60,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x11,0x51,0x21,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 35944 0x8c68 "豨" */
+0x00,0xfc,0x10,0x20,0x61,0x94,0x39,0x50,0x98,0x35,0x56,0x90,0x10,0x10,0x50,0x20,
+0xc2,0x34,0x18,0x64,0x82,0x20,0xfe,0x50,0x90,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 35945 0x8c69 "豩" */
+0x00,0xfd,0x10,0x20,0x60,0x95,0x38,0x50,0x98,0x35,0x54,0x90,0x10,0x11,0x50,0x20,
+0x00,0xfe,0x20,0x40,0xa2,0x12,0x34,0x58,0x98,0x14,0x34,0x52,0x90,0x10,0x50,0x20,
+/* 35946 0x8c6a "豪" */
+0x01,0x7f,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x40,0x9f,0x06,0x19,0x06,0x39,0x06,0x39,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xf4,0x00,0x20,0xc0,0xb0,0x8c,0x80,
+/* 35947 0x8c6b "豫" */
+0x00,0xf8,0x09,0x53,0x25,0x11,0xfd,0x24,0x28,0x23,0x20,0x23,0x20,0x20,0xa3,0x40,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 35948 0x8c6c "豬" */
+0x00,0xfe,0x08,0x10,0x30,0x4b,0x9c,0x28,0x4c,0x9b,0x2a,0x48,0x88,0x08,0x28,0x10,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 35949 0x8c6d "豭" */
+0x00,0xfd,0x11,0x21,0x61,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x11,0x51,0x21,
+0x00,0xdc,0x44,0x44,0x44,0xdc,0x00,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 35950 0x8c6e "豮" */
+0x00,0xfd,0x10,0x20,0x63,0x94,0x38,0x51,0x99,0x35,0x55,0x91,0x11,0x10,0x50,0x23,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 35951 0x8c6f "豯" */
+0x00,0xfe,0x08,0x10,0x30,0x4a,0x9c,0x28,0x4c,0x9a,0x2a,0x48,0x88,0x08,0x28,0x10,
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x44,0x82,
+/* 35952 0x8c70 "豰" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0xfe,0x20,0x54,0x28,0xdc,0x2a,0xd9,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 35953 0x8c71 "豱" */
+0x00,0xfc,0x10,0x20,0x60,0x94,0x38,0x50,0x98,0x35,0x55,0x91,0x11,0x11,0x53,0x20,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35954 0x8c72 "豲" */
+0x00,0xfd,0x11,0x21,0x61,0x95,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x12,0x52,0x24,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 35955 0x8c73 "豳" */
+0x01,0x41,0x7d,0x49,0x51,0x6b,0x4d,0x59,0x6d,0x4b,0x59,0x69,0x59,0x41,0x7f,0x00,
+0x00,0x04,0xf4,0x24,0x44,0xac,0x34,0x64,0xb4,0x2c,0x64,0xa4,0x64,0x04,0xfc,0x04,
+/* 35956 0x8c74 "豴" */
+0x00,0xfe,0x08,0x10,0x30,0x4a,0x9c,0x28,0x4c,0x9a,0x2a,0x48,0x88,0x08,0x28,0x10,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x82,0x92,0xfe,0x92,0xba,0xaa,0xaa,0xba,0x82,0x86,
+/* 35957 0x8c75 "豵" */
+0x01,0xf9,0x22,0x44,0xa1,0x15,0x3b,0x55,0x99,0x35,0x51,0x91,0x11,0x11,0x51,0x21,
+0x24,0x24,0x24,0xa4,0x54,0x4a,0x92,0x08,0x08,0x28,0x2e,0x28,0x28,0x58,0x4e,0x80,
+/* 35958 0x8c76 "豶" */
+0x00,0xfd,0x10,0x20,0x63,0x94,0x39,0x51,0x99,0x35,0x55,0x91,0x11,0x10,0x51,0x22,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 35959 0x8c77 "豷" */
+0x00,0xfb,0x20,0x41,0xa0,0x17,0x3a,0x51,0x98,0x35,0x51,0x91,0x11,0x10,0x53,0x20,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 35960 0x8c78 "豸" */
+0x00,0x07,0x7a,0x11,0x08,0x07,0x78,0x00,0x03,0x0c,0x70,0x01,0x06,0x18,0xe0,0x00,
+0xe0,0x00,0x0c,0x30,0xc0,0x80,0x40,0xa0,0x30,0x50,0x90,0x10,0x10,0x10,0xa0,0x40,
+/* 35961 0x8c79 "豹" */
+0x0c,0x30,0xc2,0x14,0x49,0x32,0xc8,0x15,0x24,0xcc,0x14,0x24,0xc4,0x04,0x28,0x10,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 35962 0x8c7a "豺" */
+0x0c,0x30,0xc2,0x14,0x49,0x30,0xc8,0x14,0x24,0xcc,0x14,0x25,0xc4,0x04,0x28,0x10,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x30,0x30,0x50,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 35963 0x8c7b "豻" */
+0x0c,0x30,0xc2,0x14,0x48,0x30,0xc8,0x15,0x24,0xcc,0x14,0x24,0xc4,0x04,0x28,0x10,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 35964 0x8c7c "豼" */
+0x0c,0x31,0xc3,0x15,0x49,0x31,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x05,0x29,0x10,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 35965 0x8c7d "豽" */
+0x0c,0x30,0xc2,0x15,0x49,0x31,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x05,0x29,0x11,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 35966 0x8c7e "豾" */
+0x0c,0x31,0xc2,0x14,0x48,0x30,0xc8,0x14,0x25,0xce,0x14,0x24,0xc4,0x04,0x2b,0x10,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 35967 0x8c7f "豿" */
+0x0c,0x30,0xc2,0x15,0x49,0x32,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x04,0x28,0x10,
+0x80,0x80,0x80,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0xe4,0x24,0x04,0x28,0x10,
+/* 35968 0x8c80 "貀" */
+0x0c,0x30,0xc3,0x15,0x49,0x31,0xc9,0x14,0x24,0xcd,0x15,0x25,0xc5,0x05,0x29,0x10,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 35969 0x8c81 "貁" */
+0x10,0x20,0xd4,0x0b,0x52,0x24,0xd0,0x18,0x28,0xc8,0x18,0x29,0xc9,0x09,0x52,0x24,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x90,0x90,0x90,0x88,0x08,0x08,0x04,0x04,0x02,
+/* 35970 0x8c82 "貂" */
+0x0c,0x31,0xc2,0x14,0x48,0x30,0xc8,0x14,0x25,0xcc,0x14,0x24,0xc4,0x04,0x28,0x10,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 35971 0x8c83 "貃" */
+0x0c,0x30,0xc2,0x15,0x49,0x31,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x05,0x29,0x11,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 35972 0x8c84 "貄" */
+0x0c,0x30,0xc3,0x14,0x4b,0x30,0xc9,0x14,0x24,0xcd,0x14,0x24,0xc7,0x04,0x28,0x10,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 35973 0x8c85 "貅" */
+0x10,0x20,0xd4,0x09,0x51,0x23,0xd5,0x19,0x29,0xc9,0x19,0x29,0xc9,0x09,0x51,0x21,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 35974 0x8c86 "貆" */
+0x0c,0x31,0xc2,0x14,0x48,0x30,0xc8,0x14,0x24,0xcc,0x14,0x24,0xc4,0x04,0x29,0x10,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 35975 0x8c87 "貇" */
+0x0c,0x31,0xc3,0x15,0x49,0x31,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x05,0x29,0x11,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 35976 0x8c88 "貈" */
+0x0c,0x30,0xc2,0x14,0x48,0x30,0xc8,0x15,0x24,0xcc,0x14,0x24,0xc4,0x05,0x29,0x12,
+0x10,0x20,0xfc,0x84,0xa4,0x94,0x94,0xfe,0x84,0xa4,0x94,0x94,0x84,0x04,0x14,0x08,
+/* 35977 0x8c89 "貉" */
+0x10,0x20,0xd4,0x09,0x53,0x24,0xd0,0x18,0x29,0xca,0x1d,0x29,0xc9,0x09,0x51,0x21,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 35978 0x8c8a "貊" */
+0x0c,0x30,0xc2,0x14,0x48,0x30,0xc8,0x14,0x24,0xcc,0x14,0x24,0xc4,0x04,0x28,0x10,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 35979 0x8c8b "貋" */
+0x0c,0x31,0xc3,0x15,0x49,0x31,0xc8,0x14,0x25,0xcc,0x14,0x27,0xc4,0x04,0x28,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 35980 0x8c8c "貌" */
+0x0c,0x30,0xc3,0x15,0x49,0x31,0xc9,0x15,0x25,0xcc,0x14,0x24,0xc4,0x04,0x29,0x12,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 35981 0x8c8d "貍" */
+0x0c,0x31,0xc3,0x15,0x49,0x31,0xc9,0x15,0x24,0xcc,0x15,0x24,0xc4,0x04,0x2b,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 35982 0x8c8e "貎" */
+0x10,0x20,0xd7,0x0a,0x52,0x23,0xd2,0x1a,0x2b,0xc8,0x18,0x28,0xc8,0x09,0x52,0x24,
+0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0xfc,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 35983 0x8c8f "貏" */
+0x10,0x20,0xd5,0x09,0x51,0x21,0xd1,0x19,0x29,0xc8,0x19,0x2b,0xc8,0x08,0x50,0x20,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 35984 0x8c90 "貐" */
+0x10,0x20,0xd5,0x0a,0x55,0x20,0xd3,0x1a,0x2a,0xcb,0x1a,0x2a,0xcb,0x0a,0x52,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 35985 0x8c91 "貑" */
+0x10,0x23,0xd6,0x0a,0x52,0x23,0xd2,0x1a,0x2b,0xca,0x1a,0x2b,0xca,0x0a,0x52,0x22,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 35986 0x8c92 "貒" */
+0x0c,0x31,0xc3,0x15,0x49,0x30,0xcb,0x14,0x24,0xcd,0x15,0x25,0xc5,0x05,0x29,0x11,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 35987 0x8c93 "貓" */
+0x0c,0x30,0xc3,0x14,0x48,0x30,0xc9,0x15,0x25,0xcd,0x15,0x25,0xc5,0x05,0x29,0x11,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 35988 0x8c94 "貔" */
+0x0c,0x30,0xc3,0x15,0x49,0x31,0xc9,0x15,0x25,0xcc,0x15,0x25,0xc5,0x05,0x29,0x11,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 35989 0x8c95 "貕" */
+0x10,0x23,0xd5,0x08,0x50,0x20,0xd1,0x18,0x28,0xc9,0x18,0x28,0xcb,0x08,0x50,0x23,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 35990 0x8c96 "貖" */
+0x11,0x20,0xd4,0x08,0x53,0x20,0xd0,0x19,0x2a,0xc9,0x19,0x29,0xc9,0x09,0x57,0x20,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 35991 0x8c97 "貗" */
+0x10,0x21,0xd5,0x0b,0x51,0x21,0xd0,0x19,0x29,0xc9,0x18,0x2b,0xc8,0x09,0x50,0x23,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 35992 0x8c98 "貘" */
+0x0c,0x30,0xc3,0x14,0x48,0x31,0xc9,0x15,0x25,0xcd,0x14,0x25,0xc4,0x04,0x29,0x12,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 35993 0x8c99 "貙" */
+0x10,0x23,0xd6,0x0a,0x52,0x22,0xd2,0x1a,0x2a,0xca,0x1a,0x2a,0xca,0x0a,0x53,0x20,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 35994 0x8c9a "貚" */
+0x10,0x23,0xd6,0x0a,0x53,0x20,0xd1,0x19,0x29,0xc9,0x19,0x28,0xcb,0x08,0x50,0x20,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 35995 0x8c9b "貛" */
+0x10,0x23,0xd4,0x0b,0x52,0x23,0xd0,0x18,0x29,0xc9,0x1b,0x2d,0xc9,0x09,0x51,0x21,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 35996 0x8c9c "貜" */
+0x13,0x22,0xd7,0x0a,0x53,0x20,0xd1,0x1b,0x2d,0xc9,0x19,0x28,0xc9,0x08,0x50,0x27,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 35997 0x8c9d "貝" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x00,0x08,0x10,0x20,0x40,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x20,0x10,0x08,0x04,
+/* 35998 0x8c9e "貞" */
+0x01,0x01,0x01,0x01,0x3f,0x20,0x20,0x3f,0x20,0x3f,0x20,0x20,0x3f,0x08,0x10,0x20,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0x08,0xf8,0x20,0x10,0x08,
+/* 35999 0x8c9f "貟" */
+0x08,0x10,0x20,0x7f,0x20,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x00,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 36000 0x8ca0 "負" */
+0x08,0x08,0x1f,0x20,0x40,0xbf,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x00,0x04,0x18,0x60,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x60,0x18,0x04,
+/* 36001 0x8ca1 "財" */
+0x00,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x28,0x24,0x44,0x80,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x30,0x30,0x50,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 36002 0x8ca2 "貢" */
+0x00,0x3f,0x01,0x01,0xff,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x00,0xf8,0x00,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 36003 0x8ca3 "貣" */
+0x04,0x02,0x01,0xff,0x00,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x20,0x10,0x3e,0xc0,0x22,0x1a,0xf6,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x20,0x10,
+/* 36004 0x8ca4 "貤" */
+0x00,0x78,0x48,0x49,0x79,0x49,0x49,0x7b,0x49,0x49,0x79,0x01,0x51,0x49,0x88,0x00,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 36005 0x8ca5 "貥" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x25,0x45,0x82,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 36006 0x8ca6 "貦" */
+0x00,0x7c,0x45,0x44,0x7c,0x44,0x47,0x7c,0x44,0x44,0x7c,0x00,0x28,0x25,0x45,0x82,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,
+/* 36007 0x8ca7 "貧" */
+0x04,0x08,0x30,0xcf,0x04,0x18,0x60,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0x20,0x18,0xe6,0x20,0xa0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36008 0x8ca8 "貨" */
+0x08,0x10,0x30,0x57,0x90,0x10,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x80,0x98,0xe0,0x84,0x84,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36009 0x8ca9 "販" */
+0x00,0x78,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 36010 0x8caa "貪" */
+0x01,0x02,0x0c,0x31,0xcf,0x00,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0x80,0x60,0x18,0xe6,0x40,0x80,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36011 0x8cab "貫" */
+0x00,0x1f,0x11,0xff,0x11,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xf0,0x10,0xfe,0x10,0xf0,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36012 0x8cac "責" */
+0x01,0x3f,0x01,0x1f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xf8,0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36013 0x8cad "貭" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x24,0x47,0x42,0x84,
+0x08,0x7c,0x80,0x80,0x80,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 36014 0x8cae "貮" */
+0x00,0x3f,0x00,0x00,0xff,0x00,0x7f,0x40,0x7f,0x40,0x7f,0x40,0x7f,0x12,0x21,0x40,
+0x20,0x28,0x24,0x20,0xfe,0x20,0xa0,0xa0,0xa0,0x90,0x90,0x90,0x8a,0x0a,0x06,0x82,
+/* 36015 0x8caf "貯" */
+0x00,0x7c,0x44,0x45,0x7d,0x46,0x44,0x7c,0x45,0x44,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 36016 0x8cb0 "貰" */
+0x12,0x7f,0x12,0x13,0x10,0x1f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0xfc,0x20,0xe0,0x00,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36017 0x8cb1 "貱" */
+0x00,0x78,0x48,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 36018 0x8cb2 "貲" */
+0x08,0x28,0x2e,0x28,0x2e,0xf0,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36019 0x8cb3 "貳" */
+0x00,0xff,0x00,0x3f,0x00,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x11,0x20,
+0x24,0xfe,0x20,0xa0,0x20,0xa0,0x20,0xa0,0xa0,0x90,0x90,0x90,0x8a,0x8a,0x06,0x82,
+/* 36020 0x8cb4 "貴" */
+0x01,0x1f,0x11,0x1f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xf0,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36021 0x8cb5 "貵" */
+0x04,0x08,0x1f,0x02,0xff,0x08,0x30,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0x20,0xf0,0x10,0xfe,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36022 0x8cb6 "貶" */
+0x00,0x7c,0x45,0x44,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x00,0x28,0x25,0x46,0x80,
+0x04,0x1e,0xe0,0x00,0x20,0x10,0xfe,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x3e,0x00,
+/* 36023 0x8cb7 "買" */
+0x00,0x7f,0x44,0x44,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x00,0xfc,0x44,0x44,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 36024 0x8cb8 "貸" */
+0x08,0x10,0x30,0xd7,0x10,0x10,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x90,0x88,0x7e,0xc0,0x22,0x1a,0x06,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36025 0x8cb9 "貹" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x45,0x80,
+0x10,0x10,0x90,0x90,0xfe,0x90,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 36026 0x8cba "貺" */
+0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x45,0x82,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 36027 0x8cbb "費" */
+0x04,0x7f,0x04,0x3f,0x24,0x3f,0x08,0x1f,0x30,0x5f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0xf4,0x1c,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36028 0x8cbc "貼" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 36029 0x8cbd "貽" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36030 0x8cbe "貾" */
+0x00,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 36031 0x8cbf "貿" */
+0x06,0x78,0x40,0x48,0x44,0x5a,0x61,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x44,0x44,0x44,0x94,0x08,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36032 0x8cc0 "賀" */
+0x10,0x10,0x7e,0x12,0x22,0x2a,0x44,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36033 0x8cc1 "賁" */
+0x01,0x3f,0x01,0x08,0xff,0x08,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xf8,0x00,0x20,0xfe,0x20,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36034 0x8cc2 "賂" */
+0x00,0x78,0x48,0x49,0x7b,0x4c,0x48,0x78,0x49,0x4a,0x7d,0x01,0x51,0x49,0x89,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 36035 0x8cc3 "賃" */
+0x08,0x13,0x30,0x57,0x90,0x13,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x18,0xe0,0x40,0xfc,0x40,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36036 0x8cc4 "賄" */
+0x00,0x7c,0x45,0x44,0x7c,0x44,0x44,0x7d,0x46,0x44,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 36037 0x8cc5 "賅" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x01,0x28,0x24,0x44,0x81,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 36038 0x8cc6 "賆" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x45,0x7c,0x00,0x28,0x24,0x45,0x82,
+0x82,0x42,0x44,0x00,0xfe,0x44,0x44,0x44,0x44,0xfe,0x44,0x44,0x84,0x84,0x04,0x04,
+/* 36039 0x8cc7 "資" */
+0x41,0x21,0x0a,0x10,0xe0,0x21,0x26,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x44,0x48,0xa0,0x18,0x06,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36040 0x8cc8 "賈" */
+0x00,0x7f,0x04,0x3f,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x40,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36041 0x8cc9 "賉" */
+0x00,0x7c,0x44,0x44,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x01,0x29,0x25,0x47,0x80,
+0x20,0x20,0x40,0x80,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 36042 0x8cca "賊" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x47,0x44,0x7c,0x00,0x28,0x25,0x45,0x82,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xf2,0x94,0x94,0x88,0x8a,0x1a,0x26,0x42,
+/* 36043 0x8ccb "賋" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x45,0x7e,0x44,0x44,0x7c,0x00,0x28,0x24,0x44,0x83,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 36044 0x8ccc "賌" */
+0x01,0xff,0x08,0x1f,0x06,0x38,0x07,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfe,0x40,0x90,0x20,0xd0,0x08,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36045 0x8ccd "賍" */
+0x00,0x78,0x48,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 36046 0x8cce "賎" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x45,0x7c,0x44,0x45,0x7c,0x00,0x28,0x24,0x45,0x80,
+0x28,0x24,0x3e,0xe0,0x20,0x3c,0xe0,0x20,0x3e,0xe0,0x22,0x24,0x18,0x6a,0x86,0x02,
+/* 36047 0x8ccf "賏" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x44,0x81,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x48,0x44,0x82,0x02,
+/* 36048 0x8cd0 "賐" */
+0x00,0x78,0x48,0x49,0x7b,0x48,0x48,0x79,0x4a,0x48,0x79,0x02,0x50,0x48,0x89,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 36049 0x8cd1 "賑" */
+0x00,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 36050 0x8cd2 "賒" */
+0x00,0x7c,0x44,0x44,0x7d,0x46,0x44,0x7c,0x47,0x44,0x7d,0x01,0x2a,0x24,0x44,0x80,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 36051 0x8cd3 "賓" */
+0x01,0x7f,0x40,0xbf,0x09,0x31,0x03,0x3f,0xe0,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,
+0x00,0xfe,0x02,0xfc,0x10,0x60,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,
+/* 36052 0x8cd4 "賔" */
+0x01,0x7f,0x40,0xbf,0x21,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x4f,0x44,0x88,
+0x00,0xfe,0x02,0xfc,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 36053 0x8cd5 "賕" */
+0x00,0x7c,0x44,0x44,0x7d,0x44,0x45,0x7c,0x44,0x44,0x7c,0x01,0x2a,0x24,0x44,0x80,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 36054 0x8cd6 "賖" */
+0x00,0x7c,0x44,0x44,0x7d,0x46,0x44,0x7c,0x47,0x44,0x7d,0x01,0x2a,0x24,0x44,0x80,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 36055 0x8cd7 "賗" */
+0x00,0x78,0x49,0x49,0x79,0x49,0x48,0x78,0x4b,0x4a,0x7a,0x03,0x52,0x48,0x88,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0xfe,0x22,0x20,0x20,0x20,
+/* 36056 0x8cd8 "賘" */
+0x00,0x78,0x48,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x14,0x12,0x12,0x10,0xfe,0x00,
+/* 36057 0x8cd9 "賙" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x25,0x45,0x82,
+0x00,0xfe,0x92,0x92,0xba,0x92,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x02,0x0a,0x04,
+/* 36058 0x8cda "賚" */
+0x01,0x7f,0x09,0x15,0x23,0x05,0x09,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x20,0x50,0x88,0x40,0x20,0xf8,0x16,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36059 0x8cdb "賛" */
+0x08,0x08,0x7e,0x08,0xfe,0x14,0x22,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0x20,0xfc,0x20,0xfe,0x50,0x88,0xf6,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36060 0x8cdc "賜" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x02,0x28,0x25,0x44,0x80,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 36061 0x8cdd "賝" */
+0x00,0x7b,0x4a,0x4a,0x78,0x49,0x48,0x78,0x4b,0x48,0x78,0x00,0x51,0x4e,0x88,0x00,
+0x00,0xfe,0x02,0x52,0x88,0x04,0x20,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36062 0x8cde "賞" */
+0x11,0x09,0x7f,0x40,0x9f,0x10,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x20,
+0x10,0x20,0xfe,0x02,0xf4,0x10,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0x08,
+/* 36063 0x8cdf "賟" */
+0x00,0x7c,0x44,0x45,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x03,0x28,0x24,0x45,0x82,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x88,0x04,0x02,
+/* 36064 0x8ce0 "賠" */
+0x00,0x7c,0x45,0x44,0x7d,0x44,0x44,0x7d,0x44,0x44,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 36065 0x8ce1 "賡" */
+0x00,0x3f,0x20,0x2f,0x20,0x3f,0x21,0x2f,0x24,0x2f,0x34,0x27,0x44,0x47,0x82,0x04,
+0x80,0xfe,0x80,0xf8,0x88,0xfe,0x08,0xf8,0x10,0xf8,0x16,0xf0,0x10,0xf0,0x20,0x10,
+/* 36066 0x8ce2 "賢" */
+0x00,0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x44,0x44,0x28,0x10,0x28,0xf6,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36067 0x8ce3 "賣" */
+0x01,0xff,0x01,0x3f,0x00,0x7f,0x44,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfe,0x00,0xf8,0x00,0xfc,0x44,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36068 0x8ce4 "賤" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7d,0x00,0x28,0x24,0x44,0x81,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 36069 0x8ce5 "賥" */
+0x00,0x7c,0x45,0x44,0x7c,0x44,0x45,0x7e,0x44,0x44,0x7d,0x00,0x28,0x24,0x44,0x80,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 36070 0x8ce6 "賦" */
+0x00,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x45,0x45,0x7d,0x01,0x29,0x25,0x47,0x81,
+0x08,0x0c,0xea,0x0a,0x08,0xfe,0x48,0x48,0x48,0x68,0x48,0x48,0x4a,0x6a,0x86,0x02,
+/* 36071 0x8ce7 "賧" */
+0x00,0x7c,0x44,0x45,0x7c,0x44,0x47,0x7c,0x44,0x44,0x7c,0x01,0x28,0x24,0x45,0x82,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 36072 0x8ce8 "賨" */
+0x01,0x7f,0x40,0x1f,0x00,0x7f,0x11,0x25,0x42,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x04,0xf0,0x00,0xfc,0x10,0x08,0x04,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36073 0x8ce9 "賩" */
+0x00,0x78,0x4b,0x4a,0x78,0x49,0x48,0x78,0x4b,0x48,0x79,0x01,0x52,0x4c,0x88,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 36074 0x8cea "質" */
+0x06,0x38,0x20,0x3f,0x24,0x24,0x44,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x0c,0x70,0x40,0x7e,0x48,0x48,0x88,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36075 0x8ceb "賫" */
+0x01,0x7f,0x09,0x09,0x15,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x20,0x20,0x50,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36076 0x8cec "賬" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7f,0x45,0x45,0x7d,0x01,0x29,0x25,0x45,0x81,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 36077 0x8ced "賭" */
+0x00,0x7c,0x45,0x44,0x7c,0x47,0x44,0x7c,0x44,0x45,0x7e,0x00,0x28,0x24,0x44,0x80,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 36078 0x8cee "賮" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0x7f,0x24,0x5f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xf8,0x08,0xfe,0x08,0xf8,0x00,0xfc,0x88,0xf4,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36079 0x8cef "賯" */
+0x01,0x79,0x4a,0x4d,0x79,0x49,0x49,0x79,0x48,0x4b,0x78,0x00,0x57,0x48,0x88,0x00,
+0x00,0xfe,0x02,0xf2,0x12,0xf2,0x12,0xfa,0x04,0xf8,0x10,0x20,0xfe,0x20,0xa0,0x40,
+/* 36080 0x8cf0 "賰" */
+0x00,0x7c,0x47,0x44,0x7d,0x44,0x47,0x7c,0x45,0x46,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 36081 0x8cf1 "賱" */
+0x00,0x7b,0x4a,0x48,0x7b,0x48,0x49,0x79,0x49,0x49,0x79,0x00,0x53,0x48,0x88,0x00,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 36082 0x8cf2 "賲" */
+0x13,0x12,0x23,0x60,0xa7,0x21,0x22,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0xf8,0x08,0xf8,0x40,0xfc,0x50,0x48,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36083 0x8cf3 "賳" */
+0x01,0x79,0x4b,0x49,0x79,0x4f,0x48,0x78,0x4b,0x4a,0x7a,0x02,0x53,0x48,0x88,0x00,
+0x28,0x24,0xa4,0x20,0x20,0xfe,0x20,0x24,0xa4,0xa8,0xa8,0x90,0x92,0x2a,0x46,0x82,
+/* 36084 0x8cf4 "賴" */
+0x10,0x10,0xfe,0x10,0x11,0xfe,0x92,0x92,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x11,
+0x20,0x20,0x78,0x88,0x10,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,0x02,
+/* 36085 0x8cf5 "賵" */
+0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x44,0x80,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 36086 0x8cf6 "賶" */
+0x00,0x7c,0x44,0x44,0x7c,0x45,0x46,0x7c,0x44,0x44,0x7c,0x00,0x29,0x25,0x46,0x80,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 36087 0x8cf7 "賷" */
+0x01,0x7f,0x01,0x3d,0x25,0x3d,0x01,0x7f,0x50,0x9f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x00,0xfc,0x00,0x78,0x48,0x78,0x00,0xfe,0x12,0xf4,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36088 0x8cf8 "賸" */
+0x00,0x3d,0x24,0x25,0x24,0x3f,0x24,0x25,0x26,0x3c,0x24,0x24,0x24,0x44,0x54,0x88,
+0x20,0x24,0xa8,0xfc,0x40,0xfe,0x88,0xfc,0x8a,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,
+/* 36089 0x8cf9 "賹" */
+0x01,0x78,0x48,0x48,0x7b,0x48,0x48,0x79,0x4a,0x49,0x79,0x01,0x51,0x49,0x8f,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 36090 0x8cfa "賺" */
+0x01,0x78,0x48,0x4b,0x78,0x4b,0x48,0x7b,0x48,0x4b,0x78,0x01,0x52,0x4c,0x88,0x00,
+0x10,0xa0,0x00,0xfc,0xa0,0xf8,0xa8,0xfe,0xa8,0xf8,0xa0,0xb0,0xa8,0xa6,0xa0,0xa0,
+/* 36091 0x8cfb "賻" */
+0x00,0x7c,0x47,0x44,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7c,0x03,0x28,0x24,0x44,0x80,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 36092 0x8cfc "購" */
+0x00,0x78,0x4b,0x48,0x79,0x48,0x4b,0x78,0x49,0x49,0x79,0x01,0x53,0x49,0x89,0x01,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 36093 0x8cfd "賽" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x1f,0x28,0xcf,0x08,0x0f,0x04,0x08,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x28,0xe6,0x20,0xe0,0x40,0x20,
+/* 36094 0x8cfe "賾" */
+0x00,0x7d,0x48,0x48,0x48,0x5d,0x54,0x54,0x54,0x5c,0x48,0x48,0x48,0x7e,0x00,0x00,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 36095 0x8cff "賿" */
+0x00,0x7b,0x48,0x4a,0x79,0x4a,0x48,0x78,0x4b,0x48,0x79,0x00,0x51,0x48,0x88,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 36096 0x8d00 "贀" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36097 0x8d01 "贁" */
+0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x43,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 36098 0x8d02 "贂" */
+0x00,0x78,0x49,0x49,0x7a,0x4b,0x48,0x79,0x4e,0x48,0x7b,0x00,0x53,0x48,0x88,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 36099 0x8d03 "贃" */
+0x00,0x78,0x49,0x49,0x79,0x48,0x4b,0x7a,0x4b,0x48,0x78,0x00,0x52,0x4a,0x8c,0x00,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x20,0x40,0x24,0xa2,0x8a,0x78,0x00,
+/* 36100 0x8d04 "贄" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36101 0x8d05 "贅" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x5f,0x90,0x1f,0x10,0x1f,0x08,0x10,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0xf2,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36102 0x8d06 "贆" */
+0x00,0x78,0x4b,0x48,0x78,0x49,0x4a,0x79,0x49,0x49,0x7b,0x01,0x52,0x4a,0x8c,0x08,
+0x28,0x24,0xfe,0x50,0x88,0x04,0x02,0x98,0x54,0x10,0xbe,0x10,0xa8,0xa8,0x44,0x82,
+/* 36103 0x8d07 "贇" */
+0x41,0x20,0xfb,0x10,0x52,0x22,0x57,0x80,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,
+0xd4,0x10,0xfe,0x90,0xc8,0x8a,0xe6,0x02,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,
+/* 36104 0x8d08 "贈" */
+0x01,0x78,0x48,0x4b,0x7a,0x4a,0x4a,0x7a,0x4b,0x48,0x79,0x01,0x51,0x49,0x89,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 36105 0x8d09 "贉" */
+0x00,0x7b,0x48,0x4b,0x7a,0x4b,0x48,0x79,0x49,0x49,0x79,0x01,0x50,0x4b,0x88,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 36106 0x8d0a "贊" */
+0x28,0x3e,0x48,0xfe,0x15,0x26,0x44,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x50,0x7c,0x90,0xfe,0x28,0x4a,0x86,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36107 0x8d0b "贋" */
+0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x24,0x20,0x27,0x24,0x27,0x44,0x47,0x82,0x04,
+0xfe,0x50,0x88,0xfe,0x90,0xfc,0x90,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 36108 0x8d0c "贌" */
+0x00,0x7a,0x49,0x48,0x7b,0x48,0x48,0x7b,0x48,0x49,0x78,0x03,0x50,0x48,0x89,0x06,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 36109 0x8d0d "贍" */
+0x00,0x78,0x49,0x4b,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x4a,0x8a,0x04,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 36110 0x8d0e "贎" */
+0x00,0x78,0x4b,0x48,0x79,0x49,0x49,0x79,0x49,0x48,0x7b,0x02,0x52,0x4a,0x8a,0x02,
+0x88,0x88,0xfe,0x88,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x06,
+/* 36111 0x8d0f "贏" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x77,0x54,0x77,0x54,0x77,0x52,0xb4,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0xdc,0x54,0xd4,0x5c,0xd6,0x96,0x62,
+/* 36112 0x8d10 "贐" */
+0x00,0x79,0x48,0x4b,0x78,0x49,0x48,0x7b,0x48,0x4a,0x7c,0x01,0x51,0x49,0x8f,0x00,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfe,0x00,0xa4,0x52,0xfc,0x54,0x54,0xfe,0x00,
+/* 36113 0x8d11 "贑" */
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,0x11,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,0x02,
+/* 36114 0x8d12 "贒" */
+0x7e,0x51,0x7d,0x45,0x7c,0x51,0x7e,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,
+0x20,0xfc,0x24,0xfc,0x24,0x4a,0xf8,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,
+/* 36115 0x8d13 "贓" */
+0x00,0x70,0x51,0x55,0x75,0x55,0x57,0x71,0x51,0x5f,0x75,0x05,0x55,0x4a,0x82,0x04,
+0x0c,0x0a,0xfe,0x08,0xe8,0x48,0x4a,0xea,0x2a,0xec,0x4c,0x4c,0xea,0x0a,0x16,0x22,
+/* 36116 0x8d14 "贔" */
+0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,
+0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 36117 0x8d15 "贕" */
+0x20,0xce,0x8a,0xaa,0xaa,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0xa8,0x28,0x48,0x48,0x88,
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0xaa,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,
+/* 36118 0x8d16 "贖" */
+0x00,0x7b,0x48,0x49,0x78,0x4b,0x4a,0x7b,0x49,0x49,0x79,0x01,0x51,0x49,0x88,0x01,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 36119 0x8d17 "贗" */
+0x3f,0x22,0x25,0x2d,0x35,0x25,0x25,0x26,0x24,0x27,0x24,0x27,0x44,0x47,0x82,0x04,
+0xfe,0x40,0xf8,0x08,0xf8,0x08,0xfe,0xaa,0x06,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,
+/* 36120 0x8d18 "贘" */
+0x01,0x78,0x4b,0x4a,0x78,0x48,0x49,0x79,0x49,0x49,0x79,0x01,0x51,0x48,0x88,0x01,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,
+/* 36121 0x8d19 "贙" */
+0x0e,0x08,0x7e,0x4a,0x5c,0x4a,0x5c,0x95,0x22,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,
+0x1c,0x10,0xfc,0x94,0xb8,0x94,0xb8,0x2a,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 36122 0x8d1a "贚" */
+0x01,0x78,0x4b,0x48,0x7a,0x49,0x4b,0x78,0x4b,0x4a,0x7b,0x02,0x53,0x4a,0x8a,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 36123 0x8d1b "贛" */
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x45,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,0x10,
+0x40,0x7c,0xc8,0x30,0xce,0x78,0x20,0xfc,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,
+/* 36124 0x8d1c "贜" */
+0x00,0x70,0x57,0x50,0x70,0x51,0x55,0x77,0x51,0x51,0x7f,0x05,0x55,0x49,0x82,0x04,
+0x90,0x90,0xfe,0x94,0x0a,0xfe,0x08,0xe8,0x4a,0xea,0x2a,0xea,0x4c,0xea,0x16,0x62,
+/* 36125 0x8d1d "贝" */
+0x00,0x1f,0x10,0x10,0x10,0x11,0x11,0x11,0x11,0x11,0x12,0x02,0x04,0x08,0x10,0x20,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x80,0x40,0x20,0x10,0x08,
+/* 36126 0x8d1e "贞" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x21,0x21,0x21,0x22,0x22,0x04,0x08,0x30,0xc0,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xc0,0x30,0x08,0x04,
+/* 36127 0x8d1f "负" */
+0x04,0x04,0x0f,0x10,0x20,0x5f,0x10,0x11,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0x00,0x00,0xe0,0x20,0x40,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0xc0,0x20,0x10,0x08,
+/* 36128 0x8d20 "贠" */
+0x02,0x04,0x08,0x10,0x3f,0x00,0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x04,0x18,0x60,
+0x00,0x00,0x20,0x10,0xf8,0x08,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36129 0x8d21 "贡" */
+0x00,0x3f,0x01,0x01,0x7f,0x00,0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x04,0x18,0x60,
+0x00,0xf8,0x00,0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36130 0x8d22 "财" */
+0x00,0x7c,0x44,0x54,0x55,0x54,0x54,0x54,0x54,0x54,0x54,0x11,0x28,0x24,0x44,0x80,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x30,0x30,0x50,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 36131 0x8d23 "责" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0xff,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36132 0x8d24 "贤" */
+0x04,0x25,0x24,0x24,0x24,0x24,0x27,0x04,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0xf8,0x88,0x50,0x20,0xd8,0x06,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36133 0x8d25 "败" */
+0x00,0x7c,0x44,0x54,0x54,0x55,0x56,0x54,0x54,0x54,0x54,0x10,0x28,0x24,0x45,0x82,
+0x40,0x40,0x40,0x80,0xfe,0x08,0x88,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 36134 0x8d26 "账" */
+0x00,0x7c,0x44,0x54,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x10,0x28,0x24,0x44,0x80,
+0x80,0x84,0x84,0x88,0x90,0xa0,0x80,0xfe,0xa0,0xa0,0x90,0x90,0x88,0xa4,0xc2,0x80,
+/* 36135 0x8d27 "货" */
+0x08,0x08,0x10,0x30,0x57,0x90,0x10,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x80,0x80,0x98,0xe0,0x84,0x84,0x7c,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36136 0x8d28 "质" */
+0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x41,0x46,0x98,
+0x7c,0xc0,0x40,0x40,0xfe,0x40,0x40,0xfc,0x04,0x44,0x44,0x44,0xb4,0x08,0x04,0x02,
+/* 36137 0x8d29 "贩" */
+0x00,0x7c,0x44,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x10,0x29,0x25,0x42,0x80,
+0x04,0x0e,0xf0,0x80,0x80,0xfc,0xa4,0xa4,0xa4,0xa8,0xa8,0x90,0x10,0x28,0x44,0x82,
+/* 36138 0x8d2a "贪" */
+0x01,0x02,0x04,0x09,0x30,0xcf,0x00,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0x80,0x40,0x20,0x98,0xe6,0x40,0x80,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36139 0x8d2b "贫" */
+0x04,0x08,0x30,0xdf,0x04,0x04,0x08,0x10,0x3f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x40,0x20,0x18,0xe6,0x20,0x20,0xa0,0x40,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36140 0x8d2c "贬" */
+0x00,0x7c,0x45,0x44,0x54,0x54,0x55,0x54,0x54,0x54,0x54,0x10,0x28,0x25,0x42,0x80,
+0x08,0x3c,0xc0,0x00,0x20,0x10,0xfc,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x3e,0x00,
+/* 36141 0x8d2d "购" */
+0x00,0x7c,0x44,0x54,0x55,0x55,0x56,0x54,0x54,0x54,0x55,0x11,0x28,0x24,0x44,0x80,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x44,0x44,0x84,0xa4,0x14,0xf4,0x14,0x04,0x28,0x10,
+/* 36142 0x8d2e "贮" */
+0x00,0x7c,0x44,0x54,0x55,0x55,0x56,0x54,0x54,0x54,0x54,0x10,0x28,0x25,0x44,0x80,
+0x40,0x20,0x20,0x00,0xfe,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 36143 0x8d2f "贯" */
+0x1f,0x11,0x11,0xff,0x11,0x11,0x1f,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0xf0,0x10,0x10,0xfe,0x10,0x10,0xf0,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36144 0x8d30 "贰" */
+0x00,0x00,0xff,0x00,0x3f,0x00,0x7f,0x00,0x3f,0x20,0x24,0x24,0x24,0x0a,0x11,0x60,
+0x28,0x24,0xfe,0x20,0xa0,0x20,0xa0,0x20,0xa0,0x90,0x90,0x90,0x8a,0x0a,0x06,0x82,
+/* 36145 0x8d31 "贱" */
+0x00,0x7c,0x44,0x44,0x55,0x54,0x54,0x57,0x54,0x54,0x54,0x10,0x28,0x24,0x43,0x80,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 36146 0x8d32 "贲" */
+0x01,0x3f,0x01,0x08,0xff,0x08,0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x04,0x18,0x60,
+0x00,0xf8,0x00,0x20,0xfe,0x20,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36147 0x8d33 "贳" */
+0x12,0x12,0xff,0x12,0x13,0x10,0x1f,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x20,0x20,0xfe,0x20,0xe0,0x00,0xf8,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36148 0x8d34 "贴" */
+0x00,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x55,0x55,0x55,0x11,0x29,0x25,0x45,0x81,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 36149 0x8d35 "贵" */
+0x01,0x1f,0x11,0x11,0x1f,0x01,0xff,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xfe,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36150 0x8d36 "贶" */
+0x00,0x7d,0x45,0x45,0x55,0x55,0x55,0x54,0x54,0x54,0x54,0x10,0x28,0x25,0x42,0x84,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 36151 0x8d37 "贷" */
+0x08,0x10,0x30,0xd7,0x10,0x10,0x00,0x1f,0x10,0x11,0x11,0x11,0x12,0x04,0x18,0x60,
+0x90,0x88,0x7e,0xc0,0x22,0x1a,0x06,0xf0,0x10,0x10,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36152 0x8d38 "贸" */
+0x06,0x78,0x40,0x48,0x44,0x5a,0x61,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0xfc,0x44,0x44,0x44,0x94,0x08,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36153 0x8d39 "费" */
+0x04,0x7f,0x04,0x3f,0x24,0x3f,0x08,0x10,0x20,0x5f,0x10,0x11,0x11,0x02,0x0c,0x30,
+0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0x08,0xf0,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36154 0x8d3a "贺" */
+0x10,0x10,0x7e,0x12,0x22,0x2a,0x44,0x9f,0x10,0x11,0x11,0x11,0x12,0x04,0x18,0x60,
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36155 0x8d3b "贻" */
+0x00,0x7c,0x44,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x54,0x10,0x28,0x24,0x44,0x80,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36156 0x8d3c "贼" */
+0x00,0x7c,0x44,0x45,0x54,0x54,0x54,0x54,0x57,0x54,0x54,0x10,0x28,0x25,0x41,0x82,
+0x14,0x12,0x10,0xfe,0x10,0x90,0x92,0x92,0xf2,0x94,0x94,0x88,0x8a,0x1a,0x26,0x42,
+/* 36157 0x8d3d "贽" */
+0x10,0x10,0xfb,0x10,0x19,0xf0,0x11,0x52,0x24,0x1f,0x10,0x11,0x11,0x02,0x0c,0x30,
+0x80,0x80,0xf0,0x90,0x90,0x94,0x54,0x0c,0x04,0xf0,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36158 0x8d3e "贾" */
+0x00,0x7f,0x04,0x3f,0x24,0x24,0x3f,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0xfc,0x40,0xf8,0x48,0x48,0xf8,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36159 0x8d3f "贿" */
+0x00,0x7c,0x45,0x54,0x54,0x54,0x54,0x55,0x56,0x54,0x54,0x10,0x28,0x24,0x44,0x80,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 36160 0x8d40 "赀" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36161 0x8d41 "赁" */
+0x08,0x13,0x30,0x50,0x97,0x10,0x10,0x13,0x00,0x1f,0x10,0x11,0x11,0x02,0x0c,0x30,
+0x38,0xc0,0x40,0x40,0xfc,0x40,0x40,0xf8,0x00,0xf0,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36162 0x8d42 "赂" */
+0x00,0x7c,0x44,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x10,0x28,0x24,0x44,0x80,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 36163 0x8d43 "赃" */
+0x00,0x7c,0x44,0x45,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x11,0x29,0x26,0x42,0x84,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 36164 0x8d44 "资" */
+0x01,0x41,0x21,0x0a,0x14,0xe0,0x21,0x26,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0x00,0xfc,0x44,0x48,0xa0,0x10,0x0c,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36165 0x8d45 "赅" */
+0x00,0x7c,0x44,0x47,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x13,0x28,0x24,0x40,0x83,
+0x20,0x10,0x10,0xfe,0x20,0x42,0x84,0xf8,0x10,0x22,0xc4,0x08,0x10,0x28,0xc4,0x02,
+/* 36166 0x8d46 "赆" */
+0x00,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x55,0x55,0x12,0x28,0x24,0x44,0x80,
+0x00,0xfc,0x84,0x84,0xfc,0x90,0x90,0x88,0x84,0x32,0x08,0x00,0x60,0x18,0x04,0x00,
+/* 36167 0x8d47 "赇" */
+0x00,0x7c,0x44,0x54,0x55,0x54,0x55,0x54,0x54,0x54,0x54,0x11,0x2a,0x24,0x44,0x80,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 36168 0x8d48 "赈" */
+0x00,0x7d,0x45,0x45,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x11,0x29,0x26,0x42,0x84,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 36169 0x8d49 "赉" */
+0x01,0x01,0x7f,0x11,0x09,0xff,0x05,0x09,0x30,0xdf,0x10,0x11,0x11,0x02,0x0c,0x30,
+0x00,0x00,0xfc,0x10,0x20,0xfe,0x40,0x20,0x18,0xf6,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36170 0x8d4a "赊" */
+0x00,0x7c,0x44,0x54,0x55,0x56,0x54,0x54,0x57,0x54,0x55,0x11,0x2a,0x24,0x44,0x80,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 36171 0x8d4b "赋" */
+0x00,0x7c,0x44,0x44,0x54,0x55,0x54,0x54,0x55,0x55,0x55,0x11,0x29,0x25,0x43,0x81,
+0x08,0x0c,0xea,0x0a,0x08,0xfe,0x48,0x48,0x48,0x68,0x48,0x48,0x4a,0x6a,0x86,0x02,
+/* 36172 0x8d4c "赌" */
+0x00,0x7c,0x45,0x44,0x54,0x57,0x54,0x54,0x54,0x55,0x56,0x10,0x28,0x24,0x40,0x80,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 36173 0x8d4d "赍" */
+0x01,0x7f,0x09,0x09,0x15,0x7f,0x40,0x80,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x00,0xfc,0x20,0x20,0x50,0xfe,0x02,0x04,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36174 0x8d4e "赎" */
+0x00,0x7c,0x45,0x44,0x54,0x57,0x54,0x54,0x54,0x55,0x54,0x13,0x28,0x24,0x40,0x83,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x02,0x94,0x50,0x10,0x90,0xfe,0x28,0x44,0x82,0x02,
+/* 36175 0x8d4f "赏" */
+0x11,0x09,0x3f,0x20,0x4f,0x08,0x0f,0x00,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0x10,0x20,0xfc,0x04,0xe8,0x20,0xe0,0x00,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36176 0x8d50 "赐" */
+0x00,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x55,0x12,0x28,0x25,0x44,0x80,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 36177 0x8d51 "赑" */
+0x1f,0x10,0x11,0x11,0x02,0x0c,0x70,0x00,0x3e,0x22,0x2a,0x2a,0x2a,0x14,0x22,0x41,
+0xf0,0x10,0x10,0x10,0xc0,0x30,0x08,0x00,0xf8,0x88,0xa8,0xa8,0xa8,0x50,0x88,0x04,
+/* 36178 0x8d52 "赒" */
+0x00,0x7d,0x45,0x45,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x11,0x29,0x26,0x42,0x84,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 36179 0x8d53 "赓" */
+0x00,0x3f,0x20,0x2f,0x20,0x3f,0x21,0x2f,0x24,0x2f,0x34,0x24,0x44,0x41,0x82,0x0c,
+0x80,0xfe,0x80,0xf8,0x88,0xfe,0x08,0xf8,0x10,0xf8,0x16,0x90,0x90,0x60,0x10,0x08,
+/* 36180 0x8d54 "赔" */
+0x00,0x7c,0x45,0x54,0x55,0x54,0x54,0x57,0x54,0x54,0x55,0x11,0x29,0x25,0x45,0x81,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 36181 0x8d55 "赕" */
+0x00,0x7c,0x44,0x45,0x54,0x54,0x57,0x54,0x54,0x54,0x54,0x11,0x28,0x24,0x41,0x82,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 36182 0x8d56 "赖" */
+0x10,0x10,0xfe,0x11,0x12,0x7d,0x55,0x55,0x55,0x7d,0x11,0x39,0x54,0x90,0x11,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x88,0x04,0x02,
+/* 36183 0x8d57 "赗" */
+0x00,0x7d,0x45,0x45,0x55,0x55,0x55,0x54,0x54,0x54,0x54,0x10,0x28,0x24,0x40,0x80,
+0x00,0xfe,0x02,0x7a,0x02,0x7a,0x02,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 36184 0x8d58 "赘" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x46,0x9f,0x10,0x11,0x02,0x0c,0x70,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0x82,0xf0,0x10,0x10,0xc0,0x30,0x08,
+/* 36185 0x8d59 "赙" */
+0x00,0x7c,0x47,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x13,0x28,0x24,0x44,0x80,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 36186 0x8d5a "赚" */
+0x00,0x7c,0x44,0x55,0x54,0x55,0x54,0x57,0x54,0x55,0x54,0x10,0x29,0x26,0x44,0x80,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 36187 0x8d5b "赛" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x1f,0x29,0xc9,0x09,0x0a,0x04,0x18,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x28,0x26,0x20,0xa0,0x40,0x20,
+/* 36188 0x8d5c "赜" */
+0x00,0x7d,0x48,0x48,0x48,0x5d,0x54,0x55,0x55,0x5d,0x49,0x49,0x49,0x7e,0x00,0x03,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 36189 0x8d5d "赝" */
+0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x24,0x24,0x20,0x27,0x24,0x44,0x40,0x83,0x1c,
+0xfe,0x50,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x00,0xfc,0x44,0x44,0xb0,0x0c,0x02,
+/* 36190 0x8d5e "赞" */
+0x08,0x28,0x3e,0x48,0x7e,0x14,0x25,0x46,0x81,0x1f,0x10,0x11,0x11,0x02,0x0c,0x30,
+0x10,0x50,0x7c,0x90,0xfe,0x28,0x48,0x8a,0x06,0xf0,0x10,0x10,0x10,0xc0,0x30,0x08,
+/* 36191 0x8d5f "赟" */
+0x41,0x20,0xfb,0x10,0x52,0x22,0x57,0x80,0x1f,0x10,0x11,0x11,0x11,0x02,0x0c,0x70,
+0xd4,0x10,0xfe,0x90,0xc8,0x8a,0xe6,0x02,0xf0,0x10,0x10,0x10,0x10,0x60,0x18,0x04,
+/* 36192 0x8d60 "赠" */
+0x00,0x7c,0x44,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x54,0x10,0x28,0x24,0x44,0x80,
+0x88,0x48,0x50,0xfc,0x24,0xac,0x74,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,
+/* 36193 0x8d61 "赡" */
+0x00,0x7c,0x45,0x47,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x11,0x29,0x26,0x42,0x84,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 36194 0x8d62 "赢" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x77,0x54,0x75,0x55,0x75,0x52,0xb4,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0xdc,0x54,0x54,0x5c,0x56,0x96,0x62,
+/* 36195 0x8d63 "赣" */
+0x10,0xfe,0x44,0x29,0xfe,0x01,0x7c,0x44,0x7d,0x44,0x7c,0x10,0xfe,0x10,0x10,0x11,
+0x40,0x78,0xd0,0x20,0x58,0x86,0xf8,0x20,0xfc,0x00,0xf8,0x88,0xa8,0xa8,0x50,0x88,
+/* 36196 0x8d64 "赤" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0xff,0x04,0x04,0x24,0x24,0x44,0x88,0x08,0x11,0x20,
+0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x40,0x40,0x48,0x44,0x42,0x42,0x40,0x40,0x80,
+/* 36197 0x8d65 "赥" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x54,0x88,
+0x10,0x10,0x10,0x10,0x3e,0x22,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x24,0x44,0x82,
+/* 36198 0x8d66 "赦" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x54,0x88,
+0x20,0x20,0x20,0x40,0x7e,0x84,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 36199 0x8d67 "赧" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x94,0x24,0x24,0x54,0x88,
+0x00,0xfc,0x84,0x84,0x94,0x88,0x80,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0xa8,0xc4,0x82,
+/* 36200 0x8d68 "赨" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x54,0x88,
+0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x10,0x14,0x12,0x1e,0xf2,0x00,
+/* 36201 0x8d69 "赩" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x54,0x88,
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x54,0x7c,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 36202 0x8d6a "赪" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x94,0x24,0x24,0x54,0x88,
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x82,0x92,0x92,0x92,0x92,0x92,0x28,0x24,0x42,0x82,
+/* 36203 0x8d6b "赫" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x14,0x14,0x56,0x55,0x94,0x24,0x24,0x54,0x89,
+0x20,0x20,0x20,0xf8,0x20,0x20,0xfe,0x50,0x50,0xd8,0x54,0x52,0x50,0x90,0x90,0x30,
+/* 36204 0x8d6c "赬" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x94,0x24,0x24,0x54,0x89,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x48,0x84,0x02,
+/* 36205 0x8d6d "赭" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x14,0x14,0x56,0x55,0x95,0x24,0x24,0x54,0x88,
+0x20,0x24,0xf4,0x28,0x28,0xfe,0x10,0x20,0x7c,0xc4,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 36206 0x8d6e "赮" */
+0x10,0x11,0x11,0x7d,0x11,0x11,0xff,0x29,0x29,0x6d,0xab,0x29,0x29,0x49,0x49,0x99,
+0x00,0xdc,0x44,0x44,0x44,0xdc,0x00,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 36207 0x8d6f "赯" */
+0x10,0x10,0x11,0x7d,0x11,0x11,0xfd,0x29,0x29,0x6d,0xab,0x29,0x29,0x4a,0x4a,0x9c,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 36208 0x8d70 "走" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0xff,0x01,0x01,0x11,0x11,0x11,0x11,0x29,0x47,0x80,
+0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 36209 0x8d71 "赱" */
+0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,0x20,0x10,0x00,0x03,0x0c,0x13,0x20,0x40,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x10,0x20,0xc0,0x00,0x00,0x00,0xfe,0x00,
+/* 36210 0x8d72 "赲" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,0x00,0xfe,0x00,
+/* 36211 0x8d73 "赳" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x4c,0x54,0x64,0x04,0x04,0x04,0x00,0xfe,0x00,
+/* 36212 0x8d74 "赴" */
+0x04,0x04,0x04,0x3f,0x04,0x04,0x7f,0x04,0x04,0x24,0x27,0x24,0x24,0x54,0x4f,0x80,
+0x20,0x20,0x20,0x20,0x30,0x28,0xa4,0x24,0x20,0x20,0xa0,0x20,0x20,0x00,0xfe,0x00,
+/* 36213 0x8d75 "赵" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x04,0x84,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0x00,0xfe,0x00,
+/* 36214 0x8d76 "赶" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36215 0x8d77 "起" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x88,0x80,0x80,0x84,0x84,0x7c,0x00,0xfe,0x00,
+/* 36216 0x8d78 "赸" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,0x00,0xfe,0x00,
+/* 36217 0x8d79 "赹" */
+0x08,0x08,0x08,0x7e,0x09,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0x40,0xfe,0x02,0x42,0x22,0x22,0x0a,0x32,0xc2,0x02,0x14,0x08,0xfe,0x00,
+/* 36218 0x8d7a "赺" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x10,0x20,0x20,0x00,0xfe,0x00,
+/* 36219 0x8d7b "赻" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x12,0x04,0x08,0x10,0x60,0x80,0x00,0xfe,0x00,
+/* 36220 0x8d7c "赼" */
+0x04,0x04,0x04,0x3f,0x04,0x04,0x7f,0x04,0x04,0x24,0x27,0x24,0x24,0x54,0x4f,0x80,
+0x20,0x20,0x20,0x3e,0x42,0x04,0x90,0x10,0x10,0x28,0xa4,0x42,0x82,0x00,0xfe,0x00,
+/* 36221 0x8d7d "赽" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x48,0x84,0x04,0x00,0xfe,0x00,
+/* 36222 0x8d7e "赾" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x00,0x0c,0x70,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x88,0x88,0x08,0x00,0xfe,0x00,
+/* 36223 0x8d7f "赿" */
+0x10,0x10,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x4a,0x86,0x02,0x00,0xfe,
+/* 36224 0x8d80 "趀" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x16,0xf8,0x90,0x90,0xfe,0x12,0x32,0x52,0x96,0x10,0x10,0x10,0xfe,0x00,
+/* 36225 0x8d81 "趁" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0x50,0x50,0x88,0x24,0x42,0x90,0x20,0x44,0x88,0x10,0x20,0x40,0xfe,0x00,
+/* 36226 0x8d82 "趂" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x29,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x40,0x40,0x40,0xfe,0x82,0x24,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,0x00,0xfe,0x00,
+/* 36227 0x8d83 "趃" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x09,0x28,0x28,0x2e,0x28,0x29,0x58,0x4f,0x80,
+0x20,0xa0,0xa0,0xfc,0xa0,0x20,0x20,0xfe,0x20,0x50,0x48,0x84,0x04,0x00,0xfe,0x00,
+/* 36228 0x8d84 "趄" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x88,0xfe,0x00,0x00,0xfe,0x00,
+/* 36229 0x8d85 "超" */
+0x08,0x09,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfc,0x44,0x44,0x44,0x94,0x08,0xfc,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x00,
+/* 36230 0x8d86 "趆" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x1c,0xf0,0x90,0x90,0xfe,0x90,0x90,0x90,0xaa,0xca,0xa6,0x12,0x00,0xfe,0x00,
+/* 36231 0x8d87 "趇" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x10,0x10,0xfe,0x04,0x44,0x44,0x28,0x28,0x28,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 36232 0x8d88 "趈" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 36233 0x8d89 "趉" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x92,0x92,0x92,0xfe,0x10,0x92,0x92,0x92,0x92,0xfe,0x02,0x00,0xfe,0x00,
+/* 36234 0x8d8a "越" */
+0x10,0x10,0x10,0x7d,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x70,0x50,0x4f,0x80,
+0x28,0x24,0x20,0xfc,0x20,0x24,0x24,0x28,0x28,0x10,0x94,0x2c,0x44,0x00,0xfe,0x00,
+/* 36235 0x8d8b "趋" */
+0x08,0x08,0x08,0x7e,0x09,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x40,0x40,0x78,0x88,0x10,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x00,
+/* 36236 0x8d8c "趌" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 36237 0x8d8d "趍" */
+0x10,0x10,0x10,0x7c,0x13,0x10,0xfc,0x13,0x10,0x50,0x5c,0x50,0x50,0x73,0x50,0x8f,
+0x20,0x20,0x7c,0x88,0x50,0x24,0xc8,0x1e,0x22,0xe4,0x18,0x10,0x60,0x80,0x00,0xfe,
+/* 36238 0x8d8e "趎" */
+0x08,0x08,0x08,0x7e,0x09,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x10,0x50,0x50,0xfc,0x10,0x10,0xfe,0x30,0x38,0x54,0x94,0x10,0x10,0x00,0xfe,0x00,
+/* 36239 0x8d8f "趏" */
+0x08,0x08,0x08,0x7e,0x09,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 36240 0x8d90 "趐" */
+0x08,0x09,0x08,0x7e,0x09,0x08,0xfe,0x08,0x29,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xdc,0x44,0x44,0x54,0xcc,0x44,0xcc,0x54,0x44,0x44,0x54,0xc8,0x00,0xfe,0x00,
+/* 36241 0x8d91 "趑" */
+0x10,0x12,0x11,0x7d,0x10,0x10,0xfc,0x10,0x13,0x51,0x5d,0x51,0x51,0x70,0x50,0x8f,
+0x20,0x20,0x20,0x3e,0x42,0x84,0x90,0x90,0x10,0x10,0x28,0x24,0x42,0x82,0x00,0xfe,
+/* 36242 0x8d92 "趒" */
+0x08,0x08,0x08,0x7e,0x09,0x08,0xfe,0x08,0x29,0x28,0x2e,0x28,0x29,0x5a,0x4f,0x80,
+0x10,0x50,0x50,0x50,0x54,0xd8,0x50,0xd8,0x54,0x52,0x92,0x92,0x0e,0x00,0xfe,0x00,
+/* 36243 0x8d93 "趓" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfd,0x12,0x11,0x50,0x5c,0x50,0x51,0x72,0x50,0x8f,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x26,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0xfe,
+/* 36244 0x8d94 "趔" */
+0x10,0x13,0x10,0x7c,0x10,0x11,0xfd,0x11,0x12,0x50,0x5c,0x50,0x51,0x72,0x50,0x8f,
+0x02,0xf2,0x82,0x8a,0x8a,0xea,0x2a,0x2a,0xaa,0x4a,0x4a,0x82,0x0a,0x04,0x00,0xfe,
+/* 36245 0x8d95 "趕" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 36246 0x8d96 "趖" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x10,0x54,0x54,0x54,0xba,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x00,0xfe,0x00,
+/* 36247 0x8d97 "趗" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x2a,0x58,0x4f,0x80,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x20,0xa0,0xbc,0xa0,0xa0,0x60,0x3c,0x00,0xfe,0x00,
+/* 36248 0x8d98 "趘" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x29,0x29,0x5a,0x4f,0x80,
+0x00,0xfe,0x82,0xfe,0x80,0x8c,0xf0,0x9c,0xf0,0x9e,0xf0,0x12,0x0e,0x00,0xfe,0x00,
+/* 36249 0x8d99 "趙" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x92,0x54,0x10,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x82,0x8a,0x84,0x00,0xfe,0x00,
+/* 36250 0x8d9a "趚" */
+0x08,0x08,0x09,0x7e,0x08,0x09,0xff,0x09,0x29,0x28,0x2e,0x29,0x2a,0x58,0x4f,0x80,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x70,0xa8,0x24,0x22,0x20,0xfe,0x00,
+/* 36251 0x8d9b "趛" */
+0x08,0x08,0x08,0x7e,0x09,0x0a,0xfe,0x08,0x29,0x28,0x2e,0x28,0x2b,0x58,0x4f,0x80,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfc,0x20,0xa8,0x70,0xfe,0x00,0xfe,0x00,
+/* 36252 0x8d9c "趜" */
+0x08,0x08,0x09,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x29,0x28,0x58,0x4f,0x80,
+0x80,0x80,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x2a,0x04,0xfe,0x00,
+/* 36253 0x8d9d "趝" */
+0x10,0x10,0x10,0x7c,0x11,0x12,0xfd,0x10,0x10,0x50,0x5c,0x52,0x52,0x74,0x50,0x8f,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x8a,0x8a,0x78,0x00,0xfe,
+/* 36254 0x8d9e "趞" */
+0x08,0x08,0x08,0x7e,0x08,0x09,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x48,0x48,0xfc,0x48,0x48,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 36255 0x8d9f "趟" */
+0x10,0x11,0x10,0x7c,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x71,0x50,0x4f,0x80,
+0x20,0x24,0xa4,0xa8,0xfc,0x04,0x04,0x74,0x54,0x54,0x74,0x04,0x0c,0x00,0xfe,0x00,
+/* 36256 0x8da0 "趠" */
+0x10,0x10,0x10,0x7c,0x11,0x11,0xfd,0x11,0x11,0x51,0x5c,0x53,0x50,0x70,0x50,0x8f,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0xfe,
+/* 36257 0x8da1 "趡" */
+0x08,0x08,0x08,0x7e,0x09,0x0a,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0xfe,0x80,0xfe,0x00,
+/* 36258 0x8da2 "趢" */
+0x11,0x10,0x10,0x7c,0x13,0x10,0xfc,0x11,0x10,0x50,0x5c,0x53,0x50,0x70,0x50,0x8f,
+0xf8,0x08,0xf8,0x08,0xfe,0x20,0x24,0x24,0xa8,0x70,0xa8,0x24,0x24,0xa0,0x40,0xfe,
+/* 36259 0x8da3 "趣" */
+0x10,0x13,0x11,0x7d,0x11,0x11,0xfd,0x11,0x11,0x51,0x5d,0x53,0x70,0x50,0x4f,0x80,
+0x00,0xe0,0x5e,0x42,0xd2,0x4a,0x4a,0xc4,0x44,0x64,0xca,0x4a,0x52,0x40,0xfe,0x00,
+/* 36260 0x8da4 "趤" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x28,0x29,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x10,0xfe,0x82,0x00,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 36261 0x8da5 "趥" */
+0x10,0x10,0x13,0x7c,0x10,0x11,0xfd,0x11,0x11,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x88,0x50,0xfe,0x50,0x50,0xfc,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0xfe,
+/* 36262 0x8da6 "趦" */
+0x12,0x11,0x10,0x7c,0x13,0x11,0xfc,0x10,0x11,0x51,0x5d,0x51,0x51,0x71,0x50,0x8f,
+0x20,0x3e,0x42,0x94,0x10,0x28,0x46,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0xfe,
+/* 36263 0x8da7 "趧" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x28,0x29,0x5a,0x4f,0x80,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x10,0x9c,0x90,0x90,0x7e,0x00,0xfe,0x00,
+/* 36264 0x8da8 "趨" */
+0x10,0x11,0x12,0x7d,0x11,0x10,0xfd,0x10,0x11,0x52,0x5d,0x51,0x50,0x71,0x50,0x8f,
+0x80,0xfc,0x44,0x54,0xf4,0x84,0x18,0x80,0xfc,0x44,0x54,0xf4,0x84,0x18,0x00,0xfe,
+/* 36265 0x8da9 "趩" */
+0x10,0x11,0x11,0x7d,0x11,0x11,0xfc,0x10,0x11,0x50,0x5c,0x53,0x50,0x71,0x50,0x8f,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x88,0xfc,0x88,0x88,0xfe,0x88,0x04,0x00,0xfe,
+/* 36266 0x8daa "趪" */
+0x10,0x10,0x11,0x7c,0x10,0x13,0xfc,0x11,0x11,0x51,0x5d,0x51,0x50,0x70,0x51,0x8f,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0xfe,
+/* 36267 0x8dab "趫" */
+0x10,0x13,0x10,0x7b,0x10,0x11,0xfa,0x14,0x13,0x52,0x5a,0x52,0x52,0x72,0x50,0x8f,
+0x3c,0xc0,0x40,0xfe,0x90,0x08,0xf4,0x92,0xfc,0x04,0xf4,0x94,0xf4,0x0c,0x00,0xfe,
+/* 36268 0x8dac "趬" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x7c,0x10,0xfe,0x44,0xee,0x44,0xee,0x00,0xfe,0x28,0x2a,0x46,0x80,0xfe,0x00,
+/* 36269 0x8dad "趭" */
+0x10,0x10,0x11,0x7d,0x13,0x11,0xfd,0x11,0x11,0x51,0x5c,0x52,0x52,0x74,0x50,0x8f,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x00,0xa4,0x52,0x52,0x00,0xfe,
+/* 36270 0x8dae "趮" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xfe,0x08,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x7c,0x44,0x7c,0x00,0xee,0xaa,0xee,0x10,0xfe,0x38,0x54,0x92,0x10,0xfe,0x00,
+/* 36271 0x8daf "趯" */
+0x08,0x09,0x08,0x7e,0x08,0x08,0xfe,0x09,0x28,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xee,0xaa,0x66,0xaa,0x50,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xfe,0x00,
+/* 36272 0x8db0 "趰" */
+0x10,0x13,0x11,0x7a,0x17,0x13,0xfa,0x13,0x12,0x53,0x5a,0x53,0x52,0x72,0x50,0x8f,
+0x00,0xfe,0x24,0x22,0xfe,0x76,0xaa,0x76,0x22,0x76,0xaa,0x76,0x22,0x06,0x00,0xfe,
+/* 36273 0x8db1 "趱" */
+0x11,0x15,0x17,0x79,0x17,0x13,0xfd,0x19,0x13,0x52,0x5a,0x52,0x50,0x71,0x52,0x8f,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xf8,0x08,0x48,0x48,0xa0,0x10,0x08,0xfe,
+/* 36274 0x8db2 "趲" */
+0x15,0x17,0x19,0x7f,0x13,0x15,0xf9,0x13,0x12,0x53,0x5a,0x53,0x52,0x73,0x51,0x8f,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0xfe,
+/* 36275 0x8db3 "足" */
+0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x01,0x01,0x11,0x11,0x11,0x29,0x25,0x43,0x80,
+0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 36276 0x8db4 "趴" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x52,0x5e,0xe4,0x08,0x10,
+0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 36277 0x8db5 "趵" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x10,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x40,0x40,0x40,0xfc,0x84,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 36278 0x8db6 "趶" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x13,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 36279 0x8db7 "趷" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x10,0x10,0x5c,0x50,0x50,0x50,0x5d,0xe1,0x00,0x00,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 36280 0x8db8 "趸" */
+0x00,0xff,0x04,0x07,0x08,0x10,0x60,0x00,0x1f,0x10,0x1f,0x01,0x11,0x11,0x29,0x47,
+0x00,0xfe,0x00,0xf0,0x10,0xa0,0x40,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,
+/* 36281 0x8db9 "趹" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x01,0x02,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36282 0x8dba "趺" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x01,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36283 0x8dbb "趻" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x12,0x10,0x5c,0x51,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 36284 0x8dbc "趼" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x13,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x01,0x02,
+0x00,0xfe,0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,0x08,
+/* 36285 0x8dbd "趽" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x10,0x10,0x5c,0x50,0x50,0x50,0x5d,0xe1,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 36286 0x8dbe "趾" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x07,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36287 0x8dbf "趿" */
+0x00,0x7b,0x48,0x48,0x48,0x78,0x10,0x10,0x51,0x5d,0x51,0x51,0x5a,0xe2,0x04,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 36288 0x8dc0 "跀" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0x5c,0x50,0x50,0x50,0x5d,0xe1,0x02,0x04,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 36289 0x8dc1 "跁" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x00,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 36290 0x8dc2 "跂" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x01,0x06,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 36291 0x8dc3 "跃" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x13,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x01,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36292 0x8dc4 "跄" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x12,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0xf8,0x88,0x88,0xa8,0x90,0x82,0x82,0x7e,0x00,
+/* 36293 0x8dc5 "跅" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0x00,0xfe,0x10,0x10,0x30,0x18,0x14,0x12,0x10,0x10,0x10,
+/* 36294 0x8dc6 "跆" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x13,0x10,0x10,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 36295 0x8dc7 "跇" */
+0x00,0x7d,0x45,0x45,0x45,0x7f,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x00,
+0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x78,0x00,0x00,0x00,0xfe,0x00,
+/* 36296 0x8dc8 "跈" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x10,0x10,0x11,0x5c,0x50,0x50,0x51,0x5c,0xe0,0x03,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 36297 0x8dc9 "跉" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x12,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 36298 0x8dca "跊" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x13,0x5c,0x50,0x50,0x51,0x5d,0xe2,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 36299 0x8dcb "跋" */
+0x00,0x7c,0x44,0x44,0x47,0x7c,0x10,0x10,0x5d,0x51,0x51,0x51,0x5e,0xe2,0x04,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 36300 0x8dcc "跌" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x12,0x10,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe1,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36301 0x8dcd "跍" */
+0x00,0x7c,0x44,0x44,0x47,0x7c,0x10,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 36302 0x8dce "跎" */
+0x00,0x7c,0x44,0x45,0x45,0x7e,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 36303 0x8dcf "跏" */
+0x01,0x79,0x49,0x49,0x4b,0x79,0x11,0x11,0x51,0x5d,0x51,0x51,0x59,0xe2,0x03,0x04,
+0x00,0x00,0x00,0x1c,0xd4,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x54,0x80,
+/* 36304 0x8dd0 "跐" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe3,0x01,0x00,
+0x48,0x48,0x48,0x48,0x4a,0x6c,0x48,0x48,0x48,0x48,0x48,0x4a,0x6a,0x8a,0x06,0x00,
+/* 36305 0x8dd1 "跑" */
+0x00,0x7c,0x45,0x45,0x46,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x00,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 36306 0x8dd2 "跒" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x50,0x5c,0xe0,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 36307 0x8dd3 "跓" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x03,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36308 0x8dd4 "跔" */
+0x00,0x7c,0x45,0x45,0x46,0x7c,0x11,0x11,0x5d,0x51,0x51,0x51,0x5c,0xe0,0x00,0x00,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 36309 0x8dd5 "跕" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 36310 0x8dd6 "跖" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x10,0x10,0x10,0x5d,0x52,0x50,0x50,0x5c,0xe0,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36311 0x8dd7 "跗" */
+0x00,0x78,0x48,0x49,0x49,0x7b,0x15,0x11,0x51,0x5d,0x51,0x51,0x59,0xe1,0x01,0x01,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 36312 0x8dd8 "跘" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x11,0x10,0x5c,0x50,0x53,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 36313 0x8dd9 "跙" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x07,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 36314 0x8dda "跚" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x13,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0xd4,0x24,0x4c,
+/* 36315 0x8ddb "跛" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 36316 0x8ddc "跜" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 36317 0x8ddd "距" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 36318 0x8dde "跞" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5c,0x50,0x50,0x50,0x5d,0xe2,0x00,0x00,
+0x08,0x1c,0xe0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 36319 0x8ddf "跟" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 36320 0x8de0 "跠" */
+0x00,0x7c,0x47,0x44,0x45,0x7c,0x11,0x11,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe1,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 36321 0x8de1 "跡" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x10,0x12,0x5e,0x52,0x54,0x50,0x5d,0xe1,0x02,0x04,
+0x40,0x20,0x20,0xfe,0x90,0x90,0x90,0x94,0x92,0x92,0x92,0x90,0x10,0x10,0x50,0x20,
+/* 36322 0x8de2 "跢" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x10,0x5d,0x50,0x50,0x51,0x5c,0xe0,0x00,0x01,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 36323 0x8de3 "跣" */
+0x00,0x79,0x49,0x49,0x49,0x7a,0x10,0x13,0x50,0x5c,0x50,0x50,0x59,0xe1,0x02,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 36324 0x8de4 "跤" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x11,0x12,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 36325 0x8de5 "跥" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x11,0x5c,0x53,0x50,0x50,0x5c,0xe1,0x02,0x00,
+0x00,0xfc,0x44,0x48,0x5e,0x82,0x8a,0x24,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 36326 0x8de6 "跦" */
+0x00,0x7d,0x45,0x45,0x45,0x7e,0x10,0x13,0x5c,0x50,0x50,0x51,0x5d,0xe2,0x00,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 36327 0x8de7 "跧" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x11,0x10,0x5c,0x50,0x51,0x50,0x5c,0xe0,0x03,0x00,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 36328 0x8de8 "跨" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x16,0x10,0x53,0x5c,0x50,0x51,0x58,0xe0,0x00,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 36329 0x8de9 "跩" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x03,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x24,0x18,0x32,0xca,0x06,0x02,
+/* 36330 0x8dea "跪" */
+0x00,0x7c,0x44,0x45,0x46,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 36331 0x8deb "跫" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x44,0x1f,0x10,0x1f,0x01,0x11,0x11,0x29,0x47,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,
+/* 36332 0x8dec "跬" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x13,0x10,0x5c,0x50,0x51,0x50,0x5c,0xe0,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 36333 0x8ded "跭" */
+0x00,0x78,0x48,0x49,0x4a,0x78,0x11,0x16,0x10,0x5d,0x50,0x52,0x53,0x5c,0xe0,0x00,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 36334 0x8dee "跮" */
+0x00,0x7d,0x44,0x44,0x44,0x7d,0x11,0x10,0x5c,0x50,0x51,0x50,0x5c,0xe0,0x03,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 36335 0x8def "路" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x10,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 36336 0x8df0 "跰" */
+0x01,0x7c,0x44,0x44,0x45,0x7c,0x10,0x10,0x5c,0x53,0x50,0x50,0x5d,0xe1,0x02,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 36337 0x8df1 "跱" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x13,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0xfe,0x08,0x08,0xfe,0x08,0x88,0x48,0x08,0x28,0x10,
+/* 36338 0x8df2 "跲" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x11,0x10,0x10,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 36339 0x8df3 "跳" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe1,0x02,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 36340 0x8df4 "跴" */
+0x00,0x7b,0x48,0x48,0x48,0x79,0x11,0x11,0x1d,0x51,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x00,0xfe,0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0x5c,0x84,0x04,0x04,0xfc,0x04,
+/* 36341 0x8df5 "践" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x10,0x11,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x03,0x00,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 36342 0x8df6 "跶" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x13,0x11,0x51,0x5d,0x51,0x51,0x59,0xe2,0x04,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x28,0x24,0x44,0x42,0x82,0x00,0x80,0x7e,0x00,
+/* 36343 0x8df7 "跷" */
+0x00,0x7c,0x44,0x47,0x44,0x7c,0x10,0x13,0x5c,0x53,0x50,0x50,0x5d,0xe1,0x02,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 36344 0x8df8 "跸" */
+0x01,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5c,0x53,0x50,0x50,0x5c,0xe0,0x00,
+0x10,0x12,0x14,0xd8,0x10,0x12,0x52,0x8e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 36345 0x8df9 "跹" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x10,0x17,0x51,0x5d,0x51,0x51,0x59,0xe2,0x04,0x00,
+0x00,0x0c,0x70,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x80,0x7e,0x00,
+/* 36346 0x8dfa "跺" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x11,0x12,0x5d,0x50,0x50,0x50,0x5d,0xe2,0x00,0x00,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x26,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36347 0x8dfb "跻" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x10,0x10,0x11,0x5c,0x50,0x50,0x50,0x5d,0xe1,0x02,
+0x40,0x20,0xfe,0x88,0x50,0x20,0x50,0x88,0x06,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 36348 0x8dfc "跼" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5e,0xe2,0x04,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 36349 0x8dfd "跽" */
+0x00,0x7d,0x44,0x44,0x45,0x7d,0x11,0x11,0x5c,0x50,0x50,0x50,0x5e,0xe2,0x04,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x04,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 36350 0x8dfe "跾" */
+0x10,0x10,0x24,0x64,0xa5,0x24,0x24,0x20,0x1f,0x10,0x1f,0x01,0x11,0x11,0x29,0x47,
+0x40,0x40,0xfe,0x88,0x50,0x20,0x50,0x88,0xf4,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,
+/* 36351 0x8dff "跿" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x13,0x10,0x5c,0x51,0x51,0x51,0x5e,0xe2,0x04,0x08,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 36352 0x8e00 "踀" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x10,0x10,0x5d,0x51,0x51,0x51,0x5e,0xe2,0x04,0x08,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3c,0x20,0x20,0xa0,0x60,0x3e,0x00,
+/* 36353 0x8e01 "踁" */
+0x00,0x7d,0x44,0x44,0x45,0x7e,0x11,0x10,0x10,0x5d,0x50,0x50,0x50,0x5c,0xe3,0x00,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36354 0x8e02 "踂" */
+0x00,0x7b,0x49,0x49,0x49,0x79,0x11,0x11,0x51,0x5d,0x51,0x51,0x59,0xe3,0x00,0x00,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 36355 0x8e03 "踃" */
+0x00,0x7d,0x44,0x44,0x44,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 36356 0x8e04 "踄" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x13,0x10,0x5c,0x50,0x50,0x51,0x5e,0xe0,0x00,0x03,
+0x10,0x10,0x90,0x9e,0x90,0x90,0xfe,0x00,0x10,0x92,0x92,0x14,0x08,0x10,0x60,0x80,
+/* 36357 0x8e05 "踅" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x12,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0x08,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36358 0x8e06 "踆" */
+0x00,0x7c,0x44,0x45,0x47,0x7c,0x10,0x11,0x12,0x5c,0x51,0x52,0x50,0x5c,0xe1,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 36359 0x8e07 "踇" */
+0x00,0x7c,0x44,0x45,0x46,0x7c,0x10,0x10,0x5d,0x50,0x51,0x51,0x5d,0xe0,0x00,0x00,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 36360 0x8e08 "踈" */
+0x00,0x7c,0x47,0x44,0x44,0x7d,0x11,0x11,0x5d,0x50,0x50,0x50,0x5d,0xe2,0x00,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36361 0x8e09 "踉" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 36362 0x8e0a "踊" */
+0x00,0x7d,0x44,0x44,0x44,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 36363 0x8e0b "踋" */
+0x01,0xf1,0x91,0x93,0x91,0xf1,0x21,0x27,0xa1,0xb9,0xa2,0xa2,0xa7,0xb2,0xc0,0x00,
+0x00,0x00,0x1e,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0x1a,0x94,0xd0,0x50,0x10,0x10,
+/* 36364 0x8e0c "踌" */
+0x00,0x7c,0x47,0x44,0x45,0x7c,0x13,0x10,0x5c,0x50,0x51,0x51,0x5e,0xe4,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 36365 0x8e0d "踍" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x10,0x10,0x11,0x5c,0x51,0x52,0x54,0x5c,0xe0,0x00,
+0x20,0x22,0xfa,0x24,0x24,0xfe,0x10,0x20,0xfc,0x88,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 36366 0x8e0e "踎" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x11,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36367 0x8e0f "踏" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x12,0x10,0x51,0x5d,0x51,0x51,0x59,0xe1,0x01,0x01,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 36368 0x8e10 "踐" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x11,0x10,0x5c,0x51,0x50,0x50,0x5c,0xe0,0x01,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 36369 0x8e11 "踑" */
+0x00,0x7c,0x47,0x44,0x44,0x7c,0x10,0x10,0x5c,0x50,0x50,0x53,0x5c,0xe0,0x01,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 36370 0x8e12 "踒" */
+0x00,0x7d,0x44,0x44,0x47,0x7c,0x11,0x12,0x5c,0x53,0x50,0x51,0x5c,0xe0,0x00,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 36371 0x8e13 "踓" */
+0x00,0x7c,0x44,0x45,0x45,0x7d,0x13,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0xa0,0x90,0x90,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,
+/* 36372 0x8e14 "踔" */
+0x00,0x7c,0x44,0x44,0x45,0x7d,0x11,0x11,0x5d,0x51,0x50,0x53,0x5c,0xe0,0x00,0x00,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 36373 0x8e15 "踕" */
+0x00,0x7c,0x47,0x44,0x45,0x7c,0x13,0x10,0x5d,0x50,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0x3e,0x20,0xa0,0x7e,0x00,
+/* 36374 0x8e16 "踖" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x11,0x10,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 36375 0x8e17 "踗" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x11,0x10,0x5c,0x50,0x50,0x52,0x5e,0xe2,0x04,0x00,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 36376 0x8e18 "踘" */
+0x01,0x7d,0x45,0x46,0x44,0x7d,0x10,0x10,0x13,0x5c,0x50,0x51,0x52,0x5c,0xe0,0x00,
+0x00,0x00,0xfc,0x04,0x44,0x54,0xe4,0x44,0xfc,0x44,0xe4,0x54,0x44,0x44,0x14,0x08,
+/* 36377 0x8e19 "踙" */
+0x00,0x7b,0x49,0x49,0x49,0x79,0x11,0x11,0x51,0x5d,0x51,0x53,0x58,0xe0,0x00,0x00,
+0x00,0xe0,0x5c,0x54,0xd4,0x54,0x54,0xd4,0x54,0x54,0x68,0xc8,0x48,0x54,0x54,0x62,
+/* 36378 0x8e1a "踚" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x10,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 36379 0x8e1b "踛" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x10,0x11,0x5e,0x50,0x51,0x50,0x5c,0xe0,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 36380 0x8e1c "踜" */
+0x00,0x78,0x49,0x48,0x48,0x7b,0x10,0x11,0x12,0x5c,0x51,0x52,0x50,0x5c,0xe1,0x06,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 36381 0x8e1d "踝" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x10,0x5d,0x50,0x50,0x51,0x5e,0xe0,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36382 0x8e1e "踞" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x00,0xfe,0x02,0x02,0xfe,0x10,0x10,0xfe,0x10,0x10,0x7e,0x42,0x42,0x42,0x7e,0x42,
+/* 36383 0x8e1f "踟" */
+0x01,0x79,0x49,0x4b,0x4a,0x7c,0x10,0x10,0x53,0x5c,0x50,0x51,0x59,0xe2,0x04,0x08,
+0x00,0x00,0x00,0xde,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x52,0x5e,0x20,0x20,0x00,
+/* 36384 0x8e20 "踠" */
+0x00,0x78,0x4b,0x4a,0x4d,0x79,0x11,0x12,0x1e,0x53,0x54,0x50,0x51,0x5d,0xe2,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 36385 0x8e21 "踡" */
+0x00,0x7d,0x44,0x44,0x45,0x7c,0x13,0x10,0x5d,0x52,0x54,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 36386 0x8e22 "踢" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x10,0x5c,0x50,0x51,0x52,0x5c,0xe1,0x00,0x00,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 36387 0x8e23 "踣" */
+0x00,0x7c,0x45,0x44,0x45,0x7c,0x10,0x13,0x10,0x5c,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 36388 0x8e24 "踤" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x11,0x12,0x10,0x5c,0x53,0x50,0x50,0x5c,0xe0,0x00,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 36389 0x8e25 "踥" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x13,0x10,0x5c,0x53,0x50,0x51,0x5c,0xe0,0x00,0x03,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x40,0x40,0xfe,0x88,0x88,0x50,0x30,0xc8,0x04,
+/* 36390 0x8e26 "踦" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x13,0x10,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x00,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 36391 0x8e27 "踧" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x13,0x10,0x10,0x5c,0x51,0x52,0x50,0x5c,0xe0,0x01,
+0x80,0x80,0x9c,0xf4,0x94,0x94,0xf4,0x14,0x94,0x94,0xc8,0xa8,0x88,0x94,0x94,0xa2,
+/* 36392 0x8e28 "踨" */
+0x00,0x78,0x48,0x48,0x49,0x7a,0x14,0x10,0x50,0x5d,0x51,0x51,0x5a,0xe2,0x04,0x08,
+0x88,0x88,0x88,0x88,0x54,0x22,0x42,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 36393 0x8e29 "踩" */
+0x00,0x7c,0x45,0x44,0x45,0x7c,0x10,0x10,0x5d,0x50,0x50,0x50,0x5d,0xe2,0x04,0x00,
+0x08,0x3c,0xc0,0x44,0x24,0xa8,0x80,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 36394 0x8e2a "踪" */
+0x00,0x78,0x4b,0x4a,0x4c,0x79,0x10,0x10,0x53,0x5c,0x51,0x51,0x5a,0xe4,0x00,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 36395 0x8e2b "踫" */
+0x01,0x7c,0x44,0x45,0x44,0x7c,0x10,0x12,0x11,0x5d,0x50,0x50,0x50,0x5c,0xe3,0x00,
+0x08,0x90,0x00,0xfc,0x90,0x90,0x92,0x92,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 36396 0x8e2c "踬" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x1c,0xe0,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x54,0x54,0x54,0x54,0x28,0x44,0x82,
+/* 36397 0x8e2d "踭" */
+0x00,0x7c,0x44,0x45,0x46,0x7d,0x10,0x10,0x5d,0x50,0x50,0x51,0x5c,0xe0,0x00,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 36398 0x8e2e "踮" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x20,0x10,0xfe,0x00,0x20,0x20,0x3c,0x20,0x20,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 36399 0x8e2f "踯" */
+0x04,0xf2,0x92,0x90,0x97,0xf1,0x21,0x21,0xa7,0xb9,0xa1,0xa1,0xba,0xe2,0x04,0x08,
+0x40,0x5e,0x92,0x12,0xd4,0x14,0x18,0x14,0xf2,0x12,0x12,0x1a,0x94,0x50,0x50,0x10,
+/* 36400 0x8e30 "踰" */
+0x00,0x7c,0x44,0x45,0x46,0x7c,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xe2,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x2a,0x64,
+/* 36401 0x8e31 "踱" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x40,0x20,0xfe,0x48,0x48,0xfe,0x48,0x78,0x00,0xfc,0x44,0x48,0x28,0x10,0x28,0xc6,
+/* 36402 0x8e32 "踲" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x02,0x04,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 36403 0x8e33 "踳" */
+0x00,0x7c,0x47,0x44,0x45,0x7c,0x13,0x10,0x5d,0x52,0x50,0x50,0x5c,0xe0,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 36404 0x8e34 "踴" */
+0x00,0x7d,0x44,0x44,0x45,0x7d,0x11,0x11,0x5d,0x51,0x50,0x51,0x5c,0xe0,0x01,0x02,
+0x00,0xfc,0x48,0x30,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x40,0xfc,0x44,0x84,0x14,0x08,
+/* 36405 0x8e35 "踵" */
+0x00,0x7c,0x45,0x44,0x47,0x7c,0x11,0x11,0x5d,0x51,0x51,0x50,0x5d,0xe0,0x03,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 36406 0x8e36 "踶" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x11,0x5c,0x53,0x50,0x51,0x5d,0xe1,0x02,0x04,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 36407 0x8e37 "踷" */
+0x00,0x7c,0x45,0x44,0x44,0x7f,0x10,0x10,0x10,0x5d,0x52,0x50,0x50,0x5c,0xe0,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 36408 0x8e38 "踸" */
+0x00,0x7c,0x47,0x44,0x44,0x7c,0x10,0x10,0x5c,0x53,0x51,0x51,0x5d,0xe1,0x01,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 36409 0x8e39 "踹" */
+0x00,0x7d,0x45,0x45,0x45,0x7c,0x13,0x10,0x5c,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 36410 0x8e3a "踺" */
+0x00,0x78,0x4f,0x49,0x49,0x7a,0x12,0x17,0x51,0x5d,0x55,0x52,0x5a,0xe5,0x08,0x00,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 36411 0x8e3b "踻" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x00,0xfc,0x84,0x84,0xf4,0x94,0x94,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 36412 0x8e3c "踼" */
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x10,0x11,0x5c,0x50,0x51,0x52,0x5c,0xe1,0x00,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 36413 0x8e3d "踽" */
+0x00,0x7c,0x47,0x44,0x45,0x7d,0x11,0x11,0x5c,0x53,0x52,0x52,0x5e,0xe2,0x02,0x02,
+0x04,0x1e,0xe0,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x22,0x2a,0xfa,0x02,0x0a,0x04,
+/* 36414 0x8e3e "踾" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x00,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 36415 0x8e3f "踿" */
+0x00,0x78,0x4b,0x49,0x49,0x79,0x13,0x11,0x1d,0x53,0x55,0x51,0x51,0x5d,0xe1,0x01,
+0x08,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 36416 0x8e40 "蹀" */
+0x00,0x7d,0x45,0x47,0x45,0x7d,0x11,0x11,0x5d,0x50,0x53,0x50,0x5c,0xe1,0x06,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36417 0x8e41 "蹁" */
+0x00,0x7c,0x45,0x45,0x45,0x7d,0x11,0x11,0x5d,0x51,0x51,0x52,0x5e,0xe2,0x04,0x00,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 36418 0x8e42 "蹂" */
+0x00,0x7d,0x44,0x44,0x47,0x7c,0x10,0x11,0x5e,0x50,0x53,0x50,0x5c,0xe1,0x06,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36419 0x8e43 "蹃" */
+0x00,0x7c,0x47,0x44,0x44,0x7c,0x13,0x10,0x10,0x5c,0x51,0x52,0x50,0x5c,0xe0,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36420 0x8e44 "蹄" */
+0x00,0x7c,0x45,0x44,0x44,0x7c,0x13,0x12,0x5c,0x51,0x51,0x51,0x5d,0xe1,0x00,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 36421 0x8e45 "蹅" */
+0x00,0x7c,0x47,0x44,0x44,0x7d,0x12,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x03,0x00,
+0x20,0x20,0xfe,0x70,0xa8,0x24,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 36422 0x8e46 "蹆" */
+0x00,0x7a,0x49,0x49,0x48,0x78,0x17,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x04,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x50,0x4a,0x44,0x54,0x62,0x42,0x80,0x7e,
+/* 36423 0x8e47 "蹇" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x1f,0x28,0xcf,0x01,0x09,0x15,0x23,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x28,0xe6,0x00,0xf0,0x00,0xfc,
+/* 36424 0x8e48 "蹈" */
+0x00,0x7d,0x44,0x45,0x44,0x7c,0x10,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 36425 0x8e49 "蹉" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x10,0x11,0x5c,0x50,0x50,0x51,0x5e,0xe4,0x01,0x00,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 36426 0x8e4a "蹊" */
+0x00,0x7b,0x49,0x48,0x48,0x78,0x11,0x10,0x50,0x5d,0x50,0x50,0x5b,0xe0,0x00,0x03,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 36427 0x8e4b "蹋" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x10,0x10,0x13,0x5c,0x52,0x51,0x52,0x5c,0xe1,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 36428 0x8e4c "蹌" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x12,0x10,0x5c,0x50,0x50,0x50,0x5d,0xe1,0x02,0x00,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 36429 0x8e4d "蹍" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x12,0x12,0x12,0x5e,0x53,0x52,0x52,0x5c,0xe4,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x48,0x48,0xfc,0x48,0x48,0xfe,0xa4,0xa8,0x90,0xc8,0x86,
+/* 36430 0x8e4e "蹎" */
+0x00,0x7c,0x47,0x44,0x45,0x7d,0x11,0x11,0x11,0x5d,0x51,0x51,0x53,0x5c,0xe1,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 36431 0x8e4f "蹏" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7a,0x12,0x12,0x52,0x5e,0x52,0x52,0x5a,0xe4,0x05,0x0a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 36432 0x8e50 "蹐" */
+0x00,0x7d,0x44,0x45,0x44,0x7d,0x12,0x14,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe0,0x00,
+0x20,0x24,0xa8,0x54,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x98,
+/* 36433 0x8e51 "蹑" */
+0x00,0x7d,0x44,0x44,0x44,0x7c,0x10,0x13,0x5c,0x53,0x50,0x51,0x5c,0xe1,0x02,0x04,
+0x00,0xfe,0x84,0xfc,0x84,0xfc,0x86,0xfc,0x04,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 36434 0x8e52 "蹒" */
+0x00,0x7c,0x45,0x44,0x44,0x7d,0x10,0x10,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x48,0x48,0xfe,0x48,0x00,0xfe,0x48,0x48,0xfe,0x4a,0x4a,0xb6,0x22,0x02,0x0a,0x04,
+/* 36435 0x8e53 "蹓" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x11,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x40,0xbc,0x14,0x94,0x54,0xa4,0x4c,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 36436 0x8e54 "蹔" */
+0x08,0x7f,0x08,0x3e,0x2a,0x3e,0x2a,0xff,0x08,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36437 0x8e55 "蹕" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x10,0x10,0x5d,0x50,0x50,0x51,0x5c,0xe3,0x00,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 36438 0x8e56 "蹖" */
+0x00,0x7c,0x47,0x44,0x45,0x7c,0x13,0x10,0x5d,0x52,0x55,0x51,0x5d,0xe1,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0x42,0x9c,0x04,0xdc,0x04,0xfc,0x04,
+/* 36439 0x8e57 "蹗" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7b,0x12,0x12,0x53,0x5e,0x52,0x52,0x5a,0xe4,0x04,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 36440 0x8e58 "蹘" */
+0x00,0x7b,0x48,0x4a,0x49,0x7a,0x10,0x10,0x53,0x5c,0x51,0x50,0x59,0xe0,0x00,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 36441 0x8e59 "蹙" */
+0x00,0x3f,0x22,0x23,0x22,0x3f,0x2b,0x52,0x46,0x9f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x24,0xfe,0x20,0xa4,0x24,0xa8,0x10,0x9a,0x26,0xf2,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36442 0x8e5a "蹚" */
+0x00,0x79,0x48,0x4b,0x4a,0x78,0x10,0x10,0x1c,0x50,0x50,0x51,0x50,0x5c,0xe3,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 36443 0x8e5b "蹛" */
+0x02,0xf2,0x97,0x92,0x92,0xf4,0x28,0x27,0xa4,0xb8,0xa3,0xa2,0xa2,0xb2,0xc2,0x00,
+0xa8,0xa8,0xfc,0xa8,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x48,0x58,0x40,
+/* 36444 0x8e5c "蹜" */
+0x00,0x78,0x4b,0x4a,0x48,0x78,0x11,0x13,0x1d,0x51,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x20,0x10,0xfe,0x02,0x80,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 36445 0x8e5d "蹝" */
+0x01,0x79,0x4a,0x4c,0x48,0x79,0x13,0x15,0x1d,0x51,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x08,0x08,0x28,0xae,0xa8,0x28,0x7e,0x00,0x08,0x28,0x2e,0x28,0x58,0x48,0x86,0x00,
+/* 36446 0x8e5e "蹞" */
+0x00,0x78,0x48,0x4a,0x4a,0x7a,0x13,0x12,0x52,0x5e,0x52,0x53,0x5a,0xe0,0x00,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0xc4,0x7c,0x44,0x7c,0xc4,0x44,0x7c,0x28,0x44,0x82,
+/* 36447 0x8e5f "蹟" */
+0x00,0x7b,0x48,0x49,0x48,0x7b,0x10,0x11,0x1d,0x51,0x51,0x51,0x51,0x5d,0xe0,0x01,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 36448 0x8e60 "蹠" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7a,0x13,0x12,0x52,0x5e,0x52,0x52,0x5d,0xe5,0x0a,0x10,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x54,0x2a,0x2a,0x00,
+/* 36449 0x8e61 "蹡" */
+0x00,0x7d,0x45,0x45,0x45,0x7d,0x10,0x10,0x13,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x04,
+0x48,0x48,0x5e,0x6a,0x54,0xc8,0x50,0x64,0xc4,0x7e,0x44,0x64,0x54,0x44,0x54,0x48,
+/* 36450 0x8e62 "蹢" */
+0x00,0x78,0x4b,0x48,0x48,0x7b,0x12,0x12,0x52,0x5e,0x52,0x52,0x5a,0xe2,0x02,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 36451 0x8e63 "蹣" */
+0x00,0x7c,0x47,0x44,0x44,0x7c,0x10,0x13,0x5e,0x53,0x52,0x53,0x5e,0xe2,0x02,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 36452 0x8e64 "蹤" */
+0x01,0x79,0x4a,0x4c,0x49,0x79,0x13,0x15,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x24,0x24,0x24,0xa4,0x54,0x4a,0x92,0x08,0x08,0x28,0x2e,0x28,0x28,0x58,0x4e,0x80,
+/* 36453 0x8e65 "蹥" */
+0x00,0x7c,0x46,0x45,0x45,0x7c,0x10,0x13,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x04,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 36454 0x8e66 "蹦" */
+0x00,0x7a,0x4a,0x4b,0x48,0x7b,0x12,0x12,0x53,0x5e,0x52,0x53,0x5a,0xe2,0x05,0x08,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 36455 0x8e67 "蹧" */
+0x00,0x78,0x4f,0x48,0x4b,0x7a,0x13,0x12,0x53,0x5c,0x51,0x51,0x59,0xe1,0x01,0x01,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 36456 0x8e68 "蹨" */
+0x01,0x79,0x49,0x4a,0x4a,0x7d,0x10,0x12,0x51,0x5d,0x52,0x54,0x58,0xe2,0x02,0x04,
+0x10,0x14,0xd2,0x50,0x7e,0x50,0x90,0xa8,0x28,0x44,0x44,0x82,0x08,0xa4,0x52,0x52,
+/* 36457 0x8e69 "蹩" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x1f,0x10,0x1f,0x01,0x11,0x11,0x29,0x47,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0xf0,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfe,
+/* 36458 0x8e6a "蹪" */
+0x00,0x79,0x49,0x49,0x48,0x7b,0x10,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe0,0x01,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 36459 0x8e6b "蹫" */
+0x00,0x79,0x48,0x48,0x4b,0x78,0x10,0x13,0x1c,0x53,0x52,0x52,0x53,0x5e,0xe2,0x02,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0xfe,0x52,0x8a,0x76,0x52,0x72,0x06,
+/* 36460 0x8e6c "蹬" */
+0x00,0x7b,0x48,0x49,0x48,0x79,0x12,0x14,0x51,0x5d,0x51,0x51,0x59,0xe0,0x07,0x00,
+0x10,0xd2,0x54,0x48,0x8a,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 36461 0x8e6d "蹭" */
+0x01,0x78,0x48,0x4b,0x4a,0x7a,0x12,0x12,0x53,0x5c,0x51,0x51,0x59,0xe1,0x01,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 36462 0x8e6e "蹮" */
+0x00,0x7d,0x44,0x45,0x45,0x7d,0x10,0x13,0x5c,0x50,0x51,0x52,0x5c,0xe0,0x00,0x00,
+0x00,0xfc,0x50,0xfc,0x54,0xfc,0x20,0xfe,0x48,0x84,0xfa,0x88,0xf8,0x84,0x84,0x7c,
+/* 36463 0x8e6f "蹯" */
+0x00,0x7d,0x45,0x44,0x45,0x7c,0x11,0x12,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,0x01,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 36464 0x8e70 "蹰" */
+0x00,0x7b,0x4a,0x4a,0x4b,0x7a,0x12,0x12,0x52,0x5e,0x52,0x52,0x5a,0xe2,0x05,0x00,
+0x00,0xfe,0x00,0x04,0xf4,0x04,0xee,0xa4,0xa4,0xec,0x04,0xa4,0x44,0x74,0x94,0x08,
+/* 36465 0x8e71 "蹱" */
+0x00,0x7d,0x44,0x44,0x47,0x7c,0x11,0x11,0x5d,0x51,0x51,0x50,0x5d,0xe0,0x03,0x00,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 36466 0x8e72 "蹲" */
+0x00,0x78,0x4b,0x48,0x49,0x79,0x11,0x11,0x51,0x5d,0x50,0x53,0x59,0xe0,0x00,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 36467 0x8e73 "蹳" */
+0x00,0x7b,0x48,0x4d,0x4a,0x7c,0x13,0x10,0x1c,0x53,0x52,0x53,0x50,0x5c,0xe2,0x01,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 36468 0x8e74 "蹴" */
+0x02,0xf1,0x9f,0x90,0x90,0xf7,0x24,0x24,0xa7,0xb9,0xa5,0xa5,0xa9,0xb1,0xc5,0x02,
+0x14,0x12,0xd2,0x10,0x7e,0x90,0x90,0x90,0x90,0x28,0xa8,0x68,0x28,0x4a,0x4a,0x86,
+/* 36469 0x8e75 "蹵" */
+0x08,0x7f,0x00,0x3e,0x22,0x3e,0x49,0x98,0x00,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x28,0x24,0xfe,0x20,0x50,0x50,0x52,0x8e,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36470 0x8e76 "蹶" */
+0x00,0xf7,0x94,0x96,0x95,0xf7,0x24,0x24,0xa6,0xbe,0xa7,0xa4,0xbc,0xe5,0x09,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 36471 0x8e77 "蹷" */
+0x3f,0x28,0x25,0x3f,0x22,0x2a,0x2f,0x22,0x24,0x2b,0x22,0x23,0x20,0x42,0x45,0x88,
+0xfe,0x90,0x10,0xde,0x22,0x88,0x88,0x94,0x22,0xf8,0x08,0xf8,0x40,0x7c,0x40,0xfe,
+/* 36472 0x8e78 "蹸" */
+0x00,0x79,0x48,0x4b,0x48,0x79,0x12,0x11,0x11,0x5d,0x52,0x55,0x50,0x5d,0xe2,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 36473 0x8e79 "蹹" */
+0x00,0x7c,0x44,0x45,0x46,0x7c,0x10,0x10,0x10,0x5d,0x50,0x51,0x50,0x5d,0xe0,0x00,
+0x20,0x50,0x88,0x74,0x02,0xf8,0x88,0xf8,0x00,0xdc,0x44,0x54,0xcc,0x54,0x44,0xcc,
+/* 36474 0x8e7a "蹺" */
+0x00,0x78,0x49,0x48,0x4b,0x79,0x13,0x11,0x1d,0x56,0x50,0x53,0x50,0x5c,0xe1,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 36475 0x8e7b "蹻" */
+0x00,0x7d,0x44,0x47,0x44,0x7d,0x12,0x10,0x10,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 36476 0x8e7c "蹼" */
+0x00,0x7a,0x49,0x48,0x4b,0x78,0x10,0x13,0x50,0x5d,0x50,0x53,0x58,0xe0,0x01,0x06,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 36477 0x8e7d "蹽" */
+0x00,0x7c,0x45,0x44,0x45,0x7c,0x11,0x12,0x10,0x5c,0x50,0x50,0x50,0x5c,0xe1,0x00,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 36478 0x8e7e "蹾" */
+0x01,0x78,0x4b,0x48,0x4b,0x7a,0x13,0x10,0x13,0x5c,0x50,0x50,0x53,0x5c,0xe2,0x01,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 36479 0x8e7f "蹿" */
+0x00,0x78,0x4b,0x4a,0x49,0x7a,0x11,0x11,0x51,0x5c,0x53,0x52,0x5b,0xe2,0x00,0x00,
+0x40,0x20,0xfe,0x8a,0x24,0x22,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x22,0x20,0x20,
+/* 36480 0x8e80 "躀" */
+0x00,0x7d,0x45,0x47,0x45,0x7d,0x10,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x00,0x01,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 36481 0x8e81 "躁" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x11,0x11,0x5d,0x50,0x53,0x50,0x5c,0xe1,0x02,0x00,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36482 0x8e82 "躂" */
+0x00,0x7a,0x49,0x48,0x48,0x78,0x13,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe2,0x04,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 36483 0x8e83 "躃" */
+0x00,0x78,0x4b,0x4a,0x4a,0x7a,0x13,0x12,0x52,0x5f,0x53,0x55,0x5d,0xe5,0x09,0x00,
+0x10,0x08,0xc8,0x7e,0x40,0x54,0xc8,0x7e,0x08,0xc8,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 36484 0x8e84 "躄" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x00,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36485 0x8e85 "躅" */
+0x00,0x7d,0x45,0x45,0x45,0x7c,0x11,0x12,0x11,0x5d,0x51,0x51,0x50,0x5d,0xe0,0x00,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 36486 0x8e86 "躆" */
+0x00,0x78,0x48,0x4b,0x4a,0x7a,0x13,0x12,0x1e,0x53,0x52,0x53,0x52,0x5d,0xe4,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 36487 0x8e87 "躇" */
+0x00,0x78,0x4b,0x48,0x48,0x79,0x10,0x10,0x53,0x5c,0x50,0x51,0x5a,0xe4,0x00,0x00,
+0x88,0x88,0xfe,0xa8,0x22,0xfa,0x24,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 36488 0x8e88 "躈" */
+0x00,0x79,0x4b,0x4a,0x4b,0x7a,0x13,0x11,0x50,0x5f,0x51,0x51,0x59,0xe2,0x03,0x04,
+0x88,0x08,0xc8,0x50,0xde,0x64,0xd4,0x14,0x94,0xf4,0x14,0xc8,0x48,0x54,0x54,0xa2,
+/* 36489 0x8e89 "躉" */
+0x08,0xff,0x08,0x1f,0x11,0x1f,0x11,0x7f,0x41,0x5f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfc,0x24,0xfc,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36490 0x8e8a "躊" */
+0x00,0x7b,0x48,0x49,0x48,0x7b,0x10,0x11,0x1c,0x53,0x50,0x53,0x50,0x5f,0xe2,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 36491 0x8e8b "躋" */
+0x00,0xf0,0x97,0x91,0x90,0xff,0x25,0x25,0xab,0xb8,0xa2,0xa3,0xba,0xe3,0x02,0x04,
+0x80,0x40,0xfc,0x10,0xa4,0x58,0x54,0x52,0x58,0x00,0x08,0xf8,0x08,0xf8,0x08,0x08,
+/* 36492 0x8e8c "躌" */
+0x00,0x79,0x4b,0x4d,0x49,0x7b,0x11,0x11,0x13,0x5d,0x51,0x52,0x51,0x5c,0xe1,0x02,
+0x80,0x00,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,
+/* 36493 0x8e8d "躍" */
+0x00,0x7b,0x48,0x4a,0x49,0x7a,0x10,0x11,0x13,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x90,0x08,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 36494 0x8e8e "躎" */
+0x00,0xf7,0x92,0x94,0x9f,0xf4,0x26,0x25,0xa6,0xbc,0xa6,0xa5,0xa6,0xb4,0xc4,0x04,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 36495 0x8e8f "躏" */
+0x00,0x7d,0x44,0x45,0x44,0x7c,0x11,0x11,0x11,0x5d,0x51,0x51,0x51,0x5d,0xe1,0x01,
+0x48,0xfe,0x48,0x00,0xbe,0x82,0x52,0x7e,0xd2,0x7e,0x52,0x7e,0x52,0x7e,0x42,0x06,
+/* 36496 0x8e90 "躐" */
+0x01,0x7a,0x49,0x48,0x4b,0x7a,0x12,0x12,0x13,0x5e,0x53,0x52,0x53,0x5e,0xe2,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 36497 0x8e91 "躑" */
+0x04,0xf2,0x9f,0x92,0x9f,0xfa,0x2c,0x2b,0xa8,0xbf,0xa1,0xaf,0xa2,0xb4,0xc8,0x00,
+0x40,0x8e,0xea,0x8a,0xea,0xaa,0x6c,0xaa,0x2a,0xea,0x0a,0xea,0x8c,0x48,0x28,0x08,
+/* 36498 0x8e92 "躒" */
+0x01,0x79,0x4a,0x4a,0x4b,0x79,0x12,0x13,0x10,0x5c,0x53,0x50,0x50,0x5d,0xe2,0x00,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36499 0x8e93 "躓" */
+0x00,0x7b,0x4a,0x4b,0x4a,0x7a,0x14,0x13,0x52,0x5f,0x52,0x53,0x5a,0xe3,0x01,0x02,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 36500 0x8e94 "躔" */
+0x00,0xf7,0x94,0x95,0x95,0xf5,0x25,0x25,0xa4,0xbd,0xa4,0xa7,0xbd,0xea,0x08,0x13,
+0x20,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x24,0xfa,0x20,0xfe,
+/* 36501 0x8e95 "躕" */
+0x00,0x78,0x4b,0x4a,0x4b,0x7a,0x12,0x12,0x52,0x5e,0x52,0x52,0x5a,0xe4,0x05,0x08,
+0x40,0x20,0xfe,0x44,0xf4,0x44,0xee,0x04,0xf4,0xac,0xe4,0x14,0xa4,0x74,0x94,0x08,
+/* 36502 0x8e96 "躖" */
+0x01,0x7a,0x4b,0x49,0x4a,0x7b,0x10,0x13,0x1d,0x52,0x53,0x51,0x52,0x5f,0xe0,0x03,
+0x10,0x12,0xaa,0x3a,0x92,0xba,0x8a,0xfe,0x12,0x12,0xaa,0x3a,0x92,0xba,0x8a,0xfe,
+/* 36503 0x8e97 "躗" */
+0x22,0x4f,0x94,0x2f,0x61,0xaf,0x25,0x27,0x01,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x00,0x9c,0x80,0xde,0x08,0xc8,0x08,0xd8,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36504 0x8e98 "躘" */
+0x01,0x78,0x4b,0x48,0x4a,0x79,0x13,0x10,0x13,0x5e,0x53,0x52,0x53,0x5e,0xe2,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 36505 0x8e99 "躙" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x12,0x12,0x1f,0x52,0x52,0x52,0x52,0x5e,0xe2,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0x92,0xfa,0xa2,0xfa,0xa2,0xfa,0xa2,0xfa,0x82,0x06,
+/* 36506 0x8e9a "躚" */
+0x00,0xf0,0x94,0x92,0x92,0xf0,0x20,0x21,0xa6,0xba,0xa3,0xa2,0xba,0xe2,0x05,0x08,
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x10,0xfe,0x44,0xfe,0x44,0x7c,0x42,0x3e,0x00,0xfe,
+/* 36507 0x8e9b "躛" */
+0x22,0x4f,0x94,0x2f,0x62,0xaf,0x2a,0x2a,0x00,0x1f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x00,0x9c,0x80,0xde,0x08,0xc8,0x48,0xd8,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36508 0x8e9c "躜" */
+0x01,0xf5,0x97,0x99,0x97,0xf3,0x25,0x29,0xa0,0xbb,0xa2,0xa2,0xba,0xe0,0x01,0x06,
+0x08,0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0x00,0xf8,0x08,0x48,0x48,0xb0,0x08,0x04,
+/* 36509 0x8e9d "躝" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x12,0x12,0x52,0x5e,0x52,0x52,0x5a,0xe2,0x02,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 36510 0x8e9e "躞" */
+0x02,0xf2,0x93,0x96,0x9a,0xf2,0x22,0x22,0xa5,0xb8,0xa0,0xa3,0xb9,0xe0,0x03,0x0c,
+0x48,0xe8,0x08,0xea,0x1c,0xe8,0x08,0xe8,0xb4,0xe2,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 36511 0x8e9f "躟" */
+0x00,0x7b,0x48,0x49,0x49,0x79,0x10,0x13,0x1c,0x53,0x50,0x53,0x50,0x5d,0xe2,0x00,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 36512 0x8ea0 "躠" */
+0x08,0xff,0x28,0x7d,0x44,0x7d,0x40,0x7d,0x44,0x7f,0x10,0x1f,0x01,0x11,0x31,0xcf,
+0x20,0xfe,0x20,0xfc,0x88,0xfe,0x20,0xfc,0x20,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,
+/* 36513 0x8ea1 "躡" */
+0x03,0xf1,0x91,0x91,0x91,0xf1,0x27,0x20,0xa7,0xba,0xa3,0xa2,0xa3,0xb2,0xc7,0x00,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 36514 0x8ea2 "躢" */
+0x07,0xf4,0x97,0x94,0x97,0xf5,0x25,0x25,0xa5,0xbc,0xa7,0xa6,0xa5,0xb6,0xc5,0x04,
+0x9e,0x92,0x9e,0x92,0xfe,0x12,0xf2,0x12,0xf2,0x02,0xba,0xaa,0x9a,0xaa,0x9a,0x06,
+/* 36515 0x8ea3 "躣" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x7a,0x13,0x10,0x11,0x5d,0x53,0x55,0x51,0x5d,0xe1,0x01,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 36516 0x8ea4 "躤" */
+0x01,0xf7,0x91,0x90,0x91,0xf7,0x21,0x27,0xb1,0xaf,0xa1,0xa3,0xb5,0xc9,0x01,0x01,
+0x08,0xfe,0x08,0x00,0x14,0xbe,0x14,0x94,0x7e,0x80,0x3e,0xa2,0x7e,0x22,0x3e,0x22,
+/* 36517 0x8ea5 "躥" */
+0x00,0xf7,0x94,0x91,0x90,0xf3,0x22,0x23,0xa2,0xbb,0xa2,0xa3,0xa2,0xb3,0xc2,0x03,
+0x40,0xfe,0x92,0x08,0x80,0x1c,0x04,0x9c,0x04,0xfc,0x48,0x68,0x48,0x6a,0x46,0x62,
+/* 36518 0x8ea6 "躦" */
+0x05,0xf7,0x99,0x97,0x93,0xf5,0x29,0x23,0xa2,0xbb,0xa2,0xa3,0xba,0xe3,0x01,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 36519 0x8ea7 "躧" */
+0x03,0x78,0x4b,0x4a,0x4b,0x7a,0x10,0x13,0x1e,0x53,0x52,0x53,0x52,0x5e,0xe2,0x04,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 36520 0x8ea8 "躨" */
+0x01,0xf7,0x90,0x92,0x92,0xfb,0x2a,0x2a,0xab,0xbc,0xa2,0xa5,0xa2,0xb0,0xc1,0x06,
+0x10,0xfe,0x40,0xee,0xaa,0xea,0xae,0xe8,0xaa,0xe6,0x88,0xf4,0x90,0x60,0x98,0x06,
+/* 36521 0x8ea9 "躩" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x78,0x11,0x13,0x15,0x5d,0x51,0x50,0x51,0x5c,0xe0,0x07,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 36522 0x8eaa "躪" */
+0x00,0x7b,0x48,0x4b,0x4a,0x7b,0x12,0x13,0x12,0x5e,0x53,0x52,0x52,0x5e,0xe2,0x02,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x4a,0xfe,0x92,0xfe,0x92,0xfe,0x82,0x06,
+/* 36523 0x8eab "身" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x7f,0x00,0x00,0x03,0x1c,0xe0,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf2,0x14,0x18,0xf0,0x50,0x90,0x10,0x10,0x50,0x20,
+/* 36524 0x8eac "躬" */
+0x08,0x10,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0xfe,0x06,0x0a,0x12,0x22,0x4a,0x04,
+0x00,0xfc,0x04,0x04,0x04,0x7c,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 36525 0x8ead "躭" */
+0x10,0x20,0x7c,0x45,0x7d,0x46,0x7c,0x44,0x44,0xfc,0x0c,0x14,0x24,0x44,0x95,0x0a,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 36526 0x8eae "躮" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7d,0x46,0x44,0xfc,0x0c,0x14,0x24,0x44,0x95,0x0a,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 36527 0x8eaf "躯" */
+0x10,0x21,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x45,0xfd,0x0d,0x15,0x25,0x45,0x95,0x08,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 36528 0x8eb0 "躰" */
+0x10,0x20,0x7c,0x44,0x7d,0x44,0x7c,0x44,0x45,0xfd,0x0e,0x14,0x24,0x44,0x94,0x08,
+0x20,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0xf8,0x20,0x20,0x20,0x20,
+/* 36529 0x8eb1 "躱" */
+0x10,0x21,0x7c,0x44,0x7c,0x44,0x7c,0x45,0x44,0xfd,0x0c,0x14,0x24,0x45,0x96,0x08,
+0x00,0xfc,0x44,0x48,0x5e,0x82,0x8a,0x24,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 36530 0x8eb2 "躲" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7d,0x46,0x45,0xfc,0x0c,0x14,0x25,0x46,0x94,0x08,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x26,0x20,0xfe,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36531 0x8eb3 "躳" */
+0x08,0x10,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0xfe,0x06,0x0a,0x12,0x22,0x4a,0x04,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x00,0x00,0xfe,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 36532 0x8eb4 "躴" */
+0x08,0x10,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x22,0xfe,0x06,0x0a,0x12,0x22,0x4a,0x04,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 36533 0x8eb5 "躵" */
+0x10,0x21,0x7c,0x44,0x7c,0x45,0x7c,0x44,0x44,0xfc,0x0c,0x15,0x25,0x45,0x96,0x08,
+0x00,0xfc,0x24,0xa4,0xa4,0x24,0x54,0x48,0xa0,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 36534 0x8eb6 "躶" */
+0x10,0x21,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x44,0xfd,0x0c,0x14,0x25,0x46,0x94,0x08,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36535 0x8eb7 "躷" */
+0x10,0x21,0x7c,0x44,0x7f,0x44,0x7d,0x46,0x44,0xff,0x0c,0x15,0x24,0x44,0x94,0x09,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 36536 0x8eb8 "躸" */
+0x10,0x20,0x7d,0x44,0x7c,0x45,0x7f,0x44,0x45,0xfd,0x0d,0x15,0x25,0x44,0x94,0x08,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 36537 0x8eb9 "躹" */
+0x10,0x20,0x7c,0x45,0x7e,0x44,0x7c,0x44,0x45,0xfc,0x0c,0x14,0x25,0x44,0x94,0x08,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 36538 0x8eba "躺" */
+0x10,0x21,0x7c,0x44,0x7c,0x45,0x7d,0x45,0x45,0xfd,0x0d,0x15,0x25,0x45,0x95,0x09,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 36539 0x8ebb "躻" */
+0x10,0x20,0x7d,0x45,0x7e,0x44,0x7c,0x45,0x44,0xfd,0x0c,0x14,0x24,0x44,0x97,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x50,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36540 0x8ebc "躼" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x47,0x45,0xfd,0x0d,0x15,0x25,0x45,0x95,0x09,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 36541 0x8ebd "躽" */
+0x10,0x23,0x7a,0x4a,0x7a,0x4a,0x7a,0x4a,0x4a,0xfb,0x1a,0x2a,0x4a,0x8a,0x2a,0x13,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 36542 0x8ebe "躾" */
+0x10,0x20,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x45,0xfc,0x0c,0x15,0x24,0x44,0x94,0x0b,
+0x84,0x48,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 36543 0x8ebf "躿" */
+0x10,0x20,0x79,0x49,0x79,0x49,0x79,0x49,0x49,0xf9,0x19,0x29,0x49,0x8a,0x2a,0x14,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 36544 0x8ec0 "軀" */
+0x10,0x23,0x7a,0x4a,0x7a,0x4a,0x7a,0x4a,0x4a,0xfa,0x1a,0x2a,0x4a,0x8a,0x2b,0x10,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 36545 0x8ec1 "軁" */
+0x10,0x21,0x7d,0x47,0x7d,0x45,0x7c,0x45,0x45,0xfd,0x0c,0x17,0x24,0x45,0x94,0x0b,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 36546 0x8ec2 "軂" */
+0x10,0x21,0x7c,0x44,0x7c,0x45,0x7d,0x45,0x44,0xfc,0x0c,0x14,0x24,0x44,0x94,0x09,
+0x48,0x6a,0xdc,0x48,0xb4,0x22,0xfe,0x02,0x20,0x20,0xfc,0x24,0x44,0x44,0x94,0x08,
+/* 36547 0x8ec3 "軃" */
+0x10,0x21,0x7d,0x45,0x7d,0x44,0x7d,0x45,0x45,0xfd,0x0d,0x14,0x27,0x44,0x94,0x08,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 36548 0x8ec4 "軄" */
+0x11,0x20,0x7b,0x48,0x7a,0x49,0x7f,0x48,0x4b,0xfa,0x1a,0x2b,0x4a,0x8a,0x2b,0x10,
+0x10,0x94,0xd2,0x12,0x50,0x90,0xfe,0x10,0xd2,0x52,0x54,0xd4,0x4a,0x4a,0xd6,0x22,
+/* 36549 0x8ec5 "軅" */
+0x10,0x23,0x7a,0x4a,0x7a,0x4a,0x7b,0x4a,0x4a,0xfa,0x1a,0x2a,0x4a,0x8a,0x2a,0x14,
+0x00,0xfe,0x00,0x58,0x54,0xbe,0xa8,0xe8,0xbe,0xa8,0xa8,0xbe,0xa8,0xa8,0xbe,0xa0,
+/* 36550 0x8ec6 "軆" */
+0x10,0x21,0x7d,0x45,0x7d,0x45,0x7c,0x45,0x44,0xfd,0x0d,0x15,0x24,0x44,0x97,0x08,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 36551 0x8ec7 "軇" */
+0x10,0x23,0x78,0x49,0x78,0x4b,0x78,0x49,0x48,0xfb,0x18,0x2b,0x48,0x8b,0x2a,0x13,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 36552 0x8ec8 "軈" */
+0x10,0x20,0x7b,0x4a,0x7a,0x4a,0x7b,0x4a,0x4a,0xfa,0x1a,0x2a,0x4a,0x8b,0x2d,0x12,
+0x40,0x20,0xfe,0x54,0x7e,0xa8,0xbc,0xa8,0xbc,0xa8,0xbe,0xa0,0x54,0x42,0x4a,0x38,
+/* 36553 0x8ec9 "軉" */
+0x10,0x23,0x7a,0x49,0x78,0x49,0x78,0x4b,0x48,0xf9,0x19,0x29,0x49,0x89,0x28,0x11,
+0x20,0xfe,0x12,0xdc,0xa8,0xdc,0xaa,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 36554 0x8eca "車" */
+0x01,0x01,0x7f,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 36555 0x8ecb "軋" */
+0x08,0x08,0xff,0x08,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0xa2,0x22,0x1e,0x00,
+/* 36556 0x8ecc "軌" */
+0x10,0x10,0x10,0xfc,0x13,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,0x14,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 36557 0x8ecd "軍" */
+0x00,0x7f,0x41,0x81,0x3f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,0x01,0x01,
+0x00,0xfe,0x02,0x04,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,0x00,
+/* 36558 0x8ece "軎" */
+0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x01,0x3f,0x20,0x20,0x3f,0x20,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 36559 0x8ecf "軏" */
+0x10,0x10,0x13,0xfc,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 36560 0x8ed0 "軐" */
+0x10,0x11,0x10,0xfe,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 36561 0x8ed1 "軑" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36562 0x8ed2 "軒" */
+0x08,0x08,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 36563 0x8ed3 "軓" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0xd0,0xb0,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 36564 0x8ed4 "軔" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 36565 0x8ed5 "軕" */
+0x10,0x10,0x10,0xfc,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xff,0x11,0x11,0x10,0x10,
+0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 36566 0x8ed6 "軖" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x13,0x10,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36567 0x8ed7 "軗" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x56,0x7d,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x13,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 36568 0x8ed8 "軘" */
+0x10,0x10,0x10,0xfd,0x10,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 36569 0x8ed9 "軙" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x16,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 36570 0x8eda "軚" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 36571 0x8edb "軛" */
+0x10,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 36572 0x8edc "軜" */
+0x10,0x10,0x10,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 36573 0x8edd "軝" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xc6,0x82,
+/* 36574 0x8ede "軞" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x11,0xfe,0x10,0x10,0x10,0x10,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x24,0x24,0x24,0x1c,
+/* 36575 0x8edf "軟" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36576 0x8ee0 "軠" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 36577 0x8ee1 "軡" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x56,0x7c,0x54,0x7d,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 36578 0x8ee2 "転" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x10,0x10,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0x88,0x84,0xfe,0x82,0x00,
+/* 36579 0x8ee3 "軣" */
+0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0xff,0x01,0x60,0x18,0x06,0x18,0x60,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0x0c,0x30,0xc0,0x30,0x0c,
+/* 36580 0x8ee4 "軤" */
+0x10,0x10,0x13,0xfc,0x11,0x7c,0x54,0x7c,0x57,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 36581 0x8ee5 "軥" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x40,0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x28,0x10,
+/* 36582 0x8ee6 "軦" */
+0x10,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x50,0x50,0x50,0x50,0x92,0x92,0x12,0x0e,0x00,
+/* 36583 0x8ee7 "軧" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xd6,0x8a,
+/* 36584 0x8ee8 "軨" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x56,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 36585 0x8ee9 "軩" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36586 0x8eea "軪" */
+0x20,0x20,0x20,0xf9,0x21,0xfa,0xab,0xf8,0xa9,0xf9,0x22,0xfb,0x20,0x20,0x20,0x20,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 36587 0x8eeb "軫" */
+0x10,0x10,0x10,0xfe,0x11,0x7e,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x11,0x10,0x10,0x13,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 36588 0x8eec "軬" */
+0x04,0x08,0x1f,0x02,0xff,0x09,0x3f,0xc1,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x00,0x20,0xf0,0x10,0xfe,0x20,0xf8,0x06,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 36589 0x8eed "軭" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x80,0x80,0xfe,0x90,0x90,0xbc,0x90,0x90,0x90,0xfe,0x80,0x80,0xfe,0x00,
+/* 36590 0x8eee "軮" */
+0x10,0x10,0x10,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7f,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 36591 0x8eef "軯" */
+0x10,0x11,0x10,0xfc,0x11,0x7c,0x54,0x7c,0x57,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 36592 0x8ef0 "軰" */
+0x04,0x7c,0x04,0x1c,0xe4,0x01,0x7f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x44,0x58,0x62,0x42,0x3e,0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 36593 0x8ef1 "軱" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 36594 0x8ef2 "軲" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36595 0x8ef3 "軳" */
+0x10,0x10,0x10,0xfe,0x11,0x7e,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 36596 0x8ef4 "軴" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x13,0x10,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36597 0x8ef5 "軵" */
+0x10,0x10,0x10,0xfe,0x10,0x7d,0x56,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x44,0x44,0x44,0x84,0xbe,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 36598 0x8ef6 "軶" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x08,0x10,0x20,0x42,0x82,0x7e,0x00,
+/* 36599 0x8ef7 "軷" */
+0x10,0x10,0x10,0xfc,0x13,0x7c,0x54,0x7c,0x55,0x7d,0x11,0xfd,0x12,0x12,0x14,0x11,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 36600 0x8ef8 "軸" */
+0x10,0x10,0x10,0xfe,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 36601 0x8ef9 "軹" */
+0x10,0x10,0x11,0xff,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfe,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 36602 0x8efa "軺" */
+0x10,0x11,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36603 0x8efb "軻" */
+0x10,0x10,0x13,0xfc,0x10,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 36604 0x8efc "軼" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x56,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36605 0x8efd "軽" */
+0x10,0x11,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x57,0x7c,0x11,0xfe,0x10,0x10,0x13,0x10,
+0x00,0xfc,0x84,0x88,0x50,0x20,0x50,0x88,0x26,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 36606 0x8efe "軾" */
+0x10,0x10,0x10,0xfc,0x13,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfc,0x10,0x13,0x10,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x90,0x90,0x90,0x88,0xea,0x8a,0x06,0x02,
+/* 36607 0x8eff "軿" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x11,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 36608 0x8f00 "輀" */
+0x10,0x13,0x10,0xfe,0x10,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x44,0x14,0x08,
+/* 36609 0x8f01 "輁" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7c,0x54,0x7d,0x10,0xfe,0x10,0x10,0x10,0x11,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0xfe,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 36610 0x8f02 "輂" */
+0x08,0x7f,0x08,0xff,0x10,0x21,0x5f,0x81,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x20,0xfc,0x20,0xfe,0x10,0x08,0xf4,0x02,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 36611 0x8f03 "較" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x55,0x7e,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 36612 0x8f04 "輄" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x57,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x11,0x12,0x14,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 36613 0x8f05 "輅" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 36614 0x8f06 "輆" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfd,0x10,0x10,0x10,0x11,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 36615 0x8f07 "輇" */
+0x10,0x10,0x10,0xfe,0x11,0x7e,0x55,0x7c,0x54,0x7c,0x11,0xfe,0x10,0x10,0x13,0x10,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 36616 0x8f08 "輈" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x10,0x20,0xfc,0x84,0xa4,0x94,0x94,0xfe,0x84,0xa4,0x94,0x94,0x84,0x04,0x14,0x08,
+/* 36617 0x8f09 "載" */
+0x08,0x7f,0x08,0xff,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x20,0x28,0x24,0xfe,0x20,0xa0,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0xaa,0x46,0x82,
+/* 36618 0x8f0a "輊" */
+0x10,0x11,0x10,0xfe,0x10,0x7d,0x55,0x7c,0x54,0x7c,0x11,0xfe,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 36619 0x8f0b "輋" */
+0x01,0x41,0x7f,0x02,0xff,0x09,0x3f,0xc1,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x00,0x04,0xfc,0x00,0xfe,0x20,0xf8,0x06,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 36620 0x8f0c "輌" */
+0x20,0x23,0x20,0xf8,0x20,0xfb,0xaa,0xfa,0xaa,0xfa,0x22,0xfa,0x22,0x22,0x22,0x22,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 36621 0x8f0d "輍" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7c,0x55,0x7e,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0x50,0x48,0x84,0x24,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 36622 0x8f0e "輎" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 36623 0x8f0f "輏" */
+0x10,0x13,0x10,0xfc,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x50,0x50,0xfc,0x54,0x54,0x54,0x8c,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 36624 0x8f10 "輐" */
+0x10,0x10,0x11,0xfd,0x12,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 36625 0x8f11 "輑" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x40,0x40,0xfc,0xc4,0x44,0x44,0x7c,0x44,
+/* 36626 0x8f12 "輒" */
+0x10,0x13,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x13,0x10,0x10,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 36627 0x8f13 "輓" */
+0x10,0x10,0x10,0xfd,0x12,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 36628 0x8f14 "輔" */
+0x10,0x10,0x13,0xfc,0x10,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 36629 0x8f15 "輕" */
+0x10,0x11,0x10,0xfe,0x11,0x7e,0x55,0x7c,0x54,0x7d,0x10,0xfe,0x10,0x10,0x13,0x10,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36630 0x8f16 "輖" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x11,0x11,0x12,
+0x00,0xfe,0x92,0x92,0xba,0x92,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x02,0x0a,0x04,
+/* 36631 0x8f17 "輗" */
+0x10,0x10,0x11,0xff,0x11,0x7d,0x55,0x7d,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x00,0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 36632 0x8f18 "輘" */
+0x10,0x10,0x10,0xfc,0x10,0x7d,0x54,0x7c,0x55,0x7c,0x10,0xfd,0x10,0x10,0x10,0x11,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x48,0x84,0x22,0x78,0x88,0x48,0x50,0x20,0x50,0x8c,
+/* 36633 0x8f19 "輙" */
+0x10,0x13,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x13,0x10,0x10,0x10,
+0x00,0xe0,0x5c,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x48,0x68,0xc8,0x54,0x54,0x62,
+/* 36634 0x8f1a "輚" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x11,0xfe,0x10,0x10,0x10,0x11,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 36635 0x8f1b "輛" */
+0x20,0x23,0x20,0xf8,0x23,0xfa,0xaa,0xfb,0xaa,0xfa,0x23,0xfa,0x22,0x22,0x22,0x22,
+0x00,0xfe,0x20,0x20,0xfe,0x22,0x22,0x32,0xaa,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,
+/* 36636 0x8f1c "輜" */
+0x10,0x10,0x11,0xfe,0x11,0x7c,0x54,0x7c,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 36637 0x8f1d "輝" */
+0x10,0x13,0x92,0x54,0x5b,0x10,0xfd,0x29,0x29,0x29,0x29,0x28,0x2b,0x4c,0x48,0x80,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 36638 0x8f1e "輞" */
+0x20,0x23,0x22,0xfa,0x22,0xfb,0xaa,0xfa,0xab,0xfa,0x22,0xfa,0x22,0x22,0x22,0x22,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 36639 0x8f1f "輟" */
+0x20,0x23,0x20,0xf9,0x20,0xf9,0xaa,0xfc,0xa8,0xfb,0x20,0xf9,0x20,0x21,0x22,0x24,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 36640 0x8f20 "輠" */
+0x10,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x54,0x7d,0x10,0xfe,0x11,0x12,0x10,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36641 0x8f21 "輡" */
+0x10,0x10,0x10,0xfc,0x11,0x7e,0x54,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 36642 0x8f22 "輢" */
+0x10,0x10,0x11,0xfc,0x10,0x7d,0x57,0x7c,0x55,0x7d,0x11,0xfd,0x11,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 36643 0x8f23 "輣" */
+0x10,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x00,0xdc,0x54,0x54,0x54,0xdc,0x54,0x54,0x54,0xdc,0x54,0x54,0x54,0xd4,0x24,0x4c,
+/* 36644 0x8f24 "輤" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 36645 0x8f25 "輥" */
+0x10,0x11,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x54,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 36646 0x8f26 "輦" */
+0x08,0x3e,0x08,0x7e,0x14,0x23,0x5f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0xff,0x01,
+0x20,0xf8,0x20,0xfc,0x50,0x88,0xf4,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 36647 0x8f27 "輧" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x11,
+0x44,0x44,0x88,0xdc,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 36648 0x8f28 "輨" */
+0x10,0x10,0x11,0xfd,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x10,0xfe,0x02,0x00,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 36649 0x8f29 "輩" */
+0x04,0x7c,0x04,0x3c,0x04,0x7c,0x05,0x3f,0x01,0x1f,0x11,0x1f,0x11,0xff,0x01,0x01,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,0x00,
+/* 36650 0x8f2a "輪" */
+0x10,0x10,0x10,0xfe,0x11,0x7e,0x54,0x7d,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 36651 0x8f2b "輫" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfd,0x10,0x10,0x10,0x10,
+0x48,0x48,0x48,0xce,0x48,0x48,0x48,0xce,0x48,0x48,0x48,0xce,0x48,0x48,0x48,0x48,
+/* 36652 0x8f2c "輬" */
+0x10,0x10,0x13,0xfc,0x10,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfe,0x11,0x12,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 36653 0x8f2d "輭" */
+0x10,0x13,0x10,0xfc,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x10,0xfd,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 36654 0x8f2e "輮" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x54,0x7d,0x56,0x7c,0x11,0xfe,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36655 0x8f2f "輯" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x55,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x13,0x10,0x10,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 36656 0x8f30 "輰" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7d,0x54,0x7c,0x11,0xfe,0x10,0x11,0x10,0x10,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 36657 0x8f31 "輱" */
+0x20,0x20,0x20,0xfb,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x22,0xfa,0x22,0x22,0x22,0x24,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 36658 0x8f32 "輲" */
+0x10,0x11,0x11,0xfd,0x11,0x7c,0x57,0x7c,0x54,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 36659 0x8f33 "輳" */
+0x10,0x10,0x13,0xfc,0x11,0x7c,0x57,0x7c,0x55,0x7e,0x10,0xfd,0x10,0x10,0x10,0x13,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x20,0xfc,0x20,0x50,0x88,0x04,
+/* 36660 0x8f34 "輴" */
+0x10,0x10,0x11,0xfd,0x11,0x7d,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 36661 0x8f35 "輵" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfe,0x12,0x92,0xaa,0x82,0xfa,0x02,0x14,0x08,
+/* 36662 0x8f36 "輶" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 36663 0x8f37 "輷" */
+0x10,0x10,0x10,0xfd,0x12,0x7d,0x54,0x7d,0x54,0x7d,0x10,0xfd,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x42,0xfa,0x02,0xf2,0x02,0xf2,0x02,0xf2,0x12,0xf2,0x14,0x08,
+/* 36664 0x8f38 "輸" */
+0x20,0x20,0x21,0xfa,0x25,0xf8,0xab,0xfa,0xaa,0xfb,0x22,0xfa,0x23,0x22,0x22,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 36665 0x8f39 "輹" */
+0x10,0x10,0x10,0xfe,0x11,0x7e,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x11,0x10,0x10,0x11,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 36666 0x8f3a "輺" */
+0x10,0x10,0x10,0xfd,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x52,0x52,0xa4,0xfe,0xa4,0x52,0x52,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 36667 0x8f3b "輻" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 36668 0x8f3c "輼" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7d,0x11,0xff,0x11,0x11,0x13,0x10,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 36669 0x8f3d "輽" */
+0x10,0x10,0x10,0xfd,0x10,0x7f,0x54,0x7d,0x57,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x04,0xfe,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 36670 0x8f3e "輾" */
+0x20,0x23,0x22,0xfa,0x23,0xfa,0xaa,0xfa,0xaa,0xfa,0x23,0xfa,0x22,0x24,0x24,0x28,
+0x00,0xfc,0x04,0x04,0xfc,0x48,0x48,0xfc,0x48,0x48,0xfe,0xa4,0xa8,0x90,0xc8,0x86,
+/* 36671 0x8f3f "輿" */
+0x01,0x17,0x61,0x47,0x45,0x77,0x45,0x47,0x71,0x47,0x41,0xff,0x00,0x10,0x20,0x40,
+0x00,0xc0,0x1c,0xc4,0x44,0xdc,0x44,0xc4,0x1c,0xc4,0x04,0xfe,0x00,0x10,0x08,0x04,
+/* 36672 0x8f40 "轀" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7d,0x11,0xff,0x11,0x11,0x13,0x10,
+0x00,0xf8,0xa8,0xa8,0xd8,0x88,0xf8,0x00,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 36673 0x8f41 "轁" */
+0x10,0x11,0x10,0xfd,0x10,0x7c,0x54,0x7d,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 36674 0x8f42 "轂" */
+0x08,0xff,0x08,0x7f,0x00,0xff,0x88,0x7f,0x08,0x7f,0x49,0x7f,0x49,0xff,0x08,0x08,
+0x00,0xb8,0x28,0x28,0x28,0xc6,0x80,0x7c,0x24,0x24,0x28,0x28,0x10,0xa8,0x44,0x82,
+/* 36675 0x8f43 "轃" */
+0x10,0x10,0x13,0xfc,0x11,0x7c,0x57,0x7c,0x55,0x7e,0x10,0xfd,0x10,0x10,0x13,0x10,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x34,0xe2,0x20,0xfc,0x70,0xac,0x22,0x20,
+/* 36676 0x8f44 "轄" */
+0x20,0x20,0x23,0xfa,0x24,0xf9,0xa8,0xf9,0xa8,0xfb,0x20,0xf9,0x21,0x21,0x21,0x21,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 36677 0x8f45 "轅" */
+0x10,0x10,0x11,0xfc,0x13,0x7c,0x55,0x7d,0x55,0x7d,0x10,0xfc,0x11,0x16,0x10,0x10,
+0x20,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x52,0x94,0x88,0xa4,0xc2,0x80,
+/* 36678 0x8f46 "轆" */
+0x20,0x20,0x23,0xfa,0x22,0xfb,0xaa,0xfa,0xab,0xfa,0x22,0xfa,0x22,0x24,0x24,0x28,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 36679 0x8f47 "轇" */
+0x20,0x23,0x20,0xfa,0x21,0xfa,0xa8,0xf8,0xab,0xf8,0x21,0xf8,0x21,0x20,0x20,0x23,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 36680 0x8f48 "轈" */
+0x11,0x12,0x11,0xfc,0x11,0x7d,0x55,0x7d,0x55,0x7c,0x13,0xfc,0x10,0x11,0x16,0x10,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36681 0x8f49 "轉" */
+0x10,0x13,0x10,0xfd,0x11,0x7d,0x55,0x7d,0x54,0x7d,0x10,0xfd,0x11,0x10,0x10,0x10,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 36682 0x8f4a "轊" */
+0x10,0x13,0x10,0xfd,0x10,0x7f,0x54,0x7c,0x57,0x7c,0x10,0xfd,0x10,0x10,0x13,0x10,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 36683 0x8f4b "轋" */
+0x10,0x10,0x12,0xfd,0x11,0x7c,0x54,0x7f,0x55,0x7d,0x11,0xfd,0x11,0x12,0x14,0x10,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 36684 0x8f4c "轌" */
+0x10,0x11,0x10,0xff,0x12,0x7d,0x54,0x7d,0x54,0x7d,0x10,0xfd,0x10,0x10,0x11,0x10,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 36685 0x8f4d "轍" */
+0x21,0x20,0x23,0xf9,0x22,0xff,0xa8,0xfb,0xaa,0xfb,0x22,0xfb,0x22,0x22,0x22,0x22,
+0x08,0x88,0xe8,0x10,0x9e,0xd4,0x64,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 36686 0x8f4e "轎" */
+0x20,0x21,0x20,0xfb,0x20,0xf9,0xaa,0xfc,0xa8,0xf8,0x23,0xfa,0x22,0x22,0x22,0x22,
+0x1c,0xe0,0x40,0xfe,0x88,0x04,0xfa,0x88,0xf8,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x06,
+/* 36687 0x8f4f "轏" */
+0x23,0x22,0x23,0xfa,0x22,0xfa,0xab,0xfa,0xaa,0xfb,0x22,0xfa,0x24,0x27,0x28,0x21,
+0xfe,0x02,0xfe,0x00,0xfc,0x08,0xfe,0x10,0x30,0xce,0x42,0x84,0xee,0x84,0x84,0x8c,
+/* 36688 0x8f50 "轐" */
+0x10,0x11,0x10,0xfc,0x11,0x7c,0x54,0x7d,0x54,0x7c,0x10,0xfd,0x10,0x10,0x11,0x12,
+0x50,0x52,0xd4,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 36689 0x8f51 "轑" */
+0x10,0x10,0x11,0xfc,0x11,0x7c,0x55,0x7e,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 36690 0x8f52 "轒" */
+0x10,0x11,0x10,0xfc,0x13,0x7c,0x55,0x7d,0x55,0x7d,0x11,0xfd,0x11,0x10,0x11,0x12,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 36691 0x8f53 "轓" */
+0x10,0x13,0x11,0xfc,0x13,0x7c,0x55,0x7e,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 36692 0x8f54 "轔" */
+0x20,0x21,0x20,0xfb,0x20,0xf9,0xaa,0xf9,0xa9,0xf9,0x22,0xfd,0x20,0x21,0x22,0x24,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 36693 0x8f55 "轕" */
+0x10,0x13,0x10,0xfd,0x11,0x7d,0x55,0x7d,0x54,0x7d,0x12,0xfd,0x11,0x11,0x10,0x10,
+0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0x02,0xfa,0x0a,0x04,
+/* 36694 0x8f56 "轖" */
+0x20,0x20,0x23,0xf9,0x21,0xfa,0xaf,0xf8,0xa9,0xf9,0x21,0xf9,0x21,0x21,0x21,0x21,
+0x20,0x20,0xfe,0x24,0x24,0xaa,0xfe,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0xfc,0x04,
+/* 36695 0x8f57 "轗" */
+0x20,0x20,0x23,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x24,0xf8,0x22,0x22,0x24,0x20,
+0x14,0x12,0xfe,0x10,0xf0,0x14,0xf4,0xb8,0xea,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 36696 0x8f58 "轘" */
+0x10,0x11,0x11,0xfd,0x11,0x7c,0x57,0x7c,0x55,0x7d,0x11,0xfc,0x10,0x11,0x12,0x10,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 36697 0x8f59 "轙" */
+0x11,0x10,0x13,0xfc,0x11,0x7c,0x57,0x7c,0x55,0x7c,0x13,0xfc,0x10,0x13,0x10,0x11,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 36698 0x8f5a "轚" */
+0x08,0x7f,0x2a,0x3e,0x2a,0xff,0x49,0x7f,0x01,0x7f,0x11,0x1f,0x11,0xff,0x01,0x01,
+0x00,0x3c,0x24,0x42,0x3c,0xa4,0x18,0x66,0x00,0xfc,0x10,0xf0,0x10,0xfe,0x00,0x00,
+/* 36699 0x8f5b "轛" */
+0x21,0x21,0x25,0xfb,0x21,0xfb,0xa8,0xfa,0xa9,0xfb,0x20,0xfb,0x20,0x20,0x27,0x20,
+0x44,0x44,0x54,0x64,0x5e,0xe4,0x04,0x34,0x4c,0xe4,0x84,0xe4,0x84,0xe4,0x14,0x08,
+/* 36700 0x8f5c "轜" */
+0x20,0x21,0x20,0xfb,0x22,0xf9,0xa8,0xf9,0xa8,0xfb,0x20,0xf9,0x21,0x21,0x21,0x21,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 36701 0x8f5d "轝" */
+0x1a,0x23,0x3a,0x23,0x38,0x22,0xff,0x11,0x3f,0xc1,0x1f,0x11,0x1f,0x11,0xff,0x01,
+0x38,0x88,0x38,0x88,0xb8,0x88,0xfe,0x10,0xf8,0x06,0xf0,0x10,0xf0,0x10,0xfe,0x00,
+/* 36702 0x8f5e "轞" */
+0x20,0x23,0x22,0xfb,0x22,0xfb,0xaa,0xfb,0xa8,0xf9,0x21,0xf9,0x21,0x21,0x27,0x20,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 36703 0x8f5f "轟" */
+0x01,0x3f,0x01,0x1f,0x11,0x1f,0x11,0xff,0x01,0x11,0xfe,0x54,0x7c,0x54,0xfe,0x10,
+0x00,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,0x10,0xfe,0x54,0x7c,0x54,0xfe,0x10,
+/* 36704 0x8f60 "轠" */
+0x20,0x21,0x21,0xf9,0x21,0xf9,0xa9,0xf8,0xab,0xfa,0x22,0xfb,0x22,0x22,0x23,0x22,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xfe,0x22,
+/* 36705 0x8f61 "轡" */
+0x21,0x27,0x41,0x97,0xe5,0x47,0x95,0xf7,0x01,0xaf,0xa9,0x01,0x3f,0x20,0x3f,0x20,
+0x04,0xc4,0x08,0xd2,0x5c,0xc8,0x52,0xde,0x00,0xea,0x2a,0x00,0xf8,0x08,0xf8,0x08,
+/* 36706 0x8f62 "轢" */
+0x21,0x21,0x22,0xfa,0x23,0xf9,0xaa,0xfb,0xa8,0xf8,0x23,0xf8,0x20,0x21,0x22,0x20,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 36707 0x8f63 "轣" */
+0x20,0x23,0x22,0xfa,0x22,0xfb,0xaa,0xfa,0xab,0xfa,0x22,0xfa,0x22,0x24,0x24,0x2b,
+0x00,0xfe,0x22,0xcc,0x44,0xee,0x44,0xee,0x54,0x44,0x10,0x90,0x9e,0x90,0x90,0xfe,
+/* 36708 0x8f64 "轤" */
+0x20,0x20,0x20,0xfb,0x22,0xfb,0xaa,0xfa,0xaa,0xfa,0x22,0xfa,0x22,0x25,0x25,0x2b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 36709 0x8f65 "轥" */
+0x20,0x23,0x20,0xfb,0x22,0xfb,0xaa,0xfb,0xaa,0xfa,0x23,0xfa,0x22,0x22,0x22,0x22,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x4a,0xfe,0x92,0xfe,0x92,0xfe,0x82,0x06,
+/* 36710 0x8f66 "车" */
+0x02,0x02,0x02,0x7f,0x04,0x09,0x11,0x21,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 36711 0x8f67 "轧" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 36712 0x8f68 "轨" */
+0x20,0x20,0x20,0xfc,0x43,0x50,0x90,0xfc,0x10,0x10,0x1c,0xf0,0x51,0x11,0x12,0x14,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 36713 0x8f69 "轩" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x09,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 36714 0x8f6a "轪" */
+0x10,0x10,0x10,0xfe,0x20,0x29,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x09,0x0a,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36715 0x8f6b "轫" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x09,0x0e,0xf8,0x48,0x08,0x09,0x0a,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0xa4,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 36716 0x8f6c "转" */
+0x20,0x20,0x20,0xfd,0x40,0x50,0x93,0xfc,0x10,0x11,0x1c,0xf0,0x50,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfc,0x20,0x40,0xfe,0x40,0x80,0xfc,0x04,0x88,0x50,0x20,0x10,0x10,
+/* 36717 0x8f6d "轭" */
+0x20,0x21,0x21,0xfd,0x41,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x11,0x12,0x14,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 36718 0x8f6e "轮" */
+0x20,0x20,0x20,0xfc,0x41,0x52,0x94,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x11,0x10,0x10,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0x06,0x10,0x20,0x40,0x80,0x00,0x04,0x04,0xfc,0x00,
+/* 36719 0x8f6f "软" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x49,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x09,0x0a,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36720 0x8f70 "轰" */
+0x02,0x02,0x7f,0x08,0x11,0x3f,0x01,0xff,0x01,0x01,0x3e,0x02,0x14,0x08,0x34,0xc2,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0xfe,0x00,0x00,0xf8,0x88,0x50,0x20,0x58,0x86,
+/* 36721 0x8f71 "轱" */
+0x10,0x10,0x10,0xfe,0x21,0x28,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36722 0x8f72 "轲" */
+0x20,0x20,0x21,0xfc,0x40,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x50,0x10,0x10,0x10,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 36723 0x8f73 "轳" */
+0x20,0x20,0x20,0xfc,0x40,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x12,0x12,0x14,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,
+/* 36724 0x8f74 "轴" */
+0x20,0x20,0x20,0xfc,0x41,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 36725 0x8f75 "轵" */
+0x20,0x20,0x21,0xfd,0x41,0x51,0x91,0xfd,0x11,0x11,0x1c,0xf0,0x50,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 36726 0x8f76 "轶" */
+0x20,0x20,0x21,0xfd,0x41,0x51,0x92,0xfc,0x13,0x10,0x1c,0xf0,0x50,0x10,0x11,0x12,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 36727 0x8f77 "轷" */
+0x20,0x20,0x23,0xfc,0x41,0x50,0x90,0xfc,0x13,0x10,0x1c,0xf0,0x50,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 36728 0x8f78 "轸" */
+0x20,0x20,0x20,0xfc,0x41,0x52,0x90,0xfc,0x11,0x10,0x1c,0xf0,0x51,0x10,0x10,0x13,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 36729 0x8f79 "轹" */
+0x20,0x20,0x21,0xfd,0x41,0x51,0x91,0xfd,0x10,0x10,0x1c,0xf0,0x51,0x12,0x10,0x10,
+0x08,0x1c,0xe0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 36730 0x8f7a "轺" */
+0x10,0x11,0x10,0xfe,0x20,0x28,0x48,0x7e,0x09,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 36731 0x8f7b "轻" */
+0x20,0x21,0x20,0xfc,0x40,0x50,0x90,0xff,0x10,0x11,0x1c,0xf0,0x50,0x10,0x13,0x10,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36732 0x8f7c "轼" */
+0x20,0x20,0x20,0xfc,0x41,0x50,0x90,0xfd,0x10,0x10,0x1c,0xf0,0x50,0x13,0x10,0x10,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x90,0x90,0x90,0x88,0xea,0x8a,0x06,0x02,
+/* 36733 0x8f7d "载" */
+0x08,0x08,0x7f,0x08,0xff,0x10,0x10,0xff,0x20,0x48,0x7f,0x08,0x0f,0xf8,0x08,0x08,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 36734 0x8f7e "轾" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x08,0x0e,0xf8,0x48,0x08,0x09,0x08,
+0x00,0xfe,0x10,0x20,0x44,0x82,0xfe,0x12,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 36735 0x8f7f "轿" */
+0x20,0x20,0x21,0xfc,0x40,0x53,0x90,0xfc,0x11,0x12,0x1c,0xf0,0x50,0x11,0x11,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 36736 0x8f80 "辀" */
+0x20,0x20,0x20,0xfc,0x40,0x50,0x90,0xfd,0x10,0x10,0x1c,0xf0,0x50,0x11,0x11,0x12,
+0x10,0x20,0xfc,0x84,0xa4,0x94,0x94,0xfe,0x84,0xa4,0x94,0x94,0x84,0x04,0x14,0x08,
+/* 36737 0x8f81 "辁" */
+0x20,0x20,0x20,0xfc,0x41,0x52,0x91,0xfc,0x10,0x10,0x1d,0xf0,0x50,0x10,0x13,0x10,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 36738 0x8f82 "辂" */
+0x10,0x10,0x10,0xfe,0x21,0x28,0x48,0x7e,0x09,0x08,0x0e,0xf8,0x48,0x08,0x08,0x08,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 36739 0x8f83 "较" */
+0x20,0x20,0x20,0xfd,0x40,0x50,0x91,0xfe,0x10,0x10,0x1c,0xf0,0x50,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 36740 0x8f84 "辄" */
+0x20,0x23,0x21,0xfd,0x41,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x13,0x10,0x10,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 36741 0x8f85 "辅" */
+0x20,0x20,0x23,0xfc,0x40,0x51,0x91,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 36742 0x8f86 "辆" */
+0x20,0x23,0x20,0xfc,0x40,0x53,0x92,0xfe,0x12,0x12,0x1e,0xf3,0x52,0x12,0x12,0x12,
+0x00,0xfe,0x50,0x50,0x50,0xfe,0x52,0x52,0x52,0xaa,0xa6,0x02,0x02,0x02,0x0a,0x04,
+/* 36743 0x8f87 "辇" */
+0x08,0x08,0x7e,0x08,0xfe,0x14,0x22,0x42,0xbf,0x05,0x09,0x1f,0x01,0xff,0x01,0x01,
+0x20,0x20,0xfc,0x20,0xfe,0x50,0x88,0x06,0xf8,0x00,0x00,0xf0,0x00,0xfe,0x00,0x00,
+/* 36744 0x8f88 "辈" */
+0x04,0x7c,0x04,0x3c,0x04,0x7c,0x06,0x02,0x3f,0x05,0x09,0x1f,0x01,0xff,0x01,0x01,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x00,0xf8,0x00,0x00,0xf0,0x00,0xfe,0x00,0x00,
+/* 36745 0x8f89 "辉" */
+0x10,0x13,0x92,0x54,0x58,0x13,0xfc,0x28,0x29,0x29,0x28,0x28,0x2b,0x4c,0x48,0x80,
+0x00,0xfe,0x02,0x44,0x40,0xfc,0x80,0xa0,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 36746 0x8f8a "辊" */
+0x20,0x21,0x21,0xfd,0x41,0x51,0x91,0xfd,0x10,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 36747 0x8f8b "辋" */
+0x20,0x23,0x22,0xfa,0x42,0x53,0x92,0xfe,0x13,0x12,0x1e,0xf2,0x52,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 36748 0x8f8c "辌" */
+0x20,0x20,0x23,0xfc,0x40,0x51,0x91,0xfd,0x11,0x10,0x1d,0xf1,0x52,0x14,0x10,0x10,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 36749 0x8f8d "辍" */
+0x20,0x23,0x20,0xfd,0x40,0x51,0x92,0xfc,0x10,0x13,0x1c,0xf1,0x50,0x11,0x12,0x14,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 36750 0x8f8e "辎" */
+0x20,0x20,0x21,0xfa,0x41,0x50,0x90,0xfc,0x11,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 36751 0x8f8f "辏" */
+0x20,0x20,0x23,0xfc,0x41,0x50,0x93,0xfc,0x11,0x12,0x1c,0xf1,0x50,0x10,0x10,0x13,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x20,0xfc,0x20,0x50,0x88,0x04,
+/* 36752 0x8f90 "辐" */
+0x20,0x21,0x20,0xfc,0x40,0x50,0x90,0xfc,0x11,0x11,0x1d,0xf1,0x51,0x11,0x11,0x11,
+0x00,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 36753 0x8f91 "辑" */
+0x20,0x21,0x21,0xfd,0x41,0x50,0x97,0xfd,0x11,0x11,0x1d,0xf1,0x51,0x17,0x10,0x10,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x08,0xf8,0x08,0xf8,0x08,0x3e,0xc8,0x08,0x08,
+/* 36754 0x8f92 "辒" */
+0x10,0x10,0x10,0xfe,0x20,0x28,0x48,0x7e,0x08,0x09,0x0f,0xf9,0x49,0x09,0x0b,0x08,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 36755 0x8f93 "输" */
+0x20,0x20,0x21,0xfa,0x25,0x40,0x53,0x92,0xfa,0x13,0x1a,0xf2,0x53,0x12,0x12,0x12,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 36756 0x8f94 "辔" */
+0x22,0x22,0x47,0x8a,0xf5,0x27,0x41,0xf9,0x07,0x19,0xe1,0x3f,0x20,0x20,0x3f,0x20,
+0x08,0x08,0xd0,0x22,0x3c,0xc8,0x10,0x3e,0xc0,0x3e,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 36757 0x8f95 "辕" */
+0x20,0x20,0x21,0xfc,0x43,0x50,0x91,0xfd,0x11,0x11,0x1c,0xf0,0x51,0x16,0x10,0x10,
+0x20,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x52,0x94,0x88,0xa4,0xc2,0x80,
+/* 36758 0x8f96 "辖" */
+0x20,0x20,0x23,0xfe,0x44,0x51,0x90,0xfd,0x10,0x13,0x1c,0xf1,0x51,0x11,0x11,0x11,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 36759 0x8f97 "辗" */
+0x20,0x23,0x22,0xfa,0x43,0x52,0x92,0xfe,0x12,0x12,0x1f,0xf2,0x52,0x14,0x14,0x18,
+0x00,0xfc,0x04,0x04,0xfc,0x48,0x48,0xfc,0x48,0x48,0xfe,0xa4,0xa8,0x90,0xc8,0x86,
+/* 36760 0x8f98 "辘" */
+0x20,0x20,0x23,0xfa,0x42,0x53,0x92,0xfe,0x13,0x12,0x1e,0xf2,0x52,0x14,0x14,0x18,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 36761 0x8f99 "辙" */
+0x22,0x21,0x27,0xfa,0x24,0x4f,0x50,0x97,0xfc,0x17,0x1c,0xf7,0x54,0x14,0x14,0x15,
+0x08,0x08,0xc8,0x10,0x9e,0xd4,0x64,0x94,0x94,0x94,0x94,0x88,0x88,0x94,0xa4,0xc2,
+/* 36762 0x8f9a "辚" */
+0x20,0x21,0x20,0xfb,0x20,0x41,0x52,0x91,0xf9,0x11,0x1a,0xf5,0x50,0x11,0x12,0x14,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 36763 0x8f9b "辛" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x01,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 36764 0x8f9c "辜" */
+0x01,0x7f,0x01,0x1f,0x10,0x1f,0x01,0x3f,0x08,0x04,0xff,0x01,0x3f,0x01,0x01,0x01,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x20,0x40,0xfe,0x00,0xf8,0x00,0x00,0x00,
+/* 36765 0x8f9d "辝" */
+0x10,0x10,0x20,0x29,0x44,0xfe,0x42,0x01,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x20,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 36766 0x8f9e "辞" */
+0x08,0x1c,0x71,0x10,0x10,0xfc,0x13,0x10,0x7c,0x44,0x45,0x44,0x44,0x7c,0x44,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 36767 0x8f9f "辟" */
+0x00,0x7c,0x44,0x45,0x44,0x7c,0x40,0x41,0x7c,0x64,0xa5,0xa4,0x24,0x3c,0x24,0x00,
+0x40,0x20,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 36768 0x8fa0 "辠" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x01,0x3f,0x08,0xff,0x01,0x3f,0x01,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x20,0xfe,0x00,0xf8,0x00,0x00,
+/* 36769 0x8fa1 "辡" */
+0x20,0x10,0x10,0xfd,0x00,0x44,0x28,0xfd,0x10,0x10,0xfd,0x10,0x20,0x20,0x40,0x80,
+0x40,0x20,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 36770 0x8fa2 "辢" */
+0x10,0x10,0xfe,0x11,0x10,0xfe,0x92,0x93,0xfe,0x10,0x39,0x54,0x92,0x10,0x10,0x10,
+0x40,0x20,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 36771 0x8fa3 "辣" */
+0x20,0x10,0x11,0xfc,0x00,0x45,0x29,0xfd,0x11,0x10,0xfc,0x10,0x21,0x22,0x40,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 36772 0x8fa4 "辤" */
+0x04,0x1e,0xe0,0x22,0x92,0x54,0xfe,0x82,0x00,0x7c,0x04,0x68,0x10,0x28,0x44,0x82,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,
+/* 36773 0x8fa5 "辥" */
+0x08,0x4a,0x52,0x7e,0x24,0x48,0xbe,0x22,0x22,0x3e,0x20,0x3e,0x22,0x22,0x3e,0x22,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,
+/* 36774 0x8fa6 "辦" */
+0x42,0x22,0x22,0xfa,0x07,0x52,0x22,0xfa,0x22,0x22,0x72,0x22,0x24,0x44,0x4a,0x91,
+0x10,0x08,0x08,0x3e,0x80,0x94,0x88,0xbe,0x88,0x88,0x9c,0x88,0x88,0x88,0x88,0x08,
+/* 36775 0x8fa7 "辧" */
+0x40,0x20,0x27,0xfa,0x02,0x52,0x22,0xfa,0x22,0x22,0x72,0x22,0x24,0x44,0x4a,0x91,
+0x10,0x08,0x88,0xbe,0x80,0x94,0x88,0xbe,0x88,0x88,0x9c,0x88,0x88,0x88,0x88,0x08,
+/* 36776 0x8fa8 "辨" */
+0x20,0x10,0x10,0x7c,0x00,0x2a,0x12,0xfe,0x12,0x10,0x7c,0x11,0x11,0x22,0x24,0x40,
+0x10,0x88,0x88,0xbe,0x80,0x94,0x88,0xbe,0x88,0x88,0x9c,0x08,0x08,0x08,0x08,0x08,
+/* 36777 0x8fa9 "辩" */
+0x20,0x12,0x11,0x7d,0x00,0x2b,0x11,0xfd,0x11,0x11,0x7d,0x11,0x11,0x21,0x20,0x40,
+0x10,0x08,0x08,0x3e,0x00,0x14,0x08,0x3e,0x08,0x08,0x1c,0x48,0x88,0x08,0x08,0x08,
+/* 36778 0x8faa "辪" */
+0x08,0x4f,0x48,0x48,0xff,0x08,0x10,0x7e,0x42,0x7e,0x40,0x7f,0x41,0x7f,0x41,0x00,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,
+/* 36779 0x8fab "辫" */
+0x20,0x10,0x10,0x7d,0x01,0x2b,0x10,0xfc,0x11,0x13,0x7c,0x10,0x10,0x23,0x20,0x40,
+0x10,0x88,0x88,0x3e,0x40,0xd4,0x88,0xbe,0x08,0xc8,0x1c,0x08,0xc8,0x08,0x08,0x08,
+/* 36780 0x8fac "辬" */
+0x40,0x22,0x21,0xf9,0x00,0x57,0x20,0xfc,0x22,0x21,0x71,0x22,0x22,0x44,0x48,0x80,
+0x10,0x08,0x08,0x3e,0x00,0xd4,0x88,0xbe,0x88,0x08,0x1c,0x88,0x88,0x88,0x08,0x08,
+/* 36781 0x8fad "辭" */
+0x0f,0xf0,0x49,0x22,0xfe,0x14,0x08,0xff,0x95,0xbd,0x83,0xbd,0x95,0x89,0x95,0xa3,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x28,0xfe,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,
+/* 36782 0x8fae "辮" */
+0x41,0x21,0x22,0xfa,0x07,0x51,0x21,0xfa,0x27,0x21,0x71,0x25,0x25,0x49,0x45,0x82,
+0x10,0x08,0x88,0xbe,0x80,0x14,0x08,0xbe,0xc8,0x48,0x1c,0x88,0x48,0x48,0x08,0x08,
+/* 36783 0x8faf "辯" */
+0x42,0x21,0x20,0xfb,0x00,0x53,0x20,0xfb,0x20,0x23,0x72,0x22,0x22,0x43,0x42,0x80,
+0x10,0x08,0x08,0xbe,0x00,0x94,0x08,0xbe,0x08,0x88,0x9c,0x88,0x88,0x88,0x88,0x08,
+/* 36784 0x8fb0 "辰" */
+0x00,0x3f,0x20,0x20,0x2f,0x20,0x20,0x3f,0x24,0x24,0x24,0x24,0x44,0x45,0x86,0x04,
+0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0x80,0x88,0x50,0x20,0x10,0x08,0x06,0x00,
+/* 36785 0x8fb1 "辱" */
+0x00,0x3f,0x20,0x2f,0x20,0x3f,0x28,0x48,0x4a,0x8c,0x00,0xff,0x08,0x04,0x04,0x00,
+0x00,0xfc,0x00,0xf8,0x00,0xfe,0x88,0x50,0x30,0x0e,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 36786 0x8fb2 "農" */
+0x04,0x3f,0x24,0x3f,0x24,0x3f,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x28,0x48,0x4a,0x8c,
+0x40,0xf8,0x48,0xf8,0x48,0xf8,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x88,0x50,0x30,0x0e,
+/* 36787 0x8fb3 "辳" */
+0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc8,0x3f,0x20,0x2f,0x20,0x3f,0x28,0x48,0x4a,0x8c,
+0x20,0x20,0xfc,0x20,0x70,0xa8,0x24,0xfc,0x00,0xf8,0x00,0xfe,0x88,0x50,0x30,0x0e,
+/* 36788 0x8fb4 "辴" */
+0x00,0xee,0xaa,0xaa,0xee,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x11,0x11,0x12,
+0x00,0xfe,0x80,0x80,0xbc,0x80,0x80,0xfe,0xa0,0xb2,0xb4,0xa8,0xa8,0x24,0x32,0x20,
+/* 36789 0x8fb5 "辵" */
+0x00,0x03,0x7c,0x00,0x03,0x3c,0x00,0x07,0x78,0x01,0x11,0x11,0x11,0x29,0x47,0x80,
+0x38,0xc0,0x00,0x38,0xc0,0x0c,0x70,0x80,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 36790 0x8fb6 "辶" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 36791 0x8fb7 "辷" */
+0x00,0x20,0x10,0x10,0x00,0x07,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 36792 0x8fb8 "辸" */
+0x00,0x20,0x17,0x11,0x01,0x01,0xf1,0x11,0x11,0x12,0x12,0x14,0x18,0x28,0x47,0x00,
+0x00,0x00,0xf8,0x08,0x10,0x20,0x3c,0x04,0x04,0x04,0x04,0x28,0x10,0x00,0xfe,0x00,
+/* 36793 0x8fb9 "边" */
+0x00,0x20,0x10,0x13,0x00,0x00,0xf0,0x10,0x10,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x84,0x84,0x04,0x04,0x28,0x10,0x00,0xfe,0x00,
+/* 36794 0x8fba "辺" */
+0x00,0x20,0x17,0x10,0x00,0x00,0xf0,0x10,0x10,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,0x00,0xfe,0x00,
+/* 36795 0x8fbb "辻" */
+0x00,0x20,0x10,0x10,0x00,0x07,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 36796 0x8fbc "込" */
+0x02,0x21,0x10,0x10,0x00,0x00,0xf0,0x11,0x11,0x12,0x14,0x18,0x10,0x28,0x47,0x00,
+0x00,0x00,0x80,0x40,0x40,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,0x00,0x00,0xfe,0x00,
+/* 36797 0x8fbd "辽" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x11,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x10,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0xfe,0x00,
+/* 36798 0x8fbe "达" */
+0x00,0x20,0x10,0x10,0x07,0x00,0xf0,0x10,0x10,0x11,0x12,0x14,0x10,0x28,0x47,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0x90,0x08,0x04,0x04,0x00,0x00,0xfe,0x00,
+/* 36799 0x8fbf "辿" */
+0x00,0x20,0x10,0x14,0x04,0x04,0xf4,0x14,0x14,0x14,0x17,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0x40,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 36800 0x8fc0 "迀" */
+0x00,0x21,0x10,0x10,0x00,0x00,0xf3,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 36801 0x8fc1 "迁" */
+0x00,0x20,0x13,0x10,0x00,0x00,0xf7,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x10,0x78,0xc0,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 36802 0x8fc2 "迂" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf7,0x10,0x10,0x10,0x10,0x10,0x11,0x28,0x47,0x00,
+0x00,0xf8,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0xfe,0x00,
+/* 36803 0x8fc3 "迃" */
+0x00,0x23,0x10,0x10,0x07,0x00,0xf1,0x11,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x00,0x00,0xfe,0x80,0x00,0xf8,0x08,0x08,0x08,0x50,0x20,0x00,0xfe,0x00,
+/* 36804 0x8fc4 "迄" */
+0x01,0x21,0x11,0x12,0x04,0x01,0xf0,0x10,0x10,0x11,0x11,0x10,0x10,0x28,0x47,0x00,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x10,0x60,0x80,0x04,0x04,0xfc,0x00,0x00,0xfe,0x00,
+/* 36805 0x8fc5 "迅" */
+0x00,0x4f,0x22,0x22,0x02,0x02,0xef,0x22,0x22,0x22,0x22,0x22,0x22,0x50,0x8f,0x00,
+0x00,0xe0,0x20,0x20,0x20,0x20,0xa0,0x20,0x24,0x14,0x14,0x0c,0x04,0x00,0xfe,0x00,
+/* 36806 0x8fc6 "迆" */
+0x00,0x20,0x10,0x12,0x02,0x07,0xf2,0x12,0x12,0x12,0x12,0x11,0x10,0x28,0x47,0x00,
+0x40,0x40,0x40,0x58,0xe8,0x48,0x48,0x68,0x54,0x44,0x04,0xfc,0x00,0x00,0xfe,0x00,
+/* 36807 0x8fc7 "过" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf2,0x11,0x11,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,0x00,0xfe,0x00,
+/* 36808 0x8fc8 "迈" */
+0x00,0x20,0x17,0x10,0x00,0x00,0xf0,0x10,0x10,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0x00,0xfe,0x80,0x80,0xfc,0x84,0x84,0x84,0x04,0x04,0x28,0x10,0x00,0xfe,0x00,
+/* 36809 0x8fc9 "迉" */
+0x00,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 36810 0x8fca "迊" */
+0x00,0x4f,0x20,0x20,0x07,0x04,0xe4,0x24,0x24,0x24,0x24,0x20,0x20,0x50,0x8f,0x00,
+0x00,0xfe,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,0x00,0xfe,0x00,
+/* 36811 0x8fcb "迋" */
+0x00,0x27,0x10,0x10,0x00,0x00,0xf3,0x10,0x10,0x10,0x10,0x17,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 36812 0x8fcc "迌" */
+0x00,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36813 0x8fcd "迍" */
+0x00,0x20,0x17,0x10,0x02,0x02,0xf2,0x13,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0xf8,0x44,0x44,0x44,0x3c,0x00,0x00,0xfe,0x00,
+/* 36814 0x8fce "迎" */
+0x00,0x20,0x13,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x13,0x12,0x10,0x28,0x47,0x00,
+0x00,0x80,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0xb4,0x28,0x20,0x20,0x20,0xfe,0x00,
+/* 36815 0x8fcf "迏" */
+0x00,0x20,0x10,0x10,0x07,0x00,0xf0,0x10,0x10,0x11,0x12,0x14,0x10,0x28,0x47,0x00,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0xa0,0x90,0x08,0x44,0x24,0x20,0x00,0xfe,0x00,
+/* 36816 0x8fd0 "运" */
+0x00,0x23,0x10,0x10,0x00,0x07,0xf0,0x10,0x11,0x12,0x17,0x12,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x00,0x00,0x00,0xfc,0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 36817 0x8fd1 "近" */
+0x00,0x20,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x11,0x12,0x12,0x14,0x28,0x47,0x00,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 36818 0x8fd2 "迒" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf1,0x11,0x11,0x11,0x12,0x12,0x14,0x28,0x47,0x00,
+0x80,0x40,0x40,0xfe,0x00,0x00,0xf0,0x10,0x10,0x10,0x12,0x12,0x0e,0x00,0xfe,0x00,
+/* 36819 0x8fd3 "迓" */
+0x00,0x23,0x10,0x11,0x01,0x02,0xf3,0x10,0x10,0x10,0x11,0x16,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x10,0x10,0x10,0x10,0xfe,0x30,0x50,0x90,0x10,0x50,0x20,0x00,0xfe,0x00,
+/* 36820 0x8fd4 "返" */
+0x00,0x20,0x13,0x12,0x02,0x03,0xf2,0x12,0x12,0x12,0x12,0x14,0x15,0x28,0x47,0x00,
+0x08,0x3c,0xc0,0x00,0x00,0xfc,0x04,0x88,0x50,0x20,0x50,0x88,0x04,0x00,0xfe,0x00,
+/* 36821 0x8fd5 "迕" */
+0x00,0x20,0x10,0x11,0x01,0x02,0xf0,0x10,0x17,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x80,0x80,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 36822 0x8fd6 "迖" */
+0x00,0x20,0x10,0x10,0x07,0x00,0xf0,0x10,0x10,0x11,0x12,0x14,0x10,0x28,0x47,0x00,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0xa0,0x90,0x08,0x04,0x04,0x00,0x00,0xfe,0x00,
+/* 36823 0x8fd7 "迗" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf7,0x10,0x10,0x10,0x11,0x12,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x40,0xa0,0x90,0x08,0x04,0x04,0x00,0xfe,0x00,
+/* 36824 0x8fd8 "还" */
+0x00,0x23,0x10,0x10,0x00,0x00,0xf0,0x11,0x12,0x14,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x20,0x20,0x40,0x40,0xd0,0x48,0x44,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 36825 0x8fd9 "这" */
+0x00,0x20,0x10,0x17,0x00,0x02,0xf1,0x10,0x10,0x10,0x11,0x12,0x14,0x28,0x47,0x00,
+0x80,0x40,0x40,0xfc,0x10,0x10,0x20,0xa0,0x40,0xa0,0x10,0x08,0x08,0x00,0xfe,0x00,
+/* 36826 0x8fda "迚" */
+0x00,0x20,0x10,0x17,0x04,0x04,0xf4,0x14,0x17,0x14,0x10,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 36827 0x8fdb "进" */
+0x00,0x20,0x10,0x13,0x00,0x00,0xf0,0x17,0x10,0x10,0x11,0x11,0x12,0x28,0x47,0x00,
+0x90,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x90,0x90,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 36828 0x8fdc "远" */
+0x00,0x23,0x10,0x10,0x00,0x07,0xf1,0x11,0x11,0x11,0x11,0x12,0x12,0x14,0x28,0x47,
+0x00,0xf8,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x24,0x24,0x24,0x1c,0x00,0xfe,
+/* 36829 0x8fdd "违" */
+0x00,0x40,0x2f,0x20,0x00,0x07,0xe0,0x20,0x2f,0x20,0x20,0x20,0x20,0x50,0x8f,0x00,
+0x80,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfc,0x84,0x84,0x94,0x88,0x80,0xfe,0x00,
+/* 36830 0x8fde "连" */
+0x00,0x20,0x17,0x10,0x00,0x01,0xf3,0x10,0x10,0x10,0x17,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 36831 0x8fdf "迟" */
+0x00,0x21,0x11,0x11,0x01,0x01,0xf1,0x11,0x11,0x12,0x12,0x14,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x20,0x10,0x08,0x04,0x04,0x00,0x00,0xfe,0x00,
+/* 36832 0x8fe0 "迠" */
+0x00,0x20,0x10,0x10,0x00,0x00,0xf3,0x12,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x40,0x40,0x40,0x7e,0x40,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 36833 0x8fe1 "迡" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,0xfe,0x00,
+/* 36834 0x8fe2 "迢" */
+0x00,0x23,0x10,0x10,0x00,0x01,0xf2,0x11,0x11,0x11,0x11,0x11,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x84,0x84,0x84,0x14,0x08,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x00,
+/* 36835 0x8fe3 "迣" */
+0x00,0x22,0x12,0x12,0x07,0x02,0xf2,0x12,0x12,0x12,0x12,0x13,0x10,0x28,0x47,0x00,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0x00,0xfe,0x00,0x00,0xfe,0x00,
+/* 36836 0x8fe4 "迤" */
+0x02,0x22,0x13,0x14,0x04,0x0a,0xf2,0x17,0x12,0x12,0x12,0x12,0x11,0x28,0x47,0x00,
+0x00,0x00,0xfc,0x40,0x40,0x58,0xe8,0x48,0x68,0x50,0x44,0x04,0xfc,0x00,0xfe,0x00,
+/* 36837 0x8fe5 "迥" */
+0x00,0x23,0x12,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x28,0x47,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x94,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36838 0x8fe6 "迦" */
+0x04,0x44,0x24,0x2f,0x04,0x04,0xe4,0x24,0x24,0x28,0x28,0x32,0x21,0x50,0x8f,0x00,
+0x00,0x00,0x3c,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,0x00,0x00,0xfe,0x00,
+/* 36839 0x8fe7 "迧" */
+0x00,0x20,0x17,0x14,0x04,0x07,0xf4,0x14,0x17,0x14,0x10,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x00,0xfe,0x00,
+/* 36840 0x8fe8 "迨" */
+0x00,0x20,0x11,0x12,0x07,0x02,0xf0,0x13,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x80,0x80,0x10,0x08,0xfc,0x04,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36841 0x8fe9 "迩" */
+0x00,0x20,0x11,0x11,0x02,0x04,0xf0,0x11,0x11,0x12,0x14,0x10,0x10,0x28,0x47,0x00,
+0x80,0x80,0x00,0xfe,0x02,0x24,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,0x00,0xfe,0x00,
+/* 36842 0x8fea "迪" */
+0x00,0x40,0x20,0x27,0x04,0x04,0xe4,0x27,0x24,0x24,0x24,0x27,0x20,0x50,0x8f,0x00,
+0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0xfc,0x44,0x44,0x44,0xfc,0x00,0x00,0xfe,0x00,
+/* 36843 0x8feb "迫" */
+0x00,0x20,0x10,0x13,0x02,0x02,0xf2,0x13,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x40,0x40,0x80,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36844 0x8fec "迬" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf0,0x13,0x10,0x10,0x10,0x1f,0x10,0x28,0x47,0x00,
+0x80,0x40,0x00,0xfc,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,0x00,0xfe,0x00,
+/* 36845 0x8fed "迭" */
+0x00,0x22,0x12,0x13,0x02,0x04,0xf0,0x17,0x10,0x10,0x10,0x11,0x12,0x28,0x47,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0x90,0x08,0x08,0x00,0xfe,0x00,
+/* 36846 0x8fee "迮" */
+0x01,0x21,0x11,0x13,0x02,0x04,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0x00,0x00,0xfe,0x80,0x80,0xf8,0x80,0x80,0xfc,0x80,0x80,0x80,0x00,0xfe,0x00,
+/* 36847 0x8fef "迯" */
+0x01,0x21,0x11,0x11,0x02,0x02,0xf2,0x15,0x18,0x10,0x11,0x12,0x14,0x28,0x47,0x00,
+0x10,0x10,0x10,0xd0,0x58,0x54,0x52,0x52,0x90,0x90,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 36848 0x8ff0 "述" */
+0x00,0x20,0x10,0x10,0x07,0x00,0xf0,0x11,0x11,0x12,0x14,0x10,0x10,0x28,0x47,0x00,
+0x40,0x50,0x48,0x40,0xfc,0xc0,0xe0,0x50,0x48,0x44,0x44,0x40,0x40,0x00,0xfe,0x00,
+/* 36849 0x8ff1 "迱" */
+0x00,0x40,0x27,0x24,0x08,0x02,0xe2,0x22,0x23,0x22,0x22,0x21,0x20,0x50,0x8f,0x00,
+0x80,0x40,0xfc,0x04,0x08,0x00,0x10,0x60,0x80,0x04,0x04,0xfc,0x00,0x00,0xfe,0x00,
+/* 36850 0x8ff2 "迲" */
+0x00,0x20,0x10,0x13,0x00,0x00,0xf7,0x10,0x10,0x11,0x12,0x17,0x12,0x28,0x47,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xfe,0x40,0x80,0x10,0x08,0xfc,0x04,0x00,0xfe,0x00,
+/* 36851 0x8ff3 "迳" */
+0x00,0x23,0x10,0x10,0x00,0x01,0xf6,0x13,0x10,0x10,0x10,0x17,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x10,0x20,0x50,0x88,0x04,0xf8,0x40,0x40,0x40,0xfc,0x00,0x00,0xfe,0x00,
+/* 36852 0x8ff4 "迴" */
+0x00,0x23,0x12,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x13,0x12,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x94,0x94,0xf4,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 36853 0x8ff5 "迵" */
+0x00,0x23,0x12,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x28,0x47,0x00,
+0x00,0xfc,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0xf4,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36854 0x8ff6 "迶" */
+0x00,0x20,0x17,0x10,0x01,0x03,0xf5,0x19,0x11,0x11,0x11,0x11,0x11,0x28,0x47,0x00,
+0x40,0x40,0xfe,0x80,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36855 0x8ff7 "迷" */
+0x00,0x22,0x11,0x11,0x00,0x07,0xf0,0x10,0x11,0x12,0x14,0x10,0x10,0x28,0x47,0x00,
+0x40,0x48,0x48,0x50,0x40,0xfc,0x40,0xe0,0x50,0x48,0x44,0x40,0x40,0x00,0xfe,0x00,
+/* 36856 0x8ff8 "迸" */
+0x02,0x21,0x10,0x17,0x01,0x01,0xf1,0x17,0x11,0x11,0x12,0x12,0x14,0x28,0x47,0x00,
+0x08,0x10,0x00,0xfc,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x00,0xfe,0x00,
+/* 36857 0x8ff9 "迹" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf2,0x12,0x14,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x40,0x20,0x20,0xfe,0x90,0x90,0x94,0x92,0x92,0x10,0x10,0x50,0x20,0x00,0xfe,0x00,
+/* 36858 0x8ffa "迺" */
+0x00,0x4f,0x20,0x20,0x07,0x04,0xe4,0x24,0x25,0x26,0x24,0x27,0x24,0x50,0x8f,0x00,
+0x00,0xfe,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0x1c,0x04,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 36859 0x8ffb "迻" */
+0x00,0x20,0x11,0x16,0x01,0x00,0xf1,0x16,0x10,0x13,0x10,0x10,0x17,0x28,0x47,0x00,
+0x40,0x80,0xf8,0x10,0x20,0xc0,0x20,0x7c,0x84,0x48,0x30,0xc0,0x00,0x00,0xfe,0x00,
+/* 36860 0x8ffc "迼" */
+0x00,0x20,0x10,0x17,0x00,0x00,0xf3,0x10,0x10,0x13,0x12,0x12,0x13,0x12,0x28,0x47,
+0x40,0x40,0x40,0xfc,0x40,0x40,0xf8,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x00,0xfe,
+/* 36861 0x8ffd "追" */
+0x00,0x20,0x13,0x12,0x02,0x03,0xf2,0x12,0x13,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x20,0x40,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x02,0xfe,0x02,0x00,0xfe,0x00,
+/* 36862 0x8ffe "迾" */
+0x00,0x27,0x11,0x11,0x01,0x03,0xf2,0x12,0x15,0x10,0x10,0x11,0x12,0x14,0x28,0x47,
+0x04,0xe4,0x04,0x14,0x14,0xd4,0x54,0x54,0x54,0x94,0x94,0x04,0x14,0x08,0x00,0xfe,
+/* 36863 0x8fff "迿" */
+0x01,0x21,0x11,0x12,0x04,0x03,0xf2,0x12,0x13,0x12,0x12,0x13,0x10,0x10,0x28,0x47,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x28,0x10,0xfe,
+/* 36864 0x9000 "退" */
+0x03,0x22,0x12,0x13,0x02,0x02,0xf3,0x12,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x28,0x10,0x88,0x04,0x04,0x00,0xfe,0x00,
+/* 36865 0x9001 "送" */
+0x02,0x21,0x11,0x13,0x00,0x00,0xf0,0x17,0x10,0x10,0x10,0x11,0x12,0x28,0x47,0x00,
+0x08,0x08,0x10,0xfc,0x40,0x40,0x40,0xfe,0x40,0xa0,0x90,0x08,0x08,0x00,0xfe,0x00,
+/* 36866 0x9002 "适" */
+0x00,0x23,0x10,0x10,0x07,0x00,0xf0,0x13,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x78,0xc0,0x40,0x40,0xfe,0x40,0x40,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36867 0x9003 "逃" */
+0x00,0x20,0x14,0x12,0x01,0x00,0xf1,0x12,0x14,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0xa0,0xa0,0xa4,0xa8,0xb0,0xa0,0xb0,0xa8,0xa4,0x20,0x24,0x24,0x1c,0x00,0xfe,0x00,
+/* 36868 0x9004 "逄" */
+0x00,0x20,0x10,0x11,0x02,0x00,0xf1,0x16,0x10,0x11,0x10,0x12,0x13,0x10,0x28,0x47,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfe,
+/* 36869 0x9005 "逅" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x12,0x12,0x14,0x14,0x18,0x10,0x28,0x47,0x00,
+0x3c,0xc0,0x00,0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 36870 0x9006 "逆" */
+0x02,0x41,0x21,0x2f,0x00,0x00,0xe4,0x24,0x24,0x27,0x20,0x21,0x22,0x54,0x8f,0x00,
+0x08,0x08,0x10,0xfe,0x40,0x40,0x44,0x44,0x44,0xfc,0x84,0x00,0x00,0x00,0xfe,0x00,
+/* 36871 0x9007 "逇" */
+0x02,0x42,0x22,0x22,0x0f,0x02,0xe2,0x22,0x22,0x23,0x2e,0x24,0x20,0x50,0x8f,0x00,
+0x10,0x50,0x50,0x5c,0x74,0xd4,0x54,0x54,0x5c,0x50,0x42,0x42,0x3e,0x00,0xfe,0x00,
+/* 36872 0x9008 "逈" */
+0x00,0x20,0x13,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x28,0x47,0x00,
+0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36873 0x9009 "选" */
+0x00,0x22,0x12,0x13,0x04,0x00,0xf7,0x11,0x11,0x11,0x12,0x12,0x14,0x28,0x47,0x00,
+0x40,0x40,0x40,0xf8,0x40,0x40,0xfc,0x20,0x20,0x20,0x24,0x24,0x1c,0x00,0xfe,0x00,
+/* 36874 0x900a "逊" */
+0x00,0x4f,0x20,0x21,0x02,0x02,0xe3,0x22,0x26,0x2a,0x23,0x22,0x2a,0x24,0x50,0x8f,
+0x10,0x90,0x90,0x10,0x10,0xd8,0x54,0x54,0x92,0x92,0x12,0x10,0x50,0x20,0x00,0xfe,
+/* 36875 0x900b "逋" */
+0x00,0x40,0x2f,0x20,0x07,0x04,0xe7,0x24,0x27,0x24,0x24,0x24,0x24,0x50,0x8f,0x00,
+0x48,0x44,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x44,0x54,0x08,0x00,0xfe,0x00,
+/* 36876 0x900c "逌" */
+0x00,0x20,0x10,0x10,0x00,0x03,0xf2,0x13,0x12,0x13,0x12,0x13,0x12,0x28,0x47,0x00,
+0x40,0x40,0x7c,0x40,0x40,0xfc,0x04,0xf4,0x14,0xf4,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 36877 0x900d "逍" */
+0x00,0x22,0x11,0x11,0x00,0x03,0xf2,0x12,0x13,0x12,0x12,0x13,0x12,0x12,0x2a,0x47,
+0x40,0x48,0x48,0x50,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x28,0x10,0xfe,
+/* 36878 0x900e "逎" */
+0x00,0x27,0x10,0x10,0x03,0x02,0xf2,0x13,0x12,0x13,0x12,0x12,0x13,0x12,0x28,0x47,
+0x00,0xfe,0x90,0x90,0xfc,0x94,0x94,0x0c,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,0xfe,
+/* 36879 0x900f "透" */
+0x00,0x23,0x10,0x17,0x01,0x02,0xf4,0x13,0x11,0x11,0x11,0x12,0x14,0x28,0x47,0x00,
+0x38,0xc0,0x40,0xfc,0x50,0x48,0x46,0xf0,0x10,0x3c,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36880 0x9010 "逐" */
+0x00,0x23,0x10,0x10,0x01,0x06,0xf0,0x11,0x16,0x10,0x11,0x16,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x40,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x24,0x20,0xa0,0x40,0xfe,0x00,
+/* 36881 0x9011 "逑" */
+0x00,0x20,0x10,0x17,0x00,0x02,0xf1,0x10,0x11,0x12,0x14,0x11,0x10,0x28,0x47,0x00,
+0x40,0x50,0x48,0xfc,0x40,0x48,0x50,0xe0,0x50,0x48,0x44,0x40,0x80,0x00,0xfe,0x00,
+/* 36882 0x9012 "递" */
+0x01,0x20,0x13,0x10,0x00,0x03,0xf2,0x12,0x13,0x10,0x11,0x12,0x14,0x28,0x47,0x00,
+0x10,0xa0,0xf8,0x48,0x48,0xf8,0x40,0x40,0xfc,0xc4,0x44,0x54,0x48,0x40,0xfe,0x00,
+/* 36883 0x9013 "逓" */
+0x00,0x47,0x24,0x25,0x04,0x07,0xe4,0x24,0x25,0x25,0x25,0x29,0x29,0x30,0x50,0x8f,
+0x3c,0xe0,0x20,0xfc,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0x00,0xfe,
+/* 36884 0x9014 "途" */
+0x00,0x20,0x11,0x12,0x05,0x00,0xf0,0x17,0x10,0x12,0x12,0x14,0x11,0x28,0x47,0x00,
+0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x48,0x44,0x44,0x40,0x80,0xfe,0x00,
+/* 36885 0x9015 "逕" */
+0x00,0x27,0x10,0x12,0x04,0x02,0xf0,0x17,0x10,0x10,0x10,0x1f,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x00,0x48,0x90,0x48,0x00,0xfc,0x40,0x40,0x40,0xfe,0x00,0x00,0xfe,0x00,
+/* 36886 0x9016 "逖" */
+0x09,0x45,0x22,0x26,0x0a,0x02,0xe2,0x26,0x2a,0x32,0x22,0x2a,0x25,0x50,0x8f,0x00,
+0x10,0x10,0x10,0x52,0x52,0x54,0x90,0x28,0x24,0x44,0x42,0x82,0x00,0x00,0xfe,0x00,
+/* 36887 0x9017 "逗" */
+0x00,0x27,0x10,0x10,0x03,0x02,0xf2,0x13,0x10,0x12,0x11,0x17,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x00,0x08,0x10,0xfc,0x00,0x00,0xfe,0x00,
+/* 36888 0x9018 "逘" */
+0x00,0x21,0x12,0x17,0x01,0x01,0xf3,0x14,0x10,0x17,0x10,0x10,0x11,0x2a,0x47,0x00,
+0x80,0x00,0x08,0xfc,0x04,0x00,0xf8,0x40,0x40,0xfe,0x40,0xa0,0x10,0x08,0xfe,0x00,
+/* 36889 0x9019 "這" */
+0x00,0x20,0x17,0x10,0x03,0x00,0xf3,0x10,0x13,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x80,0x40,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36890 0x901a "通" */
+0x00,0x47,0x20,0x21,0x00,0x07,0xe4,0x24,0x27,0x24,0x24,0x27,0x24,0x24,0x54,0x8f,
+0x00,0xf8,0x10,0xa0,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x54,0x08,0xfe,
+/* 36891 0x901b "逛" */
+0x00,0x48,0x25,0x22,0x0d,0x01,0xe1,0x23,0x2d,0x21,0x21,0x2a,0x24,0x50,0x8f,0x00,
+0x00,0x80,0x7c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x7e,0x00,0x00,0xfe,0x00,
+/* 36892 0x901c "逜" */
+0x00,0x4f,0x20,0x20,0x07,0x01,0xe1,0x2f,0x20,0x27,0x24,0x24,0x27,0x50,0x8f,0x00,
+0x00,0xf8,0x80,0x80,0xf0,0x10,0x10,0xfc,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,
+/* 36893 0x901d "逝" */
+0x02,0x42,0x22,0x22,0x0f,0x02,0xe2,0x23,0x2e,0x22,0x22,0x2a,0x24,0x51,0x8f,0x00,
+0x08,0x1c,0x60,0x40,0xc0,0x7e,0xc8,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0xfe,0x00,
+/* 36894 0x901e "逞" */
+0x03,0x22,0x12,0x12,0x03,0x00,0xf7,0x10,0x10,0x13,0x10,0x10,0x17,0x28,0x47,0x00,
+0xf8,0x08,0x08,0x08,0xf8,0x00,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0xfe,0x00,
+/* 36895 0x901f "速" */
+0x00,0x20,0x17,0x10,0x03,0x02,0xf2,0x13,0x10,0x11,0x12,0x14,0x10,0x28,0x47,0x00,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0x48,0xf8,0xe0,0x50,0x48,0x44,0x40,0x00,0xfe,0x00,
+/* 36896 0x9020 "造" */
+0x00,0x22,0x13,0x14,0x00,0x07,0xf0,0x10,0x13,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x40,0x40,0xf8,0x40,0x40,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36897 0x9021 "逡" */
+0x00,0x21,0x12,0x17,0x00,0x01,0xf2,0x15,0x11,0x12,0x15,0x10,0x11,0x2e,0x47,0x00,
+0x80,0x10,0x08,0xfc,0x04,0x10,0x08,0x04,0xf8,0x08,0x90,0x60,0x90,0x08,0xfe,0x00,
+/* 36898 0x9022 "逢" */
+0x01,0x21,0x13,0x14,0x00,0x01,0xf6,0x10,0x13,0x10,0x13,0x10,0x17,0x10,0x28,0x47,
+0x00,0xf8,0x08,0x90,0x60,0x98,0x06,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x40,0x40,0xfe,
+/* 36899 0x9023 "連" */
+0x00,0x40,0x2f,0x20,0x07,0x04,0xe7,0x24,0x27,0x20,0x2f,0x20,0x20,0x50,0x8f,0x00,
+0x40,0x40,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x40,0xfe,0x40,0x40,0x40,0xfe,0x00,
+/* 36900 0x9024 "逤" */
+0x00,0x22,0x11,0x14,0x02,0x00,0xf0,0x11,0x16,0x12,0x12,0x12,0x10,0x28,0x47,0x00,
+0x10,0x10,0x10,0x54,0x52,0x92,0x10,0x14,0x04,0x08,0x10,0x20,0xc0,0x00,0xfe,0x00,
+/* 36901 0x9025 "逥" */
+0x00,0x23,0x12,0x12,0x02,0x02,0xf2,0x12,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x00,0xfc,0x94,0x94,0xf4,0x94,0x94,0xf4,0x94,0x94,0x94,0xfc,0x04,0x00,0xfe,0x00,
+/* 36902 0x9026 "逦" */
+0x00,0x4f,0x20,0x20,0x07,0x04,0xe4,0x26,0x25,0x24,0x24,0x24,0x25,0x50,0x8f,0x00,
+0x00,0xfe,0x00,0x00,0xbc,0xa4,0xa4,0xb4,0xac,0xa4,0xa4,0xa4,0xac,0x00,0xfe,0x00,
+/* 36903 0x9027 "逧" */
+0x01,0x22,0x14,0x10,0x01,0x02,0xf4,0x13,0x12,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x10,0x48,0x44,0xa0,0x10,0x08,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36904 0x9028 "逨" */
+0x00,0x20,0x17,0x10,0x01,0x01,0xf2,0x14,0x10,0x11,0x12,0x14,0x10,0x28,0x47,0x00,
+0x40,0x40,0xfc,0x40,0x50,0x50,0xe8,0x44,0xe0,0x50,0x48,0x44,0x40,0x00,0xfe,0x00,
+/* 36905 0x9029 "逩" */
+0x00,0x20,0x17,0x11,0x02,0x0c,0xf3,0x10,0x11,0x11,0x17,0x11,0x12,0x14,0x28,0x47,
+0x00,0x80,0xfc,0x10,0x48,0x46,0xf8,0x40,0x50,0x10,0xfe,0x10,0x10,0x10,0x10,0xfe,
+/* 36906 0x902a "逪" */
+0x01,0x21,0x17,0x11,0x01,0x0f,0xf0,0x13,0x12,0x13,0x12,0x13,0x12,0x28,0x47,0x00,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36907 0x902b "逫" */
+0x00,0x47,0x20,0x25,0x02,0x05,0xe8,0x27,0x20,0x25,0x22,0x25,0x28,0x50,0x8f,0x00,
+0x00,0xbc,0x84,0x28,0x10,0x28,0x40,0xbc,0x84,0x28,0x10,0x28,0x44,0x00,0xfe,0x00,
+/* 36908 0x902c "逬" */
+0x00,0x20,0x11,0x17,0x01,0x01,0xf1,0x11,0x17,0x11,0x11,0x11,0x11,0x2a,0x47,0x00,
+0x84,0x84,0x08,0xbc,0x08,0x08,0x08,0x08,0xbe,0x08,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 36909 0x902d "逭" */
+0x00,0x20,0x17,0x14,0x03,0x02,0xf2,0x13,0x12,0x13,0x12,0x12,0x13,0x28,0x47,0x00,
+0x80,0x40,0xfc,0x04,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,
+/* 36910 0x902e "逮" */
+0x00,0x20,0x13,0x10,0x07,0x00,0xf3,0x14,0x12,0x11,0x12,0x14,0x11,0x28,0x47,0x00,
+0x40,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x44,0x48,0x50,0x48,0x44,0x40,0x80,0xfe,0x00,
+/* 36911 0x902f "逯" */
+0x00,0x47,0x20,0x23,0x00,0x0f,0xe0,0x24,0x22,0x21,0x22,0x24,0x21,0x50,0x8f,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xfe,0x40,0x44,0xe8,0x50,0x48,0x44,0x40,0x80,0xfe,0x00,
+/* 36912 0x9030 "逰" */
+0x02,0x42,0x22,0x2f,0x02,0x02,0xe3,0x22,0x2e,0x22,0x22,0x22,0x2a,0x24,0x50,0x8f,
+0x20,0x20,0x3e,0x40,0x80,0x7c,0x04,0x08,0x7e,0x08,0x08,0x08,0x28,0x10,0x00,0xfe,
+/* 36913 0x9031 "週" */
+0x00,0x47,0x24,0x24,0x05,0x04,0xe7,0x24,0x25,0x25,0x25,0x24,0x28,0x50,0x8f,0x00,
+0x00,0xfc,0x44,0x44,0xf4,0x44,0xfc,0x04,0xf4,0x14,0xf4,0x04,0x0c,0x00,0xfe,0x00,
+/* 36914 0x9032 "進" */
+0x01,0x21,0x13,0x12,0x06,0x0b,0xf2,0x12,0x13,0x12,0x12,0x13,0x12,0x28,0x47,0x00,
+0x40,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x00,0xfe,0x00,
+/* 36915 0x9033 "逳" */
+0x00,0x20,0x17,0x11,0x02,0x07,0xf0,0x13,0x12,0x13,0x12,0x13,0x12,0x12,0x2a,0x47,
+0x80,0x40,0xfe,0x00,0x08,0xfc,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,0xfe,
+/* 36916 0x9034 "逴" */
+0x00,0x20,0x10,0x10,0x03,0x02,0xf3,0x12,0x13,0x10,0x1f,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0x7e,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,0x40,0x40,0xfe,0x00,
+/* 36917 0x9035 "逵" */
+0x00,0x20,0x13,0x10,0x00,0x07,0xf1,0x12,0x14,0x13,0x10,0x10,0x17,0x10,0x28,0x47,
+0x40,0x40,0xf8,0x40,0x40,0xfc,0x10,0x48,0x44,0xf8,0x40,0x40,0xfc,0x00,0x00,0xfe,
+/* 36918 0x9036 "逶" */
+0x00,0x23,0x10,0x17,0x01,0x02,0xf4,0x10,0x1f,0x11,0x13,0x10,0x11,0x16,0x28,0x47,
+0x38,0xc0,0x40,0xfc,0x50,0x48,0x44,0x80,0xfe,0x08,0x90,0x60,0x98,0x04,0x00,0xfe,
+/* 36919 0x9037 "逷" */
+0x00,0x23,0x12,0x13,0x02,0x03,0xf1,0x13,0x14,0x19,0x12,0x14,0x11,0x2a,0x47,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0x24,0x44,0xa8,0x10,0x00,0xfe,0x00,
+/* 36920 0x9038 "逸" */
+0x01,0x41,0x21,0x22,0x04,0x0f,0xe4,0x24,0x27,0x20,0x21,0x21,0x22,0x24,0x50,0x8f,
+0x00,0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfc,0xa0,0x30,0x2a,0x22,0x1e,0x00,0xfe,
+/* 36921 0x9039 "逹" */
+0x00,0x20,0x13,0x10,0x00,0x07,0xf1,0x10,0x13,0x10,0x10,0x17,0x10,0x10,0x28,0x47,
+0x40,0x40,0xf8,0x40,0x40,0xfc,0x10,0xa0,0xf8,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,
+/* 36922 0x903a "逺" */
+0x00,0x20,0x13,0x10,0x07,0x00,0xf1,0x13,0x10,0x11,0x16,0x10,0x10,0x28,0x47,0x00,
+0x40,0x40,0xf8,0x40,0xfe,0x80,0x10,0xe0,0x44,0xa8,0x90,0x88,0xc4,0x00,0xfe,0x00,
+/* 36923 0x903b "逻" */
+0x00,0x47,0x24,0x24,0x07,0x00,0xe1,0x22,0x25,0x20,0x20,0x21,0x2e,0x50,0x8f,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x80,0xf8,0x08,0x10,0xa0,0x40,0x80,0x00,0x00,0xfe,0x00,
+/* 36924 0x903c "逼" */
+0x00,0x27,0x10,0x13,0x02,0x03,0xf0,0x17,0x14,0x17,0x14,0x17,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,0x00,0xfe,0x00,
+/* 36925 0x903d "逽" */
+0x01,0x21,0x17,0x11,0x00,0x07,0xf0,0x11,0x13,0x15,0x19,0x11,0x11,0x28,0x47,0x00,
+0x08,0x08,0xfe,0x08,0x40,0xfe,0x80,0x00,0xfc,0x04,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 36926 0x903e "逾" */
+0x00,0x40,0x21,0x22,0x0d,0x00,0xe7,0x24,0x27,0x24,0x27,0x24,0x24,0x25,0x50,0x8f,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0x84,0xa4,0xa4,0xa4,0xa4,0x84,0x94,0x88,0x00,0xfe,
+/* 36927 0x903f "逿" */
+0x01,0x21,0x11,0x11,0x01,0x00,0xf7,0x11,0x13,0x14,0x11,0x12,0x10,0x28,0x47,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,0x00,0xfe,0x00,
+/* 36928 0x9040 "遀" */
+0x00,0x27,0x11,0x13,0x04,0x0b,0xf0,0x13,0x12,0x13,0x12,0x13,0x12,0x12,0x2a,0x47,
+0x80,0xfc,0x00,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x28,0x10,0xfe,
+/* 36929 0x9041 "遁" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x12,0x12,0x12,0x12,0x14,0x14,0x28,0x47,0x00,
+0x1e,0xe0,0x20,0x20,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x00,
+/* 36930 0x9042 "遂" */
+0x01,0x20,0x10,0x17,0x00,0x01,0xf6,0x10,0x11,0x16,0x10,0x11,0x16,0x28,0x47,0x00,
+0x10,0x90,0xa0,0xfc,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x24,0xa0,0x40,0xfe,0x00,
+/* 36931 0x9043 "遃" */
+0x00,0x20,0x13,0x10,0x01,0x00,0xf3,0x12,0x12,0x12,0x12,0x12,0x12,0x14,0x29,0x47,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xc8,0x10,0x24,0xc8,0x10,0x60,0x80,0xfe,
+/* 36932 0x9044 "遄" */
+0x00,0x44,0x24,0x24,0x07,0x00,0xef,0x20,0x27,0x24,0x24,0x24,0x24,0x24,0x50,0x8f,
+0x40,0x44,0x44,0x44,0xfc,0x00,0xfe,0x80,0xfc,0xa4,0xa4,0xa4,0xa4,0x0c,0x00,0xfe,
+/* 36933 0x9045 "遅" */
+0x00,0x4f,0x28,0x28,0x0f,0x09,0xe8,0x2f,0x28,0x2b,0x28,0x37,0x20,0x50,0x8f,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 36934 0x9046 "遆" */
+0x00,0x20,0x17,0x11,0x00,0x07,0xf4,0x10,0x13,0x12,0x12,0x12,0x12,0x10,0x28,0x47,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0x40,0xf8,0x48,0x48,0x68,0x50,0x40,0x40,0xfe,
+/* 36935 0x9047 "遇" */
+0x00,0x23,0x12,0x13,0x02,0x03,0xf0,0x17,0x14,0x14,0x14,0x15,0x14,0x14,0x28,0x47,
+0x00,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0x74,0x94,0x04,0x0c,0x00,0xfe,
+/* 36936 0x9048 "遈" */
+0x00,0x43,0x22,0x23,0x02,0x03,0xe0,0x2f,0x20,0x22,0x22,0x25,0x28,0x50,0x8f,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0x78,0x40,0x40,0xfe,0x00,0xfe,0x00,
+/* 36937 0x9049 "遉" */
+0x00,0x20,0x10,0x10,0x03,0x02,0xf3,0x12,0x13,0x12,0x13,0x10,0x11,0x2a,0x47,0x00,
+0x40,0x40,0x7c,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0xa0,0x10,0x08,0xfe,0x00,
+/* 36938 0x904a "遊" */
+0x04,0x42,0x2f,0x24,0x04,0x07,0xe4,0x24,0x24,0x24,0x24,0x28,0x29,0x50,0x8f,0x00,
+0x20,0x20,0xbe,0x40,0x3c,0x84,0x88,0x88,0xfe,0x88,0x88,0x88,0xa8,0x10,0xfe,0x00,
+/* 36939 0x904b "運" */
+0x00,0x27,0x14,0x13,0x00,0x03,0xf2,0x13,0x12,0x13,0x10,0x17,0x10,0x28,0x47,0x00,
+0x00,0xfc,0x44,0xf8,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 36940 0x904c "遌" */
+0x00,0x27,0x14,0x17,0x00,0x03,0xf0,0x17,0x11,0x11,0x10,0x10,0x10,0x28,0x47,0x00,
+0x00,0xbc,0xa4,0xbc,0x00,0xf8,0x00,0xfe,0x00,0xf8,0x08,0x08,0x50,0x20,0xfe,0x00,
+/* 36941 0x904d "遍" */
+0x00,0x20,0x13,0x12,0x02,0x03,0xf2,0x13,0x13,0x15,0x15,0x19,0x11,0x11,0x28,0x47,
+0x80,0x40,0xfc,0x04,0x04,0xfc,0x00,0xfc,0x54,0x54,0xfc,0x54,0x44,0x0c,0x00,0xfe,
+/* 36942 0x904e "過" */
+0x01,0x21,0x11,0x11,0x01,0x03,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x28,0x47,0x00,
+0xf8,0x08,0xe8,0x28,0x28,0xfc,0x04,0xf4,0x94,0xf4,0x04,0x14,0x08,0x00,0xfe,0x00,
+/* 36943 0x904f "遏" */
+0x00,0x23,0x12,0x13,0x02,0x03,0xf1,0x13,0x14,0x1a,0x12,0x13,0x10,0x28,0x47,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0x04,0xf4,0x14,0x08,0xfe,0x00,
+/* 36944 0x9050 "遐" */
+0x00,0x47,0x24,0x24,0x07,0x04,0xe4,0x27,0x24,0x24,0x27,0x24,0x24,0x54,0x8f,0x00,
+0x00,0xbc,0x84,0x84,0xbc,0x00,0x00,0xbc,0x04,0x04,0xa8,0x10,0x28,0x44,0xfe,0x00,
+/* 36945 0x9051 "遑" */
+0x00,0x20,0x13,0x12,0x03,0x02,0xf3,0x10,0x17,0x10,0x13,0x10,0x17,0x28,0x47,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x40,0xf8,0x40,0xfc,0x00,0xfe,0x00,
+/* 36946 0x9052 "遒" */
+0x02,0x41,0x2f,0x20,0x07,0x04,0xe4,0x25,0x26,0x24,0x27,0x24,0x27,0x50,0x8f,0x00,
+0x08,0x10,0xfe,0xa0,0xfc,0xa4,0xa4,0x24,0x1c,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,
+/* 36947 0x9053 "道" */
+0x02,0x21,0x10,0x17,0x00,0x03,0xf2,0x13,0x12,0x13,0x12,0x13,0x12,0x28,0x47,0x00,
+0x08,0x10,0x00,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 36948 0x9054 "達" */
+0x00,0x20,0x13,0x10,0x07,0x01,0xf0,0x17,0x10,0x13,0x10,0x17,0x10,0x28,0x47,0x00,
+0x40,0x40,0xf8,0x40,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0x40,0x40,0xfe,0x00,
+/* 36949 0x9055 "違" */
+0x00,0x20,0x13,0x10,0x07,0x00,0xf3,0x12,0x13,0x10,0x13,0x14,0x17,0x10,0x28,0x47,
+0x40,0x40,0xf8,0x88,0xfe,0x00,0xf8,0x08,0xf8,0x40,0xfc,0x40,0xfe,0x40,0x00,0xfe,
+/* 36950 0x9056 "遖" */
+0x00,0x40,0x2f,0x20,0x07,0x05,0xe4,0x25,0x24,0x25,0x24,0x24,0x24,0x50,0x8f,0x00,
+0x40,0x40,0xfe,0x40,0xfc,0x14,0xa4,0xf4,0x44,0xf4,0x44,0x54,0x48,0x00,0xfe,0x00,
+/* 36951 0x9057 "遗" */
+0x00,0x23,0x12,0x13,0x00,0x0f,0xf0,0x13,0x12,0x12,0x12,0x10,0x11,0x2a,0x47,0x00,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0x48,0x48,0xa0,0x10,0x08,0xfe,0x00,
+/* 36952 0x9058 "遘" */
+0x01,0x27,0x11,0x13,0x01,0x07,0xf0,0x13,0x12,0x13,0x12,0x17,0x12,0x12,0x2a,0x47,
+0x10,0xfc,0x10,0xf8,0x10,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xfe,0x08,0x28,0x10,0xfe,
+/* 36953 0x9059 "遙" */
+0x00,0x20,0x13,0x10,0x00,0x07,0xf1,0x12,0x10,0x17,0x10,0x12,0x13,0x28,0x47,0x00,
+0x40,0xfc,0x24,0x98,0xe0,0x00,0xf8,0x40,0x40,0xfc,0x40,0x44,0xfc,0x00,0xfe,0x00,
+/* 36954 0x905a "遚" */
+0x00,0x21,0x16,0x14,0x07,0x04,0xf7,0x10,0x17,0x10,0x11,0x10,0x11,0x16,0x28,0x47,
+0x40,0x40,0x5c,0x44,0x5c,0x44,0xfc,0x40,0xfc,0x08,0x90,0x60,0x98,0x04,0x00,0xfe,
+/* 36955 0x905b "遛" */
+0x00,0x47,0x24,0x25,0x04,0x05,0xe6,0x20,0x27,0x24,0x27,0x24,0x27,0x50,0x8f,0x00,
+0x80,0x7c,0x24,0x24,0xa4,0x54,0x48,0x80,0xfc,0x44,0xfc,0x44,0xfc,0x00,0xfe,0x00,
+/* 36956 0x905c "遜" */
+0x00,0x4f,0x20,0x21,0x02,0x02,0xe3,0x2e,0x22,0x22,0x22,0x2a,0x24,0x50,0x8f,0x00,
+0x06,0xb8,0x90,0x20,0x44,0x78,0x10,0x24,0x7e,0x12,0x54,0x92,0x50,0x20,0xfe,0x00,
+/* 36957 0x905d "遝" */
+0x00,0x27,0x14,0x14,0x07,0x00,0xf1,0x12,0x14,0x11,0x12,0x14,0x10,0x28,0x47,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0x40,0x50,0x48,0x44,0x50,0x48,0x44,0x40,0x00,0xfe,0x00,
+/* 36958 0x905e "遞" */
+0x00,0x47,0x24,0x24,0x05,0x05,0xe5,0x25,0x25,0x25,0x29,0x2a,0x32,0x25,0x50,0x8f,
+0x1e,0xe0,0x3c,0x20,0xfe,0x22,0x38,0xe2,0x1e,0x00,0x78,0x48,0x8a,0x06,0x00,0xfe,
+/* 36959 0x905f "遟" */
+0x00,0x23,0x12,0x12,0x03,0x02,0xf2,0x13,0x12,0x12,0x13,0x12,0x15,0x14,0x28,0x47,
+0x00,0xfc,0x04,0x04,0xfc,0x40,0x20,0xfc,0x88,0x50,0xfe,0x20,0xfc,0x20,0x20,0xfe,
+/* 36960 0x9060 "遠" */
+0x00,0x20,0x13,0x10,0x07,0x00,0xf3,0x12,0x13,0x10,0x11,0x12,0x14,0x10,0x28,0x47,
+0x40,0x40,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0xc4,0xa8,0x90,0x88,0x84,0x00,0xfe,
+/* 36961 0x9061 "遡" */
+0x04,0x22,0x12,0x10,0x07,0x01,0xf5,0x15,0x15,0x17,0x11,0x12,0x12,0x14,0x28,0x47,
+0x40,0x5e,0x92,0x12,0xd2,0x1e,0x52,0x52,0x52,0xde,0x52,0x12,0x22,0x2a,0x44,0xfe,
+/* 36962 0x9062 "遢" */
+0x00,0x23,0x12,0x13,0x02,0x03,0xf0,0x17,0x10,0x14,0x12,0x14,0x12,0x11,0x28,0x47,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xbc,0x84,0xa4,0x94,0xa4,0x94,0x08,0x00,0xfe,
+/* 36963 0x9063 "遣" */
+0x00,0x23,0x12,0x13,0x00,0x07,0xf0,0x13,0x12,0x13,0x12,0x13,0x12,0x13,0x28,0x47,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x08,0xf8,0x00,0xfe,
+/* 36964 0x9064 "遤" */
+0x00,0x23,0x12,0x13,0x02,0x03,0xf2,0x13,0x10,0x15,0x15,0x15,0x14,0x28,0x47,0x00,
+0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0xfc,0x04,0x54,0x54,0x54,0x28,0x10,0xfe,0x00,
+/* 36965 0x9065 "遥" */
+0x00,0x23,0x10,0x12,0x01,0x01,0xf2,0x10,0x13,0x10,0x11,0x11,0x11,0x11,0x28,0x47,
+0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,
+/* 36966 0x9066 "遦" */
+0x03,0x22,0x17,0x12,0x03,0x00,0xf3,0x12,0x13,0x12,0x13,0x12,0x13,0x11,0x2a,0x47,
+0xfc,0x44,0xfe,0x44,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,0xfe,
+/* 36967 0x9067 "遧" */
+0x00,0x47,0x21,0x2f,0x00,0x03,0xe2,0x23,0x22,0x23,0x20,0x2f,0x20,0x50,0x8f,0x00,
+0x40,0xfc,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x40,0x40,0xfe,0x00,
+/* 36968 0x9068 "遨" */
+0x02,0x42,0x2f,0x22,0x07,0x02,0xef,0x24,0x27,0x24,0x24,0x2a,0x29,0x50,0x8f,0x00,
+0x10,0x10,0x90,0x1e,0xa4,0x44,0x94,0x14,0x88,0x88,0x94,0xa2,0x42,0x00,0xfe,0x00,
+/* 36969 0x9069 "適" */
+0x00,0x40,0x27,0x21,0x00,0x07,0xe4,0x27,0x24,0x25,0x25,0x25,0x24,0x24,0x50,0x8f,
+0x80,0x40,0xfc,0x10,0xa0,0xfc,0x44,0xfc,0x44,0xf4,0x14,0xf4,0x04,0x0c,0x00,0xfe,
+/* 36970 0x906a "遪" */
+0x00,0x21,0x13,0x12,0x04,0x07,0xf0,0x13,0x1c,0x13,0x10,0x13,0x10,0x13,0x28,0x47,
+0x80,0x10,0xf8,0x10,0xa4,0xfc,0xa0,0x18,0x46,0x90,0x64,0x98,0x60,0x80,0x00,0xfe,
+/* 36971 0x906b "遫" */
+0x02,0x42,0x2f,0x22,0x0f,0x0a,0xea,0x2f,0x22,0x27,0x2a,0x32,0x22,0x50,0x8f,0x00,
+0x10,0x10,0x90,0x3e,0xa4,0xc4,0xa4,0x94,0x08,0x08,0x94,0x24,0x44,0x00,0xfe,0x00,
+/* 36972 0x906c "遬" */
+0x02,0x42,0x2f,0x22,0x0f,0x0a,0xea,0x2f,0x22,0x27,0x2a,0x32,0x22,0x50,0x8f,0x00,
+0x20,0x20,0xa0,0x3c,0xc4,0x90,0x90,0x90,0x10,0x28,0xa8,0x44,0x84,0x00,0xfe,0x00,
+/* 36973 0x906d "遭" */
+0x00,0x2f,0x10,0x17,0x04,0x07,0xf4,0x17,0x10,0x13,0x12,0x13,0x12,0x13,0x28,0x47,
+0xa0,0xfe,0xa0,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,
+/* 36974 0x906e "遮" */
+0x00,0x40,0x27,0x24,0x04,0x04,0xe7,0x24,0x24,0x24,0x28,0x2a,0x32,0x24,0x50,0x8f,
+0x40,0x20,0xfe,0x00,0x88,0x88,0xfe,0x88,0x88,0xf8,0x00,0xa4,0x52,0x52,0x00,0xfe,
+/* 36975 0x906f "遯" */
+0x00,0x47,0x25,0x25,0x07,0x05,0xe5,0x27,0x25,0x25,0x25,0x25,0x2b,0x50,0x8f,0x00,
+0x00,0x7e,0x10,0x30,0x4a,0x9a,0x2c,0x4c,0x9a,0x2a,0x4a,0xa8,0x10,0x00,0xfe,0x00,
+/* 36976 0x9070 "遰" */
+0x02,0x22,0x17,0x12,0x04,0x08,0xf7,0x14,0x10,0x13,0x12,0x12,0x12,0x28,0x47,0x00,
+0xa8,0xa8,0xfc,0xaa,0xe6,0x00,0xfc,0x44,0x40,0xf8,0x48,0x48,0x58,0x40,0xfe,0x00,
+/* 36977 0x9071 "遱" */
+0x00,0x43,0x22,0x2f,0x02,0x03,0xe0,0x23,0x22,0x23,0x20,0x2f,0x21,0x20,0x53,0x8f,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0xf8,0x48,0xf8,0x80,0xfe,0x10,0xe0,0x18,0xfe,
+/* 36978 0x9072 "遲" */
+0x07,0x44,0x27,0x24,0x04,0x04,0xe4,0x25,0x24,0x24,0x25,0x24,0x2b,0x28,0x50,0x8f,
+0xfc,0x04,0xfc,0x20,0xa8,0x70,0xa8,0x04,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfe,
+/* 36979 0x9073 "遳" */
+0x01,0x21,0x17,0x11,0x00,0x02,0xf2,0x15,0x10,0x13,0x10,0x10,0x17,0x28,0x47,0x00,
+0x10,0x10,0xfc,0x10,0x40,0x48,0x48,0x54,0x40,0xf8,0x40,0x40,0xfc,0x00,0xfe,0x00,
+/* 36980 0x9074 "遴" */
+0x00,0x22,0x11,0x17,0x01,0x02,0xf4,0x12,0x13,0x14,0x1a,0x11,0x11,0x12,0x2a,0x47,
+0x40,0x48,0x50,0xfc,0x50,0x48,0x44,0x10,0x90,0xbc,0x90,0x50,0x7e,0x10,0x10,0xfe,
+/* 36981 0x9075 "遵" */
+0x01,0x4f,0x20,0x27,0x04,0x05,0xe6,0x27,0x24,0x27,0x20,0x2f,0x21,0x20,0x50,0x8f,
+0x10,0xfe,0xa0,0xfc,0xa4,0x1c,0x04,0xfc,0x04,0xfc,0x10,0xfe,0x10,0xb0,0x00,0xfe,
+/* 36982 0x9076 "遶" */
+0x00,0x20,0x13,0x10,0x07,0x02,0xf7,0x12,0x1f,0x10,0x17,0x11,0x12,0x14,0x28,0x47,
+0x40,0x40,0xf8,0x40,0xfc,0x10,0x38,0x10,0x7c,0x00,0xfc,0x20,0x24,0x1c,0x00,0xfe,
+/* 36983 0x9077 "遷" */
+0x07,0x20,0x17,0x14,0x07,0x00,0xf7,0x12,0x15,0x19,0x11,0x11,0x10,0x28,0x47,0x00,
+0xfc,0xa0,0xfc,0xa4,0xfc,0x80,0xfe,0x08,0xf4,0x12,0xf0,0x04,0xfc,0x00,0xfe,0x00,
+/* 36984 0x9078 "選" */
+0x0f,0x49,0x2f,0x28,0x07,0x01,0xe7,0x21,0x21,0x2f,0x21,0x22,0x24,0x50,0x8f,0x00,
+0x3c,0x24,0x3c,0xa2,0x9e,0x10,0xfc,0x10,0x10,0xfe,0x10,0x08,0x04,0x00,0xfe,0x00,
+/* 36985 0x9079 "遹" */
+0x00,0x23,0x10,0x10,0x07,0x01,0xf6,0x10,0x17,0x14,0x15,0x16,0x14,0x14,0x28,0x47,
+0x00,0xf8,0x90,0x60,0xfc,0x24,0xa8,0x40,0xfc,0xa4,0x14,0xec,0xa4,0xec,0x00,0xfe,
+/* 36986 0x907a "遺" */
+0x00,0x23,0x12,0x13,0x00,0x0f,0xf0,0x13,0x12,0x13,0x12,0x13,0x11,0x12,0x28,0x47,
+0x40,0xf8,0x48,0xf8,0x40,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x10,0x08,0x00,0xfe,
+/* 36987 0x907b "遻" */
+0x00,0x27,0x14,0x14,0x07,0x01,0xf0,0x17,0x10,0x12,0x12,0x13,0x10,0x10,0x29,0x47,
+0x00,0xbc,0xa4,0xa4,0xbc,0x10,0xa0,0xfc,0x40,0x48,0x48,0xf8,0x40,0x80,0x00,0xfe,
+/* 36988 0x907c "遼" */
+0x00,0x40,0x2f,0x20,0x05,0x03,0xe6,0x2b,0x22,0x23,0x20,0x22,0x24,0x29,0x50,0x8f,
+0x40,0x40,0xfc,0xa0,0x14,0xf8,0x0c,0xfa,0x08,0xf8,0x40,0x48,0x44,0x44,0x80,0xfe,
+/* 36989 0x907d "遽" */
+0x00,0x40,0x20,0x27,0x04,0x05,0xe4,0x27,0x24,0x27,0x28,0x2b,0x30,0x23,0x50,0x8f,
+0x40,0x7c,0x40,0xfe,0x42,0xf8,0x44,0xfc,0xc0,0x22,0xd4,0x18,0x74,0x92,0x20,0xfe,
+/* 36990 0x907e "遾" */
+0x02,0x42,0x23,0x25,0x08,0x07,0xe0,0x22,0x22,0x25,0x28,0x20,0x2f,0x50,0x8f,0x00,
+0x10,0x10,0xde,0x28,0x84,0xfc,0x40,0x48,0x48,0x54,0xe2,0x40,0xfe,0x00,0xfe,0x00,
+/* 36991 0x907f "避" */
+0x00,0x47,0x24,0x24,0x04,0x07,0xe4,0x28,0x2f,0x34,0x24,0x27,0x24,0x50,0x8f,0x00,
+0x10,0x88,0xbe,0x80,0xa2,0x94,0x3e,0x08,0x88,0xbe,0x88,0x88,0x88,0x00,0xfe,0x00,
+/* 36992 0x9080 "邀" */
+0x02,0x44,0x2f,0x28,0x0f,0x08,0xef,0x22,0x3f,0x24,0x27,0x28,0x32,0x21,0x50,0x8f,
+0x00,0x10,0x90,0x90,0x9e,0xa4,0xc4,0x14,0xd4,0x08,0x88,0x94,0xa2,0x42,0x00,0xfe,
+/* 36993 0x9081 "邁" */
+0x01,0x4f,0x21,0x23,0x02,0x03,0xe2,0x23,0x20,0x27,0x24,0x25,0x24,0x24,0x50,0x8f,
+0x10,0xfe,0x10,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x54,0xf4,0x14,0x0c,0x00,0xfe,
+/* 36994 0x9082 "邂" */
+0x04,0x4f,0x29,0x32,0x0f,0x0a,0xea,0x2f,0x2a,0x2a,0x2f,0x2a,0x2a,0x31,0x50,0x8f,
+0x00,0x3c,0x14,0x14,0x94,0xa8,0xa8,0xbc,0xc8,0x88,0xbe,0x88,0x88,0x88,0x08,0xfe,
+/* 36995 0x9083 "邃" */
+0x00,0x40,0x2f,0x2a,0x14,0x01,0xe7,0x20,0x21,0x26,0x21,0x26,0x21,0x26,0x50,0x8f,
+0x80,0x40,0xfe,0x12,0x0c,0x20,0xfc,0x80,0x44,0x68,0xb0,0x68,0xa4,0xa4,0x40,0xfe,
+/* 36996 0x9084 "還" */
+0x00,0x47,0x24,0x27,0x00,0x0f,0xe0,0x23,0x22,0x23,0x21,0x23,0x2d,0x51,0x8f,0x00,
+0x00,0xfc,0xa4,0xfc,0x00,0xfe,0x00,0xf8,0x08,0xf8,0x44,0x28,0x90,0x08,0xfe,0x00,
+/* 36997 0x9085 "邅" */
+0x00,0x27,0x10,0x13,0x02,0x02,0xf2,0x13,0x11,0x11,0x11,0x11,0x10,0x17,0x28,0x47,
+0x20,0xfe,0x00,0xfc,0x04,0xf4,0x94,0xfc,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfe,
+/* 36998 0x9086 "邆" */
+0x00,0x23,0x10,0x15,0x02,0x05,0xf0,0x13,0x12,0x13,0x12,0x11,0x17,0x28,0x47,0x00,
+0x24,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0xf8,0x08,0x10,0xfc,0x00,0xfe,0x00,
+/* 36999 0x9087 "邇" */
+0x07,0x42,0x24,0x2f,0x04,0x06,0xe5,0x26,0x24,0x26,0x25,0x26,0x24,0x24,0x50,0x8f,
+0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x0c,0x00,0xfe,
+/* 37000 0x9088 "邈" */
+0x01,0x42,0x2d,0x25,0x02,0x0d,0xe3,0x25,0x29,0x23,0x25,0x29,0x25,0x52,0x8f,0x00,
+0x10,0x20,0x7c,0xc4,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0x2a,0x46,0x80,0xfe,0x00,
+/* 37001 0x9089 "邉" */
+0x00,0x43,0x22,0x23,0x02,0x03,0xe0,0x2f,0x29,0x22,0x25,0x29,0x21,0x21,0x50,0x8f,
+0x80,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0x12,0x08,0xf4,0x12,0x10,0xf0,0x00,0xfe,
+/* 37002 0x908a "邊" */
+0x00,0x47,0x25,0x24,0x07,0x00,0xef,0x2a,0x24,0x2b,0x21,0x21,0x22,0x24,0x50,0x8f,
+0x80,0xf8,0x48,0xa8,0xf8,0x40,0xfc,0x14,0x88,0xf4,0x00,0xf0,0x10,0x30,0x00,0xfe,
+/* 37003 0x908b "邋" */
+0x02,0x44,0x22,0x27,0x05,0x04,0xe5,0x27,0x24,0x26,0x24,0x26,0x24,0x26,0x50,0x8f,
+0x48,0x90,0x48,0xf8,0x28,0xc8,0x28,0xf8,0x90,0xd0,0x90,0xd4,0x8c,0xc4,0x00,0xfe,
+/* 37004 0x908c "邌" */
+0x01,0x46,0x22,0x2f,0x03,0x06,0xea,0x20,0x23,0x2c,0x22,0x21,0x22,0x25,0x50,0x8f,
+0x90,0x1e,0x2a,0x8a,0x12,0xaa,0x44,0xa0,0x18,0x46,0x50,0x60,0x50,0x48,0x80,0xfe,
+/* 37005 0x908d "邍" */
+0x01,0x43,0x25,0x20,0x07,0x03,0xe2,0x23,0x22,0x23,0x20,0x2f,0x22,0x21,0x52,0x8f,
+0x00,0xf0,0x10,0xe0,0x1c,0xf8,0x48,0xf8,0x48,0xf8,0x08,0xfe,0x48,0x50,0x48,0xfe,
+/* 37006 0x908e "邎" */
+0x04,0x4f,0x35,0x2a,0x04,0x1a,0xef,0x20,0x2f,0x20,0x2f,0x29,0x2f,0x50,0x8f,0x00,
+0x00,0x8c,0x70,0x20,0x44,0x78,0x90,0x24,0x7e,0x10,0x54,0x92,0x30,0x00,0xfe,0x00,
+/* 37007 0x908f "邏" */
+0x00,0x4f,0x29,0x2f,0x02,0x04,0xe9,0x2f,0x22,0x25,0x2f,0x21,0x2a,0x2a,0x50,0x8f,
+0x00,0xfe,0x12,0xfe,0x28,0x24,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0xfe,0x40,0x00,0xfe,
+/* 37008 0x9090 "邐" */
+0x0f,0x40,0x2f,0x2c,0x0a,0x00,0xef,0x29,0x2f,0x29,0x2f,0x2a,0x2b,0x2a,0x53,0x8f,
+0xbe,0x00,0xbe,0xb2,0xaa,0x40,0xfe,0x20,0xfc,0x24,0xfc,0x28,0xb2,0x1e,0x80,0xfe,
+/* 37009 0x9091 "邑" */
+0x00,0x1f,0x10,0x10,0x1f,0x00,0x3f,0x21,0x21,0x21,0x3f,0x20,0x20,0x20,0x1f,0x00,
+0x00,0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x02,0x02,0xfe,0x00,
+/* 37010 0x9092 "邒" */
+0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37011 0x9093 "邓" */
+0x00,0x7e,0x02,0x02,0x42,0x24,0x14,0x08,0x08,0x14,0x14,0x22,0x42,0x80,0x00,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37012 0x9094 "邔" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x3f,0x21,0x20,0x20,0x20,0x21,0x26,0x38,0x20,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37013 0x9095 "邕" */
+0x08,0x11,0x22,0x11,0x08,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x21,0x3f,0x20,0x20,0x1f,
+0x88,0x10,0x20,0x10,0x88,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x02,0x02,0xfe,
+/* 37014 0x9096 "邖" */
+0x08,0x08,0x08,0x08,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x4f,0x79,0x00,0x00,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37015 0x9097 "邗" */
+0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0xc8,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37016 0x9098 "邘" */
+0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0xc8,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37017 0x9099 "邙" */
+0x10,0x08,0x08,0x00,0xff,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37018 0x909a "邚" */
+0x10,0x10,0x10,0x10,0xfe,0x22,0x22,0x22,0x42,0x24,0x14,0x08,0x14,0x22,0x42,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37019 0x909b "邛" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0f,0xf0,0x40,0x00,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37020 0x909c "邜" */
+0x10,0x10,0x10,0x1f,0x21,0x21,0x51,0x8a,0x0a,0x04,0x04,0x08,0x10,0x20,0x40,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37021 0x909d "邝" */
+0x08,0x04,0x04,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x80,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37022 0x909e "邞" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x08,0x14,0x12,0x22,0x21,0x41,0x80,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0xc8,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37023 0x909f "邟" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x80,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37024 0x90a0 "邠" */
+0x00,0x14,0x12,0x12,0x21,0x21,0x40,0xbe,0x12,0x12,0x12,0x12,0x22,0x22,0x4a,0x84,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37025 0x90a1 "邡" */
+0x10,0x08,0x08,0xff,0x10,0x10,0x1f,0x11,0x11,0x11,0x11,0x11,0x21,0x25,0x42,0x80,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37026 0x90a2 "邢" */
+0x00,0x7f,0x12,0x12,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x22,0x22,0x42,0x82,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0xe4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37027 0x90a3 "那" */
+0x00,0x7e,0x12,0x12,0x12,0x7e,0x12,0x12,0x7e,0x12,0x12,0x22,0x22,0x4a,0x84,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37028 0x90a4 "邤" */
+0x02,0x07,0x38,0x20,0x20,0x20,0x3f,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x00,0x7c,0x44,0x48,0x48,0x50,0xc8,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37029 0x90a5 "邥" */
+0x08,0x08,0x08,0x7f,0x49,0x08,0x08,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37030 0x90a6 "邦" */
+0x08,0x08,0x08,0xff,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x10,0x10,0x20,0x40,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37031 0x90a7 "邧" */
+0x00,0x3f,0x00,0x00,0x00,0xff,0x12,0x12,0x12,0x12,0x12,0x22,0x23,0x42,0x80,0x00,
+0x00,0x3e,0x22,0x24,0x24,0xa8,0x24,0x24,0x22,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37032 0x90a8 "邨" */
+0x08,0x08,0x08,0xff,0x08,0x49,0x49,0x49,0x49,0x7f,0x08,0x08,0x09,0x0a,0x0c,0x08,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37033 0x90a9 "邩" */
+0x08,0x08,0x08,0x09,0x49,0x4a,0x4c,0x88,0x08,0x08,0x14,0x12,0x21,0x21,0x40,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37034 0x90aa "邪" */
+0x00,0x7f,0x02,0x22,0x22,0x22,0x42,0x7f,0x06,0x0a,0x12,0x22,0x42,0x82,0x0a,0x04,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0xe4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37035 0x90ab "邫" */
+0x10,0x10,0x10,0xfc,0x10,0x10,0x7d,0x11,0x11,0xff,0x11,0x11,0x21,0x21,0x41,0x80,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 37036 0x90ac "邬" */
+0x10,0x20,0x7e,0x42,0x42,0x4a,0x44,0x40,0x7f,0x01,0x01,0x1d,0xe1,0x41,0x0a,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37037 0x90ad "邭" */
+0x10,0x10,0x20,0x3f,0x41,0x81,0x3d,0x25,0x25,0x25,0x3d,0x25,0x01,0x01,0x0a,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37038 0x90ae "邮" */
+0x08,0x08,0x08,0x7f,0x49,0x49,0x49,0x49,0x7f,0x49,0x49,0x49,0x49,0x7f,0x41,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37039 0x90af "邯" */
+0x22,0x22,0x22,0x22,0xff,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37040 0x90b0 "邰" */
+0x08,0x08,0x10,0x22,0x41,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x00,0x3e,0x22,0x24,0x24,0xa8,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37041 0x90b1 "邱" */
+0x00,0x03,0x3c,0x20,0x20,0x20,0x3f,0x22,0x22,0x22,0x22,0x22,0x27,0xf8,0x40,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37042 0x90b2 "邲" */
+0x10,0x08,0x0a,0x02,0x12,0x13,0x54,0x54,0x54,0x98,0x19,0x11,0x31,0x4f,0x80,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37043 0x90b3 "邳" */
+0x00,0xff,0x08,0x08,0x10,0x14,0x32,0x51,0x90,0x10,0x10,0x00,0x0e,0xf0,0x40,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37044 0x90b4 "邴" */
+0x00,0x7f,0x08,0x08,0x08,0x7f,0x48,0x48,0x54,0x52,0x62,0x40,0x40,0x40,0x42,0x41,
+0x00,0xbe,0x22,0x24,0x24,0xa8,0xa4,0xa4,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 37045 0x90b5 "邵" */
+0x00,0x7f,0x11,0x11,0x21,0x25,0x42,0x80,0x3f,0x21,0x21,0x21,0x21,0x3f,0x21,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37046 0x90b6 "邶" */
+0x12,0x12,0x12,0x12,0x12,0xf3,0x12,0x12,0x12,0x12,0x12,0x32,0x52,0x93,0x12,0x00,
+0x00,0x3e,0x22,0x24,0x24,0xa8,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37047 0x90b7 "邷" */
+0x00,0xff,0x20,0x20,0x3c,0x24,0x24,0x34,0x4c,0x4c,0x44,0x45,0x55,0x65,0x43,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37048 0x90b8 "邸" */
+0x01,0x07,0x7c,0x44,0x44,0x44,0x44,0x7f,0x44,0x44,0x44,0x42,0x42,0x52,0x69,0x44,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0xa8,0xa0,0xa0,0xa0,
+/* 37049 0x90b9 "邹" */
+0x20,0x20,0x3e,0x42,0x84,0x08,0xfe,0x02,0x02,0x7e,0x02,0x02,0x02,0xfe,0x02,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37050 0x90ba "邺" */
+0x14,0x14,0x14,0x14,0x94,0x55,0x55,0x56,0x14,0x14,0x14,0x17,0xf8,0x40,0x00,0x00,
+0x00,0x3e,0x22,0xa4,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37051 0x90bb "邻" */
+0x08,0x08,0x14,0x12,0x21,0x48,0x84,0x04,0x7f,0x01,0x22,0x14,0x08,0x04,0x04,0x00,
+0x00,0x7c,0x44,0x48,0x48,0xd0,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37052 0x90bc "邼" */
+0x00,0x7f,0x40,0x40,0x7f,0x44,0x44,0x5f,0x44,0x44,0x7f,0x40,0x40,0x7f,0x00,0x00,
+0x00,0xbe,0x22,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0xa2,0x34,0x28,0xa0,0x20,0x20,
+/* 37053 0x90bd "邽" */
+0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x00,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0xc8,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37054 0x90be "邾" */
+0x08,0x48,0x48,0x7f,0x48,0x88,0x08,0xff,0x18,0x1c,0x2a,0x29,0x49,0x88,0x08,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0xc8,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37055 0x90bf "邿" */
+0x08,0x08,0x08,0x7f,0x08,0x08,0xff,0x02,0x02,0x7f,0x02,0x22,0x12,0x02,0x0a,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0x24,0x22,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37056 0x90c0 "郀" */
+0x08,0x08,0xff,0x14,0x22,0x41,0xbe,0x00,0xff,0x10,0x20,0x7f,0x01,0x01,0x0a,0x04,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0xa2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37057 0x90c1 "郁" */
+0x08,0x08,0xff,0x10,0x10,0x3f,0x21,0x61,0xbf,0x21,0x21,0x3f,0x21,0x21,0x25,0x22,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37058 0x90c2 "郂" */
+0x10,0x08,0x00,0xff,0x08,0x11,0x21,0x7e,0x04,0x09,0x12,0x24,0xcc,0x12,0x21,0xc0,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0xa0,
+/* 37059 0x90c3 "郃" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0x7c,0x44,0x48,0x48,0xd0,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37060 0x90c4 "郄" */
+0x01,0x32,0x0c,0x12,0x69,0x08,0xff,0x10,0x24,0x24,0x48,0x8a,0x11,0x3f,0x11,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37061 0x90c5 "郅" */
+0x00,0xff,0x08,0x10,0x22,0x41,0xff,0x08,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf8,0x40,
+0x00,0xbe,0x22,0x24,0x24,0x28,0xa4,0xa4,0x22,0x22,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 37062 0x90c6 "郆" */
+0x08,0x08,0x08,0xff,0x08,0x08,0x7f,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,0x00,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37063 0x90c7 "郇" */
+0x20,0x20,0x7f,0x41,0x81,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x41,0x01,0x0a,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37064 0x90c8 "郈" */
+0x02,0x07,0x78,0x40,0x40,0x7f,0x40,0x40,0x5f,0x51,0x51,0x51,0x51,0x9f,0x91,0x00,
+0x00,0x3e,0x22,0x24,0x24,0xa8,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37065 0x90c9 "郉" */
+0x00,0x77,0x22,0x22,0x22,0x22,0x22,0xf7,0x22,0x22,0x22,0x22,0x22,0x42,0x42,0x82,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37066 0x90ca "郊" */
+0x10,0x08,0x00,0xff,0x00,0x24,0x42,0x81,0x24,0x14,0x08,0x14,0x22,0x42,0x80,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37067 0x90cb "郋" */
+0x08,0x08,0x10,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x41,0x41,0x7f,0x41,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37068 0x90cc "郌" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfd,0x01,0x11,0x11,0x7d,0x11,0x11,0x1d,0xe1,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 37069 0x90cd "郍" */
+0x08,0x10,0x3f,0x21,0x29,0x25,0x25,0xff,0x21,0x29,0x25,0x25,0x21,0x41,0x45,0x82,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37070 0x90ce "郎" */
+0x08,0x04,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x20,0x24,0x22,0x25,0x29,0x30,0x20,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37071 0x90cf "郏" */
+0x08,0x08,0x08,0xff,0x08,0x49,0x29,0x2a,0xff,0x08,0x08,0x14,0x12,0x21,0x41,0x80,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0xa2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37072 0x90d0 "郐" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0xff,0x10,0x10,0x22,0x41,0xff,0x41,0x00,
+0x00,0x3e,0x22,0x24,0x24,0xa8,0x24,0x24,0xa2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37073 0x90d1 "郑" */
+0x22,0x12,0x14,0x7f,0x08,0x08,0x08,0xff,0x08,0x08,0x14,0x12,0x21,0x41,0x80,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37074 0x90d2 "郒" */
+0x00,0x20,0x10,0x7c,0x44,0x44,0x7d,0x45,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 37075 0x90d3 "郓" */
+0x00,0x7f,0x48,0x08,0x7f,0x10,0x14,0x24,0x7f,0x04,0x04,0x07,0xfc,0x44,0x04,0x04,
+0x00,0xbe,0xa2,0x24,0xa4,0x28,0x24,0x24,0xa2,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37076 0x90d4 "郔" */
+0x00,0x01,0x77,0x11,0x11,0x25,0x25,0x75,0x15,0x55,0x55,0x27,0x20,0x50,0x8f,0x00,
+0x80,0xde,0x12,0x12,0x14,0x14,0xd8,0x14,0x12,0x12,0x12,0xda,0x14,0x10,0xf0,0x10,
+/* 37077 0x90d5 "郕" */
+0x04,0x05,0x04,0x04,0x7f,0x44,0x44,0x75,0x55,0x55,0x55,0x52,0x52,0xa6,0x89,0x10,
+0x00,0x3e,0xa2,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0xa0,0xa0,0xa0,
+/* 37078 0x90d6 "郖" */
+0x00,0x7f,0x00,0x00,0x3f,0x21,0x21,0x21,0x3f,0x00,0x21,0x11,0x12,0x07,0x78,0x20,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 37079 0x90d7 "郗" */
+0x30,0x0d,0x06,0x19,0x60,0x08,0x7f,0x14,0x24,0x7f,0xa4,0x24,0x26,0x25,0x04,0x04,
+0x80,0x3e,0x22,0x24,0xa4,0x28,0xe4,0x24,0x22,0xa2,0xa2,0xb4,0xa8,0x20,0x20,0x20,
+/* 37080 0x90d8 "郘" */
+0x00,0x3e,0x22,0x22,0x22,0x22,0x3e,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x7f,0x41,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37081 0x90d9 "郙" */
+0x0a,0x09,0xff,0x08,0x08,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x49,0x49,0x49,0x43,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37082 0x90da "郚" */
+0x00,0xff,0x08,0x08,0x7f,0x11,0x11,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0xe4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37083 0x90db "郛" */
+0x02,0x0f,0xf0,0x01,0x91,0x4a,0x00,0xfe,0x04,0x08,0x0f,0xf8,0x48,0x08,0x28,0x10,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37084 0x90dc "郜" */
+0x08,0x48,0x48,0x7f,0x48,0x88,0x08,0xff,0x00,0x00,0x7f,0x41,0x41,0x41,0x7f,0x41,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37085 0x90dd "郝" */
+0x08,0x08,0x7f,0x08,0x08,0x08,0xff,0x12,0x12,0x53,0x52,0x92,0x22,0x22,0x4a,0x84,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0xa2,0xb4,0x28,0x20,0x20,0x20,
+/* 37086 0x90de "郞" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x51,0x4a,0x44,0x44,0x52,0x62,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37087 0x90df "郟" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x14,0x12,0x21,0x41,0x80,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0x24,0x24,0x22,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37088 0x90e0 "郠" */
+0x00,0x7f,0x08,0x08,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0x68,0x18,0x26,0xc1,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37089 0x90e1 "郡" */
+0x00,0x7f,0x11,0x11,0xff,0x11,0x11,0x7f,0x20,0x20,0x7f,0xa1,0x21,0x21,0x3f,0x21,
+0x00,0x3e,0x22,0x24,0xe4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37090 0x90e2 "郢" */
+0x00,0x7f,0x41,0x41,0x41,0x7f,0x00,0x7f,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37091 0x90e3 "郣" */
+0x08,0x08,0x7f,0x08,0x08,0x7f,0x41,0x82,0x3c,0x04,0x08,0x0f,0x78,0x08,0x28,0x10,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37092 0x90e4 "郤" */
+0x14,0x12,0x21,0x49,0x08,0x14,0x22,0x41,0xbe,0x22,0x22,0x22,0x22,0x3e,0x22,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37093 0x90e5 "郥" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x00,0x24,0x22,0x41,0x81,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37094 0x90e6 "郦" */
+0x00,0x7f,0x00,0x00,0x7b,0x4a,0x4a,0x4a,0x6b,0x5a,0x4a,0x4a,0x4a,0x4a,0x4a,0x5a,
+0x00,0xde,0x12,0x12,0xd4,0x54,0x58,0x54,0x52,0xd2,0x52,0x5a,0x54,0x50,0x50,0xd0,
+/* 37095 0x90e7 "郧" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x41,0x49,0x49,0x49,0x49,0x14,0x12,0x21,0xc1,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37096 0x90e8 "部" */
+0x10,0x08,0x7f,0x00,0x21,0x12,0xff,0x00,0x00,0x3f,0x21,0x21,0x21,0x3f,0x21,0x00,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xe4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37097 0x90e9 "郩" */
+0x61,0x1a,0x0c,0x32,0xc9,0x08,0xff,0x10,0x3f,0x61,0xbf,0x21,0x3f,0x21,0x25,0x22,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37098 0x90ea "郪" */
+0x08,0x08,0xff,0x08,0x7f,0x09,0xff,0x09,0x7f,0x10,0xff,0x21,0x72,0x0c,0x33,0xc0,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0xa0,
+/* 37099 0x90eb "郫" */
+0x10,0x20,0x7f,0x49,0x49,0x7f,0x49,0x51,0x7f,0x24,0x44,0xff,0x04,0x04,0x04,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37100 0x90ec "郬" */
+0x08,0x08,0xff,0x08,0x7f,0x08,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x45,0x42,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37101 0x90ed "郭" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x00,0x7e,0x04,0x08,0x0f,0xf8,0x08,0x28,0x10,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37102 0x90ee "郮" */
+0x00,0x3f,0x24,0x24,0x2e,0x24,0x3f,0x20,0x2e,0x2a,0x2a,0x2e,0x20,0x40,0x42,0x81,
+0x00,0xbe,0xa2,0xa4,0xa4,0xa8,0xa4,0xa4,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 37103 0x90ef "郯" */
+0x08,0x09,0x49,0x4a,0x88,0x14,0x22,0x49,0x88,0x49,0x49,0x8a,0x14,0x22,0x41,0x80,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0xa0,
+/* 37104 0x90f0 "郰" */
+0x00,0xfc,0x48,0x4b,0x78,0x4a,0x49,0x79,0x48,0x48,0x5c,0xe9,0x49,0x0a,0x08,0x08,
+0x00,0x1e,0x12,0xd2,0x54,0x54,0x58,0x54,0x92,0x92,0x92,0x5a,0x54,0x50,0x10,0x10,
+/* 37105 0x90f1 "郱" */
+0x21,0x11,0x12,0x00,0x7f,0x12,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x12,0x22,0x42,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0x24,0x22,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37106 0x90f2 "郲" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37107 0x90f3 "郳" */
+0x10,0x67,0x41,0x41,0x77,0x41,0x41,0x7f,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37108 0x90f4 "郴" */
+0x11,0x11,0x11,0x11,0x7b,0x11,0x11,0x33,0x3b,0x55,0x55,0x99,0x11,0x11,0x11,0x11,
+0x00,0x1e,0x12,0x12,0xd4,0x14,0x18,0x14,0x92,0x52,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 37109 0x90f5 "郵" */
+0x02,0x0f,0x78,0x08,0xff,0x2a,0x2a,0xff,0x2a,0x2a,0xff,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0xa4,0x22,0x22,0xa2,0x34,0x28,0x20,0x20,0x20,
+/* 37110 0x90f6 "郶" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0x01,0xff,0x01,0x01,0x7d,0x45,0x45,0x45,0x7d,0x44,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,
+/* 37111 0x90f7 "郷" */
+0x20,0x23,0x22,0x4a,0x4b,0xf2,0x12,0x23,0x4a,0xfa,0x0a,0x12,0x13,0x22,0x40,0x80,
+0x00,0xde,0x52,0x52,0xd4,0x54,0x58,0xd4,0x12,0x92,0x52,0xda,0x54,0x10,0x10,0x10,
+/* 37112 0x90f8 "郸" */
+0x41,0x22,0x14,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0x08,0xff,0x08,0x08,0x08,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37113 0x90f9 "郹" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x14,0x12,0xff,0x10,0x28,0x24,0x42,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37114 0x90fa "郺" */
+0x21,0x22,0x3d,0x44,0xa8,0x10,0x20,0xc8,0x11,0x3d,0x45,0x85,0x29,0x11,0x21,0xc0,
+0x24,0x48,0x24,0x00,0xf8,0x88,0xf8,0x00,0xfc,0x24,0x24,0xfc,0x00,0x04,0x04,0xfc,
+/* 37115 0x90fb "郻" */
+0x3f,0xa1,0xbf,0xa1,0xbf,0xa1,0xbf,0x80,0xff,0x00,0x49,0x49,0x92,0x92,0x49,0x49,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37116 0x90fc "郼" */
+0x10,0x10,0x7f,0x21,0xff,0x00,0x7f,0x41,0x7f,0x08,0xff,0x08,0x88,0xff,0x08,0x08,
+0x00,0x3e,0x22,0x24,0xe4,0x28,0x24,0x24,0x22,0x22,0xa2,0x34,0x28,0xe0,0x20,0x20,
+/* 37117 0x90fd "都" */
+0x08,0x08,0x7e,0x09,0x0a,0xff,0x08,0x10,0x3f,0x61,0xa1,0x3f,0x21,0x21,0x3f,0x21,
+0x00,0xbe,0xa2,0x24,0x24,0xe8,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37118 0x90fe "郾" */
+0x00,0x7f,0x40,0x5f,0x50,0x5f,0x50,0x5f,0x44,0x7f,0x49,0x59,0x46,0x49,0x50,0x7f,
+0x00,0xde,0x12,0x92,0x94,0x94,0x98,0x94,0x12,0xd2,0x12,0x1a,0x14,0x10,0x90,0xd0,
+/* 37119 0x90ff "郿" */
+0x00,0x7f,0x49,0x49,0x7f,0x40,0x5f,0x51,0x51,0x5f,0x51,0x5f,0x51,0x51,0x9f,0x11,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37120 0x9100 "鄀" */
+0x22,0x22,0xff,0x22,0x2a,0x08,0xff,0x10,0x20,0x3f,0x61,0xa1,0x21,0x21,0x3f,0x21,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37121 0x9101 "鄁" */
+0x14,0x14,0xf7,0x14,0x34,0xd3,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x41,0x45,0x42,
+0x00,0xbe,0x22,0x24,0xa4,0xa8,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37122 0x9102 "鄂" */
+0x00,0x77,0x55,0x55,0x77,0x00,0x7f,0x00,0xff,0x20,0x3f,0x01,0x01,0x01,0x0a,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37123 0x9103 "鄃" */
+0x08,0x14,0x22,0x41,0xbe,0x00,0x78,0x4a,0x4a,0x7a,0x4a,0x4a,0x7a,0x48,0x4a,0x59,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0xa4,0xa4,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 37124 0x9104 "鄄" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x7f,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37125 0x9105 "鄅" */
+0x01,0x07,0xf8,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x88,0x8a,0xbe,0x80,0x82,0x81,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 37126 0x9106 "鄆" */
+0x00,0xff,0x88,0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x00,0xbe,0xa2,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37127 0x9107 "鄇" */
+0x10,0x17,0x10,0x20,0x2f,0x64,0xa4,0x27,0x29,0x21,0x2f,0x21,0x22,0x22,0x24,0x28,
+0x00,0x9e,0x92,0x92,0xf4,0x14,0x18,0xd4,0x12,0x12,0xf2,0x1a,0x94,0x50,0x50,0x10,
+/* 37128 0x9108 "鄈" */
+0x0a,0x74,0x15,0x52,0x22,0x21,0x41,0xbe,0x08,0x08,0x7f,0x08,0x14,0x12,0x22,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37129 0x9109 "鄉" */
+0x21,0x20,0x23,0x4a,0x4a,0xf3,0x12,0x22,0x4b,0xfa,0x0a,0x12,0x12,0x23,0x42,0x80,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 37130 0x910a "鄊" */
+0x20,0x27,0x22,0x4a,0x4b,0xf2,0x12,0x23,0x4a,0xfa,0x0a,0x17,0x10,0x20,0x40,0x80,
+0x00,0xfe,0x52,0x52,0xd4,0x54,0x58,0xd4,0x52,0x52,0x72,0xda,0x54,0x50,0x50,0x50,
+/* 37131 0x910b "鄋" */
+0x28,0x4b,0x49,0x49,0x6b,0x49,0x49,0x7f,0x08,0x7f,0x01,0x32,0x0c,0x12,0x61,0x00,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37132 0x910c "鄌" */
+0x08,0x04,0x7f,0x44,0x5f,0x45,0x7f,0x45,0x5f,0x44,0x5f,0x51,0x51,0x51,0x5f,0x91,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37133 0x910d "鄍" */
+0x00,0xff,0x80,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x10,0x08,0xff,0x00,0x22,0x41,0x80,
+0x00,0xbe,0xa2,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0xb4,0x28,0x20,0x20,0xa0,
+/* 37134 0x910e "鄎" */
+0x08,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x10,0x08,0x29,0xa2,0xa2,0x1e,0x00,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0xa0,0x20,0x20,
+/* 37135 0x910f "鄏" */
+0x00,0x7f,0x40,0x5f,0x40,0x7f,0x55,0x52,0x59,0x50,0x42,0x7f,0x52,0x4a,0x82,0x06,
+0x00,0xbe,0x22,0x24,0x24,0xa8,0x24,0x24,0x22,0xa2,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37136 0x9110 "鄐" */
+0x10,0x08,0xff,0x10,0x22,0x7c,0x08,0x11,0x7f,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x41,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0x24,0x24,0xa2,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37137 0x9111 "鄑" */
+0x00,0x7f,0x12,0x52,0x33,0x12,0xff,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,
+0x00,0xbe,0x22,0xa4,0x24,0x28,0xe4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37138 0x9112 "鄒" */
+0x10,0x10,0x3f,0x48,0x2a,0x3e,0x10,0x25,0x52,0x3f,0x48,0xaa,0x3e,0x10,0x25,0x42,
+0x00,0x3e,0xa2,0xa4,0xa4,0xa8,0xa4,0x24,0x22,0xa2,0xa2,0xb4,0xa8,0xa0,0x20,0x20,
+/* 37139 0x9113 "鄓" */
+0x08,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x0a,0x09,0xff,0x08,0x14,0x22,0x41,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37140 0x9114 "鄔" */
+0x10,0x20,0x7f,0x41,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x00,0x05,0x02,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0xe4,0x22,0xa2,0xa2,0xb4,0xa8,0xa0,0x20,0x20,
+/* 37141 0x9115 "鄕" */
+0x20,0x21,0x23,0x4a,0x4a,0xf3,0x12,0x22,0x4b,0xf8,0x0a,0x13,0x12,0x22,0x41,0x80,
+0x80,0x1e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x52,0x9a,0x14,0x50,0xd0,0x10,
+/* 37142 0x9116 "鄖" */
+0x00,0x3f,0x21,0x21,0x3f,0x00,0x7f,0x40,0x7f,0x40,0x7f,0x40,0x7f,0x12,0x21,0x40,
+0x00,0x3e,0x22,0x24,0x24,0x28,0xa4,0xa4,0xa2,0xa2,0xa2,0xb4,0xa8,0x20,0x20,0xa0,
+/* 37143 0x9117 "鄗" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x00,0xff,0x81,0xbd,0xa5,0xbd,0x81,0x85,0x82,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37144 0x9118 "鄘" */
+0x02,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x22,0x2f,0x2a,0x2f,0x4a,0x4f,0x8a,0x09,
+0x00,0xde,0x12,0x92,0x94,0xd4,0x98,0x94,0x12,0x92,0x92,0x9a,0x94,0x90,0x90,0x90,
+/* 37145 0x9119 "鄙" */
+0x1f,0x11,0x11,0x1f,0x04,0x7f,0x04,0x3f,0x20,0x2e,0x2a,0x2e,0x20,0x3f,0x20,0x00,
+0x00,0x3e,0x22,0x24,0x24,0xe8,0x24,0xa4,0xa2,0xa2,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 37146 0x911a "鄚" */
+0x22,0x22,0xff,0x22,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x08,0x14,0x22,0x41,0x81,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0xa2,0x34,0x28,0x20,0x20,0x20,
+/* 37147 0x911b "鄛" */
+0x49,0x92,0x49,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0xc4,0x68,0x50,0x40,0x40,0x40,
+/* 37148 0x911c "鄜" */
+0x08,0x04,0x7f,0x52,0x52,0x7f,0x52,0x52,0x7f,0x52,0x52,0x5b,0x52,0x52,0x9b,0x12,
+0x00,0x3e,0xa2,0x24,0x24,0xa8,0xa4,0xa4,0xa2,0x22,0x22,0xb4,0x28,0xa0,0x20,0x20,
+/* 37149 0x911d "鄝" */
+0x00,0x77,0x11,0x55,0x33,0x55,0x0c,0x33,0xc4,0x18,0x62,0x0c,0x71,0x06,0x18,0xe0,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37150 0x911e "鄞" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x0f,0xf0,
+0x00,0x7c,0xc4,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37151 0x911f "鄟" */
+0x08,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x02,0xff,0x42,0x22,0x0a,0x04,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0xa2,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37152 0x9120 "鄠" */
+0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0x7f,0x00,0xff,0x20,0x3f,0x01,0x0a,0x04,
+0x00,0x3e,0xa2,0xa4,0x24,0x28,0x24,0x24,0x22,0x22,0xa2,0x34,0x28,0x20,0x20,0x20,
+/* 37153 0x9121 "鄡" */
+0x10,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x08,0x7e,0x1d,0x2a,0xc9,0x08,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0xa4,0x22,0xa2,0xa2,0xb4,0xa8,0x20,0x20,0x20,
+/* 37154 0x9122 "鄢" */
+0x00,0x7f,0x04,0x27,0x24,0xff,0x20,0x3f,0x40,0x7f,0x00,0xaa,0xaa,0x00,0x05,0x02,
+0x00,0xbe,0x22,0x24,0x24,0xa8,0x24,0xa4,0x22,0xa2,0xa2,0xb4,0xa8,0xa0,0x20,0x20,
+/* 37155 0x9123 "鄣" */
+0x08,0x7f,0x22,0x14,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37156 0x9124 "鄤" */
+0x7e,0x42,0x7e,0x42,0x7e,0x00,0xff,0xa5,0xff,0x00,0x7e,0x02,0x34,0x08,0x14,0x62,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37157 0x9125 "鄥" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x80,0x03,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0x22,0xa2,0xb4,0xa8,0xa0,0xa0,0x20,
+/* 37158 0x9126 "鄦" */
+0x20,0x20,0x7f,0xd5,0x55,0x55,0xff,0x55,0x55,0x55,0xff,0x00,0x6a,0x55,0x95,0x00,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0xa2,0x34,0x28,0x20,0x20,0x20,
+/* 37159 0x9127 "鄧" */
+0x05,0x72,0x12,0x51,0x21,0x5e,0x80,0x3f,0x21,0x21,0x3f,0x21,0x12,0x07,0x78,0x20,
+0x00,0x3e,0xa2,0x24,0x24,0xa8,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 37160 0x9128 "鄨" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x20,0x1f,
+0x20,0x3e,0x44,0xa8,0x10,0x28,0x46,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x02,0xfe,
+/* 37161 0x9129 "鄩" */
+0x00,0x7f,0x01,0x3f,0x01,0x7f,0x00,0x77,0x25,0xf7,0x02,0xff,0x42,0x22,0x2a,0x04,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0xb4,0x28,0x20,0x20,0x20,
+/* 37162 0x912a "鄪" */
+0x12,0xff,0x12,0x7f,0x52,0x7f,0x22,0x7f,0xa1,0x3f,0x21,0x3f,0x21,0x3f,0x12,0x21,
+0x00,0x9e,0x92,0x92,0x14,0xd4,0x58,0x54,0xd2,0x12,0x12,0x1a,0x14,0x10,0x10,0x10,
+/* 37163 0x912b "鄫" */
+0x41,0x22,0x00,0xff,0x88,0xaa,0x9c,0x88,0xff,0x00,0x7f,0x41,0x7f,0x41,0x7f,0x41,
+0x00,0x3e,0x22,0xa4,0xa4,0xa8,0xa4,0xa4,0xa2,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37164 0x912c "鄬" */
+0x03,0x7c,0x28,0x15,0x3f,0x21,0x21,0x3f,0x20,0x20,0x3f,0x20,0x55,0x55,0xa1,0x00,
+0xc0,0x1e,0x92,0x12,0x14,0x14,0x18,0x94,0x92,0x92,0xd2,0x5a,0x54,0x50,0x50,0x90,
+/* 37165 0x912d "鄭" */
+0x22,0x14,0xff,0x14,0x7f,0x55,0x63,0x5d,0x41,0x7f,0x08,0xff,0x14,0x22,0x41,0x80,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37166 0x912e "鄮" */
+0x10,0xef,0xa4,0x94,0xaa,0xc9,0x10,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,
+0x00,0xbe,0xa2,0xa4,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37167 0x912f "鄯" */
+0x22,0x14,0xff,0x08,0x7f,0x08,0xff,0x49,0x2a,0xff,0x00,0x7f,0x41,0x41,0x7f,0x41,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37168 0x9130 "鄰" */
+0x08,0x49,0x2a,0xff,0x2a,0x49,0x88,0x41,0x41,0x77,0x91,0x55,0x27,0x41,0x81,0x01,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0xa4,0x24,0x22,0xa2,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37169 0x9131 "鄱" */
+0x0f,0xf8,0x49,0x2a,0xff,0x2a,0x49,0x80,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x41,
+0x00,0x3e,0x22,0x24,0xa4,0x28,0x24,0xa4,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37170 0x9132 "鄲" */
+0x00,0xf7,0x94,0x94,0xf7,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,
+0x00,0xbe,0xa2,0xa4,0xa4,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0xa8,0x20,0x20,0x20,
+/* 37171 0x9133 "鄳" */
+0x00,0x7f,0x55,0x55,0x77,0x14,0x77,0x55,0x55,0x77,0x55,0x55,0x77,0x54,0x14,0x0f,
+0x00,0x3e,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0xa0,0xa0,
+/* 37172 0x9134 "鄴" */
+0x14,0x55,0x36,0x14,0xff,0x22,0x14,0x7f,0x08,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x08,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 37173 0x9135 "鄵" */
+0x00,0x7f,0x41,0x7f,0x00,0xf7,0x94,0xf7,0x08,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x00,0x3e,0x22,0x24,0x24,0xa8,0xa4,0xa4,0x22,0x22,0xa2,0x34,0x28,0x20,0xa0,0x20,
+/* 37174 0x9136 "鄶" */
+0x04,0x0b,0x30,0xdf,0x00,0x7f,0x55,0x4e,0x7f,0x00,0x3f,0x20,0x3f,0x20,0x3f,0x20,
+0x00,0x1e,0xd2,0x32,0x14,0xd4,0x58,0x54,0xd2,0x12,0x92,0x9a,0x94,0x90,0x90,0x90,
+/* 37175 0x9137 "鄷" */
+0x12,0x7f,0x52,0x7f,0x52,0x7f,0x00,0x7f,0x00,0x7f,0x40,0x7f,0x21,0x12,0x0f,0xf0,
+0x00,0xbe,0xa2,0xa4,0xa4,0xa8,0x24,0xa4,0x22,0xa2,0xa2,0xb4,0x28,0x20,0xa0,0x20,
+/* 37176 0x9138 "鄸" */
+0x22,0xff,0x22,0x7f,0x55,0x55,0x7f,0x00,0xff,0x90,0x3e,0x22,0x52,0x0c,0x18,0xe0,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0xa2,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37177 0x9139 "鄹" */
+0xfc,0x4b,0x78,0x4a,0x79,0x4d,0xfa,0x0c,0x07,0xf8,0x28,0x4d,0x1a,0x29,0xc8,0x08,
+0x00,0xbe,0xa2,0xa4,0x24,0x28,0xa4,0xa4,0xa2,0x22,0xa2,0x34,0x28,0x20,0xa0,0x20,
+/* 37178 0x913a "鄺" */
+0x08,0x04,0x7f,0x4a,0x5f,0x4a,0x7f,0x44,0x5f,0x55,0x5f,0x55,0x5f,0x80,0x91,0x20,
+0x00,0x3e,0xa2,0x24,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0xa0,
+/* 37179 0x913b "鄻" */
+0x22,0xf7,0x22,0xf7,0x55,0x88,0x7f,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,
+0x00,0xbe,0x22,0xa4,0x24,0xa8,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0xa0,0x20,
+/* 37180 0x913c "鄼" */
+0x22,0x77,0x22,0xf7,0x22,0x55,0x88,0x7f,0x41,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,
+0x00,0x3e,0x22,0xa4,0x24,0x28,0xa4,0x24,0x22,0x22,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37181 0x913d "鄽" */
+0x04,0x7f,0x40,0x5f,0x54,0x5f,0x54,0x5f,0x44,0x5f,0x44,0x7f,0x54,0xaf,0x84,0x3f,
+0x00,0xde,0x12,0x92,0x94,0x94,0x98,0x94,0x12,0x92,0x12,0xda,0x94,0x50,0x10,0xd0,
+/* 37182 0x913e "鄾" */
+0x7f,0x08,0x3f,0x21,0x3f,0x21,0x7f,0x48,0x25,0x52,0x0e,0x10,0x3f,0x51,0x0e,0x71,
+0x80,0x3e,0x22,0x24,0x24,0x28,0xa4,0xa4,0x22,0xa2,0x22,0x34,0x28,0x20,0x20,0x20,
+/* 37183 0x913f "鄿" */
+0x22,0xff,0x22,0x77,0x55,0x77,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0xff,0x08,0x08,
+0x00,0xbe,0x22,0x24,0x24,0x28,0x24,0x24,0x22,0x22,0x22,0x34,0x28,0xa0,0x20,0x20,
+/* 37184 0x9140 "酀" */
+0x22,0x22,0xff,0x22,0x3e,0x41,0x5d,0xd5,0x55,0x55,0xdd,0x40,0x00,0x54,0x4a,0x8a,
+0x00,0x1e,0x92,0x12,0x14,0x14,0x58,0x94,0x12,0x52,0x52,0xda,0x14,0x90,0x50,0x50,
+/* 37185 0x9141 "酁" */
+0x3e,0x42,0xff,0x40,0x7f,0x44,0x77,0x44,0x3f,0x42,0xff,0x48,0x7f,0x1a,0x29,0xc7,
+0x00,0x1e,0x92,0x92,0x94,0x94,0x18,0x54,0xd2,0x12,0x92,0x9a,0x94,0x10,0x50,0xd0,
+/* 37186 0x9142 "酂" */
+0x10,0x52,0x7b,0x94,0xfb,0x31,0x5a,0x94,0x00,0x3f,0x20,0x24,0x24,0x0b,0x10,0x60,
+0x80,0x9e,0xd2,0x92,0xf4,0x94,0xd8,0x94,0x12,0x92,0x92,0x9a,0x94,0x10,0x90,0x50,
+/* 37187 0x9143 "酃" */
+0x00,0x7f,0x04,0xff,0x84,0x35,0x04,0x35,0x00,0x00,0xee,0xaa,0xaa,0xaa,0xee,0xaa,
+0x00,0xce,0x0a,0xea,0x2a,0x8a,0x0c,0x8a,0x0a,0x0a,0xea,0xaa,0xac,0xa8,0xe8,0xa8,
+/* 37188 0x9144 "酄" */
+0x11,0x7f,0x11,0x7b,0x4a,0x7b,0x14,0x12,0x3f,0x24,0x7f,0xa4,0x3f,0x24,0x3f,0x20,
+0x00,0xde,0x12,0xd2,0x54,0xd4,0x18,0x14,0xd2,0x12,0x92,0x1a,0x94,0x10,0xd0,0x10,
+/* 37189 0x9145 "酅" */
+0x44,0x7f,0x12,0x3f,0x62,0xbf,0x22,0x3f,0x22,0x3f,0x20,0x7f,0x51,0x6e,0x4a,0x4e,
+0x40,0xde,0x12,0xd2,0x14,0xd4,0x18,0xd4,0x12,0xd2,0x12,0xda,0x54,0xd0,0x50,0xd0,
+/* 37190 0x9146 "酆" */
+0x2a,0x7f,0xaa,0xff,0xaa,0xff,0xaa,0xff,0x00,0xff,0x00,0x7f,0x41,0x7f,0x22,0xff,
+0x00,0x3e,0xa2,0xa4,0xa4,0xa8,0xa4,0xa4,0x22,0xa2,0x22,0x34,0x28,0x20,0x20,0xa0,
+/* 37191 0x9147 "酇" */
+0x52,0x7b,0x94,0xfb,0x31,0x5a,0x94,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x11,0x20,
+0x80,0xde,0x92,0xf2,0x94,0xd4,0x98,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x10,0x90,
+/* 37192 0x9148 "酈" */
+0x7b,0x00,0x7b,0x4a,0x6b,0x4a,0x04,0x7f,0x4a,0x7f,0x4a,0x7f,0x52,0x5b,0x52,0x99,
+0xc0,0x1e,0xd2,0x52,0x54,0x54,0x18,0xd4,0x12,0xd2,0x52,0xda,0x54,0x90,0x50,0xd0,
+/* 37193 0x9149 "酉" */
+0x00,0xff,0x04,0x04,0x7f,0x44,0x44,0x48,0x50,0x60,0x40,0x7f,0x40,0x40,0x7f,0x40,
+0x00,0xfe,0x40,0x40,0xfc,0x44,0x44,0x44,0x3c,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37194 0x914a "酊" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x00,0x80,0x7e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 37195 0x914b "酋" */
+0x10,0x08,0x08,0xff,0x04,0x04,0x7f,0x44,0x48,0x50,0x60,0x7f,0x40,0x40,0x7f,0x40,
+0x10,0x10,0x20,0xfe,0x40,0x40,0xfc,0x44,0x44,0x3c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37196 0x914c "酌" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0x20,0x7c,0x44,0x84,0x04,0x44,0x24,0x14,0x14,0x04,0x04,0x04,0x28,0x10,
+/* 37197 0x914d "配" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x88,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 37198 0x914e "酎" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x08,0x08,0x08,0x08,0xfe,0x08,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x28,0x10,
+/* 37199 0x914f "酏" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xa4,0xb4,0xa8,0xa2,0xa2,0x82,0x7e,0x00,
+/* 37200 0x9150 "酐" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 37201 0x9151 "酑" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 37202 0x9152 "酒" */
+0x00,0x4f,0x20,0x20,0x07,0x84,0x44,0x54,0x15,0x26,0xe4,0x27,0x24,0x24,0x27,0x04,
+0x00,0xfe,0xa0,0xa0,0xfc,0xa4,0xa4,0xa4,0x1c,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37203 0x9153 "酓" */
+0x01,0x02,0x0c,0x31,0xcf,0x00,0x00,0xff,0x04,0x3f,0x24,0x28,0x30,0x3f,0x20,0x3f,
+0x00,0x80,0x60,0x18,0xe6,0x40,0x80,0xfe,0x80,0xf8,0x88,0x78,0x08,0xf8,0x08,0xf8,
+/* 37204 0x9154 "酔" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x83,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x40,0xf8,0x48,0x88,0x8a,0x0a,0x26,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 37205 0x9155 "酕" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x08,0x1c,0xf0,0x10,0x10,0x1c,0xf0,0x10,0x10,0x1e,0xf0,0x10,0x12,0x12,0x12,0x0e,
+/* 37206 0x9156 "酖" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 37207 0x9157 "酗" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x44,0x44,0x28,0xaa,0xaa,0x92,0x92,0xaa,0xaa,0xa6,0xc6,0x82,0x82,0xfe,0x02,
+/* 37208 0x9158 "酘" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 37209 0x9159 "酙" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 37210 0x915a "酚" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x08,0x28,0x28,0x28,0x44,0x44,0x82,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 37211 0x915b "酛" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 37212 0x915c "酜" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x48,0x88,0x84,0x04,0x02,
+/* 37213 0x915d "酝" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x00,0x7c,0x00,0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x44,0x42,0xfe,0x42,0x00,
+/* 37214 0x915e "酞" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 37215 0x915f "酟" */
+0x00,0xff,0x14,0x14,0x7f,0x55,0x55,0x55,0x57,0x61,0x41,0x7f,0x41,0x41,0x7f,0x41,
+0x10,0x90,0x10,0x10,0x1e,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 37216 0x9160 "酠" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x00,0xfe,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 37217 0x9161 "酡" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0x10,0xfe,0x82,0x84,0x40,0x44,0x48,0x50,0x60,0x42,0x42,0x42,0x3e,0x00,
+/* 37218 0x9162 "酢" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x40,0x40,0x7e,0xa0,0xa0,0x20,0x3c,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 37219 0x9163 "酣" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x44,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 37220 0x9164 "酤" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 37221 0x9165 "酥" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0xfe,0x10,0x38,0x34,0x54,0x52,0x90,0x10,0x10,0x10,
+/* 37222 0x9166 "酦" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x83,0xfe,0x82,
+0x20,0x28,0xa4,0xa0,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 37223 0x9167 "酧" */
+0x00,0xfe,0x28,0x28,0xff,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x82,0x0c,0x08,0x08,0xfe,0x08,0x48,0x28,0x28,0x08,0x08,0x28,0x10,
+/* 37224 0x9168 "酨" */
+0x08,0x08,0x7f,0x08,0xff,0x00,0xff,0x14,0x7f,0x55,0x63,0x41,0x7f,0x41,0x7f,0x41,
+0x20,0x28,0x24,0x20,0xfe,0x20,0xa4,0x24,0x24,0x28,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 37225 0x9169 "酩" */
+0x00,0xfe,0x28,0x28,0xff,0xaa,0xaa,0xaa,0xae,0xc2,0x83,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0x7e,0x82,0x44,0x28,0x10,0x20,0x40,0xfe,0x42,0x42,0x42,0x42,0x7e,0x42,
+/* 37226 0x916a "酪" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0x3c,0x44,0xa8,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 37227 0x916b "酫" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x28,0x28,0x44,0x82,0x7c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 37228 0x916c "酬" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x04,0x44,0x54,0x54,0x54,0x54,0xdc,0x74,0x54,0x54,0x54,0x54,0x54,0x54,0x84,0x04,
+/* 37229 0x916d "酭" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xaf,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0xfe,0x20,0x40,0x7c,0x44,0xc4,0x7c,0x44,0x44,0x7c,0x44,0x44,0x44,0x4c,
+/* 37230 0x916e "酮" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfe,0x82,0x82,0xba,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x84,
+/* 37231 0x916f "酯" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x80,0x82,0x8c,0xf0,0x82,0x82,0x7e,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 37232 0x9170 "酰" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x28,0x28,0x28,0x28,0x4a,0x4a,0x86,0x00,
+/* 37233 0x9171 "酱" */
+0x08,0x48,0x29,0x1a,0x28,0xc9,0x08,0xff,0x04,0x3f,0x24,0x28,0x30,0x3f,0x20,0x3f,
+0x40,0x80,0xfc,0x48,0x30,0xc0,0x00,0xfe,0x80,0xf8,0x88,0x78,0x08,0xf8,0x08,0xf8,
+/* 37234 0x9172 "酲" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 37235 0x9173 "酳" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x44,0xf8,0x10,0x24,0xfe,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 37236 0x9174 "酴" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x83,0xfe,0x82,
+0x10,0x10,0x28,0x28,0x44,0xba,0x10,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x20,
+/* 37237 0x9175 "酵" */
+0x00,0xfe,0x29,0x28,0xfe,0xab,0xaa,0xaa,0xaf,0xc2,0x83,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x22,0xfa,0x24,0x24,0xfe,0x10,0x20,0xfc,0x88,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 37238 0x9176 "酶" */
+0x00,0xfe,0x28,0x28,0xff,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x64,0x54,0xfe,0x44,0xa4,0x94,0xfe,0x04,0x28,0x10,
+/* 37239 0x9177 "酷" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x50,0x50,0x7c,0x50,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 37240 0x9178 "酸" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 37241 0x9179 "酹" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xaf,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x04,0x1e,0xe0,0x22,0x92,0x54,0x40,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 37242 0x917a "酺" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 37243 0x917b "酻" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x0e,0xf0,0x22,0x92,0x54,0x00,0x7c,0x08,0x10,0x10,0xfe,0x10,0x10,0x10,0x50,0x20,
+/* 37244 0x917c "酼" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 37245 0x917d "酽" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x83,0xff,0x82,
+0x00,0xfe,0x28,0xaa,0x6c,0x28,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 37246 0x917e "酾" */
+0x00,0xfb,0x20,0x20,0xfb,0xaa,0xaa,0xaa,0xdb,0x8a,0x8a,0xfa,0x8a,0x8a,0xfa,0x8a,
+0x00,0xfe,0x00,0x00,0xde,0x52,0x52,0x52,0x5a,0xd6,0x52,0x52,0x52,0x52,0x52,0xd6,
+/* 37247 0x917f "酿" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 37248 0x9180 "醀" */
+0x00,0xfe,0x28,0x28,0xff,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 37249 0x9181 "醁" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfc,0x04,0x04,0x7c,0x04,0x04,0xfe,0x10,0x92,0x54,0x38,0x54,0x92,0x50,0x20,
+/* 37250 0x9182 "醂" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0xec,0xdc,0x5a,0x48,0x48,0x48,0x48,0x48,0x48,
+/* 37251 0x9183 "醃" */
+0x00,0xfe,0x29,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0xfe,0x50,0xa8,0x26,0xf8,0xa8,0xa8,0xf8,0xa8,0xa8,0xf8,0xaa,0x22,0x1e,
+/* 37252 0x9184 "醄" */
+0x00,0xfe,0x28,0x28,0xff,0xaa,0xaa,0xaa,0xaf,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x40,0xfe,0x82,0x42,0x7a,0xa2,0x22,0xfe,0x22,0xaa,0xaa,0xfa,0x02,0x14,0x08,
+/* 37253 0x9185 "醅" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfc,0x00,0x84,0x48,0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 37254 0x9186 "醆" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x28,0x24,0x2e,0xf0,0x28,0x12,0x2a,0xd6,0x28,0x2e,0xf0,0x24,0x28,0x12,0x2a,0xc6,
+/* 37255 0x9187 "醇" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0x7c,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 37256 0x9188 "醈" */
+0x00,0xfe,0x28,0x29,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xff,0x82,0x82,0xff,0x82,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 37257 0x9189 "醉" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x83,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 37258 0x918a "醊" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x00,0xee,0x22,0xaa,0x44,0xaa,0x12,0x00,0xee,0x2a,0xaa,0x4a,0x44,0xa4,0x2a,0x10,
+/* 37259 0x918b "醋" */
+0x00,0xfe,0x28,0x29,0xfe,0xaa,0xab,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 37260 0x918c "醌" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x90,0x92,0xf4,0x98,0x92,0xd2,0x8e,
+/* 37261 0x918d "醍" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x5e,0x50,0x50,0xb0,0x9e,0x00,
+/* 37262 0x918e "醎" */
+0x00,0xf8,0x20,0x23,0xfa,0xaa,0xaa,0xaa,0xda,0x8a,0x8a,0xfa,0x8a,0x8a,0xfa,0x8c,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 37263 0x918f "醏" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x20,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 37264 0x9190 "醐" */
+0x01,0xf9,0x21,0x27,0xf9,0xa9,0xa9,0xab,0xda,0x8a,0x8a,0xfa,0x8b,0x88,0xf8,0x88,
+0x00,0x3c,0x24,0xe4,0x24,0x3c,0x24,0xa4,0xa4,0xbc,0xa4,0xa4,0xa4,0x44,0x54,0x88,
+/* 37265 0x9191 "醑" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfc,0x14,0x50,0x5c,0x50,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+/* 37266 0x9192 "醒" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x50,0x7c,0x90,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 37267 0x9193 "醓" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x10,0x10,0xfe,0x92,0x92,0x28,0x28,0x4a,0x86,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,
+/* 37268 0x9194 "醔" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x09,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,
+/* 37269 0x9195 "醕" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 37270 0x9196 "醖" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 37271 0x9197 "醗" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x08,0xec,0x28,0xaa,0x44,0x44,0x84,0x7a,0x28,0x28,0xfe,0x28,0x28,0x4a,0x4a,0x86,
+/* 37272 0x9198 "醘" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x10,0x10,0x7e,0x10,0x10,0xfe,0x20,0x42,0xfe,0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 37273 0x9199 "醙" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x50,0x96,0x92,0x92,0xd6,0x92,0x92,0xfe,0x10,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 37274 0x919a "醚" */
+0x00,0xfe,0x29,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x82,0x83,0xfe,0x82,
+0x08,0x4a,0x2a,0xac,0x88,0x3e,0x08,0x98,0x9c,0xaa,0xca,0x88,0x88,0x40,0x3e,0x00,
+/* 37275 0x919b "醛" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x44,0x44,0xfe,0x44,0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 37276 0x919c "醜" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x10,0x20,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x20,0x24,0x5a,0x5e,0x90,0x92,0x0e,
+/* 37277 0x919d "醝" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x83,0xfe,0x82,
+0x44,0x24,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x20,0x20,0x7c,0x50,0x90,0x10,0xfe,0x00,
+/* 37278 0x919e "醞" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x00,0x7c,0x54,0x54,0x6c,0x44,0x7c,0x00,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 37279 0x919f "醟" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x40,0xbf,0x04,0x3f,0x24,0x28,0x30,0x3f,0x20,0x3f,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x80,0xf8,0x88,0x78,0x08,0xf8,0x08,0xf8,
+/* 37280 0x91a0 "醠" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x10,0x10,0x7c,0x54,0x54,0xfe,0x28,0x44,0x82,0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 37281 0x91a1 "醡" */
+0x00,0xfe,0x29,0x29,0xfe,0xaa,0xab,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x44,0x40,0xfe,0x20,0x3c,0x20,0x3e,0x20,0x20,0x20,
+/* 37282 0x91a2 "醢" */
+0x00,0xf8,0x23,0x20,0xf8,0xa9,0xaa,0xac,0xd8,0x88,0x89,0xf9,0x89,0x89,0xfb,0x88,
+0x20,0x20,0xfc,0x40,0x80,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 37283 0x91a3 "醣" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x20,0x10,0xfe,0x90,0xbc,0x94,0xfe,0x94,0xbc,0x90,0xbc,0xa4,0xa4,0xa4,0xbc,0x24,
+/* 37284 0x91a4 "醤" */
+0x08,0x4b,0x2a,0x29,0x1b,0x29,0xc8,0x08,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,
+0x3e,0xc4,0x48,0x28,0xfe,0x08,0xa8,0x10,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,
+/* 37285 0x91a5 "醥" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x20,
+/* 37286 0x91a6 "醦" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x10,0x20,0x44,0xfe,0x44,0xaa,0xee,0x10,0x28,0x54,0xaa,0x50,0x24,0x48,0x10,0x60,
+/* 37287 0x91a7 "醧" */
+0x00,0xfb,0x22,0x22,0xfa,0xaa,0xaa,0xaa,0xda,0x8a,0x8a,0xfa,0x8a,0x8a,0xfb,0x88,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 37288 0x91a8 "醨" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x28,0x92,0xaa,0x82,0xfe,0x10,0xfe,0xa2,0xaa,0xba,0x82,0x8a,0x84,
+/* 37289 0x91a9 "醩" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x28,0x28,0xfe,0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+/* 37290 0x91aa "醪" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc3,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x10,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x18,0xe0,
+/* 37291 0x91ab "醫" */
+0x7f,0x48,0x5e,0x64,0x5f,0x4a,0x7f,0x00,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,
+0x78,0x48,0x86,0x78,0x48,0x30,0x48,0x84,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,
+/* 37292 0x91ac "醬" */
+0x04,0x24,0x3c,0x05,0x7c,0x25,0x44,0x80,0xff,0x04,0x3f,0x28,0x30,0x27,0x20,0x3f,
+0x40,0x7c,0xa8,0x50,0x28,0xfe,0x88,0x58,0xfe,0x40,0xf8,0x48,0x38,0xc8,0x08,0xf8,
+/* 37293 0x91ad "醭" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x28,0xaa,0x6c,0x28,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x28,0x44,0x82,
+/* 37294 0x91ae "醮" */
+0x00,0xfe,0x28,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0xaa,0x2a,
+/* 37295 0x91af "醯" */
+0x00,0xf8,0x23,0x20,0xf8,0xa9,0xa8,0xa8,0xd9,0x8a,0x89,0xf9,0x89,0x89,0xfb,0x88,
+0x40,0x20,0xfe,0x40,0x84,0xfe,0xa8,0xaa,0x26,0x00,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 37296 0x91b0 "醰" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,
+/* 37297 0x91b1 "醱" */
+0x00,0xfb,0x20,0x25,0xfa,0xac,0xab,0xa8,0xd8,0x8b,0x8a,0xfb,0x88,0x88,0xfa,0x89,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 37298 0x91b2 "醲" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x80,0xbe,0x80,0xfe,0xa8,0xaa,0xa4,0x32,
+/* 37299 0x91b3 "醳" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xae,0xc2,0x82,0xfe,0x83,0x82,0xfe,0x82,
+0x00,0xfe,0xaa,0xfe,0x10,0xfe,0x10,0xfe,0x44,0x28,0xfe,0x10,0xfe,0x10,0x10,0x10,
+/* 37300 0x91b4 "醴" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x00,0xfe,0x82,0xfe,0x44,0x28,0xfe,0x00,
+/* 37301 0x91b5 "醵" */
+0x00,0xf8,0x20,0x23,0xfa,0xaa,0xab,0xaa,0xda,0x8b,0x8a,0xfb,0x8a,0x8d,0xfc,0x89,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 37302 0x91b6 "醶" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x83,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x44,0x44,0xaa,0xaa,0x12,
+/* 37303 0x91b7 "醷" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x83,0xfe,0x82,
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x94,0x42,0x44,0x3c,
+/* 37304 0x91b8 "醸" */
+0x00,0xfe,0x29,0x28,0xfe,0xab,0xaa,0xaa,0xae,0xc2,0x83,0xfe,0x82,0x83,0xfe,0x82,
+0x20,0x10,0xfe,0x48,0x84,0x4a,0xfc,0x48,0xfc,0x48,0xfe,0x54,0xc8,0x54,0x62,0x40,
+/* 37305 0x91b9 "醹" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x00,0x7c,0x10,0xfe,0x92,0x54,0x10,0x54,0x00,0xfe,0x10,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 37306 0x91ba "醺" */
+0x00,0xf9,0x20,0x23,0xf8,0xa9,0xa9,0xa9,0xd9,0x88,0x89,0xf8,0x8b,0x88,0xf9,0x8a,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 37307 0x91bb "醻" */
+0x00,0xfb,0x20,0x21,0xf8,0xab,0xa8,0xa9,0xd8,0x8b,0x88,0xfb,0x88,0x8b,0xfa,0x8b,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 37308 0x91bc "醼" */
+0x01,0xf9,0x27,0x21,0xf9,0xaa,0xaa,0xae,0xda,0x8a,0x8e,0xfa,0x88,0x8a,0xfa,0x8c,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 37309 0x91bd "醽" */
+0x00,0xf9,0x20,0x23,0xfa,0xa9,0xa8,0xa9,0xd8,0x8b,0x8a,0xfa,0x8a,0x8a,0xfb,0x8a,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0xaa,
+/* 37310 0x91be "醾" */
+0x00,0xf8,0x23,0x22,0xfb,0xaa,0xaa,0xab,0xda,0x8b,0x8a,0xfb,0x8a,0x8a,0xfd,0x88,
+0x40,0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x24,0xa8,0xfe,0x70,0xa8,0x26,0x20,
+/* 37311 0x91bf "醿" */
+0x00,0xfb,0x22,0x23,0xfa,0xaa,0xab,0xaa,0xda,0x8a,0x8a,0xfa,0x8a,0x8a,0xfa,0x8c,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x20,0x44,0x78,0x14,0xfe,0x10,0x54,0xb2,
+/* 37312 0x91c0 "釀" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xff,0x82,
+0x10,0xfe,0x00,0xee,0xaa,0xee,0x44,0xfe,0x44,0xfe,0x44,0xfe,0x50,0xca,0x64,0x42,
+/* 37313 0x91c1 "釁" */
+0x2f,0x48,0x6b,0x48,0x6b,0x4a,0xff,0x92,0x1d,0x10,0x1f,0x04,0x18,0xef,0x04,0x18,
+0xec,0x24,0xac,0x24,0xac,0xa4,0xfe,0x92,0x70,0x10,0xf0,0x40,0x30,0xee,0x20,0x60,
+/* 37314 0x91c2 "釂" */
+0x00,0xfb,0x21,0x20,0xfb,0xaa,0xab,0xa8,0xdb,0x8a,0x8b,0xfa,0x8b,0x8a,0xfa,0x8b,
+0x1e,0xe0,0x22,0x94,0xfe,0x52,0xfe,0x04,0xc4,0x7e,0xc4,0x54,0xcc,0x84,0xd4,0x48,
+/* 37315 0x91c3 "釃" */
+0x03,0xf8,0x23,0x22,0xfb,0xaa,0xa8,0xab,0xda,0x8b,0x8a,0xfb,0x8a,0x8a,0xfa,0x8c,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 37316 0x91c4 "釄" */
+0x00,0xfb,0x22,0x23,0xfa,0xaa,0xab,0xaa,0xda,0x8b,0x8a,0xfb,0x8a,0x8b,0xfa,0x8c,
+0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0x50,0xde,0x50,0xdc,0x50,0xde,0x50,0x50,
+/* 37317 0x91c5 "釅" */
+0x03,0xfa,0x23,0x20,0xfb,0xaa,0xaa,0xaa,0xdb,0x8a,0x8a,0xfa,0x8a,0x8a,0xfd,0x88,
+0xde,0x52,0xde,0x00,0xfe,0x00,0xc8,0x4e,0xea,0xb2,0xea,0xaa,0xea,0xb4,0xe4,0x2a,
+/* 37318 0x91c6 "釆" */
+0x00,0x00,0x3f,0x01,0x11,0x09,0x09,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x10,0xf8,0x00,0x00,0x10,0x10,0x20,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 37319 0x91c7 "采" */
+0x00,0x00,0x3f,0x02,0x11,0x09,0x08,0x01,0x7f,0x03,0x05,0x09,0x11,0x21,0xc1,0x01,
+0x10,0xf8,0x00,0x00,0x10,0x10,0x20,0x00,0xfc,0x80,0x40,0x20,0x10,0x08,0x06,0x00,
+/* 37320 0x91c8 "釈" */
+0x0c,0xf1,0x11,0x55,0x39,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x12,0x14,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x20,0x10,0x10,0x08,0x04,0x02,
+/* 37321 0x91c9 "釉" */
+0x0c,0xf0,0x10,0x54,0x39,0x11,0xfd,0x11,0x31,0x39,0x55,0x51,0x91,0x11,0x11,0x11,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 37322 0x91ca "释" */
+0x0c,0xf3,0x11,0x54,0x38,0x10,0xfc,0x13,0x30,0x39,0x54,0x50,0x93,0x10,0x10,0x10,
+0x00,0xfc,0x04,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 37323 0x91cb "釋" */
+0x0c,0xf1,0x11,0x55,0x38,0x11,0xfc,0x13,0x30,0x38,0x55,0x50,0x93,0x10,0x10,0x10,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 37324 0x91cc "里" */
+0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x01,0x3f,0x01,0x01,0x01,0xff,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,
+/* 37325 0x91cd "重" */
+0x00,0x00,0x3f,0x01,0xff,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0xff,0x00,
+0x10,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,
+/* 37326 0x91ce "野" */
+0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0x08,0x7f,0x08,0x08,0x0f,0xf0,0x40,
+0x00,0x7c,0x04,0x28,0x10,0x08,0x7e,0x12,0x14,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 37327 0x91cf "量" */
+0x00,0x1f,0x10,0x1f,0x10,0xff,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x01,0x1f,0x01,0x7f,
+0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf0,0x00,0xfc,
+/* 37328 0x91d0 "釐" */
+0x08,0x3e,0x08,0x7f,0x1c,0x2a,0x49,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x4f,0x40,0x9f,
+0x20,0x7e,0xa4,0x28,0x10,0x28,0x44,0xfe,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x80,0xfc,
+/* 37329 0x91d1 "金" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x2f,0xc1,0x01,0x3f,0x01,0x11,0x09,0x09,0xff,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0xf8,0x00,0x10,0x10,0x20,0xfe,0x00,
+/* 37330 0x91d2 "釒" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 37331 0x91d3 "釓" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 37332 0x91d4 "釔" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0xfe,0x04,0x08,0x10,0x20,0x20,0x40,0x40,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 37333 0x91d5 "釕" */
+0x10,0x11,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 37334 0x91d6 "釖" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1f,0xf2,0x44,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 37335 0x91d7 "釗" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x04,0x14,0x08,
+/* 37336 0x91d8 "釘" */
+0x10,0x10,0x2b,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 37337 0x91d9 "釙" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x40,0x40,0x40,0x40,0x40,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 37338 0x91da "釚" */
+0x10,0x10,0x28,0x24,0x43,0xb8,0x10,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x80,0x80,0x80,0x80,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 37339 0x91db "釛" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 37340 0x91dc "釜" */
+0x04,0x08,0x18,0x24,0x03,0x0c,0x30,0xc0,0x1f,0x01,0x01,0x3f,0x01,0x11,0x09,0x7f,
+0x40,0x20,0x50,0x88,0x00,0xc0,0x30,0x0e,0xf0,0x00,0x00,0xf8,0x00,0x10,0x20,0xfc,
+/* 37341 0x91dd "針" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x13,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 37342 0x91de "釞" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x48,0x88,0x88,0x84,0x04,0x02,
+/* 37343 0x91df "釟" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x10,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0x10,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x08,0x08,0x08,0x04,0x04,0x02,
+/* 37344 0x91e0 "釠" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1f,0xf1,0x42,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 37345 0x91e1 "釡" */
+0x08,0x10,0x21,0x42,0x04,0x08,0x30,0xcf,0x01,0x01,0x3f,0x01,0x11,0x09,0xff,0x00,
+0x20,0x10,0x08,0x84,0x40,0x20,0x18,0xe6,0x00,0x00,0xf8,0x00,0x10,0x20,0xfe,0x00,
+/* 37346 0x91e2 "釢" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1f,0xf1,0x42,
+0x00,0x00,0xfc,0x44,0x48,0x48,0x50,0x5e,0x42,0x42,0x82,0x82,0x82,0x02,0x14,0x08,
+/* 37347 0x91e3 "釣" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x11,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x40,0x40,0x40,0x7c,0x84,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 37348 0x91e4 "釤" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x08,0x08,0x7f,0x08,0x49,0x2a,0x08,0x0f,0xf0,0x40,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x20,0xc0,
+/* 37349 0x91e5 "釥" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfd,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0x20,0x20,0xa8,0xa4,0xa4,0x22,0x22,0x22,0x20,0x20,0x20,0xa0,0x40,
+/* 37350 0x91e6 "釦" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 37351 0x91e7 "釧" */
+0x11,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 37352 0x91e8 "釨" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 37353 0x91e9 "釩" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 37354 0x91ea "釪" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 37355 0x91eb "釫" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 37356 0x91ec "釬" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 37357 0x91ed "釭" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 37358 0x91ee "釮" */
+0x10,0x10,0x28,0x24,0x43,0xbc,0x10,0x10,0xfe,0x10,0x94,0x59,0x50,0x1e,0xf0,0x40,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x30,0x30,0x50,0x50,0x90,0x10,0x10,0x10,0x50,0x20,
+/* 37359 0x91ef "釯" */
+0x10,0x10,0x28,0x24,0x43,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x40,0x20,0x20,0x00,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 37360 0x91f0 "釰" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 37361 0x91f1 "釱" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37362 0x91f2 "釲" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x80,0x80,0x82,0x82,0x82,0x7e,0x00,
+/* 37363 0x91f3 "釳" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe0,0x40,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 37364 0x91f4 "釴" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x50,0x48,0x48,0x40,0x5e,0xe0,0x40,0x40,0x40,0x40,0x20,0x22,0x12,0x0a,0x06,0x02,
+/* 37365 0x91f5 "釵" */
+0x10,0x11,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 37366 0x91f6 "釶" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 37367 0x91f7 "釷" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x11,0x10,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 37368 0x91f8 "釸" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x41,
+0x40,0x40,0x40,0x7c,0x44,0x84,0xc4,0x24,0x18,0x08,0x10,0x10,0x20,0x40,0x80,0x00,
+/* 37369 0x91f9 "釹" */
+0x10,0x10,0x28,0x24,0x43,0xb8,0x10,0x10,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe0,0x43,
+0x40,0x40,0x40,0x40,0xfe,0x88,0x88,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x88,0x04,
+/* 37370 0x91fa "釺" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x13,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 37371 0x91fb "釻" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1d,0xe2,0x44,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xaa,0x0a,0x06,0x02,
+/* 37372 0x91fc "釼" */
+0x10,0x10,0x29,0x24,0x40,0xb9,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe2,0x44,
+0x00,0x00,0xfc,0x44,0x44,0x44,0xc4,0x44,0x64,0x54,0x4c,0x86,0x84,0x04,0x28,0x10,
+/* 37373 0x91fd "釽" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x48,0x44,0x44,0x42,0x00,
+/* 37374 0x91fe "釾" */
+0x10,0x11,0x28,0x24,0x40,0xb8,0x11,0x11,0xfc,0x10,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x00,0xfe,0x08,0x88,0x88,0x88,0x08,0xfe,0x18,0x28,0x48,0x88,0x08,0x08,0x28,0x10,
+/* 37375 0x91ff "釿" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1f,0xf1,0x42,
+0x04,0x0e,0xf0,0x80,0x80,0x80,0xfe,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 37376 0x9200 "鈀" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 37377 0x9201 "鈁" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x40,0x20,0x20,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 37378 0x9202 "鈂" */
+0x10,0x10,0x28,0x25,0x41,0xba,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0x20,0x50,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 37379 0x9203 "鈃" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x41,
+0x00,0xfc,0x48,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 37380 0x9204 "鈄" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x95,0x58,0x50,0x1e,0xf0,0x40,
+0x08,0x88,0x48,0x48,0x08,0x88,0x48,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,
+/* 37381 0x9205 "鈅" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 37382 0x9206 "鈆" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x11,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe0,0x40,
+0x08,0x48,0x48,0x48,0x44,0x84,0xa4,0x22,0x20,0x40,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 37383 0x9207 "鈇" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37384 0x9208 "鈈" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x95,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0x64,0xa2,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 37385 0x9209 "鈉" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 37386 0x920a "鈊" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x11,0xfd,0x11,0x95,0x5a,0x50,0x1c,0xe0,0x40,
+0x00,0x40,0x20,0x10,0x50,0x40,0x40,0x44,0x42,0x42,0x42,0x44,0x44,0x44,0x3c,0x00,
+/* 37387 0x920b "鈋" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0xa0,0xa0,0xa0,0x24,0x24,0x28,0x30,0x20,0x60,0xa0,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 37388 0x920c "鈌" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37389 0x920d "鈍" */
+0x10,0x10,0x28,0x25,0x40,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 37390 0x920e "鈎" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x12,0x10,0xfc,0x10,0x95,0x59,0x50,0x1c,0xe0,0x40,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x44,0x44,0x84,0xa4,0x14,0xf4,0x14,0x04,0x28,0x10,
+/* 37391 0x920f "鈏" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1c,0xe1,0x40,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 37392 0x9210 "鈐" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x12,0x10,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 37393 0x9211 "鈑" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 37394 0x9212 "鈒" */
+0x10,0x13,0x28,0x24,0x40,0xb8,0x10,0x10,0xfd,0x11,0x95,0x59,0x52,0x1e,0xe4,0x41,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 37395 0x9213 "鈓" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x13,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x40,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 37396 0x9214 "鈔" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x11,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x43,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 37397 0x9215 "鈕" */
+0x10,0x11,0x28,0x24,0x40,0xb8,0x10,0x11,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 37398 0x9216 "鈖" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x12,0x15,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x10,0x90,0x90,0x88,0x08,0x04,0x04,0xfa,0x88,0x88,0x88,0x88,0x08,0x08,0x28,0x10,
+/* 37399 0x9217 "鈗" */
+0x10,0x10,0x28,0x24,0x41,0xbb,0x10,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 37400 0x9218 "鈘" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x11,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x46,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 37401 0x9219 "鈙" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x46,
+0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 37402 0x921a "鈚" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x40,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 37403 0x921b "鈛" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x48,0x44,0x44,0x40,0x5e,0xe0,0x40,0x44,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 37404 0x921c "鈜" */
+0x10,0x10,0x28,0x24,0x43,0xb8,0x10,0x10,0xfc,0x11,0x95,0x5a,0x52,0x1c,0xe1,0x40,
+0x40,0x40,0x40,0x40,0xfe,0x40,0x80,0x90,0x90,0x20,0x20,0x48,0x44,0x84,0xfe,0x82,
+/* 37405 0x921d "鈝" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x11,0x10,0xfe,0x11,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x10,0x10,0x90,0x90,0xfe,0x90,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 37406 0x921e "鈞" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfc,0x10,0x94,0x58,0x51,0x1c,0xe0,0x40,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 37407 0x921f "鈟" */
+0x10,0x11,0x28,0x24,0x42,0xbd,0x11,0x11,0xff,0x11,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x20,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 37408 0x9220 "鈠" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x12,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x43,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 37409 0x9221 "鈡" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 37410 0x9222 "鈢" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x10,0x95,0x59,0x52,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 37411 0x9223 "鈣" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfe,0x10,0x10,0x90,0x9e,0x90,0x90,0x90,0xfe,0x02,0x02,0x02,0x02,0x14,0x08,
+/* 37412 0x9224 "鈤" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37413 0x9225 "鈥" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x20,0x20,0x20,0x24,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37414 0x9226 "鈦" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 37415 0x9227 "鈧" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe1,0x42,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 37416 0x9228 "鈨" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 37417 0x9229 "鈩" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1f,0xf1,0x42,
+0x20,0x10,0x10,0xfe,0x82,0x82,0x82,0xfe,0x82,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 37418 0x922a "鈪" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe2,0x44,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 37419 0x922b "鈫" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 37420 0x922c "鈬" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x90,0x90,0x90,0x90,0x88,0x88,0x84,0x04,0x02,
+/* 37421 0x922d "鈭" */
+0x08,0x08,0x2e,0x28,0x28,0x2e,0xf1,0x06,0x18,0xef,0x01,0x3f,0x09,0x05,0xff,0x00,
+0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,0xc0,0x30,0xee,0x00,0xf8,0x20,0x40,0xfe,0x00,
+/* 37422 0x922e "鈮" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 37423 0x922f "鈯" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x40,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 37424 0x9230 "鈰" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x40,0x20,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 37425 0x9231 "鈱" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0x10,0x12,0x4a,0x86,0x02,
+/* 37426 0x9232 "鈲" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x08,0x1c,0xf0,0x50,0x50,0x50,0x50,0x50,0x50,0x48,0x48,0x68,0x54,0x74,0x52,0x00,
+/* 37427 0x9233 "鈳" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe0,0x40,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 37428 0x9234 "鈴" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x12,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 37429 0x9235 "鈵" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 37430 0x9236 "鈶" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x11,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37431 0x9237 "鈷" */
+0x10,0x10,0x28,0x24,0x43,0xb8,0x10,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37432 0x9238 "鈸" */
+0x10,0x10,0x28,0x24,0x43,0xbc,0x10,0x10,0xfe,0x10,0x94,0x59,0x51,0x1e,0xf0,0x40,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 37433 0x9239 "鈹" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 37434 0x923a "鈺" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x24,0x20,0xfe,0x00,
+/* 37435 0x923b "鈻" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0xfe,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 37436 0x923c "鈼" */
+0x10,0x10,0x28,0x24,0x43,0xbd,0x12,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 37437 0x923d "鈽" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0xfe,0x40,0x50,0x90,0xfe,0x92,0x92,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 37438 0x923e "鈾" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 37439 0x923f "鈿" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 37440 0x9240 "鉀" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x58,0x50,0x1c,0xe0,0x40,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 37441 0x9241 "鉁" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfd,0x10,0x94,0x58,0x51,0x1c,0xe0,0x43,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 37442 0x9242 "鉂" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x10,0x95,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0xc0,0x40,0xa0,0x18,0x06,
+/* 37443 0x9243 "鉃" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x40,0x40,0x80,0xfc,0x20,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37444 0x9244 "鉄" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x12,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37445 0x9245 "鉅" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 37446 0x9246 "鉆" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37447 0x9247 "鉇" */
+0x10,0x10,0x28,0x25,0x42,0x7d,0x91,0x11,0x7b,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 37448 0x9248 "鉈" */
+0x10,0x10,0x28,0x25,0x41,0xba,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 37449 0x9249 "鉉" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1d,0xe0,0x40,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 37450 0x924a "鉊" */
+0x10,0x11,0x28,0x24,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37451 0x924b "鉋" */
+0x10,0x10,0x29,0x25,0x42,0xbd,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 37452 0x924c "鉌" */
+0x10,0x11,0x28,0x24,0x40,0xbb,0x10,0x10,0xfc,0x10,0x94,0x59,0x52,0x1c,0xe0,0x40,
+0x1c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,0x20,
+/* 37453 0x924d "鉍" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x11,0xfd,0x11,0x96,0x58,0x50,0x1d,0xe2,0x40,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 37454 0x924e "鉎" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x12,0x10,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 37455 0x924f "鉏" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 37456 0x9250 "鉐" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x00,0x00,0xfe,0x20,0x20,0x40,0x40,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37457 0x9251 "鉑" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x10,0x10,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37458 0x9252 "鉒" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 37459 0x9253 "鉓" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x80,0x80,0x80,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 37460 0x9254 "鉔" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x40,
+0x00,0xfe,0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x54,0x5c,0x10,0x10,0xfe,0x00,
+/* 37461 0x9255 "鉕" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,0x80,0x80,0xfe,0x00,
+/* 37462 0x9256 "鉖" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfc,0x13,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 37463 0x9257 "鉗" */
+0x10,0x10,0x28,0x24,0x43,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 37464 0x9258 "鉘" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1c,0xe0,0x41,
+0x50,0x50,0x50,0xfc,0x54,0x54,0xfc,0x50,0x50,0xfe,0x52,0x52,0x5a,0x94,0x90,0x10,
+/* 37465 0x9259 "鉙" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1d,0xe2,0x44,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x90,0x88,0x04,0x02,0x02,
+/* 37466 0x925a "鉚" */
+0x20,0x20,0x53,0x4a,0x82,0x7a,0x22,0x22,0xfa,0x22,0x2b,0xb2,0x60,0x38,0xe1,0x02,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 37467 0x925b "鉛" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x11,0x12,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x06,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37468 0x925c "鉜" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 37469 0x925d "鉝" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x40,
+0x20,0x10,0x10,0x00,0xfe,0x00,0x04,0x84,0x84,0x48,0x48,0x48,0x50,0x10,0xfe,0x00,
+/* 37470 0x925e "鉞" */
+0x20,0x20,0x50,0x48,0x83,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x63,0x3a,0xe0,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 37471 0x925f "鉟" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x11,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0x64,0xa2,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 37472 0x9260 "鉠" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x13,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 37473 0x9261 "鉡" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x11,0x10,0xfc,0x10,0x97,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 37474 0x9262 "鉢" */
+0x10,0x10,0x28,0x24,0x43,0xb8,0x10,0x10,0xfc,0x10,0x95,0x5a,0x54,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x70,0x70,0xa8,0xa8,0x24,0xfa,0x20,0x20,0x20,0x20,
+/* 37475 0x9263 "鉣" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x13,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe0,0x40,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 37476 0x9264 "鉤" */
+0x10,0x10,0x29,0x25,0x42,0xbc,0x11,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe0,0x40,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 37477 0x9265 "鉥" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x10,0x95,0x59,0x52,0x1c,0xe0,0x40,
+0x20,0x28,0x24,0x20,0xfc,0x20,0x70,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,0x20,
+/* 37478 0x9266 "鉦" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x10,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 37479 0x9267 "鉧" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x13,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x00,0xfc,0x84,0xa4,0x94,0x84,0x84,0xfe,0x04,0x44,0x24,0x04,0xfe,0x04,0x28,0x10,
+/* 37480 0x9268 "鉨" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x12,0x10,0xfc,0x10,0x95,0x59,0x52,0x1c,0xe0,0x40,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 37481 0x9269 "鉩" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x12,0x10,0xfc,0x10,0x95,0x59,0x52,0x1c,0xe0,0x40,
+0x20,0x20,0x50,0x50,0x88,0x04,0x22,0x20,0xa8,0xa4,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 37482 0x926a "鉪" */
+0x10,0x10,0x28,0x24,0x42,0xbd,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x24,0xa4,0xa4,0xa4,0xa4,0xfe,0xa4,0xa4,0xa4,0xa4,0xbc,0x80,0x80,0x80,0xfe,0x00,
+/* 37483 0x926b "鉫" */
+0x11,0x11,0x29,0x25,0x43,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe3,0x44,
+0x00,0x00,0x00,0x1c,0xd4,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x5c,0x54,0x80,
+/* 37484 0x926c "鉬" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37485 0x926d "鉭" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 37486 0x926e "鉮" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,
+/* 37487 0x926f "鉯" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x08,0x48,0x28,0x28,0x28,0x08,0x08,0x08,0x08,0x08,0x48,0x94,0x14,0x22,0x42,0x82,
+/* 37488 0x9270 "鉰" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x10,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe0,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 37489 0x9271 "鉱" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x52,0x1e,0xe4,0x48,
+0x20,0x10,0x10,0xfe,0x00,0x10,0x10,0x10,0x10,0x20,0x28,0x24,0x44,0xfe,0x42,0x00,
+/* 37490 0x9272 "鉲" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0xfe,0x20,0x20,0x28,0x24,0x22,0x20,0x20,0x20,
+/* 37491 0x9273 "鉳" */
+0x10,0x10,0x28,0x24,0x40,0xbb,0x10,0x10,0xfc,0x10,0x94,0x59,0x52,0x1c,0xe0,0x40,
+0x90,0x90,0x90,0x90,0x90,0x92,0x94,0x98,0x90,0x90,0x90,0x92,0x92,0x92,0x8e,0x80,
+/* 37492 0x9274 "鉴" */
+0x04,0x24,0x24,0x24,0x24,0x25,0x02,0x0c,0x30,0xcf,0x01,0x3f,0x09,0x05,0x7f,0x00,
+0x40,0x40,0x7c,0x90,0x88,0x08,0x80,0x60,0x18,0xe6,0x00,0xf8,0x20,0x40,0xfc,0x00,
+/* 37493 0x9275 "鉵" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1d,0xe0,0x40,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x28,0x24,0xfe,0x82,0x00,
+/* 37494 0x9276 "鉶" */
+0x10,0x13,0x29,0x25,0x41,0xb9,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x02,0xe2,0x42,0x4a,0x4a,0x4a,0x4a,0xea,0x4a,0x4a,0x4a,0x4a,0x42,0x42,0x4a,0x44,
+/* 37495 0x9277 "鉷" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe0,0x41,
+0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0xfe,0x00,0x48,0x44,0x84,0x82,0x02,
+/* 37496 0x9278 "鉸" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x11,0x12,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe0,0x43,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 37497 0x9279 "鉹" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x59,0x50,0x1c,0xe0,0x41,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 37498 0x927a "鉺" */
+0x10,0x13,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x10,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x00,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x8e,0xf8,0x08,0x08,0x08,0x08,
+/* 37499 0x927b "鉻" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 37500 0x927c "鉼" */
+0x11,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x13,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 37501 0x927d "鉽" */
+0x20,0x20,0x50,0x48,0x83,0x78,0x20,0x21,0xf8,0x20,0x28,0xb0,0x60,0x3b,0xe0,0x00,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x10,0xd0,0x90,0x90,0x90,0x88,0xea,0x8a,0x06,0x02,
+/* 37502 0x927e "鉾" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x11,0x94,0x59,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x48,0x84,0xfe,0x12,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 37503 0x927f "鉿" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x11,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37504 0x9280 "銀" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 37505 0x9281 "銁" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x40,0x40,0x80,0xfe,0x02,0x02,0xf2,0x12,0x12,0xf2,0x12,0x12,0xf2,0x02,0x14,0x08,
+/* 37506 0x9282 "銂" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x12,0x12,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe1,0x42,
+0x82,0x92,0x92,0x92,0x92,0x92,0xda,0xb6,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 37507 0x9283 "銃" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x11,0x11,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 37508 0x9284 "銄" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 37509 0x9285 "銅" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x04,0x74,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 37510 0x9286 "銆" */
+0x10,0x13,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37511 0x9287 "銇" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x51,0x1e,0xe4,0x40,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 37512 0x9288 "銈" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 37513 0x9289 "銉" */
+0x10,0x10,0x29,0x24,0x43,0xb8,0x11,0x10,0xfc,0x11,0x94,0x58,0x53,0x1c,0xe0,0x40,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 37514 0x928a "銊" */
+0x20,0x20,0x50,0x48,0x83,0x7a,0x22,0x22,0xfa,0x23,0x2a,0xb2,0x62,0x3c,0xe4,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0xa8,0x28,0x10,0x12,0x2a,0x46,0x82,
+/* 37515 0x928b "銋" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x80,0x88,0x9c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 37516 0x928c "銌" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0xfe,0x40,0x40,0xbc,0x84,0x88,0x88,0xfe,0x88,0x88,0x88,0xa8,0x90,
+/* 37517 0x928d "銍" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x11,0x10,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 37518 0x928e "銎" */
+0x00,0x7d,0x11,0x11,0x11,0x1d,0xe2,0x45,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x00,0xf0,0x10,0x90,0x52,0x12,0x0e,0x00,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37519 0x928f "銏" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0xfe,0x54,0x54,0x54,0x54,0x54,0xd4,0x24,0x4c,
+/* 37520 0x9290 "銐" */
+0x00,0x7f,0x08,0x1f,0x21,0x52,0x0c,0x31,0xc6,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x04,0x84,0x24,0x24,0x24,0x24,0x24,0x04,0xcc,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37521 0x9291 "銑" */
+0x10,0x11,0x29,0x25,0x41,0xba,0x10,0x13,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 37522 0x9292 "銒" */
+0x10,0x11,0x28,0x24,0x40,0xb8,0x10,0x13,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe1,0x42,
+0x00,0xdc,0x88,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 37523 0x9293 "銓" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x11,0x10,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 37524 0x9294 "銔" */
+0x10,0x13,0x28,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x00,0xfe,0x10,0x20,0x68,0xa4,0x22,0x20,0x00,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 37525 0x9295 "銕" */
+0x10,0x10,0x2b,0x24,0x41,0xb8,0x11,0x11,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 37526 0x9296 "銖" */
+0x10,0x11,0x29,0x25,0x41,0xba,0x10,0x13,0xfc,0x10,0x94,0x59,0x51,0x1e,0xe0,0x40,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 37527 0x9297 "銗" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 37528 0x9298 "銘" */
+0x10,0x10,0x28,0x25,0x42,0xb8,0x10,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37529 0x9299 "銙" */
+0x20,0x20,0x53,0x48,0x80,0x79,0x22,0x20,0xfb,0x20,0x28,0xb1,0x60,0x38,0xe0,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 37530 0x929a "銚" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x10,0x10,0xfe,0x11,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 37531 0x929b "銛" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37532 0x929c "銜" */
+0x11,0x11,0x22,0x42,0x84,0x1b,0x21,0x61,0xaf,0x21,0x29,0x25,0x25,0x21,0x2e,0x24,
+0x00,0x00,0x9c,0x40,0x20,0xc0,0x3e,0x08,0xc8,0x08,0x48,0x88,0x08,0xc8,0x28,0x10,
+/* 37533 0x929d "銝" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x90,0x90,0x90,0x10,0xfe,0x10,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,0x10,0x10,
+/* 37534 0x929e "銞" */
+0x10,0x1f,0x20,0x5f,0x90,0x1f,0x10,0x1f,0x01,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x00,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xe8,0x10,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37535 0x929f "銟" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x10,0x92,0x92,0x92,0xfe,0x00,0x10,0x10,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,0x10,
+/* 37536 0x92a0 "銠" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x13,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 37537 0x92a1 "銡" */
+0x10,0x10,0x28,0x27,0x40,0xb8,0x11,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 37538 0x92a2 "銢" */
+0x20,0x21,0x50,0x48,0x83,0x78,0x20,0x20,0xfb,0x20,0x28,0xb1,0x61,0x3a,0xe4,0x00,
+0x00,0xfc,0x00,0x00,0xfe,0x00,0x20,0x22,0xb2,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 37539 0x92a3 "銣" */
+0x21,0x21,0x51,0x49,0x87,0x7a,0x22,0x22,0xfa,0x24,0x2a,0xb1,0x62,0x3a,0xe4,0x08,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x12,0x92,0x5e,0x52,0x00,
+/* 37540 0x92a4 "銤" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x13,0xfc,0x10,0x94,0x59,0x51,0x1e,0xe0,0x40,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 37541 0x92a5 "銥" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x88,0xa4,0xc2,0x80,
+/* 37542 0x92a6 "銦" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfe,0x02,0x22,0x22,0x22,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0xfe,0x02,
+/* 37543 0x92a7 "銧" */
+0x10,0x10,0x2a,0x25,0x41,0xb8,0x17,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x40,0x44,0x44,0x48,0x50,0x40,0xfe,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 37544 0x92a8 "銨" */
+0x10,0x10,0x28,0x27,0x42,0xbc,0x10,0x13,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe0,0x43,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 37545 0x92a9 "銩" */
+0x10,0x10,0x29,0x24,0x40,0xb9,0x10,0x10,0xfc,0x13,0x94,0x58,0x50,0x1d,0xe3,0x41,
+0x08,0x3c,0xe0,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 37546 0x92aa "銪" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 37547 0x92ab "銫" */
+0x10,0x10,0x28,0x25,0x42,0xbd,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 37548 0x92ac "銬" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 37549 0x92ad "銭" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x11,0x10,0xfe,0x11,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x28,0x24,0x3e,0xe0,0x20,0x3c,0xe0,0x20,0x3e,0xe0,0x22,0x24,0x18,0x6a,0x86,0x02,
+/* 37550 0x92ae "銮" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x44,0x01,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x44,0x00,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37551 0x92af "銯" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x20,0x20,0x48,0x88,0xf0,0x20,0x40,0x88,0xfc,0x24,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 37552 0x92b0 "銰" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x11,0x11,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x88,0x88,0xfe,0x88,0x88,0x00,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 37553 0x92b1 "銱" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 37554 0x92b2 "銲" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x10,0xfd,0x10,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 37555 0x92b3 "銳" */
+0x10,0x10,0x28,0x25,0x42,0xbd,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1d,0xe2,0x44,
+0x10,0x90,0x88,0x08,0x04,0xfa,0x08,0x08,0x08,0xf8,0x90,0x90,0x90,0x12,0x12,0x0e,
+/* 37556 0x92b4 "銴" */
+0x08,0x08,0x7e,0x08,0x0e,0x78,0x08,0x29,0x16,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x0c,0xf0,0x80,0x80,0xfe,0x88,0x88,0x08,0xc8,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37557 0x92b5 "銵" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x13,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x40,0xf8,0x88,0xf8,0x88,0xf8,0x8a,0x8c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 37558 0x92b6 "銶" */
+0x10,0x10,0x28,0x24,0x43,0xb8,0x11,0x10,0xfc,0x10,0x94,0x59,0x52,0x1c,0xe0,0x40,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 37559 0x92b7 "銷" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 37560 0x92b8 "銸" */
+0x10,0x13,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1f,0xe0,0x40,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 37561 0x92b9 "銹" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x11,0x12,0xfd,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 37562 0x92ba "銺" */
+0x24,0x24,0x3d,0x04,0xfc,0x24,0x45,0x06,0x18,0xef,0x01,0x3f,0x09,0x05,0xff,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xf8,0x00,0xc0,0x30,0xee,0x00,0xf8,0x20,0x40,0xfe,0x00,
+/* 37563 0x92bb "銻" */
+0x11,0x10,0x28,0x25,0x40,0xb8,0x11,0x11,0xfd,0x11,0x94,0x58,0x51,0x1e,0xe4,0x40,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 37564 0x92bc "銼" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x12,0x10,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 37565 0x92bd "銽" */
+0x10,0x13,0x2a,0x26,0x43,0xba,0x12,0x13,0xfe,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x1c,0xe0,0x20,0x20,0xfe,0x20,0x90,0x0a,0x06,0xfa,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 37566 0x92be "銾" */
+0x20,0x21,0x50,0x48,0x83,0x78,0x20,0x20,0xfb,0x20,0x28,0xb1,0x61,0x3a,0xe4,0x00,
+0x00,0xfc,0x20,0x20,0xfe,0x00,0x20,0x22,0xb2,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 37567 0x92bf "銿" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 37568 0x92c0 "鋀" */
+0x10,0x11,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 37569 0x92c1 "鋁" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x11,0x95,0x59,0x51,0x1f,0xf1,0x41,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfe,0x02,
+/* 37570 0x92c2 "鋂" */
+0x10,0x10,0x28,0x25,0x42,0xb8,0x10,0x10,0xfd,0x10,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x80,0x80,0xfe,0x00,0xfc,0x84,0xa4,0x94,0xfe,0x84,0x24,0x14,0xfe,0x04,0x28,0x10,
+/* 37571 0x92c3 "鋃" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 37572 0x92c4 "鋄" */
+0x10,0x13,0x28,0x24,0x41,0xb8,0x10,0x11,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe0,0x47,
+0x00,0xfe,0x20,0xa4,0x28,0x50,0x88,0x04,0x00,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 37573 0x92c5 "鋅" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 37574 0x92c6 "鋆" */
+0x10,0x10,0x7d,0x10,0x10,0x1c,0xe1,0x06,0x18,0xef,0x01,0x3f,0x09,0x05,0xff,0x00,
+0x80,0xfc,0x04,0x44,0x34,0xc4,0x14,0xc8,0x30,0xee,0x00,0xf8,0x20,0x40,0xfe,0x00,
+/* 37575 0x92c7 "鋇" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x58,0x50,0x1c,0xe1,0x42,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x84,0x02,0x02,
+/* 37576 0x92c8 "鋈" */
+0x10,0x09,0x40,0x24,0x0b,0x70,0x10,0x11,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x1c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37577 0x92c9 "鋉" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x11,0xfd,0x10,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 37578 0x92ca "鋊" */
+0x10,0x10,0x29,0x26,0x40,0xb8,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x88,0x84,0x02,0x22,0x20,0x50,0x88,0x04,0x02,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37579 0x92cb "鋋" */
+0x20,0x20,0x53,0x48,0x80,0x79,0x21,0x23,0xf8,0x22,0x2a,0xb1,0x61,0x3a,0xe4,0x08,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 37580 0x92cc "鋌" */
+0x20,0x20,0x53,0x48,0x80,0x79,0x21,0x23,0xf8,0x22,0x2a,0xb1,0x61,0x3a,0xe4,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 37581 0x92cd "鋍" */
+0x20,0x20,0x53,0x48,0x80,0x7b,0x22,0x24,0xf9,0x20,0x28,0xb3,0x60,0x38,0xe0,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 37582 0x92ce "鋎" */
+0x10,0x10,0x29,0x25,0x42,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 37583 0x92cf "鋏" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0x74,0x22,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 37584 0x92d0 "鋐" */
+0x10,0x10,0x29,0x25,0x42,0xb8,0x11,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x44,
+0x40,0x20,0xfe,0x02,0x44,0x40,0xfe,0x40,0x50,0x90,0x90,0xa0,0x24,0x42,0x7e,0x22,
+/* 37585 0x92d1 "鋑" */
+0x10,0x10,0x28,0x25,0x43,0xb8,0x10,0x11,0xfe,0x10,0x95,0x5a,0x50,0x1c,0xe1,0x46,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 37586 0x92d2 "鋒" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x13,0xfc,0x10,0x94,0x58,0x53,0x1c,0xe0,0x40,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 37587 0x92d3 "鋓" */
+0x20,0x20,0x53,0x48,0x80,0x78,0x23,0x20,0xf9,0x21,0x2a,0xb2,0x64,0x38,0xe0,0x00,
+0x42,0xe2,0x82,0x8a,0x8a,0x8a,0xea,0x8a,0x8a,0xca,0xaa,0x82,0x82,0x82,0x8a,0x84,
+/* 37588 0x92d4 "鋔" */
+0x10,0x10,0x28,0x25,0x42,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 37589 0x92d5 "鋕" */
+0x20,0x20,0x50,0x4b,0x80,0x78,0x20,0x21,0xf8,0x20,0x28,0xb2,0x62,0x3a,0xe4,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 37590 0x92d6 "鋖" */
+0x10,0x10,0x29,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x59,0x50,0x1c,0xe0,0x43,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xfe,0x44,0x84,0xc8,0x30,0x28,0xc4,0x02,
+/* 37591 0x92d7 "鋗" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 37592 0x92d8 "鋘" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x10,0x11,0xfc,0x10,0x97,0x58,0x50,0x1c,0xe1,0x42,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 37593 0x92d9 "鋙" */
+0x10,0x11,0x28,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfe,0x20,0x20,0xfc,0x44,0x44,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 37594 0x92da "鋚" */
+0x10,0x10,0x24,0x64,0xa5,0x24,0x24,0x21,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x40,0x40,0xfe,0x88,0x50,0x20,0x50,0x88,0xc4,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37595 0x92db "鋛" */
+0x20,0x20,0x51,0x49,0x81,0x79,0x20,0x20,0xfb,0x22,0x2a,0xb3,0x62,0x38,0xe0,0x00,
+0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0xfe,0x22,0x20,0x20,0x20,
+/* 37596 0x92dc "鋜" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x10,0xfc,0x11,0x95,0x59,0x51,0x1e,0xe4,0x48,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0x3e,0x20,0x20,0xa0,0x7e,0x00,
+/* 37597 0x92dd "鋝" */
+0x10,0x10,0x29,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 37598 0x92de "鋞" */
+0x10,0x11,0x28,0x24,0x41,0xba,0x11,0x10,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0xfe,0x00,0x92,0x24,0x48,0x24,0x92,0x00,0xfe,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 37599 0x92df "鋟" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x10,0x13,0xfe,0x11,0x94,0x58,0x50,0x1c,0xe0,0x43,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 37600 0x92e0 "鋠" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 37601 0x92e1 "鋡" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfc,0x10,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 37602 0x92e2 "鋢" */
+0x10,0x10,0x29,0x24,0x41,0xb8,0x10,0x11,0xfc,0x10,0x97,0x58,0x50,0x1c,0xe0,0x40,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 37603 0x92e3 "鋣" */
+0x20,0x27,0x50,0x4c,0x84,0x7c,0x27,0x20,0xf9,0x21,0x2a,0xb2,0x64,0x38,0xe2,0x01,
+0x00,0xde,0x92,0x92,0x94,0x94,0xd8,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x90,0x10,
+/* 37604 0x92e4 "鋤" */
+0x20,0x20,0x53,0x4a,0x82,0x7a,0x23,0x22,0xfa,0x23,0x2a,0xb2,0x62,0x3b,0xe6,0x00,
+0x08,0x08,0xc8,0x48,0x5e,0x4a,0xca,0x4a,0x4a,0xca,0x4a,0x4a,0x6a,0xd2,0x12,0x26,
+/* 37605 0x92e5 "鋥" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x10,0xfd,0x10,0x94,0x59,0x50,0x1c,0xe3,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 37606 0x92e6 "鋦" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x52,0x1e,0xe4,0x40,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0xfe,0x02,0x7a,0x4a,0x4a,0x7a,0x02,0x14,0x08,
+/* 37607 0x92e7 "鋧" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x58,0x50,0x1d,0xe2,0x44,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x90,0x90,0x12,0x12,0x0e,
+/* 37608 0x92e8 "鋨" */
+0x20,0x20,0x53,0x48,0x80,0x7b,0x20,0x20,0xf8,0x20,0x2b,0xb0,0x60,0x38,0xe2,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 37609 0x92e9 "鋩" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x10,0x11,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x48,0x48,0xfe,0x48,0x48,0x20,0x10,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 37610 0x92ea "鋪" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 37611 0x92eb "鋫" */
+0x03,0x3c,0x04,0x7f,0x0e,0x15,0x64,0x05,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x04,0x04,0x24,0xa4,0x24,0x24,0x84,0x0c,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37612 0x92ec "鋬" */
+0x10,0x11,0xfd,0x11,0x1d,0xf1,0x12,0x31,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x1c,0xe0,0x00,0xfc,0x04,0x68,0x10,0x28,0xc4,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37613 0x92ed "鋭" */
+0x11,0x10,0x28,0x24,0x41,0xb9,0x11,0x11,0xfd,0x10,0x94,0x58,0x50,0x1d,0xe2,0x44,
+0x04,0x84,0x88,0x10,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,0x00,
+/* 37614 0x92ee "鋮" */
+0x20,0x20,0x50,0x48,0x83,0x7a,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x62,0x3d,0xe4,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 37615 0x92ef "鋯" */
+0x10,0x11,0x29,0x25,0x41,0xba,0x10,0x13,0xfc,0x10,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 37616 0x92f0 "鋰" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 37617 0x92f1 "鋱" */
+0x20,0x20,0x50,0x48,0x83,0x78,0x20,0x20,0xf8,0x20,0x28,0xb2,0x62,0x3a,0xe4,0x00,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x90,0x50,0x48,0x08,0x88,0xa8,0x9a,0xaa,0x66,0x02,
+/* 37618 0x92f2 "鋲" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x97,0x58,0x50,0x1d,0xe2,0x44,
+0x10,0x38,0xc0,0x00,0x00,0xfc,0x10,0x10,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,0x02,
+/* 37619 0x92f3 "鋳" */
+0x10,0x10,0x2b,0x24,0x41,0xb8,0x13,0x10,0xfc,0x10,0x95,0x59,0x52,0x1c,0xe0,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 37620 0x92f4 "鋴" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 37621 0x92f5 "鋵" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x11,0x12,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0x00,0xf8,0x88,0x88,0x88,0x8a,0x0a,0x06,
+/* 37622 0x92f6 "鋶" */
+0x10,0x10,0x29,0x24,0x42,0xbc,0x11,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x42,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 37623 0x92f7 "鋷" */
+0x20,0x27,0x52,0x4a,0x82,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x67,0x38,0xe0,0x00,
+0x00,0xe0,0x5e,0x52,0x52,0xd2,0x52,0x54,0xd4,0x54,0x48,0xe8,0x54,0x54,0x62,0x40,
+/* 37624 0x92f8 "鋸" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x42,
+0x00,0xfc,0x04,0x04,0xfc,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 37625 0x92f9 "鋹" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x13,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 37626 0x92fa "鋺" */
+0x20,0x20,0x53,0x4a,0x85,0x79,0x21,0x22,0xfa,0x23,0x2c,0xb0,0x61,0x39,0xe2,0x04,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xde,0x52,0x52,0x52,0x9a,0x94,0x10,0x12,0x12,0x0e,
+/* 37627 0x92fb "鋻" */
+0x7e,0x48,0x7e,0x42,0x7e,0x48,0x7e,0x01,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x7c,0x04,0x44,0x28,0x10,0x28,0xc4,0x00,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37628 0x92fc "鋼" */
+0x20,0x23,0x52,0x4a,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x22,0x22,0xaa,0xaa,0xaa,0xfa,0x02,0x02,0x0a,0x04,
+/* 37629 0x92fd "鋽" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x20,0x20,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 37630 0x92fe "鋾" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x40,0xfe,0x82,0x42,0x7a,0xa2,0x22,0xfe,0x22,0xaa,0xaa,0xfa,0x02,0x14,0x08,
+/* 37631 0x92ff "鋿" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 37632 0x9300 "錀" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 37633 0x9301 "錁" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x11,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 37634 0x9302 "錂" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x11,0xfe,0x10,0x95,0x5a,0x50,0x1c,0xe1,0x46,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 37635 0x9303 "錃" */
+0x10,0x09,0x41,0x25,0x09,0x11,0x72,0x14,0x11,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x20,0xfe,0x22,0x20,0xfc,0x04,0x68,0x10,0x28,0xc4,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37636 0x9304 "錄" */
+0x10,0x10,0x28,0x25,0x41,0xb8,0x10,0x13,0xfc,0x12,0x95,0x58,0x51,0x1e,0xe0,0x40,
+0x80,0xf8,0x88,0x08,0xf0,0x10,0x10,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 37637 0x9305 "錅" */
+0x06,0x38,0x08,0x7e,0x1c,0x2a,0x49,0x06,0x18,0xef,0x01,0x3f,0x09,0x05,0xff,0x00,
+0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0xc0,0x30,0xee,0x00,0xf8,0x20,0x40,0xfe,0x00,
+/* 37638 0x9306 "錆" */
+0x10,0x10,0x2b,0x24,0x41,0xb8,0x13,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 37639 0x9307 "錇" */
+0x10,0x10,0x29,0x24,0x41,0xb8,0x10,0x13,0xfc,0x10,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x80,0x40,0xfc,0x00,0x08,0x88,0x90,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 37640 0x9308 "錈" */
+0x10,0x11,0x28,0x24,0x41,0xb8,0x13,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 37641 0x9309 "錉" */
+0x10,0x13,0x2a,0x27,0x42,0xba,0x13,0x12,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x1c,0xe0,0x20,0xfe,0x20,0x92,0x0a,0x06,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37642 0x930a "錊" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x11,0x12,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x00,0x88,0x88,0x54,0x22,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 37643 0x930b "錋" */
+0x20,0x23,0x52,0x4a,0x82,0x7b,0x22,0x22,0xfa,0x23,0x2a,0xb2,0x62,0x3a,0xe5,0x08,
+0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0xde,0x52,0x52,0x52,0x52,0x52,0xa6,
+/* 37644 0x930c "錌" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0x7c,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 37645 0x930d "錍" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x10,0x95,0x5b,0x50,0x1c,0xe0,0x40,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 37646 0x930e "錎" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 37647 0x930f "錏" */
+0x10,0x13,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1c,0xe3,0x40,
+0x00,0xfe,0x50,0x50,0x50,0xdc,0x04,0x04,0x04,0xdc,0x50,0x50,0x50,0x50,0xfe,0x00,
+/* 37648 0x9310 "錐" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 37649 0x9311 "錑" */
+0x20,0x20,0x53,0x4a,0x82,0x7b,0x22,0x22,0xfa,0x23,0x2a,0xb2,0x62,0x3c,0xe5,0x0a,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x28,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 37650 0x9312 "錒" */
+0x20,0x27,0x55,0x4d,0x85,0x75,0x26,0x25,0xf5,0x25,0xa5,0x75,0x26,0x34,0xc4,0x04,
+0x00,0x7e,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x14,0x08,
+/* 37651 0x9313 "錓" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x11,0x10,0xfc,0x13,0x94,0x58,0x50,0x1c,0xe1,0x42,
+0x88,0x48,0x50,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 37652 0x9314 "錔" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x12,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37653 0x9315 "錕" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 37654 0x9316 "錖" */
+0x08,0x0e,0x08,0x7f,0x08,0x2a,0x49,0x19,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x00,0x7c,0x04,0x44,0x28,0x10,0x28,0x44,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37655 0x9317 "錗" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x11,0x12,0xfc,0x13,0x94,0x59,0x50,0x1c,0xe0,0x41,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 37656 0x9318 "錘" */
+0x20,0x20,0x51,0x48,0x83,0x78,0x20,0x20,0xfb,0x20,0x28,0xb3,0x60,0x38,0xe1,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xfe,0x20,0x20,0xfc,0x00,
+/* 37657 0x9319 "錙" */
+0x10,0x10,0x29,0x26,0x41,0xb8,0x10,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 37658 0x931a "錚" */
+0x10,0x10,0x28,0x25,0x42,0xb9,0x10,0x10,0xfd,0x10,0x94,0x59,0x50,0x1c,0xe0,0x40,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 37659 0x931b "錛" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x12,0x10,0xfc,0x10,0x97,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0xfe,0x50,0xa8,0x24,0xfa,0x20,0xa8,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 37660 0x931c "錜" */
+0x20,0x20,0x50,0x48,0x81,0x7a,0x21,0x20,0xf8,0x20,0x28,0xb2,0x62,0x3a,0xe4,0x00,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 37661 0x931d "錝" */
+0x20,0x20,0x53,0x4a,0x80,0x79,0x20,0x20,0xfb,0x20,0x29,0xb1,0x62,0x3c,0xe0,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 37662 0x931e "錞" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x10,0xfd,0x10,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x20,0x20,0xa0,0x40,
+/* 37663 0x931f "錟" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x13,0x10,0xfc,0x10,0x94,0x59,0x50,0x1c,0xe1,0x42,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 37664 0x9320 "錠" */
+0x20,0x20,0x53,0x4a,0x84,0x78,0x23,0x20,0xf8,0x21,0x29,0xb1,0x62,0x3a,0xe4,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 37665 0x9321 "錡" */
+0x10,0x10,0x29,0x24,0x40,0xb9,0x13,0x10,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 37666 0x9322 "錢" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x10,0x11,0xfe,0x10,0x95,0x58,0x50,0x1e,0xf0,0x41,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 37667 0x9323 "錣" */
+0x20,0x23,0x50,0x49,0x80,0x79,0x22,0x24,0xf8,0x23,0x28,0xb1,0x60,0x39,0xe2,0x04,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 37668 0x9324 "錤" */
+0x10,0x10,0x2b,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x5b,0x50,0x1e,0xf1,0x42,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 37669 0x9325 "錥" */
+0x10,0x10,0x2b,0x24,0x41,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x40,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 37670 0x9326 "錦" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 37671 0x9327 "錧" */
+0x10,0x10,0x29,0x25,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0xfc,0x84,
+/* 37672 0x9328 "錨" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 37673 0x9329 "錩" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37674 0x932a "錪" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x5b,0x50,0x1c,0xe0,0x41,
+0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0xfe,0x00,0x50,0x88,0x04,
+/* 37675 0x932b "錫" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x10,0x95,0x5a,0x50,0x1d,0xe0,0x40,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 37676 0x932c "錬" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x10,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 37677 0x932d "錭" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 37678 0x932e "錮" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 37679 0x932f "錯" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x11,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 37680 0x9330 "錰" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x51,0x1d,0xe2,0x40,
+0x20,0x20,0x20,0xfe,0x20,0x70,0xa8,0xa8,0x24,0x22,0x20,0x00,0x54,0x2a,0x2a,0x00,
+/* 37681 0x9331 "錱" */
+0x01,0x02,0x0c,0x30,0xdf,0x01,0x3f,0x11,0x09,0x7f,0x00,0x7e,0x08,0x3e,0x08,0x7e,
+0x00,0x80,0x60,0x18,0xf6,0x00,0xf8,0x10,0x20,0xfc,0x00,0xfe,0x10,0x7c,0x10,0xfe,
+/* 37682 0x9332 "録" */
+0x10,0x11,0x28,0x24,0x41,0xb8,0x10,0x13,0xfc,0x12,0x95,0x58,0x51,0x1e,0xe0,0x40,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xfe,0x20,0x22,0x74,0xa8,0x24,0x22,0xa0,0x40,
+/* 37683 0x9333 "錳" */
+0x10,0x11,0x28,0x24,0x40,0xbb,0x10,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe3,0x40,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 37684 0x9334 "錴" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x11,0xfe,0x10,0x95,0x58,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 37685 0x9335 "錵" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x10,0x10,0xfd,0x12,0x94,0x58,0x50,0x1c,0xe0,0x40,
+0x88,0x88,0xfe,0x88,0x88,0x50,0x50,0x94,0x94,0x98,0x90,0xb2,0xd2,0x92,0x8e,0x80,
+/* 37686 0x9336 "錶" */
+0x20,0x20,0x53,0x48,0x80,0x79,0x20,0x20,0xfb,0x20,0x28,0xb1,0x62,0x3c,0xe0,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0xa4,0xa8,0x90,0x88,0xc6,0x80,
+/* 37687 0x9337 "錷" */
+0x20,0x20,0x20,0x57,0x88,0x73,0x22,0x23,0xfa,0x23,0x28,0xb7,0x60,0x38,0xe0,0x00,
+0x88,0x88,0x88,0xe8,0x88,0xe8,0xa8,0xe8,0xa8,0xe8,0x88,0xe8,0x8a,0x8a,0x8a,0x86,
+/* 37688 0x9338 "錸" */
+0x20,0x20,0x50,0x4b,0x80,0x79,0x21,0x21,0xfa,0x20,0x28,0xb0,0x61,0x3a,0xe4,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xaa,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 37689 0x9339 "錹" */
+0x10,0x11,0x29,0x25,0x41,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 37690 0x933a "錺" */
+0x11,0x11,0x2b,0x25,0x41,0xb8,0x13,0x10,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe1,0x42,
+0x08,0x08,0xfe,0x08,0x48,0x20,0xfe,0x80,0x80,0xf8,0x88,0x88,0x88,0x08,0x28,0x10,
+/* 37691 0x933b "錻" */
+0x20,0x20,0x51,0x48,0x80,0x7b,0x20,0x20,0xf8,0x22,0x2a,0xb2,0x62,0x3a,0xe7,0x02,
+0x10,0x14,0xd2,0x12,0x10,0xfe,0x10,0x90,0x90,0xd0,0x90,0x90,0x8a,0xea,0x06,0x02,
+/* 37692 0x933c "錼" */
+0x20,0x20,0x53,0x48,0x80,0x79,0x22,0x20,0xf8,0x23,0x28,0xb1,0x61,0x3a,0xe0,0x00,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0x00,0xfe,0x20,0x24,0x22,0x22,0xa0,0x40,
+/* 37693 0x933d "錽" */
+0x10,0x13,0x28,0x24,0x41,0xb8,0x10,0x11,0xfc,0x10,0x95,0x5a,0x50,0x1c,0xe0,0x47,
+0x00,0xfe,0x20,0xa4,0x28,0x50,0x88,0x44,0x40,0xfc,0x84,0x88,0x50,0x20,0xd8,0x06,
+/* 37694 0x933e "錾" */
+0x10,0xff,0x28,0x7f,0x08,0x0f,0xf8,0x09,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x04,0x78,0x40,0x7e,0x48,0x48,0x88,0x08,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37695 0x933f "錿" */
+0x10,0x10,0x28,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x52,0x1e,0xe4,0x49,
+0x20,0x20,0x3e,0x20,0xfe,0x22,0x38,0xe0,0x22,0x1e,0x00,0x78,0x48,0x4a,0x8a,0x06,
+/* 37696 0x9340 "鍀" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x11,0xfc,0x13,0x94,0x59,0x50,0x1c,0xe0,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x08,0xfe,0x08,0x08,0x88,0x08,0x28,0x10,
+/* 37697 0x9341 "鍁" */
+0x20,0x20,0x57,0x4c,0x84,0x74,0x27,0x25,0xf5,0x25,0xa5,0x75,0x25,0x39,0xc9,0x10,
+0x10,0x90,0x10,0x3e,0x22,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 37698 0x9342 "鍂" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfc,0x11,0x94,0x59,0x50,0x1c,0xe3,0x40,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0xfe,0x00,
+/* 37699 0x9343 "鍃" */
+0x20,0x20,0x50,0x49,0x82,0x78,0x21,0x22,0xf8,0x21,0x28,0xb0,0x62,0x3a,0xe4,0x00,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 37700 0x9344 "鍄" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x11,0xfd,0x10,0x95,0x59,0x52,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 37701 0x9345 "鍅" */
+0x22,0x21,0x21,0x54,0x8a,0x72,0x20,0x21,0xf9,0x22,0x2e,0xb2,0x62,0x3a,0xe2,0x00,
+0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x7e,0x10,0x10,0x20,0x24,0x42,0xfe,0x42,0x00,
+/* 37702 0x9346 "鍆" */
+0x20,0x23,0x52,0x4a,0x83,0x7a,0x22,0x23,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x04,
+/* 37703 0x9347 "鍇" */
+0x11,0x11,0x29,0x25,0x41,0xb9,0x11,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37704 0x9348 "鍈" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x11,0x11,0xfd,0x11,0x97,0x58,0x50,0x1c,0xe1,0x42,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 37705 0x9349 "鍉" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x13,0x94,0x59,0x51,0x1d,0xe2,0x44,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 37706 0x934a "鍊" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x50,0x1d,0xe2,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 37707 0x934b "鍋" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xf8,0x88,0x88,0xe8,0xa8,0xa8,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 37708 0x934c "鍌" */
+0x00,0x11,0x49,0x22,0x0b,0x10,0x70,0x11,0x16,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x20,0x20,0xfc,0x20,0xfe,0x90,0x92,0x0e,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37709 0x934d "鍍" */
+0x20,0x20,0x53,0x4a,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3c,0xe4,0x09,
+0x40,0x20,0xfe,0x48,0x48,0xfe,0x48,0x78,0x00,0xfc,0x44,0x48,0x28,0x10,0x68,0x86,
+/* 37710 0x934e "鍎" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x08,0x1c,0xf0,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 37711 0x934f "鍏" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x10,0xfc,0x10,0x95,0x58,0x51,0x1d,0xe0,0x40,
+0x20,0x20,0xfc,0x44,0xfe,0x00,0xfc,0x84,0xfc,0x20,0xfe,0x20,0x20,0xfe,0x20,0x20,
+/* 37712 0x9350 "鍐" */
+0x20,0x20,0x52,0x4a,0x82,0x7a,0x22,0x23,0xf8,0x21,0x2a,0xb0,0x61,0x38,0xe0,0x07,
+0x00,0x88,0x52,0x22,0x52,0x8a,0x02,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 37713 0x9351 "鍑" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfc,0x10,0x94,0x58,0x51,0x1c,0xe0,0x41,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 37714 0x9352 "鍒" */
+0x10,0x10,0x28,0x24,0x41,0xb8,0x10,0x11,0xfe,0x10,0x95,0x58,0x50,0x1d,0xe2,0x40,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37715 0x9353 "鍓" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe0,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x9e,0xe8,0x08,0x08,
+/* 37716 0x9354 "鍔" */
+0x20,0x23,0x52,0x4a,0x83,0x78,0x21,0x20,0xfb,0x20,0x29,0xb1,0x60,0x38,0xe0,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 37717 0x9355 "鍕" */
+0x10,0x13,0x2a,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x95,0x58,0x53,0x1c,0xe0,0x40,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 37718 0x9356 "鍖" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x10,0x10,0xfc,0x13,0x95,0x59,0x51,0x1d,0xe1,0x40,
+0x88,0x88,0xfe,0x88,0xf8,0x88,0xf8,0x88,0x88,0xfe,0x00,0x48,0x84,0x00,0xfe,0x00,
+/* 37719 0x9357 "鍗" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x13,0x12,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe0,0x40,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x22,0x24,0xfc,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 37720 0x9358 "鍘" */
+0x20,0x23,0x52,0x4a,0x83,0x7a,0x22,0x23,0xfa,0x22,0x2b,0xb0,0x61,0x39,0xe2,0x04,
+0x02,0xc2,0x42,0x52,0xd2,0x52,0x52,0xd2,0x52,0x52,0xd2,0x02,0x82,0x42,0x4a,0x04,
+/* 37721 0x9359 "鍙" */
+0x10,0x08,0x43,0x20,0x08,0x17,0x70,0x11,0x16,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x90,0x90,0xfc,0x90,0x90,0xfe,0x90,0x08,0xc4,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37722 0x935a "鍚" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x11,0xfc,0x10,0x95,0x5a,0x50,0x1d,0xe0,0x40,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 37723 0x935b "鍛" */
+0x20,0x23,0x52,0x4a,0x83,0x7a,0x22,0x22,0xfb,0x22,0x2a,0xb3,0x66,0x3a,0xe2,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 37724 0x935c "鍜" */
+0x20,0x23,0x52,0x4a,0x82,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb3,0x62,0x3a,0xe2,0x02,
+0x00,0xde,0x42,0x42,0x42,0xde,0x00,0x3e,0xd2,0x12,0x14,0xd4,0x08,0x14,0x24,0x42,
+/* 37725 0x935d "鍝" */
+0x11,0x11,0x29,0x25,0x41,0xb9,0x11,0x10,0xfc,0x13,0x96,0x5a,0x52,0x1e,0xe2,0x42,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 37726 0x935e "鍞" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x3e,0x20,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,0x02,
+/* 37727 0x935f "鍟" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x11,0xfd,0x12,0x94,0x59,0x50,0x1c,0xe3,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 37728 0x9360 "鍠" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfd,0x10,0x94,0x58,0x50,0x1c,0xe1,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 37729 0x9361 "鍡" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x13,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 37730 0x9362 "鍢" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 37731 0x9363 "鍣" */
+0x10,0x10,0x29,0x24,0x42,0xbd,0x10,0x10,0xfe,0x11,0x96,0x58,0x50,0x1e,0xf0,0x40,
+0x48,0x48,0xfe,0x48,0x00,0xfc,0x44,0x44,0x94,0x08,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 37732 0x9364 "鍤" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 37733 0x9365 "鍥" */
+0x10,0x10,0x2b,0x24,0x41,0xb8,0x13,0x10,0xfc,0x10,0x97,0x58,0x50,0x1c,0xe1,0x46,
+0x80,0x9e,0xea,0x8a,0xca,0x8a,0xea,0x92,0xa6,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 37734 0x9366 "鍦" */
+0x22,0x21,0x21,0x57,0x8a,0x72,0x23,0x22,0xfa,0x22,0x2a,0xb2,0x64,0x3c,0xe9,0x10,
+0x10,0x10,0x10,0xbe,0x28,0x48,0xaa,0xae,0xba,0xea,0xae,0xa8,0xaa,0xa2,0xa2,0x1e,
+/* 37735 0x9367 "鍧" */
+0x10,0x10,0x28,0x25,0x42,0xb9,0x10,0x11,0xfc,0x11,0x94,0x59,0x51,0x1d,0xe0,0x40,
+0x80,0x80,0xfe,0x02,0x42,0xfa,0x02,0xf2,0x02,0xf2,0x02,0xf2,0x12,0xf2,0x14,0x08,
+/* 37736 0x9368 "鍨" */
+0x10,0x11,0x28,0x26,0x41,0xb8,0x11,0x12,0xfc,0x10,0x95,0x58,0x50,0x1c,0xe1,0x42,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 37737 0x9369 "鍩" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x13,0x10,0xfc,0x10,0x95,0x5a,0x50,0x1c,0xe0,0x40,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 37738 0x936a "鍪" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x99,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x20,0x20,0x7e,0x84,0x28,0x10,0x28,0x44,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37739 0x936b "鍫" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x09,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0x04,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37740 0x936c "鍬" */
+0x20,0x21,0x57,0x49,0x81,0x71,0x27,0x21,0xf3,0x23,0xa5,0x75,0x29,0x31,0xc1,0x01,
+0x88,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 37741 0x936d "鍭" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 37742 0x936e "鍮" */
+0x20,0x20,0x51,0x4a,0x85,0x78,0x23,0x22,0xfa,0x23,0x2a,0xb2,0x63,0x3a,0xe2,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 37743 0x936f "鍯" */
+0x20,0x20,0x50,0x49,0x82,0x78,0x21,0x22,0xf8,0x21,0x28,0xb0,0x62,0x3a,0xe4,0x00,
+0x80,0x80,0xfc,0x54,0xd4,0xb4,0x2c,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 37744 0x9370 "鍰" */
+0x10,0x13,0x28,0x25,0x40,0xb9,0x10,0x10,0xfd,0x10,0x94,0x59,0x51,0x1e,0xe0,0x41,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 37745 0x9371 "鍱" */
+0x20,0x21,0x51,0x4b,0x81,0x79,0x21,0x21,0xf9,0x20,0x2b,0xb0,0x60,0x39,0xe6,0x00,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37746 0x9372 "鍲" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x10,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0xfc,0x10,0xfe,0x10,0x4a,0x86,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 37747 0x9373 "鍳" */
+0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x01,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x20,0x20,0x3e,0x40,0x50,0x88,0x08,0x00,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37748 0x9374 "鍴" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x13,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x0c,
+/* 37749 0x9375 "鍵" */
+0x20,0x20,0x57,0x49,0x81,0x72,0x22,0x27,0xf1,0x25,0xa5,0x72,0x22,0x35,0xc8,0x00,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 37750 0x9376 "鍶" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x10,0x94,0x59,0x51,0x1d,0xe2,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 37751 0x9377 "鍷" */
+0x10,0x10,0x2b,0x24,0x40,0xbb,0x11,0x10,0xfc,0x13,0x94,0x58,0x51,0x1c,0xe0,0x43,
+0x20,0x20,0xfe,0x50,0x88,0x26,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfc,0x20,0x20,0xfe,
+/* 37752 0x9378 "鍸" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x80,0x9e,0x92,0xd2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 37753 0x9379 "鍹" */
+0x10,0x10,0x2b,0x26,0x44,0xb9,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe3,0x40,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,0xfe,0x00,
+/* 37754 0x937a "鍺" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 37755 0x937b "鍻" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x11,0xfe,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 37756 0x937c "鍼" */
+0x20,0x20,0x50,0x4b,0x82,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x04,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 37757 0x937d "鍽" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x96,0x5a,0x54,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 37758 0x937e "鍾" */
+0x10,0x10,0x29,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x95,0x58,0x51,0x1c,0xe3,0x40,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 37759 0x937f "鍿" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x40,
+0x52,0x52,0xa4,0xfe,0xa4,0x52,0x52,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 37760 0x9380 "鎀" */
+0x10,0x10,0x28,0x25,0x41,0xbb,0x15,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x90,0x9e,0xa2,0x54,0x08,0x54,0x62,0x40,0x44,0x58,0x42,0x44,0x18,0x02,0x0c,0x30,
+/* 37761 0x9381 "鎁" */
+0x20,0x2f,0x54,0x4c,0x84,0x77,0x24,0x24,0xf7,0x24,0xa4,0x75,0x2e,0x30,0xc0,0x00,
+0x00,0xde,0x92,0x92,0x94,0x94,0x98,0x94,0x92,0x92,0x92,0xda,0x94,0x90,0x90,0x90,
+/* 37762 0x9382 "鎂" */
+0x11,0x10,0x2b,0x24,0x40,0xb9,0x10,0x10,0xfd,0x10,0x94,0x5b,0x50,0x1c,0xe0,0x43,
+0x04,0x88,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 37763 0x9383 "鎃" */
+0x20,0x24,0x52,0x4a,0x88,0x74,0x24,0x22,0xf2,0x24,0xac,0x74,0x24,0x35,0xc5,0x02,
+0x08,0x1c,0xe0,0x80,0x8c,0xb0,0xa8,0xaa,0xac,0xa8,0xa8,0xa8,0xa4,0x24,0x32,0x20,
+/* 37764 0x9384 "鎄" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x10,0x94,0x59,0x52,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0x04,0x04,0xfc,0x52,0x94,0x88,0x88,0xa4,0xc2,0x80,
+/* 37765 0x9385 "鎅" */
+0x11,0x11,0x29,0x25,0x41,0xb9,0x11,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe1,0x42,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,
+/* 37766 0x9386 "鎆" */
+0x21,0x20,0x50,0x4b,0x80,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb3,0x62,0x3a,0xe2,0x02,
+0x08,0x88,0x90,0xfe,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x44,0x54,0xc8,
+/* 37767 0x9387 "鎇" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 37768 0x9388 "鎈" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x11,0xfc,0x10,0x94,0x59,0x52,0x1c,0xe1,0x40,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 37769 0x9389 "鎉" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x13,0xfc,0x12,0x95,0x58,0x53,0x1c,0xe1,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xde,0x42,0x52,0x4a,0xc6,0x5a,0x42,0x4a,0x84,
+/* 37770 0x938a "鎊" */
+0x10,0x10,0x29,0x24,0x40,0xb9,0x11,0x12,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe0,0x41,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 37771 0x938b "鎋" */
+0x20,0x20,0x53,0x4a,0x84,0x79,0x20,0x21,0xf8,0x23,0x28,0xb1,0x61,0x39,0xe1,0x01,
+0x40,0x20,0xfe,0x02,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 37772 0x938c "鎌" */
+0x10,0x10,0x28,0x25,0x40,0xb9,0x10,0x13,0xfc,0x11,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 37773 0x938d "鎍" */
+0x20,0x20,0x53,0x48,0x83,0x7a,0x24,0x21,0xf8,0x20,0x2b,0xb0,0x61,0x3a,0xe4,0x00,
+0x20,0x20,0xfe,0x20,0xfe,0x42,0x8c,0xf0,0x20,0x44,0xfe,0x22,0x28,0x24,0xa4,0x40,
+/* 37774 0x938e "鎎" */
+0x21,0x21,0x51,0x4a,0x85,0x78,0x23,0x20,0xfa,0x21,0x2b,0xb0,0x61,0x3a,0xe0,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x88,0xa8,0xc8,0xf8,0x8a,0xca,0xaa,0x86,0x82,
+/* 37775 0x938f "鎏" */
+0x20,0x17,0x80,0x49,0x13,0xe1,0x22,0x24,0x01,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x40,0xfe,0x90,0x08,0xfc,0x50,0x52,0x4e,0x00,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37776 0x9390 "鎐" */
+0x10,0x10,0x2b,0x24,0x42,0xb9,0x11,0x12,0xfc,0x13,0x94,0x59,0x51,0x1d,0xe1,0x40,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 37777 0x9391 "鎑" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x10,0x10,0xfd,0x10,0x95,0x59,0x51,0x1d,0xe3,0x40,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x84,0xfe,0x02,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 37778 0x9392 "鎒" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x00,0xfe,0x00,0x7e,0x00,0xfe,0x54,0x48,0x64,0x42,0x04,0xfe,0x44,0x24,0x04,0x0c,
+/* 37779 0x9393 "鎓" */
+0x20,0x20,0x51,0x4a,0x84,0x79,0x20,0x20,0xfb,0x20,0x2a,0xb1,0x62,0x38,0xe1,0x00,
+0x90,0x88,0x04,0x42,0x88,0xfc,0x04,0x00,0xde,0x42,0x52,0x4a,0x52,0x42,0x4a,0x84,
+/* 37780 0x9394 "鎔" */
+0x10,0x10,0x2b,0x26,0x40,0xb8,0x11,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 37781 0x9395 "鎕" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 37782 0x9396 "鎖" */
+0x10,0x11,0x28,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x41,
+0x20,0x24,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x00,0x88,0x04,
+/* 37783 0x9397 "鎗" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x12,0x10,0xfc,0x10,0x94,0x58,0x51,0x1d,0xe2,0x40,
+0x20,0x20,0x50,0x48,0xa4,0xfe,0x84,0xfc,0x84,0xfc,0x80,0xfc,0x44,0x44,0x7c,0x44,
+/* 37784 0x9398 "鎘" */
+0x20,0x23,0x50,0x49,0x81,0x79,0x21,0x20,0xfb,0x22,0x2a,0xb3,0x62,0x3a,0xe2,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 37785 0x9399 "鎙" */
+0x24,0x22,0x52,0x48,0x87,0x79,0x25,0x25,0xfd,0x27,0x29,0xb1,0x62,0x3a,0xe4,0x08,
+0x40,0x5e,0x92,0x12,0xd2,0x1e,0x52,0x52,0x52,0xde,0x52,0x12,0x12,0x22,0x2a,0x44,
+/* 37786 0x939a "鎚" */
+0x10,0x12,0x29,0x25,0x40,0xb8,0x13,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe4,0x40,
+0x10,0x20,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7c,0x44,0x44,0x7c,0x44,0x80,0x7e,0x00,
+/* 37787 0x939b "鎛" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 37788 0x939c "鎜" */
+0x10,0x3e,0x2a,0x22,0xfe,0x2b,0x42,0x4a,0x85,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xc4,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37789 0x939d "鎝" */
+0x10,0x10,0x2b,0x24,0x40,0xb8,0x10,0x11,0xfe,0x10,0x94,0x59,0x51,0x1d,0xe1,0x41,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 37790 0x939e "鎞" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x10,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0xfc,0x00,0x12,0xd4,0x18,0x52,0x92,0x0e,
+/* 37791 0x939f "鎟" */
+0x21,0x20,0x50,0x49,0x80,0x7b,0x22,0x21,0xfa,0x20,0x2b,0xb0,0x60,0x39,0xe6,0x00,
+0xf8,0x88,0x70,0x8c,0x00,0xde,0x52,0x8c,0x52,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37792 0x93a0 "鎠" */
+0x20,0x23,0x52,0x4a,0x83,0x78,0x20,0x23,0xf8,0x20,0x29,0xb1,0x61,0x39,0xe7,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x00,0x00,0xfe,0x20,0x20,0x3c,0x20,0x20,0x20,0xfe,0x00,
+/* 37793 0x93a1 "鎡" */
+0x20,0x20,0x50,0x4b,0x80,0x78,0x21,0x21,0xfa,0x23,0x28,0xb1,0x61,0x3a,0xe3,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 37794 0x93a2 "鎢" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5a,0x52,0x1c,0xe0,0x40,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 37795 0x93a3 "鎣" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x41,0x86,0x18,0xef,0x01,0x3f,0x09,0x05,0xff,0x00,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xc4,0x30,0xee,0x00,0xf8,0x20,0x40,0xfe,0x00,
+/* 37796 0x93a4 "鎤" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x11,0xfc,0x10,0x97,0x58,0x50,0x1d,0xe2,0x44,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x24,0xa8,0x20,0xfe,0x90,0x90,0x12,0x12,0x0e,
+/* 37797 0x93a5 "鎥" */
+0x10,0x11,0x22,0x68,0xab,0x28,0x29,0x28,0x21,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x80,0xf8,0x88,0x70,0x8e,0x20,0xfc,0xa8,0x64,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37798 0x93a6 "鎦" */
+0x20,0x23,0x52,0x4a,0x82,0x7a,0x23,0x20,0xfb,0x22,0x2a,0xb3,0x62,0x3a,0xe3,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 37799 0x93a7 "鎧" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x13,0x10,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe3,0x40,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 37800 0x93a8 "鎨" */
+0x10,0x10,0x29,0x27,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe0,0x40,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 37801 0x93a9 "鎩" */
+0x20,0x24,0x52,0x49,0x82,0x74,0x21,0x21,0xf7,0x21,0xa5,0x75,0x29,0x31,0xc5,0x02,
+0x00,0x5c,0x94,0x14,0x94,0x54,0x26,0x00,0xdc,0x14,0x94,0x54,0x48,0x08,0x14,0x22,
+/* 37802 0x93aa "鎪" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x11,0x94,0x58,0x50,0x1c,0xe0,0x43,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 37803 0x93ab "鎫" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfc,0x11,0x96,0x58,0x51,0x1c,0xe0,0x47,
+0x20,0x40,0xfc,0x04,0x54,0x24,0x54,0x04,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 37804 0x93ac "鎬" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 37805 0x93ad "鎭" */
+0x11,0x11,0x29,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x18,0xe0,0x02,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x88,0x04,
+/* 37806 0x93ae "鎮" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x53,0x1c,0xe1,0x42,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 37807 0x93af "鎯" */
+0x21,0x20,0x53,0x4a,0x82,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x62,0x3b,0xe2,0x00,
+0x00,0x9e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x92,0x5a,0xd4,0x50,0x10,0x10,
+/* 37808 0x93b0 "鎰" */
+0x10,0x10,0x28,0x25,0x40,0xb8,0x10,0x11,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe3,0x40,
+0x88,0x50,0x00,0xfc,0x00,0x50,0x88,0x04,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 37809 0x93b1 "鎱" */
+0x10,0x10,0x29,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x94,0x58,0x51,0x1e,0xe0,0x40,
+0x20,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x52,0x94,0x88,0xa4,0xc2,0x80,
+/* 37810 0x93b2 "鎲" */
+0x10,0x11,0x28,0x24,0x43,0xba,0x10,0x11,0xfd,0x11,0x95,0x58,0x50,0x1c,0xe1,0x42,
+0x20,0x24,0xa8,0x20,0xfe,0x02,0x00,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 37811 0x93b3 "鎳" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x10,0x95,0x58,0x50,0x1d,0xe2,0x40,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37812 0x93b4 "鎴" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x10,0x94,0x58,0x52,0x1e,0xe4,0x40,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x40,0x20,0xa4,0x8a,0x8a,0x78,0x00,
+/* 37813 0x93b5 "鎵" */
+0x20,0x20,0x53,0x4a,0x80,0x79,0x20,0x20,0xfb,0x20,0x28,0xb3,0x60,0x38,0xe3,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 37814 0x93b6 "鎶" */
+0x10,0x13,0x28,0x25,0x41,0xb9,0x10,0x13,0xfc,0x11,0x95,0x59,0x51,0x1c,0xe0,0x40,
+0x00,0xfe,0x08,0xe8,0x28,0xe8,0x00,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x08,0x28,0x10,
+/* 37815 0x93b7 "鎷" */
+0x20,0x21,0x51,0x49,0x81,0x79,0x21,0x21,0xf9,0x20,0x2a,0xb2,0x62,0x3a,0xe0,0x00,
+0x00,0xfe,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0xaa,0x02,0x14,0x08,
+/* 37816 0x93b8 "鎸" */
+0x20,0x20,0x51,0x4b,0x85,0x79,0x21,0x21,0xf9,0x21,0x2b,0xb0,0x60,0x39,0xe2,0x04,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 37817 0x93b9 "鎹" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x10,0x11,0xfc,0x10,0x94,0x58,0x50,0x1d,0xe2,0x40,
+0x22,0x12,0x14,0x80,0xbe,0x08,0x08,0xbe,0x88,0x88,0x94,0x92,0xa2,0x40,0x3e,0x00,
+/* 37818 0x93ba "鎺" */
+0x22,0x21,0x51,0x48,0x87,0x78,0x21,0x21,0xfb,0x25,0x29,0xb1,0x61,0x39,0xe1,0x01,
+0x00,0x00,0x3c,0x24,0xa4,0xa4,0x3c,0x24,0xa4,0x64,0x3c,0x24,0x24,0x24,0x7e,0x00,
+/* 37819 0x93bb "鎻" */
+0x10,0x11,0x2a,0x25,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe1,0x42,
+0x92,0x24,0x48,0x24,0x92,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 37820 0x93bc "鎼" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe2,0x1e,0x04,0x78,0x10,0x7c,0x10,0xfe,0x10,0x30,
+/* 37821 0x93bd "鎽" */
+0x20,0x22,0x53,0x48,0x81,0x7a,0x20,0x23,0xf8,0x21,0x28,0xb1,0x60,0x3b,0xe0,0x00,
+0x20,0x22,0xfe,0x80,0xf8,0x88,0x70,0x8e,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 37822 0x93be "鎾" */
+0x10,0x10,0x28,0x24,0x40,0xb8,0x10,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe3,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 37823 0x93bf "鎿" */
+0x10,0x10,0x28,0x25,0x42,0xb8,0x10,0x10,0xfc,0x11,0x94,0x59,0x50,0x1d,0xe0,0x40,
+0x20,0x50,0x88,0x74,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0x60,
+/* 37824 0x93c0 "鏀" */
+0x20,0x20,0x50,0x48,0x80,0x7b,0x22,0x23,0xfa,0x22,0x2b,0xb2,0x62,0x3b,0xe3,0x02,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x02,0x26,0x8a,0x52,0x26,0x52,0x8a,0x26,0xfe,0x02,
+/* 37825 0x93c1 "鏁" */
+0x11,0x12,0x29,0x24,0x41,0xb9,0x11,0x11,0xfd,0x10,0x97,0x58,0x50,0x1d,0xe6,0x40,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37826 0x93c2 "鏂" */
+0x20,0x23,0x52,0x4a,0x82,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe3,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 37827 0x93c3 "鏃" */
+0x22,0x21,0x51,0x4f,0x82,0x7a,0x23,0x22,0xfa,0x22,0x2a,0xb2,0x64,0x3d,0xe8,0x10,
+0x20,0x20,0x20,0xbe,0x40,0x20,0xbc,0xd0,0x90,0x90,0xfe,0x90,0xa8,0xa8,0x44,0x82,
+/* 37828 0x93c4 "鏄" */
+0x10,0x13,0x28,0x25,0x41,0xb9,0x11,0x11,0xfc,0x13,0x94,0x5b,0x51,0x1c,0xe0,0x40,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 37829 0x93c5 "鏅" */
+0x21,0x21,0x21,0x52,0x8a,0x76,0x2a,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0x20,0x3c,0x44,0xa8,0x10,0xa8,0xc6,0xbc,0xa4,0xbc,0xa4,0xbc,0x24,0x24,0x24,0x2c,
+/* 37830 0x93c6 "鏆" */
+0x10,0x11,0x29,0x27,0x41,0xb9,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x00,0xfc,0x24,0xfe,0x24,0xfc,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 37831 0x93c7 "鏇" */
+0x22,0x21,0x21,0x57,0x8a,0x72,0x23,0x22,0xfa,0x22,0x2a,0xb2,0x64,0x3d,0xe8,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 37832 0x93c8 "鏈" */
+0x20,0x20,0x52,0x49,0x81,0x78,0x20,0x23,0xf9,0x21,0x29,0xb1,0x61,0x3a,0xe4,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 37833 0x93c9 "鏉" */
+0x21,0x21,0x57,0x49,0x81,0x77,0x25,0x25,0xf7,0x21,0xa3,0x75,0x29,0x31,0xc1,0x01,
+0x08,0x08,0xc8,0x08,0x1e,0xd2,0x64,0x40,0xc8,0x08,0x88,0x48,0x54,0x14,0x24,0x42,
+/* 37834 0x93ca "鏊" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x20,0x3e,0x43,0x86,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x20,0x20,0x3e,0x44,0x84,0x28,0x10,0x28,0x44,0xc2,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37835 0x93cb "鏋" */
+0x20,0x20,0x53,0x48,0x80,0x78,0x20,0x23,0xfa,0x23,0x2a,0xb3,0x62,0x3a,0xe2,0x02,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x20,0xfe,0x22,0x32,0xaa,0x76,0x22,0x22,0x2a,0x24,
+/* 37836 0x93cc "鏌" */
+0x10,0x10,0x2b,0x24,0x40,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe1,0x42,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 37837 0x93cd "鏍" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x10,0xfd,0x10,0x94,0x5b,0x50,0x1d,0xe2,0x40,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 37838 0x93ce "鏎" */
+0x20,0x21,0x51,0x49,0x81,0x79,0x20,0x20,0xfb,0x20,0x28,0xb1,0x60,0x3b,0xe0,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 37839 0x93cf "鏏" */
+0x20,0x23,0x50,0x49,0x80,0x7b,0x20,0x20,0xfb,0x20,0x28,0xb1,0x60,0x38,0xe3,0x00,
+0x88,0xde,0x88,0xdc,0x88,0xde,0x88,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37840 0x93d0 "鏐" */
+0x20,0x23,0x50,0x4a,0x81,0x7a,0x20,0x20,0xfb,0x20,0x29,0xb0,0x61,0x38,0xe0,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 37841 0x93d1 "鏑" */
+0x10,0x10,0x2b,0x24,0x40,0xbb,0x12,0x12,0xfe,0x12,0x96,0x5a,0x52,0x1e,0xe2,0x42,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 37842 0x93d2 "鏒" */
+0x20,0x20,0x51,0x49,0x82,0x7b,0x20,0x21,0xfe,0x20,0x2b,0xb0,0x63,0x38,0xe0,0x07,
+0x40,0x88,0xfc,0x08,0x52,0xfe,0x50,0x88,0x26,0xc0,0x10,0x64,0x88,0x30,0xc0,0x00,
+/* 37843 0x93d3 "鏓" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x58,0x51,0x1d,0xe1,0x42,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 37844 0x93d4 "鏔" */
+0x10,0x10,0x2b,0x26,0x40,0xb9,0x10,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe1,0x42,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 37845 0x93d5 "鏕" */
+0x20,0x20,0x53,0x4a,0x82,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x62,0x3c,0xe4,0x08,
+0x40,0x20,0xfe,0x50,0x50,0xfe,0x52,0x52,0xfe,0x00,0x92,0xd4,0x98,0x92,0xd2,0x8e,
+/* 37846 0x93d6 "鏖" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x23,0x2d,0x20,0x47,0x42,0x8f,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x62,0xbe,0x18,0xf6,0x40,0xfc,0x48,0xfe,
+/* 37847 0x93d7 "鏗" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x22,0xfb,0x20,0x28,0xb1,0x60,0x38,0xe3,0x00,
+0x00,0xdc,0x94,0xd4,0x54,0xc8,0x88,0x94,0xe2,0x00,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 37848 0x93d8 "鏘" */
+0x20,0x22,0x52,0x4a,0x82,0x7b,0x20,0x20,0xf8,0x27,0x2a,0xb2,0x62,0x3a,0xe4,0x00,
+0x88,0x88,0x9e,0xaa,0x94,0x88,0x90,0xa4,0x84,0xbe,0x84,0xa4,0x94,0x84,0x94,0x88,
+/* 37849 0x93d9 "鏙" */
+0x10,0x12,0x2b,0x24,0x40,0xb9,0x13,0x15,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x22,0xfe,0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 37850 0x93da "鏚" */
+0x20,0x20,0x50,0x4b,0x82,0x7a,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x63,0x3c,0xe4,0x08,
+0x0c,0x0a,0x08,0xfe,0x08,0x48,0x6a,0x4a,0xfa,0x4c,0x4c,0xec,0x5a,0x4a,0xd6,0x22,
+/* 37851 0x93db "鏛" */
+0x10,0x11,0x28,0x27,0x42,0xb8,0x10,0x10,0xfc,0x10,0x95,0x59,0x51,0x1d,0xe1,0x40,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,
+/* 37852 0x93dc "鏜" */
+0x10,0x11,0x28,0x27,0x42,0xb8,0x10,0x10,0xfc,0x10,0x94,0x59,0x50,0x1c,0xe3,0x40,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 37853 0x93dd "鏝" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x13,0xfe,0x13,0x94,0x59,0x50,0x1c,0xe1,0x46,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 37854 0x93de "鏞" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 37855 0x93df "鏟" */
+0x10,0x10,0x29,0x24,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x10,0xfe,0x00,0x84,0x48,0xfe,0x10,0x50,0x7e,0x90,0x10,0x7e,0x10,0x10,0xfe,
+/* 37856 0x93e0 "鏠" */
+0x20,0x24,0x52,0x49,0x80,0x78,0x26,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe5,0x08,
+0x20,0x7c,0x84,0x48,0x30,0xce,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 37857 0x93e1 "鏡" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe1,0x46,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x92,0x12,0x0e,
+/* 37858 0x93e2 "鏢" */
+0x10,0x13,0x28,0x25,0x41,0xb9,0x11,0x10,0xfd,0x10,0x97,0x58,0x50,0x1d,0xe2,0x40,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 37859 0x93e3 "鏣" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x52,0x1e,0xe5,0x48,
+0x40,0x20,0xfe,0x00,0x48,0x48,0xfe,0x48,0x48,0x48,0x78,0x00,0xd4,0xaa,0x2a,0x00,
+/* 37860 0x93e4 "鏤" */
+0x10,0x11,0x29,0x27,0x41,0xb9,0x10,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1d,0xe0,0x43,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 37861 0x93e5 "鏥" */
+0x10,0x10,0x2b,0x26,0x40,0xb8,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x10,0xfe,0x02,0x80,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 37862 0x93e6 "鏦" */
+0x11,0x11,0x2a,0x24,0x41,0x7d,0x93,0x15,0x79,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x24,0x24,0x24,0xa4,0x54,0x4a,0x92,0x08,0x08,0x28,0x2e,0x28,0x28,0x58,0x4e,0x80,
+/* 37863 0x93e7 "鏧" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x41,0x86,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x48,0xc4,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37864 0x93e8 "鏨" */
+0x08,0x7f,0x08,0x3e,0x2a,0x3e,0x2a,0xff,0x09,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x04,0x78,0x40,0x40,0x7e,0x48,0x48,0x48,0x88,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37865 0x93e9 "鏩" */
+0x21,0x21,0x51,0x4f,0x81,0x77,0x25,0x27,0xf5,0x27,0xa1,0x77,0x21,0x31,0xc1,0x01,
+0x00,0x02,0x1c,0xd0,0x10,0xd0,0x5e,0xd4,0x54,0xd4,0x14,0xd4,0x14,0x24,0x24,0x44,
+/* 37866 0x93ea "鏪" */
+0x20,0x20,0x57,0x48,0x83,0x7a,0x23,0x22,0xfb,0x20,0x29,0xb1,0x61,0x39,0xe1,0x01,
+0x90,0x90,0xfe,0x90,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,
+/* 37867 0x93eb "鏫" */
+0x20,0x23,0x20,0x57,0x88,0x71,0x22,0x24,0xf8,0x20,0x2b,0xb0,0x60,0x39,0xe2,0x00,
+0x62,0x8a,0x8a,0xea,0x8a,0xca,0xa2,0x8a,0xa4,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37868 0x93ec "鏬" */
+0x20,0x20,0x50,0x4b,0x82,0x7a,0x23,0x22,0xfa,0x22,0x2b,0xb2,0x65,0x3c,0xe8,0x00,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x08,0xf0,0x24,0xa8,0xfe,0x20,0xa0,0x40,
+/* 37869 0x93ed "鏭" */
+0x20,0x21,0x50,0x49,0x80,0x7b,0x20,0x20,0xf9,0x22,0x28,0xb0,0x62,0x3a,0xe4,0x00,
+0x1c,0xe0,0x20,0x24,0xa8,0xfe,0x70,0xa8,0x24,0x22,0x40,0x24,0xa2,0x8a,0x88,0x78,
+/* 37870 0x93ee "鏮" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 37871 0x93ef "鏯" */
+0x20,0x20,0x53,0x48,0x82,0x79,0x22,0x20,0xfa,0x21,0x2a,0xb0,0x60,0x38,0xe1,0x06,
+0x20,0x20,0xfe,0x20,0xaa,0x24,0xaa,0x20,0xaa,0x24,0xaa,0x50,0x50,0x88,0x04,0x02,
+/* 37872 0x93f0 "鏰" */
+0x20,0x22,0x52,0x4b,0x80,0x7b,0x22,0x22,0xfb,0x22,0x2a,0xb3,0x62,0x3a,0xe5,0x08,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 37873 0x93f1 "鏱" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x95,0x58,0x53,0x1c,0xe0,0x40,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 37874 0x93f2 "鏲" */
+0x20,0x23,0x50,0x48,0x80,0x7b,0x22,0x20,0xf9,0x20,0x29,0xb1,0x62,0x3b,0xe0,0x00,
+0x20,0xfe,0x48,0xf0,0x20,0xfe,0x42,0x90,0xf8,0x28,0x20,0xfc,0x20,0xfe,0x20,0x20,
+/* 37875 0x93f3 "鏳" */
+0x21,0x20,0x50,0x4b,0x82,0x7a,0x22,0x22,0xfb,0x20,0x29,0xb1,0x61,0x39,0xe1,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 37876 0x93f4 "鏴" */
+0x20,0x27,0x54,0x4c,0x84,0x77,0x21,0x21,0xf1,0x25,0xa5,0x75,0x25,0x35,0xce,0x00,
+0x10,0x90,0xbc,0xa4,0xc4,0xa8,0x10,0x28,0x46,0xc0,0x3c,0x24,0x24,0xa4,0x3c,0x24,
+/* 37877 0x93f5 "鏵" */
+0x10,0x13,0x28,0x24,0x41,0xb8,0x10,0x13,0xfc,0x10,0x95,0x58,0x53,0x1c,0xe0,0x40,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 37878 0x93f6 "鏶" */
+0x10,0x10,0x29,0x27,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe3,0x40,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 37879 0x93f7 "鏷" */
+0x10,0x12,0x29,0x24,0x43,0xb8,0x10,0x13,0xfc,0x11,0x94,0x5b,0x50,0x1c,0xe1,0x46,
+0x50,0x52,0x54,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 37880 0x93f8 "鏸" */
+0x20,0x20,0x53,0x48,0x81,0x79,0x21,0x21,0xf9,0x20,0x2b,0xb0,0x60,0x3a,0xe2,0x04,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x42,0x24,0xa2,0x8a,0x78,
+/* 37881 0x93f9 "鏹" */
+0x20,0x23,0x50,0x48,0x80,0x7b,0x22,0x22,0xfa,0x23,0x28,0xb0,0x60,0x38,0xe5,0x02,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 37882 0x93fa "鏺" */
+0x20,0x23,0x20,0x55,0x8a,0x74,0x23,0x20,0xf8,0x23,0x2a,0xb3,0x60,0x38,0xe2,0x01,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 37883 0x93fb "鏻" */
+0x20,0x21,0x50,0x4b,0x80,0x79,0x22,0x21,0xf9,0x21,0x2a,0xb5,0x60,0x39,0xe2,0x04,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 37884 0x93fc "鏼" */
+0x22,0x22,0x53,0x4d,0x80,0x78,0x23,0x20,0xfb,0x22,0x2a,0xb2,0x60,0x39,0xe6,0x00,
+0x10,0x10,0xde,0x28,0xa4,0x20,0xfe,0x20,0xfe,0x22,0x2a,0x74,0xa8,0x24,0x22,0x20,
+/* 37885 0x93fd "鏽" */
+0x20,0x23,0x50,0x4f,0x80,0x73,0x20,0x25,0xf7,0x24,0xa7,0x74,0x27,0x35,0xc5,0x08,
+0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x54,0x5c,0x44,0xfc,0x44,0x5c,0x54,0x54,0x44,
+/* 37886 0x93fe "鏾" */
+0x22,0x22,0x57,0x4a,0x82,0x77,0x20,0x27,0xf4,0x27,0xa4,0x77,0x24,0x34,0xc4,0x04,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 37887 0x93ff "鏿" */
+0x20,0x21,0x50,0x4b,0x82,0x78,0x20,0x20,0xf8,0x20,0x2b,0xb0,0x60,0x39,0xe2,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37888 0x9400 "鐀" */
+0x10,0x11,0x29,0x25,0x40,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 37889 0x9401 "鐁" */
+0x22,0x22,0x52,0x4f,0x82,0x7b,0x22,0x23,0xfa,0x22,0x2f,0xb0,0x62,0x3c,0xe8,0x00,
+0x40,0x42,0x5c,0xf0,0x50,0xd0,0x5e,0xd4,0x54,0x54,0xf4,0x14,0x94,0x64,0x24,0x44,
+/* 37890 0x9402 "鐂" */
+0x20,0x23,0x50,0x4b,0x82,0x7a,0x23,0x20,0xfb,0x22,0x2a,0xb3,0x62,0x3a,0xe3,0x02,
+0x00,0xfe,0x50,0xde,0x52,0x52,0xde,0x50,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 37891 0x9403 "鐃" */
+0x20,0x20,0x51,0x48,0x83,0x79,0x23,0x21,0xf9,0x26,0x28,0xb3,0x60,0x38,0xe1,0x02,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 37892 0x9404 "鐄" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe1,0x42,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x88,0x04,0x02,
+/* 37893 0x9405 "鐅" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x44,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37894 0x9406 "鐆" */
+0x01,0x78,0x4b,0x50,0x49,0x44,0x55,0x48,0x41,0x46,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x08,0x90,0xfc,0x40,0xa4,0x58,0xb4,0x52,0xb0,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37895 0x9407 "鐇" */
+0x10,0x13,0x29,0x24,0x43,0xb8,0x11,0x12,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x3c,0xe0,0x24,0xa8,0xfe,0xa8,0x24,0x02,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 37896 0x9408 "鐈" */
+0x10,0x11,0x28,0x27,0x40,0xb9,0x12,0x10,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 37897 0x9409 "鐉" */
+0x10,0x13,0x2a,0x27,0x42,0xba,0x11,0x10,0xfc,0x13,0x94,0x58,0x53,0x1c,0xe1,0x42,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 37898 0x940a "鐊" */
+0x20,0x27,0x55,0x4d,0x85,0x75,0x26,0x25,0xf5,0x25,0xa5,0x75,0x26,0x34,0xc4,0x04,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x2a,0x4a,0x92,0x2a,0x44,
+/* 37899 0x940b "鐋" */
+0x20,0x22,0x51,0x49,0x84,0x7a,0x22,0x21,0xf9,0x22,0x2e,0xb3,0x62,0x3a,0xe2,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x2a,0x4a,0x92,0x2a,0x44,
+/* 37900 0x940c "鐌" */
+0x20,0x20,0x51,0x4b,0x85,0x79,0x21,0x20,0xf8,0x23,0x28,0xb3,0x60,0x38,0xe3,0x00,
+0x80,0xf8,0x08,0xfe,0x12,0x22,0xfe,0x40,0xa2,0x54,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 37901 0x940d "鐍" */
+0x11,0x10,0x28,0x27,0x40,0xb9,0x12,0x10,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0xf8,0x50,0x20,0xfc,0xa4,0x28,0xa0,0x40,0xfc,0x54,0x8c,0x74,0x54,0x74,0x04,0x0c,
+/* 37902 0x940e "鐎" */
+0x10,0x10,0x29,0x25,0x43,0xbd,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x90,0x88,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 37903 0x940f "鐏" */
+0x10,0x10,0x2b,0x24,0x41,0xb9,0x11,0x11,0xfd,0x11,0x94,0x5b,0x51,0x1c,0xe0,0x40,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x8c,0x74,0x04,0xfc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 37904 0x9410 "鐐" */
+0x10,0x10,0x29,0x24,0x41,0xb8,0x11,0x12,0xfc,0x10,0x94,0x58,0x50,0x1c,0xe1,0x40,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 37905 0x9411 "鐑" */
+0x20,0x20,0x51,0x49,0x82,0x7b,0x20,0x21,0xfa,0x23,0x28,0xb0,0x62,0x3a,0xe2,0x00,
+0x88,0x88,0x08,0x3e,0x48,0x88,0x9c,0x00,0x40,0xdc,0x14,0x54,0xb4,0x94,0x1c,0x14,
+/* 37906 0x9412 "鐒" */
+0x20,0x22,0x22,0x54,0x89,0x72,0x20,0x23,0xfa,0x24,0x2b,0xb0,0x60,0x38,0xe1,0x02,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x42,0x44,0xfc,0x44,0x44,0x84,0x14,0x08,
+/* 37907 0x9413 "鐓" */
+0x21,0x20,0x53,0x48,0x83,0x7a,0x23,0x20,0xfb,0x20,0x28,0xb0,0x63,0x38,0xe2,0x01,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 37908 0x9414 "鐔" */
+0x20,0x23,0x50,0x4b,0x82,0x7b,0x20,0x21,0xf9,0x21,0x29,0xb1,0x60,0x3b,0xe0,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 37909 0x9415 "鐕" */
+0x20,0x23,0x50,0x4a,0x83,0x79,0x22,0x24,0xf9,0x21,0x29,0xb1,0x61,0x39,0xe1,0x01,
+0x00,0xde,0x88,0xa8,0xfe,0x88,0xda,0xa6,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 37910 0x9416 "鐖" */
+0x21,0x21,0x52,0x4b,0x81,0x7a,0x23,0x21,0xfb,0x21,0x29,0xb1,0x62,0x3a,0xe2,0x04,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 37911 0x9417 "鐗" */
+0x23,0x22,0x53,0x4a,0x83,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3b,0xe2,0x02,
+0xde,0x52,0xde,0x52,0xde,0x02,0xf2,0x92,0xf2,0x92,0xf2,0x92,0x92,0x32,0x02,0x06,
+/* 37912 0x9418 "鐘" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x95,0x58,0x51,0x1c,0xe3,0x40,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 37913 0x9419 "鐙" */
+0x10,0x10,0x28,0x25,0x42,0xbc,0x11,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf1,0x40,
+0x10,0xd4,0x48,0x4a,0x84,0x84,0x7a,0x00,0xfc,0x84,0xfc,0x00,0x84,0x48,0xfe,0x00,
+/* 37914 0x941a "鐚" */
+0x10,0x13,0x28,0x25,0x41,0xb9,0x11,0x10,0xfc,0x13,0x94,0x58,0x50,0x1e,0xe2,0x44,
+0x00,0xfe,0x50,0xdc,0x04,0x04,0xdc,0x50,0x50,0xfe,0x40,0x20,0xa4,0x8a,0x8a,0x78,
+/* 37915 0x941b "鐛" */
+0x10,0x11,0x29,0x25,0x41,0xb9,0x10,0x13,0xfc,0x11,0x95,0x59,0x50,0x1d,0xe2,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x20,0x24,0x22,0x60,
+/* 37916 0x941c "鐜" */
+0x08,0x7f,0x22,0x3e,0x00,0x3e,0x04,0x7e,0x09,0x2e,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x20,0x20,0x3e,0x44,0x84,0x28,0x10,0x28,0x44,0xc2,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37917 0x941d "鐝" */
+0x20,0x27,0x54,0x4e,0x85,0x77,0x24,0x24,0xf6,0x26,0xa7,0x74,0x24,0x35,0xc9,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 37918 0x941e "鐞" */
+0x10,0x11,0x28,0x24,0x40,0xb9,0x10,0x11,0xfc,0x13,0x94,0x5b,0x51,0x1c,0xe0,0x40,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xdc,0x94,0xdc,0x08,0xfe,0x08,0x88,0xa8,0x10,
+/* 37919 0x941f "鐟" */
+0x10,0x10,0x2b,0x24,0x47,0xb8,0x11,0x12,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x88,0x88,0xde,0x88,0xfe,0x88,0x54,0x22,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 37920 0x9420 "鐠" */
+0x21,0x20,0x53,0x48,0x82,0x79,0x20,0x27,0xf8,0x21,0x29,0xb1,0x61,0x39,0xe1,0x01,
+0x08,0x90,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 37921 0x9421 "鐡" */
+0x20,0x20,0x53,0x48,0x87,0x70,0x23,0x22,0xf2,0x23,0xa4,0x72,0x20,0x37,0xc0,0x00,
+0x94,0x92,0xf2,0x90,0xfe,0x10,0xd2,0x52,0x52,0xd4,0x54,0x8c,0xea,0x0a,0x16,0x22,
+/* 37922 0x9422 "鐢" */
+0x22,0x21,0xfa,0x20,0x72,0xa9,0x22,0x21,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x88,0x08,0xbe,0x08,0x9c,0x2a,0x88,0x08,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37923 0x9423 "鐣" */
+0x11,0x10,0x2b,0x26,0x40,0xb8,0x10,0x10,0xfd,0x10,0x95,0x58,0x53,0x1c,0xe0,0x40,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0xa0,0x40,
+/* 37924 0x9424 "鐤" */
+0x21,0x21,0x51,0x4d,0x85,0x75,0x25,0x24,0xf7,0x20,0xa0,0x7f,0x24,0x34,0xc4,0x08,
+0xf8,0x08,0xf8,0x0a,0xfa,0x0a,0xfa,0x02,0x9e,0x90,0x90,0x9e,0x92,0x92,0x92,0x92,
+/* 37925 0x9425 "鐥" */
+0x10,0x10,0x2b,0x24,0x41,0xb8,0x13,0x11,0xfc,0x13,0x94,0x59,0x51,0x1d,0xe1,0x41,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 37926 0x9426 "鐦" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2b,0xb2,0x62,0x3a,0xe2,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x52,0x52,0xfe,0x52,0x52,0x92,0x0a,0x04,
+/* 37927 0x9427 "鐧" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0xfa,0x8a,0xfa,0x8a,0xfa,0x8a,0x02,0x0a,0x04,
+/* 37928 0x9428 "鐨" */
+0x10,0x17,0x28,0x27,0x42,0xbb,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x90,0xfc,0x94,0xfc,0x90,0xfe,0x12,0xfa,0x0e,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x08,
+/* 37929 0x9429 "鐩" */
+0x10,0x12,0x29,0x24,0x40,0xb8,0x13,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe2,0x44,
+0x44,0x24,0x28,0x7e,0x10,0x28,0x4a,0x1c,0x28,0x4c,0x1a,0x2a,0x48,0x10,0xfe,0x00,
+/* 37930 0x942a "鐪" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x3e,0x20,0xfe,0x22,0xfc,0x22,0x7e,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x22,0xc6,
+/* 37931 0x942b "鐫" */
+0x20,0x20,0x51,0x4b,0x81,0x79,0x21,0x21,0xf9,0x21,0x2b,0xb2,0x62,0x3a,0xe2,0x02,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xde,0x52,0x52,0x72,0x02,0x06,
+/* 37932 0x942c "鐬" */
+0x20,0x21,0x51,0x4b,0x80,0x78,0x23,0x22,0xfb,0x22,0x2a,0xb2,0x63,0x3c,0xe8,0x03,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 37933 0x942d "鐭" */
+0x20,0x20,0x53,0x4a,0x82,0x7a,0x23,0x22,0xfa,0x22,0x28,0xb3,0x60,0x38,0xe1,0x06,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 37934 0x942e "鐮" */
+0x20,0x23,0x52,0x4a,0x83,0x7a,0x22,0x22,0xfb,0x22,0x2a,0xb2,0x62,0x3d,0xe6,0x08,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 37935 0x942f "鐯" */
+0x10,0x10,0x2b,0x24,0x40,0x7d,0x90,0x10,0x7b,0x10,0x94,0x59,0x52,0x1c,0xe0,0x40,
+0x88,0x88,0xfe,0xa8,0x22,0xfa,0x24,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 37936 0x9430 "鐰" */
+0x10,0x10,0x28,0x24,0x40,0xb9,0x11,0x11,0xfd,0x10,0x95,0x58,0x50,0x1d,0xe2,0x40,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37937 0x9431 "鐱" */
+0x10,0x10,0x28,0x24,0x41,0xba,0x10,0x10,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe1,0x42,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 37938 0x9432 "鐲" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x11,0x12,0xfd,0x11,0x95,0x59,0x50,0x1d,0xe0,0x40,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 37939 0x9433 "鐳" */
+0x10,0x11,0x28,0x27,0x42,0xb9,0x10,0x11,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,
+/* 37940 0x9434 "鐴" */
+0x20,0x23,0x52,0x4a,0x82,0x7b,0x22,0x22,0xfb,0x22,0x2e,0xb2,0x62,0x3b,0xe2,0x00,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 37941 0x9435 "鐵" */
+0x20,0x23,0x50,0x4b,0x80,0x7b,0x22,0x23,0xf8,0x23,0x28,0xb3,0x60,0x38,0xe3,0x00,
+0x8c,0xea,0x88,0xfe,0x08,0xe8,0x2a,0xea,0x0a,0xec,0x8c,0xec,0x8a,0xea,0x96,0x22,
+/* 37942 0x9436 "鐶" */
+0x10,0x11,0x29,0x25,0x41,0xb8,0x13,0x10,0xfd,0x11,0x95,0x58,0x50,0x1d,0xe2,0x40,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 37943 0x9437 "鐷" */
+0x10,0x13,0x28,0x24,0x41,0xbb,0x11,0x11,0xfd,0x11,0x94,0x5b,0x50,0x1c,0xe3,0x40,
+0x88,0xfe,0x88,0x00,0x48,0xfe,0x48,0x78,0x00,0xfc,0x20,0xfe,0x70,0xa8,0x26,0x20,
+/* 37944 0x9438 "鐸" */
+0x10,0x11,0x29,0x25,0x40,0xb9,0x10,0x13,0xfc,0x10,0x95,0x58,0x53,0x1c,0xe0,0x40,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 37945 0x9439 "鐹" */
+0x20,0x22,0x51,0x49,0x80,0x78,0x26,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe5,0x08,
+0x00,0x7c,0x44,0x74,0x54,0x54,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,0x00,0xfe,
+/* 37946 0x943a "鐺" */
+0x10,0x11,0x28,0x27,0x42,0xb8,0x10,0x10,0xfc,0x10,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,
+/* 37947 0x943b "鐻" */
+0x20,0x20,0x50,0x4b,0x82,0x7a,0x23,0x22,0xfa,0x23,0x2a,0xb3,0x62,0x3d,0xe4,0x09,
+0x40,0x7c,0x40,0xfe,0x42,0x78,0xc4,0x3c,0x00,0xfe,0x40,0xa4,0x58,0xb4,0x52,0xb0,
+/* 37948 0x943c "鐼" */
+0x10,0x11,0x28,0x24,0x43,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe1,0x42,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 37949 0x943d "鐽" */
+0x10,0x12,0x29,0x24,0x40,0xb8,0x13,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe2,0x44,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 37950 0x943e "鐾" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x23,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37951 0x943f "鐿" */
+0x10,0x10,0x29,0x24,0x40,0xbb,0x10,0x11,0xfd,0x11,0x95,0x59,0x50,0x1e,0xe2,0x44,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 37952 0x9440 "鑀" */
+0x10,0x11,0x28,0x24,0x41,0xb9,0x10,0x11,0xfd,0x12,0x94,0x58,0x50,0x1d,0xe0,0x41,
+0x0e,0xf0,0xa2,0x54,0xfe,0x22,0x14,0x52,0x4a,0x38,0x40,0x7c,0x84,0x48,0x30,0xce,
+/* 37953 0x9441 "鑁" */
+0x20,0x20,0x52,0x4b,0x82,0x7a,0x22,0x23,0xf8,0x21,0x2a,0xb0,0x61,0x38,0xe0,0x07,
+0x20,0x88,0x52,0x26,0x52,0x8a,0x22,0xfe,0x88,0x44,0x7a,0x88,0x50,0x20,0xd8,0x06,
+/* 37954 0x9442 "鑂" */
+0x10,0x11,0x28,0x27,0x40,0xb9,0x11,0x11,0xfd,0x10,0x95,0x58,0x53,0x1c,0xe1,0x42,
+0x1c,0xe0,0x20,0xfe,0x20,0xfc,0xac,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x00,0x54,0x2a,
+/* 37955 0x9443 "鑃" */
+0x10,0x11,0x28,0x25,0x40,0xb9,0x10,0x10,0xfc,0x11,0x96,0x58,0x50,0x1c,0xe0,0x40,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x00,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,
+/* 37956 0x9444 "鑄" */
+0x20,0x23,0x50,0x49,0x80,0x7b,0x20,0x21,0xf8,0x23,0x28,0xb3,0x60,0x3b,0xe2,0x03,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 37957 0x9445 "鑅" */
+0x20,0x22,0x22,0x54,0x89,0x72,0x20,0x23,0xfa,0x20,0x2b,0xb0,0x60,0x39,0xe6,0x00,
+0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0xfe,0x22,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 37958 0x9446 "鑆" */
+0x21,0x21,0x55,0x4b,0x81,0x7b,0x20,0x22,0xf9,0x23,0x28,0xb3,0x60,0x38,0xe7,0x00,
+0x44,0x44,0x54,0x64,0x4e,0xe4,0x04,0x2c,0x44,0xe4,0x84,0xe4,0x84,0xe4,0x14,0x08,
+/* 37959 0x9447 "鑇" */
+0x20,0x20,0x53,0x48,0x80,0x77,0x22,0x22,0xf5,0x20,0xa1,0x71,0x21,0x31,0xc1,0x02,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 37960 0x9448 "鑈" */
+0x20,0x27,0x22,0x54,0x8f,0x74,0x26,0x25,0xfe,0x24,0x2e,0xb5,0x66,0x3c,0xe4,0x04,
+0x00,0xfc,0x48,0x44,0xfe,0x44,0xec,0x54,0xec,0x44,0xec,0x54,0xec,0x44,0x54,0x08,
+/* 37961 0x9449 "鑉" */
+0x10,0x13,0x28,0x24,0x41,0xb8,0x13,0x10,0xfc,0x11,0x94,0x59,0x51,0x1d,0xe7,0x40,
+0x88,0xfe,0x88,0x20,0xfc,0x20,0xfe,0x40,0x88,0xfc,0x00,0xfc,0x54,0x54,0xfe,0x00,
+/* 37962 0x944a "鑊" */
+0x10,0x13,0x28,0x24,0x41,0xbb,0x11,0x11,0xfd,0x11,0x95,0x59,0x53,0x1c,0xe0,0x43,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 37963 0x944b "鑋" */
+0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0xfe,0x11,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x00,0xfe,0x54,0xa8,0x54,0x7c,0x10,0xfe,0x00,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37964 0x944c "鑌" */
+0x20,0x20,0x53,0x4a,0x81,0x79,0x22,0x21,0xfb,0x21,0x29,0xb1,0x61,0x39,0xe0,0x01,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 37965 0x944d "鑍" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x23,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 37966 0x944e "鑎" */
+0x23,0x22,0x52,0x4a,0x82,0x7a,0x23,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x03,
+0xfe,0x20,0xfc,0xa4,0xfc,0x20,0xfe,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,0xfe,
+/* 37967 0x944f "鑏" */
+0x10,0x10,0x2b,0x26,0x41,0xb9,0x12,0x10,0xfd,0x11,0x97,0x58,0x51,0x1c,0xe0,0x40,
+0x40,0x20,0xfe,0x22,0x54,0x4a,0x3a,0x00,0xfc,0x54,0xfe,0x00,0xfc,0x20,0xa0,0x40,
+/* 37968 0x9450 "鑐" */
+0x10,0x11,0x28,0x27,0x42,0xb9,0x10,0x11,0xfc,0x13,0x94,0x59,0x51,0x1d,0xe1,0x41,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 37969 0x9451 "鑑" */
+0x20,0x23,0x52,0x4b,0x82,0x7b,0x22,0x23,0xf8,0x21,0x29,0xb1,0x61,0x39,0xe7,0x00,
+0x08,0xe8,0x88,0xee,0x28,0xf4,0x82,0xe2,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 37970 0x9452 "鑒" */
+0x7e,0x48,0x7e,0x43,0x7e,0x48,0x7e,0x01,0x06,0x18,0xef,0x01,0x3f,0x11,0x09,0xff,
+0x40,0x7e,0x90,0x08,0xfe,0xaa,0xfe,0x00,0xc0,0x30,0xee,0x00,0xf8,0x10,0x20,0xfe,
+/* 37971 0x9453 "鑓" */
+0x10,0x10,0x2a,0x25,0x41,0xb8,0x10,0x13,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe2,0x44,
+0x10,0x7c,0x54,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x40,0x7c,0x44,0x7c,0x80,0x7e,
+/* 37972 0x9454 "鑔" */
+0x20,0x20,0x53,0x4a,0x85,0x79,0x22,0x25,0xfa,0x21,0x2a,0xb1,0x60,0x39,0xe2,0x00,
+0x40,0x20,0xfe,0x02,0x14,0xde,0x52,0x54,0x88,0x74,0x02,0xfc,0x20,0x24,0x22,0x60,
+/* 37973 0x9455 "鑕" */
+0x20,0x23,0x52,0x4b,0x82,0x7a,0x24,0x23,0xfa,0x23,0x2a,0xb3,0x62,0x3b,0xe1,0x02,
+0x42,0x9c,0x10,0xde,0x94,0x94,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 37974 0x9456 "鑖" */
+0x21,0x27,0x51,0x48,0x83,0x7a,0x22,0x23,0xf8,0x23,0x2a,0xb3,0x62,0x3a,0xe4,0x08,
+0x08,0xfe,0x08,0x00,0xfc,0x94,0x94,0xfc,0x28,0xfe,0x20,0x24,0xa8,0x92,0x2a,0xc6,
+/* 37975 0x9457 "鑗" */
+0x10,0x11,0x28,0x27,0x40,0xb9,0x12,0x10,0xfc,0x10,0x97,0x58,0x50,0x1c,0xe1,0x40,
+0x50,0x90,0x9e,0xea,0x8a,0xd2,0x8a,0xa4,0x50,0x88,0x26,0xa8,0x70,0xa8,0x24,0x60,
+/* 37976 0x9458 "鑘" */
+0x23,0x22,0x52,0x4b,0x82,0x72,0x23,0x20,0xff,0x2a,0xaa,0x7f,0x2a,0x3a,0xcf,0x08,
+0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xa2,
+/* 37977 0x9459 "鑙" */
+0x23,0x21,0x27,0x51,0x8b,0x75,0x22,0x23,0xfa,0x21,0x28,0xb3,0x62,0x3b,0xe2,0x03,
+0x94,0x10,0xbe,0x18,0xaa,0x46,0x18,0xe0,0x04,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,
+/* 37978 0x945a "鑚" */
+0x10,0x11,0x28,0x25,0x40,0xb9,0x12,0x11,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x88,0xdc,0x88,0xde,0x88,0x54,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 37979 0x945b "鑛" */
+0x10,0x10,0x29,0x25,0x41,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x20,0x10,0xfe,0x28,0x7c,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x44,0x82,
+/* 37980 0x945c "鑜" */
+0x11,0x10,0x2b,0x26,0x40,0xb8,0x11,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe0,0x41,
+0x24,0xa8,0xfe,0x02,0xf8,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x00,0x88,0x04,
+/* 37981 0x945d "鑝" */
+0x20,0x23,0x50,0x48,0x82,0x79,0x20,0x20,0xfb,0x21,0x29,0xb1,0x61,0x39,0xe3,0x04,
+0x88,0xfe,0x88,0x20,0x3c,0x44,0x38,0xd6,0x38,0x10,0x7c,0x10,0x7e,0x10,0x10,0xfe,
+/* 37982 0x945e "鑞" */
+0x21,0x22,0x51,0x48,0x83,0x7a,0x22,0x22,0xfb,0x22,0x2b,0xb2,0x63,0x3a,0xe2,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 37983 0x945f "鑟" */
+0x10,0x13,0x28,0x25,0x40,0xbb,0x12,0x13,0xfd,0x11,0x95,0x59,0x51,0x1d,0xe0,0x41,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 37984 0x9460 "鑠" */
+0x24,0x24,0x58,0x4a,0x8e,0x74,0x2a,0x2e,0xf2,0x20,0xaf,0x70,0x21,0x32,0xcc,0x00,
+0x44,0xe4,0xa8,0xaa,0xee,0xa4,0xaa,0xee,0x42,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 37985 0x9461 "鑡" */
+0x20,0x21,0x51,0x49,0x87,0x78,0x22,0x23,0xfa,0x23,0x2a,0xb2,0x63,0x3a,0xe3,0x00,
+0x20,0x20,0x3c,0x20,0xfe,0x90,0x94,0x6c,0x04,0xfc,0x94,0x94,0x6c,0x04,0xfc,0x04,
+/* 37986 0x9462 "鑢" */
+0x20,0x20,0x50,0x4b,0x82,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x64,0x3d,0xe9,0x02,
+0x20,0x3c,0x20,0xfe,0x22,0xf8,0x24,0xfc,0xa4,0xfc,0xa4,0xfc,0x20,0x54,0x4a,0x3a,
+/* 37987 0x9463 "鑣" */
+0x20,0x20,0x53,0x4a,0x83,0x7a,0x23,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3c,0xe5,0x0a,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 37988 0x9464 "鑤" */
+0x11,0x11,0x29,0x25,0x41,0x7c,0x91,0x10,0x7b,0x10,0x95,0x5a,0x50,0x1c,0xe1,0x40,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 37989 0x9465 "鑥" */
+0x10,0x11,0x2a,0x25,0x41,0xb9,0x11,0x11,0xfd,0x12,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x80,0xf8,0x08,0xfc,0x24,0xfc,0x24,0xfc,0x54,0x2a,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 37990 0x9466 "鑦" */
+0x27,0x25,0x27,0x54,0x8f,0x75,0x27,0x20,0xfb,0x22,0x2b,0xb2,0x63,0x3a,0xe3,0x01,
+0xde,0x12,0xd2,0x54,0xc8,0x14,0xe2,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,
+/* 37991 0x9467 "鑧" */
+0x10,0x13,0x2a,0x25,0x40,0xb9,0x11,0x11,0xfd,0x11,0x95,0x59,0x50,0x1c,0xe1,0x42,
+0x20,0xfe,0x8a,0xfc,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x90,0x94,0x12,0x0e,
+/* 37992 0x9468 "鑨" */
+0x21,0x20,0x53,0x48,0x82,0x79,0x23,0x20,0xfb,0x22,0x2b,0xb2,0x63,0x3a,0xe2,0x02,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 37993 0x9469 "鑩" */
+0x20,0x23,0x50,0x4b,0x82,0x7a,0x23,0x20,0xfb,0x20,0x2b,0xb2,0x62,0x3b,0xe0,0x03,
+0x00,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,
+/* 37994 0x946a "鑪" */
+0x20,0x20,0x50,0x4b,0x82,0x7b,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3d,0xe5,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 37995 0x946b "鑫" */
+0x01,0x06,0x18,0xef,0x01,0x1f,0x09,0x3f,0x10,0x28,0x7c,0x92,0x7c,0x10,0x54,0xfe,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x20,0xf8,0x10,0x28,0x7c,0x92,0x7c,0x10,0x54,0xfe,
+/* 37996 0x946c "鑬" */
+0x13,0x12,0x2b,0x26,0x43,0xba,0x13,0x11,0xfd,0x11,0x95,0x59,0x51,0x1c,0xe1,0x46,
+0xd0,0x90,0xde,0x68,0xc4,0x84,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x90,0x12,0x0e,
+/* 37997 0x946d "鑭" */
+0x23,0x22,0x53,0x4a,0x83,0x7a,0x22,0x22,0xfa,0x22,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfa,0x22,0xfa,0xaa,0xfa,0xaa,0xfa,0x72,0xaa,0x26,
+/* 37998 0x946e "鑮" */
+0x20,0x23,0x20,0x54,0x8a,0x70,0x24,0x22,0xfa,0x20,0x29,0xb2,0x66,0x3a,0xe2,0x02,
+0x88,0xfe,0x88,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x2c,
+/* 37999 0x946f "鑯" */
+0x21,0x21,0x52,0x48,0x83,0x79,0x23,0x21,0xfb,0x21,0x2b,0xb1,0x61,0x3b,0xe0,0x00,
+0x48,0x4c,0xaa,0x08,0xfe,0x48,0x68,0x4a,0x6a,0x4a,0x6c,0x4c,0x6a,0x8a,0x16,0x22,
+/* 38000 0x9470 "鑰" */
+0x10,0x10,0x28,0x25,0x42,0xb9,0x11,0x11,0xfc,0x11,0x95,0x59,0x51,0x1d,0xe1,0x41,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x54,0xfc,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x0c,
+/* 38001 0x9471 "鑱" */
+0x21,0x22,0x57,0x4a,0x83,0x7a,0x23,0x22,0xf9,0x22,0x2f,0xb2,0x63,0x38,0xe1,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 38002 0x9472 "鑲" */
+0x10,0x13,0x28,0x25,0x41,0xb9,0x10,0x13,0xfc,0x13,0x94,0x5b,0x50,0x1d,0xe2,0x40,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 38003 0x9473 "鑳" */
+0x20,0x27,0x54,0x4b,0x80,0x7b,0x20,0x27,0xf9,0x23,0x2d,0xb1,0x62,0x3a,0xe5,0x08,
+0x40,0xfe,0x92,0xfc,0x90,0xfc,0x90,0xfe,0x08,0xfc,0x0a,0xf8,0x40,0x7c,0x40,0xfe,
+/* 38004 0x9474 "鑴" */
+0x22,0x23,0x20,0x51,0x8b,0x75,0x21,0x21,0xf9,0x21,0x29,0xb3,0x62,0x3b,0xe2,0x02,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 38005 0x9475 "鑵" */
+0x20,0x23,0x50,0x4b,0x82,0x7b,0x20,0x20,0xf9,0x21,0x2b,0xb5,0x61,0x39,0xe1,0x01,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 38006 0x9476 "鑶" */
+0x20,0x20,0x57,0x48,0x80,0x71,0x25,0x27,0xf1,0x21,0xaf,0x75,0x25,0x39,0xc2,0x04,
+0x90,0x90,0xfe,0x94,0x0a,0xfe,0x08,0xe8,0x4a,0xea,0x2a,0xea,0x4c,0xea,0x16,0x62,
+/* 38007 0x9477 "鑷" */
+0x23,0x21,0x51,0x49,0x81,0x79,0x27,0x20,0xff,0x22,0x2b,0xb2,0x63,0x3a,0xe7,0x00,
+0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xfe,0x94,0x9c,0x94,0x9c,0xd6,0xbc,0x84,
+/* 38008 0x9478 "鑸" */
+0x27,0x24,0x57,0x4c,0x87,0x70,0x2f,0x2a,0xff,0x2a,0xaf,0x70,0x20,0x37,0xc0,0x0f,
+0xfc,0x44,0xfc,0x44,0xfc,0x00,0xbe,0xaa,0xbe,0xaa,0xbe,0x40,0x40,0xfc,0x40,0xfe,
+/* 38009 0x9479 "鑹" */
+0x20,0x27,0x54,0x49,0x80,0x7b,0x22,0x23,0xfa,0x23,0x2a,0xb3,0x62,0x3b,0xe2,0x03,
+0x40,0xfe,0x92,0x08,0x80,0x1c,0x04,0x9c,0x04,0xfc,0x48,0x68,0x48,0x6a,0x46,0x62,
+/* 38010 0x947a "鑺" */
+0x23,0x22,0x53,0x4a,0x83,0x7a,0x23,0x20,0xf9,0x21,0x2b,0xb5,0x61,0x39,0xe1,0x01,
+0xde,0x52,0xde,0x52,0xde,0x52,0xde,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,
+/* 38011 0x947b "鑻" */
+0x22,0x22,0x57,0x4a,0x87,0x7a,0x22,0x2f,0xf2,0x25,0xa8,0x73,0x20,0x37,0xc0,0x00,
+0xa8,0x48,0xbe,0xa8,0x5c,0xaa,0x88,0xfe,0x18,0xe4,0x42,0xf8,0x40,0xfc,0x40,0xc0,
+/* 38012 0x947c "鑼" */
+0x20,0x23,0x52,0x4a,0x83,0x71,0x21,0x22,0xf7,0x21,0xa2,0x77,0x20,0x35,0xc5,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x08,0x54,0x5e,0xb4,0x1e,0x54,0xde,0x14,0x54,0x5e,0x10,
+/* 38013 0x947d "鑽" */
+0x25,0x27,0x29,0x57,0x8b,0x75,0x29,0x23,0xfa,0x23,0x2a,0xb3,0x62,0x3b,0xe1,0x02,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 38014 0x947e "鑾" */
+0x21,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x01,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x08,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0x00,0xc0,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 38015 0x947f "鑿" */
+0x55,0x14,0xff,0x22,0x7f,0x08,0x6b,0x49,0x7f,0x06,0x18,0xef,0x01,0x3f,0x09,0xff,
+0x78,0x48,0x48,0x86,0x78,0x48,0x28,0x10,0x28,0xc4,0x30,0xee,0x00,0xf8,0x20,0xfe,
+/* 38016 0x9480 "钀" */
+0x21,0x21,0x51,0x4f,0x89,0x7b,0x29,0x2f,0xf9,0x2b,0xaa,0x7b,0x2a,0x3b,0xca,0x12,
+0x08,0xec,0x0a,0xea,0x28,0xc8,0x3e,0xe8,0x48,0xe8,0x28,0x68,0xa8,0xf4,0xb4,0xa2,
+/* 38017 0x9481 "钁" */
+0x23,0x22,0x53,0x4a,0x83,0x78,0x21,0x23,0xfd,0x21,0x29,0xb0,0x61,0x38,0xe0,0x07,
+0xde,0x52,0xde,0x52,0xde,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 38018 0x9482 "钂" */
+0x22,0x21,0x57,0x4c,0x81,0x71,0x27,0x25,0xf4,0x27,0xa0,0x77,0x20,0x3f,0xc2,0x04,
+0x48,0x50,0xfc,0x04,0xf0,0x10,0xfc,0x54,0xe4,0xfc,0x40,0xfc,0x40,0xfe,0xa4,0x52,
+/* 38019 0x9483 "钃" */
+0x23,0x22,0x53,0x4a,0x82,0x7a,0x22,0x22,0xfa,0x23,0x2a,0xb2,0x62,0x3a,0xe5,0x00,
+0xfe,0x02,0xfe,0x92,0x54,0x92,0xfe,0xaa,0xfe,0x22,0xfa,0xaa,0xfa,0x22,0xfa,0x04,
+/* 38020 0x9484 "钄" */
+0x20,0x23,0x50,0x4b,0x82,0x7b,0x22,0x23,0xfa,0x23,0x2a,0xb2,0x62,0x3a,0xe2,0x02,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0xaa,0xfa,0x22,0x72,0xaa,0x24,
+/* 38021 0x9485 "钅" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 38022 0x9486 "钆" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x84,0x7c,0x00,
+/* 38023 0x9487 "钇" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x10,0xfc,0x10,0x11,0x11,0x15,0x19,0x10,0x00,
+0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x40,0x80,0x80,0x00,0x04,0x04,0x04,0xfc,0x00,
+/* 38024 0x9488 "针" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x93,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 38025 0x9489 "钉" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 38026 0x948a "钊" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x04,0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x04,0x04,0x04,0x14,0x08,
+/* 38027 0x948b "钋" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x40,0x40,0x40,0x40,0x40,0x60,0x50,0x48,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,
+/* 38028 0x948c "钌" */
+0x10,0x11,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x00,0xfc,0x04,0x08,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 38029 0x948d "钍" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x11,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x13,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 38030 0x948e "钎" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x13,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 38031 0x948f "钏" */
+0x11,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 38032 0x9490 "钐" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x10,0x03,
+0x08,0x08,0x10,0x20,0x40,0x88,0x08,0x10,0x20,0x44,0x84,0x08,0x10,0x20,0xc0,0x00,
+/* 38033 0x9491 "钑" */
+0x10,0x13,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfd,0x11,0x11,0x11,0x16,0x1a,0x14,0x01,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 38034 0x9492 "钒" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x90,0x50,0x50,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 38035 0x9493 "钓" */
+0x10,0x10,0x3c,0x20,0x41,0xbe,0x10,0x11,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x44,0x04,0x04,0x04,0x28,0x10,
+/* 38036 0x9494 "钔" */
+0x10,0x10,0x3c,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x80,0x40,0x5e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x04,
+/* 38037 0x9495 "钕" */
+0x10,0x10,0x3c,0x20,0x43,0xbc,0x10,0x10,0xfc,0x11,0x10,0x10,0x14,0x18,0x10,0x03,
+0x40,0x40,0x40,0x40,0xfe,0x88,0x88,0x88,0x88,0x08,0x90,0x50,0x20,0x50,0x88,0x04,
+/* 38038 0x9496 "钖" */
+0x10,0x11,0x3c,0x20,0x40,0xbc,0x11,0x10,0xfc,0x10,0x11,0x10,0x14,0x18,0x11,0x00,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfc,0x54,0x54,0x94,0x24,0x24,0x44,0x84,0x28,0x10,
+/* 38039 0x9497 "钗" */
+0x10,0x13,0x3d,0x21,0x41,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x11,0x06,
+0x00,0xfc,0x04,0x44,0x24,0xa8,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 38040 0x9498 "钘" */
+0x10,0x11,0x3c,0x20,0x40,0xbc,0x10,0x13,0xfc,0x10,0x10,0x10,0x14,0x19,0x11,0x02,
+0x00,0xfc,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 38041 0x9499 "钙" */
+0x10,0x13,0x3c,0x20,0x41,0xbd,0x11,0x11,0xfd,0x11,0x10,0x10,0x14,0x18,0x10,0x00,
+0x00,0xfe,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfe,0x02,0x02,0x02,0x02,0x14,0x08,
+/* 38042 0x949a "钚" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x10,0xfc,0x11,0x12,0x10,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 38043 0x949b "钛" */
+0x10,0x10,0x1e,0x20,0x20,0x7d,0x90,0x10,0xfe,0x10,0x10,0x12,0x14,0x18,0x11,0x02,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0xc8,0x24,0x02,
+/* 38044 0x949c "钜" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x00,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xfe,0x00,
+/* 38045 0x949d "钝" */
+0x20,0x20,0x38,0x27,0x40,0x7a,0xa2,0x22,0xfa,0x23,0x20,0x20,0x28,0x30,0x20,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 38046 0x949e "钞" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x11,0x11,0xfe,0x10,0x10,0x10,0x14,0x18,0x10,0x03,
+0x20,0x20,0x20,0xa8,0xa4,0xa2,0x22,0x20,0x24,0x24,0x28,0x08,0x10,0x20,0xc0,0x00,
+/* 38047 0x949f "钟" */
+0x10,0x10,0x3c,0x20,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x10,0x14,0x18,0x10,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 38048 0x94a0 "钠" */
+0x10,0x10,0x3c,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 38049 0x94a1 "钡" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x10,0x14,0x18,0x11,0x06,
+0x00,0xfc,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x02,0x02,
+/* 38050 0x94a2 "钢" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x04,0x04,0x94,0x54,0x54,0x24,0x24,0x54,0x54,0x94,0x04,0x04,0x14,0x08,
+/* 38051 0x94a3 "钣" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 38052 0x94a4 "钤" */
+0x10,0x10,0x3c,0x20,0x40,0xbd,0x12,0x10,0xfc,0x11,0x10,0x10,0x14,0x18,0x10,0x00,
+0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0x00,0xfc,0x04,0x08,0x08,0x10,0x10,0x20,
+/* 38053 0x94a5 "钥" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x15,0x19,0x12,0x04,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 38054 0x94a6 "钦" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x11,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x11,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 38055 0x94a7 "钧" */
+0x10,0x10,0x3c,0x20,0x41,0xbe,0x10,0x10,0xfc,0x10,0x10,0x10,0x15,0x18,0x10,0x00,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 38056 0x94a8 "钨" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x15,0x18,0x10,0x00,
+0x20,0x40,0xfc,0x84,0x84,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 38057 0x94a9 "钩" */
+0x10,0x10,0x3c,0x20,0x41,0xbd,0x12,0x10,0xfc,0x10,0x11,0x11,0x14,0x18,0x10,0x00,
+0x80,0x80,0x80,0xfc,0x04,0x04,0x44,0x44,0x84,0xa4,0x14,0xf4,0x14,0x04,0x28,0x10,
+/* 38058 0x94aa "钪" */
+0x10,0x10,0x3c,0x21,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x19,0x11,0x02,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 38059 0x94ab "钫" */
+0x10,0x10,0x3c,0x23,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x15,0x19,0x12,0x04,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 38060 0x94ac "钬" */
+0x10,0x10,0x1e,0x20,0x20,0x7c,0x90,0x11,0xfe,0x10,0x10,0x12,0x14,0x18,0x11,0x02,
+0x20,0x20,0x20,0x24,0xa4,0xa4,0xa8,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 38061 0x94ad "钭" */
+0x10,0x11,0x3c,0x20,0x40,0xbd,0x10,0x10,0xfc,0x10,0x13,0x10,0x14,0x18,0x10,0x00,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 38062 0x94ae "钮" */
+0x10,0x11,0x3c,0x20,0x40,0xbc,0x10,0x11,0xfc,0x10,0x10,0x10,0x14,0x18,0x13,0x00,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 38063 0x94af "钯" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 38064 0x94b0 "钰" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x10,0xfd,0x10,0x10,0x10,0x14,0x18,0x13,0x00,
+0x00,0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x24,0x20,0xfe,0x00,
+/* 38065 0x94b1 "钱" */
+0x10,0x10,0x3c,0x20,0x41,0xbc,0x10,0x11,0xfc,0x10,0x10,0x10,0x14,0x18,0x13,0x00,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 38066 0x94b2 "钲" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x13,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 38067 0x94b3 "钳" */
+0x10,0x10,0x3c,0x20,0x43,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 38068 0x94b4 "钴" */
+0x10,0x10,0x3c,0x20,0x43,0xbc,0x10,0x10,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38069 0x94b5 "钵" */
+0x10,0x10,0x3c,0x20,0x41,0xbc,0x10,0x10,0xfd,0x11,0x12,0x10,0x14,0x18,0x10,0x00,
+0x20,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0xf8,0x20,0x20,0x20,0x20,
+/* 38070 0x94b6 "钶" */
+0x10,0x10,0x3d,0x20,0x40,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 38071 0x94b7 "钷" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x00,
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x00,0xfe,0x00,
+/* 38072 0x94b8 "钸" */
+0x20,0x20,0x38,0x23,0x40,0x78,0xa1,0x21,0xfb,0x25,0x21,0x21,0x29,0x31,0x20,0x00,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 38073 0x94b9 "钹" */
+0x10,0x10,0x3c,0x20,0x43,0xbc,0x10,0x10,0xfd,0x11,0x11,0x11,0x16,0x1a,0x14,0x01,
+0x50,0x48,0x48,0x40,0xfe,0x80,0x80,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 38074 0x94ba "钺" */
+0x20,0x20,0x38,0x20,0x43,0x7a,0xa2,0x22,0xfa,0x22,0x22,0x22,0x2b,0x32,0x20,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0x24,0x28,0x28,0x90,0x12,0x2a,0x46,0x82,
+/* 38075 0x94bb "钻" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38076 0x94bc "钼" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38077 0x94bd "钽" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x14,0x18,0x13,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0xfe,0x00,
+/* 38078 0x94be "钾" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x10,0x14,0x18,0x10,0x00,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 38079 0x94bf "钿" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 38080 0x94c0 "铀" */
+0x10,0x10,0x3c,0x20,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 38081 0x94c1 "铁" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x12,0x10,0xfd,0x10,0x10,0x10,0x14,0x18,0x11,0x02,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 38082 0x94c2 "铂" */
+0x10,0x10,0x3c,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38083 0x94c3 "铃" */
+0x20,0x20,0x38,0x20,0x41,0x7a,0xa4,0x20,0xfb,0x20,0x20,0x21,0x28,0x30,0x20,0x00,
+0x40,0x40,0xa0,0xa0,0x10,0x48,0x26,0x20,0xf8,0x08,0x10,0x10,0xa0,0x40,0x20,0x20,
+/* 38084 0x94c4 "铄" */
+0x20,0x20,0x3b,0x22,0x42,0x7a,0xa2,0x23,0xf8,0x20,0x21,0x21,0x2a,0x34,0x20,0x00,
+0x08,0x3c,0xc0,0x00,0x20,0x20,0x20,0xfe,0x20,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 38085 0x94c5 "铅" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x11,0x12,0xfc,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xf8,0x88,0x88,0x88,0x88,0x06,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38086 0x94c6 "铆" */
+0x20,0x20,0x3b,0x22,0x42,0x7a,0xa2,0x22,0xfa,0x22,0x23,0x22,0x28,0x30,0x21,0x02,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 38087 0x94c7 "铇" */
+0x10,0x10,0x3d,0x21,0x42,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 38088 0x94c8 "铈" */
+0x10,0x10,0x3c,0x23,0x40,0xbc,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x40,0x20,0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 38089 0x94c9 "铉" */
+0x10,0x10,0x3c,0x21,0x40,0xbc,0x10,0x10,0xfd,0x10,0x10,0x10,0x14,0x19,0x10,0x00,
+0x20,0x10,0x10,0xfe,0x20,0x20,0x44,0x84,0xf8,0x10,0x20,0x44,0x82,0xfe,0x82,0x00,
+/* 38090 0x94ca "铊" */
+0x10,0x10,0x3c,0x21,0x41,0xbe,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 38091 0x94cb "铋" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x11,0xfd,0x11,0x12,0x10,0x14,0x19,0x12,0x00,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 38092 0x94cc "铌" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x40,0x44,0x48,0x70,0x40,0x42,0x42,0x3e,0x00,
+/* 38093 0x94cd "铍" */
+0x10,0x10,0x3c,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 38094 0x94ce "铎" */
+0x10,0x13,0x3d,0x20,0x40,0xbc,0x10,0x13,0xfc,0x11,0x10,0x10,0x17,0x18,0x10,0x00,
+0x00,0xfc,0x04,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 38095 0x94cf "铏" */
+0x20,0x27,0x3a,0x22,0x42,0x7a,0xa2,0x27,0xfa,0x22,0x22,0x22,0x2a,0x34,0x24,0x08,
+0x04,0xc4,0x84,0x94,0x94,0x94,0x94,0xd4,0x94,0x94,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 38096 0x94d0 "铐" */
+0x10,0x10,0x3d,0x20,0x40,0xbd,0x10,0x10,0xfd,0x12,0x14,0x10,0x14,0x18,0x10,0x00,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 38097 0x94d1 "铑" */
+0x10,0x10,0x3c,0x21,0x40,0xbc,0x13,0x10,0xfc,0x11,0x12,0x10,0x14,0x18,0x10,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 38098 0x94d2 "铒" */
+0x10,0x11,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfc,0x10,0x10,0x10,0x15,0x18,0x10,0x00,
+0x00,0xfe,0x88,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0x9e,0xe8,0x08,0x08,0x08,
+/* 38099 0x94d3 "铓" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x11,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x48,0x48,0xfe,0x48,0x48,0x20,0x10,0xfe,0x80,0x80,0x80,0x80,0x80,0x80,0xfc,0x00,
+/* 38100 0x94d4 "铔" */
+0x20,0x23,0x38,0x20,0x40,0x78,0xa4,0x22,0xfa,0x22,0x20,0x20,0x28,0x30,0x27,0x00,
+0x00,0xfc,0x90,0x90,0x90,0x92,0x92,0x94,0x94,0x98,0x90,0x90,0x90,0x90,0xfe,0x00,
+/* 38101 0x94d5 "铕" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x10,0x11,0xfe,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 38102 0x94d6 "铖" */
+0x20,0x20,0x38,0x20,0x43,0x7a,0xa2,0x22,0xfb,0x22,0x22,0x22,0x2a,0x35,0x24,0x08,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x24,0x24,0xa4,0xa8,0xa8,0x90,0x92,0xaa,0x46,0x82,
+/* 38103 0x94d7 "铗" */
+0x10,0x10,0x3c,0x21,0x40,0xbd,0x10,0x10,0xfc,0x13,0x10,0x10,0x14,0x18,0x11,0x02,
+0x20,0x20,0x20,0xfc,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 38104 0x94d8 "铘" */
+0x20,0x27,0x38,0x44,0x44,0x7c,0xa7,0x20,0xf9,0x21,0x22,0x2a,0x34,0x28,0x02,0x01,
+0x00,0xde,0x92,0x92,0x94,0x94,0xd8,0x94,0x92,0x92,0x92,0x9a,0x94,0x90,0x90,0x10,
+/* 38105 0x94d9 "铙" */
+0x20,0x20,0x38,0x23,0x40,0x78,0xa0,0x23,0xf8,0x23,0x20,0x20,0x29,0x31,0x22,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 38106 0x94da "铚" */
+0x10,0x11,0x3c,0x20,0x40,0xbd,0x11,0x10,0xfc,0x10,0x11,0x10,0x14,0x18,0x13,0x00,
+0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x22,0x20,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 38107 0x94db "铛" */
+0x10,0x11,0x3c,0x20,0x40,0xbc,0x13,0x10,0xfc,0x10,0x11,0x10,0x14,0x18,0x13,0x00,
+0x20,0x24,0xa4,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 38108 0x94dc "铜" */
+0x20,0x23,0x3a,0x22,0x42,0x7a,0xa2,0x22,0xfa,0x22,0x22,0x22,0x2a,0x32,0x22,0x02,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 38109 0x94dd "铝" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfc,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0xfe,0x02,
+/* 38110 0x94de "铞" */
+0x20,0x21,0x39,0x21,0x41,0x78,0xa0,0x23,0xfa,0x22,0x22,0x22,0x2a,0x32,0x20,0x00,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 38111 0x94df "铟" */
+0x20,0x23,0x3a,0x22,0x42,0x7a,0xa3,0x22,0xfa,0x22,0x22,0x22,0x2b,0x32,0x23,0x02,
+0x00,0xfe,0x02,0x22,0x22,0x22,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0xfe,0x02,
+/* 38112 0x94e0 "铠" */
+0x10,0x11,0x3d,0x21,0x41,0xbc,0x11,0x10,0xfc,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfc,0x04,0x04,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 38113 0x94e1 "铡" */
+0x20,0x23,0x3a,0x22,0x42,0x7a,0xa2,0x22,0xfa,0x22,0x22,0x20,0x29,0x31,0x22,0x04,
+0x02,0xe2,0x22,0x2a,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0x82,0x42,0x22,0x0a,0x04,
+/* 38114 0x94e2 "铢" */
+0x20,0x21,0x39,0x21,0x41,0x7a,0xa0,0x23,0xf8,0x20,0x20,0x21,0x29,0x32,0x20,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 38115 0x94e3 "铣" */
+0x10,0x11,0x3d,0x21,0x41,0xbe,0x10,0x13,0xfc,0x10,0x10,0x10,0x15,0x19,0x12,0x04,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,
+/* 38116 0x94e4 "铤" */
+0x20,0x20,0x3b,0x20,0x40,0x79,0xa1,0x23,0xf8,0x22,0x22,0x21,0x29,0x32,0x24,0x08,
+0x00,0x06,0xb8,0x88,0x88,0x08,0x3e,0x88,0x88,0x88,0x88,0x3e,0x00,0x80,0x7e,0x00,
+/* 38117 0x94e5 "铥" */
+0x10,0x10,0x3d,0x20,0x40,0xbd,0x10,0x10,0xfc,0x13,0x10,0x10,0x14,0x19,0x13,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 38118 0x94e6 "铦" */
+0x10,0x10,0x3d,0x20,0x40,0xbd,0x10,0x10,0xfc,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38119 0x94e7 "铧" */
+0x10,0x10,0x3d,0x21,0x43,0xbd,0x11,0x11,0xfd,0x10,0x13,0x10,0x14,0x18,0x10,0x00,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 38120 0x94e8 "铨" */
+0x20,0x20,0x38,0x21,0x42,0x7c,0xa3,0x20,0xf8,0x20,0x23,0x20,0x28,0x30,0x27,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xfe,0x00,
+/* 38121 0x94e9 "铩" */
+0x10,0x11,0x3c,0x20,0x40,0xbc,0x11,0x10,0xff,0x10,0x10,0x10,0x15,0x1a,0x10,0x00,
+0x04,0x88,0x50,0x20,0x50,0x88,0x24,0x20,0xfe,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 38122 0x94ea "铪" */
+0x20,0x20,0x38,0x21,0x42,0x7c,0xa3,0x20,0xf8,0x23,0x22,0x22,0x2a,0x32,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 38123 0x94eb "铫" */
+0x10,0x10,0x3c,0x21,0x40,0xbc,0x10,0x10,0xfc,0x11,0x12,0x10,0x14,0x18,0x11,0x02,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 38124 0x94ec "铬" */
+0x10,0x10,0x3c,0x20,0x41,0xbc,0x10,0x10,0xfd,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 38125 0x94ed "铭" */
+0x10,0x10,0x3c,0x21,0x42,0xbc,0x10,0x10,0xfc,0x11,0x12,0x10,0x14,0x18,0x10,0x00,
+0x40,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 38126 0x94ee "铮" */
+0x20,0x20,0x39,0x22,0x40,0x7b,0xa0,0x20,0xfb,0x20,0x20,0x23,0x28,0x30,0x20,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 38127 0x94ef "铯" */
+0x10,0x10,0x3c,0x21,0x42,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x10,0x00,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 38128 0x94f0 "铰" */
+0x10,0x10,0x3c,0x21,0x40,0xbc,0x11,0x12,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 38129 0x94f1 "铱" */
+0x10,0x10,0x3c,0x23,0x40,0xbc,0x10,0x10,0xfd,0x12,0x14,0x10,0x14,0x18,0x10,0x00,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 38130 0x94f2 "铲" */
+0x20,0x20,0x3b,0x20,0x41,0x78,0xa3,0x22,0xfa,0x22,0x22,0x22,0x2a,0x34,0x24,0x08,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 38131 0x94f3 "铳" */
+0x10,0x10,0x3c,0x23,0x40,0xbc,0x11,0x13,0xfc,0x10,0x10,0x10,0x15,0x19,0x12,0x04,
+0x40,0x20,0x20,0xfe,0x40,0x88,0x04,0xfe,0x92,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 38132 0x94f4 "铴" */
+0x22,0x21,0x39,0x24,0x42,0x7a,0xa0,0x21,0xf9,0x22,0x26,0x22,0x2a,0x33,0x22,0x00,
+0x00,0x7c,0x04,0x08,0x10,0x20,0x7e,0x2a,0x2a,0x2a,0x4a,0x52,0x92,0x22,0x4a,0x84,
+/* 38133 0x94f5 "铵" */
+0x20,0x20,0x38,0x23,0x42,0x7c,0xa0,0x23,0xf8,0x20,0x21,0x20,0x28,0x30,0x20,0x03,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 38134 0x94f6 "银" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x48,0x86,0x00,
+/* 38135 0x94f7 "铷" */
+0x21,0x21,0x39,0x21,0x47,0x7a,0xa2,0x22,0xfa,0x24,0x22,0x21,0x2a,0x32,0x24,0x08,
+0x00,0x00,0x00,0x1e,0xd2,0x52,0x52,0x52,0x52,0x92,0x92,0x12,0x92,0x5e,0x52,0x00,
+/* 38136 0x94f8 "铸" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x11,0x10,0xfc,0x10,0x10,0x11,0x15,0x1a,0x10,0x00,
+0x20,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x48,0x48,0xfe,0x88,0x48,0x28,0x08,0x28,0x10,
+/* 38137 0x94f9 "铹" */
+0x20,0x20,0x3b,0x20,0x40,0x7b,0xa2,0x24,0xf8,0x23,0x20,0x20,0x28,0x31,0x22,0x04,
+0x88,0x88,0xfe,0x88,0x00,0xfe,0x02,0x44,0x40,0xfc,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 38138 0x94fa "铺" */
+0x20,0x20,0x3b,0x20,0x40,0x7b,0xa2,0x22,0xfb,0x22,0x22,0x23,0x2a,0x32,0x22,0x02,
+0x48,0x44,0xfe,0x40,0x40,0xfc,0x44,0x44,0xfc,0x44,0x44,0xfc,0x44,0x44,0x54,0x08,
+/* 38139 0x94fb "铻" */
+0x10,0x13,0x3c,0x20,0x41,0xbc,0x10,0x13,0xfc,0x10,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 38140 0x94fc "铼" */
+0x20,0x20,0x38,0x23,0x40,0x79,0xa0,0x20,0xfb,0x20,0x20,0x20,0x29,0x32,0x24,0x00,
+0x20,0x20,0x20,0xfe,0x20,0x24,0xa4,0xa8,0xfe,0x70,0xa8,0xa8,0x24,0x22,0x20,0x20,
+/* 38141 0x94fd "铽" */
+0x20,0x20,0x38,0x20,0x43,0x78,0xa0,0x20,0xf8,0x20,0x20,0x22,0x2a,0x32,0x24,0x00,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x90,0x50,0x48,0x08,0x88,0xa8,0x9a,0xaa,0x66,0x02,
+/* 38142 0x94fe "链" */
+0x20,0x22,0x39,0x21,0x40,0x78,0xa7,0x21,0xf9,0x21,0x21,0x21,0x29,0x32,0x24,0x00,
+0x10,0x10,0x10,0x7e,0x20,0x28,0x48,0x7e,0x08,0x08,0xfe,0x08,0x08,0x88,0x7e,0x00,
+/* 38143 0x94ff "铿" */
+0x20,0x22,0x3a,0x22,0x42,0x7a,0xa2,0x20,0xf8,0x20,0x21,0x20,0x28,0x30,0x23,0x00,
+0x80,0xfc,0xa4,0xa4,0xa8,0x90,0xa8,0xc6,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38144 0x9500 "销" */
+0x10,0x11,0x3c,0x20,0x40,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 38145 0x9501 "锁" */
+0x10,0x11,0x3c,0x20,0x40,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x14,0x18,0x11,0x02,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x50,0x88,0x04,0x02,
+/* 38146 0x9502 "锂" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfc,0x10,0x11,0x10,0x14,0x18,0x13,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38147 0x9503 "锃" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x10,0x10,0xfd,0x10,0x10,0x11,0x14,0x18,0x13,0x00,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38148 0x9504 "锄" */
+0x20,0x20,0x3b,0x22,0x42,0x7a,0xa3,0x22,0xfa,0x23,0x22,0x22,0x2a,0x33,0x26,0x00,
+0x08,0x08,0xc8,0x48,0x5e,0x4a,0xca,0x4a,0x4a,0xca,0x4a,0x4a,0x6a,0xd2,0x12,0x26,
+/* 38149 0x9505 "锅" */
+0x20,0x21,0x39,0x21,0x41,0x79,0xa0,0x20,0xfb,0x22,0x22,0x22,0x2b,0x32,0x22,0x02,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xfe,0x22,0x52,0x8a,0x0a,0x02,0x0a,0x04,
+/* 38150 0x9506 "锆" */
+0x20,0x21,0x39,0x21,0x41,0x7a,0xa0,0x23,0xf8,0x20,0x21,0x21,0x29,0x31,0x21,0x01,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 38151 0x9507 "锇" */
+0x20,0x20,0x3b,0x20,0x40,0x7b,0xa0,0x20,0xf8,0x20,0x23,0x20,0x28,0x30,0x22,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 38152 0x9508 "锈" */
+0x10,0x11,0x3c,0x20,0x43,0xbc,0x11,0x12,0xfd,0x10,0x10,0x10,0x15,0x19,0x12,0x04,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x22,0xf8,0x88,0x90,0xbe,0x02,0x02,0x14,0x08,
+/* 38153 0x9509 "锉" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x12,0x14,0xfc,0x10,0x11,0x10,0x14,0x18,0x13,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xaa,0x72,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38154 0x950a "锊" */
+0x10,0x10,0x3d,0x20,0x41,0xbc,0x10,0x10,0xfd,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x08,0xfe,0x08,0x88,0x48,0x48,0x08,0x28,0x10,
+/* 38155 0x950b "锋" */
+0x10,0x10,0x3c,0x20,0x41,0xbc,0x10,0x13,0xfc,0x10,0x10,0x10,0x17,0x18,0x10,0x00,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 38156 0x950c "锌" */
+0x10,0x10,0x3d,0x20,0x40,0xbc,0x13,0x10,0xfc,0x10,0x11,0x10,0x14,0x18,0x10,0x00,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 38157 0x950d "锍" */
+0x20,0x20,0x3b,0x20,0x40,0x79,0xa3,0x20,0xf9,0x21,0x21,0x21,0x2a,0x32,0x24,0x08,
+0x40,0x20,0xfc,0x40,0x90,0x08,0xfc,0x04,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x0e,
+/* 38158 0x950e "锎" */
+0x21,0x20,0x3a,0x22,0x42,0x7a,0xa2,0x22,0xfb,0x22,0x22,0x22,0x2b,0x32,0x22,0x02,
+0x00,0xbe,0x82,0x02,0xfa,0x52,0x52,0x52,0xfe,0x52,0x52,0x92,0x12,0x02,0x0a,0x04,
+/* 38159 0x950f "锏" */
+0x21,0x20,0x3a,0x22,0x42,0x7a,0xa2,0x22,0xfa,0x22,0x22,0x22,0x2a,0x32,0x22,0x02,
+0x00,0xbe,0x82,0x02,0x02,0xfa,0x8a,0x8a,0xfa,0x8a,0x8a,0xfa,0x02,0x02,0x0a,0x04,
+/* 38160 0x9510 "锐" */
+0x22,0x21,0x39,0x40,0x43,0x7a,0xa2,0x22,0xfb,0x20,0x20,0x29,0x31,0x22,0x04,0x08,
+0x08,0x08,0x10,0x20,0xf8,0x08,0x08,0x08,0xf8,0xa0,0xa0,0x20,0x24,0x24,0x1c,0x00,
+/* 38161 0x9511 "锑" */
+0x21,0x20,0x38,0x23,0x40,0x78,0xa3,0x22,0xfa,0x23,0x20,0x20,0x29,0x32,0x24,0x00,
+0x08,0x88,0x90,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x62,0xa2,0x2a,0x24,0x20,0x20,
+/* 38162 0x9512 "锒" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x22,0x14,0x08,0x44,0x82,0x00,
+/* 38163 0x9513 "锓" */
+0x10,0x11,0x3c,0x20,0x40,0xbd,0x10,0x13,0xfe,0x11,0x10,0x10,0x14,0x18,0x10,0x03,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xf8,0x88,0x88,0x50,0x20,0xd8,0x06,
+/* 38164 0x9514 "锔" */
+0x20,0x23,0x3a,0x42,0x43,0x7a,0xa2,0x23,0xfa,0x22,0x22,0x2a,0x34,0x24,0x08,0x00,
+0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0xf4,0x94,0x94,0xf4,0x04,0x28,0x10,
+/* 38165 0x9515 "锕" */
+0x20,0x27,0x3d,0x25,0x45,0x7d,0xa6,0x25,0xfd,0x25,0x25,0x25,0x2e,0x34,0x24,0x04,
+0x00,0x7e,0x04,0x04,0x74,0x54,0x54,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x14,0x08,
+/* 38166 0x9516 "锖" */
+0x20,0x20,0x3b,0x20,0x41,0x78,0xa3,0x20,0xf9,0x21,0x21,0x21,0x29,0x31,0x21,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 38167 0x9517 "锗" */
+0x20,0x20,0x39,0x20,0x40,0x7b,0xa0,0x20,0xf8,0x21,0x22,0x20,0x28,0x30,0x20,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 38168 0x9518 "锘" */
+0x20,0x20,0x3b,0x20,0x40,0x78,0xa3,0x20,0xf8,0x20,0x21,0x22,0x28,0x30,0x20,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 38169 0x9519 "错" */
+0x21,0x21,0x39,0x27,0x41,0x79,0xaf,0x20,0xfb,0x22,0x22,0x23,0x2a,0x32,0x23,0x02,
+0x10,0x10,0x10,0xfc,0x10,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 38170 0x951a "锚" */
+0x20,0x20,0x3b,0x20,0x40,0x78,0xa1,0x21,0xf9,0x21,0x21,0x21,0x29,0x31,0x21,0x01,
+0x88,0x88,0xfe,0x88,0x88,0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x04,
+/* 38171 0x951b "锛" */
+0x20,0x20,0x3b,0x20,0x40,0x79,0xa2,0x20,0xf8,0x20,0x23,0x20,0x28,0x30,0x21,0x02,
+0x20,0x20,0xfe,0x50,0xa8,0x24,0xfa,0x20,0xa8,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 38172 0x951c "锜" */
+0x10,0x10,0x3d,0x20,0x40,0xbd,0x13,0x10,0xfd,0x11,0x11,0x11,0x15,0x18,0x10,0x00,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 38173 0x951d "锝" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x10,0x11,0xfc,0x13,0x10,0x11,0x14,0x18,0x10,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x08,0xfe,0x08,0x08,0x88,0x08,0x28,0x10,
+/* 38174 0x951e "锞" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfc,0x13,0x10,0x10,0x15,0x1a,0x10,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 38175 0x951f "锟" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfc,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 38176 0x9520 "锠" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 38177 0x9521 "锡" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfc,0x11,0x12,0x10,0x15,0x1a,0x10,0x01,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x80,0xfc,0x54,0x94,0x24,0x44,0x94,0x08,
+/* 38178 0x9522 "锢" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 38179 0x9523 "锣" */
+0x20,0x23,0x3a,0x22,0x42,0x7b,0xa0,0x20,0xf8,0x21,0x22,0x20,0x28,0x30,0x21,0x06,
+0x00,0xfe,0x52,0x52,0x52,0xfe,0x20,0x40,0xfc,0x04,0x88,0x50,0x20,0x40,0x80,0x00,
+/* 38180 0x9524 "锤" */
+0x20,0x20,0x39,0x20,0x40,0x7b,0xa1,0x21,0xfb,0x21,0x21,0x23,0x28,0x30,0x23,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x24,0x24,0xfe,0x24,0x24,0xfe,0x20,0x20,0xfe,0x00,
+/* 38181 0x9525 "锥" */
+0x10,0x10,0x3c,0x20,0x41,0xbe,0x10,0x10,0xfc,0x10,0x10,0x10,0x14,0x18,0x10,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38182 0x9526 "锦" */
+0x10,0x10,0x3d,0x21,0x41,0xbd,0x11,0x10,0xfc,0x13,0x12,0x12,0x16,0x1a,0x10,0x00,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 38183 0x9527 "锧" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x1a,0x12,0x04,
+0x1c,0xe0,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x54,0x54,0x54,0x54,0x28,0x44,0x82,
+/* 38184 0x9528 "锨" */
+0x20,0x20,0x3b,0x22,0x42,0x7a,0xa3,0x22,0xfa,0x22,0x22,0x22,0x2a,0x34,0x24,0x08,
+0x10,0x50,0x90,0x1e,0x12,0x24,0xc8,0x88,0x88,0x88,0x88,0x94,0x94,0x94,0x94,0x22,
+/* 38185 0x9529 "锩" */
+0x10,0x11,0x3c,0x20,0x41,0xbc,0x13,0x10,0xfd,0x12,0x14,0x10,0x14,0x18,0x10,0x00,
+0x20,0x24,0xa8,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xa8,0x92,0x82,0x7e,
+/* 38186 0x952a "锪" */
+0x20,0x20,0x38,0x21,0x42,0x78,0xa1,0x22,0xf8,0x21,0x20,0x20,0x2a,0x32,0x24,0x00,
+0x80,0x80,0xfc,0x54,0x54,0xa4,0x24,0x44,0x94,0x08,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 38187 0x952b "锫" */
+0x10,0x10,0x3d,0x20,0x41,0xbc,0x10,0x13,0xfc,0x10,0x11,0x11,0x15,0x19,0x11,0x01,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 38188 0x952c "锬" */
+0x20,0x22,0x3a,0x24,0x40,0x79,0xa6,0x20,0xf8,0x22,0x22,0x24,0x28,0x31,0x22,0x0c,
+0x40,0x44,0x44,0x48,0xa0,0x10,0x08,0x44,0x40,0x48,0x48,0x50,0xa0,0x10,0x08,0x06,
+/* 38189 0x952d "锭" */
+0x20,0x20,0x3b,0x22,0x44,0x78,0xa3,0x20,0xf8,0x21,0x21,0x21,0x2a,0x32,0x24,0x08,
+0x40,0x20,0xfe,0x02,0x04,0x00,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 38190 0x952e "键" */
+0x20,0x20,0x3b,0x21,0x41,0x7a,0xa2,0x27,0xf9,0x25,0x25,0x22,0x2a,0x35,0x28,0x00,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 38191 0x952f "锯" */
+0x20,0x23,0x3a,0x22,0x43,0x7a,0xa2,0x23,0xfa,0x22,0x22,0x22,0x2a,0x34,0x24,0x08,
+0x00,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 38192 0x9530 "锰" */
+0x20,0x21,0x38,0x20,0x40,0x7b,0xa0,0x20,0xf8,0x21,0x21,0x21,0x29,0x31,0x27,0x00,
+0x00,0xfc,0x08,0x10,0x20,0xfe,0x20,0xa0,0x40,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 38193 0x9531 "锱" */
+0x10,0x10,0x3d,0x22,0x41,0xbc,0x10,0x10,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 38194 0x9532 "锲" */
+0x21,0x21,0x3b,0x21,0x43,0x79,0xa7,0x21,0xf9,0x20,0x27,0x20,0x28,0x31,0x22,0x0c,
+0x00,0x3c,0xd4,0x14,0x94,0x14,0xd4,0x24,0x4c,0x40,0xfe,0x40,0xa0,0x10,0x08,0x06,
+/* 38195 0x9533 "锳" */
+0x20,0x20,0x3b,0x20,0x40,0x78,0xa1,0x21,0xf9,0x21,0x27,0x20,0x28,0x30,0x21,0x02,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfc,0x24,0x24,0x24,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 38196 0x9534 "锴" */
+0x11,0x11,0x3d,0x21,0x41,0xbd,0x11,0x10,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 38197 0x9535 "锵" */
+0x10,0x10,0x3c,0x22,0x41,0xbc,0x10,0x10,0xfd,0x12,0x14,0x10,0x14,0x18,0x10,0x00,
+0x90,0x90,0x9e,0xa2,0xd4,0x88,0x94,0xa4,0xfe,0x84,0xa4,0x94,0x94,0x84,0x94,0x88,
+/* 38198 0x9536 "锶" */
+0x20,0x21,0x39,0x21,0x41,0x79,0xa1,0x21,0xf8,0x20,0x20,0x22,0x2a,0x34,0x20,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x40,0x24,0xa2,0x8a,0x88,0x78,0x00,
+/* 38199 0x9537 "锷" */
+0x20,0x23,0x3a,0x22,0x43,0x78,0xa1,0x20,0xfb,0x20,0x21,0x21,0x28,0x30,0x20,0x00,
+0x00,0xde,0x52,0x52,0xde,0x00,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 38200 0x9538 "锸" */
+0x10,0x10,0x3d,0x20,0x40,0xbd,0x10,0x10,0xfd,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x04,
+/* 38201 0x9539 "锹" */
+0x20,0x20,0x3b,0x21,0x41,0x79,0xa3,0x21,0xf9,0x23,0x25,0x21,0x29,0x31,0x21,0x01,
+0x08,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 38202 0x953a "锺" */
+0x10,0x10,0x3d,0x20,0x43,0xbc,0x11,0x11,0xfd,0x11,0x11,0x10,0x15,0x18,0x13,0x00,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 38203 0x953b "锻" */
+0x20,0x23,0x3a,0x22,0x43,0x7a,0xa2,0x22,0xfb,0x22,0x22,0x23,0x2e,0x32,0x22,0x02,
+0x80,0x38,0x28,0x28,0xa8,0x46,0x00,0x7c,0xa4,0x24,0x28,0xa8,0x10,0x28,0x44,0x82,
+/* 38204 0x953c "锼" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x11,0x11,0xfc,0x11,0x10,0x10,0x14,0x18,0x10,0x03,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 38205 0x953d "锽" */
+0x10,0x10,0x3c,0x20,0x40,0xbc,0x10,0x10,0xfd,0x10,0x10,0x10,0x14,0x18,0x11,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38206 0x953e "锾" */
+0x10,0x13,0x3c,0x21,0x40,0xbd,0x10,0x10,0xfd,0x10,0x10,0x11,0x15,0x1a,0x10,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 38207 0x953f "锿" */
+0x20,0x20,0x3b,0x20,0x41,0x79,0xa1,0x21,0xf9,0x20,0x20,0x21,0x2a,0x34,0x20,0x00,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0x04,0x04,0xfc,0x52,0x94,0x88,0x88,0xa4,0xc2,0x80,
+/* 38208 0x9540 "镀" */
+0x20,0x20,0x3b,0x22,0x42,0x7b,0xa2,0x22,0xfa,0x22,0x22,0x22,0x2a,0x34,0x24,0x09,
+0x40,0x20,0xfe,0x48,0x48,0xfe,0x48,0x78,0x00,0xfc,0x44,0x48,0x28,0x10,0x68,0x86,
+/* 38209 0x9541 "镁" */
+0x21,0x20,0x3b,0x20,0x40,0x79,0xa0,0x20,0xfb,0x20,0x20,0x23,0x28,0x30,0x20,0x03,
+0x04,0x88,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x20,0xfe,0x20,0x50,0x88,0x06,
+/* 38210 0x9542 "镂" */
+0x10,0x11,0x3c,0x20,0x43,0xbc,0x11,0x12,0xfc,0x13,0x10,0x11,0x15,0x18,0x11,0x06,
+0x20,0x24,0xa8,0x20,0xfe,0xa8,0x24,0x02,0x40,0xfe,0x88,0x08,0x90,0x60,0x98,0x04,
+/* 38211 0x9543 "镃" */
+0x20,0x20,0x38,0x23,0x40,0x78,0xa1,0x21,0xfa,0x23,0x20,0x21,0x29,0x32,0x23,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 38212 0x9544 "镄" */
+0x20,0x27,0x38,0x23,0x42,0x7b,0xa1,0x22,0xfd,0x21,0x21,0x21,0x29,0x30,0x20,0x03,
+0x90,0xfc,0x94,0xfc,0x90,0xfe,0x12,0x16,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 38213 0x9545 "镅" */
+0x20,0x23,0x3a,0x42,0x43,0x7a,0xa2,0x22,0xfa,0x22,0x22,0x2a,0x34,0x24,0x08,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x00,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 38214 0x9546 "镆" */
+0x20,0x20,0x3b,0x20,0x40,0x79,0xa1,0x21,0xf9,0x21,0x20,0x23,0x28,0x30,0x21,0x02,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 38215 0x9547 "镇" */
+0x20,0x20,0x3b,0x40,0x41,0x79,0xa1,0x21,0xf9,0x21,0x21,0x29,0x37,0x20,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 38216 0x9548 "镈" */
+0x20,0x20,0x3b,0x20,0x41,0x79,0xa1,0x21,0xf9,0x21,0x20,0x23,0x28,0x30,0x20,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 38217 0x9549 "镉" */
+0x20,0x23,0x38,0x21,0x41,0x79,0xa1,0x20,0xfb,0x22,0x22,0x23,0x2a,0x32,0x22,0x02,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 38218 0x954a "镊" */
+0x20,0x23,0x39,0x21,0x41,0x79,0xa1,0x27,0xf8,0x27,0x20,0x22,0x29,0x32,0x24,0x08,
+0x00,0xfc,0x08,0xf8,0x08,0xf8,0x0e,0xf8,0x08,0xbc,0xa4,0xa4,0x28,0x90,0xa8,0x46,
+/* 38219 0x954b "镋" */
+0x20,0x21,0x38,0x20,0x43,0x7a,0xa0,0x21,0xf9,0x21,0x21,0x20,0x28,0x30,0x21,0x02,
+0x20,0x24,0xa8,0x20,0xfe,0x02,0x00,0xfc,0x04,0x04,0xfc,0x50,0x50,0x92,0x12,0x0e,
+/* 38220 0x954c "镌" */
+0x20,0x20,0x39,0x23,0x45,0x79,0xa1,0x21,0xf9,0x21,0x23,0x20,0x28,0x31,0x22,0x04,
+0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x9e,0x02,0x0a,0x04,
+/* 38221 0x954d "镍" */
+0x20,0x20,0x3b,0x22,0x43,0x7a,0xa3,0x22,0xfb,0x20,0x27,0x20,0x29,0x32,0x24,0x00,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfe,0xe0,0x50,0x48,0x46,0x40,
+/* 38222 0x954e "镎" */
+0x10,0x10,0x3c,0x21,0x42,0xbc,0x10,0x10,0xfc,0x11,0x10,0x11,0x14,0x1b,0x10,0x00,
+0x20,0x50,0x88,0x74,0x02,0xf8,0x88,0xf8,0x0c,0xf0,0x20,0xfc,0x20,0xfe,0x20,0x60,
+/* 38223 0x954f "镏" */
+0x20,0x23,0x3a,0x22,0x42,0x7a,0xa3,0x20,0xfb,0x22,0x22,0x23,0x2a,0x32,0x23,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 38224 0x9550 "镐" */
+0x20,0x20,0x3b,0x20,0x41,0x79,0xa1,0x20,0xfb,0x22,0x22,0x22,0x2a,0x32,0x22,0x02,
+0x40,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x00,0xfe,0x02,0xfa,0x8a,0xfa,0x02,0x0a,0x04,
+/* 38225 0x9551 "镑" */
+0x20,0x20,0x3b,0x21,0x40,0x7b,0xa2,0x24,0xf8,0x23,0x20,0x20,0x28,0x31,0x21,0x02,
+0x40,0x20,0xfc,0x08,0x90,0xfe,0x02,0x44,0x20,0xfc,0x80,0xf8,0x88,0x08,0x28,0x10,
+/* 38226 0x9552 "镒" */
+0x21,0x20,0x38,0x20,0x43,0x78,0xa0,0x21,0xfa,0x21,0x21,0x21,0x29,0x31,0x27,0x00,
+0x04,0x84,0x88,0x00,0xfe,0x00,0x88,0x04,0x02,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 38227 0x9553 "镓" */
+0x20,0x20,0x3b,0x22,0x40,0x79,0xa0,0x20,0xfb,0x20,0x20,0x23,0x28,0x30,0x23,0x00,
+0x40,0x20,0xfe,0x02,0x00,0xfc,0x40,0xa2,0x34,0x58,0x94,0x34,0x52,0x90,0x50,0x20,
+/* 38228 0x9554 "镔" */
+0x20,0x20,0x3b,0x22,0x44,0x79,0xa1,0x21,0xf9,0x21,0x21,0x27,0x28,0x30,0x21,0x02,
+0x40,0x20,0xfe,0x02,0x14,0xe0,0x00,0x00,0xfc,0x10,0x10,0xfe,0x00,0x90,0x08,0x04,
+/* 38229 0x9555 "镕" */
+0x20,0x20,0x3b,0x22,0x40,0x78,0xa1,0x20,0xf8,0x21,0x22,0x20,0x28,0x30,0x20,0x00,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 38230 0x9556 "镖" */
+0x10,0x13,0x3c,0x21,0x41,0xbd,0x11,0x10,0xfd,0x10,0x13,0x10,0x14,0x19,0x12,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 38231 0x9557 "镗" */
+0x20,0x21,0x38,0x23,0x42,0x78,0xa0,0x20,0xf8,0x20,0x20,0x21,0x28,0x30,0x23,0x00,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38232 0x9558 "镘" */
+0x20,0x21,0x39,0x21,0x41,0x79,0xa0,0x23,0xfa,0x23,0x20,0x21,0x28,0x30,0x21,0x06,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 38233 0x9559 "镙" */
+0x10,0x11,0x3d,0x21,0x41,0xbd,0x10,0x10,0xfd,0x10,0x10,0x13,0x14,0x19,0x12,0x00,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 38234 0x955a "镚" */
+0x20,0x22,0x3a,0x23,0x40,0x7b,0xa2,0x22,0xfb,0x22,0x22,0x23,0x2a,0x32,0x25,0x08,
+0x20,0x22,0x22,0xfe,0x00,0xde,0x52,0x52,0xde,0x52,0x52,0xde,0x52,0x52,0x5a,0xa4,
+/* 38235 0x955b "镛" */
+0x20,0x27,0x3c,0x25,0x44,0x77,0xa4,0x25,0xfc,0x25,0x25,0x25,0x2d,0x39,0x29,0x11,
+0x20,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x2c,
+/* 38236 0x955c "镜" */
+0x20,0x20,0x3b,0x21,0x40,0x77,0xa0,0x23,0xfa,0x23,0x22,0x23,0x29,0x31,0x22,0x0c,
+0x80,0x40,0xf8,0x10,0xa0,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x22,0x22,0x1e,
+/* 38237 0x955d "镝" */
+0x20,0x20,0x3b,0x20,0x40,0x7b,0xa2,0x22,0xfa,0x22,0x22,0x22,0x2a,0x32,0x22,0x02,
+0x40,0x20,0xfe,0x88,0x50,0xfe,0x22,0xfa,0x22,0xfa,0x8a,0x8a,0xfa,0x02,0x0a,0x04,
+/* 38238 0x955e "镞" */
+0x22,0x21,0x39,0x47,0x42,0x7a,0xa3,0x22,0xfa,0x22,0x22,0x2a,0x34,0x25,0x08,0x10,
+0x20,0x20,0x20,0xbe,0x40,0x20,0xbc,0xd0,0x90,0x90,0xfe,0x90,0xa8,0xa8,0x44,0x82,
+/* 38239 0x955f "镟" */
+0x22,0x21,0x39,0x47,0x42,0x7a,0xa3,0x22,0xfa,0x22,0x22,0x2a,0x34,0x25,0x08,0x10,
+0x10,0x10,0x10,0xbe,0x40,0x00,0xbe,0x8a,0x88,0xa8,0xae,0xa8,0xa8,0xa8,0x5e,0x80,
+/* 38240 0x9560 "镠" */
+0x20,0x23,0x38,0x22,0x41,0x7a,0xa0,0x20,0xfb,0x20,0x21,0x20,0x29,0x30,0x20,0x03,
+0x00,0xde,0x42,0x52,0x4a,0x52,0x28,0xc4,0x12,0x60,0x88,0x32,0xc4,0x18,0x60,0x80,
+/* 38241 0x9561 "镡" */
+0x20,0x23,0x38,0x23,0x42,0x7b,0xa0,0x21,0xf9,0x21,0x21,0x21,0x28,0x33,0x20,0x00,
+0x00,0xfe,0x50,0xfe,0x52,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,
+/* 38242 0x9562 "镢" */
+0x20,0x2f,0x38,0x4a,0x49,0x7b,0xa8,0x28,0xfa,0x2a,0x2b,0x28,0x38,0x29,0x09,0x12,
+0x00,0xfe,0x00,0x28,0x48,0xee,0x92,0x84,0xa0,0xa8,0xe8,0x88,0x94,0x14,0x24,0x42,
+/* 38243 0x9563 "镣" */
+0x20,0x20,0x3b,0x20,0x42,0x79,0xa3,0x25,0xf9,0x21,0x21,0x20,0x29,0x32,0x24,0x00,
+0x20,0x20,0xfe,0x50,0x8a,0x04,0xfe,0x04,0xfc,0x04,0xfc,0x20,0x24,0x22,0xa2,0x40,
+/* 38244 0x9564 "镤" */
+0x20,0x24,0x3a,0x20,0x47,0x79,0xa0,0x27,0xf8,0x23,0x20,0x27,0x28,0x31,0x22,0x0c,
+0xa0,0xa4,0xa8,0xa0,0xfc,0x10,0xa0,0xfc,0x40,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 38245 0x9565 "镥" */
+0x20,0x20,0x39,0x23,0x45,0x79,0xa1,0x21,0xf8,0x23,0x20,0x21,0x29,0x31,0x21,0x01,
+0x80,0xf8,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,
+/* 38246 0x9566 "镦" */
+0x21,0x20,0x3b,0x20,0x43,0x7a,0xa3,0x20,0xfb,0x20,0x20,0x20,0x2b,0x30,0x22,0x01,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 38247 0x9567 "镧" */
+0x22,0x21,0x3d,0x24,0x45,0x7c,0xa5,0x25,0xfd,0x25,0x25,0x25,0x2c,0x35,0x24,0x04,
+0x00,0x7c,0x04,0x44,0xf4,0x44,0xf4,0x54,0x74,0xd4,0x54,0xf4,0xe4,0x54,0x44,0x4c,
+/* 38248 0x9568 "镨" */
+0x21,0x20,0x3b,0x20,0x42,0x79,0xa0,0x27,0xf8,0x21,0x21,0x21,0x29,0x31,0x21,0x01,
+0x08,0x90,0xfc,0x90,0x94,0x98,0x90,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 38249 0x9569 "镩" */
+0x20,0x20,0x3b,0x22,0x41,0x7a,0xa1,0x21,0xf9,0x20,0x23,0x22,0x2b,0x32,0x20,0x00,
+0x40,0x20,0xfe,0x8a,0x24,0x22,0xfc,0x24,0xfc,0x20,0xfe,0x22,0xfe,0x22,0x20,0x20,
+/* 38250 0x956a "镪" */
+0x20,0x23,0x38,0x20,0x40,0x7b,0xa2,0x22,0xfa,0x23,0x20,0x20,0x28,0x30,0x25,0x02,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 38251 0x956b "镫" */
+0x20,0x27,0x38,0x22,0x41,0x7a,0xa5,0x28,0xfb,0x22,0x22,0x23,0x2a,0x31,0x2f,0x00,
+0x20,0xa4,0xa8,0x92,0x14,0x08,0xf4,0x02,0xf8,0x08,0x08,0xf8,0x08,0x10,0xfe,0x00,
+/* 38252 0x956c "镬" */
+0x20,0x23,0x38,0x20,0x41,0x7b,0xa1,0x21,0xf9,0x21,0x21,0x21,0x2b,0x30,0x20,0x03,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 38253 0x956d "镭" */
+0x10,0x11,0x3c,0x23,0x42,0xbd,0x10,0x11,0xfc,0x11,0x11,0x11,0x15,0x19,0x11,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,
+/* 38254 0x956e "镮" */
+0x20,0x23,0x3a,0x22,0x43,0x78,0xa7,0x20,0xfb,0x22,0x23,0x20,0x29,0x33,0x2d,0x01,
+0x00,0xfc,0x94,0x94,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0xa2,0x14,0x08,0x44,0x82,
+/* 38255 0x956f "镯" */
+0x20,0x23,0x3a,0x22,0x43,0x79,0xa3,0x24,0xfb,0x22,0x22,0x23,0x28,0x37,0x20,0x00,
+0x00,0xf8,0xa8,0xa8,0xf8,0x00,0xfc,0x84,0xe4,0xa4,0xa4,0xe4,0x94,0xf4,0x14,0x08,
+/* 38256 0x9570 "镰" */
+0x20,0x23,0x3a,0x22,0x43,0x7a,0xa2,0x22,0xfb,0x22,0x22,0x22,0x2a,0x35,0x26,0x08,
+0x20,0xfe,0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,
+/* 38257 0x9571 "镱" */
+0x20,0x20,0x39,0x20,0x40,0x7b,0xa0,0x21,0xf9,0x21,0x21,0x21,0x28,0x32,0x22,0x04,
+0x40,0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x94,0x8a,0x7a,
+/* 38258 0x9572 "镲" */
+0x20,0x20,0x37,0x44,0x4a,0x73,0xa4,0x2a,0xf5,0x22,0x24,0x23,0x28,0x32,0x24,0x00,
+0x80,0x40,0xfe,0x02,0x24,0xbc,0xa4,0xa8,0x10,0xe8,0x04,0xf8,0x40,0x48,0x44,0xc0,
+/* 38259 0x9573 "镳" */
+0x20,0x20,0x3b,0x22,0x43,0x7a,0xa3,0x22,0xfa,0x22,0x22,0x22,0x2a,0x34,0x25,0x0a,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x00,0x94,0xd8,0x90,0xd2,0x8e,0x00,0x54,0x2a,
+/* 38260 0x9574 "镴" */
+0x21,0x22,0x39,0x20,0x43,0x7a,0xa2,0x22,0xfb,0x22,0x23,0x22,0x2b,0x32,0x22,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 38261 0x9575 "镵" */
+0x21,0x22,0x3b,0x26,0x43,0x7a,0xa3,0x22,0xf9,0x22,0x27,0x22,0x2b,0x30,0x21,0x06,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 38262 0x9576 "镶" */
+0x20,0x27,0x38,0x23,0x42,0x7b,0xa1,0x27,0xf9,0x27,0x21,0x27,0x29,0x33,0x25,0x01,
+0x40,0xfc,0x00,0xb8,0xa8,0xb8,0x10,0xfc,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 38263 0x9577 "長" */
+0x00,0x0f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x12,0x11,0x10,0x10,0x12,0x14,0x18,0x10,
+0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfe,0x00,0x10,0xa0,0x40,0x20,0x18,0x06,0x00,
+/* 38264 0x9578 "镸" */
+0x00,0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0xff,0x04,0x08,0x10,0x3f,0x10,
+0x00,0xf8,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xfe,0x00,0x20,0x10,0xf8,0x08,
+/* 38265 0x9579 "镹" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x3c,0x21,0x20,0xfe,0x10,0x20,0x44,0xfe,0x02,0x01,
+0x40,0x40,0x40,0x78,0x88,0x88,0x88,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 38266 0x957a "镺" */
+0x00,0x3e,0x21,0x20,0x3c,0x20,0x3d,0x20,0x20,0xfe,0x10,0x20,0x44,0xfe,0x03,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 38267 0x957b "镻" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x3d,0x20,0x21,0xfe,0x10,0x20,0x44,0xfe,0x03,0x02,
+0x20,0x20,0xa0,0xa0,0xfc,0xa0,0x20,0x20,0xfe,0x20,0x30,0x50,0x48,0x88,0x04,0x02,
+/* 38268 0x957c "镼" */
+0x00,0x3e,0x20,0x20,0x3c,0x20,0x3c,0x20,0x20,0xfe,0x10,0x20,0x44,0xfe,0x02,0x01,
+0x00,0xfe,0x82,0xfe,0x88,0xaa,0xaa,0xaa,0xbe,0x88,0xaa,0xaa,0xaa,0xaa,0xbe,0x02,
+/* 38269 0x957d "镽" */
+0x00,0x3e,0x21,0x20,0x3d,0x20,0x3d,0x22,0x20,0xfe,0x10,0x20,0x44,0xfe,0x03,0x00,
+0x20,0x20,0xfc,0x20,0x54,0x88,0x04,0xfa,0x88,0xf8,0x88,0xf8,0x20,0xa8,0x24,0x60,
+/* 38270 0x957e "镾" */
+0x00,0x3b,0x21,0x3a,0x27,0x3a,0x23,0x22,0xfb,0x22,0x23,0x4a,0xfb,0x4a,0x02,0x02,
+0x00,0xfe,0x24,0x22,0xfe,0x22,0x76,0xaa,0x76,0x22,0x76,0xaa,0x76,0x22,0x2a,0x04,
+/* 38271 0x957f "长" */
+0x08,0x08,0x08,0x08,0x08,0x09,0x08,0xff,0x0a,0x09,0x08,0x08,0x09,0x0a,0x0c,0x08,
+0x00,0x10,0x20,0x40,0x80,0x00,0x00,0xfe,0x00,0x00,0x80,0x40,0x20,0x18,0x06,0x00,
+/* 38272 0x9580 "門" */
+0x00,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38273 0x9581 "閁" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x40,0x41,0x41,0x42,0x44,0x48,0x40,0x40,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x08,0x88,0x88,0x08,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 38274 0x9582 "閂" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x40,0x5f,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38275 0x9583 "閃" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x41,0x41,0x41,0x42,0x42,0x44,0x48,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x04,0x04,0x84,0x44,0x24,0x04,0x14,0x08,
+/* 38276 0x9584 "閄" */
+0x00,0x77,0x55,0x55,0x77,0x55,0x55,0x77,0x41,0x41,0x41,0x41,0x41,0x41,0x45,0x42,
+0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 38277 0x9585 "閅" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x41,0x41,0x41,0x41,0x41,0x45,0x42,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38278 0x9586 "閆" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x40,0x4f,0x40,0x5f,0x40,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x04,0xf4,0x04,0x04,0x14,0x08,
+/* 38279 0x9587 "閇" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0x84,0x44,0x24,0x04,0x04,0x14,0x08,
+/* 38280 0x9588 "閈" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x41,0x41,0x5f,0x41,0x41,0x41,0x41,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0x04,0xf4,0x04,0x04,0x04,0x14,0x08,
+/* 38281 0x9589 "閉" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x4f,0x41,0x42,0x44,0x48,0x42,0x41,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x84,0x84,0xf4,0x84,0x84,0x84,0x84,0x84,0x14,0x08,
+/* 38282 0x958a "閊" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x49,0x49,0x49,0x49,0x4f,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x24,0x24,0x24,0x24,0xe4,0x04,0x14,0x08,
+/* 38283 0x958b "開" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x44,0x44,0x5f,0x44,0x44,0x48,0x50,0x40,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x08,0xc8,0x88,0x88,0xe8,0x88,0x88,0x88,0xa8,0x10,
+/* 38284 0x958c "閌" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x5f,0x40,0x47,0x44,0x44,0x48,0x50,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0xc4,0x44,0x44,0x54,0x34,0x04,0x0c,
+/* 38285 0x958d "閍" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x7f,0x44,0x47,0x44,0x48,0x51,0x60,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xfc,0x04,0xe4,0x24,0x24,0x44,0x94,0x08,
+/* 38286 0x958e "閎" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x5f,0x42,0x44,0x44,0x49,0x52,0x67,0x42,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0x84,0x84,0x04,0x24,0xf4,0x14,0x0c,
+/* 38287 0x958f "閏" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x41,0x4f,0x41,0x41,0x5f,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 38288 0x9590 "閐" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x41,0x5e,0x43,0x5e,0x43,0x5e,0x42,0x41,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x04,0xc4,0x04,0xe4,0x04,0x24,0xe4,0x14,0x08,
+/* 38289 0x9591 "閑" */
+0x7c,0x44,0x7c,0x44,0x7d,0x41,0x41,0x5f,0x41,0x43,0x45,0x49,0x51,0x41,0x41,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0x84,0x44,0x24,0x14,0x04,0x14,0x08,
+/* 38290 0x9592 "閒" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x47,0x44,0x47,0x44,0x47,0x44,0x48,0x50,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xa4,0x44,0x14,0x08,
+/* 38291 0x9593 "間" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x40,0x40,0x40,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xc8,0x48,0x08,0x28,0x10,
+/* 38292 0x9594 "閔" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x5f,0x40,0x44,0x42,0x41,0x42,0x44,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x44,0x44,0x84,0x04,0x84,0x44,0x54,0x08,
+/* 38293 0x9595 "閕" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x40,0x48,0x4f,0x42,0x44,0x58,0x41,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x84,0x84,0xf4,0x84,0x84,0x84,0x94,0x08,
+/* 38294 0x9596 "閖" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x5d,0x45,0x45,0x49,0x49,0x51,0x65,0x42,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0x14,0xa4,0x44,0x24,0x14,0x14,0x04,0x14,0x08,
+/* 38295 0x9597 "閗" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x44,0x42,0x48,0x44,0x40,0x5f,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x84,0x84,0x84,0x84,0x84,0xf4,0x84,0x84,0x94,0x88,
+/* 38296 0x9598 "閘" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x49,0x4f,0x49,0x4f,0x49,0x41,0x41,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x04,0x04,0x14,0x08,
+/* 38297 0x9599 "閙" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x5f,0x41,0x4f,0x49,0x49,0x49,0x41,0x41,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xf4,0x04,0xe4,0x24,0xa4,0x44,0x14,0x08,
+/* 38298 0x959a "閚" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x4f,0x44,0x42,0x42,0x5f,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0x44,0x44,0x84,0xf4,0x04,0x14,0x08,
+/* 38299 0x959b "閛" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x41,0x49,0x45,0x5f,0x41,0x41,0x41,0x41,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0x24,0x44,0xf4,0x04,0x04,0x04,0x14,0x08,
+/* 38300 0x959c "閜" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x40,0x4f,0x49,0x4f,0x40,0x41,0x40,0x40,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x08,0xe8,0x48,0x48,0x48,0x48,0x48,0x48,0xa8,0x10,
+/* 38301 0x959d "閝" */
+0x7c,0x44,0x7c,0x44,0x7d,0x41,0x42,0x44,0x4a,0x51,0x6f,0x40,0x40,0x42,0x41,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x84,0x44,0x24,0x1c,0xe4,0x24,0x44,0x84,0x14,0x88,
+/* 38302 0x959e "閞" */
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x48,0x5f,0x44,0x44,0x5f,0x44,0x44,0x44,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x24,0xf4,0x54,0x44,0xf4,0x44,0x44,0x44,0x54,0x08,
+/* 38303 0x959f "閟" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x42,0x41,0x44,0x55,0x56,0x64,0x4c,0x73,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x84,0x24,0x14,0x54,0x44,0xc4,0x14,0x08,
+/* 38304 0x95a0 "閠" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x41,0x4f,0x41,0x41,0x5f,0x40,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x04,0x44,0xf4,0x04,0x14,0x08,
+/* 38305 0x95a1 "閡" */
+0x7c,0x44,0x7c,0x44,0x7e,0x41,0x5f,0x42,0x44,0x4f,0x41,0x46,0x58,0x43,0x4c,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0x44,0x84,0x24,0x44,0x84,0x44,0x34,0x08,
+/* 38306 0x95a2 "関" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x44,0x42,0x4f,0x41,0x5f,0x41,0x42,0x44,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x84,0xe4,0x04,0xf4,0x04,0x84,0x44,0x24,0x0c,
+/* 38307 0x95a3 "閣" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x47,0x48,0x54,0x43,0x4c,0x70,0x47,0x44,0x44,0x47,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0x44,0x84,0x64,0x1c,0xc4,0x44,0x54,0xc8,
+/* 38308 0x95a4 "閤" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x42,0x44,0x5b,0x40,0x47,0x44,0x44,0x47,0x44,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x84,0x44,0xb4,0x04,0xc4,0x44,0x44,0xc4,0x54,0x08,
+/* 38309 0x95a5 "閥" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x45,0x49,0x59,0x6f,0x49,0x48,0x49,0x4a,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x24,0xf4,0x24,0x44,0x84,0x54,0x34,0x14,0x0c,
+/* 38310 0x95a6 "閦" */
+0x00,0x7c,0x44,0x7c,0x44,0x7d,0x42,0x44,0x58,0x44,0x44,0x44,0x4a,0x51,0x40,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x84,0x44,0x34,0x44,0x44,0x44,0xa4,0x14,0x14,0x08,
+/* 38311 0x95a7 "閧" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x44,0x5f,0x44,0x44,0x7f,0x40,0x44,0x44,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0xf4,0x44,0x44,0xfc,0x04,0x44,0x24,0x24,0x0c,
+/* 38312 0x95a8 "閨" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x4f,0x41,0x5f,0x41,0x4f,0x41,0x5f,0x40,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0xf4,0x04,0xe4,0x04,0xf4,0x04,0x14,0x08,
+/* 38313 0x95a9 "閩" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x41,0x4f,0x49,0x49,0x4f,0x41,0x5f,0x40,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0x24,0x24,0xe4,0x14,0xf4,0x14,0x04,0x0c,
+/* 38314 0x95aa "閪" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x4f,0x4a,0x4a,0x4c,0x48,0x4f,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x84,0xe4,0xa4,0xa4,0xe4,0x24,0xe4,0x24,0x0c,
+/* 38315 0x95ab "閫" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x51,0x51,0x5f,0x53,0x55,0x59,0x51,0x5f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x14,0x14,0xf4,0x94,0x54,0x34,0x14,0xf4,0x0c,
+/* 38316 0x95ac "閬" */
+0x7c,0x44,0x7c,0x44,0x7e,0x41,0x4f,0x48,0x4f,0x48,0x4f,0x49,0x48,0x4a,0x4c,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x24,0x1c,
+/* 38317 0x95ad "閭" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x40,0x5f,0x50,0x5f,0x40,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x04,0xf4,0x14,0xf4,0x04,0x14,0x08,
+/* 38318 0x95ae "閮" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5d,0x44,0x48,0x5d,0x44,0x54,0x49,0x56,0x61,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x34,0xc4,0x44,0x44,0xf4,0x44,0x44,0xf4,0x04,0xf4,0x0c,
+/* 38319 0x95af "閯" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x50,0x48,0x62,0x52,0x4c,0x70,0x50,0x51,0x56,0x40,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x84,0x84,0xa4,0x94,0x84,0x24,0x44,0x84,0x14,0x08,
+/* 38320 0x95b0 "閰" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x42,0x4c,0x48,0x48,0x4e,0x48,0x48,0x4f,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x04,0x0c,
+/* 38321 0x95b1 "閱" */
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x48,0x5f,0x68,0x48,0x4f,0x42,0x42,0x44,0x48,0x50,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x24,0xf4,0x2c,0x24,0xe4,0x84,0x84,0x94,0x74,0x0c,
+/* 38322 0x95b2 "閲" */
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x42,0x4f,0x48,0x4f,0x42,0x42,0x44,0x58,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x84,0xe4,0x24,0xe4,0x84,0x84,0x94,0x74,0x04,0x0c,
+/* 38323 0x95b3 "閳" */
+0x7c,0x44,0x7c,0x44,0x7d,0x41,0x5f,0x41,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x5f,0x41,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x0c,
+/* 38324 0x95b4 "閴" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x44,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x44,0x24,0x0c,
+/* 38325 0x95b5 "閵" */
+0x7c,0x44,0x7c,0x44,0x7c,0x45,0x44,0x4f,0x59,0x6f,0x49,0x4f,0x49,0x4f,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x84,0xf4,0x04,0xe4,0x04,0xe4,0x04,0xf4,0x04,0x0c,
+/* 38326 0x95b6 "閶" */
+0x7c,0x44,0x7c,0x44,0x7f,0x48,0x4f,0x48,0x4f,0x40,0x5f,0x50,0x5f,0x50,0x5f,0x40,
+0x7c,0x44,0x7c,0x44,0xfc,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x08,
+/* 38327 0x95b7 "閷" */
+0x08,0x8b,0x52,0x23,0x52,0x8b,0x22,0x22,0xfa,0x22,0xb2,0xaa,0x2a,0x22,0xa2,0x42,
+0x00,0xde,0x52,0xde,0x52,0xde,0x02,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x0a,0x04,
+/* 38328 0x95b8 "閸" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x4e,0x48,0x48,0x4e,0x42,0x42,0x5f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x84,0xe4,0x24,0x24,0xe4,0x84,0x84,0xf4,0x0c,
+/* 38329 0x95b9 "閹" */
+0x7c,0x44,0x7c,0x44,0x7d,0x42,0x5f,0x49,0x5f,0x69,0x4f,0x49,0x4f,0x41,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x24,0xf4,0x2c,0xe4,0x24,0xe4,0x14,0xf4,0x0c,
+/* 38330 0x95ba "閺" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x41,0x5f,0x44,0x43,0x5c,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x44,0x84,0x6c,
+/* 38331 0x95bb "閻" */
+0x7c,0x44,0x7c,0x44,0x7e,0x42,0x47,0x48,0x52,0x4c,0x48,0x48,0x4e,0x48,0x48,0x4f,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0x44,0xe4,0x24,0x24,0xe4,0x24,0x24,0xec,
+/* 38332 0x95bc "閼" */
+0x7c,0x44,0x7c,0x44,0x7c,0x48,0x44,0x5e,0x48,0x4f,0x4a,0x4a,0x4a,0x52,0x66,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x44,0xa4,0x14,0x4c,0x24,0x84,0x44,0x24,0x0c,
+/* 38333 0x95bd "閽" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x51,0x5f,0x50,0x58,0x4f,0x48,0x4f,0x48,0x4f,
+0x7c,0x44,0x7c,0x44,0x7c,0x64,0x84,0x04,0xe4,0x94,0x74,0xe4,0x24,0xe4,0x24,0xec,
+/* 38334 0x95be "閾" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x40,0x5f,0x40,0x4e,0x4a,0x4e,0x40,0x46,0x59,0x42,
+0x7c,0x44,0x7c,0x44,0x7c,0x84,0xa4,0xf4,0x84,0xa4,0xa4,0xa4,0x54,0xb4,0x14,0x0c,
+/* 38335 0x95bf "閿" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x49,0x5f,0x50,0x47,0x40,0x46,0x41,0x42,0x4c,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x24,0x44,0xf4,0x14,0xc4,0x44,0x84,0x04,0x84,0x4c,
+/* 38336 0x95c0 "闀" */
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x5f,0x44,0x7f,0x48,0x57,0x64,0x47,0x44,0x43,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0xf4,0x44,0xfc,0x24,0xd4,0x4c,0xc4,0x24,0xe4,0x0c,
+/* 38337 0x95c1 "闁" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4e,0x4a,0x4e,0x4a,0x4e,0x48,0x48,0x48,0x48,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0xa4,0xe4,0xa4,0xe4,0x24,0x24,0x24,0x64,0x0c,
+/* 38338 0x95c2 "闂" */
+0x7c,0x44,0x7c,0x44,0x7c,0x49,0x45,0x5f,0x42,0x7f,0x48,0x57,0x64,0x44,0x44,0x43,
+0x7c,0x44,0x7c,0x44,0x7c,0x24,0x44,0xf4,0x04,0xfc,0x24,0xd4,0x4c,0xc4,0x24,0xec,
+/* 38339 0x95c3 "闃" */
+0x7c,0x44,0x7c,0x44,0x7c,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x41,0x5f,0x42,0x44,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x44,0xf4,0x84,0x4c,
+/* 38340 0x95c4 "闄" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x4f,0x4a,0x4f,0x42,0x5f,0x44,0x43,0x5c,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x84,0xe4,0xa4,0xe4,0x04,0xf4,0x44,0x84,0x6c,
+/* 38341 0x95c5 "闅" */
+0x7c,0x44,0x7c,0x44,0x7f,0x48,0x4f,0x48,0x4f,0x42,0x43,0x42,0x5f,0x44,0x43,0x5c,
+0x7c,0x44,0x7c,0x44,0xfc,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x04,0xe4,0x44,0x84,0x6c,
+/* 38342 0x95c6 "闆" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x47,0x44,0x47,0x40,0x4e,0x4a,0x4a,0x4e,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x44,0xc4,0x04,0xe4,0xa4,0xa4,0xe4,0x14,0x08,
+/* 38343 0x95c7 "闇" */
+0x7c,0x44,0x7c,0x44,0x7e,0x41,0x4f,0x44,0x42,0x5f,0x40,0x4f,0x48,0x4f,0x48,0x4f,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x44,0x84,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xec,
+/* 38344 0x95c8 "闈" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x4f,0x44,0x5f,0x48,0x4f,0x41,0x4f,0x51,0x5f,0x41,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xc4,0x44,0xf4,0x24,0xe4,0x04,0xe4,0x04,0xf4,0x08,
+/* 38345 0x95c9 "闉" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x42,0x5f,0x52,0x5f,0x41,0x4f,0x41,0x5f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x84,0xf4,0x94,0xf4,0x04,0xe4,0x04,0xf4,0x0c,
+/* 38346 0x95ca "闊" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x48,0x45,0x40,0x53,0x48,0x41,0x45,0x49,0x50,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x34,0xc4,0x44,0xfc,0x44,0xf4,0x14,0xf4,0x14,0x08,
+/* 38347 0x95cb "闋" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4e,0x42,0x54,0x48,0x57,0x41,0x4f,0x42,0x44,0x58,
+0x7c,0x44,0x7c,0x44,0x7c,0x94,0xa4,0x4c,0x54,0x24,0xd4,0x0c,0xe4,0x84,0x44,0x2c,
+/* 38348 0x95cc "闌" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x5f,0x41,0x5f,0x55,0x53,0x5f,0x45,0x49,0x51,0x41,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xf4,0x54,0x94,0xf4,0x44,0x24,0x14,0x0c,
+/* 38349 0x95cd "闍" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x4f,0x41,0x5f,0x42,0x4f,0x74,0x47,0x44,0x47,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x14,0xe4,0x44,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x0c,
+/* 38350 0x95ce "闎" */
+0x7c,0x44,0x7c,0x44,0x7d,0x42,0x4f,0x48,0x4f,0x48,0x4f,0x41,0x5d,0x45,0x49,0x53,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x24,0x1c,
+/* 38351 0x95cf "闏" */
+0xfc,0x84,0xfc,0x84,0xfc,0x80,0xbf,0xa0,0xaf,0xa2,0xaf,0xaa,0xaf,0xa2,0xdf,0x80,
+0x7e,0x42,0x7e,0x42,0x7e,0x02,0xe2,0x22,0xa2,0x22,0xa2,0xaa,0xaa,0x5a,0xca,0x46,
+/* 38352 0x95d0 "闐" */
+0x7c,0x44,0x7c,0x44,0x7d,0x4f,0x41,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x7f,0x44,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xfc,0x44,0x2c,
+/* 38353 0x95d1 "闑" */
+0x7c,0x44,0x7d,0x46,0x7f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x41,0x5f,0x45,0x49,0x41,
+0x7c,0x44,0x7c,0x44,0xfc,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x44,0x24,0x0c,
+/* 38354 0x95d2 "闒" */
+0x7c,0x44,0x7c,0x44,0x7c,0x47,0x44,0x47,0x44,0x47,0x40,0x4e,0x4a,0x46,0x4a,0x46,
+0x7c,0x44,0x7c,0x44,0x7c,0xc4,0x44,0xc4,0x44,0xc4,0x04,0xe4,0xa4,0x64,0xa4,0x6c,
+/* 38355 0x95d3 "闓" */
+0x7c,0x44,0x7c,0x44,0x7d,0x49,0x4f,0x40,0x5f,0x40,0x4f,0x48,0x4f,0x44,0x5f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x24,0xe4,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x44,0xf4,0x0c,
+/* 38356 0x95d4 "闔" */
+0x7c,0x44,0x7c,0x44,0x7c,0x41,0x4f,0x41,0x5f,0x44,0x4f,0x40,0x4f,0x4a,0x5f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x04,0xf4,0x44,0xe4,0x04,0xe4,0xa4,0xf4,0x0c,
+/* 38357 0x95d5 "闕" */
+0x7c,0x44,0x7c,0x44,0x7c,0x51,0x4a,0x5f,0x44,0x55,0x55,0x5f,0x44,0x48,0x49,0x52,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x74,0x94,0x24,0x44,0x44,0x44,0xa4,0x14,0x08,
+/* 38358 0x95d6 "闖" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x49,0x4f,0x49,0x4f,0x49,0x4f,0x40,0x55,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xf4,0x04,0xe4,0x04,0xe4,0x04,0xf4,0x14,0x54,0x2c,
+/* 38359 0x95d7 "闗" */
+0x7c,0x44,0x7c,0x44,0x7c,0x48,0x48,0x52,0x5c,0x48,0x52,0x5e,0x40,0x4a,0x51,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x94,0xe4,0x44,0x94,0xf4,0x04,0xa4,0x54,0x0c,
+/* 38360 0x95d8 "闘" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5e,0x40,0x5e,0x52,0x5e,0x52,0x4f,0x78,0x50,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x24,0x24,0xf4,0x24,0xa4,0x64,0x24,0x24,0xb4,0x48,
+/* 38361 0x95d9 "闙" */
+0x7c,0x44,0x7c,0x44,0x7c,0x48,0x44,0x5e,0x52,0x5e,0x51,0x5e,0x6a,0x4e,0x40,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x7c,0x94,0x94,0x54,0x24,0x54,0x8c,0x04,0x0c,
+/* 38362 0x95da "闚" */
+0x7c,0x44,0x7c,0x44,0x7c,0x48,0x49,0x5d,0x49,0x49,0x7d,0x49,0x49,0x54,0x51,0x62,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0xc4,0x54,0x3c,
+/* 38363 0x95db "闛" */
+0x7c,0x44,0x7c,0x44,0x7c,0x49,0x45,0x5f,0x50,0x47,0x44,0x47,0x41,0x4f,0x41,0x5f,
+0x7c,0x44,0x7c,0x44,0x7c,0x24,0x44,0xf4,0x14,0xc4,0x44,0xc4,0x04,0xe4,0x04,0xec,
+/* 38364 0x95dc "關" */
+0x7c,0x44,0x7c,0x44,0x7c,0x48,0x52,0x5c,0x4a,0x5e,0x42,0x52,0x5e,0x42,0x44,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0xe4,0x54,0xf4,0x84,0x94,0xf4,0x84,0x94,0x88,
+/* 38365 0x95dd "闝" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5f,0x51,0x5f,0x51,0x5f,0x51,0x5f,0x4a,0x51,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x24,0x24,0x7c,0x94,0x14,0x54,0x24,0x24,0x54,0x94,0x0c,
+/* 38366 0x95de "闞" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5c,0x44,0x7f,0x52,0x5e,0x52,0x5e,0x53,0x7e,0x42,
+0x7c,0x44,0x7c,0x44,0x7c,0x04,0x44,0x7c,0x54,0x94,0x14,0x54,0x24,0xa4,0x54,0x98,
+/* 38367 0x95df "闟" */
+0x7c,0x44,0x7c,0x44,0x7d,0x46,0x58,0x47,0x44,0x47,0x40,0x4e,0x4a,0x46,0x4a,0x46,
+0x7c,0x44,0x7c,0x44,0x7c,0xc4,0x34,0xc4,0x44,0xc4,0x04,0xe4,0xa4,0x64,0xa4,0x6c,
+/* 38368 0x95e0 "闠" */
+0x7c,0x44,0x7c,0x44,0x7d,0x4f,0x49,0x4f,0x41,0x7f,0x48,0x4f,0x48,0x4f,0x44,0x48,
+0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x24,0xe4,0x04,0xfc,0x24,0xe4,0x24,0xe4,0x44,0x2c,
+/* 38369 0x95e1 "闡" */
+0x7c,0x44,0x7c,0x44,0x7e,0x4a,0x4e,0x40,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x5f,0x41,
+0x7c,0x44,0x7c,0x44,0xfc,0xa4,0xe4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x08,
+/* 38370 0x95e2 "闢" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x5e,0x53,0x5e,0x50,0x5e,0x6a,0x4a,0x4e,0x4a,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x84,0x44,0xf4,0xa4,0x44,0xf4,0x44,0xe4,0x44,0x54,0x08,
+/* 38371 0x95e3 "闣" */
+0x7c,0x44,0x7c,0x44,0x7c,0x49,0x45,0x5f,0x50,0x47,0x44,0x4f,0x49,0x4f,0x49,0x4f,
+0x7c,0x44,0x7c,0x44,0x7c,0x24,0x44,0xf4,0x14,0xc4,0x44,0xe4,0x24,0xe4,0x24,0xec,
+/* 38372 0x95e4 "闤" */
+0x7c,0x44,0x7c,0x44,0x7f,0x4a,0x4f,0x40,0x5f,0x40,0x4f,0x48,0x4f,0x45,0x4c,0x56,
+0x7c,0x44,0x7c,0x44,0xfc,0xa4,0xe4,0x04,0xf4,0x04,0xc4,0x44,0xc4,0x24,0xc4,0x2c,
+/* 38373 0x95e5 "闥" */
+0x7c,0x44,0x7c,0x44,0x7c,0x50,0x4b,0x40,0x47,0x59,0x4b,0x48,0x4f,0x48,0x48,0x57,
+0x7c,0x44,0x7c,0x44,0x7c,0x84,0xe4,0x84,0xf4,0x44,0xe4,0x84,0xf4,0x84,0x84,0xec,
+/* 38374 0x95e6 "闦" */
+0x7c,0x44,0x7c,0x44,0x7c,0x42,0x4f,0x4a,0x4f,0x4a,0x5f,0x44,0x47,0x44,0x42,0x4f,
+0x7c,0x44,0x7c,0x44,0x7c,0x84,0xe4,0xa4,0xe4,0xa4,0xf4,0x44,0xc4,0x44,0x84,0xec,
+/* 38375 0x95e7 "闧" */
+0x7c,0x44,0x7c,0x44,0x7c,0x40,0x63,0x50,0x47,0x72,0x53,0x51,0x53,0x55,0x6f,0x40,
+0x7c,0x44,0x7c,0x44,0x7c,0x84,0xe4,0x84,0xf4,0x24,0xe4,0x54,0x24,0x14,0xf4,0x0c,
+/* 38376 0x95e8 "门" */
+0x20,0x13,0x10,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38377 0x95e9 "闩" */
+0x20,0x17,0x00,0x40,0x40,0x40,0x40,0x5f,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38378 0x95ea "闪" */
+0x20,0x17,0x00,0x40,0x41,0x41,0x41,0x41,0x42,0x42,0x44,0x48,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x44,0x24,0x24,0x04,0x04,0x14,0x08,
+/* 38379 0x95eb "闫" */
+0x20,0x17,0x00,0x40,0x5f,0x40,0x40,0x40,0x4f,0x40,0x40,0x40,0x5f,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 38380 0x95ec "闬" */
+0x20,0x17,0x00,0x40,0x4f,0x41,0x41,0x41,0x5f,0x41,0x41,0x41,0x41,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38381 0x95ed "闭" */
+0x20,0x17,0x00,0x40,0x40,0x5f,0x40,0x41,0x42,0x44,0x48,0x50,0x42,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x84,0x84,0xf4,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x14,0x08,
+/* 38382 0x95ee "问" */
+0x20,0x17,0x00,0x40,0x40,0x47,0x44,0x44,0x44,0x44,0x44,0x47,0x44,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xc4,0x44,0x44,0x44,0x44,0x44,0xc4,0x44,0x04,0x14,0x08,
+/* 38383 0x95ef "闯" */
+0x20,0x13,0x10,0x40,0x5f,0x40,0x48,0x48,0x4f,0x40,0x40,0x5f,0x40,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x84,0x84,0x84,0x84,0xe4,0x24,0x24,0xa4,0x24,0x44,0x94,0x08,
+/* 38384 0x95f0 "闰" */
+0x20,0x13,0x10,0x40,0x40,0x5f,0x41,0x41,0x4f,0x41,0x41,0x41,0x5f,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0xe4,0x04,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 38385 0x95f1 "闱" */
+0x20,0x17,0x01,0x41,0x5f,0x41,0x41,0x4f,0x41,0x41,0x5f,0x41,0x41,0x41,0x41,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x04,0x04,0xf4,0x14,0x14,0x54,0x24,0x0c,
+/* 38386 0x95f2 "闲" */
+0x20,0x17,0x00,0x41,0x41,0x41,0x5f,0x41,0x43,0x45,0x49,0x51,0x41,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0xf4,0x04,0x84,0x44,0x24,0x14,0x04,0x04,0x14,0x08,
+/* 38387 0x95f3 "闳" */
+0x20,0x17,0x02,0x42,0x42,0x5f,0x44,0x44,0x48,0x49,0x51,0x52,0x67,0x42,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x84,0x84,0x04,0x44,0x24,0xf4,0x14,0x14,0x08,
+/* 38388 0x95f4 "间" */
+0x20,0x13,0x10,0x40,0x47,0x44,0x44,0x44,0x47,0x44,0x44,0x44,0x47,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xc4,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0xc4,0x04,0x14,0x08,
+/* 38389 0x95f5 "闵" */
+0x20,0x17,0x00,0x42,0x41,0x5f,0x40,0x44,0x42,0x41,0x42,0x44,0x48,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x44,0x44,0x84,0x04,0x84,0x44,0x44,0x04,0x14,0x08,
+/* 38390 0x95f6 "闶" */
+0x20,0x17,0x00,0x42,0x41,0x5f,0x40,0x40,0x47,0x44,0x44,0x44,0x48,0x50,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0xc4,0x44,0x44,0x54,0x34,0x04,0x14,0x08,
+/* 38391 0x95f7 "闷" */
+0x20,0x17,0x00,0x42,0x41,0x41,0x44,0x54,0x54,0x64,0x44,0x43,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x24,0x14,0x54,0x44,0xc4,0x04,0x04,0x14,0x08,
+/* 38392 0x95f8 "闸" */
+0x20,0x17,0x00,0x40,0x4f,0x49,0x49,0x4f,0x49,0x49,0x4f,0x49,0x41,0x41,0x41,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x24,0x04,0x04,0x14,0x08,
+/* 38393 0x95f9 "闹" */
+0x20,0x17,0x00,0x42,0x41,0x5f,0x41,0x41,0x4f,0x49,0x49,0x49,0x49,0x41,0x41,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0xa4,0x44,0x04,0x14,0x08,
+/* 38394 0x95fa "闺" */
+0x20,0x17,0x00,0x41,0x4f,0x41,0x41,0x5f,0x40,0x41,0x4f,0x41,0x41,0x5f,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x04,0x04,0xf4,0x04,0x04,0xe4,0x04,0x04,0xf4,0x04,0x0c,
+/* 38395 0x95fb "闻" */
+0x20,0x17,0x00,0x40,0x5f,0x44,0x47,0x44,0x47,0x44,0x44,0x5f,0x40,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0xc4,0x44,0xc4,0x44,0x74,0xc4,0x44,0x44,0x54,0x08,
+/* 38396 0x95fc "闼" */
+0x20,0x17,0x00,0x48,0x44,0x45,0x40,0x5c,0x44,0x44,0x45,0x4a,0x51,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x44,0x44,0xf4,0x44,0x44,0xa4,0x94,0x14,0x04,0xf4,0x04,0x14,0x08,
+/* 38397 0x95fd "闽" */
+0x20,0x17,0x00,0x41,0x41,0x4f,0x49,0x49,0x49,0x4f,0x49,0x41,0x41,0x5e,0x48,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x24,0xf4,0x14,0x04,0x0c,
+/* 38398 0x95fe "闾" */
+0x20,0x17,0x00,0x40,0x47,0x44,0x44,0x47,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xc4,0x44,0x44,0xc4,0x04,0xe4,0x24,0x24,0xe4,0x04,0x14,0x08,
+/* 38399 0x95ff "闿" */
+0x20,0x17,0x01,0x49,0x49,0x4f,0x40,0x4f,0x40,0x40,0x4f,0x48,0x48,0x47,0x40,0x40,
+0x00,0xfc,0x04,0x24,0x24,0xe4,0x04,0xe4,0x24,0x24,0xe4,0x04,0x14,0xf4,0x04,0x0c,
+/* 38400 0x9600 "阀" */
+0x20,0x17,0x00,0x45,0x45,0x49,0x59,0x6f,0x49,0x49,0x48,0x48,0x49,0x4a,0x48,0x40,
+0x00,0xfc,0x04,0x44,0x24,0x04,0xf4,0x04,0x24,0x24,0xc4,0x94,0x54,0x34,0x14,0x08,
+/* 38401 0x9601 "阁" */
+0x20,0x17,0x02,0x42,0x47,0x4c,0x52,0x41,0x42,0x4c,0x77,0x44,0x44,0x47,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x44,0x84,0x04,0x84,0x64,0xdc,0x44,0x44,0xc4,0x14,0x08,
+/* 38402 0x9602 "阂" */
+0x20,0x17,0x00,0x42,0x41,0x5f,0x42,0x44,0x4f,0x41,0x46,0x58,0x43,0x4c,0x40,0x40,
+0x00,0xfc,0x04,0x04,0x04,0xf4,0x04,0x44,0x84,0x24,0x44,0x84,0x44,0x24,0x04,0x0c,
+/* 38403 0x9603 "阃" */
+0x20,0x17,0x00,0x40,0x5f,0x51,0x51,0x5f,0x51,0x53,0x55,0x59,0x51,0x5f,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x14,0x14,0xf4,0x14,0x94,0x54,0x34,0x14,0xf4,0x04,0x0c,
+/* 38404 0x9604 "阄" */
+0x20,0x17,0x00,0x44,0x47,0x48,0x51,0x6f,0x49,0x4f,0x49,0x4f,0x41,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xc4,0x84,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x14,0x14,0xf4,0x0c,
+/* 38405 0x9605 "阅" */
+0x20,0x17,0x00,0x44,0x42,0x40,0x4f,0x48,0x48,0x4f,0x42,0x42,0x44,0x48,0x50,0x40,
+0x00,0xfc,0x04,0x44,0x84,0x04,0xe4,0x24,0x24,0xe4,0x84,0x84,0x84,0x94,0x74,0x08,
+/* 38406 0x9606 "阆" */
+0x20,0x17,0x02,0x41,0x4f,0x48,0x4f,0x48,0x4f,0x49,0x48,0x4a,0x4c,0x48,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x24,0x14,0x04,0x0c,
+/* 38407 0x9607 "阇" */
+0x20,0x17,0x01,0x41,0x4f,0x41,0x5f,0x42,0x4f,0x74,0x47,0x44,0x47,0x44,0x40,0x40,
+0x00,0xfc,0x04,0x14,0xe4,0x44,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0x14,0x08,
+/* 38408 0x9608 "阈" */
+0x20,0x17,0x00,0x40,0x40,0x5f,0x40,0x4e,0x4a,0x4e,0x40,0x46,0x58,0x41,0x42,0x40,
+0x00,0xfc,0x84,0xa4,0x94,0xf4,0x84,0xa4,0xa4,0xa4,0xc4,0x54,0xb4,0x14,0x04,0x0c,
+/* 38409 0x9609 "阉" */
+0x20,0x17,0x00,0x42,0x5f,0x44,0x49,0x71,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xf4,0x44,0x24,0x1c,0xe4,0x24,0xe4,0x24,0xe4,0x14,0xf4,0x08,
+/* 38410 0x960a "阊" */
+0x20,0x17,0x00,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x5f,0x50,0x5f,0x50,0x5f,0x40,0x40,
+0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x14,0xf4,0x14,0xf4,0x04,0x0c,
+/* 38411 0x960b "阋" */
+0x20,0x17,0x00,0x42,0x4c,0x48,0x4e,0x48,0x4f,0x42,0x42,0x44,0x44,0x48,0x50,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x84,0x84,0x94,0x94,0x74,0x04,0x0c,
+/* 38412 0x960c "阌" */
+0x20,0x17,0x00,0x40,0x5f,0x4a,0x45,0x5f,0x50,0x47,0x40,0x46,0x41,0x42,0x44,0x48,
+0x00,0xfc,0x04,0xe4,0x04,0x24,0x44,0xf4,0x14,0xc4,0x44,0x84,0x04,0x84,0x44,0x2c,
+/* 38413 0x960d "阍" */
+0x20,0x17,0x00,0x40,0x5f,0x51,0x5f,0x50,0x5c,0x50,0x4f,0x48,0x4f,0x48,0x4f,0x48,
+0x00,0xfc,0x04,0x64,0x84,0x04,0xf4,0x84,0x54,0x34,0xe4,0x24,0xe4,0x24,0xe4,0x2c,
+/* 38414 0x960e "阎" */
+0x20,0x17,0x02,0x42,0x47,0x48,0x52,0x4c,0x48,0x48,0x4e,0x48,0x48,0x4f,0x40,0x40,
+0x00,0xfc,0x04,0x04,0xe4,0x24,0x44,0xe4,0x24,0x24,0xe4,0x24,0x24,0xe4,0x14,0x08,
+/* 38415 0x960f "阏" */
+0x20,0x17,0x00,0x48,0x44,0x5e,0x48,0x49,0x4e,0x4a,0x4a,0x4a,0x4a,0x52,0x56,0x60,
+0x00,0xfc,0x04,0x44,0x44,0xa4,0xa4,0x14,0x0c,0x44,0x24,0x04,0x84,0x44,0x24,0x0c,
+/* 38416 0x9610 "阐" */
+0x20,0x17,0x00,0x44,0x42,0x4f,0x49,0x4f,0x49,0x4f,0x41,0x5f,0x41,0x41,0x40,0x40,
+0x00,0xfc,0x04,0x44,0x84,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x04,0x04,0x14,0x08,
+/* 38417 0x9611 "阑" */
+0x20,0x17,0x01,0x41,0x5f,0x41,0x5f,0x51,0x55,0x53,0x5f,0x45,0x49,0x51,0x41,0x41,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0xf4,0x14,0x54,0x94,0xf4,0x44,0x24,0x24,0x04,0x0c,
+/* 38418 0x9612 "阒" */
+0x20,0x17,0x00,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x41,0x5f,0x41,0x42,0x44,0x48,
+0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x44,0xf4,0x04,0x84,0x44,0x2c,
+/* 38419 0x9613 "阓" */
+0x20,0x17,0x01,0x4f,0x49,0x4f,0x41,0x7f,0x40,0x4f,0x48,0x49,0x49,0x42,0x44,0x48,
+0x00,0xfc,0x04,0xe4,0x24,0xe4,0x04,0xfc,0x04,0xe4,0x24,0x24,0x24,0x84,0x44,0x2c,
+/* 38420 0x9614 "阔" */
+0x20,0x17,0x00,0x48,0x45,0x64,0x50,0x51,0x44,0x48,0x79,0x49,0x49,0x49,0x40,0x40,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0x44,0xf4,0x44,0x44,0xf4,0x14,0x14,0xf4,0x04,0x0c,
+/* 38421 0x9615 "阕" */
+0x20,0x17,0x00,0x40,0x5e,0x42,0x4a,0x44,0x48,0x57,0x61,0x4f,0x41,0x42,0x44,0x58,
+0x00,0xfc,0x04,0x84,0x94,0xa4,0x4c,0x54,0x24,0xd4,0x0c,0xe4,0x04,0x84,0x44,0x2c,
+/* 38422 0x9616 "阖" */
+0x20,0x13,0x11,0x4f,0x41,0x5f,0x42,0x44,0x4f,0x40,0x4f,0x4a,0x4a,0x5f,0x40,0x40,
+0x00,0xfc,0x04,0xe4,0x04,0xf4,0x04,0x44,0xe4,0x04,0xe4,0xa4,0xa4,0xf4,0x14,0x08,
+/* 38423 0x9617 "阗" */
+0x20,0x17,0x01,0x5f,0x41,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x4f,0x48,0x7f,0x44,0x48,
+0x00,0xfc,0x04,0xf4,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xe4,0x24,0xfc,0x44,0x2c,
+/* 38424 0x9618 "阘" */
+0x20,0x17,0x00,0x4f,0x48,0x4f,0x48,0x4f,0x40,0x5e,0x42,0x52,0x4a,0x52,0x4a,0x44,
+0x00,0xfc,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x04,0xf4,0x14,0x94,0x54,0x94,0x54,0x2c,
+/* 38425 0x9619 "阙" */
+0x20,0x17,0x00,0x51,0x4a,0x5f,0x44,0x55,0x55,0x5f,0x44,0x48,0x49,0x52,0x40,0x40,
+0x00,0xfc,0x04,0x44,0x44,0x74,0x94,0x24,0x44,0x44,0x44,0xa4,0x14,0x04,0x14,0x08,
+/* 38426 0x961a "阚" */
+0x20,0x17,0x00,0x5c,0x44,0x7f,0x52,0x5e,0x52,0x5e,0x53,0x7e,0x42,0x43,0x40,0x40,
+0x00,0xfc,0x04,0x44,0x7c,0x54,0x94,0x14,0x54,0x24,0xa4,0x54,0x94,0x04,0x14,0x08,
+/* 38427 0x961b "阛" */
+0x20,0x17,0x00,0x5f,0x52,0x5f,0x40,0x7f,0x40,0x4f,0x48,0x4f,0x45,0x4c,0x74,0x46,
+0x00,0xfc,0x04,0xf4,0x94,0xf4,0x04,0xfc,0x04,0xe4,0x24,0xe4,0x14,0xa4,0x44,0x2c,
+/* 38428 0x961c "阜" */
+0x02,0x04,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x20,0x3f,0x01,0x01,0xff,0x01,0x01,0x01,
+0x00,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 38429 0x961d "阝" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 38430 0x961e "阞" */
+0x00,0x7c,0x44,0x48,0x4b,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x40,0x40,0x40,0x40,0xfc,0x44,0x44,0x44,0x44,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 38431 0x961f "队" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x69,0x51,0x42,0x44,0x48,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xa0,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 38432 0x9620 "阠" */
+0x00,0x7d,0x44,0x48,0x48,0x50,0x48,0x49,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x92,0x8a,0x8a,0x86,0x82,
+/* 38433 0x9621 "阡" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x48,0x4b,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 38434 0x9622 "阢" */
+0x00,0x7c,0x47,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 38435 0x9623 "阣" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x48,0x48,0x44,0x44,0x44,0x68,0x51,0x41,0x40,0x40,
+0x40,0x40,0x80,0xfe,0x00,0x00,0xfc,0x08,0x10,0x20,0x40,0x80,0x02,0x02,0xfe,0x00,
+/* 38436 0x9624 "阤" */
+0x00,0x7c,0x44,0x49,0x49,0x51,0x49,0x4b,0x45,0x45,0x45,0x69,0x51,0x41,0x40,0x40,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 38437 0x9625 "阥" */
+0x00,0x78,0x48,0x50,0x50,0x67,0x51,0x49,0x49,0x4a,0x6a,0x54,0x48,0x40,0x41,0x40,
+0x40,0x40,0x40,0x44,0x68,0x70,0x60,0x50,0x50,0x48,0x48,0x44,0x42,0x40,0x40,0x80,
+/* 38438 0x9626 "阦" */
+0x00,0x7c,0x44,0x48,0x49,0x51,0x49,0x4a,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x40,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0xa0,0xa0,0x90,0x10,0x08,0x04,0x02,
+/* 38439 0x9627 "阧" */
+0x00,0x7d,0x44,0x48,0x48,0x51,0x48,0x48,0x44,0x44,0x45,0x68,0x50,0x40,0x40,0x40,
+0x10,0x10,0x90,0x90,0x10,0x10,0x90,0x90,0x10,0x1e,0xf0,0x10,0x10,0x10,0x10,0x10,
+/* 38440 0x9628 "阨" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x42,0x44,
+0x00,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x68,0x50,0x42,0x42,0x42,0x3e,0x00,
+/* 38441 0x9629 "阩" */
+0x00,0x7c,0x47,0x48,0x48,0x50,0x48,0x4b,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x08,0x68,0x88,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 38442 0x962a "阪" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 38443 0x962b "阫" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x48,0x48,0x44,0x45,0x46,0x68,0x50,0x40,0x40,0x40,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x20,0x20,
+/* 38444 0x962c "阬" */
+0x00,0x7c,0x44,0x4b,0x48,0x50,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x80,0x40,0x40,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 38445 0x962d "阭" */
+0x00,0x7c,0x44,0x48,0x49,0x53,0x48,0x48,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x40,0x40,0x80,0x88,0x04,0xfe,0x02,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 38446 0x962e "阮" */
+0x00,0x7d,0x44,0x48,0x48,0x53,0x48,0x48,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x90,0x90,0x90,0x90,0x90,0x92,0x12,0x12,0x0e,0x00,
+/* 38447 0x962f "阯" */
+0x00,0x7c,0x44,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x47,0x40,
+0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 38448 0x9630 "阰" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x40,
+0x10,0x10,0x10,0x12,0x12,0x14,0xd8,0x10,0x10,0x10,0x10,0x12,0x52,0x92,0x0e,0x00,
+/* 38449 0x9631 "阱" */
+0x00,0x7c,0x44,0x48,0x4b,0x50,0x48,0x48,0x44,0x47,0x44,0x68,0x50,0x41,0x41,0x42,
+0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 38450 0x9632 "防" */
+0x00,0x7c,0x44,0x4b,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x51,0x41,0x42,0x44,
+0x40,0x20,0x20,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 38451 0x9633 "阳" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38452 0x9634 "阴" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x52,0x42,0x44,0x48,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x14,0x08,
+/* 38453 0x9635 "阵" */
+0x00,0x7c,0x44,0x4b,0x48,0x50,0x49,0x49,0x44,0x44,0x44,0x6b,0x50,0x40,0x40,0x40,
+0x40,0x40,0x40,0xfe,0x80,0xa0,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 38454 0x9636 "阶" */
+0x00,0x7c,0x44,0x48,0x48,0x51,0x4a,0x48,0x44,0x44,0x44,0x68,0x50,0x41,0x41,0x42,
+0x20,0x20,0x50,0x50,0x88,0x04,0x02,0x88,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 38455 0x9637 "阷" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x47,0x40,
+0x00,0x00,0xfe,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 38456 0x9638 "阸" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x40,0x20,0xfc,0x04,0x04,0xfc,0x00,0x00,0x7c,0x08,0x10,0x20,0x42,0x82,0x7e,0x00,
+/* 38457 0x9639 "阹" */
+0x00,0x7c,0x44,0x49,0x48,0x50,0x48,0x4b,0x44,0x44,0x44,0x68,0x51,0x43,0x41,0x40,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x40,0x40,0x88,0x04,0xfe,0x02,0x00,
+/* 38458 0x963a "阺" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x04,0x1e,0xf0,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x08,0x0a,0x4a,0xa6,0x12,
+/* 38459 0x963b "阻" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x47,0x40,
+0x00,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0xfe,0x00,
+/* 38460 0x963c "阼" */
+0x00,0x7c,0x44,0x48,0x49,0x51,0x4a,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x80,0x80,0x80,0xfe,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x40,
+/* 38461 0x963d "阽" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38462 0x963e "阾" */
+0x00,0x7c,0x44,0x48,0x48,0x51,0x4a,0x48,0x45,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 38463 0x963f "阿" */
+0x00,0x7d,0x44,0x48,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x50,0x40,0x40,0x40,
+0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 38464 0x9640 "陀" */
+0x00,0x7c,0x44,0x49,0x49,0x52,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x40,0x40,
+0x40,0x20,0x20,0xfe,0x02,0x04,0x00,0x08,0x10,0x20,0xc0,0x04,0x04,0x04,0xfc,0x00,
+/* 38465 0x9641 "陁" */
+0x00,0x7c,0x44,0x49,0x4a,0x51,0x49,0x49,0x47,0x45,0x45,0x69,0x51,0x41,0x40,0x40,
+0x80,0x80,0xfe,0x00,0x20,0x20,0x2c,0x74,0xa4,0x24,0x34,0x28,0x22,0x02,0xfe,0x00,
+/* 38466 0x9642 "陂" */
+0x00,0x78,0x48,0x53,0x52,0x62,0x52,0x4b,0x4a,0x4a,0x6a,0x52,0x42,0x44,0x44,0x49,
+0x20,0x20,0x20,0xfe,0x22,0x24,0x20,0xfc,0x84,0x88,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 38467 0x9643 "陃" */
+0x00,0x7d,0x44,0x48,0x48,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 38468 0x9644 "附" */
+0x00,0x7c,0x44,0x49,0x49,0x53,0x4d,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 38469 0x9645 "际" */
+0x00,0x79,0x48,0x50,0x50,0x63,0x50,0x48,0x49,0x49,0x6a,0x52,0x44,0x40,0x40,0x40,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x20,0x20,0x28,0x24,0x24,0x22,0x22,0x20,0xa0,0x40,
+/* 38470 0x9646 "陆" */
+0x00,0x7c,0x44,0x49,0x48,0x50,0x48,0x4b,0x44,0x44,0x45,0x69,0x51,0x41,0x41,0x40,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 38471 0x9647 "陇" */
+0x00,0x7c,0x44,0x48,0x4b,0x50,0x48,0x48,0x44,0x45,0x45,0x69,0x52,0x42,0x44,0x48,
+0x90,0x88,0x88,0x80,0xfe,0xa0,0xa0,0xa4,0xa4,0x28,0x28,0x32,0x22,0x62,0x9e,0x00,
+/* 38472 0x9648 "陈" */
+0x00,0x78,0x48,0x57,0x50,0x61,0x51,0x4a,0x4b,0x48,0x69,0x51,0x42,0x44,0x40,0x40,
+0x40,0x40,0x40,0xfe,0x80,0x20,0x20,0x20,0xfc,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 38473 0x9649 "陉" */
+0x00,0x7d,0x44,0x48,0x48,0x50,0x48,0x4b,0x44,0x45,0x44,0x68,0x50,0x40,0x43,0x40,
+0x00,0xfc,0x08,0x10,0x30,0x48,0x84,0x02,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 38474 0x964a "陊" */
+0x00,0x7c,0x44,0x48,0x49,0x50,0x48,0x48,0x45,0x44,0x44,0x69,0x50,0x40,0x40,0x41,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x60,0x80,
+/* 38475 0x964b "陋" */
+0x00,0x7b,0x48,0x50,0x52,0x62,0x52,0x4a,0x4a,0x4a,0x6a,0x52,0x42,0x42,0x43,0x40,
+0x00,0xfe,0x20,0x20,0xfc,0xa4,0xa4,0xa4,0xd4,0x84,0x84,0x94,0x88,0x00,0xfe,0x00,
+/* 38476 0x964c "陌" */
+0x00,0x7d,0x44,0x48,0x48,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38477 0x964d "降" */
+0x00,0x7c,0x44,0x49,0x4a,0x50,0x49,0x4e,0x44,0x45,0x44,0x6a,0x53,0x40,0x40,0x40,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 38478 0x964e "陎" */
+0x00,0x7d,0x45,0x49,0x49,0x52,0x48,0x4b,0x44,0x44,0x44,0x69,0x51,0x42,0x40,0x40,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 38479 0x964f "陏" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x48,0x49,0x46,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 38480 0x9650 "限" */
+0x00,0x7b,0x4a,0x52,0x53,0x62,0x52,0x4b,0x4a,0x4a,0x6a,0x52,0x42,0x42,0x43,0x42,
+0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x20,0x10,0x88,0x06,0x00,
+/* 38481 0x9651 "陑" */
+0x00,0x7d,0x44,0x48,0x48,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x00,0xfe,0x20,0x20,0x40,0xfe,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0x42,0x0a,0x04,
+/* 38482 0x9652 "陒" */
+0x00,0x7c,0x44,0x49,0x4a,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 38483 0x9653 "陓" */
+0x00,0x78,0x4b,0x48,0x50,0x51,0x62,0x50,0x4b,0x48,0x48,0x69,0x50,0x40,0x40,0x40,
+0x20,0x20,0xfe,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 38484 0x9654 "陔" */
+0x00,0x78,0x48,0x57,0x50,0x60,0x51,0x4b,0x48,0x48,0x69,0x56,0x40,0x40,0x41,0x46,
+0x40,0x20,0x20,0xfe,0x40,0x84,0x08,0xf0,0x22,0x44,0x88,0x10,0x20,0x50,0x88,0x04,
+/* 38485 0x9655 "陕" */
+0x00,0x78,0x48,0x57,0x50,0x62,0x51,0x48,0x4f,0x48,0x68,0x51,0x41,0x42,0x44,0x48,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x50,0x40,0xfe,0xa0,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 38486 0x9656 "陖" */
+0x00,0x7c,0x44,0x49,0x4b,0x50,0x48,0x49,0x46,0x44,0x45,0x6a,0x50,0x40,0x41,0x46,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 38487 0x9657 "陗" */
+0x00,0x7d,0x44,0x48,0x48,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 38488 0x9658 "陘" */
+0x00,0x7b,0x48,0x51,0x52,0x64,0x52,0x49,0x48,0x4b,0x68,0x50,0x40,0x40,0x47,0x40,
+0x00,0xfc,0x00,0x24,0x48,0x90,0x48,0x24,0x00,0xfc,0x40,0x40,0x40,0x40,0xfe,0x00,
+/* 38489 0x9659 "陙" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x42,0x42,0x44,
+0x00,0xfe,0x00,0x00,0x7c,0x00,0x00,0xfe,0x50,0x52,0x54,0x48,0x48,0x44,0x52,0x60,
+/* 38490 0x965a "陚" */
+0x00,0x78,0x4b,0x50,0x50,0x67,0x50,0x48,0x48,0x4a,0x6a,0x52,0x42,0x42,0x47,0x42,
+0x10,0x18,0xd4,0x14,0x10,0xfe,0x10,0x90,0x90,0xd0,0x90,0x90,0x8a,0xea,0x06,0x02,
+/* 38491 0x965b "陛" */
+0x02,0x7a,0x4a,0x53,0x52,0x62,0x52,0x4b,0x48,0x48,0x6b,0x50,0x40,0x40,0x47,0x40,
+0x20,0x24,0x28,0xb0,0x20,0x22,0xa2,0x1e,0x40,0x40,0xfc,0x40,0x40,0x40,0xfe,0x00,
+/* 38492 0x965c "陜" */
+0x00,0x7c,0x44,0x4b,0x48,0x50,0x49,0x49,0x45,0x46,0x44,0x68,0x50,0x40,0x41,0x42,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 38493 0x965d "陝" */
+0x00,0x78,0x48,0x57,0x50,0x64,0x52,0x4a,0x4d,0x48,0x68,0x51,0x41,0x42,0x44,0x48,
+0x40,0x40,0x40,0xfe,0x40,0x50,0x48,0x48,0x54,0xa2,0xa0,0x10,0x10,0x08,0x04,0x02,
+/* 38494 0x965e "陞" */
+0x00,0x7d,0x44,0x48,0x4b,0x50,0x48,0x49,0x46,0x44,0x45,0x68,0x50,0x40,0x43,0x40,
+0x28,0xc8,0x88,0x88,0xfe,0x88,0x88,0x08,0x28,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38495 0x965f "陟" */
+0x00,0x78,0x49,0x51,0x51,0x61,0x57,0x48,0x48,0x49,0x69,0x52,0x44,0x40,0x40,0x47,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x24,0x24,0x28,0x10,0x20,0xc0,0x00,
+/* 38496 0x9660 "陠" */
+0x00,0x7c,0x45,0x48,0x48,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 38497 0x9661 "陡" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x4b,0x48,0x44,0x45,0x45,0x69,0x52,0x42,0x44,0x48,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x3c,0x20,0xa0,0x60,0x3e,0x00,
+/* 38498 0x9662 "院" */
+0x00,0x78,0x4b,0x52,0x54,0x61,0x50,0x48,0x4b,0x48,0x68,0x50,0x41,0x41,0x42,0x44,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x90,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 38499 0x9663 "陣" */
+0x00,0x7c,0x45,0x48,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x68,0x53,0x40,0x40,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 38500 0x9664 "除" */
+0x00,0x78,0x48,0x50,0x51,0x62,0x55,0x48,0x48,0x4b,0x68,0x51,0x42,0x44,0x41,0x40,
+0x00,0x40,0x40,0xa0,0x10,0x08,0xf6,0x40,0x40,0xfc,0x40,0x50,0x48,0x44,0x44,0x80,
+/* 38501 0x9665 "陥" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x40,0x40,0x7c,0x84,0x08,0x10,0x3e,0x22,0x22,0x22,0x3e,0x22,0x22,0x22,0x3e,0x22,
+/* 38502 0x9666 "陦" */
+0x00,0x7c,0x47,0x48,0x49,0x50,0x4b,0x48,0x44,0x44,0x45,0x69,0x52,0x44,0x40,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x48,0x88,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 38503 0x9667 "陧" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x44,0x44,0x45,0x68,0x50,0x40,0x43,0x40,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38504 0x9668 "陨" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x49,0x49,0x45,0x45,0x45,0x69,0x50,0x40,0x40,0x43,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x48,0x84,0x04,
+/* 38505 0x9669 "险" */
+0x00,0x78,0x48,0x50,0x51,0x62,0x55,0x48,0x48,0x48,0x6a,0x51,0x41,0x40,0x47,0x40,
+0x40,0x40,0xa0,0xa0,0x10,0x08,0xf6,0x00,0x88,0x48,0x48,0x50,0x10,0x20,0xfe,0x00,
+/* 38506 0x966a "陪" */
+0x00,0x7c,0x45,0x48,0x49,0x50,0x48,0x4b,0x44,0x44,0x45,0x69,0x51,0x41,0x41,0x41,
+0x40,0x20,0xfc,0x00,0x08,0x90,0x00,0xfe,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 38507 0x966b "陫" */
+0x00,0x7c,0x44,0x4b,0x48,0x50,0x48,0x4b,0x44,0x44,0x44,0x6b,0x50,0x40,0x40,0x40,
+0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x9c,0x90,0x90,0x90,0x9e,0x90,0x90,0x90,0x90,
+/* 38508 0x966c "陬" */
+0x00,0x7f,0x4a,0x52,0x52,0x63,0x52,0x4a,0x4b,0x4a,0x6a,0x52,0x47,0x40,0x40,0x40,
+0x00,0xe0,0x5e,0x52,0x52,0xd2,0x52,0x54,0xd4,0x54,0x48,0xe8,0x54,0x54,0x62,0x40,
+/* 38509 0x966d "陭" */
+0x00,0x7c,0x45,0x48,0x48,0x51,0x4b,0x48,0x45,0x45,0x45,0x69,0x51,0x40,0x40,0x40,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 38510 0x966e "陮" */
+0x00,0x7c,0x44,0x49,0x49,0x53,0x4d,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 38511 0x966f "陯" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x48,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x04,0x0c,
+/* 38512 0x9670 "陰" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x49,0x48,0x44,0x45,0x44,0x6b,0x50,0x40,0x41,0x40,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0xfc,0x00,0xfe,0x40,0x88,0xfc,0x84,
+/* 38513 0x9671 "陱" */
+0x00,0x7c,0x44,0x49,0x4a,0x52,0x49,0x48,0x47,0x44,0x44,0x69,0x52,0x40,0x40,0x40,
+0x80,0x80,0xfe,0x02,0x42,0x4a,0x52,0x42,0xfe,0x42,0xe2,0x52,0x4a,0x42,0x54,0x08,
+/* 38514 0x9672 "陲" */
+0x00,0x78,0x49,0x50,0x50,0x63,0x51,0x49,0x4f,0x49,0x69,0x53,0x40,0x40,0x43,0x40,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x24,0x24,0xfe,0x24,0x24,0xfe,0x20,0x20,0xfe,0x00,
+/* 38515 0x9673 "陳" */
+0x00,0x78,0x4f,0x50,0x53,0x62,0x53,0x4a,0x4b,0x48,0x68,0x51,0x42,0x4c,0x40,0x40,
+0x40,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xe0,0x50,0x48,0x46,0x40,0x40,
+/* 38516 0x9674 "陴" */
+0x00,0x78,0x4b,0x52,0x52,0x63,0x52,0x4a,0x4b,0x48,0x69,0x57,0x40,0x40,0x40,0x40,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 38517 0x9675 "陵" */
+0x00,0x78,0x49,0x50,0x50,0x63,0x50,0x49,0x4a,0x48,0x69,0x52,0x40,0x40,0x41,0x46,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 38518 0x9676 "陶" */
+0x01,0x79,0x49,0x52,0x55,0x61,0x52,0x48,0x4f,0x48,0x6a,0x52,0x43,0x40,0x40,0x40,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x84,0x84,0xf4,0x84,0xa4,0xa4,0xe4,0x04,0x28,0x10,
+/* 38519 0x9677 "陷" */
+0x00,0x78,0x48,0x51,0x52,0x64,0x50,0x4b,0x4a,0x4a,0x6b,0x52,0x42,0x42,0x43,0x42,
+0x80,0x80,0xf8,0x08,0x10,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 38520 0x9678 "陸" */
+0x00,0x7c,0x45,0x48,0x48,0x53,0x48,0x49,0x46,0x44,0x45,0x68,0x50,0x40,0x43,0x40,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x88,0x04,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38521 0x9679 "陹" */
+0x00,0x7d,0x44,0x48,0x4b,0x50,0x48,0x49,0x46,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x28,0xc8,0x88,0x88,0xfe,0x88,0x88,0x08,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,
+/* 38522 0x967a "険" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x48,0x48,0x45,0x45,0x45,0x69,0x50,0x40,0x41,0x42,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfc,0x24,0x24,0xfc,0x50,0x88,0x04,0x02,
+/* 38523 0x967b "陻" */
+0x00,0x7b,0x48,0x50,0x53,0x62,0x52,0x4a,0x4b,0x48,0x68,0x53,0x40,0x40,0x47,0x40,
+0x00,0xfe,0x50,0x50,0xfe,0x52,0x52,0x52,0xfe,0x20,0x20,0xfe,0x20,0x20,0xfe,0x00,
+/* 38524 0x967c "陼" */
+0x00,0x7c,0x45,0x48,0x48,0x53,0x48,0x48,0x44,0x45,0x46,0x68,0x50,0x40,0x40,0x40,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 38525 0x967d "陽" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x49,0x44,0x44,0x45,0x6a,0x50,0x41,0x40,0x40,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 38526 0x967e "陾" */
+0x00,0x7b,0x48,0x50,0x51,0x61,0x51,0x49,0x49,0x49,0x68,0x53,0x40,0x40,0x41,0x42,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 38527 0x967f "陿" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x40,
+0x00,0xfe,0x10,0x10,0xfc,0x10,0x54,0x54,0xba,0x10,0x28,0x24,0x42,0x80,0xfe,0x00,
+/* 38528 0x9680 "隀" */
+0x00,0x7c,0x45,0x48,0x4b,0x50,0x49,0x49,0x45,0x45,0x45,0x68,0x51,0x40,0x43,0x40,
+0x08,0x3c,0xe0,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 38529 0x9681 "隁" */
+0x00,0x7b,0x4a,0x52,0x52,0x62,0x52,0x4a,0x4a,0x4b,0x6a,0x52,0x42,0x42,0x42,0x43,
+0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x20,0xfe,0x48,0xc8,0x30,0x48,0x84,0xfe,
+/* 38530 0x9682 "隂" */
+0x00,0x7c,0x44,0x49,0x4a,0x50,0x48,0x48,0x44,0x44,0x47,0x68,0x50,0x41,0x43,0x40,
+0x20,0x50,0x88,0x04,0xfe,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x88,0x04,0xfe,0x02,
+/* 38531 0x9683 "隃" */
+0x00,0x78,0x49,0x52,0x55,0x60,0x53,0x4a,0x4a,0x4b,0x6a,0x52,0x43,0x42,0x42,0x42,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 38532 0x9684 "隄" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x44,0x47,0x44,0x69,0x51,0x41,0x42,0x44,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x20,0x20,0x3c,0x20,0xa0,0x7e,
+/* 38533 0x9685 "隅" */
+0x01,0x79,0x49,0x49,0x51,0x51,0x61,0x50,0x48,0x4b,0x4a,0x6a,0x52,0x42,0x42,0x42,
+0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 38534 0x9686 "隆" */
+0x00,0x79,0x4a,0x55,0x50,0x63,0x5c,0x4b,0x48,0x4a,0x6b,0x54,0x43,0x40,0x4f,0x40,
+0x80,0xf8,0x08,0x10,0xe0,0x18,0x06,0xf8,0x40,0x40,0xfc,0x40,0xf8,0x40,0xfe,0x00,
+/* 38535 0x9687 "隇" */
+0x00,0x78,0x48,0x4b,0x52,0x53,0x62,0x52,0x4b,0x4a,0x4a,0x6a,0x52,0x43,0x42,0x44,
+0x0c,0x0a,0x08,0xfe,0x08,0xf8,0x4a,0x4a,0xea,0xac,0xac,0x4c,0xaa,0x0a,0x16,0x22,
+/* 38536 0x9688 "隈" */
+0x00,0x7b,0x4a,0x4a,0x53,0x52,0x62,0x53,0x48,0x4f,0x4a,0x6a,0x52,0x42,0x43,0x42,
+0x00,0xf8,0x48,0x48,0xf8,0x48,0x48,0xf8,0x00,0xfe,0x40,0x44,0x28,0x90,0x08,0x06,
+/* 38537 0x9689 "隉" */
+0x00,0x7d,0x45,0x49,0x49,0x51,0x49,0x49,0x44,0x44,0x45,0x68,0x50,0x40,0x43,0x40,
+0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x00,0x00,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38538 0x968a "隊" */
+0x01,0x78,0x48,0x53,0x50,0x60,0x51,0x4a,0x48,0x49,0x6a,0x50,0x41,0x46,0x40,0x40,
+0x04,0x88,0x00,0xfe,0x40,0xc2,0x22,0x54,0x98,0x38,0x54,0x94,0x12,0x10,0x50,0x20,
+/* 38539 0x968b "隋" */
+0x00,0x78,0x4b,0x50,0x51,0x62,0x55,0x48,0x49,0x49,0x69,0x51,0x41,0x41,0x41,0x41,
+0x40,0x40,0xfe,0x80,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 38540 0x968c "隌" */
+0x00,0x7c,0x45,0x48,0x48,0x50,0x4b,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+0x40,0x20,0xfe,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 38541 0x968d "隍" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x48,0x47,0x44,0x44,0x69,0x50,0x40,0x43,0x40,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38542 0x968e "階" */
+0x01,0x7d,0x45,0x49,0x49,0x51,0x49,0x48,0x45,0x45,0x45,0x69,0x51,0x41,0x41,0x41,
+0x10,0x12,0xd4,0x18,0x52,0x92,0x2e,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 38543 0x968f "随" */
+0x00,0x78,0x49,0x54,0x52,0x60,0x51,0x48,0x4e,0x4a,0x6a,0x52,0x42,0x42,0x45,0x48,
+0x10,0x10,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,0x7c,0x44,0x54,0x48,0x00,0xfe,
+/* 38544 0x9690 "隐" */
+0x00,0x78,0x49,0x4a,0x54,0x53,0x60,0x51,0x48,0x4b,0x48,0x68,0x51,0x45,0x45,0x48,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x40,0x24,0x2a,0x0a,0xf8,
+/* 38545 0x9691 "隑" */
+0x00,0x7d,0x45,0x49,0x49,0x50,0x4b,0x48,0x45,0x45,0x45,0x69,0x50,0x40,0x43,0x40,
+0x20,0x24,0x24,0x24,0xfc,0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 38546 0x9692 "隒" */
+0x00,0x7c,0x44,0x49,0x48,0x51,0x48,0x4b,0x44,0x45,0x44,0x68,0x51,0x42,0x40,0x40,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 38547 0x9693 "隓" */
+0x00,0x7c,0x45,0x48,0x48,0x51,0x4a,0x48,0x44,0x45,0x44,0x68,0x51,0x42,0x41,0x40,
+0x20,0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0x20,0xfe,0x40,0xfc,0x10,0x10,0xfe,0x00,
+/* 38548 0x9694 "隔" */
+0x00,0x7b,0x48,0x51,0x51,0x61,0x51,0x48,0x4b,0x4a,0x6a,0x53,0x42,0x42,0x42,0x42,
+0x00,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x8a,0x52,0xfe,0x22,0x22,0x2a,0x04,
+/* 38549 0x9695 "隕" */
+0x00,0x7c,0x44,0x48,0x48,0x50,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x40,0x40,0x41,
+0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0xfe,0x02,0xfe,0x02,0xfe,0x48,0x84,0x02,
+/* 38550 0x9696 "隖" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x44,0x6a,0x52,0x44,0x40,0x40,
+0x40,0x80,0xfc,0x04,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 38551 0x9697 "隗" */
+0x00,0x78,0x4b,0x4a,0x52,0x53,0x62,0x52,0x4b,0x48,0x48,0x68,0x51,0x41,0x42,0x44,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xa8,0xb4,0x3c,0x22,0x22,0x1e,
+/* 38552 0x9698 "隘" */
+0x02,0x79,0x49,0x48,0x57,0x50,0x61,0x52,0x4c,0x4b,0x4a,0x6a,0x52,0x42,0x4f,0x40,
+0x08,0x08,0x10,0x00,0xfc,0x00,0x10,0x08,0x04,0xf8,0xa8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 38553 0x9699 "隙" */
+0x00,0x7c,0x45,0x4a,0x48,0x51,0x49,0x49,0x45,0x45,0x44,0x68,0x51,0x42,0x40,0x40,
+0x20,0xa8,0x24,0x22,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 38554 0x969a "隚" */
+0x00,0x7d,0x44,0x4b,0x4a,0x50,0x48,0x48,0x44,0x44,0x44,0x69,0x50,0x40,0x43,0x40,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38555 0x969b "際" */
+0x01,0x79,0x4b,0x52,0x55,0x62,0x51,0x4a,0x4c,0x48,0x6b,0x50,0x41,0x42,0x45,0x40,
+0x00,0x10,0xdc,0x54,0x54,0x88,0x08,0xf4,0x02,0x00,0xfc,0x40,0x50,0x48,0x44,0x80,
+/* 38556 0x969c "障" */
+0x00,0x7d,0x44,0x48,0x4b,0x50,0x49,0x49,0x45,0x45,0x45,0x68,0x53,0x40,0x40,0x40,
+0x20,0xfc,0x88,0x50,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 38557 0x969d "隝" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x49,0x49,0x45,0x45,0x45,0x68,0x52,0x42,0x42,0x40,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 38558 0x969e "隞" */
+0x01,0x79,0x49,0x57,0x51,0x67,0x51,0x4f,0x4a,0x4b,0x6a,0x52,0x42,0x44,0x44,0x48,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 38559 0x969f "隟" */
+0x01,0x7a,0x49,0x50,0x51,0x61,0x51,0x49,0x49,0x48,0x6b,0x50,0x40,0x41,0x46,0x40,
+0x24,0x48,0x24,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 38560 0x96a0 "隠" */
+0x00,0x7c,0x45,0x48,0x49,0x50,0x49,0x48,0x44,0x44,0x45,0x68,0x50,0x42,0x42,0x44,
+0x08,0x3c,0xc0,0x44,0x24,0xa8,0xfc,0x04,0xfc,0x04,0xfc,0x40,0xa4,0xaa,0x8a,0x78,
+/* 38561 0x96a1 "隡" */
+0x00,0x78,0x4b,0x50,0x51,0x60,0x53,0x4a,0x4a,0x4a,0x6b,0x52,0x42,0x44,0x44,0x49,
+0x40,0x20,0xfc,0x00,0x08,0x90,0xfe,0x20,0xa0,0xfc,0x20,0x20,0xfc,0x20,0x20,0xfe,
+/* 38562 0x96a2 "隢" */
+0x00,0x7c,0x45,0x48,0x4b,0x51,0x4b,0x49,0x45,0x46,0x44,0x6b,0x50,0x40,0x41,0x42,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 38563 0x96a3 "隣" */
+0x00,0x79,0x48,0x53,0x50,0x61,0x52,0x49,0x49,0x49,0x6a,0x55,0x40,0x41,0x42,0x44,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 38564 0x96a4 "隤" */
+0x00,0x7d,0x45,0x49,0x48,0x53,0x48,0x49,0x45,0x45,0x45,0x69,0x51,0x41,0x40,0x41,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 38565 0x96a5 "隥" */
+0x00,0x7b,0x48,0x51,0x50,0x61,0x52,0x4c,0x49,0x49,0x69,0x51,0x41,0x40,0x47,0x40,
+0x10,0xd2,0x54,0x48,0x8a,0x04,0xfa,0x00,0xfc,0x04,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 38566 0x96a6 "隦" */
+0x00,0x7b,0x4a,0x52,0x52,0x63,0x52,0x4a,0x4b,0x4a,0x6e,0x52,0x42,0x43,0x42,0x40,
+0x10,0xc8,0x7e,0x40,0x62,0xd4,0x00,0x3e,0xc8,0x48,0x7e,0x48,0x48,0xc8,0x48,0x08,
+/* 38567 0x96a7 "隧" */
+0x00,0x7c,0x4a,0x50,0x50,0x60,0x56,0x4a,0x4a,0x4a,0x6a,0x52,0x42,0x42,0x45,0x48,
+0x88,0x48,0x50,0xfc,0x20,0x50,0x94,0x38,0x50,0x98,0x34,0x54,0x90,0x20,0xfe,0x00,
+/* 38568 0x96a8 "隨" */
+0x00,0x79,0x4c,0x4a,0x51,0x52,0x60,0x56,0x4a,0x4a,0x4a,0x6a,0x52,0x42,0x45,0x48,
+0x20,0xfe,0x40,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x8c,0x00,0xfe,
+/* 38569 0x96a9 "隩" */
+0x00,0x78,0x4b,0x52,0x52,0x62,0x53,0x4a,0x4a,0x4a,0x68,0x53,0x40,0x40,0x41,0x46,
+0x40,0x80,0xfe,0x22,0xaa,0x22,0xfe,0x72,0xaa,0x02,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 38570 0x96aa "險" */
+0x00,0x7c,0x44,0x48,0x49,0x52,0x48,0x48,0x45,0x45,0x45,0x69,0x50,0x40,0x41,0x42,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 38571 0x96ab "隫" */
+0x00,0x7d,0x44,0x48,0x4b,0x50,0x49,0x49,0x45,0x45,0x45,0x69,0x51,0x40,0x41,0x42,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 38572 0x96ac "隬" */
+0x00,0x7b,0x49,0x4a,0x57,0x52,0x63,0x52,0x4b,0x4a,0x4b,0x6a,0x53,0x42,0x42,0x42,
+0x00,0xfe,0x24,0x22,0xfe,0x22,0x76,0xaa,0x76,0x22,0x76,0xaa,0x76,0x22,0x2a,0x04,
+/* 38573 0x96ad "隭" */
+0x00,0x79,0x48,0x4b,0x52,0x51,0x60,0x51,0x48,0x4b,0x48,0x69,0x51,0x41,0x41,0x41,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 38574 0x96ae "隮" */
+0x00,0x78,0x4b,0x48,0x50,0x57,0x62,0x52,0x4d,0x48,0x49,0x69,0x51,0x41,0x41,0x42,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 38575 0x96af "隯" */
+0x00,0x7b,0x48,0x49,0x50,0x53,0x60,0x51,0x48,0x4b,0x48,0x6b,0x50,0x43,0x42,0x43,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x20,0xfe,0x00,0xfe,0x04,0xbe,0xa4,0x8c,
+/* 38576 0x96b0 "隰" */
+0x00,0x7b,0x4a,0x4b,0x52,0x53,0x61,0x52,0x4b,0x49,0x4a,0x6b,0x50,0x42,0x42,0x44,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x08,0x52,0x9c,0x08,0x52,0xde,0x00,0xa4,0x52,0x52,
+/* 38577 0x96b1 "隱" */
+0x00,0x7f,0x4a,0x49,0x53,0x50,0x67,0x50,0x4b,0x48,0x4b,0x68,0x53,0x45,0x45,0x48,
+0x3e,0xc0,0x44,0x28,0xf8,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x2a,0xfa,
+/* 38578 0x96b2 "隲" */
+0x00,0x7c,0x45,0x4a,0x48,0x50,0x4b,0x49,0x45,0x45,0x45,0x69,0x51,0x40,0x42,0x40,
+0x20,0xa8,0x24,0x2a,0x30,0xc0,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xaa,0x04,
+/* 38579 0x96b3 "隳" */
+0x00,0x7b,0x48,0x51,0x4a,0x4d,0x68,0x50,0x41,0x46,0x19,0xe1,0x11,0x21,0x45,0x02,
+0x40,0xfc,0x80,0xf8,0x20,0xfc,0x88,0xf8,0x88,0xc0,0x30,0x0e,0x90,0x48,0x24,0x00,
+/* 38580 0x96b4 "隴" */
+0x01,0x78,0x4b,0x48,0x52,0x51,0x63,0x50,0x4b,0x4a,0x4b,0x6a,0x53,0x42,0x42,0x42,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 38581 0x96b5 "隵" */
+0x01,0xf1,0x91,0xa7,0xa5,0xc5,0xa7,0x94,0x94,0x97,0xd4,0xa7,0x8a,0x8b,0x91,0x87,
+0x08,0xec,0x0a,0xe8,0x28,0xde,0x28,0xea,0x0a,0xea,0x0c,0xec,0x2a,0xea,0x56,0xe2,
+/* 38582 0x96b6 "隶" */
+0x01,0x01,0x3f,0x01,0x01,0xff,0x01,0x01,0x3f,0x21,0x11,0x05,0x09,0x31,0xc5,0x02,
+0x00,0x00,0xf8,0x08,0x08,0xfe,0x08,0x08,0xf8,0x08,0x90,0x60,0x20,0x18,0x06,0x00,
+/* 38583 0x96b7 "隷" */
+0x10,0x10,0xfc,0x10,0x11,0x7c,0x00,0x7c,0x01,0xfc,0x10,0x54,0x53,0x92,0x10,0x30,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,
+/* 38584 0x96b8 "隸" */
+0x10,0x10,0xfe,0x38,0x55,0x92,0x10,0x7c,0x01,0xfe,0x10,0x54,0x53,0x92,0x50,0x20,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,
+/* 38585 0x96b9 "隹" */
+0x09,0x08,0x08,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,
+0x00,0x80,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0x80,0xfc,0x00,0x00,
+/* 38586 0x96ba "隺" */
+0x02,0x02,0x7f,0x45,0x08,0x1f,0x30,0x50,0x9f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xfc,0x04,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,
+/* 38587 0x96bb "隻" */
+0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3f,0x08,0x04,0x03,0x1c,0xe0,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 38588 0x96bc "隼" */
+0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x11,0x01,0xff,0x01,0x01,0x01,0x01,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 38589 0x96bd "隽" */
+0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3f,0x04,0x04,0x08,0x30,0xc0,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xe0,0x20,0x7c,0x04,0x14,0x08,
+/* 38590 0x96be "难" */
+0x00,0x00,0xfc,0x05,0x05,0x4b,0x2d,0x29,0x11,0x11,0x29,0x25,0x45,0x81,0x01,0x01,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 38591 0x96bf "隿" */
+0x28,0x24,0x24,0x20,0x3d,0xe2,0x20,0x20,0x20,0x20,0x20,0x20,0x14,0x14,0x0c,0x04,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38592 0x96c0 "雀" */
+0x01,0x11,0x11,0x21,0x40,0x03,0x0c,0x30,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0x10,0x08,0x24,0xc0,0x00,0x80,0x40,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 38593 0x96c1 "雁" */
+0x00,0x3f,0x20,0x22,0x22,0x24,0x24,0x2d,0x36,0x24,0x24,0x24,0x24,0x44,0x44,0x84,
+0x00,0xfe,0x00,0x50,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 38594 0x96c2 "雂" */
+0x08,0x08,0x14,0x14,0x23,0x52,0x88,0x08,0x00,0x7e,0x02,0x04,0x04,0x08,0x08,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38595 0x96c3 "雃" */
+0x00,0x7e,0x24,0x24,0x25,0x26,0x24,0xff,0x24,0x24,0x24,0x24,0x24,0x24,0x44,0x84,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38596 0x96c4 "雄" */
+0x08,0x08,0x08,0x7e,0x11,0x12,0x20,0x28,0x48,0x48,0x90,0x14,0x22,0x7e,0x22,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38597 0x96c5 "雅" */
+0x00,0x7e,0x04,0x24,0x25,0x26,0x44,0x7f,0x0c,0x14,0x14,0x24,0x44,0x84,0x14,0x08,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38598 0x96c6 "集" */
+0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x11,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 38599 0x96c7 "雇" */
+0x01,0x00,0x3f,0x20,0x3f,0x22,0x22,0x27,0x2c,0x37,0x24,0x27,0x44,0x44,0x87,0x04,
+0x00,0x80,0xfc,0x04,0xfc,0x80,0x40,0xfc,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x00,
+/* 38600 0x96c8 "雈" */
+0x04,0xfc,0x04,0x01,0x08,0x1f,0x10,0x30,0x5f,0x90,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x40,0x7e,0x40,0x00,0x80,0xfc,0x80,0x80,0xf8,0x80,0x80,0xf8,0x80,0x80,0xfc,0x00,
+/* 38601 0x96c9 "雉" */
+0x20,0x20,0x20,0x7d,0x51,0x93,0x15,0xfd,0x11,0x11,0x11,0x29,0x25,0x45,0x41,0x81,
+0xa0,0x90,0x80,0xfe,0x10,0x10,0xfc,0x10,0x10,0xfc,0x10,0x10,0x10,0xfe,0x00,0x00,
+/* 38602 0x96ca "雊" */
+0x20,0x20,0x20,0x7e,0x43,0x82,0x7a,0x4a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x14,0x08,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38603 0x96cb "雋" */
+0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,0x3e,0x22,0x22,0x23,0x20,0x20,
+0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,0x7c,0x44,0x44,0xc4,0x14,0x08,
+/* 38604 0x96cc "雌" */
+0x14,0x14,0x14,0x54,0x55,0x5e,0x54,0x54,0x54,0x54,0x54,0x54,0x5d,0x76,0xc4,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38605 0x96cd "雍" */
+0x02,0x01,0xff,0x10,0x10,0x24,0x45,0x7a,0x10,0x24,0x44,0x78,0x08,0x10,0x20,0xc0,
+0x00,0x00,0xfe,0x50,0x48,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0xfe,0x80,
+/* 38606 0x96ce "雎" */
+0x00,0x7c,0x44,0x44,0x45,0x7e,0x44,0x44,0x7c,0x44,0x44,0x44,0x4e,0xf0,0x00,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38607 0x96cf "雏" */
+0x20,0x20,0x3e,0x42,0x85,0x0a,0xfe,0x02,0x02,0x7e,0x02,0x02,0x02,0xfe,0x02,0x00,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38608 0x96d0 "雐" */
+0x01,0x01,0x01,0x3f,0x21,0x21,0x2f,0x22,0x22,0x27,0x2c,0x37,0x24,0x47,0x44,0x87,
+0x00,0xf8,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x40,0xfe,0x40,0xfc,0x40,0xfc,0x40,0xfe,
+/* 38609 0x96d1 "雑" */
+0x20,0x20,0xf8,0x28,0x29,0x2a,0x46,0x90,0x10,0xfe,0x10,0x34,0x52,0x92,0x50,0x20,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38610 0x96d2 "雒" */
+0x20,0x20,0x3c,0x44,0xc5,0x2a,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x7c,0x44,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38611 0x96d3 "雓" */
+0x10,0x10,0x28,0x44,0x83,0x7e,0x10,0x10,0xfe,0x10,0x54,0x52,0x92,0x10,0x50,0x20,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38612 0x96d4 "雔" */
+0x14,0x12,0x20,0x3f,0x64,0xa5,0x3f,0x24,0x24,0x3f,0x24,0x24,0x24,0x3f,0x20,0x20,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38613 0x96d5 "雕" */
+0x00,0x7f,0x49,0x49,0x5d,0x49,0x7f,0x41,0x5d,0x55,0x55,0x5d,0x41,0x41,0x45,0x82,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38614 0x96d6 "雖" */
+0x00,0x7c,0x44,0x44,0x7d,0x12,0x10,0xfe,0x92,0x92,0xfe,0x10,0x14,0x12,0xfe,0x02,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38615 0x96d7 "雗" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x44,0x7d,0x46,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x40,0x40,0x7e,0x80,0x50,0x48,0xfe,0x90,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x80,
+/* 38616 0x96d8 "雘" */
+0x00,0x3d,0x24,0x24,0x34,0x2d,0x24,0x24,0xfe,0x24,0x24,0x24,0x25,0x24,0x44,0x8d,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 38617 0x96d9 "雙" */
+0x08,0x24,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,0x1f,0x08,0x04,0x03,0x1c,0xe0,
+0x10,0x48,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,0x40,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 38618 0x96da "雚" */
+0x08,0xff,0x08,0x3e,0x22,0x3e,0x09,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0x20,0xfe,0x20,0xf8,0x88,0xf8,0x00,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 38619 0x96db "雛" */
+0x20,0x20,0x7f,0x91,0x55,0x7d,0x21,0x4a,0xa4,0x7f,0x91,0x55,0x7d,0x21,0x4a,0x84,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38620 0x96dc "雜" */
+0x10,0x08,0xfe,0x00,0x25,0x26,0x5a,0x91,0x10,0xfe,0x10,0x54,0x92,0x12,0x50,0x20,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38621 0x96dd "雝" */
+0x49,0x92,0x49,0x00,0x7c,0x45,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x81,0x81,0x7f,0x00,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38622 0x96de "雞" */
+0x0e,0xf0,0x22,0x92,0x45,0x22,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x44,0x82,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 38623 0x96df "雟" */
+0x01,0x42,0x7f,0x08,0x34,0xcf,0x18,0x2f,0x48,0x0f,0x08,0x3f,0x24,0x2b,0x22,0x23,
+0x00,0x04,0xfc,0x80,0x40,0xfc,0x80,0xf8,0x80,0xfe,0x00,0xfc,0x24,0xd4,0x44,0xcc,
+/* 38624 0x96e0 "雠" */
+0x30,0x2a,0x41,0x7d,0xd0,0x53,0x7d,0x51,0x51,0x7d,0x51,0x51,0x51,0x7d,0x40,0x40,
+0x18,0x14,0x20,0x3e,0x68,0x28,0x3e,0x28,0x28,0x3e,0x28,0x68,0xa8,0x3e,0x20,0x20,
+/* 38625 0x96e1 "雡" */
+0x00,0xee,0x22,0xaa,0x66,0xab,0x18,0x66,0x89,0x30,0xc4,0x19,0xe2,0x0c,0x30,0xc0,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38626 0x96e2 "離" */
+0x10,0x08,0x7f,0x14,0x49,0x55,0x41,0x7f,0x08,0x7f,0x51,0x55,0x5d,0x41,0x45,0x42,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38627 0x96e3 "難" */
+0x22,0x22,0xff,0x22,0x3e,0x09,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x14,0x22,0x41,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 38628 0x96e4 "雤" */
+0x3a,0x21,0x3a,0x22,0x39,0x22,0x7f,0x48,0x9f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0xb8,0x08,0xb8,0x88,0x38,0x88,0xfe,0x82,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 38629 0x96e5 "雥" */
+0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x24,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,
+0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x48,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,
+/* 38630 0x96e6 "雦" */
+0x31,0x29,0x22,0x7b,0x56,0xd2,0x7b,0x52,0x52,0x7b,0x52,0x52,0x52,0x7b,0x42,0x42,
+0x8c,0x4a,0x10,0xde,0xb4,0x94,0xde,0x94,0x94,0xde,0x94,0x94,0x94,0xde,0x10,0x10,
+/* 38631 0x96e7 "雧" */
+0x08,0x1f,0x30,0xdf,0x10,0x1f,0x14,0x3f,0x64,0xbf,0x24,0x3f,0x01,0xff,0x09,0x71,
+0x80,0xfc,0x80,0xf8,0x80,0xfc,0x28,0x7e,0xc8,0x7e,0x48,0x7e,0x00,0xfe,0x20,0x1c,
+/* 38632 0x96e8 "雨" */
+0x00,0xff,0x01,0x01,0x01,0x7f,0x41,0x41,0x49,0x45,0x41,0x49,0x45,0x41,0x41,0x40,
+0x00,0xfe,0x00,0x00,0x00,0xfc,0x04,0x04,0x44,0x24,0x04,0x44,0x24,0x04,0x14,0x08,
+/* 38633 0x96e9 "雩" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x00,0xff,0x04,0x0f,0x00,0x00,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xa0,0x40,
+/* 38634 0x96ea "雪" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x00,0x00,0x1f,0x00,0x00,0x3f,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 38635 0x96eb "雫" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0xff,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfe,0x00,0x40,0x20,0x10,0x00,0x00,
+/* 38636 0x96ec "雬" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x01,0x7f,0x03,0x05,0x19,0xe1,0x01,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x00,0xfc,0x80,0x60,0x18,0x06,0x00,
+/* 38637 0x96ed "雭" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x08,0x0c,0x12,0x11,0x20,0x43,0x9c,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xe0,0x40,0xf8,0x10,0x20,0xc0,0x30,0x0e,
+/* 38638 0x96ee "雮" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,
+/* 38639 0x96ef "雯" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x02,0x01,0x7f,0x08,0x04,0x03,0x04,0x18,0xe0,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x00,0xfc,0x20,0x40,0x80,0x40,0x30,0x0e,
+/* 38640 0x96f0 "雰" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x04,0x08,0x30,0xdf,0x04,0x04,0x08,0x10,0x20,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0x20,0x18,0xe6,0x20,0x20,0x20,0xa0,0x40,
+/* 38641 0x96f1 "雱" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x02,0x01,0x7f,0x04,0x07,0x04,0x08,0x10,0x60,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x00,0xfc,0x00,0xf0,0x10,0x10,0xa0,0x40,
+/* 38642 0x96f2 "雲" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x00,0x00,0xff,0x08,0x10,0x3f,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x00,0x00,0xfe,0x20,0x10,0xf8,0x08,
+/* 38643 0x96f3 "雳" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x20,0x21,0x2f,0x21,0x42,0x44,0x98,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 38644 0x96f4 "雴" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,
+/* 38645 0x96f5 "雵" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x01,0x1f,0x11,0x11,0xff,0x02,0x1c,0xe0,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x00,0xf0,0x10,0x10,0xfe,0x80,0x70,0x0e,
+/* 38646 0x96f6 "零" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x02,0x0c,0x32,0xc1,0x1f,0x00,0x06,0x01,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x80,0x60,0x18,0x06,0xe0,0x20,0x40,0x80,0x40,
+/* 38647 0x96f7 "雷" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,
+/* 38648 0x96f8 "雸" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x08,0x7f,0x08,0x0f,0x08,0x0f,0x08,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x20,0xfc,0x20,0xe0,0x20,0xe0,0x20,
+/* 38649 0x96f9 "雹" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x08,0x1f,0x20,0x5f,0x10,0x1f,0x10,0x10,0x0f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf0,0x10,0x90,0x90,0xd0,0x20,0x04,0xfc,
+/* 38650 0x96fa "雺" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x1f,0x02,0x01,0x7f,0x04,0x18,0x62,0x01,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf0,0x20,0x40,0xfc,0x84,0x88,0x80,0x00,
+/* 38651 0x96fb "電" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x01,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x02,0x02,0xfe,
+/* 38652 0x96fc "雼" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7f,0x04,0x08,0x1f,0x28,0xc8,0x0f,0x08,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 38653 0x96fd "雽" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x00,0x7f,0x11,0x09,0xff,0x01,0x05,0x02,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x00,0x10,0x20,0xfe,0x00,0x00,0x00,
+/* 38654 0x96fe "雾" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x04,0x0f,0x14,0x03,0x1c,0xe2,0x0f,0x04,0x18,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xe0,0x40,0x80,0x70,0x0e,0xe0,0x20,0x60,
+/* 38655 0x96ff "雿" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x24,0x14,0x0c,0x14,0x64,0x08,0x10,0x60,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x48,0x50,0x60,0x50,0x48,0x42,0x42,0x3e,
+/* 38656 0x9700 "需" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0xff,0x02,0x3f,0x24,0x24,0x24,0x20,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfe,0x00,0xf8,0x88,0x88,0xa8,0x10,
+/* 38657 0x9701 "霁" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7f,0x08,0x07,0x18,0xe4,0x04,0x08,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x80,0xfc,0x20,0xc0,0x30,0x4e,0x40,0x40,0x40,
+/* 38658 0x9702 "霂" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0x87,0x50,0x21,0xe2,0x24,0x28,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0x40,0xfe,0xe0,0x50,0x48,0x44,0x42,
+/* 38659 0x9703 "霃" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x13,0x82,0x54,0x10,0xe1,0x22,0x24,0x28,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0xfc,0x44,0xa8,0xa0,0x22,0x22,0x1e,0x00,
+/* 38660 0x9704 "霄" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x11,0x09,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x20,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x10,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 38661 0x9705 "霅" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x01,0x7f,0x00,0x3f,0x00,0x3f,0x00,0x3f,0x20,0x3f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x00,0xfc,0x00,0xf8,0x00,0xf8,0x00,0xf8,0x08,0xf8,
+/* 38662 0x9706 "霆" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7c,0x09,0x10,0x3d,0x44,0x2b,0x10,0x6f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x08,0x3c,0xe0,0x20,0xfc,0x20,0xfe,0x00,0xfe,
+/* 38663 0x9707 "震" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x44,0x86,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x48,0x30,0x0e,
+/* 38664 0x9708 "霈" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x17,0x40,0x2b,0x0a,0x72,0x12,0x10,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0xfc,0x40,0xf8,0x48,0x48,0x58,0x40,
+/* 38665 0x9709 "霉" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x10,0x1f,0x20,0x5f,0x12,0xff,0x20,0x3f,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x00,0xf0,0x10,0xfe,0x90,0xfc,0x30,
+/* 38666 0x970a "霊" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x1f,0x00,0x7f,0x04,0x24,0x14,0xff,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf0,0x00,0xfc,0x40,0x48,0x50,0xfe,0x00,
+/* 38667 0x970b "霋" */
+0x3f,0x01,0x7f,0x41,0x9d,0x02,0x1f,0x02,0x7f,0x02,0x1f,0x04,0x7f,0x08,0x07,0x78,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf0,0x10,0xfc,0x10,0xf0,0x00,0xfc,0x20,0xc0,0x38,
+/* 38668 0x970c "霌" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3f,0x21,0x27,0x21,0x2f,0x20,0x27,0x44,0x47,0x80,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xf8,0x08,0xc8,0x08,0xe8,0x08,0xc8,0x48,0xc8,0x18,
+/* 38669 0x970d "霍" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x08,0x1f,0x30,0x5f,0x90,0x1f,0x10,0x1f,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x80,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfc,0x00,
+/* 38670 0x970e "霎" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x02,0x3f,0x08,0x7f,0x02,0xff,0x08,0x07,0x78,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x20,0xfc,0x00,0xfe,0x20,0xc0,0x38,
+/* 38671 0x970f "霏" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,
+/* 38672 0x9710 "霐" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x27,0x10,0x87,0x54,0x27,0xe0,0x22,0x21,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x88,0x88,0x88,0x10,0x90,0xa4,0xbe,0x02,
+/* 38673 0x9711 "霑" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0x80,0x48,0x0b,0x12,0xe2,0x23,0x22,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0x40,0x7c,0x40,0xf8,0x08,0x08,0xf8,0x08,
+/* 38674 0x9712 "霒" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0x7e,0x00,0xff,0x10,0x22,0x7f,0x01,
+0x10,0x10,0x10,0xa8,0xa8,0x44,0xa2,0x10,0x10,0x7c,0x04,0x04,0x08,0x08,0x10,0x10,
+/* 38675 0x9713 "霓" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x06,0x38,0x20,0x3c,0x20,0x3f,0x08,0x10,0xe0,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x42,0x42,0x3e,
+/* 38676 0x9714 "霔" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0x87,0x40,0x10,0x23,0xe0,0x20,0x27,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x80,0x40,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfc,
+/* 38677 0x9715 "霕" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0x7f,0x00,0xff,0x10,0x22,0x7f,0x21,
+0x10,0x10,0x7e,0x90,0x90,0x54,0x54,0x54,0x54,0x7c,0x14,0x90,0x12,0x12,0x12,0x0e,
+/* 38678 0x9716 "霖" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x08,0x08,0x7e,0x08,0x1c,0x2a,0xc9,0x08,0x08,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0x20,0xfc,0x30,0x68,0xa4,0x22,0x20,0x20,
+/* 38679 0x9717 "霗" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0x01,0x46,0x29,0x08,0x70,0x10,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0xa0,0x58,0x26,0xf0,0x10,0xa0,0x40,0x20,
+/* 38680 0x9718 "霘" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x13,0x02,0x42,0x2a,0x0a,0x72,0x12,0x12,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x04,0xf4,0x04,0xf4,0x94,0xf4,0x0c,
+/* 38681 0x9719 "霙" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x08,0xff,0x09,0x1f,0x11,0xff,0x02,0x1c,0xe0,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0xfe,0x20,0xf0,0x10,0xfe,0x80,0x70,0x0e,
+/* 38682 0x971a "霚" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,
+/* 38683 0x971b "霛" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7b,0x08,0x7b,0x42,0x7b,0x08,0x29,0x10,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xde,0x42,0xde,0x10,0xde,0x42,0x4a,0x84,
+/* 38684 0x971c "霜" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x08,0x7e,0x18,0x2c,0x4a,0x88,0x08,0x08,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 38685 0x971d "霝" */
+0x00,0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7b,0x4a,0x4a,0x4a,0x4a,0x7b,0x4a,
+0x00,0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xbc,0xa4,
+/* 38686 0x971e "霞" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3e,0x22,0x3e,0x20,0x3e,0x20,0x3e,0x20,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x48,0x30,0xcc,
+/* 38687 0x971f "霟" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x10,0x08,0x43,0x20,0x08,0x17,0x70,0x11,0x12,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x90,0x90,0xfc,0x90,0x90,0xfe,0x90,0x08,0x04,
+/* 38688 0x9720 "霠" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x10,0xfc,0x49,0x4a,0x10,0x1e,0xf0,0x40,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,
+/* 38689 0x9721 "霡" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3c,0x24,0x3c,0x25,0x3c,0x25,0x26,0x4c,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x20,0x10,0xe0,0x22,0xb4,0xa8,0x24,0xa2,0x40,
+/* 38690 0x9722 "霢" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x55,0x8a,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x0c,0xf0,0x08,0x70,0x44,0x68,0x50,0x48,0x66,
+/* 38691 0x9723 "霣" */
+0x3f,0x01,0x7f,0x49,0x84,0x0f,0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x08,0x10,
+0xf8,0x00,0xfe,0x22,0x14,0xe0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x20,0x10,
+/* 38692 0x9724 "霤" */
+0x3f,0x01,0x7f,0x41,0x9d,0x04,0x79,0x40,0x48,0x54,0x62,0x3f,0x21,0x3f,0x21,0x3f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x44,0x44,0x54,0x88,0xf8,0x08,0xf8,0x08,0xf8,
+/* 38693 0x9725 "霥" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x7f,0x40,0x9f,0x06,0x3b,0x04,0x19,0x62,0x0c,0x73,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfe,0x02,0xf4,0x00,0x08,0xb0,0xc0,0xa0,0x98,0x06,
+/* 38694 0x9726 "霦" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x22,0x22,0xf7,0x22,0x77,0xaa,0x22,0x22,0x22,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x04,0x08,0xb0,0x04,0x08,0xb2,0x44,0x18,0x60,
+/* 38695 0x9727 "霧" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x00,0x7e,0x15,0x08,0xfe,0x1a,0x2c,0x48,0xa8,0x11,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x40,0xfc,0x44,0x38,0x44,0xa2,0xfc,0x44,0x94,0x08,
+/* 38696 0x9728 "霨" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3f,0x21,0x3f,0x20,0x2f,0x20,0x5f,0x44,0x95,0x2c,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x08,0x08,0x7e,0x08,0x48,0x28,0x88,0x08,0x28,0x90,
+/* 38697 0x9729 "霩" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x08,0x7f,0x22,0x3e,0x00,0x3e,0x04,0x7f,0x08,0x18,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x7c,0x44,0x48,0x50,0x48,0x44,0x64,0x58,0x40,0x40,
+/* 38698 0x972a "霪" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x17,0x82,0x41,0x17,0x20,0xef,0x20,0x27,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x3c,0xc0,0x44,0x28,0xfc,0x40,0xfe,0x40,0xfc,
+/* 38699 0x972b "霫" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x7e,0x22,0x1a,0x62,0x04,0x1f,0x10,0x1f,0x10,0x1f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x44,0x34,0xc4,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 38700 0x972c "霬" */
+0x3f,0x01,0x7f,0x49,0x84,0x3f,0x21,0x3f,0x21,0x3f,0x04,0x3f,0x04,0xff,0x08,0x10,
+0xf8,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xf8,0x40,0xfe,0x20,0x10,
+/* 38701 0x972d "霭" */
+0x3f,0x01,0x7f,0x49,0x84,0x23,0x12,0x03,0x72,0x13,0x11,0x13,0x14,0x1a,0x13,0x00,
+0xf8,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0xa4,0xf4,0x0c,
+/* 38702 0x972e "霮" */
+0x3f,0x01,0x7f,0x49,0x84,0x21,0x17,0x91,0x41,0x41,0x11,0x21,0xe7,0x22,0x22,0x23,
+0xf8,0x00,0xfe,0x22,0x14,0x10,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xfc,0x50,0x88,0xfc,
+/* 38703 0x972f "霯" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x00,0x7e,0x04,0x2b,0x10,0x2f,0xc8,0x0f,0x04,0x7f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x90,0xa0,0x44,0xa8,0x10,0xe8,0x26,0xe0,0x40,0xfc,
+/* 38704 0x9730 "霰" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x12,0x3f,0x12,0x7f,0x00,0x3f,0x21,0x3f,0x21,0x23,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x20,0x20,0x3e,0x44,0xa4,0x24,0x28,0x10,0x28,0x46,
+/* 38705 0x9731 "霱" */
+0x3f,0x01,0x7f,0x49,0x9f,0x02,0x7f,0x04,0x7a,0x01,0x3f,0x28,0x37,0x24,0x27,0x20,
+0xf8,0x00,0xfe,0x22,0xf4,0x20,0xfc,0x88,0x80,0x00,0xf8,0x28,0xd8,0x48,0xc8,0x18,
+/* 38706 0x9732 "露" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7c,0x45,0x7c,0x11,0x5c,0x50,0x5c,0xe0,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x40,0xf8,0x48,0x30,0xce,0x00,0xf8,0x88,0xf8,
+/* 38707 0x9733 "霳" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x79,0x4a,0x48,0x53,0x49,0x49,0x6a,0x50,0x40,0x43,
+0xf8,0x00,0xfe,0x02,0x74,0x80,0xf8,0x88,0x70,0x8e,0x20,0xfc,0x20,0xf8,0x20,0xfe,
+/* 38708 0x9734 "霴" */
+0x00,0x7c,0x10,0xfe,0x93,0x54,0x10,0x54,0x01,0x7c,0x00,0xfe,0x21,0x48,0xfc,0x04,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,
+/* 38709 0x9735 "霵" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x3e,0x22,0x3e,0x00,0xff,0x22,0x3e,0x23,0xfe,0x02,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x28,0x24,0x24,0x20,0xfe,0x24,0x28,0x92,0x2a,0x46,
+/* 38710 0x9736 "霶" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x47,0x21,0x0f,0x88,0x57,0x11,0xe1,0x22,0x22,0x24,
+0xf8,0x00,0xfe,0x02,0x74,0x80,0xfc,0x10,0xfe,0x42,0xfc,0x00,0xf8,0x08,0x28,0x10,
+/* 38711 0x9737 "霷" */
+0x3f,0x01,0x7f,0x49,0x84,0x01,0x79,0x49,0x49,0x4b,0x79,0x4b,0x4c,0x49,0x7a,0x48,
+0xf8,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xfe,0x00,0xfc,0xa4,0x24,0x54,0x88,
+/* 38712 0x9738 "霸" */
+0x3f,0x01,0x7f,0x41,0x9d,0x22,0x7f,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0xff,0x08,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x54,0x88,
+/* 38713 0x9739 "霹" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x7e,0x42,0x7e,0x40,0x7e,0x62,0xbe,0x22,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0x10,
+/* 38714 0x973a "霺" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x20,0x45,0x97,0x20,0x6f,0xa0,0x27,0x24,0x28,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x10,0x50,0xde,0x24,0xd4,0x14,0x88,0xd4,0xa2,
+/* 38715 0x973b "霻" */
+0x3f,0x01,0x7f,0x41,0x9d,0x04,0x3f,0x24,0x3f,0x24,0x7f,0x10,0x1f,0x08,0xff,0x00,
+0xf8,0x00,0xfe,0x02,0x74,0x40,0xf8,0x48,0xf8,0x48,0xfc,0x10,0xf0,0x20,0xfe,0x00,
+/* 38716 0x973c "霼" */
+0x00,0x7c,0x10,0xff,0x92,0x54,0x11,0x54,0x01,0x7c,0x01,0xfe,0x20,0x49,0xfc,0x04,
+0x80,0x80,0xfc,0x00,0xf8,0x00,0xf8,0x48,0x68,0xc8,0xf8,0x4a,0xea,0x5a,0x46,0x42,
+/* 38717 0x973d "霽" */
+0x3f,0x01,0x7f,0x49,0x85,0xff,0x02,0x7d,0x25,0x4d,0x90,0x1f,0x10,0x1f,0x10,0x20,
+0xf8,0x00,0xfe,0x22,0x14,0xfe,0x88,0x70,0x48,0x66,0x10,0xf0,0x10,0xf0,0x10,0x10,
+/* 38718 0x973e "霾" */
+0x3f,0x01,0x7f,0x41,0x9d,0x30,0xcb,0x2d,0x31,0xc9,0x15,0x64,0x0d,0x34,0xc5,0x18,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 38719 0x973f "霿" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x7d,0x06,0x28,0x10,0xfd,0x34,0x50,0x90,0x50,0x20,
+0xf8,0x00,0xfe,0x02,0x74,0x80,0xf8,0x88,0x70,0x88,0x06,0xf8,0x88,0xf8,0x88,0xf8,
+/* 38720 0x9740 "靀" */
+0x3f,0x01,0x7f,0x41,0x9d,0x08,0x7f,0x08,0x7f,0x40,0x9f,0x06,0x19,0x06,0x38,0x03,
+0xf8,0x00,0xfe,0x02,0x74,0x20,0xfc,0x20,0xfe,0x02,0xf4,0x00,0x20,0xc0,0xa0,0x18,
+/* 38721 0x9741 "靁" */
+0x3f,0x01,0x7f,0x49,0x84,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xfe,0x92,0xfe,0x92,0xfe,
+0xf8,0x00,0xfe,0x22,0x14,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x92,0xfe,0x92,0xfe,
+/* 38722 0x9742 "靂" */
+0x3f,0x01,0x7f,0x49,0x84,0x7f,0x40,0x5f,0x44,0x7f,0x4e,0x55,0x60,0x44,0x44,0xbf,
+0xf8,0x00,0xfe,0x22,0x14,0xfe,0x00,0x3c,0x10,0x7e,0x34,0x52,0x90,0xf8,0x80,0xfe,
+/* 38723 0x9743 "靃" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x08,0x24,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x10,0x48,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,
+/* 38724 0x9744 "靄" */
+0x3f,0x01,0x7f,0x49,0xa4,0x11,0xfd,0x01,0x79,0x01,0x78,0x01,0x7a,0x4d,0x79,0x48,
+0xf8,0x00,0xfe,0x22,0x14,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x52,0xfa,0x06,
+/* 38725 0x9745 "靅" */
+0x00,0x7c,0x10,0xfe,0x92,0x54,0x10,0x54,0x00,0x7c,0x00,0xfe,0x20,0x48,0xfc,0x04,
+0x28,0xfe,0x2a,0xfe,0xa8,0xfe,0x4a,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x44,0x82,
+/* 38726 0x9746 "靆" */
+0x00,0x7e,0x11,0xfe,0x92,0x54,0x13,0x55,0x01,0x7d,0x01,0xff,0x21,0x49,0xfe,0x04,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x92,0x54,0x38,0x54,0x92,0x30,0x00,0xfe,0x00,
+/* 38727 0x9747 "靇" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,
+/* 38728 0x9748 "靈" */
+0x3f,0x01,0x7f,0x41,0x9d,0x01,0x1d,0x00,0x3b,0x2a,0x3b,0x00,0x7f,0x11,0x29,0xff,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x70,0x00,0xb8,0xa8,0xb8,0x00,0xfc,0x10,0x28,0xfe,
+/* 38729 0x9749 "靉" */
+0x00,0x7d,0x10,0xfe,0x93,0x55,0x10,0x55,0x01,0x7e,0x00,0xfe,0x20,0x49,0xfc,0x04,
+0x0e,0xf0,0xa2,0x54,0xfe,0x22,0x14,0x52,0x4a,0x38,0x40,0x7c,0x84,0x48,0x30,0xce,
+/* 38730 0x974a "靊" */
+0x3f,0x01,0x7f,0x41,0x9d,0x00,0x49,0x5d,0x49,0x7f,0x00,0x3f,0x08,0x0f,0x04,0x7f,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0x24,0x74,0x24,0xfc,0x00,0xf8,0x20,0xe0,0x40,0xfc,
+/* 38731 0x974b "靋" */
+0x3f,0x01,0x7f,0x41,0x9d,0x20,0x17,0x84,0x47,0x14,0x27,0xe5,0x26,0x29,0x29,0x13,
+0xf8,0x00,0xfe,0x02,0x74,0x00,0xfe,0x00,0xdc,0x88,0xfe,0xcc,0xaa,0x3c,0x20,0xfe,
+/* 38732 0x974c "靌" */
+0x3f,0x01,0x7f,0x49,0x85,0x7f,0x40,0x3c,0x09,0x3c,0x09,0x7f,0x11,0x1f,0x08,0x10,
+0xf8,0x00,0xfe,0x22,0x14,0xfc,0x84,0xf8,0x28,0xb0,0x28,0xf0,0x10,0xf0,0x20,0x10,
+/* 38733 0x974d "靍" */
+0x3f,0x01,0x7f,0x41,0x9d,0x28,0x24,0x7e,0x48,0xfe,0x48,0x7e,0x48,0x48,0x7e,0x40,
+0xf8,0x00,0xfe,0x02,0x74,0x40,0xfc,0x84,0xfc,0x84,0xfe,0x80,0xfe,0x02,0xaa,0x04,
+/* 38734 0x974e "靎" */
+0x3f,0x01,0x7f,0x41,0x9d,0x08,0x14,0x22,0x5c,0x88,0x3e,0x08,0x4a,0x28,0x0e,0x70,
+0xf8,0x00,0xfe,0x02,0x74,0x40,0xfc,0x84,0xfc,0x84,0xfe,0x80,0xfe,0x02,0xaa,0x04,
+/* 38735 0x974f "靏" */
+0x3f,0x01,0x7f,0x41,0x9d,0x10,0x7e,0x52,0x28,0x3e,0x68,0xbe,0x28,0x3e,0x28,0x3e,
+0xf8,0x00,0xfe,0x02,0x74,0x40,0xfc,0x84,0xfc,0x84,0xfe,0x80,0xfe,0x02,0xaa,0x04,
+/* 38736 0x9750 "靐" */
+0x3f,0x01,0x7f,0x49,0x9f,0x11,0x1f,0x00,0x7c,0x10,0xfe,0x92,0x54,0x7c,0x54,0x7c,
+0xf8,0x00,0xfe,0x22,0xf4,0x10,0xf0,0x00,0x7c,0x10,0xfe,0x92,0x54,0x7c,0x54,0x7c,
+/* 38737 0x9751 "靑" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0xff,0x00,0x1f,0x11,0x11,0x1f,0x10,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 38738 0x9752 "青" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 38739 0x9753 "靓" */
+0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x54,0x49,
+0x00,0xfc,0x84,0x84,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x50,0x50,0x50,0x92,0x92,0x0e,
+/* 38740 0x9754 "靔" */
+0x10,0x10,0xfe,0x10,0x7d,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x54,0x48,
+0x40,0x40,0x7e,0x80,0x00,0x7c,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 38741 0x9755 "靕" */
+0x00,0x00,0xfd,0x10,0x10,0x10,0x51,0x5c,0x50,0x50,0x50,0x50,0x5c,0xf0,0x00,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 38742 0x9756 "靖" */
+0x20,0x10,0x13,0xfc,0x01,0x08,0x8b,0x88,0x49,0x49,0x51,0x51,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 38743 0x9757 "靗" */
+0x10,0x10,0xfd,0x10,0x7c,0x10,0xfd,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x55,0x4a,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 38744 0x9758 "靘" */
+0x10,0x10,0xfc,0x10,0x7d,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,
+0x40,0x40,0xfc,0x88,0x10,0xfc,0xa4,0xa4,0xa4,0xfc,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 38745 0x9759 "静" */
+0x10,0x10,0xfe,0x10,0x7c,0x11,0xfe,0x00,0x7d,0x44,0x7c,0x45,0x7c,0x44,0x54,0x48,
+0x40,0x40,0x78,0x88,0x10,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 38746 0x975a "靚" */
+0x10,0x11,0xff,0x11,0x7d,0x11,0xff,0x01,0x7d,0x45,0x7d,0x44,0x7c,0x44,0x55,0x4a,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 38747 0x975b "靛" */
+0x10,0x10,0xfe,0x10,0x7d,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x55,0x4a,
+0x20,0x10,0xfe,0x82,0x04,0x00,0xfe,0x10,0x10,0x90,0x9e,0x90,0x90,0xd0,0x3e,0x00,
+/* 38748 0x975c "靜" */
+0x10,0x11,0xfe,0x10,0x7c,0x10,0xfe,0x00,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x54,0x48,
+0x1e,0xe0,0x92,0x4c,0x00,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x24,0x20,0xa0,0x40,
+/* 38749 0x975d "靝" */
+0x10,0x10,0xfc,0x11,0x7e,0x10,0xfd,0x00,0x7d,0x44,0x7d,0x44,0x7c,0x47,0x54,0x48,
+0x80,0x80,0xfc,0x00,0xf8,0x00,0xf8,0x48,0x68,0xc8,0xf8,0x4a,0xea,0x5a,0x46,0x42,
+/* 38750 0x975e "非" */
+0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,
+0x40,0x40,0x40,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x40,0x40,0x40,
+/* 38751 0x975f "靟" */
+0x04,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x00,0x3f,0x01,0x3f,0x01,0x7f,0x01,0x00,
+0x40,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0xf0,0x00,0xf0,0x00,0xf8,0x02,0x02,0xfe,
+/* 38752 0x9760 "靠" */
+0x11,0x1f,0x21,0xff,0x00,0x1f,0x10,0x1f,0x04,0x7c,0x04,0x3c,0x04,0x7c,0x04,0x04,
+0x00,0xf0,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x40,0x7c,0x40,0x78,0x40,0x7c,0x40,0x40,
+/* 38753 0x9761 "靡" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x21,0x21,0x3f,0x21,0x2f,0x21,0x5f,0x41,0x81,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0x20,0x20,0x3e,0x20,0x3c,0x20,0x3e,0x20,0x20,
+/* 38754 0x9762 "面" */
+0x00,0xff,0x02,0x02,0x04,0x3f,0x24,0x24,0x27,0x24,0x24,0x27,0x24,0x24,0x3f,0x20,
+0x00,0xfe,0x00,0x00,0x00,0xf8,0x48,0x48,0xc8,0x48,0x48,0xc8,0x48,0x48,0xf8,0x08,
+/* 38755 0x9763 "靣" */
+0x00,0xff,0x02,0x02,0x04,0x3f,0x20,0x20,0x27,0x24,0x24,0x27,0x20,0x20,0x3f,0x20,
+0x00,0xfe,0x00,0x00,0x00,0xf8,0x08,0x08,0xc8,0x48,0x48,0xc8,0x08,0x08,0xf8,0x08,
+/* 38756 0x9764 "靤" */
+0x00,0xfe,0x10,0x20,0xff,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 38757 0x9765 "靥" */
+0x3f,0x20,0x3f,0x21,0x26,0x38,0x27,0x20,0x2f,0x2a,0x2b,0x2a,0x4b,0x4a,0x8f,0x08,
+0xfc,0x90,0xfc,0x40,0x30,0x0c,0xf0,0x80,0xf8,0x28,0xe8,0x28,0xe8,0x28,0xf8,0x08,
+/* 38758 0x9766 "靦" */
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x01,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x52,0x92,0x0e,
+/* 38759 0x9767 "靧" */
+0x00,0xfe,0x10,0x20,0xfe,0xab,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xfe,0x82,0x00,
+0x10,0xfe,0x92,0xfe,0x10,0xfe,0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x44,0x82,
+/* 38760 0x9768 "靨" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x3f,0x20,0x2f,0x29,0x49,0x49,0x8f,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0x94,0xa2,0xfe,0x80,0xfc,0x24,0xe4,0x24,0xfc,
+/* 38761 0x9769 "革" */
+0x08,0x08,0x7f,0x08,0x08,0x0f,0x01,0x3f,0x21,0x21,0x3f,0x01,0xff,0x01,0x01,0x01,
+0x20,0x20,0xfc,0x20,0x20,0xe0,0x00,0xf8,0x08,0x08,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 38762 0x976a "靪" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x00,0x00,0x7e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x08,0x08,0x28,0x10,
+/* 38763 0x976b "靫" */
+0x28,0x29,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x00,0xf8,0x88,0xc8,0xa8,0xa8,0x88,0x50,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 38764 0x976c "靬" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x90,0x10,0x10,0x10,0x10,
+/* 38765 0x976d "靭" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x09,
+0x00,0x00,0x7e,0x12,0x12,0x52,0x52,0x52,0x52,0x92,0x12,0xa2,0x22,0x42,0x94,0x08,
+/* 38766 0x976e "靮" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x20,0x20,0x20,0x7e,0x42,0x82,0x02,0x82,0x42,0x22,0x22,0x82,0x02,0x02,0x14,0x08,
+/* 38767 0x976f "靯" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x08,
+0x10,0x10,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x90,0x10,0xfe,0x00,0x00,
+/* 38768 0x9770 "靰" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfc,0x10,0x10,0x11,0x12,
+0x00,0x00,0xfc,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x92,0x92,0x92,0x0e,0x00,
+/* 38769 0x9771 "靱" */
+0x28,0x28,0xfd,0x28,0x38,0x11,0x7c,0x54,0x54,0x7c,0x10,0xfc,0x10,0x11,0x12,0x14,
+0x00,0x00,0xfc,0x44,0x44,0x44,0xc4,0x44,0x64,0x54,0x4c,0x86,0x84,0x04,0x28,0x10,
+/* 38770 0x9772 "靲" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7d,0x56,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 38771 0x9773 "靳" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x08,0x09,
+0x04,0x0e,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0xc8,0x48,0x88,0x88,0x08,
+/* 38772 0x9774 "靴" */
+0x28,0x28,0xfe,0x28,0x38,0x11,0x7e,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x50,0x50,0x50,0x92,0x92,0x94,0x98,0x90,0xb0,0xd0,0x90,0x90,0x92,0x92,0x8e,0x80,
+/* 38773 0x9775 "靵" */
+0x28,0x29,0xfe,0x28,0x38,0x10,0x7c,0x55,0x54,0x7c,0x10,0xfe,0x10,0x10,0x13,0x10,
+0x00,0xf8,0x48,0x48,0x48,0x48,0x48,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 38774 0x9776 "靶" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x10,0x10,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 38775 0x9777 "靷" */
+0x28,0x29,0xfe,0x28,0x38,0x11,0x7d,0x55,0x55,0x7d,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x04,0xe4,0x24,0x24,0x24,0x24,0x44,0x84,
+/* 38776 0x9778 "靸" */
+0x28,0x2b,0xfc,0x28,0x38,0x10,0x7c,0x54,0x55,0x7d,0x11,0xfd,0x12,0x12,0x14,0x11,
+0x00,0xfc,0x84,0x88,0x88,0x90,0x9c,0x84,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 38777 0x9779 "靹" */
+0x28,0x28,0xfe,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x22,0x22,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 38778 0x977a "靺" */
+0x28,0x28,0xfc,0x2b,0x38,0x10,0x7c,0x55,0x54,0x7c,0x10,0xfd,0x11,0x12,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 38779 0x977b "靻" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x13,0x10,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 38780 0x977c "靼" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,0x00,0xfe,0x00,
+/* 38781 0x977d "靽" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7d,0x54,0x54,0x7c,0x13,0xfc,0x10,0x10,0x10,0x10,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 38782 0x977e "靾" */
+0x28,0x28,0xfe,0x28,0x38,0x13,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x28,0xa8,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xa8,0xa8,0xb8,0x80,0x80,0x80,0xfe,0x00,
+/* 38783 0x977f "靿" */
+0x50,0x50,0xf8,0x51,0x71,0x22,0xfb,0xa8,0xa9,0xf9,0x22,0xfb,0x20,0x20,0x20,0x20,
+0x10,0x90,0x90,0x10,0x7e,0x52,0x92,0x92,0x12,0x12,0x52,0xd2,0x62,0x22,0x4a,0x84,
+/* 38784 0x9780 "鞀" */
+0x28,0x29,0xfe,0x28,0x38,0x10,0x7c,0x54,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 38785 0x9781 "鞁" */
+0x28,0x28,0xfe,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xff,0x11,0x12,0x12,0x14,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 38786 0x9782 "鞂" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7d,0x54,0x54,0x7c,0x10,0xfc,0x11,0x10,0x10,0x10,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x70,0x68,0xa8,0xa4,0x22,0x20,0x20,0x20,
+/* 38787 0x9783 "鞃" */
+0x28,0x29,0xfe,0x28,0x38,0x11,0x7d,0x55,0x55,0x7d,0x10,0xfe,0x10,0x10,0x12,0x11,
+0x08,0xc8,0x48,0x48,0x48,0xc8,0x08,0x08,0x10,0xd0,0x54,0x54,0x52,0x5e,0x82,0x00,
+/* 38788 0x9784 "鞄" */
+0x28,0x28,0xfe,0x28,0x39,0x12,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 38789 0x9785 "鞅" */
+0x28,0x28,0xfe,0x29,0x39,0x11,0x7d,0x55,0x55,0x7f,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 38790 0x9786 "鞆" */
+0x28,0x29,0xfc,0x28,0x38,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x00,0xfe,0x20,0x20,0x20,0xfe,0x22,0x22,0x52,0x4a,0x8a,0x02,0x02,0x02,0x0a,0x04,
+/* 38791 0x9787 "鞇" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 38792 0x9788 "鞈" */
+0x28,0x28,0xfe,0x28,0x38,0x11,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x50,0x48,0x84,0x02,0xfc,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 38793 0x9789 "鞉" */
+0x28,0x28,0xfe,0x29,0x38,0x10,0x7c,0x54,0x54,0x7d,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 38794 0x978a "鞊" */
+0x28,0x28,0xfc,0x2b,0x38,0x10,0x7d,0x54,0x54,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 38795 0x978b "鞋" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7d,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 38796 0x978c "鞌" */
+0x01,0x7f,0x44,0x3f,0x08,0x07,0x78,0x04,0x7f,0x04,0x07,0x01,0x1f,0x11,0xff,0x01,
+0x00,0xfc,0x04,0xf8,0x20,0xc0,0x38,0x40,0xfc,0x40,0xc0,0x00,0xf0,0x10,0xfe,0x00,
+/* 38797 0x978d "鞍" */
+0x28,0x28,0xfc,0x2b,0x3a,0x14,0x7c,0x57,0x54,0x7c,0x11,0xfc,0x10,0x10,0x10,0x13,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 38798 0x978e "鞎" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xa4,0xc2,0x80,
+/* 38799 0x978f "鞏" */
+0x7c,0x10,0x10,0x1d,0xf2,0x08,0x7f,0x08,0x0f,0x01,0x3f,0x21,0x3f,0x01,0xff,0x01,
+0xf8,0x88,0xca,0x2a,0x06,0x20,0xfc,0x20,0xe0,0x00,0xf8,0x08,0xf8,0x00,0xfe,0x00,
+/* 38800 0x9790 "鞐" */
+0x28,0x28,0xfe,0x28,0x38,0x11,0x7c,0x54,0x55,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x3e,0x20,0x20,0xfe,0x00,0x00,0xfe,0x20,0x28,0x24,0x22,0x20,0x20,0x20,
+/* 38801 0x9791 "鞑" */
+0x28,0x29,0xfc,0x28,0x38,0x10,0x7d,0x54,0x54,0x7c,0x10,0xfc,0x10,0x11,0x12,0x10,
+0x10,0x10,0x90,0x90,0x7e,0x10,0x90,0x90,0x98,0xa8,0xa4,0xc4,0x80,0x40,0x3e,0x00,
+/* 38802 0x9792 "鞒" */
+0x28,0x28,0xfe,0x28,0x38,0x11,0x7c,0x54,0x55,0x7e,0x10,0xfe,0x10,0x10,0x10,0x11,
+0x08,0x1c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 38803 0x9793 "鞓" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x55,0x7c,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38804 0x9794 "鞔" */
+0x28,0x28,0xfc,0x29,0x3a,0x11,0x7d,0x55,0x55,0x7d,0x10,0xfc,0x10,0x10,0x11,0x12,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 38805 0x9795 "鞕" */
+0x28,0x29,0xfc,0x28,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x10,0x10,0x10,0x13,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 38806 0x9796 "鞖" */
+0x28,0x28,0xfd,0x28,0x39,0x10,0x7c,0x54,0x55,0x7c,0x10,0xfd,0x10,0x10,0x10,0x13,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xfe,0x44,0x84,0xc8,0x30,0x28,0xc4,0x02,
+/* 38807 0x9797 "鞗" */
+0x10,0x11,0x12,0x20,0x2b,0x68,0x6b,0xa8,0x28,0x28,0x29,0x29,0x29,0x20,0x23,0x20,
+0x80,0xf8,0x88,0x70,0x8e,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,
+/* 38808 0x9798 "鞘" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 38809 0x9799 "鞙" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7d,0x55,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x14,0x08,
+/* 38810 0x979a "鞚" */
+0x28,0x28,0xfe,0x29,0x39,0x12,0x7c,0x55,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,0x10,
+0x20,0x10,0x10,0xfe,0x02,0x54,0x88,0x04,0x00,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 38811 0x979b "鞛" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x55,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x10,0xfc,0x00,0x88,0x50,0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 38812 0x979c "鞜" */
+0x28,0x28,0xfd,0x28,0x38,0x11,0x7e,0x54,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x20,0x22,0xb4,0xa8,0xa8,0x24,0xa2,0x40,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 38813 0x979d "鞝" */
+0x28,0x29,0xfc,0x28,0x38,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x20,0x24,0xa4,0xa8,0x20,0xfc,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x14,0x08,
+/* 38814 0x979e "鞞" */
+0x28,0x28,0xfc,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfd,0x10,0x10,0x10,0x10,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 38815 0x979f "鞟" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfd,0x10,0x10,0x10,0x10,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 38816 0x97a0 "鞠" */
+0x28,0x28,0xfe,0x29,0x3a,0x10,0x7c,0x54,0x55,0x7c,0x10,0xfe,0x11,0x10,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 38817 0x97a1 "鞡" */
+0x28,0x28,0xfc,0x28,0x3b,0x10,0x7c,0x54,0x54,0x7d,0x12,0xfc,0x10,0x10,0x12,0x11,
+0x90,0x88,0x88,0xbe,0xc0,0x82,0xa2,0xe2,0x92,0x92,0x94,0x94,0x84,0x88,0xbe,0x00,
+/* 38818 0x97a2 "鞢" */
+0x28,0x29,0xfd,0x2b,0x39,0x11,0x7d,0x55,0x55,0x7c,0x13,0xfc,0x10,0x11,0x16,0x10,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 38819 0x97a3 "鞣" */
+0x28,0x29,0xfc,0x28,0x3b,0x10,0x7c,0x55,0x56,0x7c,0x13,0xfc,0x10,0x11,0x16,0x10,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 38820 0x97a4 "鞤" */
+0x08,0x7f,0x08,0xff,0x08,0x7f,0x08,0x0f,0xf0,0x04,0x7f,0x04,0x1f,0x11,0xff,0x01,
+0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,0x40,0xfc,0x40,0xf0,0x10,0xfe,0x00,
+/* 38821 0x97a5 "鞥" */
+0x28,0x28,0xfe,0x28,0x39,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x11,0x10,0x10,0x11,
+0x20,0x30,0x48,0x84,0x7a,0x00,0xfc,0x84,0x84,0xfc,0x48,0x48,0xfe,0x48,0x88,0x08,
+/* 38822 0x97a6 "鞦" */
+0x50,0x50,0xfb,0x51,0x71,0x21,0xfb,0xa9,0xa9,0xfb,0x25,0xf9,0x21,0x21,0x21,0x21,
+0x08,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 38823 0x97a7 "鞧" */
+0x28,0x28,0xfc,0x2b,0x38,0x10,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x88,0x48,0x50,0xfe,0x50,0x50,0xfc,0x54,0x54,0x8c,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 38824 0x97a8 "鞨" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7c,0x55,0x56,0x7d,0x11,0xfd,0x11,0x10,0x10,0x10,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 38825 0x97a9 "鞩" */
+0x50,0x50,0xfa,0x51,0x70,0x23,0xfa,0xaa,0xab,0xfa,0x22,0xfb,0x22,0x22,0x22,0x22,
+0x82,0x82,0xa2,0xca,0x8a,0xea,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x22,0xaa,0x44,
+/* 38826 0x97aa "鞪" */
+0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x04,0x7f,0x04,0x07,0x01,0x1f,0x11,0xff,0x01,
+0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0x40,0xfc,0x40,0xc0,0x00,0xf0,0x10,0xfe,0x00,
+/* 38827 0x97ab "鞫" */
+0x28,0x28,0xfc,0x29,0x3a,0x11,0x7c,0x55,0x54,0x7d,0x10,0xfd,0x11,0x11,0x10,0x10,
+0x80,0x80,0xfe,0x02,0x42,0xfa,0x02,0xf2,0x02,0xf2,0x02,0xf2,0x12,0xf2,0x14,0x08,
+/* 38828 0x97ac "鞬" */
+0x50,0x50,0xf8,0x57,0x71,0x21,0xfa,0xaa,0xaf,0xf9,0x21,0xfd,0x22,0x23,0x24,0x28,
+0x10,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x10,0x00,0xfe,0x00,
+/* 38829 0x97ad "鞭" */
+0x28,0x28,0xfe,0x29,0x39,0x13,0x7d,0x55,0x55,0x7d,0x11,0xff,0x11,0x11,0x11,0x11,
+0x80,0xfe,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x90,0x50,0x20,0x30,0x48,0x86,
+/* 38830 0x97ae "鞮" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7d,0x10,0xfe,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x20,0xa0,0xbc,0xa0,0x60,0x3e,
+/* 38831 0x97af "鞯" */
+0x28,0x28,0xfd,0x28,0x38,0x11,0x7c,0x54,0x54,0x7d,0x12,0xfc,0x10,0x10,0x10,0x10,
+0x48,0x48,0xfe,0x48,0x20,0xfe,0x40,0x40,0xbc,0x84,0x88,0xbe,0x88,0x88,0xa8,0x90,
+/* 38832 0x97b0 "鞰" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7d,0x11,0xff,0x11,0x11,0x13,0x10,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 38833 0x97b1 "鞱" */
+0x28,0x28,0xfe,0x28,0x38,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x1e,0xe0,0x22,0x92,0x54,0x40,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0x82,0xfe,0x82,
+/* 38834 0x97b2 "鞲" */
+0x50,0x50,0xfb,0x50,0x71,0x20,0xfb,0xa8,0xa9,0xf9,0x21,0xf9,0x23,0x21,0x21,0x21,
+0x88,0x88,0xfe,0x88,0xfc,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfe,0x04,0x14,0x08,
+/* 38835 0x97b3 "鞳" */
+0x28,0x28,0xfd,0x28,0x38,0x10,0x7c,0x55,0x56,0x7c,0x10,0xfd,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 38836 0x97b4 "鞴" */
+0x50,0x50,0xfb,0x50,0x70,0x27,0xf8,0xa9,0xab,0xfd,0x21,0xf9,0x21,0x21,0x21,0x21,
+0x88,0x88,0xfe,0x88,0x88,0xfe,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 38837 0x97b5 "鞵" */
+0x28,0x2b,0xfd,0x28,0x38,0x10,0x7d,0x54,0x54,0x7d,0x10,0xfc,0x13,0x10,0x10,0x13,
+0x1e,0xe0,0x22,0x94,0x40,0x88,0xf0,0x20,0xc4,0xfe,0x22,0x20,0xfe,0x50,0x88,0x06,
+/* 38838 0x97b6 "鞶" */
+0x08,0x3e,0x22,0x2a,0x7e,0x22,0x2a,0x46,0x7f,0x04,0x07,0x01,0x1f,0x11,0xff,0x01,
+0x78,0x48,0x8e,0x00,0xf8,0x48,0x30,0xcc,0xfc,0x40,0xc0,0x00,0xf0,0x10,0xfe,0x00,
+/* 38839 0x97b7 "鞷" */
+0x7f,0x08,0x0f,0x00,0x3f,0x24,0x2f,0x21,0x21,0x04,0x7f,0x04,0x1f,0x11,0xff,0x01,
+0xfc,0x20,0xe0,0x00,0xf8,0x48,0xe8,0x08,0x18,0x40,0xfc,0x40,0xf0,0x10,0xfe,0x00,
+/* 38840 0x97b8 "鞸" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7c,0x54,0x57,0x7c,0x10,0xfd,0x10,0x13,0x10,0x10,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 38841 0x97b9 "鞹" */
+0x51,0x50,0xfb,0x50,0x73,0x22,0xfb,0xa8,0xab,0xf8,0x20,0xf8,0x23,0x20,0x22,0x21,
+0x00,0x9e,0xd2,0x12,0xd4,0x54,0xd8,0x14,0xd2,0x52,0x92,0xda,0x94,0x90,0x90,0x10,
+/* 38842 0x97ba "鞺" */
+0x28,0x29,0xfc,0x2b,0x3a,0x10,0x7c,0x54,0x54,0x7c,0x10,0xfd,0x10,0x10,0x13,0x10,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38843 0x97bb "鞻" */
+0x28,0x29,0xfd,0x2b,0x39,0x11,0x7c,0x55,0x55,0x7d,0x10,0xfd,0x10,0x11,0x10,0x13,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 38844 0x97bc "鞼" */
+0x28,0x29,0xfd,0x29,0x38,0x13,0x7c,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x10,0x11,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 38845 0x97bd "鞽" */
+0x28,0x29,0xfc,0x2b,0x38,0x11,0x7e,0x54,0x54,0x7d,0x11,0xfd,0x11,0x11,0x11,0x11,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 38846 0x97be "鞾" */
+0x28,0x2b,0xfc,0x28,0x39,0x10,0x7c,0x57,0x54,0x7c,0x11,0xfc,0x13,0x10,0x10,0x10,
+0x88,0xfe,0x88,0x00,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 38847 0x97bf "鞿" */
+0x51,0x51,0xfa,0x53,0x71,0x22,0xfb,0xa9,0xaf,0xf9,0x21,0xf9,0x22,0x22,0x22,0x24,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 38848 0x97c0 "韀" */
+0x50,0x50,0xfb,0x52,0x73,0x22,0xfb,0xaa,0xaa,0xfa,0x22,0xfa,0x25,0x25,0x2a,0x20,
+0x40,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x80,0xfe,0x80,0xfe,0x02,0x56,0x56,0x02,0x06,
+/* 38849 0x97c1 "韁" */
+0x28,0x2b,0xfc,0x29,0x39,0x11,0x7d,0x57,0x54,0x7d,0x11,0xfd,0x11,0x11,0x10,0x13,
+0x00,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfe,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,
+/* 38850 0x97c2 "韂" */
+0x28,0x28,0xfd,0x2b,0x39,0x11,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x11,0x12,0x12,0x14,
+0x80,0xf8,0x08,0xfe,0x44,0x92,0xfe,0x00,0x7c,0x00,0x7c,0x00,0x7c,0x44,0x7c,0x44,
+/* 38851 0x97c3 "韃" */
+0x28,0x2a,0xfd,0x28,0x38,0x10,0x7f,0x55,0x55,0x7d,0x11,0xfd,0x11,0x11,0x12,0x14,
+0x10,0x10,0x7c,0x10,0xfe,0x44,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 38852 0x97c4 "韄" */
+0x28,0x2b,0xfc,0x28,0x39,0x13,0x7d,0x55,0x55,0x7d,0x11,0xfd,0x13,0x10,0x10,0x13,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 38853 0x97c5 "韅" */
+0x28,0x29,0xfd,0x29,0x39,0x11,0x7c,0x55,0x55,0x7c,0x11,0xfd,0x10,0x11,0x11,0x12,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x54,0xdc,0x88,0x54,0xdc,0x00,0xa8,0x54,0x54,
+/* 38854 0x97c6 "韆" */
+0x50,0x50,0xfc,0x52,0x72,0x20,0xf8,0xa9,0xae,0xfa,0x23,0xfa,0x22,0x22,0x25,0x28,
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x10,0xfe,0x44,0xfe,0x44,0x7c,0x42,0x3e,0x00,0xfe,
+/* 38855 0x97c7 "韇" */
+0x28,0x2b,0xfc,0x29,0x38,0x13,0x7e,0x57,0x55,0x7d,0x11,0xfd,0x11,0x11,0x10,0x11,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 38856 0x97c8 "韈" */
+0x28,0x29,0xfc,0x28,0x39,0x11,0x7d,0x55,0x54,0x7d,0x11,0xfd,0x11,0x11,0x11,0x12,
+0x48,0xfe,0x48,0x00,0xfe,0x4a,0x4a,0xfe,0x14,0xfe,0x10,0x92,0x4c,0x4a,0x16,0x22,
+/* 38857 0x97c9 "韉" */
+0x50,0x53,0xf8,0x50,0x73,0x22,0xfb,0xaa,0xab,0xfa,0x22,0xfa,0x22,0x24,0x2a,0x20,
+0x88,0xfe,0x88,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x80,0xfe,0x80,0xfe,0x02,0xaa,0x04,
+/* 38858 0x97ca "韊" */
+0x50,0x53,0xf8,0x53,0x72,0x23,0xfa,0xab,0xaa,0xfb,0x22,0xfa,0x22,0x22,0x22,0x22,
+0x88,0xfe,0x88,0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0xaa,0xfa,0x22,0x72,0xaa,0x24,
+/* 38859 0x97cb "韋" */
+0x02,0x02,0x3f,0x04,0xff,0x00,0x1f,0x10,0x1f,0x01,0x3f,0x01,0x21,0x3f,0x01,0x01,
+0x00,0x00,0xf0,0x10,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x00,0x00,0xfc,0x00,0x00,
+/* 38860 0x97cc "韌" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x09,
+0x00,0x00,0xfe,0x12,0x12,0x52,0x52,0x52,0x92,0x12,0x12,0x22,0x22,0x42,0x8a,0x04,
+/* 38861 0x97cd "韍" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x09,0x08,
+0x28,0x24,0x24,0x20,0x7e,0x20,0x20,0x3c,0x34,0x54,0x54,0x54,0x88,0x88,0x14,0x22,
+/* 38862 0x97ce "韎" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,
+/* 38863 0x97cf "韏" */
+0x11,0x09,0x7f,0x04,0xff,0x12,0x2f,0xc4,0x3f,0x10,0x1f,0x01,0x1f,0x21,0x3f,0x01,
+0x10,0x20,0xfc,0x00,0xfe,0x10,0xe8,0x26,0xf8,0x10,0xf0,0x00,0xf0,0x00,0xf8,0x00,
+/* 38864 0x97d0 "韐" */
+0x10,0x10,0x7c,0x24,0xfe,0x01,0x7e,0x44,0x7c,0x10,0x7c,0x10,0x50,0x7c,0x10,0x10,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 38865 0x97d1 "韑" */
+0x10,0x11,0x94,0x55,0x58,0x11,0xfd,0x29,0x28,0x29,0x28,0x29,0x29,0x48,0x48,0x87,
+0x20,0xfc,0x44,0xfe,0x00,0xfc,0x04,0xfc,0x20,0xfc,0x20,0x20,0xfc,0x20,0x22,0xfe,
+/* 38866 0x97d2 "韒" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 38867 0x97d3 "韓" */
+0x10,0x10,0x10,0xfe,0x11,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0xfc,0x44,0xfe,0x00,0xfc,0x84,0xfc,0x10,0xfc,0x10,0x90,0xfe,0x10,0x10,
+/* 38868 0x97d4 "韔" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x43,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x00,0x7c,0x40,0x78,0x40,0x78,0x40,0xfe,0xa0,0xa4,0x98,0x90,0x88,0xa4,0xc2,0x80,
+/* 38869 0x97d5 "韕" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0x7c,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 38870 0x97d6 "韖" */
+0x10,0x10,0x7c,0x24,0xfe,0x00,0x7c,0x45,0x7c,0x10,0x7d,0x10,0x50,0x7c,0x11,0x10,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x50,0x20,0x10,0xfe,0x38,0x54,0x92,0x10,0x10,
+/* 38871 0x97d7 "韗" */
+0x10,0x11,0x7d,0x24,0xfe,0x00,0x7d,0x45,0x7d,0x11,0x7d,0x10,0x53,0x7c,0x10,0x10,
+0x00,0xfe,0x02,0x20,0xfc,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 38872 0x97d8 "韘" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x14,0x54,0x54,0xfe,0x54,0x54,0x5c,0x40,0x7e,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,
+/* 38873 0x97d9 "韙" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x10,0x7c,0x24,0xfe,0x00,0x7c,0x44,0x7c,0x10,0x3c,0x50,0x7e,0x10,0x10,0xfe,0x00,
+/* 38874 0x97da "韚" */
+0x10,0x10,0x7d,0x24,0xfe,0x00,0x7d,0x45,0x7d,0x11,0x7c,0x13,0x50,0x7c,0x10,0x10,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 38875 0x97db "韛" */
+0x10,0x10,0x7d,0x24,0xfe,0x01,0x7c,0x44,0x7d,0x12,0x7c,0x10,0x50,0x7c,0x10,0x10,
+0x44,0x44,0xfe,0x44,0x44,0xfe,0x40,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 38876 0x97dc "韜" */
+0x10,0x11,0x7c,0x25,0xfe,0x00,0x7c,0x45,0x7d,0x11,0x7d,0x11,0x51,0x7d,0x11,0x11,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 38877 0x97dd "韝" */
+0x10,0x10,0x7d,0x24,0xfe,0x00,0x7d,0x44,0x7c,0x10,0x7c,0x10,0x51,0x7c,0x10,0x10,
+0x48,0x48,0xfe,0x48,0xfc,0x48,0xfe,0x10,0xfc,0x94,0xfc,0x94,0xfe,0x84,0x94,0x88,
+/* 38878 0x97de "韞" */
+0x10,0x10,0x7c,0x24,0xfe,0x00,0x7c,0x44,0x7c,0x11,0x7d,0x11,0x51,0x7d,0x13,0x10,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 38879 0x97df "韟" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x28,0x54,0x92,0x7c,0x10,0x10,0x10,
+/* 38880 0x97e0 "韠" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x00,0xfe,0x92,0xfe,0x92,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0xfe,0x10,0x10,
+/* 38881 0x97e1 "韡" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x44,0xfe,0x44,0x00,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0xfe,0x10,0x10,0x10,
+/* 38882 0x97e2 "韢" */
+0x10,0x10,0x7d,0x24,0xfe,0x00,0x7c,0x44,0x7c,0x10,0x7d,0x10,0x50,0x7d,0x11,0x12,
+0x10,0x10,0xfe,0x10,0xfc,0x94,0xfc,0x94,0xfc,0x12,0xfe,0x22,0x14,0x52,0x4a,0x38,
+/* 38883 0x97e3 "韣" */
+0x10,0x11,0x7d,0x25,0xff,0x00,0x7d,0x46,0x7d,0x11,0x7d,0x11,0x50,0x7d,0x10,0x10,
+0x00,0xfc,0x54,0x54,0xfc,0x80,0xfc,0x44,0xf4,0x54,0x54,0xf4,0x44,0xf4,0x14,0x08,
+/* 38884 0x97e4 "韤" */
+0x10,0x11,0x7c,0x24,0xff,0x01,0x7d,0x45,0x7c,0x11,0x7d,0x11,0x51,0x7d,0x11,0x12,
+0x48,0xfe,0x48,0x00,0xfe,0x4a,0x4a,0xfe,0x14,0xfe,0x10,0x92,0x4c,0x4a,0x16,0x22,
+/* 38885 0x97e5 "韥" */
+0x10,0x10,0x7e,0x22,0xff,0x00,0x7e,0x42,0x7e,0x08,0x7e,0x08,0x48,0x7e,0x08,0x08,
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0xaa,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,
+/* 38886 0x97e6 "韦" */
+0x01,0x01,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0x7f,0x01,0x01,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0xfe,0x00,0x00,0xf8,0x00,0x00,0xfc,0x04,0x04,0x04,0x28,0x10,0x00,
+/* 38887 0x97e7 "韧" */
+0x20,0x20,0x21,0xfc,0x20,0x20,0xf8,0x20,0x21,0xfc,0x24,0x24,0x34,0x28,0x21,0x22,
+0x00,0x00,0xfc,0x24,0x24,0xa4,0xa4,0xa4,0x24,0x24,0x24,0x44,0x44,0x84,0x14,0x08,
+/* 38888 0x97e8 "韨" */
+0x20,0x20,0x20,0xfc,0x21,0x20,0xf8,0x20,0x20,0xfc,0x24,0x25,0x35,0x2a,0x20,0x20,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 38889 0x97e9 "韩" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7d,0x10,0xfe,0x10,0x10,0x10,0x10,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x22,0x22,0x2a,0x24,0x20,0x20,
+/* 38890 0x97ea "韪" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x20,0x20,0xfc,0x20,0x20,0xf8,0x20,0x20,0xfc,0x24,0x24,0x34,0x28,0x20,0xfe,0x00,
+/* 38891 0x97eb "韫" */
+0x20,0x20,0x20,0xfc,0x20,0x20,0xf8,0x20,0x20,0xfd,0x25,0x25,0x35,0x29,0x23,0x20,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 38892 0x97ec "韬" */
+0x20,0x21,0x20,0xfd,0x20,0x20,0xf8,0x21,0x21,0xfd,0x25,0x25,0x35,0x29,0x21,0x21,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 38893 0x97ed "韭" */
+0x04,0x04,0x7c,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0xff,0x00,
+0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0xfe,0x00,
+/* 38894 0x97ee "韮" */
+0x08,0x08,0xff,0x08,0x08,0x04,0x7c,0x04,0x04,0x7c,0x04,0x04,0x7c,0x04,0x04,0xff,
+0x20,0x20,0xfe,0x20,0x20,0x40,0x7c,0x40,0x40,0x7c,0x40,0x40,0x7c,0x40,0x40,0xfe,
+/* 38895 0x97ef "韯" */
+0x08,0x08,0x7f,0x08,0xff,0x00,0x12,0x73,0x12,0x73,0x12,0x73,0x12,0x17,0xf8,0x40,
+0x20,0x28,0x24,0x20,0xfe,0x20,0x24,0xa4,0x24,0xa8,0x28,0x90,0x12,0xaa,0x46,0x82,
+/* 38896 0x97f0 "韰" */
+0x08,0x0f,0x28,0x7f,0xa1,0x16,0x38,0xc2,0x7e,0x02,0x3e,0x02,0x7e,0x02,0xff,0x00,
+0x00,0x7c,0x44,0x28,0x10,0x28,0xc6,0x80,0xfc,0x80,0xf8,0x80,0xfc,0x80,0xfe,0x00,
+/* 38897 0x97f1 "韱" */
+0x11,0x11,0x2a,0x44,0x00,0xff,0x12,0x73,0x12,0x73,0x12,0x73,0x12,0x17,0xf8,0x40,
+0x20,0x28,0xa4,0x64,0x20,0xfe,0x20,0xa4,0x24,0xa8,0x28,0x90,0x12,0xaa,0x46,0x82,
+/* 38898 0x97f2 "韲" */
+0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x02,0x7e,0x02,0x3e,0x02,0x7e,0x02,0xff,0x00,
+0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x80,0xfc,0x80,0xf8,0x80,0xfc,0x80,0xfe,0x00,
+/* 38899 0x97f3 "音" */
+0x02,0x01,0x3f,0x00,0x08,0x04,0xff,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x00,0x00,0xf8,0x00,0x20,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 38900 0x97f4 "韴" */
+0x20,0x13,0x7c,0x00,0x44,0x29,0xff,0x01,0x7d,0x45,0x45,0x7d,0x45,0x44,0x7c,0x44,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 38901 0x97f5 "韵" */
+0x20,0x10,0x7c,0x00,0x45,0x2a,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x44,
+0x40,0x40,0x80,0xfc,0x04,0x04,0x84,0x44,0x44,0x14,0x24,0x44,0x84,0x04,0x28,0x10,
+/* 38902 0x97f6 "韶" */
+0x20,0x11,0x7c,0x00,0x44,0x28,0xfe,0x00,0x7d,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 38903 0x97f7 "韷" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,
+/* 38904 0x97f8 "韸" */
+0x20,0x10,0x7c,0x00,0x45,0x28,0xfe,0x03,0x7c,0x44,0x44,0x7c,0x47,0x44,0x7c,0x44,
+0x40,0x40,0xfc,0x88,0x50,0x20,0xd8,0x26,0xf8,0x20,0xf8,0x20,0xfe,0x20,0x20,0x20,
+/* 38905 0x97f9 "韹" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xfe,0x00,0x7d,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 38906 0x97fa "韺" */
+0x20,0x10,0x7d,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7c,0x45,
+0x88,0x88,0xfc,0x88,0xa8,0x20,0xf8,0xa8,0xa8,0xa8,0xa8,0xfc,0x20,0x50,0x88,0x04,
+/* 38907 0x97fb "韻" */
+0x20,0x10,0x7c,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x28,0x44,0x82,
+/* 38908 0x97fc "韼" */
+0x20,0x12,0x79,0x00,0x48,0x30,0xfb,0x01,0x79,0x49,0x49,0x79,0x49,0x49,0x7a,0x4c,
+0x20,0x20,0x7c,0xa4,0x18,0xe6,0x10,0x7e,0x10,0x7c,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 38909 0x97fd "韽" */
+0x10,0x28,0x44,0x92,0x7c,0x08,0xfe,0x28,0xfe,0xaa,0xce,0x82,0xfe,0x82,0xfe,0x82,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 38910 0x97fe "韾" */
+0x08,0x7f,0x08,0x3e,0x00,0x3e,0x2a,0x3e,0x41,0xbf,0x04,0xff,0x10,0x1f,0x10,0x1f,
+0x00,0x78,0x48,0x48,0x86,0x78,0x48,0x30,0x4e,0xfc,0x40,0xfe,0x10,0xf0,0x10,0xf0,
+/* 38911 0x97ff "響" */
+0x11,0x23,0x7a,0x13,0x2a,0x7b,0x12,0x23,0x01,0x3f,0x04,0xff,0x10,0x1f,0x10,0x1f,
+0x00,0xde,0x52,0xd4,0x52,0xda,0x94,0x50,0x00,0xf8,0x40,0xfe,0x10,0xf0,0x10,0xf0,
+/* 38912 0x9800 "頀" */
+0x20,0x11,0x7c,0x00,0x44,0x29,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x45,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 38913 0x9801 "頁" */
+0x00,0x7f,0x02,0x04,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x10,0x1f,0x08,0x10,0x20,
+0x00,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0xf8,0x08,0x08,0xf8,0x10,0x08,0x04,
+/* 38914 0x9802 "頂" */
+0x00,0x01,0xfe,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x10,0x51,0x22,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38915 0x9803 "頃" */
+0x00,0x21,0x20,0x20,0x21,0x3d,0x21,0x21,0x21,0x25,0x29,0x31,0x21,0x00,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38916 0x9804 "頄" */
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x25,0x26,0x44,0x40,0x80,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38917 0x9805 "項" */
+0x00,0x01,0x00,0xfc,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38918 0x9806 "順" */
+0x04,0x45,0x54,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x85,0x06,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38919 0x9807 "頇" */
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38920 0x9808 "須" */
+0x08,0x09,0x10,0x20,0x41,0x89,0x09,0x11,0x21,0x45,0x85,0x09,0x11,0x20,0x41,0x82,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38921 0x9809 "頉" */
+0x08,0x09,0x08,0x08,0x48,0x4e,0x48,0x48,0x48,0x48,0x48,0x4e,0x58,0xe0,0x00,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38922 0x980a "頊" */
+0x00,0x01,0x7c,0x10,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38923 0x980b "頋" */
+0x00,0x7e,0x40,0x40,0x5e,0x52,0x52,0x52,0x5a,0x54,0x50,0x52,0x54,0x58,0x50,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38924 0x980c "頌" */
+0x00,0x28,0x24,0x24,0x42,0x52,0x90,0x10,0x20,0x20,0x48,0x44,0xfc,0x44,0x00,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38925 0x980d "頍" */
+0x10,0x11,0x10,0xfe,0x11,0x11,0xfd,0x05,0x05,0x49,0x29,0x11,0x29,0x44,0x81,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38926 0x980e "頎" */
+0x08,0x1d,0x60,0x40,0x41,0x41,0x7f,0x49,0x49,0x49,0x49,0x49,0x49,0x48,0x89,0x0a,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38927 0x980f "頏" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x80,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38928 0x9810 "預" */
+0x00,0x7c,0x04,0x28,0x10,0x08,0xfe,0x12,0x14,0x10,0x10,0x10,0x10,0x10,0x50,0x21,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38929 0x9811 "頑" */
+0x00,0x7c,0x00,0x00,0x00,0xfe,0x28,0x28,0x28,0x28,0x28,0x2a,0x4c,0x48,0x80,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38930 0x9812 "頒" */
+0x00,0x28,0x24,0x24,0x42,0x42,0x80,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38931 0x9813 "頓" */
+0x10,0x11,0x10,0xfe,0x11,0x55,0x55,0x55,0x55,0x7d,0x11,0x11,0x15,0x18,0x11,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38932 0x9814 "頔" */
+0x10,0x11,0x10,0x7c,0x55,0x55,0x55,0x55,0x7d,0x55,0x55,0x55,0x55,0x7c,0x45,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38933 0x9815 "頕" */
+0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38934 0x9816 "頖" */
+0x10,0x11,0x94,0x58,0x11,0x7d,0x11,0x11,0xff,0x11,0x11,0x11,0x21,0x20,0x41,0x82,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38935 0x9817 "頗" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7f,0x41,0x52,0x4a,0x44,0x4a,0x91,0x21,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38936 0x9818 "領" */
+0x10,0x11,0x28,0x24,0x43,0x91,0x09,0x01,0xfd,0x05,0x09,0x51,0x21,0x10,0x11,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38937 0x9819 "頙" */
+0x00,0x01,0xfc,0x10,0x11,0x11,0x51,0x5d,0x51,0x51,0x51,0x51,0x5d,0xf0,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38938 0x981a "頚" */
+0x00,0x7c,0x04,0x68,0x10,0x28,0x44,0x92,0x10,0x7c,0x10,0x10,0x1e,0xf0,0x40,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38939 0x981b "頛" */
+0x10,0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x30,0x38,0x54,0x54,0x90,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38940 0x981c "頜" */
+0x10,0x11,0x28,0x24,0x43,0x81,0x7d,0x01,0x01,0x7d,0x45,0x45,0x45,0x7c,0x45,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38941 0x981d "頝" */
+0x20,0x10,0x00,0xfe,0x00,0x28,0x44,0x82,0x04,0x44,0x28,0x10,0x28,0x44,0x84,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38942 0x981e "頞" */
+0x10,0x08,0x7e,0x42,0x94,0x10,0x10,0xfe,0x24,0x24,0x48,0x28,0x10,0x28,0x44,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38943 0x981f "頟" */
+0x20,0x20,0x3c,0x44,0xc4,0x28,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x7c,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38944 0x9820 "頠" */
+0x10,0x10,0x3f,0x21,0x42,0xbf,0x20,0x2f,0x29,0x29,0x2d,0x2a,0x28,0x4a,0x4c,0x88,
+0x00,0x7e,0x10,0x20,0x7c,0xc4,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38945 0x9821 "頡" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38946 0x9822 "頢" */
+0x08,0x1d,0x70,0x10,0x11,0xfd,0x11,0x11,0x7d,0x45,0x45,0x45,0x45,0x7c,0x45,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38947 0x9823 "頣" */
+0x00,0x7e,0x48,0x48,0x48,0x7e,0x42,0x42,0x7e,0x48,0x48,0x48,0x48,0x7e,0x00,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38948 0x9824 "頤" */
+0x00,0x7d,0x48,0x48,0x49,0x5d,0x55,0x55,0x55,0x5d,0x49,0x49,0x49,0x7e,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38949 0x9825 "頥" */
+0x40,0x5f,0x54,0x54,0x54,0x5f,0x51,0x51,0x51,0x5f,0x54,0x54,0x54,0x54,0x5f,0x40,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38950 0x9826 "頦" */
+0x10,0x08,0x08,0xff,0x08,0x10,0x22,0x7c,0x09,0x12,0x24,0xc8,0x14,0x22,0xc0,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38951 0x9827 "頧" */
+0x08,0x11,0x7c,0x44,0x45,0x45,0x7d,0x41,0x41,0x7d,0x45,0x45,0x45,0x7c,0x45,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x88,0x04,0x02,
+/* 38952 0x9828 "頨" */
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38953 0x9829 "頩" */
+0x42,0x24,0x00,0x7e,0x24,0x24,0x24,0x24,0xff,0x24,0x24,0x24,0x24,0x44,0x44,0x85,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38954 0x982a "頪" */
+0x08,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x18,0x1c,0x2a,0x2a,0x48,0x88,0x08,0x08,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38955 0x982b "頫" */
+0x28,0x28,0x28,0x28,0xaa,0x6c,0x28,0x28,0x6c,0xaa,0x28,0x28,0x2a,0x4c,0x48,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38956 0x982c "頬" */
+0x08,0x08,0x08,0x7e,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x08,0x14,0x12,0x22,0x40,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38957 0x982d "頭" */
+0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x44,0x28,0x2e,0xf0,0x40,0x00,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x00,0x48,0x84,
+/* 38958 0x982e "頮" */
+0x08,0x09,0xea,0x2c,0x4a,0x49,0xa8,0x10,0x24,0x24,0xff,0x24,0x24,0x44,0x44,0x84,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38959 0x982f "頯" */
+0x10,0x10,0x3e,0x62,0x94,0x48,0x30,0xc0,0x24,0x24,0xff,0x24,0x24,0x44,0x44,0x85,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38960 0x9830 "頰" */
+0x08,0x08,0x08,0xff,0x08,0x2a,0x2a,0x2a,0x5d,0x88,0x08,0x14,0x12,0x21,0x41,0x80,
+0x00,0xfe,0x10,0xa0,0x7c,0x44,0x44,0x7c,0x44,0xfc,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38961 0x9831 "頱" */
+0x04,0x1e,0xe0,0x22,0x92,0x54,0x40,0x04,0xff,0x04,0x44,0x24,0x24,0x04,0x14,0x09,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38962 0x9832 "頲" */
+0x00,0x01,0x76,0x12,0x12,0x22,0x27,0x72,0x12,0x52,0x52,0x27,0x20,0x50,0x8f,0x00,
+0x00,0xbe,0x08,0x10,0x3e,0x22,0xa2,0x3e,0x22,0x3e,0x22,0xa2,0x3e,0x00,0x94,0x22,
+/* 38963 0x9833 "頳" */
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x28,0x28,0x6c,0xaa,0x28,0x28,0x48,0x48,0x99,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38964 0x9834 "頴" */
+0x40,0x4c,0x70,0x42,0x42,0x3e,0x00,0x7c,0x00,0xfe,0x10,0x54,0x52,0x92,0x50,0x21,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38965 0x9835 "頵" */
+0x00,0x7e,0x12,0x12,0xff,0x12,0x12,0x7e,0x20,0x20,0x7e,0x62,0xa2,0x22,0x3e,0x22,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38966 0x9836 "頶" */
+0x08,0x28,0x28,0x3e,0x48,0x08,0xff,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38967 0x9837 "頷" */
+0x08,0x08,0x14,0x22,0x51,0x88,0x7e,0x02,0x04,0x08,0x7e,0x42,0x42,0x7e,0x42,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38968 0x9838 "頸" */
+0x00,0xfe,0x54,0x54,0xa8,0x54,0x54,0x00,0xfe,0x10,0x10,0x10,0x1e,0xf0,0x40,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38969 0x9839 "頹" */
+0x0c,0x70,0x10,0xfe,0x10,0x38,0x54,0x92,0x00,0x28,0x28,0x28,0x2a,0x4c,0x48,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38970 0x983a "頺" */
+0x0c,0x70,0x10,0xfe,0x10,0x38,0x54,0x92,0x7c,0x24,0x28,0x2e,0x22,0x42,0x4a,0x85,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38971 0x983b "頻" */
+0x08,0x08,0x28,0x2e,0x28,0x28,0xff,0x00,0x08,0x2a,0x2a,0x4c,0x84,0x08,0x30,0xc1,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38972 0x983c "頼" */
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38973 0x983d "頽" */
+0x0c,0x70,0x10,0xfe,0x10,0x38,0x54,0x92,0x00,0x38,0x28,0x28,0x2a,0x4c,0x48,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38974 0x983e "頾" */
+0x0b,0x10,0x61,0x09,0x11,0x61,0x05,0x09,0x31,0xc0,0x09,0x28,0x2e,0x28,0x2e,0xf0,
+0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x80,0x98,0xe2,0x82,0x7e,
+/* 38975 0x983f "頿" */
+0x06,0x18,0x62,0x0c,0x73,0x0c,0xf4,0x14,0x55,0x5e,0x54,0x55,0x55,0x5d,0xf3,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38976 0x9840 "顀" */
+0x14,0x12,0x20,0x3f,0x64,0xa4,0x3f,0x24,0x24,0x3f,0x24,0x24,0x24,0x3f,0x20,0x20,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38977 0x9841 "顁" */
+0x10,0x08,0x7f,0x41,0x82,0x00,0x7f,0x08,0x08,0x28,0x2e,0x28,0x28,0x58,0x4f,0x80,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38978 0x9842 "顂" */
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0xba,0x10,0x38,0x54,0x92,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38979 0x9843 "顃" */
+0x10,0x52,0x54,0x90,0x28,0x44,0x82,0x10,0x10,0x52,0x54,0x90,0x28,0x24,0x42,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38980 0x9844 "顄" */
+0x00,0x7f,0x02,0x04,0x49,0x6b,0x5d,0x49,0x5d,0x6b,0x49,0x69,0x51,0x47,0x79,0x00,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38981 0x9845 "顅" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x40,0x5e,0x52,0x5e,0x52,0x5e,0x52,0x52,0x92,0x17,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38982 0x9846 "顆" */
+0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38983 0x9847 "顇" */
+0x10,0x08,0x00,0x7f,0x00,0x22,0x22,0x55,0x88,0x08,0xff,0x08,0x08,0x08,0x08,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0xc4,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38984 0x9848 "顈" */
+0x40,0x4c,0x70,0x42,0x42,0x3e,0x20,0x44,0x78,0x10,0x24,0xfe,0x10,0x54,0x92,0x31,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38985 0x9849 "顉" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x50,0x1e,0xf0,0x41,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38986 0x984a "顊" */
+0x10,0x20,0x7e,0x42,0x7e,0x40,0x7e,0x42,0x7e,0x10,0x10,0xfe,0x10,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38987 0x984b "顋" */
+0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0x04,0x15,0x50,0x50,0x52,0x8e,0x00,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0xc4,0xfc,0x80,0x28,0x44,
+/* 38988 0x984c "題" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,0x82,0xfe,0x00,
+/* 38989 0x984d "額" */
+0x20,0x10,0xfe,0x82,0x20,0x3c,0x44,0xa8,0x10,0x28,0x44,0xfe,0x44,0x44,0x7c,0x45,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38990 0x984e "顎" */
+0x00,0xee,0xaa,0xaa,0xee,0x00,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x28,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38991 0x984f "顏" */
+0x10,0x08,0x7f,0x22,0x1c,0x22,0x7f,0x44,0x48,0x72,0x44,0x48,0x71,0x42,0x8c,0x71,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38992 0x9850 "顐" */
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x11,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38993 0x9851 "顑" */
+0x02,0x02,0x02,0x7f,0x42,0x42,0x5e,0x42,0x42,0x5e,0x56,0x55,0x5d,0x41,0x42,0x84,
+0x00,0xbe,0x08,0x90,0x3e,0x22,0x22,0xbe,0xa2,0xbe,0xa2,0x22,0x7e,0x40,0xd4,0x62,
+/* 38994 0x9852 "顒" */
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x92,0x96,0xbe,0x82,0x8a,0x85,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38995 0x9853 "顓" */
+0x10,0x92,0x92,0x92,0xfe,0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0x87,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38996 0x9854 "顔" */
+0x10,0x08,0x7f,0x22,0x14,0x7f,0x44,0x48,0x52,0x44,0x48,0x51,0x42,0x44,0x88,0x30,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 38997 0x9855 "顕" */
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x28,0x28,0xaa,0x6c,0x28,0x2e,0xf0,0x41,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 38998 0x9856 "顖" */
+0x08,0x10,0x7f,0x41,0x55,0x49,0x55,0x41,0x7f,0x08,0x05,0x54,0x50,0x92,0x0e,0x00,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0xc4,0xfc,0x00,0x28,0x44,
+/* 38999 0x9857 "顗" */
+0x08,0x49,0x49,0x7f,0x00,0xff,0x00,0x7f,0x41,0x41,0x7f,0x42,0x24,0x0f,0xf0,0x40,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39000 0x9858 "願" */
+0x00,0x7f,0x44,0x48,0x5f,0x51,0x5f,0x51,0x5f,0x44,0x56,0x55,0x65,0x45,0x94,0x08,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39001 0x9859 "顙" */
+0x00,0x7e,0x22,0x1c,0x22,0x77,0x55,0x22,0x55,0x08,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39002 0x985a "顚" */
+0x46,0x78,0x40,0x3f,0x00,0x5f,0x51,0x5f,0x51,0x5f,0x51,0x5f,0x40,0x7f,0x22,0x41,
+0x00,0x7e,0x90,0xa0,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x80,0x28,0x44,
+/* 39003 0x985b "顛" */
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x28,0x44,0x83,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39004 0x985c "顜" */
+0x22,0x22,0xff,0x22,0x7f,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0xff,0x41,0x45,0x42,
+0x00,0x3e,0x88,0x10,0x3e,0x22,0xa2,0x3e,0x22,0x3e,0x22,0x22,0xbe,0x00,0x14,0x22,
+/* 39005 0x985d "顝" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39006 0x985e "類" */
+0x10,0x92,0x54,0xfe,0x30,0x54,0x92,0x00,0x14,0x12,0xfe,0x10,0x28,0x24,0x44,0x81,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39007 0x985f "顟" */
+0x00,0x77,0x11,0x55,0x33,0x55,0x0c,0x33,0xc4,0x18,0x62,0x0c,0x71,0x06,0x18,0xe0,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0xc4,0x7c,0x44,0xc4,0x7c,0x00,0x28,0x44,
+/* 39008 0x9860 "顠" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x21,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39009 0x9861 "顡" */
+0x10,0x08,0x7f,0x22,0x14,0xff,0x10,0x29,0xce,0x14,0x26,0xcd,0x15,0x24,0xd4,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39010 0x9862 "顢" */
+0x22,0x22,0xff,0x22,0x22,0x3e,0x08,0xff,0x88,0xcc,0xaa,0xdd,0x88,0x88,0x8a,0x89,
+0x00,0x3e,0x88,0x10,0x3e,0x22,0x22,0xbe,0xa2,0xbe,0xa2,0xa2,0xbe,0x80,0x94,0x22,
+/* 39011 0x9863 "顣" */
+0x02,0x02,0x02,0x7f,0x42,0x4a,0x4e,0x4a,0x7e,0x4a,0x4a,0x5d,0x6b,0x49,0x5a,0x84,
+0x00,0x9e,0x04,0xc8,0x1e,0x12,0x12,0x9e,0x92,0x9e,0x92,0x12,0x5e,0x40,0xcc,0x52,
+/* 39012 0x9864 "顤" */
+0x10,0x10,0x7c,0x10,0xfe,0x44,0xee,0x44,0x64,0xde,0x00,0xfe,0x28,0x2a,0x4c,0x89,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39013 0x9865 "顥" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x10,0x54,0x92,0x31,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39014 0x9866 "顦" */
+0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0xaa,0xaa,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39015 0x9867 "顧" */
+0x10,0x08,0x7f,0x41,0x41,0x7f,0x54,0x52,0x7f,0x54,0x5f,0x54,0x5f,0x54,0x9f,0x10,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39016 0x9868 "顨" */
+0xfe,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x24,0x42,0x00,0xff,0x08,0x10,0x20,
+0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,0x00,0xfe,0x20,0x20,0x20,
+/* 39017 0x9869 "顩" */
+0x08,0x08,0x14,0x22,0x41,0xbe,0x00,0x00,0x77,0x55,0x55,0x77,0x22,0x22,0x55,0x88,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39018 0x986a "顪" */
+0x04,0x27,0x24,0xff,0x02,0x02,0x7f,0x42,0x7e,0x4a,0x4a,0x5a,0x6d,0x89,0x12,0x64,
+0x00,0xbe,0x08,0xd0,0x3e,0xa2,0xe2,0x3e,0x22,0xbe,0xa2,0xa2,0x3e,0x40,0xd4,0x62,
+/* 39019 0x986b "顫" */
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xff,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39020 0x986c "顬" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0xff,0x08,0x7f,0x55,0x55,0x55,0x43,
+0x00,0x3e,0x08,0x90,0xbe,0x22,0x22,0x3e,0x22,0xbe,0x22,0x22,0x3e,0x00,0x14,0x22,
+/* 39021 0x986d "顭" */
+0x22,0xff,0x22,0x7f,0x55,0x55,0x7f,0x00,0xff,0x90,0x3e,0x22,0x52,0x0c,0x18,0xe0,
+0x00,0xbe,0x08,0x10,0x3e,0x22,0x22,0x3e,0xa2,0xbe,0x22,0x22,0x3e,0x00,0x14,0x22,
+/* 39022 0x986e "顮" */
+0x10,0x08,0xff,0x80,0x7f,0x52,0x94,0x7f,0xc1,0x7f,0x41,0x7f,0x41,0x7f,0x22,0x41,
+0x00,0x7e,0x90,0xa0,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39023 0x986f "顯" */
+0x00,0xfe,0x82,0xfe,0x82,0xfe,0x44,0xaa,0xee,0x44,0xaa,0xee,0x00,0xaa,0xaa,0x01,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 39024 0x9870 "顰" */
+0x08,0x2e,0x28,0xff,0x2a,0x4c,0x32,0xc4,0x3f,0x21,0x3f,0x22,0x3f,0x08,0xff,0x00,
+0x7e,0x10,0x7e,0x42,0x7e,0x42,0x7e,0x24,0xfa,0x08,0xf8,0x08,0xf8,0x80,0xfe,0x80,
+/* 39025 0x9871 "顱" */
+0x08,0x0f,0x08,0x7f,0x48,0x7e,0x48,0x5f,0x55,0x5f,0x55,0x5f,0x40,0xbf,0x2a,0x7f,
+0x00,0xbe,0x08,0x90,0xbe,0x22,0xa2,0xbe,0x22,0x3e,0x22,0x22,0x3e,0x80,0x94,0xe2,
+/* 39026 0x9872 "顲" */
+0x29,0x4a,0x14,0x62,0x09,0x2a,0x54,0x22,0x48,0xff,0x00,0x7f,0x41,0x5d,0x55,0x7f,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39027 0x9873 "顳" */
+0x7f,0x21,0x3f,0x21,0x3f,0x21,0xff,0x01,0xff,0x52,0x73,0x52,0x73,0x5a,0xf7,0x10,
+0x80,0x3e,0x08,0x10,0x3e,0xe2,0x22,0x3e,0xe2,0xbe,0xa2,0xa2,0xbe,0xc0,0x94,0xa2,
+/* 39028 0x9874 "顴" */
+0x22,0x22,0xff,0x22,0x77,0x55,0x77,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x00,0x7e,0x90,0x20,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x44,
+/* 39029 0x9875 "页" */
+0x00,0x7f,0x02,0x04,0x1f,0x10,0x11,0x11,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0x00,0xfc,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x40,0x20,0x10,0x08,
+/* 39030 0x9876 "顶" */
+0x00,0x01,0xfe,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x10,0x50,0x21,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39031 0x9877 "顷" */
+0x00,0x21,0x20,0x20,0x21,0x3d,0x21,0x21,0x21,0x25,0x29,0x31,0x20,0x00,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39032 0x9878 "顸" */
+0x00,0x79,0x10,0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x11,0x10,0x10,0x11,0x12,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39033 0x9879 "项" */
+0x00,0x01,0x00,0xfc,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39034 0x987a "顺" */
+0x04,0x45,0x54,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x54,0x54,0x85,0x06,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39035 0x987b "须" */
+0x08,0x09,0x10,0x20,0x41,0x89,0x09,0x11,0x21,0x45,0x85,0x09,0x10,0x20,0x41,0x82,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39036 0x987c "顼" */
+0x00,0x01,0x7c,0x10,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe0,0x40,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39037 0x987d "顽" */
+0x00,0x7c,0x00,0x00,0x00,0xfe,0x28,0x28,0x28,0x28,0x28,0x2a,0x4c,0x48,0x80,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39038 0x987e "顾" */
+0x00,0x7e,0x40,0x40,0x5e,0x52,0x52,0x52,0x5a,0x54,0x50,0x52,0x54,0x58,0x50,0x83,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39039 0x987f "顿" */
+0x10,0x11,0x10,0xfe,0x11,0x55,0x55,0x55,0x55,0x7d,0x11,0x11,0x14,0x18,0x11,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39040 0x9880 "颀" */
+0x08,0x1c,0x60,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x0b,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39041 0x9881 "颁" */
+0x00,0x29,0x28,0x24,0x45,0x45,0x81,0x7d,0x25,0x25,0x25,0x25,0x24,0x44,0x55,0x8a,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39042 0x9882 "颂" */
+0x00,0x28,0x24,0x24,0x42,0x52,0x90,0x10,0x20,0x20,0x48,0x44,0xfc,0x44,0x00,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39043 0x9883 "颃" */
+0x10,0x08,0x08,0xff,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x25,0x46,0x44,0x80,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39044 0x9884 "预" */
+0x00,0xf9,0x08,0x50,0x21,0x11,0xfd,0x25,0x29,0x21,0x21,0x21,0x20,0x20,0xa1,0x42,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39045 0x9885 "颅" */
+0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x40,0x40,0x40,0x80,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39046 0x9886 "领" */
+0x10,0x11,0x28,0x24,0x43,0x91,0x09,0x01,0xfd,0x05,0x09,0x51,0x20,0x10,0x11,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39047 0x9887 "颇" */
+0x08,0x08,0x08,0x7f,0x49,0x4a,0x48,0x7f,0x41,0x52,0x4a,0x44,0x4a,0x91,0x21,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39048 0x9888 "颈" */
+0x00,0x7e,0x04,0x08,0x18,0x24,0x42,0x81,0x00,0x7e,0x08,0x08,0x08,0x0e,0xf0,0x40,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39049 0x9889 "颉" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39050 0x988a "颊" */
+0x08,0x08,0x08,0x7e,0x08,0x4a,0x2a,0x2c,0x08,0xfe,0x08,0x14,0x12,0x22,0x40,0x83,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39051 0x988b "颋" */
+0x00,0x03,0xec,0x24,0x24,0x44,0x4f,0xe4,0x24,0xa4,0xa4,0x4f,0x40,0xa0,0x1f,0x00,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39052 0x988c "颌" */
+0x10,0x10,0x28,0x24,0x42,0x80,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39053 0x988d "颍" */
+0x20,0x24,0x38,0x22,0x22,0x1e,0x00,0x08,0x0a,0xec,0x28,0x2c,0x4a,0x4a,0xa8,0x13,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39054 0x988e "颎" */
+0x40,0x44,0x78,0x42,0x42,0x3e,0x00,0x10,0x52,0x52,0x54,0x90,0x28,0x24,0x44,0x83,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39055 0x988f "颏" */
+0x10,0x08,0x08,0xff,0x08,0x10,0x22,0x7c,0x09,0x12,0x24,0xc8,0x14,0x22,0xc0,0x03,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39056 0x9890 "颐" */
+0x00,0x7d,0x48,0x48,0x49,0x5d,0x55,0x55,0x55,0x5d,0x49,0x49,0x48,0x7e,0x01,0x02,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39057 0x9891 "频" */
+0x10,0x11,0x50,0x5c,0x51,0x51,0xff,0x01,0x11,0x55,0x55,0x55,0x84,0x08,0x31,0xc2,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39058 0x9892 "颒" */
+0x08,0x09,0xea,0x2c,0x4a,0x49,0xa8,0x10,0x24,0x24,0xff,0x24,0x24,0x44,0x44,0x84,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39059 0x9893 "颓" */
+0x0c,0x71,0x10,0xfe,0x11,0x39,0x55,0x93,0x01,0x39,0x29,0x29,0x2a,0x4c,0x49,0x82,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39060 0x9894 "颔" */
+0x08,0x08,0x14,0x22,0x51,0x88,0x7e,0x02,0x04,0x08,0x7e,0x42,0x42,0x7e,0x42,0x00,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39061 0x9895 "颕" */
+0x40,0x4c,0x70,0x42,0x42,0x3e,0x00,0x7c,0x00,0xfe,0x10,0x54,0x52,0x92,0x50,0x23,
+0x00,0xfe,0x20,0x40,0xfc,0x84,0x94,0x94,0x94,0x94,0x94,0xa4,0x30,0x48,0x84,0x02,
+/* 39062 0x9896 "颖" */
+0x40,0x4d,0x70,0x44,0x45,0x3d,0x01,0x0d,0x71,0x11,0xff,0x11,0x38,0x54,0x91,0x12,
+0x00,0xfe,0x20,0x40,0xfc,0x04,0x24,0x24,0x24,0x24,0x24,0x44,0x50,0x88,0x04,0x02,
+/* 39063 0x9897 "颗" */
+0x00,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,0x08,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39064 0x9898 "题" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0xff,0x08,0x08,0x2f,0x28,0x28,0x58,0x4f,0x80,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x28,0x44,0x82,0x00,0xfe,0x00,
+/* 39065 0x9899 "颙" */
+0x00,0x3e,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x08,0x7f,0x49,0x4b,0x5f,0x41,0x45,0x42,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39066 0x989a "颚" */
+0x00,0xee,0xaa,0xaa,0xee,0x00,0xfe,0x00,0xff,0x40,0x7e,0x02,0x02,0x02,0x14,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39067 0x989b "颛" */
+0x08,0x49,0x49,0x49,0x7f,0x00,0xff,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x43,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0xd4,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39068 0x989c "颜" */
+0x10,0x08,0x7f,0x22,0x14,0x7f,0x44,0x48,0x52,0x44,0x48,0x51,0x42,0x44,0x88,0x30,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39069 0x989d "额" */
+0x10,0x08,0x7f,0x41,0x10,0x1e,0x22,0x54,0x08,0x14,0x22,0x7f,0xa2,0x22,0x3e,0x22,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39070 0x989e "颞" */
+0x00,0x7f,0x22,0x3e,0x22,0x3e,0x23,0xfe,0x02,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0xd4,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39071 0x989f "颟" */
+0x24,0x24,0xff,0x24,0x00,0xff,0x24,0x24,0xff,0xa5,0xa5,0xdb,0x91,0x81,0x85,0x82,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39072 0x98a0 "颠" */
+0x08,0x08,0x7f,0x08,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x7f,0x14,0x22,0x41,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39073 0x98a1 "颡" */
+0x00,0x7e,0x22,0x1c,0x22,0x77,0x55,0x22,0x55,0x08,0x7f,0x1c,0x2a,0x49,0x88,0x08,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39074 0x98a2 "颢" */
+0x00,0x7f,0x41,0x7f,0x41,0x7f,0x08,0xff,0x00,0x7f,0x41,0x7f,0x08,0x49,0x88,0x18,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x54,0xd4,0x54,0x54,0x54,0x54,0x20,0x28,0xc4,0x82,
+/* 39075 0x98a3 "颣" */
+0x92,0x54,0xfe,0x30,0x54,0x92,0x20,0x44,0x78,0x10,0x24,0xfe,0x10,0x54,0x92,0x30,
+0x00,0xfe,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x28,0x24,0x42,0x82,
+/* 39076 0x98a4 "颤" */
+0x08,0xff,0x00,0xff,0x81,0xbd,0xa5,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x00,0xfe,
+0x00,0x7e,0x10,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39077 0x98a5 "颥" */
+0x00,0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x00,0xff,0x08,0x7f,0x55,0x55,0x55,0x43,
+0x00,0x7e,0x10,0xa0,0xfc,0x44,0x54,0x54,0x54,0xd4,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39078 0x98a6 "颦" */
+0x08,0x2e,0x28,0xff,0x2a,0x4c,0x32,0xc4,0x3f,0x21,0x3f,0x22,0x3f,0x08,0xff,0x00,
+0x00,0xfe,0x20,0x7c,0x54,0x54,0x28,0x44,0xf8,0x08,0xf8,0x08,0xf8,0x80,0xfe,0x80,
+/* 39079 0x98a7 "颧" */
+0x22,0x22,0xff,0x22,0x77,0x55,0x77,0x12,0x3f,0x64,0xbf,0x24,0x3f,0x24,0x3f,0x20,
+0x00,0x7e,0x90,0x20,0x7c,0x44,0x54,0x54,0x54,0x54,0x54,0x54,0x20,0x28,0x44,0x82,
+/* 39080 0x98a8 "風" */
+0x00,0x3f,0x20,0x20,0x2f,0x21,0x2f,0x29,0x29,0x2f,0x29,0x21,0x21,0x5e,0x48,0x80,
+0x00,0xf8,0x08,0xe8,0x08,0x08,0xe8,0x28,0x28,0xe8,0x08,0x4a,0xea,0x2a,0x06,0x02,
+/* 39081 0x98a9 "颩" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x02,0xc2,0x44,0x48,0x52,0x42,0x44,0x48,0x50,0x42,0x44,0x48,0x50,0x22,0x1e,0x00,
+/* 39082 0x98aa "颪" */
+0x00,0x7f,0x01,0x01,0x01,0x01,0x1f,0x10,0x17,0x11,0x17,0x15,0x27,0x21,0x4f,0x80,
+0x00,0xfc,0x00,0x60,0x10,0x00,0xf0,0xd0,0x10,0x10,0xd0,0x50,0xca,0x2a,0xe6,0x22,
+/* 39083 0x98ab "颫" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x08,0xc8,0x48,0x5c,0x48,0x48,0x7e,0x48,0x48,0x54,0x52,0x62,0x40,0x22,0x1e,0x00,
+/* 39084 0x98ac "颬" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x00,0xde,0x44,0x54,0x54,0x64,0x7e,0x44,0x4c,0x54,0x64,0x54,0x48,0x22,0x1e,0x00,
+/* 39085 0x98ad "颭" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x08,0xc8,0x48,0x4e,0x48,0x48,0x48,0x5c,0x54,0x54,0x54,0x5c,0x54,0x22,0x1e,0x00,
+/* 39086 0x98ae "颮" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x40,0x40,0x7c,0x84,0x74,0x54,0x54,0x74,0x48,0x42,0x42,0x3e,0x80,0x42,0x3e,0x00,
+/* 39087 0x98af "颯" */
+0x80,0x4f,0x48,0x08,0xeb,0x08,0xa8,0xab,0xaa,0xaa,0x4b,0x38,0xc8,0x10,0x17,0x20,
+0x00,0xf8,0x08,0x68,0x88,0x88,0x88,0xe8,0xa8,0xa8,0xe8,0x8a,0xaa,0xea,0x26,0x02,
+/* 39088 0x98b0 "颰" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x08,0xca,0x48,0x7e,0x48,0x50,0x5e,0x52,0x6a,0x44,0x4a,0x52,0x40,0x22,0x1e,0x00,
+/* 39089 0x98b1 "颱" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x08,0xc8,0x48,0x52,0x5e,0x42,0x40,0x5e,0x52,0x52,0x5e,0x52,0x40,0x22,0x1e,0x00,
+/* 39090 0x98b2 "颲" */
+0x00,0x7d,0x44,0x4c,0x74,0x55,0x55,0x7d,0x56,0x7c,0x54,0x54,0x53,0x7d,0x44,0x80,
+0x02,0xf2,0x82,0x8a,0x8a,0xea,0x2a,0x2a,0xaa,0x4a,0x4a,0x82,0x0a,0x04,0x82,0x7e,
+/* 39091 0x98b3 "颳" */
+0x00,0x7f,0x40,0x43,0x5c,0x44,0x5f,0x55,0x55,0x5f,0x44,0x45,0x5f,0x49,0x80,0x00,
+0x04,0xd8,0x48,0x48,0x7e,0x48,0x48,0x5c,0x54,0x54,0x54,0x5c,0x40,0x22,0x1e,0x00,
+/* 39092 0x98b4 "颴" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x20,0x20,0x3e,0x40,0x80,0x7e,0x12,0x50,0x5c,0x50,0x50,0xbe,0x80,0x42,0x3e,0x00,
+/* 39093 0x98b5 "颵" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x54,0x38,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x4c,0x80,0x42,0x3e,0x00,
+/* 39094 0x98b6 "颶" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x00,0x28,0xc4,0x42,0x3e,0x00,
+/* 39095 0x98b7 "颷" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x52,0x94,0x28,0x44,0x84,0x10,0x12,0x54,0xa8,0x24,0x44,0x80,0x42,0x3e,0x00,
+/* 39096 0x98b8 "颸" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x00,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x24,0x12,0x60,0xa4,0x1c,0x80,0x42,0x3e,0x00,
+/* 39097 0x98b9 "颹" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x10,0x7c,0x24,0xfe,0x00,0x7c,0x44,0x7c,0x10,0x3c,0x50,0x7e,0x90,0x52,0x3e,0x00,
+/* 39098 0x98ba "颺" */
+0x00,0x7f,0x41,0x4d,0x71,0x51,0x7d,0x55,0x7d,0x51,0x55,0x7d,0x44,0x40,0x80,0x00,
+0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x52,0x2a,0x84,0x42,0x3e,0x00,
+/* 39099 0x98bb "颻" */
+0x0e,0xf1,0x23,0x93,0x45,0x21,0x3d,0x51,0x11,0xff,0x11,0x55,0x55,0x5d,0x62,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 39100 0x98bc "颼" */
+0x00,0x7d,0x45,0x4d,0x75,0x55,0x54,0x7d,0x54,0x7c,0x54,0x54,0x53,0x7d,0x44,0x80,
+0xa0,0x2c,0x24,0xac,0x24,0xfc,0x20,0xfc,0x04,0xc8,0x30,0x48,0x84,0x00,0x82,0x7e,
+/* 39101 0x98bd "颽" */
+0x10,0x55,0x55,0x55,0x7d,0x01,0x7d,0x01,0x7d,0x45,0x7d,0x45,0x29,0x1d,0xe2,0x44,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 39102 0x98be "颾" */
+0x00,0x7d,0x44,0x4c,0x74,0x54,0x54,0x7f,0x54,0x7c,0x54,0x54,0x53,0x7d,0x44,0x80,
+0x00,0xf8,0xa8,0x88,0x50,0x20,0xd8,0x26,0xf8,0xa8,0xf8,0x24,0xfc,0x04,0x82,0x7e,
+/* 39103 0x98bf "颿" */
+0x00,0x7d,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x85,0x16,0x0c,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 39104 0x98c0 "飀" */
+0x00,0x7d,0x45,0x4d,0x75,0x55,0x54,0x7d,0x55,0x7d,0x55,0x55,0x52,0x7d,0x44,0x80,
+0x40,0xbc,0x14,0x54,0xa4,0x2c,0x40,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x00,0x82,0x7e,
+/* 39105 0x98c1 "飁" */
+0x00,0xfd,0x25,0xb5,0x6d,0xb5,0x25,0x11,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7e,0x44,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 39106 0x98c2 "飂" */
+0x00,0x7d,0x44,0x4d,0x74,0x55,0x54,0x7c,0x54,0x7d,0x54,0x54,0x52,0x7d,0x44,0x80,
+0x00,0xdc,0x44,0x54,0xcc,0x54,0x20,0x50,0xa8,0x54,0xa0,0x48,0x90,0x20,0xc2,0x7e,
+/* 39107 0x98c3 "飃" */
+0x00,0x7d,0x44,0x4d,0x75,0x55,0x54,0x7c,0x54,0x7d,0x54,0x55,0x52,0x7d,0x44,0x80,
+0x00,0xfc,0x50,0xfc,0x54,0xfc,0x00,0xf8,0x00,0xfc,0xa8,0x24,0x60,0x00,0x82,0x7e,
+/* 39108 0x98c4 "飄" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x51,0x22,
+0x00,0xf8,0x88,0x98,0xe8,0xa8,0xf8,0xa8,0xf8,0xa8,0xa8,0xba,0xca,0x8a,0x06,0x02,
+/* 39109 0x98c5 "飅" */
+0x00,0x7d,0x44,0x4d,0x75,0x55,0x54,0x7d,0x55,0x7d,0x55,0x55,0x52,0x7d,0x44,0x80,
+0x00,0xfe,0x50,0xdc,0x54,0xdc,0x50,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x00,0x82,0x7e,
+/* 39110 0x98c6 "飆" */
+0x14,0x11,0xff,0x29,0x45,0x83,0x25,0x37,0x25,0xff,0x25,0x55,0x4b,0x89,0x12,0x04,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0xf4,0x16,0x06,0x02,
+/* 39111 0x98c7 "飇" */
+0x00,0x7c,0x45,0x4c,0x74,0x55,0x54,0x7c,0x54,0x7d,0x54,0x54,0x52,0x7d,0x44,0x80,
+0x28,0x20,0xfc,0x50,0x88,0x04,0x48,0x6c,0x48,0xfe,0x48,0xa8,0x94,0x12,0xa2,0x7e,
+/* 39112 0x98c8 "飈" */
+0x00,0x7c,0x44,0x4d,0x74,0x54,0x55,0x7c,0x56,0x7d,0x54,0x55,0x52,0x7d,0x44,0x80,
+0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x88,0xaa,0xdc,0x88,0x54,0x22,0x00,0x82,0x7e,
+/* 39113 0x98c9 "飉" */
+0x00,0x7c,0x45,0x4d,0x74,0x55,0x56,0x7c,0x54,0x7c,0x54,0x55,0x52,0x7d,0x44,0x80,
+0x20,0x20,0xfc,0x54,0x88,0xfc,0x8a,0xf8,0x88,0xf8,0xa8,0x24,0x60,0x00,0x82,0x7e,
+/* 39114 0x98ca "飊" */
+0x08,0x2a,0x2c,0x48,0x14,0x22,0x41,0x24,0x2d,0xb6,0x64,0x24,0x54,0x4a,0x91,0x02,
+0x00,0xf8,0x88,0x98,0xe8,0xa8,0xf8,0xa8,0xf8,0xa8,0xa8,0xba,0xca,0x8a,0x06,0x02,
+/* 39115 0x98cb "飋" */
+0x00,0x7d,0x44,0x4d,0x74,0x55,0x54,0x7c,0x54,0x7c,0x55,0x54,0x53,0x7d,0x44,0x80,
+0x00,0xde,0x84,0xce,0x84,0xde,0x20,0x18,0x48,0xd4,0x62,0x48,0xb8,0x00,0x82,0x7e,
+/* 39116 0x98cc "飌" */
+0x44,0xfe,0x44,0x00,0xee,0xaa,0xee,0x24,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7f,0x42,
+0x00,0xf8,0x88,0x98,0xe8,0xa8,0xf8,0xa8,0xf8,0xa8,0xa8,0xba,0xca,0x8a,0x06,0x02,
+/* 39117 0x98cd "飍" */
+0x1f,0x10,0x17,0x11,0x17,0x15,0x27,0x21,0x4f,0x80,0x7c,0x54,0x7c,0x54,0x7d,0x82,
+0xf0,0xd0,0x10,0x10,0xd0,0x50,0xca,0x2a,0xe6,0x22,0xf8,0xa8,0xf8,0xaa,0xfe,0x02,
+/* 39118 0x98ce "风" */
+0x00,0x3f,0x20,0x20,0x28,0x24,0x22,0x22,0x21,0x21,0x22,0x22,0x24,0x48,0x40,0x80,
+0x00,0xf0,0x10,0x10,0x50,0x50,0x90,0x90,0x10,0x10,0x90,0x92,0x4a,0x4a,0x06,0x02,
+/* 39119 0x98cf "飏" */
+0x00,0x7d,0x44,0x44,0x44,0x4d,0x6c,0x54,0x55,0x54,0x6c,0x45,0x44,0x42,0x41,0x80,
+0x00,0xf8,0x10,0x20,0xc0,0xfc,0x54,0x94,0x24,0x44,0x84,0x28,0x10,0x02,0xfe,0x00,
+/* 39120 0x98d0 "飐" */
+0x00,0x3f,0x21,0x21,0x25,0x35,0x29,0x29,0x29,0x29,0x35,0x25,0x20,0x40,0x40,0x80,
+0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x00,0x82,0x62,0x1e,0x00,
+/* 39121 0x98d1 "飑" */
+0x00,0x7c,0x44,0x45,0x46,0x4c,0x6c,0x54,0x54,0x54,0x6c,0x44,0x44,0x42,0x41,0x80,
+0x40,0x40,0xfc,0x04,0xf4,0x94,0xf4,0x84,0x94,0x8a,0x82,0x7e,0x00,0x02,0xfe,0x00,
+/* 39122 0x98d2 "飒" */
+0x20,0x13,0x12,0xfe,0x03,0x0a,0x8a,0x8a,0x4a,0x4a,0x52,0x53,0x1c,0xe4,0x48,0x10,
+0x00,0xf8,0x08,0x08,0x28,0xa8,0xa8,0x48,0x48,0xa8,0xa8,0x2a,0x0a,0x0a,0x06,0x02,
+/* 39123 0x98d3 "飓" */
+0x00,0x7c,0x44,0x44,0x44,0x4c,0x6c,0x54,0x54,0x55,0x6c,0x44,0x44,0x42,0x41,0x80,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xfc,0x00,0x50,0x88,0x02,0xfe,0x00,
+/* 39124 0x98d4 "飔" */
+0x00,0x7d,0x45,0x45,0x45,0x4d,0x6c,0x54,0x55,0x55,0x6e,0x44,0x44,0x42,0x41,0x80,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0x14,0x52,0x42,0x48,0x38,0x00,0x02,0xfe,0x00,
+/* 39125 0x98d5 "飕" */
+0x00,0x7d,0x45,0x45,0x45,0x4d,0x6c,0x55,0x54,0x54,0x6c,0x44,0x45,0x42,0x41,0x80,
+0xa0,0x2c,0x24,0xac,0x24,0xfc,0x20,0xfc,0x04,0xc8,0x30,0x48,0x84,0x02,0xfe,0x00,
+/* 39126 0x98d6 "飖" */
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x3c,0x50,0x10,0xfe,0x10,0x54,0x54,0x5d,0x65,0x02,
+0x00,0xf8,0x88,0x88,0x88,0x98,0xd8,0xa8,0xa8,0xa8,0xd8,0x8a,0x8a,0x0a,0x06,0x02,
+/* 39127 0x98d7 "飗" */
+0x00,0x7d,0x45,0x45,0x45,0x4d,0x6c,0x55,0x55,0x55,0x6d,0x45,0x44,0x42,0x41,0x80,
+0x40,0xbc,0x14,0x54,0xa4,0x2c,0x40,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x02,0xfe,0x00,
+/* 39128 0x98d8 "飘" */
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x93,0x51,0x22,
+0x00,0xf8,0x88,0x88,0x88,0x98,0xd8,0xa8,0xa8,0xa8,0xd8,0x8a,0x8a,0x0a,0x06,0x02,
+/* 39129 0x98d9 "飙" */
+0x00,0x14,0x10,0xfe,0x28,0x44,0x82,0x24,0x36,0x24,0xff,0x24,0x54,0x4b,0x89,0x12,
+0x00,0xf8,0x88,0x88,0x88,0x98,0xd8,0xa8,0xa8,0xa8,0xd8,0x8a,0x8a,0x0a,0x06,0x02,
+/* 39130 0x98da "飚" */
+0x00,0x7c,0x44,0x45,0x44,0x4c,0x6d,0x54,0x56,0x55,0x6c,0x45,0x46,0x42,0x41,0x80,
+0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x88,0xaa,0xdc,0x88,0x54,0x22,0x02,0xfe,0x00,
+/* 39131 0x98db "飛" */
+0x00,0x7f,0x00,0x0a,0x72,0x12,0x12,0x12,0xff,0x12,0x12,0x12,0x22,0x22,0x42,0x82,
+0x00,0xe0,0x24,0x28,0x24,0x20,0x12,0x0a,0xc6,0x48,0x50,0x48,0x40,0x24,0x14,0x0c,
+/* 39132 0x98dc "飜" */
+0x08,0x1d,0xf0,0x54,0x39,0xfe,0x34,0x52,0x81,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,
+0x00,0xfa,0x0c,0x4a,0x88,0xaa,0xa6,0xa2,0xf8,0xaa,0xac,0xaa,0xa8,0xaa,0xa6,0x22,
+/* 39133 0x98dd "飝" */
+0x00,0x7f,0x08,0x72,0x12,0xff,0x12,0x22,0xfd,0x24,0xd5,0x56,0xfd,0x54,0x55,0x93,
+0x04,0xe8,0x24,0x12,0x0e,0xd0,0x2a,0x1e,0xf8,0x48,0xaa,0xac,0xfa,0xa8,0xaa,0x26,
+/* 39134 0x98de "飞" */
+0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x20,0x20,0x12,0x0a,0x06,0x02,
+/* 39135 0x98df "食" */
+0x01,0x02,0x04,0x0a,0x31,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x11,0x10,0x12,0x14,0x18,
+0x00,0x80,0x40,0x20,0x18,0xf6,0x10,0xf0,0x10,0xf0,0x08,0x90,0x60,0x10,0x08,0x04,
+/* 39136 0x98e0 "飠" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 39137 0x98e1 "飡" */
+0x00,0x40,0x20,0x21,0x02,0x0c,0x0b,0x12,0x13,0xe2,0x23,0x22,0x22,0x22,0x23,0x02,
+0x40,0x40,0xa0,0x10,0x88,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x28,0x90,0x08,0x04,
+/* 39138 0x98e2 "飢" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x00,0x78,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 39139 0x98e3 "飣" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 39140 0x98e4 "飤" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x50,0x48,0x88,0x84,0x02,
+/* 39141 0x98e5 "飥" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x08,0x1c,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 39142 0x98e6 "飦" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 39143 0x98e7 "飧" */
+0x20,0x20,0x20,0x3c,0x24,0x45,0x46,0xa4,0x14,0x08,0x08,0x10,0x10,0x20,0x40,0x80,
+0x20,0x20,0x50,0x48,0xa4,0xfa,0x88,0xf8,0x88,0xf8,0xa2,0x94,0x88,0xa4,0xc4,0x80,
+/* 39144 0x98e8 "飨" */
+0x10,0x10,0x10,0x24,0x24,0x79,0x0a,0x10,0x24,0x7c,0x04,0x08,0x08,0x10,0x20,0x40,
+0x20,0x20,0x50,0x48,0xa4,0xfa,0x88,0xf8,0x88,0xf8,0xa2,0x94,0x88,0xa4,0xc4,0x80,
+/* 39145 0x98e9 "飩" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x40,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0xa8,0xa8,0xf8,0x22,0x22,0x22,0x1e,0x00,
+/* 39146 0x98ea "飪" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x08,0x1c,0x70,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,
+/* 39147 0x98eb "飫" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x65,0x42,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 39148 0x98ec "飬" */
+0x01,0x11,0x09,0x3f,0x02,0x7f,0x08,0x11,0x2f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x00,0x10,0x20,0xf8,0x00,0xfc,0x20,0x10,0xe8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39149 0x98ed "飭" */
+0x10,0x10,0x28,0x24,0x52,0xfd,0x44,0x7d,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x41,
+0x40,0x40,0x40,0xfe,0x80,0x20,0x20,0xfc,0x24,0x24,0x44,0x44,0x44,0x84,0xa8,0x10,
+/* 39150 0x98ee "飮" */
+0x08,0x08,0x14,0x12,0x28,0x44,0xbe,0x22,0x3e,0x22,0x3e,0x20,0x3e,0x20,0x3e,0x21,
+0x20,0x20,0x20,0x7e,0x42,0x84,0x10,0x10,0x10,0x10,0x28,0x28,0x48,0x44,0x84,0x02,
+/* 39151 0x98ef "飯" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x50,0x49,0x55,0x66,0x40,
+0x04,0x0e,0xf0,0x80,0x80,0xfc,0xa4,0xa4,0xa4,0xa8,0xa8,0x90,0x10,0x28,0x44,0x82,
+/* 39152 0x98f0 "飰" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x20,0x10,0x10,0x00,0xfe,0x20,0x20,0x30,0x28,0x28,0x24,0x24,0x20,0x20,0x20,0x20,
+/* 39153 0x98f1 "飱" */
+0x00,0x00,0xfc,0x20,0x21,0x3e,0x45,0x45,0x65,0x95,0x09,0x09,0x11,0x21,0x41,0x81,
+0x20,0x20,0x50,0x88,0x44,0x22,0xfc,0x04,0xfc,0x04,0xfc,0x22,0x14,0x48,0x84,0x02,
+/* 39154 0x98f2 "飲" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x65,0x42,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 39155 0x98f3 "飳" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x65,0x40,
+0x20,0x10,0x00,0xfe,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 39156 0x98f4 "飴" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x40,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 39157 0x98f5 "飵" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa3,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x40,0x40,0x40,0x7e,0xa0,0xa0,0x20,0x3c,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 39158 0x98f6 "飶" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7d,0x45,0x7d,0x42,0x50,0x48,0x55,0x66,0x40,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 39159 0x98f7 "飷" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0xfe,0x00,
+/* 39160 0x98f8 "飸" */
+0x00,0x7c,0x44,0x44,0x44,0x7d,0x02,0xfe,0x20,0x40,0x7c,0x04,0x04,0x04,0x28,0x10,
+0x20,0x20,0x50,0x48,0xa4,0xfa,0x88,0xf8,0x88,0xf8,0xa2,0x94,0x88,0xa4,0xc4,0x80,
+/* 39161 0x98f9 "飹" */
+0x10,0x10,0x2b,0x26,0x52,0xfa,0x4a,0x7a,0x4a,0x7a,0x43,0x52,0x48,0x58,0x69,0x42,
+0x00,0x80,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x5a,0x54,0x90,0x90,0x10,0x10,
+/* 39162 0x98fa "飺" */
+0x08,0x28,0x2e,0x28,0x2e,0xf1,0x02,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x80,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39163 0x98fb "飻" */
+0x10,0x10,0x28,0x24,0x53,0xfe,0x44,0x7c,0x45,0x7c,0x40,0x50,0x49,0x54,0x64,0x43,
+0x20,0x20,0x50,0x88,0x04,0x12,0x20,0x40,0x88,0x10,0x20,0x44,0x88,0x10,0x60,0x80,
+/* 39164 0x98fc "飼" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0xfe,0x02,0x02,0xfa,0x02,0x02,0xfa,0x8a,0x8a,0xfa,0x8a,0x02,0x02,0x14,0x08,
+/* 39165 0x98fd "飽" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 39166 0x98fe "飾" */
+0x10,0x10,0x28,0x24,0x53,0xfe,0x44,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x64,0x40,
+0x80,0x80,0x80,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 39167 0x98ff "飿" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,
+/* 39168 0x9900 "餀" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x45,0x7d,0x44,0x7c,0x40,0x50,0x48,0x54,0x65,0x42,
+0x88,0x88,0xfe,0x88,0x88,0x00,0x04,0x04,0x88,0x88,0x50,0x20,0x50,0x88,0x04,0x02,
+/* 39169 0x9901 "餁" */
+0x10,0x10,0x28,0x24,0x52,0xfd,0x46,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x40,
+0x40,0x44,0x4e,0xb8,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x88,0x88,0x88,0xbe,0x80,
+/* 39170 0x9902 "餂" */
+0x10,0x10,0x29,0x24,0x52,0xfd,0x44,0x7c,0x44,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 39171 0x9903 "餃" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x45,0x7e,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x43,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 39172 0x9904 "餄" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x10,0x10,0x28,0x28,0x44,0x82,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 39173 0x9905 "餅" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x23,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 39174 0x9906 "餆" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7c,0x44,0x7d,0x40,0x50,0x48,0x54,0x65,0x42,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 39175 0x9907 "餇" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0xfe,0x82,0x82,0xba,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x84,
+/* 39176 0x9908 "餈" */
+0x41,0x21,0x0a,0x14,0xe0,0x21,0x22,0x2d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x00,0xfc,0x44,0x40,0xb0,0x08,0x84,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39177 0x9909 "餉" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x10,0x10,0x20,0xfe,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x84,
+/* 39178 0x990a "養" */
+0x08,0x04,0x7f,0x01,0x3f,0x04,0xff,0x11,0x2f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x10,0xe8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39179 0x990b "餋" */
+0x11,0x09,0x7f,0x04,0xff,0x11,0x22,0xcd,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x10,0x20,0xfc,0x00,0xfe,0x10,0xc8,0x36,0xe8,0x24,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39180 0x990c "餌" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0xfe,0x44,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x4e,0xf4,0x04,0x04,0x04,
+/* 39181 0x990d "餍" */
+0x00,0x3f,0x21,0x3f,0x24,0x28,0x33,0x2c,0x37,0x24,0x27,0x24,0x27,0x44,0x45,0x86,
+0x00,0xfe,0x08,0xfc,0x10,0x88,0x64,0x98,0xf6,0x10,0xf0,0x10,0xf4,0x68,0x18,0x04,
+/* 39182 0x990e "餎" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x23,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 39183 0x990f "餏" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7c,0x45,0x7e,0x44,0x50,0x48,0x54,0x64,0x40,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x88,0xa4,0xc2,0x80,
+/* 39184 0x9910 "餐" */
+0x08,0x0f,0x28,0x7f,0xa1,0x17,0x3a,0xcd,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x00,0x78,0x08,0x28,0x10,0x28,0xc4,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39185 0x9911 "餑" */
+0x10,0x10,0x29,0x24,0x52,0xfd,0x45,0x7e,0x44,0x7c,0x40,0x51,0x48,0x54,0x64,0x40,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 39186 0x9912 "餒" */
+0x10,0x10,0x29,0x24,0x53,0xfc,0x44,0x7c,0x45,0x7c,0x40,0x51,0x48,0x54,0x64,0x43,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xfe,0x44,0x84,0xc8,0x30,0x28,0xc4,0x02,
+/* 39187 0x9913 "餓" */
+0x10,0x10,0x2b,0x24,0x50,0xfb,0x48,0x78,0x48,0x78,0x43,0x50,0x48,0x58,0x6a,0x41,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 39188 0x9914 "餔" */
+0x10,0x10,0x2b,0x24,0x52,0xfd,0x45,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x28,0x24,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 39189 0x9915 "餕" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 39190 0x9916 "餖" */
+0x10,0x11,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x65,0x40,
+0x00,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x00,0x84,0x44,0x48,0x00,0xfe,0x00,
+/* 39191 0x9917 "餗" */
+0x10,0x10,0x2b,0x24,0x52,0xfd,0x45,0x7d,0x45,0x7c,0x40,0x50,0x49,0x56,0x64,0x40,
+0x20,0x20,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 39192 0x9918 "餘" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2b,0x32,0x20,
+0x10,0x10,0x28,0x28,0x44,0xba,0x10,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x20,
+/* 39193 0x9919 "餙" */
+0x10,0x10,0x28,0x24,0x53,0xfc,0x45,0x7c,0x44,0x7d,0x42,0x50,0x48,0x54,0x64,0x40,
+0xc2,0x34,0x18,0x64,0x82,0x20,0xfe,0x50,0x90,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 39194 0x991a "餚" */
+0x11,0x10,0x28,0x24,0x53,0xfc,0x47,0x7c,0x44,0x7d,0x42,0x50,0x48,0x54,0x64,0x40,
+0x84,0x68,0x30,0xc8,0x24,0x20,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 39195 0x991b "餛" */
+0x10,0x11,0x29,0x25,0x53,0xfd,0x45,0x7d,0x44,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 39196 0x991c "餜" */
+0x10,0x11,0x29,0x25,0x53,0xfd,0x45,0x7d,0x44,0x7d,0x40,0x50,0x49,0x56,0x64,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 39197 0x991d "餝" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x41,
+0x84,0x84,0xfe,0x84,0xa4,0x10,0xfe,0x40,0x40,0x7c,0x44,0x44,0x44,0x84,0x94,0x08,
+/* 39198 0x991e "餞" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7d,0x44,0x7c,0x41,0x50,0x48,0x54,0x64,0x41,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 39199 0x991f "餟" */
+0x10,0x13,0x28,0x25,0x50,0xf9,0x4a,0x7c,0x48,0x7b,0x40,0x51,0x48,0x59,0x6a,0x44,
+0x00,0xde,0x42,0x4a,0x84,0x4a,0x52,0x20,0x00,0xde,0x52,0x52,0x94,0x48,0x54,0x22,
+/* 39200 0x9920 "餠" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7c,0x45,0x7c,0x40,0x50,0x48,0x54,0x64,0x41,
+0x44,0x44,0x88,0xdc,0x88,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 39201 0x9921 "餡" */
+0x10,0x10,0x28,0x24,0x53,0xfe,0x44,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x40,0x40,0x7c,0x84,0x08,0x00,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 39202 0x9922 "餢" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x20,0x10,0x7c,0x00,0x44,0x24,0x28,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 39203 0x9923 "餣" */
+0x10,0x10,0x2b,0x24,0x52,0xfd,0x46,0x7d,0x45,0x7d,0x41,0x51,0x48,0x54,0x64,0x40,
+0x20,0x20,0xfe,0x50,0x88,0x24,0x22,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x22,0x1e,0x00,
+/* 39204 0x9924 "餤" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x47,0x7c,0x44,0x7c,0x40,0x51,0x48,0x54,0x65,0x42,
+0x20,0xa2,0xa2,0x24,0x50,0x88,0x04,0x22,0x20,0xa4,0xa4,0x28,0x50,0x88,0x04,0x02,
+/* 39205 0x9925 "餥" */
+0x04,0x7c,0x04,0x3c,0x04,0x7d,0x06,0x0d,0x3f,0xc8,0x0f,0x08,0x0f,0x08,0x0a,0x0c,
+0x40,0x7c,0x40,0x78,0x40,0x7c,0xc0,0x60,0xf8,0x26,0xe0,0x20,0xe8,0xd0,0x30,0x08,
+/* 39206 0x9926 "餦" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7f,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x00,0xfc,0x80,0xf8,0x80,0xf8,0x80,0xfe,0x40,0x24,0x28,0x10,0x08,0x44,0x82,0x00,
+/* 39207 0x9927 "餧" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x45,0x7c,0x44,0x7d,0x40,0x50,0x48,0x54,0x64,0x41,
+0x38,0xe0,0x20,0xfc,0x70,0xa8,0x24,0x20,0x40,0xfe,0x48,0x88,0x50,0x20,0x50,0x88,
+/* 39208 0x9928 "館" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x20,0x10,0xfe,0x82,0x04,0x7c,0x44,0x44,0x7c,0x40,0x40,0x7e,0x42,0x42,0x7e,0x42,
+/* 39209 0x9929 "餩" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa3,0x3e,0x22,0x3e,0x20,0x28,0x25,0x2a,0x32,0x21,
+0x20,0x20,0x50,0x88,0x26,0x10,0xfe,0x20,0x44,0xf8,0x12,0x64,0x88,0x18,0x64,0x82,
+/* 39210 0x992a "餪" */
+0x10,0x13,0x28,0x24,0x53,0xfd,0x45,0x7d,0x45,0x7d,0x40,0x53,0x48,0x54,0x65,0x42,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x2c,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 39211 0x992b "餫" */
+0x10,0x13,0x2a,0x24,0x53,0xfc,0x45,0x7d,0x45,0x7d,0x41,0x50,0x4b,0x54,0x64,0x40,
+0x00,0xfe,0x22,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 39212 0x992c "餬" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x44,0x7d,0x45,0x7d,0x41,0x51,0x49,0x54,0x64,0x40,
+0x80,0x9e,0x92,0xd2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 39213 0x992d "餭" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x45,0x7c,0x40,0x50,0x48,0x54,0x65,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 39214 0x992e "餮" */
+0x7f,0x10,0x1e,0x23,0x54,0x09,0x10,0x61,0x06,0x1f,0xe8,0x0f,0x08,0x0f,0x08,0x0c,
+0x20,0x50,0x88,0x46,0x90,0x24,0x48,0x90,0x60,0xf8,0x16,0xf0,0x10,0xf4,0x68,0x1c,
+/* 39215 0x992f "餯" */
+0x10,0x10,0x28,0x24,0x52,0xfd,0x44,0x7c,0x45,0x7c,0x40,0x51,0x48,0x54,0x65,0x40,
+0x40,0x7c,0x84,0xf8,0x08,0xfe,0x40,0xa4,0x38,0x58,0x94,0x34,0x54,0x92,0x50,0x20,
+/* 39216 0x9930 "餰" */
+0x10,0x10,0x29,0x26,0x54,0xf8,0x49,0x7b,0x4d,0x79,0x41,0x51,0x49,0x59,0x69,0x41,
+0x80,0x8e,0x20,0x10,0xc0,0xae,0x04,0x14,0x24,0x64,0x24,0x24,0x24,0x04,0x14,0x08,
+/* 39217 0x9931 "餱" */
+0x10,0x10,0x28,0x25,0x51,0xfb,0x4d,0x79,0x49,0x79,0x41,0x51,0x49,0x59,0x69,0x41,
+0x80,0xbc,0x84,0x08,0xfe,0x20,0x20,0x7c,0x90,0x10,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 39218 0x9932 "餲" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x23,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfe,0x12,0x92,0xaa,0x82,0xfa,0x02,0x14,0x08,
+/* 39219 0x9933 "餳" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x29,0x24,0x2a,0x32,0x20,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0x7e,0xaa,0x2a,0x4a,0x92,0x2a,0x44,
+/* 39220 0x9934 "餴" */
+0x10,0x10,0x2b,0x24,0x50,0xf9,0x4a,0x78,0x48,0x78,0x43,0x50,0x48,0x58,0x69,0x42,
+0x20,0x20,0xfe,0x50,0xa8,0x24,0xfa,0x20,0xa8,0x88,0xfe,0x88,0x88,0x88,0x08,0x08,
+/* 39221 0x9935 "餵" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7d,0x40,0x50,0x48,0x54,0x64,0x40,
+0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfc,0x00,0xfe,0x90,0x94,0x88,0xa8,0xc4,0x82,
+/* 39222 0x9936 "餶" */
+0x10,0x10,0x28,0x24,0x52,0xfd,0x45,0x7c,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x40,
+0x00,0xfc,0x84,0xf4,0x94,0xfe,0x02,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 39223 0x9937 "餷" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x10,0x10,0xfe,0x38,0x54,0x92,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x00,0xfe,0x00,
+/* 39224 0x9938 "餸" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x44,0x7d,0x44,0x7c,0x40,0x50,0x48,0x55,0x66,0x40,
+0x22,0x12,0x14,0x80,0xbe,0x08,0x08,0xbe,0x88,0x88,0x94,0x92,0xa2,0x40,0x3e,0x00,
+/* 39225 0x9939 "餹" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x20,0x10,0xfe,0x90,0xbc,0x94,0xfe,0x94,0xbc,0x90,0xbc,0xa4,0xa4,0xa4,0xbc,0x24,
+/* 39226 0x993a "餺" */
+0x10,0x10,0x2b,0x24,0x53,0xfd,0x45,0x7d,0x45,0x7d,0x40,0x53,0x48,0x54,0x64,0x40,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 39227 0x993b "餻" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x20,
+0x44,0x24,0x28,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0xaa,0xaa,0xaa,0x00,
+/* 39228 0x993c "餼" */
+0x10,0x10,0x28,0x25,0x52,0xfc,0x45,0x7c,0x45,0x7c,0x41,0x50,0x48,0x55,0x64,0x40,
+0x80,0x80,0xfc,0x00,0xf8,0x00,0xf8,0x48,0x68,0xc8,0xf8,0x4a,0xea,0x5a,0x46,0x42,
+/* 39229 0x993d "餽" */
+0x10,0x10,0x29,0x25,0x53,0xfd,0x45,0x7d,0x45,0x7c,0x40,0x50,0x49,0x55,0x66,0x44,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x40,0xb0,0xa4,0x3c,0x22,0x22,0x1e,
+/* 39230 0x993e "餾" */
+0x10,0x13,0x2a,0x26,0x52,0xfa,0x4b,0x78,0x4b,0x7a,0x42,0x53,0x4a,0x5a,0x6b,0x42,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 39231 0x993f "餿" */
+0x10,0x11,0x29,0x25,0x53,0xfd,0x45,0x7d,0x44,0x7d,0x40,0x50,0x48,0x54,0x64,0x43,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 39232 0x9940 "饀" */
+0x10,0x11,0x28,0x25,0x52,0xfc,0x44,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x65,0x41,
+0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xce,0x02,0x02,0xce,0x02,0x02,0x02,0xfe,0x02,
+/* 39233 0x9941 "饁" */
+0x10,0x10,0x28,0x24,0x52,0xfd,0x44,0x7c,0x45,0x7c,0x41,0x51,0x49,0x55,0x67,0x40,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x40,0x84,0xfe,0x02,0xfc,0x54,0x54,0x54,0xfe,0x00,
+/* 39234 0x9942 "饂" */
+0x10,0x10,0x28,0x24,0x52,0xfc,0x44,0x7c,0x44,0x7d,0x41,0x51,0x49,0x55,0x67,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 39235 0x9943 "饃" */
+0x10,0x10,0x2b,0x24,0x52,0xfd,0x45,0x7d,0x45,0x7d,0x40,0x53,0x48,0x54,0x65,0x42,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0xfe,0x50,0x88,0x04,0x02,
+/* 39236 0x9944 "饄" */
+0x10,0x11,0x28,0x27,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x51,0x48,0x54,0x67,0x40,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 39237 0x9945 "饅" */
+0x08,0x08,0x14,0x12,0x29,0x7e,0xa2,0x3e,0x22,0x3e,0x20,0x28,0x24,0x2a,0x32,0x21,
+0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0xaa,0xfe,0x00,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 39238 0x9946 "饆" */
+0x10,0x11,0x29,0x25,0x53,0xfd,0x44,0x7c,0x47,0x7c,0x40,0x51,0x48,0x57,0x64,0x40,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xa8,0xfe,0xa8,0xa8,0xfc,0x20,0xfe,0x20,0x20,
+/* 39239 0x9947 "饇" */
+0x10,0x13,0x2a,0x26,0x52,0xfa,0x4a,0x7a,0x4a,0x7a,0x42,0x52,0x4a,0x5a,0x6b,0x40,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 39240 0x9948 "饈" */
+0x10,0x10,0x29,0x24,0x52,0xfc,0x45,0x7c,0x44,0x7c,0x41,0x50,0x48,0x54,0x65,0x40,
+0x84,0x48,0xfe,0x10,0xfc,0x20,0xfe,0x40,0x7c,0xa4,0x24,0xfc,0x44,0x44,0xfe,0x00,
+/* 39241 0x9949 "饉" */
+0x10,0x10,0x2b,0x24,0x52,0xfc,0x45,0x7d,0x45,0x7c,0x43,0x50,0x49,0x54,0x67,0x40,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 39242 0x994a "饊" */
+0x11,0x11,0x2b,0x25,0x51,0xfb,0x48,0x7b,0x4a,0x7b,0x42,0x53,0x4a,0x5a,0x6a,0x42,
+0x48,0x48,0xe8,0x50,0x5e,0xe4,0x14,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x54,0xe2,
+/* 39243 0x994b "饋" */
+0x10,0x11,0x29,0x25,0x52,0xff,0x44,0x7d,0x45,0x7d,0x41,0x51,0x49,0x55,0x64,0x41,
+0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 39244 0x994c "饌" */
+0x10,0x13,0x2a,0x27,0x52,0xfa,0x49,0x78,0x48,0x7b,0x40,0x50,0x4b,0x58,0x69,0x42,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 39245 0x994d "饍" */
+0x10,0x10,0x2b,0x24,0x51,0xf8,0x4b,0x79,0x48,0x7b,0x40,0x51,0x49,0x59,0x69,0x41,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 39246 0x994e "饎" */
+0x10,0x13,0x28,0x25,0x52,0xfd,0x45,0x7d,0x44,0x7f,0x40,0x51,0x49,0x55,0x65,0x41,
+0x20,0xfe,0x20,0xfc,0x00,0xfc,0x04,0xfc,0x88,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 39247 0x994f "饏" */
+0x3c,0x04,0xff,0x22,0x3e,0x23,0x7e,0x03,0x06,0x1f,0xe8,0x0f,0x08,0x0f,0x08,0x0c,
+0x20,0x3e,0x44,0xa8,0x10,0x28,0x44,0x80,0x60,0xf8,0x16,0xf0,0x10,0xf4,0x68,0x1c,
+/* 39248 0x9950 "饐" */
+0x10,0x13,0x28,0x25,0x50,0xfb,0x4a,0x79,0x48,0x79,0x41,0x51,0x49,0x58,0x6b,0x40,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x02,0xfc,0x00,0xfc,0x04,0xfc,0x04,0x88,0xfe,0x00,
+/* 39249 0x9951 "饑" */
+0x11,0x11,0x2a,0x27,0x51,0xfa,0x4b,0x79,0x4f,0x79,0x41,0x51,0x4a,0x5a,0x6a,0x44,
+0x24,0x24,0xaa,0xae,0x24,0xaa,0xae,0x24,0xfe,0x10,0x14,0x14,0x8a,0x4a,0x16,0x22,
+/* 39250 0x9952 "饒" */
+0x10,0x10,0x29,0x24,0x53,0xf9,0x4b,0x79,0x49,0x7e,0x40,0x53,0x48,0x58,0x69,0x42,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 39251 0x9953 "饓" */
+0x10,0x11,0x28,0x27,0x52,0xfc,0x44,0x7c,0x44,0x7c,0x43,0x50,0x48,0x55,0x66,0x40,
+0x20,0x24,0xa8,0xfe,0x02,0xf8,0x88,0x88,0xf8,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 39252 0x9954 "饔" */
+0x01,0xff,0x10,0x25,0x7b,0x15,0x79,0x11,0xe6,0x1f,0xe8,0x0f,0x08,0x0f,0x08,0x0c,
+0x00,0xfe,0xa0,0xfe,0x20,0xfc,0x20,0xfe,0x60,0xf8,0x16,0xf0,0x10,0xf4,0x68,0x1c,
+/* 39253 0x9955 "饕" */
+0x7c,0x44,0xfe,0x20,0x7c,0x04,0x28,0x11,0x06,0x1f,0xe8,0x0f,0x08,0x0f,0x08,0x0c,
+0x1c,0x10,0xfe,0x92,0xf8,0x94,0xbc,0xaa,0x66,0xf8,0x16,0xf0,0x10,0xf4,0x68,0x1c,
+/* 39254 0x9956 "饖" */
+0x10,0x11,0x29,0x27,0x50,0xf8,0x4b,0x7a,0x4b,0x7a,0x42,0x52,0x4b,0x54,0x68,0x43,
+0x20,0x3c,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 39255 0x9957 "饗" */
+0x11,0x23,0x7a,0x13,0x2a,0x7b,0x12,0x23,0x06,0x1f,0xe8,0x0f,0x08,0x0f,0x08,0x0c,
+0x00,0xde,0x52,0xd4,0x52,0xda,0x94,0xd0,0x60,0xf8,0x16,0xf0,0x10,0xf4,0x68,0x1c,
+/* 39256 0x9958 "饘" */
+0x10,0x11,0x28,0x25,0x53,0xfd,0x45,0x7d,0x44,0x7c,0x40,0x50,0x48,0x54,0x64,0x41,
+0x10,0xfe,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 39257 0x9959 "饙" */
+0x10,0x11,0x28,0x24,0x53,0xfc,0x45,0x7d,0x45,0x7d,0x41,0x51,0x49,0x54,0x65,0x42,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 39258 0x995a "饚" */
+0x10,0x13,0x28,0x24,0x53,0xfc,0x47,0x7c,0x44,0x7d,0x40,0x51,0x49,0x55,0x67,0x40,
+0x88,0xfe,0x88,0x20,0xfc,0x20,0xfe,0x40,0x88,0xfc,0x00,0xfc,0x54,0x54,0xfe,0x00,
+/* 39259 0x995b "饛" */
+0x10,0x13,0x28,0x27,0x52,0xf9,0x48,0x7b,0x48,0x78,0x43,0x50,0x4b,0x58,0x6b,0x40,
+0x88,0xfe,0x88,0xfe,0x02,0xfc,0x00,0xfe,0x40,0xa2,0x54,0xb8,0x54,0x92,0x50,0x20,
+/* 39260 0x995c "饜" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x23,0x26,0x2b,0x22,0x43,0x42,0x83,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0xd4,0xa2,0xf8,0x16,0xf0,0x10,0xf4,0x68,0x1c,
+/* 39261 0x995d "饝" */
+0x10,0x10,0x2b,0x26,0x53,0xfa,0x4a,0x7b,0x4a,0x7b,0x42,0x52,0x4a,0x53,0x64,0x48,
+0x40,0x20,0xfe,0x48,0xfe,0x48,0xec,0x5a,0x48,0xfe,0x20,0x7c,0xc4,0x44,0x7c,0x44,
+/* 39262 0x995e "饞" */
+0x11,0x12,0x2b,0x26,0x53,0xfa,0x4b,0x7a,0x49,0x7a,0x47,0x52,0x4b,0x58,0x69,0x42,
+0xf0,0x10,0xfc,0x04,0xfc,0x24,0xb8,0x22,0xfe,0x10,0xfc,0x44,0xfc,0xd0,0x4a,0x3e,
+/* 39263 0x995f "饟" */
+0x10,0x13,0x28,0x25,0x51,0xf9,0x48,0x7b,0x48,0x7b,0x40,0x53,0x48,0x59,0x6a,0x40,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 39264 0x9960 "饠" */
+0x10,0x13,0x2a,0x26,0x53,0xf9,0x49,0x7a,0x4f,0x79,0x42,0x57,0x48,0x55,0x65,0x40,
+0x00,0xfe,0x52,0x52,0xfe,0x08,0x54,0x5e,0xb4,0x1e,0x54,0xde,0x14,0x54,0x5e,0x10,
+/* 39265 0x9961 "饡" */
+0x15,0x17,0x29,0x27,0x53,0xfd,0x49,0x7b,0x4a,0x7b,0x42,0x53,0x4a,0x5b,0x69,0x42,
+0x28,0xbe,0x48,0xbe,0x18,0xaa,0x46,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x08,0x04,
+/* 39266 0x9962 "饢" */
+0x10,0x17,0x2a,0x27,0x50,0xff,0x4a,0x7b,0x49,0x7b,0x41,0x57,0x49,0x53,0x6d,0x41,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 39267 0x9963 "饣" */
+0x20,0x20,0x20,0x3e,0x44,0x48,0x80,0x10,0x10,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 39268 0x9964 "饤" */
+0x20,0x20,0x20,0x3e,0x44,0x48,0x80,0x10,0x10,0x10,0x10,0x12,0x14,0x18,0x10,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+/* 39269 0x9965 "饥" */
+0x20,0x21,0x21,0x3d,0x45,0x49,0xa1,0x21,0x21,0x21,0x21,0x21,0x29,0x32,0x22,0x04,
+0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x12,0x12,0x0e,0x00,
+/* 39270 0x9966 "饦" */
+0x20,0x20,0x23,0x3c,0x44,0x48,0x80,0x20,0x27,0x20,0x20,0x24,0x28,0x30,0x20,0x00,
+0x10,0x78,0xc0,0x40,0x40,0x40,0x40,0x7e,0xc0,0x40,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 39271 0x9967 "饧" */
+0x20,0x21,0x20,0x3c,0x44,0x48,0xa1,0x20,0x20,0x20,0x21,0x21,0x2a,0x34,0x20,0x01,
+0x00,0xf8,0x10,0x20,0x40,0x80,0xfe,0x92,0x92,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 39272 0x9968 "饨" */
+0x20,0x20,0x20,0x3b,0x48,0x52,0x82,0x22,0x22,0x23,0x20,0x20,0x28,0x30,0x20,0x00,
+0x40,0x40,0x40,0xfc,0x40,0x48,0x48,0x48,0x48,0xf8,0x48,0x40,0x42,0x42,0x3e,0x00,
+/* 39273 0x9969 "饩" */
+0x20,0x20,0x20,0x3d,0x46,0x48,0x80,0x20,0x21,0x20,0x20,0x24,0x28,0x30,0x20,0x00,
+0x80,0x80,0xfc,0x00,0x00,0xf8,0x00,0x00,0xf8,0x08,0x08,0x08,0x0a,0x0a,0x06,0x02,
+/* 39274 0x996a "饪" */
+0x20,0x20,0x21,0x3c,0x44,0x48,0x80,0x23,0x20,0x20,0x20,0x24,0x28,0x30,0x21,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xfc,0x00,
+/* 39275 0x996b "饫" */
+0x20,0x20,0x21,0x3c,0x44,0x48,0x83,0x20,0x20,0x20,0x20,0x24,0x28,0x30,0x21,0x02,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0xfe,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 39276 0x996c "饬" */
+0x20,0x20,0x21,0x39,0x4a,0x54,0x80,0x23,0x20,0x20,0x20,0x20,0x29,0x31,0x22,0x04,
+0x80,0x80,0x00,0xfe,0x00,0x40,0x40,0xfc,0x44,0x44,0x84,0x84,0x04,0x04,0x28,0x10,
+/* 39277 0x996d "饭" */
+0x20,0x20,0x21,0x3d,0x45,0x49,0xa1,0x21,0x21,0x21,0x21,0x21,0x29,0x32,0x22,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 39278 0x996e "饮" */
+0x20,0x20,0x20,0x3e,0x44,0x48,0x81,0x10,0x10,0x10,0x10,0x12,0x14,0x18,0x11,0x02,
+0x40,0x40,0x40,0x7c,0x84,0x88,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 39279 0x996f "饯" */
+0x20,0x20,0x20,0x3c,0x45,0x48,0xa0,0x23,0x20,0x20,0x20,0x20,0x28,0x30,0x23,0x00,
+0x50,0x48,0x40,0x5c,0xe0,0x40,0x5e,0xe0,0x44,0x48,0x30,0x22,0x52,0x8a,0x06,0x02,
+/* 39280 0x9970 "饰" */
+0x20,0x20,0x20,0x3c,0x45,0x4a,0x80,0x21,0x21,0x21,0x21,0x25,0x29,0x31,0x20,0x00,
+0x80,0x80,0x80,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,
+/* 39281 0x9971 "饱" */
+0x20,0x20,0x21,0x39,0x4a,0x55,0x81,0x21,0x21,0x21,0x21,0x21,0x29,0x31,0x20,0x00,
+0x80,0x80,0xfc,0x04,0x04,0xf4,0x14,0x14,0x14,0xf4,0x04,0x28,0x12,0x02,0xfe,0x00,
+/* 39282 0x9972 "饲" */
+0x20,0x23,0x20,0x3c,0x47,0x48,0xa0,0x23,0x22,0x22,0x22,0x23,0x28,0x30,0x20,0x00,
+0x00,0xfc,0x04,0x04,0xf4,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0x14,0x08,
+/* 39283 0x9973 "饳" */
+0x20,0x20,0x21,0x3d,0x45,0x49,0x81,0x20,0x20,0x21,0x21,0x25,0x29,0x31,0x21,0x00,
+0x20,0x20,0x24,0x24,0x24,0x24,0xfc,0x20,0x20,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 39284 0x9974 "饴" */
+0x20,0x20,0x20,0x3c,0x45,0x4b,0x80,0x20,0x21,0x21,0x21,0x25,0x29,0x31,0x21,0x01,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 39285 0x9975 "饵" */
+0x20,0x23,0x21,0x3d,0x45,0x49,0xa1,0x21,0x21,0x21,0x21,0x21,0x2b,0x30,0x20,0x00,
+0x00,0xfe,0x08,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0x1e,0xe8,0x08,0x08,0x08,
+/* 39286 0x9976 "饶" */
+0x20,0x20,0x20,0x3b,0x48,0x50,0x80,0x23,0x20,0x27,0x20,0x20,0x29,0x31,0x22,0x04,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 39287 0x9977 "饷" */
+0x20,0x20,0x20,0x3b,0x4a,0x52,0x82,0x22,0x22,0x22,0x22,0x22,0x2a,0x32,0x22,0x02,
+0x40,0x40,0x80,0xfc,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x04,0x04,0x14,0x08,
+/* 39288 0x9978 "饸" */
+0x20,0x20,0x20,0x3c,0x45,0x4a,0x81,0x20,0x20,0x21,0x21,0x25,0x29,0x31,0x21,0x01,
+0x20,0x20,0x50,0x88,0x04,0x02,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 39289 0x9979 "饹" */
+0x20,0x20,0x20,0x39,0x4b,0x54,0x80,0x20,0x21,0x22,0x25,0x21,0x29,0x31,0x21,0x01,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 39290 0x997a "饺" */
+0x20,0x20,0x20,0x3d,0x44,0x48,0xa1,0x22,0x20,0x20,0x20,0x20,0x28,0x30,0x20,0x03,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 39291 0x997b "饻" */
+0x20,0x20,0x20,0x3b,0x48,0x50,0x80,0x20,0x21,0x22,0x24,0x20,0x28,0x30,0x20,0x00,
+0x40,0x20,0x20,0xfe,0x40,0x40,0xa0,0xa2,0xa4,0x98,0x90,0x88,0x84,0xa2,0xc0,0x80,
+/* 39292 0x997c "饼" */
+0x21,0x20,0x20,0x38,0x4b,0x50,0x80,0x20,0x20,0x27,0x20,0x20,0x29,0x31,0x22,0x04,
+0x04,0x84,0x88,0x00,0xfe,0x88,0x88,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,0x08,0x08,
+/* 39293 0x997d "饽" */
+0x20,0x20,0x23,0x3c,0x44,0x4b,0xa2,0x24,0x21,0x20,0x20,0x23,0x28,0x30,0x20,0x00,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 39294 0x997e "饾" */
+0x20,0x23,0x20,0x3c,0x45,0x49,0x81,0x21,0x21,0x20,0x21,0x24,0x28,0x30,0x27,0x00,
+0x00,0xfc,0x00,0x00,0xf8,0x08,0x08,0x08,0xf8,0x00,0x08,0x88,0x90,0x00,0xfe,0x00,
+/* 39295 0x997f "饿" */
+0x20,0x20,0x23,0x3c,0x44,0x4b,0xa0,0x20,0x20,0x20,0x23,0x20,0x28,0x30,0x22,0x01,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 39296 0x9980 "馀" */
+0x20,0x20,0x20,0x3c,0x45,0x4a,0xa0,0x20,0x23,0x20,0x21,0x21,0x2a,0x34,0x20,0x00,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x28,0x24,0x22,0x22,0xa0,0x40,
+/* 39297 0x9981 "馁" */
+0x20,0x20,0x23,0x38,0x4a,0x51,0x81,0x20,0x23,0x20,0x21,0x23,0x28,0x30,0x21,0x06,
+0x08,0x3c,0xc0,0x44,0x24,0x28,0x00,0x40,0xfe,0x88,0x08,0x90,0x60,0x50,0x88,0x04,
+/* 39298 0x9982 "馂" */
+0x20,0x20,0x20,0x3d,0x47,0x48,0xa0,0x21,0x22,0x20,0x21,0x22,0x28,0x30,0x21,0x06,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 39299 0x9983 "馃" */
+0x20,0x21,0x21,0x3d,0x45,0x49,0x81,0x21,0x20,0x23,0x20,0x24,0x29,0x32,0x20,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 39300 0x9984 "馄" */
+0x20,0x21,0x21,0x3d,0x45,0x49,0xa1,0x21,0x20,0x21,0x21,0x21,0x29,0x31,0x21,0x01,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 39301 0x9985 "馅" */
+0x20,0x20,0x20,0x39,0x4a,0x54,0x80,0x23,0x22,0x22,0x23,0x22,0x2a,0x32,0x23,0x02,
+0x80,0x80,0xf8,0x08,0x10,0x00,0x40,0x9c,0x04,0x04,0x9c,0x04,0x04,0x04,0xfc,0x04,
+/* 39302 0x9986 "馆" */
+0x20,0x20,0x23,0x3a,0x4c,0x51,0x81,0x21,0x21,0x21,0x21,0x21,0x29,0x31,0x21,0x01,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 39303 0x9987 "馇" */
+0x20,0x20,0x27,0x38,0x49,0x52,0x84,0x23,0x22,0x23,0x22,0x23,0x2a,0x30,0x27,0x00,
+0x40,0x40,0xfc,0xe0,0x50,0x48,0x46,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,0xfe,0x00,
+/* 39304 0x9988 "馈" */
+0x20,0x20,0x21,0x3d,0x45,0x48,0x83,0x20,0x21,0x21,0x21,0x25,0x29,0x30,0x20,0x03,
+0x20,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x00,0xfc,0x04,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 39305 0x9989 "馉" */
+0x20,0x21,0x21,0x3d,0x45,0x4b,0x82,0x21,0x21,0x21,0x21,0x25,0x29,0x31,0x21,0x01,
+0x00,0xfc,0x04,0xe4,0x24,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x04,0x14,0x08,
+/* 39306 0x998a "馊" */
+0x20,0x23,0x22,0x3e,0x47,0x4a,0xa2,0x23,0x20,0x23,0x21,0x20,0x28,0x30,0x20,0x07,
+0xa0,0x2e,0x22,0x22,0xae,0x22,0x22,0xfe,0x20,0xfe,0x04,0x88,0x50,0x20,0xd8,0x06,
+/* 39307 0x998b "馋" */
+0x21,0x21,0x22,0x3c,0x4b,0x52,0x82,0x23,0x20,0x21,0x26,0x20,0x28,0x31,0x20,0x00,
+0x00,0xf0,0x10,0x20,0xfc,0x44,0x44,0xfc,0xa0,0x22,0x1e,0xc0,0x30,0x80,0x60,0x10,
+/* 39308 0x998c "馌" */
+0x20,0x20,0x21,0x3c,0x44,0x4b,0xa0,0x21,0x23,0x20,0x23,0x22,0x2a,0x32,0x27,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x80,0x04,0xfe,0x02,0xfc,0x94,0x94,0x94,0xfe,0x00,
+/* 39309 0x998d "馍" */
+0x21,0x21,0x27,0x39,0x48,0x53,0x82,0x23,0x22,0x23,0x20,0x23,0x28,0x31,0x22,0x04,
+0x10,0x10,0xfc,0x10,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xfc,0xa0,0x10,0x08,0x06,
+/* 39310 0x998e "馎" */
+0x20,0x20,0x23,0x3c,0x45,0x49,0xa1,0x21,0x21,0x21,0x20,0x23,0x28,0x30,0x20,0x00,
+0x28,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x24,0x08,0xfe,0x88,0x48,0x48,0x18,
+/* 39311 0x998f "馏" */
+0x20,0x23,0x22,0x3a,0x4a,0x52,0x83,0x20,0x23,0x22,0x22,0x23,0x2a,0x32,0x23,0x02,
+0x40,0xbe,0x12,0x92,0x52,0xaa,0x24,0x40,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 39312 0x9990 "馐" */
+0x22,0x21,0x27,0x38,0x4b,0x50,0x87,0x21,0x23,0x24,0x28,0x23,0x29,0x31,0x27,0x00,
+0x08,0x10,0xfc,0x40,0xf8,0x80,0xfc,0x00,0xf8,0x88,0x88,0xf8,0x08,0x08,0xfe,0x00,
+/* 39313 0x9991 "馑" */
+0x20,0x20,0x23,0x3c,0x44,0x48,0xa1,0x21,0x21,0x20,0x23,0x20,0x29,0x30,0x23,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 39314 0x9992 "馒" */
+0x23,0x22,0x23,0x3a,0x4b,0x50,0x87,0x24,0x24,0x27,0x20,0x23,0x29,0x30,0x23,0x0c,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0xa4,0xa4,0xfc,0x00,0xf8,0x10,0xe0,0x18,0x06,
+/* 39315 0x9993 "馓" */
+0x22,0x22,0x27,0x3a,0x4a,0x57,0x80,0x27,0x24,0x27,0x24,0x27,0x2c,0x34,0x24,0x04,
+0x88,0x88,0xc8,0x90,0x9e,0xd4,0x24,0xd4,0x54,0xd4,0x54,0xc8,0x48,0x54,0x64,0xc2,
+/* 39316 0x9994 "馔" */
+0x20,0x23,0x22,0x3b,0x4a,0x52,0x81,0x20,0x20,0x23,0x20,0x20,0x2b,0x30,0x21,0x02,
+0x00,0xde,0x52,0xde,0x10,0x52,0xce,0x00,0x88,0xfe,0x88,0x88,0xfe,0x88,0x04,0x02,
+/* 39317 0x9995 "馕" */
+0x20,0x27,0x22,0x3b,0x48,0x5f,0x8a,0x23,0x21,0x27,0x21,0x2f,0x29,0x33,0x2d,0x01,
+0x40,0xfc,0x48,0xf8,0x40,0xfe,0xaa,0xb8,0x10,0xfc,0x10,0xfe,0x28,0x10,0x48,0x86,
+/* 39318 0x9996 "首" */
+0x10,0x08,0xff,0x02,0x04,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,0x20,0x3f,0x20,
+0x10,0x20,0xfe,0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 39319 0x9997 "馗" */
+0x21,0x20,0x20,0x23,0xfc,0x25,0x25,0x25,0x25,0x25,0x25,0x25,0x25,0x44,0x43,0x80,
+0x10,0xa0,0x00,0xfc,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfa,0x0a,0x02,0xfe,0x00,
+/* 39320 0x9998 "馘" */
+0x44,0x24,0x28,0xfd,0x10,0x20,0x7d,0x45,0x45,0x7d,0x45,0x7c,0x44,0x47,0x7c,0x44,
+0x14,0x12,0x10,0xfe,0x10,0x10,0xd2,0x52,0x52,0x54,0xd4,0x08,0xca,0x1a,0x26,0x42,
+/* 39321 0x9999 "香" */
+0x00,0x1f,0x01,0x01,0xff,0x05,0x09,0x31,0xdf,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,
+0x70,0x80,0x00,0x00,0xfe,0x40,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 39322 0x999a "馚" */
+0x04,0x78,0x10,0xfe,0x10,0x38,0x55,0x92,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x46,
+0x10,0x50,0x50,0x50,0x88,0x88,0x04,0xfa,0x48,0x48,0x48,0x48,0x88,0x88,0x28,0x10,
+/* 39323 0x999b "馛" */
+0x04,0x78,0x10,0xfe,0x11,0x38,0x54,0x90,0x7c,0x44,0x44,0x7d,0x45,0x46,0x7c,0x44,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 39324 0x999c "馜" */
+0x04,0x78,0x10,0xfe,0x10,0x38,0x54,0x90,0x7c,0x44,0x44,0x7c,0x44,0x45,0x7d,0x46,
+0x00,0xfc,0x84,0x84,0x84,0xfc,0x80,0xa0,0xa4,0xa8,0xb0,0xa0,0xa2,0x22,0x1e,0x00,
+/* 39325 0x999d "馝" */
+0x04,0x78,0x10,0xfe,0x10,0x38,0x54,0x91,0x7d,0x45,0x46,0x7c,0x44,0x45,0x7e,0x44,
+0x40,0x20,0x28,0x08,0x08,0x48,0x54,0x52,0x52,0x60,0x60,0x44,0xc4,0x44,0x3c,0x00,
+/* 39326 0x999e "馞" */
+0x04,0x78,0x11,0xfe,0x10,0x39,0x55,0x92,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7c,0x44,
+0x20,0x20,0xfe,0x20,0x20,0xfe,0x02,0x04,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 39327 0x999f "馟" */
+0x04,0x78,0x11,0xfe,0x11,0x38,0x54,0x91,0x7c,0x44,0x47,0x7c,0x44,0x44,0x7c,0x44,
+0x08,0x3c,0xc0,0x04,0x44,0xa8,0x00,0xf8,0x10,0x20,0xfe,0x20,0x20,0x20,0xa0,0x40,
+/* 39328 0x99a0 "馠" */
+0x04,0x78,0x10,0xfe,0x11,0x3a,0x54,0x90,0x7c,0x44,0x45,0x7d,0x45,0x45,0x7d,0x45,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 39329 0x99a1 "馡" */
+0x04,0x78,0x10,0xfd,0x10,0x38,0x54,0x91,0x7c,0x44,0x44,0x7d,0x44,0x44,0x7c,0x44,
+0x48,0x48,0x48,0xce,0x48,0x48,0x48,0xce,0x48,0x48,0x48,0xce,0x48,0x48,0x48,0x48,
+/* 39330 0x99a2 "馢" */
+0x04,0x78,0x10,0xfd,0x10,0x38,0x54,0x91,0x7c,0x44,0x45,0x7c,0x44,0x44,0x7c,0x45,
+0x48,0x44,0x5e,0xe0,0x28,0x12,0x6a,0x96,0x48,0x5e,0xe0,0x24,0x28,0x12,0x6a,0x86,
+/* 39331 0x99a3 "馣" */
+0x04,0x78,0x11,0xfe,0x10,0x39,0x54,0x90,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x20,0xfe,0x50,0xa8,0x26,0xf8,0xa8,0xa8,0xf8,0xa8,0xa8,0xf8,0xaa,0x22,0x1e,
+/* 39332 0x99a4 "馤" */
+0x04,0x79,0x11,0xfd,0x11,0x39,0x54,0x91,0x7e,0x45,0x45,0x7d,0x45,0x44,0x7c,0x44,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 39333 0x99a5 "馥" */
+0x04,0x78,0x10,0xfe,0x11,0x3a,0x54,0x90,0x7c,0x44,0x44,0x7c,0x45,0x44,0x7c,0x45,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 39334 0x99a6 "馦" */
+0x04,0x78,0x10,0xfd,0x10,0x39,0x54,0x93,0x7c,0x45,0x44,0x7c,0x45,0x46,0x7c,0x44,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 39335 0x99a7 "馧" */
+0x04,0x78,0x10,0xfe,0x10,0x38,0x54,0x90,0x7c,0x45,0x45,0x7d,0x45,0x45,0x7f,0x44,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 39336 0x99a8 "馨" */
+0x08,0xff,0x08,0x3e,0x2a,0x3e,0x40,0x9f,0x01,0x7f,0x09,0x3f,0xc8,0x0f,0x08,0x0f,
+0x78,0x48,0x86,0x78,0x48,0x30,0x48,0xe4,0x00,0xfc,0x20,0xf8,0x26,0xe0,0x20,0xe0,
+/* 39337 0x99a9 "馩" */
+0x04,0x79,0x10,0xfc,0x13,0x38,0x55,0x91,0x7d,0x45,0x45,0x7d,0x45,0x44,0x7d,0x46,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 39338 0x99aa "馪" */
+0x04,0x78,0x11,0xff,0x10,0x38,0x55,0x90,0x7d,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+0x20,0x10,0xfe,0x02,0xfc,0xa8,0x30,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 39339 0x99ab "馫" */
+0x1f,0x01,0x7f,0x09,0x3f,0xc8,0x0f,0x08,0x7f,0x10,0xfe,0x54,0x92,0x7c,0x44,0x7c,
+0xe0,0x00,0xfc,0x20,0xf8,0x26,0xe0,0x24,0xf8,0x10,0xfe,0x54,0x92,0x7c,0x44,0x7c,
+/* 39340 0x99ac "馬" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x21,0x3f,0x00,0x12,0x49,0x49,0x80,0x00,0x00,
+0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0x00,0xf8,0x08,0x48,0x28,0x28,0x08,0x50,0x20,
+/* 39341 0x99ad "馭" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x00,0x7c,0x24,0x24,0x24,0x24,0x28,0xa8,0xa8,0x90,0x90,0xa8,0xa8,0x44,0x82,
+/* 39342 0x99ae "馮" */
+0x00,0x43,0x22,0x23,0x02,0x0b,0x0a,0x12,0x13,0xe0,0x25,0x25,0x25,0x24,0x20,0x00,
+0x00,0xfc,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x04,0x54,0x54,0x54,0x04,0x28,0x10,
+/* 39343 0x99af "馯" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x7e,0x90,0x90,0x90,0x90,0x90,0x90,0x10,0x10,
+/* 39344 0x99b0 "馰" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x10,0x3c,0x24,0x44,0x04,0x24,0x94,0x94,0x84,0x84,0x84,0x84,0x28,0x10,
+/* 39345 0x99b1 "馱" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0x90,0xa8,0xa8,0xa8,0xa8,0xc4,0x44,0x82,
+/* 39346 0x99b2 "馲" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x1c,0x70,0x10,0x10,0x10,0x10,0x1e,0xf0,0x90,0x90,0x92,0x92,0x92,0x0e,0x00,
+/* 39347 0x99b3 "馳" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x49,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x20,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xa4,0xb4,0xa8,0xa2,0xa2,0x82,0x7e,0x00,
+/* 39348 0x99b4 "馴" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x02,0x22,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0x42,0x82,
+/* 39349 0x99b5 "馵" */
+0x3f,0x21,0x3f,0x21,0x3f,0x21,0x3f,0x49,0x84,0x08,0x08,0xff,0x08,0x10,0x20,0x40,
+0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x24,0x94,0x28,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 39350 0x99b6 "馶" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 39351 0x99b7 "馷" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x08,0x08,0x3e,0x08,0x08,0x3e,0x2a,0xaa,0xaa,0xaa,0xaa,0xae,0x88,0x08,0x08,
+/* 39352 0x99b8 "馸" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x0c,0x30,0x20,0x20,0x20,0x3e,0x24,0xa4,0xa4,0xa4,0xa4,0xa4,0xa4,0x44,0x84,
+/* 39353 0x99b9 "馹" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3e,0x22,0x22,0x22,0x22,0x22,0x3e,0xa2,0xa2,0xa2,0xa2,0xa2,0xbe,0x22,0x00,
+/* 39354 0x99ba "馺" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x00,0xfc,0x44,0x48,0x48,0x50,0x5c,0x44,0x44,0x44,0x68,0xa8,0x90,0x98,0x24,0x42,
+/* 39355 0x99bb "馻" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x20,0x28,0x44,0x7c,0x04,0x28,0xa8,0xa8,0xa8,0xa8,0xaa,0xca,0x46,0x80,
+/* 39356 0x99bc "馼" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0x10,0xfe,0x44,0x44,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 39357 0x99bd "馽" */
+0x3f,0x21,0x3f,0x21,0x3f,0x21,0x3f,0x49,0x84,0x01,0x3f,0x21,0x21,0x3f,0x01,0x01,
+0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x24,0x94,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,
+/* 39358 0x99be "馾" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 39359 0x99bf "馿" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x08,0x00,0x3e,0x22,0x22,0x22,0x3e,0xa2,0xa0,0xa0,0xa0,0xa0,0xa0,0x40,0x80,
+/* 39360 0x99c0 "駀" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x48,0x44,0x44,0x40,0xfe,0x50,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 39361 0x99c1 "駁" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x02,0x22,0x14,0x08,0x14,0x22,0x42,0x00,0xa2,0xa2,0x94,0x94,0x88,0x94,0x24,0x42,
+/* 39362 0x99c2 "駂" */
+0x40,0x49,0x51,0x61,0x45,0x45,0x3d,0x11,0x11,0x11,0xfc,0x12,0x12,0x12,0x10,0x10,
+0x00,0xfc,0x20,0x20,0xfc,0x20,0xfc,0x20,0x20,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 39363 0x99c3 "駃" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x10,0x10,0x7c,0x14,0x14,0x14,0x94,0xfe,0x90,0x90,0xa8,0xa8,0x44,0x82,
+/* 39364 0x99c4 "駄" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x30,0x50,0x50,0x48,0x48,0xc8,0xa4,0x24,0x02,
+/* 39365 0x99c5 "駅" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x54,0x50,0x50,0x48,0x48,0x48,0x84,0x84,0x02,
+/* 39366 0x99c6 "駆" */
+0x00,0x7d,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x85,0x15,0x08,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 39367 0x99c7 "駇" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x10,0x20,0x3e,0x44,0xa4,0x24,0xa8,0xa8,0x90,0x90,0xa8,0xa8,0x44,0x82,
+/* 39368 0x99c8 "駈" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x08,0x1c,0x60,0x40,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 39369 0x99c9 "駉" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x82,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xaa,0xba,0xaa,0x82,0x82,0x8a,0x84,
+/* 39370 0x99ca "駊" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x83,0x15,0x0a,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 39371 0x99cb "駋" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x7e,0x12,0x12,0x12,0x22,0x2a,0x44,0x80,0xbe,0xa2,0xa2,0xa2,0xa2,0x3e,0x22,
+/* 39372 0x99cc "駌" */
+0x10,0x3e,0x42,0xa2,0x14,0x18,0xe0,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x2a,0x49,
+0x00,0xf8,0x88,0xaa,0x92,0x7e,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x44,0x2c,
+/* 39373 0x99cd "駍" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x7c,0x10,0x10,0x54,0x34,0x38,0x10,0xfe,0x90,0x90,0x90,0x90,0x90,0x10,0x10,
+/* 39374 0x99ce "駎" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x08,0x08,0x08,0x3e,0x2a,0x2a,0x2a,0xaa,0xbe,0xaa,0xaa,0xaa,0xaa,0x3e,0x22,
+/* 39375 0x99cf "駏" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3e,0x20,0x20,0x20,0x3e,0x22,0x22,0xa2,0xa2,0xbe,0xa0,0xa0,0xa0,0x3e,0x00,
+/* 39376 0x99d0 "駐" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x08,0x00,0x3e,0x08,0x08,0x08,0x08,0xbe,0x88,0x88,0x88,0x88,0x88,0x7e,0x00,
+/* 39377 0x99d1 "駑" */
+0x08,0x7f,0x11,0x32,0x0c,0x12,0x61,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x2a,0x49,
+0x00,0x7c,0x44,0x28,0x10,0x28,0x46,0xf0,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x44,0x2c,
+/* 39378 0x99d2 "駒" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x20,0x20,0x20,0x7e,0x42,0x82,0x3a,0x2a,0xaa,0xaa,0xba,0xaa,0x82,0x82,0x14,0x08,
+/* 39379 0x99d3 "駓" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3e,0x08,0x08,0x08,0x18,0x1c,0x2a,0xaa,0xca,0x88,0x88,0x88,0x80,0x3e,0x00,
+/* 39380 0x99d4 "駔" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0xa4,0xbc,0xa4,0xa4,0xa4,0xa4,0x7e,0x00,
+/* 39381 0x99d5 "駕" */
+0x10,0x10,0x7e,0x12,0x22,0x2a,0x44,0x9f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x2a,0x49,
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x44,0x2c,
+/* 39382 0x99d6 "駖" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x28,0x28,0x44,0x92,0x08,0x00,0xbc,0x84,0x88,0xa8,0x90,0x88,0x04,0x00,
+/* 39383 0x99d7 "駗" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x28,0x28,0x44,0x92,0x20,0x40,0x88,0x90,0xa0,0x84,0x88,0x90,0x20,0x40,
+/* 39384 0x99d8 "駘" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x08,0x10,0x10,0x24,0x7e,0x22,0x00,0xbc,0xa4,0xa4,0xa4,0xa4,0xa4,0x3c,0x24,
+/* 39385 0x99d9 "駙" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x48,0x48,0x48,0x88,0xfe,0x88,0x88,0x88,0xc8,0xa8,0xa8,0x88,0x88,0x88,0xa8,0x90,
+/* 39386 0x99da "駚" */
+0x00,0x7c,0x50,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x07,0x54,0x54,0x54,0x84,0x15,0x0a,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0xfe,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 39387 0x99db "駛" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x08,0x08,0x3e,0x2a,0x2a,0x2a,0x2a,0xbe,0x88,0xc8,0xa8,0x90,0x98,0x24,0x42,
+/* 39388 0x99dc "駜" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xab,0xaa,0xaa,0x82,0x15,0x08,
+0x10,0x08,0x08,0x02,0x22,0x24,0x24,0xa8,0xac,0xb2,0x32,0x20,0x62,0xa2,0x1e,0x00,
+/* 39389 0x99dd "駝" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x08,0x08,0x7e,0x42,0x42,0x20,0x24,0xa8,0xb0,0xa0,0xa2,0xa2,0xa2,0x1e,0x00,
+/* 39390 0x99de "駞" */
+0x00,0x7c,0x50,0x7c,0x51,0x7c,0x50,0x50,0x7d,0x04,0x54,0x54,0x54,0x84,0x14,0x08,
+0x40,0x40,0x7e,0x80,0x20,0xa0,0xac,0xb4,0xe4,0xa4,0xb4,0xa8,0xa2,0x82,0x7e,0x00,
+/* 39391 0x99df "駟" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0x82,0xfe,0x82,
+/* 39392 0x99e0 "駠" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x20,0xce,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xea,0xac,0x28,0x48,0x48,0x88,
+/* 39393 0x99e1 "駡" */
+0x00,0x3e,0x22,0x3e,0x00,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x00,0x29,0x44,0x00,
+0x00,0xf8,0x88,0xf8,0x00,0xf8,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x04,0x24,0x94,0x08,
+/* 39394 0x99e2 "駢" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7f,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 39395 0x99e3 "駣" */
+0x00,0x7e,0x48,0x7f,0x48,0x7e,0x48,0x48,0x7e,0x03,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 39396 0x99e4 "駤" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x7e,0x10,0x10,0x24,0x22,0x7e,0x0a,0x88,0x88,0xbe,0x88,0x88,0x88,0x7e,0x00,
+/* 39397 0x99e5 "駥" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x14,0x12,0x12,0x10,0xfe,0x10,0x52,0x52,0x52,0xf4,0x54,0x54,0x8a,0x8a,0x16,0x22,
+/* 39398 0x99e6 "駦" */
+0x11,0x09,0x7f,0x02,0xff,0x08,0x30,0xdf,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x2a,0x49,
+0x10,0x20,0xfc,0x00,0xfe,0x20,0x18,0xf6,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x44,0x2c,
+/* 39399 0x99e7 "駧" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x82,0x82,0xba,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x84,
+/* 39400 0x99e8 "駨" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x10,0x10,0x10,0x3e,0x22,0x42,0x3a,0x2a,0xaa,0xba,0xaa,0xaa,0xba,0x82,0x14,0x08,
+/* 39401 0x99e9 "駩" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x08,0x08,0x14,0x14,0x22,0x40,0x3e,0x08,0x88,0x88,0xbe,0x88,0x88,0x88,0x7e,0x00,
+/* 39402 0x99ea "駪" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x28,0x28,0x28,0x28,0x4a,0x4a,0x86,0x00,
+/* 39403 0x99eb "駫" */
+0x00,0x7e,0x49,0x7e,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 39404 0x99ec "駬" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x7e,0x24,0x24,0x24,0x3c,0x24,0x24,0xbc,0xa4,0xa4,0xae,0xf4,0x84,0x04,0x04,
+/* 39405 0x99ed "駭" */
+0x00,0x7c,0x50,0x7d,0x50,0x7c,0x50,0x50,0x7c,0x04,0x54,0x55,0x54,0x84,0x14,0x09,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 39406 0x99ee "駮" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x49,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x82,0x00,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 39407 0x99ef "駯" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x50,0x50,0x7c,0x90,0x10,0x10,0xfe,0x10,0x38,0x38,0x54,0x54,0x92,0x10,0x10,
+/* 39408 0x99f0 "駰" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x82,0x92,0x92,0x92,0xfe,0x92,0x92,0xaa,0xa6,0xc6,0x82,0x82,0xfe,0x82,
+/* 39409 0x99f1 "駱" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7f,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 39410 0x99f2 "駲" */
+0x00,0x7c,0x50,0x7c,0x50,0x7c,0x52,0x52,0x7c,0x04,0x54,0x54,0x54,0x85,0x15,0x0a,
+0x82,0x92,0x92,0x92,0x92,0x92,0xda,0xb6,0x92,0x92,0x92,0x92,0x92,0x12,0x02,0x02,
+/* 39411 0x99f3 "駳" */
+0x00,0xf8,0xa3,0xf8,0xa0,0xf9,0xa1,0xa3,0xf8,0x0a,0xaa,0xa9,0xa9,0x8a,0x0c,0x38,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 39412 0x99f4 "駴" */
+0x00,0xf8,0xa0,0xf8,0xa3,0xf8,0xa1,0xa1,0xff,0x09,0xa9,0xa9,0xaa,0x8a,0x0c,0x30,
+0x10,0x14,0x12,0x10,0xfe,0x10,0x50,0x54,0xf4,0x54,0x54,0x48,0x4a,0x5a,0x26,0x42,
+/* 39413 0x99f5 "駵" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x28,0x28,0x28,0xee,0xaa,0xaa,0xaa,0xaa,0xee,0x28,0x28,0x28,0x48,0x88,
+/* 39414 0x99f6 "駶" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0xfc,0x84,0x84,0xfc,0x80,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x82,0x94,0x08,
+/* 39415 0x99f7 "駷" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x83,0x14,0x08,
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 39416 0x99f8 "駸" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x49,0x7f,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0xfc,0x04,0x7c,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x44,0x44,0x28,0x10,0x68,0x86,
+/* 39417 0x99f9 "駹" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x48,0x44,0x40,0xfe,0x50,0x54,0x58,0x52,0x54,0x58,0x52,0x54,0x9a,0x92,0x2e,0x40,
+/* 39418 0x99fa "駺" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 39419 0x99fb "駻" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x00,0xbe,0x88,0x88,0xfe,0x88,0x88,0x08,0x08,
+/* 39420 0x99fc "駼" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x83,0x14,0x08,
+0x10,0x10,0x28,0x28,0x44,0xba,0x10,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x20,
+/* 39421 0x99fd "駽" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x3e,0x22,0xa2,0xbe,0xa2,0xbe,0xa2,0xa2,0x2a,0x24,
+/* 39422 0x99fe "駾" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x84,0x44,0x48,0x00,0xfc,0x84,0x84,0x84,0xfc,0x48,0x48,0x48,0x48,0x8a,0x8a,0x06,
+/* 39423 0x99ff "駿" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 39424 0x9a00 "騀" */
+0x00,0xf8,0xa3,0xf8,0xa0,0xfb,0xa0,0xa0,0xf8,0x08,0xab,0xa8,0xa8,0x88,0x0a,0x31,
+0x10,0xd8,0x94,0x94,0x90,0xfe,0x90,0x94,0x94,0xd8,0x98,0x90,0xaa,0xca,0x86,0x02,
+/* 39425 0x9a01 "騁" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7f,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0xfc,0x94,0xfc,0x94,0xfc,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 39426 0x9a02 "騂" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x20,0x10,0x10,0x7c,0x00,0x28,0x10,0xfe,0x90,0x90,0xfc,0x90,0x90,0x90,0x10,0x10,
+/* 39427 0x9a03 "騃" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x10,0x20,0x44,0x82,0xfe,0x00,0x40,0x7e,0x90,0x10,0xfe,0x10,0x28,0x44,0x82,0x00,
+/* 39428 0x9a04 "騄" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfc,0x04,0x04,0x7c,0x04,0x04,0xfe,0x10,0x92,0x54,0x38,0x54,0x92,0x50,0x20,
+/* 39429 0x9a05 "騅" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 39430 0x9a06 "騆" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0xfe,0x92,0x92,0xba,0x92,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x04,
+/* 39431 0x9a07 "騇" */
+0x00,0xf8,0xa0,0xf8,0xa1,0xfa,0xa0,0xa0,0xfb,0x08,0xa8,0xa9,0xa9,0x89,0x09,0x31,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x20,0xfc,0x04,0x04,0xfc,0x04,
+/* 39432 0x9a08 "騈" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x22,0x22,0x44,0xee,0x44,0x44,0x44,0x44,0xee,0x44,0x44,0x44,0x44,0x44,0x44,0x84,
+/* 39433 0x9a09 "騉" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x90,0x92,0xf4,0x98,0x92,0xd2,0x8e,
+/* 39434 0x9a0a "騊" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x40,0x40,0xfe,0x82,0x42,0x7a,0xa2,0x22,0xfa,0x22,0xaa,0xaa,0xfa,0x02,0x14,0x08,
+/* 39435 0x9a0b "騋" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0xba,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 39436 0x9a0c "騌" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0xfe,0x82,0x00,0x7c,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 39437 0x9a0d "騍" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,
+/* 39438 0x9a0e "騎" */
+0x00,0x7e,0x49,0x7e,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x20,0xfc,0x20,0x50,0x88,0xfe,0x08,0xe8,0xa8,0xa8,0xe8,0xa8,0x08,0x28,0x10,
+/* 39439 0x9a0f "騏" */
+0x00,0x7f,0x48,0x7f,0x48,0x7f,0x48,0x48,0x7f,0x00,0xaa,0xaa,0xaa,0x80,0x05,0x02,
+0x24,0x24,0x7e,0x24,0x24,0x3c,0x24,0x24,0xbc,0xa4,0xa4,0xfe,0x80,0xa4,0x22,0x42,
+/* 39440 0x9a10 "騐" */
+0x00,0xf8,0xa0,0xf8,0xa1,0xfa,0xa1,0xa0,0xf8,0x08,0xa8,0xaa,0xaa,0x8a,0x0c,0x30,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 39441 0x9a11 "騑" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x28,0x28,0x28,0xee,0x28,0x28,0x28,0xee,0x28,0x28,0x28,0xee,0x28,0x28,0x28,0x28,
+/* 39442 0x9a12 "騒" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x00,0xfc,0x44,0x28,0x10,0x68,0x96,0x10,0xfe,0x92,0x92,0xfe,0x10,0x14,0xfe,0x82,
+/* 39443 0x9a13 "験" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 39444 0x9a14 "騔" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7f,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfe,0x12,0x92,0xaa,0x82,0xfa,0x02,0x14,0x08,
+/* 39445 0x9a15 "騕" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x03,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xfe,0x10,0xfe,0x24,0x44,0x68,0x18,0x64,0x82,
+/* 39446 0x9a16 "騖" */
+0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x2a,0x49,
+0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0xf0,0x00,0xf0,0x00,0xf0,0x00,0xfc,0x44,0x2c,
+/* 39447 0x9a17 "騗" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x40,0x7f,0x55,0x55,0x7f,0xd5,0x55,0x55,0x43,
+0x00,0x7c,0x50,0x7c,0x50,0x7c,0x50,0x50,0x7c,0x04,0x54,0x54,0x54,0x84,0x14,0x08,
+/* 39448 0x9a18 "騘" */
+0x00,0x7e,0x48,0x7e,0x49,0x7e,0x48,0x49,0x7e,0x02,0xaa,0xaa,0xab,0x82,0x14,0x08,
+0x40,0x40,0x7e,0xaa,0x6a,0x5a,0x96,0x22,0x4a,0x84,0x20,0x94,0x42,0x44,0x3c,0x00,
+/* 39449 0x9a19 "騙" */
+0x00,0x7c,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x56,0x56,0x54,0x84,0x14,0x08,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 39450 0x9a1a "騚" */
+0x00,0x7c,0x50,0x7d,0x50,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x85,0x15,0x09,
+0x84,0x44,0x48,0xfe,0x00,0xe2,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x2a,0x22,0x2a,0x64,
+/* 39451 0x9a1b "騛" */
+0x00,0x7d,0x50,0x7c,0x51,0x7c,0x50,0x50,0x7d,0x04,0x54,0x54,0x54,0x85,0x15,0x0a,
+0x00,0xfa,0x0c,0x4a,0x88,0xaa,0xa6,0xa2,0xf8,0xaa,0xac,0xaa,0xa8,0x2a,0x26,0x22,
+/* 39452 0x9a1c "騜" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 39453 0x9a1d "騝" */
+0x00,0xf8,0xa0,0xfb,0xa0,0xf8,0xa1,0xa1,0xfb,0x08,0xa8,0xaa,0xa9,0x89,0x0a,0x34,
+0x10,0x10,0x3c,0x94,0xfe,0x94,0x3c,0x10,0xbc,0x90,0xfe,0x90,0x10,0x80,0x7e,0x00,
+/* 39454 0x9a1e "騞" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xab,0x82,0x14,0x08,
+0x10,0x10,0xfe,0x10,0xfc,0x10,0xfe,0x10,0xfe,0x20,0x40,0xfc,0x44,0x44,0x7c,0x44,
+/* 39455 0x9a1f "騟" */
+0x00,0x7c,0x50,0x7d,0x52,0x7c,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x85,0x15,0x09,
+0x20,0x50,0x88,0x04,0xfa,0x00,0xe2,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x22,0x2a,0x64,
+/* 39456 0x9a20 "騠" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x03,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x20,0xa0,0xbc,0xa0,0x60,0x3e,
+/* 39457 0x9a21 "騡" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x10,0x20,0xfe,0x82,0xfe,0x82,0xfe,0x10,0x12,0xd4,0x58,0x54,0x94,0x92,0x50,0x20,
+/* 39458 0x9a22 "騢" */
+0x00,0x7d,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x85,0x15,0x09,
+0x00,0xdc,0x44,0x44,0x44,0xdc,0x00,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 39459 0x9a23 "騣" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x28,0x92,0xaa,0x82,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 39460 0x9a24 "騤" */
+0x00,0x7e,0x48,0x7f,0x48,0x7e,0x49,0x48,0x7e,0x02,0xab,0xaa,0xaa,0x82,0x14,0x09,
+0x10,0xd4,0x48,0x4a,0x84,0x84,0x02,0xf8,0x20,0x20,0xfc,0x20,0x50,0x48,0x84,0x04,
+/* 39461 0x9a25 "騥" */
+0x00,0x7c,0x50,0x7c,0x51,0x7c,0x50,0x51,0x7e,0x04,0x55,0x54,0x54,0x85,0x16,0x08,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 39462 0x9a26 "騦" */
+0x00,0x7d,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7c,0x04,0x54,0x55,0x55,0x85,0x16,0x08,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 39463 0x9a27 "騧" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x7c,0x44,0x44,0x74,0x54,0x54,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x8a,0x84,
+/* 39464 0x9a28 "騨" */
+0x02,0x7d,0x50,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x54,0x54,0x57,0x84,0x14,0x08,
+0x42,0x24,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 39465 0x9a29 "騩" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x09,
+0x10,0x20,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x20,0x24,0x5a,0x5e,0x90,0x92,0x0e,
+/* 39466 0x9a2a "騪" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x50,0x96,0x92,0x92,0xd6,0x92,0x92,0xfe,0x10,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 39467 0x9a2b "騫" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x09,0x1f,0x29,0xcf,0x09,0x0f,0x00,0x15,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x08,0xe6,0x00,0xf8,0x08,0x58,
+/* 39468 0x9a2c "騬" */
+0x00,0xf9,0xa0,0xfb,0xa0,0xf8,0xa3,0xa0,0xf9,0x0a,0xa8,0xa8,0xa9,0x8a,0x0c,0x30,
+0x1c,0xe0,0x20,0xfe,0xa8,0xaa,0xac,0xaa,0xaa,0xa6,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 39469 0x9a2d "騭" */
+0x00,0x79,0x49,0x53,0x48,0x6b,0x50,0x43,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x29,0x44,
+0x20,0x3c,0x20,0xfe,0xa4,0x28,0x70,0x80,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x22,0x96,
+/* 39470 0x9a2e "騮" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 39471 0x9a2f "騯" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0xa2,0x10,0xfe,0x20,0x3c,0x24,0x44,0x54,0x88,
+/* 39472 0x9a30 "騰" */
+0x01,0x78,0x49,0x48,0x4b,0x79,0x4b,0x4d,0x49,0x79,0x49,0x49,0x49,0x48,0x4a,0x98,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0xfc,0x22,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xaa,0x04,
+/* 39473 0x9a31 "騱" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x44,0x82,
+/* 39474 0x9a32 "騲" */
+0x00,0x7c,0x53,0x7c,0x50,0x7d,0x51,0x51,0x7d,0x05,0x55,0x54,0x57,0x84,0x14,0x08,
+0x88,0x88,0xfe,0x88,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x24,0x20,0xfe,0x20,0x20,0x20,
+/* 39475 0x9a33 "騳" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+/* 39476 0x9a34 "騴" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x82,0x20,0xfe,0x44,0x68,0x10,0x28,0x44,
+/* 39477 0x9a35 "騵" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x0a,
+0x00,0xfe,0x88,0x90,0xbe,0xa2,0xbe,0xa2,0xbe,0x88,0xac,0xaa,0xca,0x8a,0x28,0x10,
+/* 39478 0x9a36 "騶" */
+0x00,0x7e,0x48,0x7f,0x48,0x7e,0x48,0x48,0x7f,0x02,0xab,0xaa,0xaa,0x82,0x14,0x09,
+0x40,0x40,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x48,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x08,
+/* 39479 0x9a37 "騷" */
+0x00,0x7d,0x50,0x7c,0x50,0x7c,0x50,0x53,0x7c,0x05,0x55,0x55,0x55,0x84,0x17,0x08,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 39480 0x9a38 "騸" */
+0x00,0x7c,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x86,0x16,0x0c,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x66,
+/* 39481 0x9a39 "騹" */
+0x00,0x7c,0x53,0x7c,0x50,0x7c,0x51,0x51,0x7d,0x04,0x55,0x54,0x55,0x84,0x17,0x08,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 39482 0x9a3a "騺" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x08,0x3f,0x21,0x3f,0x21,0x3f,0x29,0x44,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xf8,0x00,0xf8,0x00,0xfe,0x22,0x96,
+/* 39483 0x9a3b "騻" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x10,0xfe,0x10,0xba,0x54,0xba,0x10,0xba,0x54,0xba,0x10,0x28,0x28,0x44,0x82,
+/* 39484 0x9a3c "騼" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xab,0x82,0x14,0x08,
+0x20,0x10,0xfe,0xa8,0xa8,0xfe,0xaa,0xaa,0xfe,0x80,0xca,0xec,0x48,0x4a,0x6a,0x46,
+/* 39485 0x9a3d "騽" */
+0x00,0x7d,0x50,0x7d,0x50,0x7d,0x50,0x50,0x7c,0x04,0x54,0x54,0x54,0x84,0x14,0x08,
+0x00,0xde,0x42,0x52,0xca,0x52,0x42,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 39486 0x9a3e "騾" */
+0x00,0x7d,0x51,0x7d,0x51,0x7d,0x50,0x50,0x7d,0x04,0x54,0x57,0x54,0x85,0x16,0x08,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 39487 0x9a3f "騿" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 39488 0x9a40 "驀" */
+0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0xff,0x08,0x3f,0xd1,0x1f,0x11,0x1f,0x2a,0x45,
+0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfe,0x20,0xf8,0x06,0xf0,0x00,0xfc,0x44,0x2c,
+/* 39489 0x9a41 "驁" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x7f,0xa1,0x3f,0x21,0x3f,0x29,0x44,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0xfa,0x00,0xf8,0x00,0xfe,0x22,0x96,
+/* 39490 0x9a42 "驂" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0x20,0x44,0xfe,0x44,0xaa,0xee,0x10,0x28,0x54,0xaa,0x50,0x24,0x48,0x10,0x60,
+/* 39491 0x9a43 "驃" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x28,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x20,
+/* 39492 0x9a44 "驄" */
+0x00,0x7c,0x51,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x54,0x54,0x55,0x85,0x15,0x0a,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 39493 0x9a45 "驅" */
+0x00,0xfb,0xa2,0xfa,0xa2,0xfa,0xa2,0xa2,0xfa,0x0a,0xaa,0xaa,0xaa,0x8a,0x0b,0x30,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 39494 0x9a46 "驆" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x92,0xfe,0x92,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0xfe,0x10,0x10,
+/* 39495 0x9a47 "驇" */
+0x08,0x3e,0x08,0x7f,0x2a,0x5d,0x08,0x3e,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x29,0x44,
+0x20,0x20,0xf8,0x28,0x68,0x2a,0x56,0x82,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x22,0x96,
+/* 39496 0x9a48 "驈" */
+0x00,0x7e,0x48,0x7f,0x48,0x7e,0x49,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0xfc,0x28,0x10,0xfe,0x52,0x94,0x50,0x20,0xfe,0xaa,0xc6,0xba,0xaa,0xba,0x82,0x86,
+/* 39497 0x9a49 "驉" */
+0x00,0x7c,0x50,0x7d,0x51,0x7d,0x51,0x51,0x7d,0x05,0x55,0x55,0x55,0x86,0x14,0x08,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x00,0x28,0xaa,0x6c,0x28,0x28,0xfe,0x00,
+/* 39498 0x9a4a "驊" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x44,0xfe,0x44,0x00,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0xfe,0x10,0x10,0x10,
+/* 39499 0x9a4b "驋" */
+0x00,0xfb,0xa0,0xfd,0xa2,0xfc,0xa3,0xa0,0xf8,0x0b,0xaa,0xab,0xa8,0x88,0x0a,0x31,
+0x24,0xa8,0x92,0x14,0x08,0x04,0xba,0xa8,0xc6,0x80,0x3c,0x84,0xa8,0x90,0xa8,0x44,
+/* 39500 0x9a4c "驌" */
+0x00,0xf9,0xa0,0xfb,0xa0,0xf9,0xa0,0xa2,0xfb,0x0a,0xab,0xaa,0xab,0x8a,0x0a,0x34,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 39501 0x9a4d "驍" */
+0x00,0xf8,0xa1,0xf8,0xa3,0xf9,0xa3,0xa1,0xf9,0x0e,0xa8,0xab,0xa8,0x88,0x09,0x32,
+0x20,0x20,0xfc,0x20,0xfe,0x08,0x9c,0x08,0x88,0x3e,0x00,0xfe,0x90,0x90,0x12,0x0e,
+/* 39502 0x9a4e "驎" */
+0x00,0xf9,0xa0,0xfb,0xa0,0xf9,0xa2,0xa1,0xf9,0x09,0xaa,0xad,0xa8,0x89,0x0a,0x34,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 39503 0x9a4f "驏" */
+0x03,0xfa,0xa3,0xfa,0xa2,0xfa,0xa3,0xa2,0xfa,0x0b,0xaa,0xaa,0xac,0x8f,0x08,0x31,
+0xfe,0x02,0xfe,0x00,0xfc,0x08,0xfe,0x10,0x30,0xce,0x42,0x84,0xee,0x84,0x84,0x8c,
+/* 39504 0x9a50 "驐" */
+0x01,0xf8,0xa3,0xf8,0xa3,0xfa,0xa3,0xa0,0xfb,0x08,0xa8,0xa8,0xab,0x88,0x0a,0x31,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 39505 0x9a51 "驑" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x28,0xee,0xaa,0xaa,0xee,0x28,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 39506 0x9a52 "驒" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xab,0x82,0x14,0x08,
+0x00,0xee,0xaa,0xaa,0xee,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xfe,0x10,0x10,0x10,
+/* 39507 0x9a53 "驓" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x44,0x24,0x28,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+/* 39508 0x9a54 "驔" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,
+/* 39509 0x9a55 "驕" */
+0x00,0xf9,0xa0,0xfb,0xa0,0xf9,0xa2,0xa0,0xf8,0x09,0xa9,0xa9,0xa9,0x89,0x09,0x31,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 39510 0x9a56 "驖" */
+0x00,0xfb,0xa0,0xfb,0xa0,0xfb,0xa2,0xa3,0xf8,0x0b,0xa8,0xab,0xa8,0x88,0x0b,0x30,
+0x8c,0xea,0x88,0xfe,0x08,0xe8,0x2a,0xea,0x0a,0xec,0x8c,0xec,0x8a,0xea,0x96,0x22,
+/* 39511 0x9a57 "驗" */
+0x00,0x7c,0x50,0x7c,0x51,0x7e,0x50,0x50,0x7d,0x05,0x55,0x55,0x54,0x84,0x15,0x0a,
+0x20,0x20,0x50,0x88,0x04,0xfa,0x00,0x00,0xdc,0x54,0x54,0xdc,0x88,0x88,0x54,0x22,
+/* 39512 0x9a58 "驘" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x00,0x77,0x55,0x77,0x55,0x77,0x50,0xb5,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0xdc,0x14,0xd4,0x1c,0xd6,0x56,0x62,
+/* 39513 0x9a59 "驙" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,
+/* 39514 0x9a5a "驚" */
+0x24,0xff,0x24,0x7e,0x82,0x7a,0x4a,0x7a,0x04,0x3f,0x21,0x3f,0x21,0x3f,0x29,0x44,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xf8,0x00,0xf8,0x00,0xfe,0x22,0x96,
+/* 39515 0x9a5b "驛" */
+0x00,0x7d,0x51,0x7d,0x50,0x7d,0x50,0x53,0x7c,0x04,0x55,0x54,0x57,0x84,0x14,0x08,
+0x00,0xfc,0x54,0xfc,0x20,0xfc,0x20,0xfe,0x88,0x50,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 39516 0x9a5c "驜" */
+0x00,0x7d,0x50,0x7c,0x51,0x7c,0x50,0x51,0x7c,0x04,0x54,0x55,0x54,0x85,0x16,0x08,
+0x50,0x52,0xd4,0x50,0xfe,0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0xa8,0x24,0x22,0x20,
+/* 39517 0x9a5d "驝" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xab,0xaa,0x82,0x14,0x09,
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x20,0x7c,0xc4,0x7c,0x10,0xfe,0x54,0x92,
+/* 39518 0x9a5e "驞" */
+0x00,0xf8,0xa3,0xfa,0xa1,0xf9,0xa2,0xa1,0xfb,0x09,0xa9,0xa9,0xa9,0x89,0x08,0x31,
+0x40,0x20,0xfe,0x02,0xfc,0x48,0x50,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,
+/* 39519 0x9a5f "驟" */
+0x03,0x7d,0x51,0x7d,0x51,0x7d,0x53,0x50,0x7c,0x07,0x54,0x55,0x54,0x84,0x17,0x08,
+0xf0,0x2e,0xe2,0x2a,0xe4,0x34,0xea,0x32,0x1e,0xe0,0xa2,0x34,0x68,0xa4,0x22,0x20,
+/* 39520 0x9a60 "驠" */
+0x01,0xf9,0xa7,0xf9,0xa1,0xfa,0xa2,0xa6,0xfa,0x0a,0xae,0xaa,0xa8,0x8a,0x0a,0x34,
+0x10,0x10,0xfc,0x10,0xf0,0x08,0xea,0xac,0xa8,0xaa,0xea,0x06,0x00,0xa4,0x52,0x52,
+/* 39521 0x9a61 "驡" */
+0x10,0x7e,0x24,0xff,0x42,0x7e,0x42,0x7e,0x42,0x3f,0x21,0x3f,0x21,0x3f,0x29,0x44,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x78,0x42,0xfe,0x00,0xf8,0x00,0xfe,0x22,0x96,
+/* 39522 0x9a62 "驢" */
+0x00,0xf8,0xa0,0xfb,0xa2,0xfb,0xa2,0xa2,0xfa,0x0a,0xaa,0xaa,0xaa,0x8d,0x09,0x33,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 39523 0x9a63 "驣" */
+0x01,0x7c,0x51,0x7c,0x53,0x7d,0x53,0x55,0x7d,0x05,0x55,0x55,0x55,0x84,0x16,0x08,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0xfc,0x22,0xfc,0x20,0xfc,0x20,0xfe,0x02,0xaa,0x04,
+/* 39524 0x9a64 "驤" */
+0x00,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x48,0x7e,0x02,0xaa,0xaa,0xaa,0x82,0x15,0x08,
+0x10,0xfe,0x00,0xee,0xaa,0xee,0x44,0xfe,0x44,0xfe,0x44,0xfe,0x50,0xca,0x64,0x42,
+/* 39525 0x9a65 "驥" */
+0x00,0xfb,0xa0,0xf9,0xa2,0xf9,0xa1,0xa1,0xf9,0x09,0xa8,0xa9,0xa8,0x8b,0x08,0x31,
+0x94,0x98,0x92,0x8e,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x04,
+/* 39526 0x9a66 "驦" */
+0x01,0xf8,0xa3,0xfa,0xa1,0xf8,0xa1,0xa0,0xf8,0x0b,0xa8,0xa9,0xaa,0x8c,0x08,0x30,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0x9e,0xf2,0x9e,0xd2,0xbe,0x92,0x9e,0x92,
+/* 39527 0x9a67 "驧" */
+0x02,0xfa,0xa7,0xfa,0xa3,0xf9,0xa7,0xa5,0xfd,0x0f,0xa9,0xaf,0xa9,0x89,0x09,0x31,
+0x90,0x90,0xd0,0xbe,0xca,0x2e,0xda,0x4a,0x7e,0xca,0x1e,0xea,0x0a,0x02,0x0a,0x04,
+/* 39528 0x9a68 "驨" */
+0x02,0xfb,0xa0,0xf9,0xa3,0xfd,0xa1,0xa1,0xf9,0x09,0xa9,0xab,0xaa,0x8b,0x0a,0x32,
+0x22,0xfe,0x90,0xfe,0x10,0xfe,0x10,0xfe,0x10,0xfe,0x00,0xfe,0x8a,0x76,0x52,0x76,
+/* 39529 0x9a69 "驩" */
+0x00,0xfb,0xa0,0xfb,0xa2,0xfb,0xa0,0xa0,0xf9,0x09,0xab,0xad,0xa9,0x89,0x09,0x31,
+0x88,0xfe,0x88,0xde,0x52,0xde,0xa0,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 39530 0x9a6a "驪" */
+0x03,0xf8,0xa3,0xfa,0xa3,0xfa,0xa0,0xa3,0xfa,0x0b,0xaa,0xab,0xaa,0x8a,0x0a,0x34,
+0xde,0x00,0xde,0x52,0x5a,0x52,0x20,0xfe,0x50,0xfe,0x52,0xfe,0x92,0xdc,0x92,0xce,
+/* 39531 0x9a6b "驫" */
+0x7f,0x42,0x7f,0x42,0x7f,0x52,0x89,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x7e,0x02,0x96,
+0xf8,0x00,0xf0,0x00,0xfc,0x44,0x2c,0x7e,0x48,0x7e,0x48,0x7e,0x48,0x7e,0x02,0x96,
+/* 39532 0x9a6c "马" */
+0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0xe4,0x04,0x04,0x28,0x10,
+/* 39533 0x9a6d "驭" */
+0x00,0x7c,0x05,0x24,0x24,0x24,0x24,0x3e,0x02,0x02,0x1a,0xe2,0x42,0x02,0x15,0x0a,
+0x00,0x00,0xfc,0x84,0x84,0x84,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x04,0x02,
+/* 39534 0x9a6e "驮" */
+0x00,0x7c,0x04,0x24,0x24,0x25,0x24,0x3e,0x02,0x02,0x1a,0xe2,0x42,0x02,0x15,0x0a,
+0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 39535 0x9a6f "驯" */
+0x01,0xf9,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1d,0xe5,0x45,0x06,0x2a,0x14,
+0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,
+/* 39536 0x9a70 "驰" */
+0x00,0xf8,0x08,0x49,0x49,0x49,0x49,0x7f,0x05,0x05,0x1d,0xe5,0x45,0x05,0x28,0x10,
+0x20,0x20,0x20,0x20,0x2c,0x34,0x64,0xa4,0x24,0x34,0x28,0x22,0x22,0x02,0xfe,0x00,
+/* 39537 0x9a71 "驱" */
+0x00,0xf9,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x10,
+0x00,0xfe,0x00,0x04,0x44,0x28,0x28,0x10,0x10,0x28,0x28,0x44,0x84,0x00,0xfe,0x00,
+/* 39538 0x9a72 "驲" */
+0x00,0x7c,0x04,0x24,0x24,0x24,0x24,0x3e,0x02,0x02,0x1a,0xe2,0x42,0x02,0x14,0x08,
+0x00,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 39539 0x9a73 "驳" */
+0x00,0xf8,0x08,0x48,0x48,0x48,0x49,0x7c,0x04,0x04,0x1c,0xe4,0x44,0x04,0x28,0x13,
+0x08,0x88,0x50,0x20,0x50,0x88,0x00,0x08,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 39540 0x9a74 "驴" */
+0x00,0xf8,0x08,0x48,0x48,0x48,0x48,0x7c,0x04,0x04,0x1c,0xe4,0x44,0x05,0x29,0x12,
+0x40,0x20,0x20,0xfc,0x84,0x84,0x84,0xfc,0x84,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 39541 0x9a75 "驵" */
+0x00,0xf8,0x08,0x48,0x48,0x48,0x48,0x7c,0x04,0x04,0x1c,0xe4,0x44,0x04,0x2b,0x10,
+0x00,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 39542 0x9a76 "驶" */
+0x00,0xf8,0x08,0x49,0x49,0x49,0x49,0x7d,0x05,0x04,0x1c,0xe4,0x44,0x04,0x29,0x12,
+0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x20,0xa0,0x60,0x60,0x90,0x08,0x06,
+/* 39543 0x9a77 "驷" */
+0x00,0xf9,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x10,
+0x00,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x94,0x8c,0x04,0x04,0x04,0xfc,0x04,0x00,
+/* 39544 0x9a78 "驸" */
+0x00,0xf8,0x08,0x49,0x49,0x4b,0x4d,0x7d,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x11,
+0x88,0x88,0x88,0x08,0x7e,0x08,0x08,0x48,0x28,0x28,0x08,0x08,0x08,0x08,0x28,0x10,
+/* 39545 0x9a79 "驹" */
+0x00,0xf8,0x09,0x49,0x4a,0x4c,0x49,0x7d,0x05,0x05,0x1d,0xe5,0x44,0x04,0x28,0x10,
+0x80,0x80,0x00,0xfc,0x04,0x04,0xe4,0x24,0x24,0x24,0xe4,0x24,0x04,0x04,0x28,0x10,
+/* 39546 0x9a7a "驺" */
+0x00,0xf8,0x08,0x49,0x4a,0x4c,0x4b,0x7c,0x04,0x04,0x1d,0xe4,0x44,0x04,0x2b,0x10,
+0x80,0x80,0xf8,0x08,0x10,0x20,0xfc,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xfc,0x04,
+/* 39547 0x9a7b "驻" */
+0x00,0xf8,0x08,0x4b,0x48,0x48,0x48,0x7c,0x05,0x04,0x1c,0xe4,0x44,0x04,0x2b,0x10,
+0x40,0x20,0x00,0xfe,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 39548 0x9a7c "驼" */
+0x00,0xf8,0x08,0x49,0x49,0x4a,0x48,0x7c,0x04,0x04,0x1c,0xe4,0x44,0x04,0x28,0x10,
+0x20,0x10,0x10,0xfe,0x02,0x04,0x80,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 39549 0x9a7d "驽" */
+0x08,0x7f,0x11,0x32,0x0c,0x12,0x61,0x1f,0x00,0x08,0x08,0x0f,0x00,0x7f,0x00,0x00,
+0x00,0x7c,0x44,0x28,0x10,0x28,0x46,0xe0,0x20,0x20,0x20,0xfc,0x04,0xc4,0x14,0x08,
+/* 39550 0x9a7e "驾" */
+0x08,0x08,0x7f,0x11,0x11,0x25,0x42,0x1f,0x00,0x08,0x08,0x0f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x7c,0x44,0x44,0x7c,0x00,0xe0,0x20,0x20,0x20,0xfc,0x04,0xc4,0x14,0x08,
+/* 39551 0x9a7f "驿" */
+0x00,0xfb,0x09,0x48,0x48,0x48,0x48,0x7f,0x04,0x05,0x1c,0xe4,0x47,0x04,0x28,0x10,
+0x00,0xfc,0x04,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 39552 0x9a80 "骀" */
+0x00,0xf8,0x08,0x48,0x49,0x4b,0x48,0x7c,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x11,
+0x20,0x20,0x40,0x88,0x04,0xfe,0x02,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 39553 0x9a81 "骁" */
+0x00,0xf8,0x08,0x4b,0x48,0x48,0x48,0x7f,0x04,0x07,0x1c,0xe4,0x45,0x05,0x2a,0x14,
+0x80,0x80,0xbc,0xc0,0x50,0x24,0xd4,0x0c,0x00,0xfe,0x90,0x90,0x12,0x12,0x0e,0x00,
+/* 39554 0x9a82 "骂" */
+0x00,0x7c,0x44,0x44,0x7c,0x00,0x3f,0x00,0x08,0x08,0x0f,0x00,0x7f,0x00,0x00,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x00,0xe0,0x20,0x20,0x20,0xfc,0x04,0xe4,0x04,0x28,0x10,
+/* 39555 0x9a83 "骃" */
+0x00,0xf9,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x11,
+0x00,0xfc,0x04,0x24,0x24,0x24,0xfc,0x24,0x24,0x54,0x4c,0x8c,0x04,0x04,0xfc,0x04,
+/* 39556 0x9a84 "骄" */
+0x00,0xf8,0x09,0x48,0x48,0x4b,0x48,0x7c,0x05,0x06,0x1c,0xe4,0x44,0x05,0x29,0x12,
+0x08,0x3c,0xe0,0x20,0x20,0xfe,0x50,0x88,0x04,0x8a,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 39557 0x9a85 "骅" */
+0x00,0xf8,0x09,0x49,0x4b,0x4d,0x49,0x7d,0x05,0x04,0x1f,0xe4,0x44,0x04,0x28,0x10,
+0x90,0x94,0x14,0x18,0x10,0x32,0x52,0x0e,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 39558 0x9a86 "骆" */
+0x00,0xf8,0x08,0x49,0x4b,0x4c,0x48,0x7c,0x05,0x06,0x1d,0xe5,0x45,0x05,0x29,0x11,
+0x80,0x80,0xf8,0x08,0x10,0xa0,0x40,0xa0,0x18,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,
+/* 39559 0x9a87 "骇" */
+0x00,0xf8,0x08,0x49,0x48,0x48,0x48,0x7c,0x04,0x04,0x1c,0xe5,0x44,0x04,0x28,0x11,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 39560 0x9a88 "骈" */
+0x00,0xf8,0x08,0x48,0x49,0x48,0x48,0x7c,0x04,0x07,0x1c,0xe4,0x44,0x04,0x28,0x11,
+0x84,0x44,0x48,0x00,0xfe,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x08,
+/* 39561 0x9a89 "骉" */
+0x3f,0x00,0x10,0x1f,0x00,0x7f,0x00,0x00,0xfc,0x04,0x44,0x7e,0x02,0xf2,0x0a,0x04,
+0xf0,0x10,0x10,0xfc,0x04,0xe4,0x28,0x10,0xfc,0x04,0x44,0x7e,0x02,0xf2,0x0a,0x04,
+/* 39562 0x9a8a "骊" */
+0x00,0xf3,0x10,0x50,0x53,0x52,0x52,0x7a,0x0b,0x0a,0x3a,0xca,0x0a,0x0a,0x2a,0x12,
+0x00,0xfe,0x00,0x00,0xde,0x52,0x52,0x52,0x5a,0xd6,0x52,0x52,0x52,0x52,0x52,0xd6,
+/* 39563 0x9a8b "骋" */
+0x00,0xf8,0x09,0x49,0x49,0x49,0x49,0x7c,0x07,0x04,0x1d,0xe5,0x44,0x04,0x28,0x10,
+0x20,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x00,0xfe,0x80,0x00,0xfc,0x04,0x04,0x28,0x10,
+/* 39564 0x9a8c "验" */
+0x00,0xf8,0x08,0x48,0x48,0x49,0x4a,0x7c,0x04,0x04,0x1d,0xe4,0x44,0x04,0x2b,0x10,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x44,0x24,0x24,0xa8,0x88,0x10,0xfe,0x00,
+/* 39565 0x9a8d "骍" */
+0x00,0xf8,0x09,0x48,0x48,0x48,0x4b,0x7c,0x04,0x04,0x1d,0xe4,0x44,0x04,0x28,0x10,
+0x40,0x20,0xfc,0x00,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 39566 0x9a8e "骎" */
+0x00,0xf8,0x08,0x48,0x48,0x48,0x48,0x7d,0x05,0x04,0x1c,0xe4,0x44,0x04,0x28,0x11,
+0x00,0xfc,0x04,0x7c,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x44,0x44,0x28,0x10,0x68,0x86,
+/* 39567 0x9a8f "骏" */
+0x00,0xf8,0x08,0x49,0x4b,0x48,0x48,0x7d,0x06,0x04,0x1d,0xe6,0x44,0x04,0x29,0x16,
+0x40,0x40,0x88,0x04,0xfe,0x02,0x88,0x44,0x42,0xf8,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 39568 0x9a90 "骐" */
+0x00,0xf8,0x0b,0x48,0x48,0x48,0x48,0x7c,0x04,0x04,0x1c,0xe7,0x44,0x04,0x28,0x11,
+0x88,0x88,0xfe,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x84,0x04,
+/* 39569 0x9a91 "骑" */
+0x00,0xf8,0x09,0x48,0x48,0x49,0x4b,0x7c,0x05,0x05,0x1d,0xe5,0x45,0x04,0x28,0x10,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x28,0x08,0x28,0x10,
+/* 39570 0x9a92 "骒" */
+0x00,0xf9,0x09,0x49,0x49,0x49,0x49,0x7d,0x04,0x07,0x1c,0xe4,0x45,0x06,0x28,0x10,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,0x20,
+/* 39571 0x9a93 "骓" */
+0x00,0xf8,0x08,0x48,0x49,0x4a,0x48,0x7c,0x04,0x04,0x1c,0xe4,0x44,0x04,0x28,0x10,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 39572 0x9a94 "骔" */
+0x00,0xf8,0x0b,0x4a,0x4c,0x48,0x48,0x7c,0x05,0x04,0x1c,0xe4,0x45,0x06,0x28,0x10,
+0x40,0x20,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 39573 0x9a95 "骕" */
+0x00,0xf8,0x09,0x48,0x4b,0x48,0x49,0x7c,0x05,0x05,0x1d,0xe5,0x45,0x05,0x2a,0x14,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0x24,0x74,0xac,0x24,0x24,0x24,0x24,
+/* 39574 0x9a96 "骖" */
+0x00,0xf8,0x08,0x49,0x48,0x4b,0x48,0x7d,0x06,0x05,0x1c,0xe4,0x45,0x04,0x28,0x13,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x62,0x84,0x18,0x60,0x80,
+/* 39575 0x9a97 "骗" */
+0x00,0xf8,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1e,0xe6,0x44,0x04,0x28,0x10,
+0x40,0x20,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xa2,0x86,
+/* 39576 0x9a98 "骘" */
+0x00,0x79,0x49,0x53,0x48,0x6b,0x50,0x43,0x1f,0x00,0x08,0x0f,0x00,0x7f,0x00,0x00,
+0x20,0x3c,0x20,0xfe,0xa4,0x28,0x70,0x80,0xe0,0x20,0x20,0xfc,0x04,0xc4,0x14,0x08,
+/* 39577 0x9a99 "骙" */
+0x00,0xfb,0x08,0x4a,0x49,0x48,0x49,0x7e,0x04,0x04,0x1d,0xe4,0x44,0x04,0x29,0x12,
+0x10,0xd4,0x58,0x52,0x8c,0x88,0x04,0xfa,0x20,0x20,0xfe,0x20,0x50,0x88,0x04,0x02,
+/* 39578 0x9a9a "骚" */
+0x00,0xf9,0x08,0x48,0x48,0x48,0x48,0x7f,0x04,0x05,0x1d,0xe5,0x45,0x04,0x2b,0x10,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 39579 0x9a9b "骛" */
+0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x00,0x1f,0x00,0x08,0x0f,0x00,0x7f,0x00,0x00,
+0x20,0x3e,0x48,0xa8,0x10,0x28,0x46,0x00,0xe0,0x20,0x20,0xfc,0x04,0xc4,0x14,0x08,
+/* 39580 0x9a9c "骜" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x5f,0x80,0x08,0x0f,0x00,0x7f,0x00,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0xe2,0x20,0x20,0xfc,0x04,0xd4,0x08,
+/* 39581 0x9a9d "骝" */
+0x00,0xf9,0x09,0x49,0x49,0x49,0x49,0x7c,0x05,0x05,0x1d,0xe5,0x45,0x05,0x29,0x11,
+0x40,0xbc,0x14,0x94,0x54,0xa4,0x4c,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x04,
+/* 39582 0x9a9e "骞" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x08,0x1f,0x20,0xc8,0x0f,0x00,0x7f,0x00,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xd0,0x48,0x46,0xf8,0x08,0xa8,0x10,
+/* 39583 0x9a9f "骟" */
+0x00,0xf8,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1d,0xe5,0x45,0x06,0x2a,0x14,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0xee,0x22,0xaa,0x66,0x22,0x66,0xaa,0x22,0x66,
+/* 39584 0x9aa0 "骠" */
+0x00,0xfb,0x08,0x49,0x49,0x49,0x49,0x7c,0x05,0x04,0x1f,0xe4,0x44,0x05,0x2a,0x10,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 39585 0x9aa1 "骡" */
+0x00,0xf9,0x09,0x49,0x49,0x49,0x48,0x7c,0x05,0x04,0x1c,0xe7,0x44,0x05,0x2a,0x10,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x40,0x88,0xf0,0x20,0x44,0xfe,0x22,0x24,0x22,0x60,
+/* 39586 0x9aa2 "骢" */
+0x00,0xf8,0x09,0x49,0x49,0x49,0x49,0x7d,0x05,0x05,0x1c,0xe4,0x45,0x05,0x29,0x12,
+0x20,0x40,0xfc,0x24,0x7c,0x8c,0x54,0x24,0x54,0xfc,0x20,0x10,0x54,0x42,0x4a,0x38,
+/* 39587 0x9aa3 "骣" */
+0x03,0xf2,0x13,0x52,0x52,0x52,0x53,0x7a,0x0a,0x0b,0x3a,0xca,0x0c,0x0f,0x28,0x11,
+0xfe,0x02,0xfe,0x00,0xfc,0x08,0xfe,0x10,0x30,0xce,0x42,0x84,0xee,0x84,0x84,0x8c,
+/* 39588 0x9aa4 "骤" */
+0x07,0xf2,0x13,0x52,0x53,0x52,0x57,0x78,0x08,0x0f,0x39,0xca,0x08,0x09,0x2e,0x10,
+0xe0,0x5c,0xc4,0x54,0xc8,0x68,0xd4,0x64,0x3c,0xc0,0x44,0x68,0xd0,0x48,0x46,0x40,
+/* 39589 0x9aa5 "骥" */
+0x00,0xfb,0x08,0x49,0x4a,0x49,0x49,0x7d,0x05,0x05,0x1c,0xe5,0x44,0x07,0x28,0x11,
+0x94,0x98,0x92,0x8e,0x80,0xfc,0x24,0xfc,0x24,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x04,
+/* 39590 0x9aa6 "骦" */
+0x01,0xf8,0x0b,0x4a,0x49,0x48,0x49,0x7c,0x04,0x07,0x1c,0xe5,0x46,0x04,0x28,0x10,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0x9e,0xf2,0x9e,0xd2,0xbe,0x92,0x9e,0x92,
+/* 39591 0x9aa7 "骧" */
+0x00,0xf3,0x10,0x51,0x51,0x51,0x50,0x7b,0x08,0x0b,0x38,0xcb,0x08,0x09,0x2a,0x10,
+0x20,0xfe,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 39592 0x9aa8 "骨" */
+0x1f,0x10,0x1f,0x10,0x10,0x7f,0x40,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x10,0x10,0x10,
+0xf0,0x10,0x90,0x90,0x90,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x10,0x10,0x50,0x20,
+/* 39593 0x9aa9 "骩" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x55,0x4a,
+0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0x48,0x48,0x4a,0x8a,0x8a,0x06,0x00,
+/* 39594 0x9aaa "骪" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x45,0x55,0x4a,
+0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0xd0,0xb0,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 39595 0x9aab "骫" */
+0x00,0x7c,0x44,0x75,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x45,0x55,0x4a,
+0x40,0x40,0x40,0xf8,0x48,0x48,0x48,0x48,0xc8,0x48,0xa8,0xa8,0x8a,0x0a,0x06,0x02,
+/* 39596 0x9aac "骬" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 39597 0x9aad "骭" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x00,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 39598 0x9aae "骮" */
+0x3f,0x21,0x3d,0x25,0x25,0x7f,0x40,0xbf,0x21,0x3f,0x21,0x3f,0x21,0x21,0x25,0x22,
+0x10,0x14,0x12,0x12,0x10,0x96,0xb8,0x10,0x10,0x10,0x10,0x10,0x0a,0x0a,0x06,0x02,
+/* 39599 0x9aaf "骯" */
+0x00,0x7c,0x44,0x75,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x45,0x55,0x4a,
+0x40,0x20,0x00,0xfc,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x92,0x92,0x12,0x0e,0x00,
+/* 39600 0x9ab0 "骰" */
+0x00,0x7c,0x44,0x74,0x54,0xff,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x4b,
+0x00,0xf8,0x88,0x88,0x88,0x06,0x00,0xfc,0x84,0x84,0x48,0x50,0x20,0x50,0x88,0x06,
+/* 39601 0x9ab1 "骱" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x83,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x20,0x20,0x20,0x50,0x50,0x88,0x06,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 39602 0x9ab2 "骲" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 39603 0x9ab3 "骳" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x45,0x55,0x4a,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 39604 0x9ab4 "骴" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x08,0x28,0x28,0x28,0xa8,0xaa,0xbc,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0xba,0xea,0x86,
+/* 39605 0x9ab5 "骵" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x45,0x7d,0x46,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0xf8,0x20,0x20,0x20,0x20,
+/* 39606 0x9ab6 "骶" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x04,0x1e,0xf0,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x88,0x8a,0xaa,0xd6,0x8a,
+/* 39607 0x9ab7 "骷" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 39608 0x9ab8 "骸" */
+0x00,0x7c,0x44,0x75,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x44,0x54,0x49,
+0x20,0x10,0x10,0xfe,0x20,0x24,0x44,0xf8,0x12,0x22,0x44,0x88,0x10,0x28,0x44,0x82,
+/* 39609 0x9ab9 "骹" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x82,0x00,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 39610 0x9aba "骺" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x45,0x55,0x4a,
+0x08,0x1c,0xe0,0x80,0x80,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xa4,0xa4,0x3c,0x24,0x00,
+/* 39611 0x9abb "骻" */
+0x00,0x7c,0x45,0x74,0x54,0xff,0x82,0x7c,0x47,0x7c,0x44,0x7d,0x44,0x44,0x54,0x48,
+0x20,0x20,0xfc,0x50,0x88,0x04,0xfa,0x00,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 39612 0x9abc "骼" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x82,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 39613 0x9abd "骽" */
+0x00,0x7c,0x45,0x74,0x55,0xfe,0x82,0x7c,0x45,0x7c,0x44,0x7d,0x44,0x44,0x54,0x4b,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xfe,0x44,0x84,0xc8,0x30,0x28,0xc4,0x02,
+/* 39614 0x9abe "骾" */
+0x00,0x7d,0x44,0x74,0x55,0xff,0x83,0x7d,0x45,0x7d,0x45,0x7d,0x44,0x44,0x54,0x4b,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 39615 0x9abf "骿" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 39616 0x9ac0 "髀" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x44,0x54,0x48,
+0x20,0x40,0xfe,0x92,0x92,0xfe,0x92,0xa2,0xfe,0x48,0x88,0xfe,0x08,0x08,0x08,0x08,
+/* 39617 0x9ac1 "髁" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7d,0x44,0x7c,0x44,0x45,0x54,0x48,
+0x00,0xf8,0xa8,0xa8,0xf8,0xa8,0xa8,0xf8,0x20,0xfc,0x20,0x70,0xa8,0x26,0x20,0x20,
+/* 39618 0x9ac2 "髂" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x47,0x7c,0x44,0x44,0x54,0x48,
+0x40,0x20,0xfc,0x04,0x40,0x78,0x88,0x50,0x20,0xd8,0x06,0xf8,0x88,0x88,0xf8,0x88,
+/* 39619 0x9ac3 "髃" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7d,0x45,0x7d,0x45,0x45,0x55,0x49,
+0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfc,0x20,0x20,0xfe,0x22,0x2a,0xfa,0x0a,0x02,0x06,
+/* 39620 0x9ac4 "髄" */
+0x00,0x7c,0x44,0x75,0x54,0xfe,0x82,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x55,0x4a,
+0x08,0x08,0xfe,0x10,0xa0,0x7e,0xa2,0x22,0xbe,0xa2,0xbe,0xa2,0xaa,0xa4,0x40,0x3e,
+/* 39621 0x9ac5 "髅" */
+0x00,0x7d,0x44,0x74,0x55,0xfe,0x82,0x7d,0x44,0x7d,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x20,0x24,0xa8,0x20,0xfe,0x68,0xa4,0x02,0x20,0xfe,0x48,0x88,0xd0,0x30,0x4c,0x82,
+/* 39622 0x9ac6 "髆" */
+0x00,0x7c,0x45,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x44,0x54,0x48,
+0x14,0x12,0xfe,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x04,0xfe,0x44,0x24,0x24,0x0c,
+/* 39623 0x9ac7 "髇" */
+0x00,0x7c,0x45,0x74,0x54,0xfe,0x82,0x7c,0x45,0x7d,0x45,0x7d,0x45,0x45,0x55,0x49,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfe,0x02,0x7a,0x4a,0x7a,0x02,0x0a,0x04,
+/* 39624 0x9ac8 "髈" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0xa2,0x10,0xfe,0x20,0x3c,0x24,0x44,0x54,0x88,
+/* 39625 0x9ac9 "髉" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x20,0xfe,0x52,0x48,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x90,0x90,0xfe,0x80,
+/* 39626 0x9aca "髊" */
+0x00,0x7c,0x44,0x75,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7d,0x46,0x44,0x55,0x48,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 39627 0x9acb "髋" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x4b,
+0x20,0x10,0xfe,0x02,0x48,0xfc,0x48,0x00,0xfc,0x84,0xa4,0xa4,0xa4,0x50,0x92,0x0e,
+/* 39628 0x9acc "髌" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7d,0x44,0x44,0x55,0x4a,
+0x40,0x20,0xfe,0x02,0x18,0xe0,0x80,0xfc,0x90,0x90,0x90,0xfe,0x00,0x88,0x04,0x02,
+/* 39629 0x9acd "髍" */
+0x00,0x7c,0x45,0x75,0x55,0xff,0x83,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x45,0x56,0x48,
+0x20,0x10,0xfe,0x48,0x48,0x48,0xfe,0x48,0x48,0xec,0x5a,0x68,0x48,0x48,0x48,0x48,
+/* 39630 0x9ace "髎" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7d,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x10,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x18,0xe0,
+/* 39631 0x9acf "髏" */
+0x00,0x7d,0x45,0x77,0x55,0xff,0x82,0x7d,0x45,0x7d,0x44,0x7d,0x44,0x45,0x54,0x4b,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x88,0xd0,0x70,0x8c,
+/* 39632 0x9ad0 "髐" */
+0x00,0x7c,0x44,0x74,0x55,0xfe,0x83,0x7c,0x44,0x7d,0x44,0x7d,0x44,0x44,0x54,0x49,
+0x20,0x20,0xfc,0x20,0xfe,0x88,0xdc,0x88,0xc8,0xbc,0x00,0xfe,0x50,0x50,0x94,0x0c,
+/* 39633 0x9ad1 "髑" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x00,0xfe,0xaa,0xaa,0xfe,0x40,0xfe,0x22,0xfa,0xaa,0xaa,0xfa,0x22,0xfa,0x0a,0x04,
+/* 39634 0x9ad2 "髒" */
+0x00,0x7d,0x44,0x74,0x55,0xfe,0x82,0x7d,0x44,0x7c,0x45,0x7d,0x44,0x44,0x54,0x49,
+0x48,0xfe,0x48,0x00,0xfe,0x88,0xea,0x2c,0xca,0x86,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 39635 0x9ad3 "髓" */
+0x00,0x7c,0x45,0x74,0x54,0xfe,0x82,0x7d,0x44,0x7c,0x44,0x7c,0x44,0x44,0x55,0x4a,
+0x10,0x7e,0x20,0xbc,0xc8,0xbe,0x00,0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0xac,0x40,0x3e,
+/* 39636 0x9ad4 "體" */
+0x00,0x7d,0x45,0x75,0x55,0xff,0x82,0x7d,0x44,0x7d,0x45,0x7d,0x44,0x44,0x57,0x48,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 39637 0x9ad5 "髕" */
+0x00,0x7c,0x45,0x75,0x54,0xfe,0x83,0x7c,0x45,0x7c,0x44,0x7c,0x44,0x44,0x54,0x48,
+0x20,0x10,0xfe,0x02,0xfc,0xa8,0x30,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 39638 0x9ad6 "髖" */
+0x00,0x7d,0x45,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x54,0x49,
+0x20,0xfe,0x4a,0xfc,0x48,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x50,0x54,0x92,0x0e,
+/* 39639 0x9ad7 "髗" */
+0x00,0x7c,0x44,0x75,0x55,0xff,0x83,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x46,0x54,0x49,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0x7e,0x54,0x7c,0x54,0x7c,0x00,0xfe,0xaa,0xfe,
+/* 39640 0x9ad8 "高" */
+0x02,0x01,0xff,0x00,0x0f,0x08,0x08,0x0f,0x00,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,
+0x00,0x00,0xfe,0x00,0xe0,0x20,0x20,0xe0,0x00,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x0c,
+/* 39641 0x9ad9 "髙" */
+0x02,0x01,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x7f,0x40,0x4f,0x48,0x48,0x4f,0x40,0x40,
+0x00,0x00,0xfc,0x10,0xf0,0x10,0xf0,0x10,0xfc,0x04,0xe4,0x24,0x24,0xe4,0x04,0x0c,
+/* 39642 0x9ada "髚" */
+0x20,0x10,0xfe,0x01,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x87,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 39643 0x9adb "髛" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x83,0x86,
+0x00,0xfc,0x84,0x84,0xfc,0xa0,0xa0,0xa0,0xf8,0xa8,0xa8,0xa8,0xa8,0xaa,0x4a,0x86,
+/* 39644 0x9adc "髜" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x86,
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x00,0x14,0x64,0x24,0x24,0xfe,0x24,0x24,0x44,0x84,
+/* 39645 0x9add "髝" */
+0x20,0x11,0xfe,0x00,0x7c,0x45,0x7d,0x01,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x87,
+0x48,0x6a,0xdc,0x48,0xb4,0x22,0xfe,0x02,0x20,0x20,0xfc,0x24,0x44,0x44,0x94,0x08,
+/* 39646 0x9ade "髞" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x83,0x86,
+0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x10,0xfe,0x38,0x54,0x92,0x10,0x10,
+/* 39647 0x9adf "髟" */
+0x3f,0x20,0x20,0x3e,0x20,0x20,0x3e,0x20,0x20,0xff,0x10,0x24,0x42,0xff,0x41,0x00,
+0x04,0x04,0x08,0x10,0x20,0x44,0x04,0x08,0x10,0x22,0x42,0x04,0x08,0x10,0x20,0xc0,
+/* 39648 0x9ae0 "髠" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x0f,0x08,0x08,0x10,0x20,0xc0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xe0,0x20,0x20,0x22,0x22,0x1e,
+/* 39649 0x9ae1 "髡" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x7f,0x04,0x04,0x08,0x30,0xc0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x40,0x40,0x42,0x42,0x3e,
+/* 39650 0x9ae2 "髢" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x11,0x1f,0x71,0x11,0x10,0x0f,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x30,0xd0,0x10,0x52,0x22,0x02,0xfe,
+/* 39651 0x9ae3 "髣" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x02,0x7f,0x04,0x07,0x08,0x10,0x60,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x00,0xf0,0x10,0xa0,0x40,
+/* 39652 0x9ae4 "髤" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x7f,0x03,0x05,0x09,0x31,0xc1,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x80,0x40,0x20,0x18,0x06,
+/* 39653 0x9ae5 "髥" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x0f,0x08,0x7f,0x08,0x7f,0x08,0x08,0x08,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xfe,0x10,0xfe,0x10,0x50,0x20,
+/* 39654 0x9ae6 "髦" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x3e,0x03,0x3e,0x03,0x7e,0x01,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0xf0,0x00,0xf0,0x00,0xfa,0x02,0xfe,
+/* 39655 0x9ae7 "髧" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x7f,0x41,0x02,0x04,0x18,0xe0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x04,0x80,0x82,0x82,0x7e,
+/* 39656 0x9ae8 "髨" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x00,0xff,0x04,0x18,0xe0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xf8,0x00,0xfe,0x40,0x42,0x3e,
+/* 39657 0x9ae9 "髩" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0xff,0x01,0x21,0x21,0x3f,0x00,0x00,0x00,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0x28,0x10,
+/* 39658 0x9aea "髪" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0xff,0x04,0x0f,0x12,0x61,0x0e,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfe,0x00,0xf0,0x20,0xc0,0x3c,
+/* 39659 0x9aeb "髫" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x7f,0x08,0x10,0x3f,0xd0,0x1f,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xf8,0x08,0x30,0xf8,0x08,0xf8,
+/* 39660 0x9aec "髬" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x7f,0x03,0x0d,0x71,0x01,0xff,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfc,0x00,0x70,0x0c,0x00,0xfe,
+/* 39661 0x9aed "髭" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x08,0x08,0x2e,0x28,0x28,0x2e,0xf0,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x80,0x88,0x90,0xe0,0x84,0x84,0x7c,
+/* 39662 0x9aee "髮" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0xff,0x04,0x0f,0x12,0x61,0x0e,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x10,0xfe,0x00,0xf0,0x20,0xc0,0x3c,
+/* 39663 0x9aef "髯" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x3f,0x21,0x3f,0x21,0xff,0x20,0x20,0x20,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x08,0xf8,0x08,0xfe,0x08,0x28,0x10,
+/* 39664 0x9af0 "髰" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x12,0xff,0x12,0x13,0x10,0x1f,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0x20,0xfe,0x20,0xe0,0x00,0xfc,
+/* 39665 0x9af1 "髱" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x08,0x1f,0x20,0x5f,0x10,0x1f,0x10,0x10,0x0f,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0x90,0x90,0xd0,0x20,0x04,0xfc,
+/* 39666 0x9af2 "髲" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x20,0x27,0x22,0x41,0x9e,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x80,0xfc,0x84,0xf0,0x20,0xc0,0x3c,
+/* 39667 0x9af3 "髳" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x04,0xff,0x04,0x18,0xe1,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xe0,0x40,0xfc,0x84,0x88,0x80,
+/* 39668 0x9af4 "髴" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x04,0x7f,0x04,0x3f,0x24,0x3f,0x08,0x10,0x20,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x44,0x54,0x48,
+/* 39669 0x9af5 "髵" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0xff,0x02,0x3f,0x24,0x24,0x20,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0xfe,0x00,0xf8,0x88,0xa8,0x10,
+/* 39670 0x9af6 "髶" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3f,0x08,0x0f,0x08,0x0f,0x08,0xff,0x00,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x20,0xe0,0x20,0xe0,0x3e,0xe0,0x20,
+/* 39671 0x9af7 "髷" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x04,0x3f,0x24,0x3f,0x24,0x3f,0x20,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x08,
+/* 39672 0x9af8 "髸" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x04,0x3f,0x04,0xff,0x08,0x10,0x20,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x40,0xf8,0x40,0xfe,0x20,0x10,0x08,
+/* 39673 0x9af9 "髹" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x08,0x10,0x37,0xd0,0x13,0x1c,0x10,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x40,0x40,0xfc,0xe0,0x58,0x46,0x40,
+/* 39674 0x9afa "髺" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x00,0x3f,0x01,0xff,0x01,0x1f,0x10,0x1f,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x10,0xf0,
+/* 39675 0x9afb "髻" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0xff,0x01,0x3f,0x00,0x3f,0x20,0x3f,0x20,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x08,
+/* 39676 0x9afc "髼" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x1f,0x28,0x07,0x18,0xe1,0x1f,0x01,0x7f,0x01,0x01,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x20,0xc0,0x30,0x0e,0xf0,0x00,0xfc,0x00,0x00,
+/* 39677 0x9afd "髽" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x11,0x11,0x29,0x45,0x3f,0x01,0xff,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x10,0x10,0x28,0x44,0xf8,0x00,0xfe,
+/* 39678 0x9afe "髾" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x11,0x09,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x20,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x10,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x18,
+/* 39679 0x9aff "髿" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x10,0x48,0x25,0x0a,0x70,0x10,0x17,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x20,0xa8,0x24,0x22,0x28,0x30,0xc0,
+/* 39680 0x9b00 "鬀" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x04,0x7f,0x01,0x3f,0x21,0x3f,0x03,0x05,0x19,0x61,
+0x04,0x18,0x62,0x0c,0x70,0x20,0x40,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x14,0x08,0x00,
+/* 39681 0x9b01 "鬁" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3e,0x08,0x7f,0x1c,0x2a,0x49,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x08,0x48,0x48,0x48,0x48,0x08,0x18,
+/* 39682 0x9b02 "鬂" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x10,0xff,0x10,0x20,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x20,0xc0,0x00,0xf8,0x80,0x80,0xfe,0x20,0x10,
+/* 39683 0x9b03 "鬃" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x7f,0x40,0x1f,0x00,0x7f,0x11,0x25,0x42,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xfc,0x04,0xf0,0x00,0xfc,0x10,0x08,0x04,
+/* 39684 0x9b04 "鬄" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x64,0x08,0x33,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x94,0x08,
+/* 39685 0x9b05 "鬅" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x4a,0x85,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0x08,
+/* 39686 0x9b06 "鬆" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x10,0x10,0xfd,0x32,0x58,0x95,0x10,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x10,0x88,0x44,0x42,0x90,0xf8,0x08,
+/* 39687 0x9b07 "鬇" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x1f,0x20,0x5f,0x01,0xff,0x01,0x1f,0x01,0x05,0x02,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x20,0xf8,0x08,0xfe,0x08,0xf8,0x08,0x00,0x00,
+/* 39688 0x9b08 "鬈" */
+0x3f,0x20,0xff,0x22,0x7f,0x11,0x09,0x7f,0x04,0xff,0x10,0x2f,0xc8,0x08,0x08,0x07,
+0x04,0x18,0x62,0x0c,0x70,0x10,0x20,0xfc,0x00,0xfe,0x10,0xe8,0x26,0xa0,0x48,0xf8,
+/* 39689 0x9b09 "鬉" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x04,0x23,0x24,0x3f,0x14,0x2f,0x14,0x03,0x7c,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x40,0x88,0x48,0xf8,0x10,0xe8,0x40,0x80,0x78,
+/* 39690 0x9b0a "鬊" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x7f,0x01,0x3f,0x02,0xff,0x08,0x1f,0x28,0xcf,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x20,0xf0,0x28,0xe6,0x20,
+/* 39691 0x9b0b "鬋" */
+0x3f,0x20,0xff,0x22,0x7f,0x10,0x08,0xff,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,
+0x04,0x18,0x62,0x0c,0x70,0x10,0x20,0xfe,0x00,0x08,0x48,0x48,0x48,0x48,0x08,0x18,
+/* 39692 0x9b0c "鬌" */
+0x3f,0x20,0xff,0x22,0x7f,0x04,0x7f,0x08,0x1f,0x28,0x4f,0x88,0x0f,0x08,0x08,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x80,0xfc,0x10,0xf0,0x10,0xf0,0x10,0x50,0x20,
+/* 39693 0x9b0d "鬍" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x10,0xff,0x10,0x7e,0x42,0x7e,0x42,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x8c,
+/* 39694 0x9b0e "鬎" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x04,0x7f,0x04,0x3f,0x24,0x3f,0x15,0x24,0x44,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x04,0xc4,0x24,0xa4,0xa4,0xa4,0x04,0x94,0x08,
+/* 39695 0x9b0f "鬏" */
+0x3e,0x20,0x3e,0x20,0x3e,0x20,0xff,0x22,0x7f,0x00,0x7c,0x10,0xfe,0x38,0x54,0x92,
+0x04,0x18,0x60,0x04,0x18,0x62,0x04,0x18,0x60,0x00,0x10,0x52,0x94,0x28,0x44,0x82,
+/* 39696 0x9b10 "鬐" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x1f,0x01,0x7f,0x06,0x1c,0x63,0x00,0x1f,0x11,0x1f,
+0x04,0x18,0x62,0x0c,0x70,0x08,0xd0,0x20,0xfc,0x20,0x44,0xfc,0x00,0xf8,0x08,0xf8,
+/* 39697 0x9b11 "鬑" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x7f,0x04,0x3f,0x04,0xff,0x04,0x3f,0x0c,0x34,0xc4,
+0x04,0x18,0x62,0x0c,0x70,0x40,0xfc,0x80,0xf0,0x90,0xfe,0x90,0xf0,0xa0,0x98,0x86,
+/* 39698 0x9b12 "鬒" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x7f,0x01,0x1f,0x10,0x11,0x11,0xff,0x08,0x10,0x20,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x00,0xf0,0x10,0x10,0x10,0xfe,0x20,0x10,0x08,
+/* 39699 0x9b13 "鬓" */
+0x3f,0x20,0xff,0x22,0x7f,0x02,0x01,0x7f,0x40,0x9f,0x10,0x1f,0x10,0xff,0x10,0x20,
+0x04,0x18,0x62,0x0c,0x70,0x00,0x00,0xfe,0x22,0xc4,0x00,0xf8,0x80,0xfe,0x20,0x10,
+/* 39700 0x9b14 "鬔" */
+0x3f,0x20,0xff,0x22,0x7f,0x21,0x13,0x15,0x00,0x77,0x11,0x10,0x13,0x28,0x47,0x00,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xe0,0x5c,0xf0,0x40,0xfc,0x40,0xfe,0x00,
+/* 39701 0x9b15 "鬕" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0xff,0x08,0x1f,0x10,0x1f,0x10,0xff,0x08,0x30,0xc0,
+0x04,0x18,0x62,0x0c,0x70,0x20,0xfe,0x20,0xf0,0x10,0xf0,0x10,0xfe,0x20,0x18,0x06,
+/* 39702 0x9b16 "鬖" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x1f,0x10,0x25,0x7e,0x04,0x18,0xe3,0x0c,0x03,0x1c,
+0x04,0x18,0x62,0x0c,0x70,0x20,0xf0,0x20,0x48,0xfc,0x40,0xb0,0x0e,0x60,0x80,0x00,
+/* 39703 0x9b17 "鬗" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x7f,0x08,0x0f,0x01,0x7f,0x51,0x49,0x55,0x61,0x41,
+0x04,0x18,0x62,0x0c,0x70,0x20,0xfc,0x20,0xe0,0x00,0xfc,0x44,0x24,0x54,0x84,0x0c,
+/* 39704 0x9b18 "鬘" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x7f,0x44,0x7f,0x08,0x07,0xf8,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0xfc,0x20,0xc0,0x3e,
+/* 39705 0x9b19 "鬙" */
+0x3f,0x20,0xff,0x22,0x7f,0x08,0x7f,0x51,0x49,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x04,0x18,0x62,0x0c,0x70,0x20,0xfc,0x14,0x24,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 39706 0x9b1a "鬚" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x0b,0x10,0x61,0x09,0x11,0x61,0x05,0x09,0x31,0xc0,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,
+/* 39707 0x9b1b "鬛" */
+0x3f,0x20,0xff,0x22,0x7f,0x02,0x3f,0x24,0x23,0x24,0x3f,0x29,0x25,0x29,0x25,0x31,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xf8,0x48,0x88,0x48,0xf8,0x48,0x28,0x4a,0x26,0x82,
+/* 39708 0x9b1c "鬜" */
+0x3f,0x20,0xff,0x22,0x7f,0x00,0x7c,0x44,0x7c,0x47,0x7c,0x47,0x44,0x47,0x44,0x48,
+0x04,0x18,0x62,0x0c,0x70,0x00,0x7c,0x44,0x7c,0xc4,0x7c,0xc4,0x44,0xc4,0x44,0xcc,
+/* 39709 0x9b1d "鬝" */
+0x3f,0x20,0xff,0x22,0x7f,0x44,0x7c,0x44,0x7c,0x40,0x4f,0x48,0x4f,0x48,0x4f,0x40,
+0x04,0x18,0x62,0x0c,0x7c,0x44,0x7c,0x44,0x7c,0x04,0xe4,0x24,0xe4,0x24,0xe4,0x0c,
+/* 39710 0x9b1e "鬞" */
+0x3f,0x20,0xff,0x22,0x7f,0x02,0x1f,0x12,0x1f,0x12,0x3f,0x20,0x3f,0x28,0x4a,0x8c,
+0x04,0x18,0x62,0x0c,0x70,0x40,0xf8,0x48,0xf8,0x48,0xfc,0x00,0xfc,0x88,0x70,0x0e,
+/* 39711 0x9b1f "鬟" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x01,0x3f,0x24,0xff,0x10,0x1f,0x0c,0x34,0xc6,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x00,0xf8,0x48,0xfe,0x10,0xf0,0x88,0x70,0x0e,
+/* 39712 0x9b20 "鬠" */
+0x3f,0x20,0x3e,0x20,0xff,0x22,0x7f,0x02,0x0c,0x3f,0xd5,0x13,0x1f,0x0a,0x09,0x0f,
+0x08,0x30,0xc4,0x18,0x62,0x0c,0x70,0x80,0x60,0xf8,0x56,0x90,0xf0,0x20,0x20,0xe0,
+/* 39713 0x9b21 "鬡" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x7f,0x42,0xa9,0x47,0x00,0x3f,0x24,0xff,0x01,0x03,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x04,0x28,0xe4,0x00,0xf8,0x48,0xfe,0x00,0x00,
+/* 39714 0x9b22 "鬢" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x7f,0x40,0x9f,0x09,0x11,0x0f,0x18,0x6f,0x04,0x08,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfe,0x02,0xf4,0x20,0xc0,0xf8,0x88,0xf8,0x10,0x08,
+/* 39715 0x9b23 "鬣" */
+0x3f,0x20,0xff,0x22,0x7f,0x10,0x21,0x10,0x3f,0x24,0x23,0x24,0x3f,0x29,0x25,0x31,
+0x04,0x18,0x62,0x0c,0x70,0x84,0x08,0x84,0xf8,0x48,0x88,0x48,0xf8,0x4a,0x26,0x82,
+/* 39716 0x9b24 "鬤" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0xff,0x22,0x3e,0x04,0x3f,0x04,0xff,0x04,0x1c,0x67,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfe,0x88,0xf8,0x40,0xf8,0x40,0xfe,0x90,0x60,0x1c,
+/* 39717 0x9b25 "鬥" */
+0x00,0x5e,0x44,0x5e,0x44,0x5e,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
+0x00,0x7a,0x22,0x7a,0x22,0x7a,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x0a,0x04,
+/* 39718 0x9b26 "鬦" */
+0x00,0x5e,0x44,0x5e,0x44,0x5e,0x40,0x44,0x42,0x48,0x44,0x40,0x5f,0x40,0x40,0x40,
+0x00,0x7a,0x22,0x7a,0x22,0x7a,0x82,0x82,0x82,0x82,0x82,0xf2,0x82,0x82,0x8a,0x84,
+/* 39719 0x9b27 "鬧" */
+0x00,0x5e,0x44,0x5e,0x44,0x5e,0x42,0x41,0x5f,0x41,0x4f,0x49,0x49,0x49,0x41,0x41,
+0x00,0x7a,0x22,0x7a,0x22,0x7a,0x02,0x02,0xf2,0x02,0xe2,0x22,0xa2,0x42,0x0a,0x04,
+/* 39720 0x9b28 "鬨" */
+0x00,0x5e,0x44,0x5e,0x44,0x5e,0x40,0x44,0x44,0x4f,0x44,0x44,0x5f,0x44,0x48,0x40,
+0x00,0x7a,0x22,0x7a,0x22,0x7a,0x02,0x42,0x42,0xe2,0x42,0x42,0xf2,0x42,0x2a,0x04,
+/* 39721 0x9b29 "鬩" */
+0x00,0x5e,0x44,0x5e,0x44,0x5e,0x42,0x4c,0x48,0x4e,0x48,0x4f,0x42,0x44,0x58,0x40,
+0x00,0x7a,0x22,0x7a,0x22,0x7a,0x02,0xe2,0x22,0xe2,0x22,0xe2,0x82,0x92,0x7a,0x04,
+/* 39722 0x9b2a "鬪" */
+0xbe,0x88,0xbe,0x88,0xbe,0x80,0xbf,0x80,0x9e,0x92,0x92,0x9e,0x92,0x8f,0xb8,0x90,
+0xfa,0x22,0xfa,0x22,0xfa,0x02,0x12,0x12,0xfe,0x12,0x92,0x52,0x12,0x12,0x52,0x26,
+/* 39723 0x9b2b "鬫" */
+0xbe,0x88,0xbe,0x88,0xbe,0x80,0x9c,0x84,0xbf,0x92,0x9e,0x92,0x9e,0x93,0xfe,0x82,
+0xfa,0x22,0xfa,0x22,0xfa,0x02,0x42,0x7a,0x52,0x92,0x12,0x52,0x22,0xa2,0x52,0x96,
+/* 39724 0x9b2c "鬬" */
+0xbe,0x88,0xbe,0x88,0xbe,0x88,0xb3,0xaa,0xbb,0x8a,0xbb,0xa0,0xbb,0x8a,0x8b,0xbc,
+0xfa,0x22,0xfa,0x22,0xfa,0x06,0xba,0xa2,0xa2,0x3e,0xaa,0xaa,0xaa,0x2a,0xaa,0x46,
+/* 39725 0x9b2d "鬭" */
+0xbe,0x88,0xbe,0x88,0xbe,0x80,0xbb,0xaa,0xbb,0x8a,0xbb,0xa0,0xbb,0x8a,0x8b,0xbc,
+0xfa,0x22,0xfa,0x22,0xfa,0x06,0xba,0xa2,0xa2,0x3e,0xaa,0xaa,0xaa,0x2a,0xaa,0x46,
+/* 39726 0x9b2e "鬮" */
+0xbe,0x88,0xbe,0x88,0xbe,0x81,0xbf,0xa0,0xbc,0x84,0xb4,0x94,0xfc,0x94,0xb4,0x83,
+0xfa,0x22,0xfa,0x22,0xfa,0x02,0xf2,0x12,0xf2,0x82,0xf2,0x92,0xf2,0x82,0x92,0xf6,
+/* 39727 0x9b2f "鬯" */
+0x09,0x24,0x22,0x29,0x22,0x24,0x29,0x3f,0x10,0x10,0x11,0x1e,0x10,0x10,0x0f,0x00,
+0x20,0x48,0x88,0x28,0x88,0x48,0x28,0xf8,0x00,0x38,0xc0,0x04,0x04,0x04,0xfc,0x00,
+/* 39728 0x9b30 "鬰" */
+0x22,0xf9,0x22,0x72,0xa9,0x22,0x00,0x7f,0x4a,0xa4,0x2a,0x3f,0x10,0x1f,0x10,0x1f,
+0x88,0x3e,0x88,0x9c,0x2a,0x88,0x00,0xfe,0x12,0xa4,0xc8,0x90,0x24,0x48,0x10,0x20,
+/* 39729 0x9b31 "鬱" */
+0x22,0xf3,0x25,0x73,0xad,0x27,0x00,0x7f,0x4a,0xa4,0x2a,0x3f,0x10,0x1f,0x10,0x1f,
+0x08,0xbc,0x08,0x9c,0x6a,0xc8,0x00,0xfe,0x12,0xa4,0xc8,0x90,0x24,0x48,0x10,0x20,
+/* 39730 0x9b32 "鬲" */
+0x00,0xff,0x00,0x1f,0x10,0x10,0x1f,0x00,0x7f,0x48,0x44,0x5f,0x41,0x41,0x41,0x40,
+0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x00,0xfc,0x24,0x44,0xf4,0x04,0x04,0x14,0x08,
+/* 39731 0x9b33 "鬳" */
+0x01,0x01,0x3f,0x21,0x21,0x2f,0x20,0x20,0x3f,0x22,0x23,0x20,0x2f,0x29,0x4b,0x88,
+0xfc,0x00,0xfe,0x02,0xf0,0x04,0xfc,0x00,0xfe,0x08,0xf8,0x00,0xfe,0x12,0xfa,0x42,
+/* 39732 0x9b34 "鬴" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 39733 0x9b35 "鬵" */
+0x3e,0x48,0x7e,0x14,0x66,0x04,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x44,0x4f,0x41,
+0x7c,0x90,0xfc,0x2a,0xc6,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x44,0xe4,0x0c,
+/* 39734 0x9b36 "鬶" */
+0x10,0x7c,0x10,0xfe,0x28,0x45,0xff,0x00,0x1f,0x10,0x1f,0x00,0x7f,0x44,0x4f,0x41,
+0xf8,0xa8,0xa8,0x52,0x8e,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfc,0x44,0xe4,0x0c,
+/* 39735 0x9b37 "鬷" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x28,0x92,0xaa,0x82,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 39736 0x9b38 "鬸" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x92,0x86,
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 39737 0x9b39 "鬹" */
+0x08,0x3e,0x08,0x7e,0x08,0x14,0x22,0x41,0xff,0x10,0x1f,0x00,0x7f,0x44,0x4f,0x41,
+0xf8,0x88,0xf8,0x88,0xf8,0x52,0x8e,0x00,0xfe,0x10,0xf0,0x00,0xfc,0x44,0xe4,0x0c,
+/* 39738 0x9b3a "鬺" */
+0x00,0xfe,0x00,0x7d,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x93,0x92,0x92,0x86,
+0x40,0x7e,0x80,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x40,0xfe,0x2a,0x4a,0x92,0x26,
+/* 39739 0x9b3b "鬻" */
+0x71,0x15,0x71,0x47,0x73,0x15,0x31,0x00,0xff,0x10,0x1f,0x00,0x7f,0x44,0x4f,0x41,
+0x1c,0x44,0x1c,0xd0,0x9c,0x44,0x0c,0x00,0xfe,0x10,0xf0,0x00,0xfc,0x44,0xe4,0x0c,
+/* 39740 0x9b3c "鬼" */
+0x02,0x04,0x3f,0x21,0x21,0x3f,0x22,0x22,0x3f,0x05,0x09,0x09,0x11,0x21,0x41,0x80,
+0x00,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x10,0x20,0x48,0x7c,0x02,0x02,0xfe,
+/* 39741 0x9b3d "鬽" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x04,0x04,0x08,0x10,0x24,0x04,0x08,0x10,0x22,0x02,0x04,0x88,0x90,0x20,0x02,0xfe,
+/* 39742 0x9b3e "鬾" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x10,0x10,0x7e,0x10,0x10,0x10,0x7c,0x04,0x44,0x28,0x10,0xa8,0xc4,0x84,0x02,0xfe,
+/* 39743 0x9b3f "鬿" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x08,0x1c,0x60,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x00,0x02,0xfe,
+/* 39744 0x9b40 "魀" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x10,0x10,0x28,0x28,0x44,0x82,0x28,0x28,0x28,0x28,0x28,0xa8,0xa8,0x48,0x02,0xfe,
+/* 39745 0x9b41 "魁" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x08,0x48,0x28,0x28,0x08,0x48,0x28,0x28,0x0e,0xf8,0x08,0x88,0x88,0x08,0x02,0xfe,
+/* 39746 0x9b42 "魂" */
+0x00,0x00,0x7d,0x01,0x01,0x01,0xff,0x21,0x21,0x20,0x48,0x44,0xfc,0x45,0x01,0x02,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x68,0xb2,0xbe,0x20,0x22,0x1e,
+/* 39747 0x9b43 "魃" */
+0x10,0x20,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x28,0x24,0x20,0xfe,0x20,0x20,0x7c,0x44,0x54,0x88,0x94,0x24,0x40,0x02,0xfe,0x00,
+/* 39748 0x9b44 "魄" */
+0x10,0x10,0x21,0x7d,0x45,0x45,0x45,0x7d,0x45,0x44,0x44,0x44,0x7c,0x45,0x01,0x02,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x68,0xb2,0xbe,0x20,0x22,0x1e,
+/* 39749 0x9b45 "魅" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x10,0x38,0x54,0x92,0x90,0x90,0x10,0x02,0xfe,
+/* 39750 0x9b46 "魆" */
+0x10,0x20,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x14,0x12,0x10,0xfe,0x90,0x94,0x94,0x88,0x8a,0xda,0xa6,0x42,0x00,0x02,0xfe,0x00,
+/* 39751 0x9b47 "魇" */
+0x3f,0x20,0x3f,0x21,0x26,0x38,0x21,0x2f,0x28,0x2f,0x28,0x2f,0x41,0x42,0x8c,0x30,
+0xfc,0x90,0xfc,0x40,0x30,0x8c,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x50,0xfa,0x8a,0x7e,
+/* 39752 0x9b48 "魈" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x10,0x54,0x38,0x10,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0xc4,0xc4,0x4c,0x02,0xfe,
+/* 39753 0x9b49 "魉" */
+0x10,0x21,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7d,0x11,0x2b,0x2d,0x4f,0x48,0x87,0x00,
+0x00,0xfc,0x50,0x50,0xfc,0x54,0x54,0x54,0xac,0x04,0x04,0x14,0x08,0x02,0xfe,0x00,
+/* 39754 0x9b4a "魊" */
+0x10,0x20,0x7c,0x57,0x54,0x7d,0x55,0x55,0x7c,0x10,0x2b,0x2d,0x4f,0x48,0x87,0x00,
+0x10,0x14,0x12,0xfe,0x10,0xd4,0x54,0xd4,0x18,0xca,0x16,0x22,0x40,0x02,0xfe,0x00,
+/* 39755 0x9b4b "魋" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0xc8,0xfe,0x40,0x02,0xfe,
+/* 39756 0x9b4c "魌" */
+0x08,0x10,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x10,0x1a,0x2c,0x2f,0x48,0x48,0x87,
+0x24,0x24,0x7e,0x24,0x24,0x3c,0x24,0x3c,0x24,0x24,0x7e,0x80,0xa8,0x44,0x02,0xfe,
+/* 39757 0x9b4d "魍" */
+0x10,0x21,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x11,0x2b,0x2d,0x4f,0x48,0x87,0x00,
+0x00,0xfc,0x04,0x8c,0x54,0xfc,0x44,0x24,0xfc,0x44,0x74,0x04,0x0c,0x02,0xfe,0x00,
+/* 39758 0x9b4e "魎" */
+0x23,0x40,0xf8,0xab,0xaa,0xfb,0xaa,0xab,0xfa,0x22,0x56,0x5a,0x5e,0x50,0x4f,0x80,
+0xfe,0x20,0x20,0xfe,0x22,0x32,0xaa,0x76,0x66,0x22,0x22,0x2a,0x04,0x02,0xfe,0x00,
+/* 39759 0x9b4f "魏" */
+0x0c,0x70,0x11,0xff,0x39,0x55,0x93,0x01,0x11,0xfc,0x24,0x44,0x28,0x11,0x29,0xc6,
+0x20,0x40,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x40,0x68,0xb2,0xbe,0x20,0x22,0x1e,
+/* 39760 0x9b50 "魐" */
+0x10,0x20,0x7d,0x54,0x55,0x7c,0x57,0x54,0x7d,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x52,0xfe,0x00,
+/* 39761 0x9b51 "魑" */
+0x10,0x20,0x7d,0x54,0x55,0x7d,0x55,0x54,0x7d,0x11,0x2b,0x2d,0x4f,0x48,0x87,0x00,
+0x40,0x20,0xfc,0x50,0x24,0x54,0xfc,0x20,0xfc,0x44,0x54,0x74,0x0c,0x02,0xfe,0x00,
+/* 39762 0x9b52 "魒" */
+0x10,0x21,0x7c,0x55,0x55,0x7d,0x54,0x54,0x7c,0x11,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x00,0xfc,0x50,0xfc,0x54,0xfc,0x00,0xf8,0x00,0xfc,0xa8,0x24,0x60,0x02,0xfe,0x00,
+/* 39763 0x9b53 "魓" */
+0x11,0x21,0x7d,0x55,0x55,0x7c,0x55,0x54,0x7c,0x11,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0xfc,0x24,0xfc,0x24,0xfc,0xa8,0xfc,0xa8,0xa8,0xfc,0x20,0xfc,0x20,0x22,0xfe,0x00,
+/* 39764 0x9b54 "魔" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x35,0x2f,0x28,0x2f,0x28,0x2f,0x21,0x42,0x4c,0xb0,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0xf8,0x88,0xf8,0x88,0xf8,0x50,0xf8,0x8a,0x7e,
+/* 39765 0x9b55 "魕" */
+0x10,0x21,0x7d,0x54,0x55,0x7d,0x54,0x55,0x7c,0x10,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x94,0x18,0xde,0x94,0x5a,0xde,0x94,0xfe,0x90,0xd4,0xaa,0x16,0x20,0x02,0xfe,0x00,
+/* 39766 0x9b56 "魖" */
+0x10,0x20,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7d,0x11,0x2a,0x2d,0x4f,0x48,0x87,0x00,
+0x20,0x3e,0x20,0xfe,0x22,0x3c,0xe2,0x1e,0x28,0xaa,0x6c,0x28,0x7c,0x02,0xfe,0x00,
+/* 39767 0x9b57 "魗" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x02,0x7c,0x10,0xfe,0x00,0xff,0x02,0xff,0xaa,0xe7,
+0x20,0x40,0xfc,0x94,0x94,0xfc,0xa4,0xa4,0xfc,0x20,0x44,0x6a,0x6e,0xa0,0xa2,0x1e,
+/* 39768 0x9b58 "魘" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x27,0x24,0x27,0x24,0x47,0x42,0x8c,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0x94,0xa2,0xf8,0x88,0xf8,0x88,0xf8,0x52,0x3e,
+/* 39769 0x9b59 "魙" */
+0x42,0x3f,0x8a,0x4f,0x2a,0x5f,0x82,0x1f,0x11,0x1f,0x12,0x1f,0x04,0x08,0x30,0xc0,
+0x04,0xd8,0x90,0x9e,0x94,0xd4,0x24,0xf0,0x10,0xf0,0x10,0xf0,0xa8,0xba,0x82,0x7e,
+/* 39770 0x9b5a "魚" */
+0x04,0x04,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x3f,0x21,0x21,0x3f,0x00,0x48,0x44,0x84,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x88,0x44,0x44,
+/* 39771 0x9b5b "魛" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x00,0x00,0xfe,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x42,0x42,0x82,0x94,0x08,
+/* 39772 0x9b5c "魜" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x50,0x48,0x88,0x84,0x02,
+/* 39773 0x9b5d "魝" */
+0x10,0x10,0x3e,0x42,0x84,0x7f,0x49,0x49,0x7f,0x49,0x49,0x7f,0x00,0x55,0x4a,0x8a,
+0x04,0x04,0x04,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x94,0x88,
+/* 39774 0x9b5e "魞" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x80,0x40,0x20,0x20,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x48,0x44,0x44,0x84,0x02,
+/* 39775 0x9b5f "魟" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 39776 0x9b60 "魠" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x08,0x3c,0xe0,0x20,0x20,0x20,0x20,0x3e,0xe0,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 39777 0x9b61 "魡" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x40,0x7c,0x84,0x84,0x04,0x44,0x24,0x24,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 39778 0x9b62 "魢" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x84,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 39779 0x9b63 "魣" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xf8,0x08,0x50,0x20,0x10,0xfe,0x22,0x24,0x20,0x20,0x20,0x20,0x20,0xa0,0x40,
+/* 39780 0x9b64 "魤" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x50,0x50,0x50,0x92,0x92,0x94,0x98,0x90,0xb0,0xd0,0x90,0x90,0x92,0x92,0x8e,0x80,
+/* 39781 0x9b65 "魥" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x00,0xfc,0x44,0x48,0x48,0x50,0x5c,0x44,0x44,0x44,0x68,0xa8,0x90,0x98,0x24,0x42,
+/* 39782 0x9b66 "魦" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 39783 0x9b67 "魧" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x20,0x10,0x10,0xfe,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0x4a,0x4a,0x8a,0x86,0x00,
+/* 39784 0x9b68 "魨" */
+0x20,0x20,0x7c,0x45,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0xa8,0xa8,0xf8,0x22,0x22,0x22,0x1e,0x00,
+/* 39785 0x9b69 "魩" */
+0x20,0x20,0x7c,0x44,0x88,0x7f,0x52,0x52,0x7e,0x52,0x53,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x40,0x7e,0xaa,0x2a,0x2a,0x4a,0x4a,0x92,0x12,0x22,0x22,0x42,0x94,0x08,
+/* 39786 0x9b6a "魪" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x10,0x10,0x10,0x28,0x28,0x44,0x82,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 39787 0x9b6b "魫" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 39788 0x9b6c "魬" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 39789 0x9b6d "魭" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x00,0xfc,0x00,0x00,0x00,0xfe,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 39790 0x9b6e "魮" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x90,0x90,0x92,0x92,0x94,0xf4,0x98,0x90,0x90,0x90,0x92,0xb2,0xd2,0x8e,0x00,
+/* 39791 0x9b6f "魯" */
+0x08,0x1f,0x20,0x7f,0xa1,0x3f,0x21,0x3f,0x44,0x82,0x1f,0x10,0x1f,0x10,0x1f,0x10,
+0x00,0xe0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x44,0x22,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 39792 0x9b70 "魰" */
+0x20,0x20,0x7c,0x45,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x40,0x20,0x20,0xfe,0x88,0x88,0x88,0x88,0x88,0x50,0x50,0x20,0x20,0x50,0x88,0x06,
+/* 39793 0x9b71 "魱" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x00,0xfe,0x20,0x20,0x20,0x3c,0x44,0x44,0x44,0x84,0xfc,0x08,0x08,0x08,0xfe,0x00,
+/* 39794 0x9b72 "魲" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x20,0x10,0x10,0x7e,0x42,0x42,0x42,0x7e,0x42,0x40,0x40,0x40,0x40,0x80,0x80,0x00,
+/* 39795 0x9b73 "魳" */
+0x20,0x23,0x78,0x48,0x90,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x00,0xfe,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x34,0x28,0x20,0x20,0x20,
+/* 39796 0x9b74 "魴" */
+0x20,0x20,0x7c,0x45,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x20,0x10,0x10,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0xa8,0x10,
+/* 39797 0x9b75 "魵" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x53,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x08,0x28,0x28,0x28,0x44,0x44,0x82,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 39798 0x9b76 "魶" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0xaa,0xaa,0xca,0x82,0x82,0x82,0x82,0x8a,0x84,
+/* 39799 0x9b77 "魷" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x48,0x44,0x44,0x40,0xfe,0x50,0x50,0x50,0x50,0x50,0x50,0x52,0x52,0x92,0x8e,0x00,
+/* 39800 0x9b78 "魸" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x10,0x90,0x90,0x90,0x90,0xfe,0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x88,0x88,0x08,
+/* 39801 0x9b79 "魹" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x53,0x7e,0x00,0xaa,0xaa,0x00,
+0x08,0x1c,0xe0,0x20,0x20,0x3c,0xe0,0x20,0x20,0x3e,0xe0,0x20,0x22,0x22,0x22,0x1e,
+/* 39802 0x9b7a "魺" */
+0x20,0x20,0x7d,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0xfe,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 39803 0x9b7b "魻" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x20,0x20,
+/* 39804 0x9b7c "魼" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x00,0xab,0xaa,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,
+/* 39805 0x9b7d "魽" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x44,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 39806 0x9b7e "魾" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7f,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x00,0xfe,0x10,0x10,0x20,0x20,0x68,0xa4,0x22,0x22,0x20,0x20,0x20,0x00,0xfe,0x00,
+/* 39807 0x9b7f "魿" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 39808 0x9b80 "鮀" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0x10,0xfe,0x82,0x84,0x40,0x44,0x48,0x50,0x60,0x42,0x42,0x42,0x3e,0x00,
+/* 39809 0x9b81 "鮁" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x01,0xaa,0xaa,0x00,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 39810 0x9b82 "鮂" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0xaa,0xa6,0xc6,0x82,0x82,0xfe,0x82,
+/* 39811 0x9b83 "鮃" */
+0x20,0x21,0x7c,0x44,0x89,0x7e,0x52,0x52,0x7f,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 39812 0x9b84 "鮄" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x55,0x7d,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x50,0x50,0x50,0xfc,0x54,0x54,0xfc,0x50,0x50,0xfe,0x52,0x52,0x5a,0x94,0x90,0x10,
+/* 39813 0x9b85 "鮅" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x53,0x7e,0x00,0xaa,0xab,0x00,
+0x10,0x08,0x08,0x02,0x22,0x24,0x24,0xa8,0xac,0xb2,0x32,0x20,0x62,0xa2,0x1e,0x00,
+/* 39814 0x9b86 "鮆" */
+0x08,0x28,0x2e,0x28,0x2e,0xf0,0x08,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x80,0x88,0xf0,0x84,0x84,0x7c,0x00,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39815 0x9b87 "鮇" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x54,0x57,0x7c,0x54,0x54,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 39816 0x9b88 "鮈" */
+0x20,0x20,0x7c,0x44,0x88,0x7f,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x28,0x10,
+/* 39817 0x9b89 "鮉" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7f,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x44,0x44,0x44,0x44,0x94,0x88,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 39818 0x9b8a "鮊" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x20,0xfe,0x82,0x82,0x82,0x82,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 39819 0x9b8b "鮋" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x92,0x92,0x92,0xfe,0x82,
+/* 39820 0x9b8c "鮌" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x08,0x08,0xfe,0x10,0x10,0x20,0x42,0xfc,0x48,0x10,0x20,0x44,0xfe,0x42,0x00,
+/* 39821 0x9b8d "鮍" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 39822 0x9b8e "鮎" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 39823 0x9b8f "鮏" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x56,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 39824 0x9b90 "鮐" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 39825 0x9b91 "鮑" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 39826 0x9b92 "鮒" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x44,0x44,0x44,0x84,0xbe,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 39827 0x9b93 "鮓" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x40,0x7e,0xa0,0xa0,0x20,0x3c,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 39828 0x9b94 "鮔" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x80,0x80,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x80,0x80,0x80,0xfe,0x00,
+/* 39829 0x9b95 "鮕" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 39830 0x9b96 "鮖" */
+0x20,0x20,0x7d,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x53,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x7c,0x44,0xc4,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 39831 0x9b97 "鮗" */
+0x20,0x20,0x78,0x48,0x91,0x7e,0x54,0x54,0x7c,0x57,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 39832 0x9b98 "鮘" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x50,0x54,0x52,0x92,0x90,0x96,0xf8,0x90,0x90,0x90,0x90,0x90,0x8a,0x8a,0x86,0x82,
+/* 39833 0x9b99 "鮙" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xee,0x22,0x22,0xaa,0x66,0x22,0x22,0x26,0x6a,0xb2,0x22,0x22,0x22,0xaa,0x44,
+/* 39834 0x9b9a "鮚" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 39835 0x9b9b "鮛" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0x3c,0x20,0x20,0xfe,0x00,0x20,0x20,0xa8,0xa4,0x22,0x22,0xa0,0x40,
+/* 39836 0x9b9c "鮜" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 39837 0x9b9d "鮝" */
+0x11,0x09,0x7f,0x02,0xff,0x08,0x34,0xcf,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x10,0x20,0xfc,0x00,0xfe,0x20,0x18,0xe6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39838 0x9b9e "鮞" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x10,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xa2,0x8a,0x84,
+/* 39839 0x9b9f "鮟" */
+0x20,0x20,0x78,0x4b,0x92,0x7c,0x54,0x57,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xaa,0x03,
+0x40,0x20,0x20,0xfe,0x02,0x44,0x40,0xfe,0x88,0x88,0x08,0xd0,0x20,0x50,0x88,0x04,
+/* 39840 0x9ba0 "鮠" */
+0x20,0x20,0x78,0x49,0x92,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x40,0x40,0xfc,0x04,0x08,0xfe,0x00,0x7c,0x44,0x44,0x54,0x48,0x42,0x42,0x3e,0x00,
+/* 39841 0x9ba1 "鮡" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x54,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xab,0x02,
+0x50,0x50,0x50,0x52,0xd4,0x58,0x50,0x58,0xd4,0x52,0x50,0x50,0x92,0x92,0x12,0x0e,
+/* 39842 0x9ba2 "鮢" */
+0x20,0x21,0x79,0x49,0x91,0x7e,0x54,0x57,0x7c,0x54,0x54,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x70,0xa8,0xa8,0x24,0x24,0x22,0x20,0x20,
+/* 39843 0x9ba3 "鮣" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x00,0x40,0x9e,0x12,0x12,0x12,0xd2,0x12,0x12,0x12,0x5a,0x94,0x10,0x10,0x10,0x10,
+/* 39844 0x9ba4 "鮤" */
+0x7f,0x08,0x1f,0x21,0x56,0x18,0xe4,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x84,0x24,0x24,0x24,0x24,0x04,0x14,0xe8,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39845 0x9ba5 "鮥" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x52,0x52,0x7f,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x78,0x88,0x50,0x20,0x50,0x88,0x06,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 39846 0x9ba6 "鮦" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x82,0x82,0xba,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x84,
+/* 39847 0x9ba7 "鮧" */
+0x20,0x20,0x7b,0x48,0x91,0x7c,0x55,0x55,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xab,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x22,0x2a,0x54,0x50,0x88,0x04,0x02,
+/* 39848 0x9ba8 "鮨" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 39849 0x9ba9 "鮩" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7f,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 39850 0x9baa "鮪" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x55,0x7e,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 39851 0x9bab "鮫" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x40,0x20,0x20,0xfc,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x04,
+/* 39852 0x9bac "鮬" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0xfe,0x28,0x44,0x82,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x28,0x10,
+/* 39853 0x9bad "鮭" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x00,
+/* 39854 0x9bae "鮮" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x54,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xaa,0x00,
+0x84,0x44,0x48,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,
+/* 39855 0x9baf "鮯" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0x50,0x50,0x88,0x04,0xfa,0x00,0x00,0xf8,0x88,0x88,0x88,0x88,0xf8,0x88,
+/* 39856 0x9bb0 "鮰" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x00,0xfe,0x82,0x82,0xba,0xaa,0xaa,0xaa,0xaa,0xba,0x82,0x82,0xfe,0x82,0x00,
+/* 39857 0x9bb1 "鮱" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x57,0x54,0x7c,0x55,0x56,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0x84,0x98,0xe0,0x82,0x82,0x7e,0x00,
+/* 39858 0x9bb2 "鮲" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x50,0x54,0x52,0x92,0x90,0xbe,0x90,0x90,0x90,0xa8,0xa8,0xa8,0xa8,0xa4,0xa4,0xc2,
+/* 39859 0x9bb3 "鮳" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x54,0x54,0x7d,0x56,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 39860 0x9bb4 "鮴" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x48,0x48,0x48,0x88,0xfe,0x88,0x88,0x9c,0x9c,0xaa,0xaa,0xc8,0x88,0x88,0x88,0x88,
+/* 39861 0x9bb5 "鮵" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x84,0x44,0x48,0x00,0xfc,0x84,0x84,0x84,0xfc,0x48,0x48,0x48,0x48,0x8a,0x8a,0x06,
+/* 39862 0x9bb6 "鮶" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x01,0xaa,0xaa,0x00,
+0x00,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x40,0x40,0xfc,0xc4,0x44,0x44,0x7c,0x44,
+/* 39863 0x9bb7 "鮷" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x55,0x7d,0x55,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x88,0x48,0x50,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfe,0x22,0x22,0x6a,0xa4,0x20,0x20,
+/* 39864 0x9bb8 "鮸" */
+0x20,0x20,0x78,0x49,0x92,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7c,0x00,0xaa,0xab,0x02,
+0x80,0x80,0xf8,0x08,0x10,0xfc,0x24,0x24,0x24,0xfc,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 39865 0x9bb9 "鮹" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x92,0x52,0x54,0x10,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,0x82,0x8a,0x84,
+/* 39866 0x9bba "鮺" */
+0x04,0x7f,0x01,0x3f,0x04,0xff,0x14,0x2f,0xd0,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39867 0x9bbb "鮻" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 39868 0x9bbc "鮼" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x55,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x00,0xfc,0x04,0x7c,0x04,0xfc,0x00,0xfe,0x02,0xfc,0x44,0x44,0x28,0x10,0x68,0x86,
+/* 39869 0x9bbd "鮽" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xab,0xaa,0x00,
+0x10,0x10,0x28,0x28,0x44,0xba,0x10,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x20,
+/* 39870 0x9bbe "鮾" */
+0x20,0x20,0x79,0x48,0x91,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x03,
+0x04,0x1e,0xe0,0x22,0x12,0x94,0x80,0x20,0xfe,0x44,0x84,0xc8,0x30,0x28,0xc4,0x02,
+/* 39871 0x9bbf "鮿" */
+0x20,0x23,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xaa,0x00,
+0x00,0xfe,0x20,0x28,0x28,0xe8,0x28,0x28,0x28,0xe8,0x28,0x2a,0x3a,0xea,0x26,0x20,
+/* 39872 0x9bc0 "鯀" */
+0x20,0x21,0x78,0x48,0x90,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x0c,0xf0,0x20,0x44,0x88,0xf0,0x20,0x44,0xfe,0x22,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 39873 0x9bc1 "鯁" */
+0x20,0x21,0x78,0x48,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x00,0xaa,0xaa,0x03,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 39874 0x9bc2 "鯂" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xc6,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 39875 0x9bc3 "鯃" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x20,0x20,0xfc,0x44,0x44,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 39876 0x9bc4 "鯄" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7d,0x02,0xaa,0xaa,0x00,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0xb2,0xb4,0x68,0xa8,0x24,0x22,0x20,0xa0,0x40,
+/* 39877 0x9bc5 "鯅" */
+0x20,0x20,0x7b,0x48,0x90,0x7d,0x55,0x57,0x7c,0x56,0x56,0x7d,0x01,0xaa,0xaa,0x00,
+0x04,0x0e,0xb8,0x88,0x88,0x28,0x2e,0xa8,0xa8,0xa8,0xa8,0x3e,0x00,0x80,0x7e,0x00,
+/* 39878 0x9bc6 "鯆" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 39879 0x9bc7 "鯇" */
+0x20,0x20,0x79,0x49,0x92,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xab,0x02,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 39880 0x9bc8 "鯈" */
+0x10,0x11,0x12,0x20,0x2b,0x68,0x68,0xa9,0x2b,0x2d,0x29,0x29,0x29,0x20,0x21,0x22,
+0x80,0xf8,0x88,0x70,0x8e,0x80,0xf8,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x54,0x2a,
+/* 39881 0x9bc9 "鯉" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 39882 0x9bca "鯊" */
+0x20,0x12,0x44,0x20,0x08,0x73,0x28,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x40,0x48,0x44,0x14,0x60,0x80,0x00,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39883 0x9bcb "鯋" */
+0x20,0x21,0x78,0x48,0x91,0x7c,0x54,0x54,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xaa,0x00,
+0x08,0x08,0x88,0x08,0x2c,0xaa,0xaa,0x48,0x48,0x8a,0x8a,0x84,0x84,0x88,0x90,0x60,
+/* 39884 0x9bcc "鯌" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x50,0x50,0x7c,0x50,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 39885 0x9bcd "鯍" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xab,0x02,
+0x20,0x10,0xfe,0x20,0x48,0x84,0xfe,0x02,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0x2a,0x06,
+/* 39886 0x9bce "鯎" */
+0x20,0x20,0x78,0x48,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x10,0x14,0x12,0x10,0xfc,0x10,0x10,0xd4,0x54,0x54,0x54,0x48,0x4a,0x9a,0x26,0x42,
+/* 39887 0x9bcf "鯏" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x55,0x7d,0x02,0xaa,0xaa,0x00,
+0x02,0x32,0xc2,0x4a,0x4a,0x4a,0xfa,0x4a,0xca,0xea,0x5a,0x42,0x42,0x42,0x4a,0x44,
+/* 39888 0x9bd0 "鯐" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x50,0x5c,0x50,0x70,0x90,0x8e,0x00,
+/* 39889 0x9bd1 "鯑" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x55,0x54,0x7c,0x55,0x56,0x7c,0x00,0xaa,0xaa,0x00,
+0xc2,0x34,0x18,0x64,0x82,0x20,0xfe,0x50,0x90,0xfe,0x92,0x92,0x9a,0x94,0x10,0x10,
+/* 39890 0x9bd2 "鯒" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x04,0x68,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 39891 0x9bd3 "鯓" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x20,0x40,0xf8,0x88,0xf8,0x88,0xf8,0x8a,0x8c,0xf8,0x18,0x28,0x48,0x88,0x28,0x10,
+/* 39892 0x9bd4 "鯔" */
+0x20,0x20,0x7c,0x45,0x89,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x92,0x92,0x24,0x24,0x92,0x92,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 39893 0x9bd5 "鯕" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x01,
+0x88,0x88,0xfc,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x50,0x88,0x04,
+/* 39894 0x9bd6 "鯖" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 39895 0x9bd7 "鯗" */
+0x04,0x7f,0x01,0x3f,0x04,0xff,0x14,0x2f,0xd0,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x40,0xfc,0x00,0xf8,0x00,0xfe,0x10,0xe8,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39896 0x9bd8 "鯘" */
+0x20,0x21,0x78,0x48,0x93,0x7c,0x55,0x56,0x7c,0x57,0x54,0x7d,0x00,0xaa,0xaa,0x01,
+0x1c,0xe0,0x20,0x20,0xfe,0xa8,0x24,0x42,0x40,0xfe,0x88,0x08,0xd0,0x30,0x48,0x84,
+/* 39897 0x9bd9 "鯙" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x00,0xfc,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 39898 0x9bda "鯚" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x00,
+0x1c,0xe0,0x20,0xfe,0x70,0xa8,0x24,0x22,0xf8,0x10,0x20,0xfe,0x20,0x20,0xa0,0x40,
+/* 39899 0x9bdb "鯛" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x00,0xfe,0x92,0x92,0xba,0x92,0xfe,0x82,0xba,0xaa,0xaa,0xba,0x82,0x82,0x8a,0x04,
+/* 39900 0x9bdc "鯜" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x53,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x20,0x20,0xfe,0x44,0xc4,0x28,0x18,0x64,0x82,
+/* 39901 0x9bdd "鯝" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x82,0x92,0x92,0xfe,0x92,0x92,0xba,0xaa,0xaa,0xba,0x82,0x82,0xfe,0x82,
+/* 39902 0x9bde "鯞" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x55,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x04,0x7c,0x04,0xfc,0x00,0xfe,0x22,0x20,0xfc,0xa4,0xa4,0xb4,0xa8,0x20,
+/* 39903 0x9bdf "鯟" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,
+/* 39904 0x9be0 "鯠" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0xba,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 39905 0x9be1 "鯡" */
+0x20,0x20,0x78,0x4b,0x90,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x03,0xaa,0xaa,0x00,
+0x50,0x50,0x50,0xde,0x50,0x50,0x50,0xdc,0x50,0x50,0x50,0x50,0xde,0x50,0x50,0x50,
+/* 39906 0x9be2 "鯢" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x00,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 39907 0x9be3 "鯣" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x53,0x7e,0x00,0xab,0xaa,0x00,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x40,0xfe,0x2a,0x4a,0x92,0x22,0x4a,0x84,
+/* 39908 0x9be4 "鯤" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x90,0x92,0xf4,0x98,0x92,0xd2,0x8e,
+/* 39909 0x9be5 "鯥" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x48,0x84,0x22,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 39910 0x9be6 "鯦" */
+0x20,0x20,0x78,0x49,0x91,0x7e,0x54,0x54,0x7d,0x56,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x88,0x88,0xe8,0x2c,0x2a,0xa8,0x48,0xa0,0x1e,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 39911 0x9be7 "鯧" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 39912 0x9be8 "鯨" */
+0x20,0x20,0x7d,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x01,0xaa,0xaa,0x00,
+0x40,0x20,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xf8,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 39913 0x9be9 "鯩" */
+0x20,0x20,0x7c,0x44,0x88,0x7f,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0x82,0x86,
+/* 39914 0x9bea "鯪" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7d,0x00,0xaa,0xaa,0x01,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x48,0x84,0x22,0x78,0x88,0x48,0x50,0x20,0x50,0x8c,
+/* 39915 0x9beb "鯫" */
+0x20,0x23,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x03,0xaa,0xaa,0x00,
+0x00,0xe0,0x5c,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x48,0x68,0xc8,0x54,0x54,0x62,
+/* 39916 0x9bec "鯬" */
+0x06,0x38,0x08,0x7e,0x1c,0x2a,0x48,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39917 0x9bed "鯭" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x00,0xfc,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 39918 0x9bee "鯮" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x82,0x00,0x7c,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x92,0x50,0x20,
+/* 39919 0x9bef "鯯" */
+0x20,0x20,0x72,0x93,0x24,0xf8,0xaf,0xa8,0xfb,0xaa,0xaa,0xfa,0x02,0xaa,0xa8,0x00,
+0x82,0x82,0x82,0xea,0x8a,0x8a,0xfa,0x8a,0xea,0xaa,0xaa,0xaa,0xa2,0xe2,0x8a,0x84,
+/* 39920 0x9bf0 "鯰" */
+0x20,0x20,0x7c,0x44,0x88,0x7f,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x10,0x10,0x28,0x44,0xa2,0x10,0xfc,0x04,0x08,0x20,0x10,0x04,0xa2,0xa2,0xaa,0x18,
+/* 39921 0x9bf1 "鯱" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x02,
+0x10,0x10,0x1e,0x10,0xfe,0x92,0x98,0xf0,0x92,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 39922 0x9bf2 "鯲" */
+0x20,0x20,0x78,0x4b,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x88,0x48,0x08,0xf4,0x14,0x22,0x00,0xe8,0x24,0x24,0x20,0x30,0x28,0x24,0xa4,0x40,
+/* 39923 0x9bf3 "鯳" */
+0x20,0x20,0x73,0x92,0x22,0xfa,0xaa,0xaa,0xfa,0xaa,0xaa,0xfa,0x02,0xaa,0xac,0x08,
+0x40,0x20,0xfe,0x00,0x1c,0xf0,0x90,0x90,0xfe,0x90,0x90,0x90,0xaa,0xca,0xa6,0x12,
+/* 39924 0x9bf4 "鯴" */
+0x20,0x21,0x78,0x48,0x91,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0x76,0x96,0x02,
+/* 39925 0x9bf5 "鯵" */
+0x20,0x20,0x78,0x49,0x90,0x7d,0x54,0x55,0x7e,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x22,0xc4,0x18,0x60,0x80,
+/* 39926 0x9bf6 "鯶" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 39927 0x9bf7 "鯷" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x53,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x5e,0x50,0x50,0xb0,0x9e,0x00,
+/* 39928 0x9bf8 "鯸" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x53,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x40,0x5c,0x44,0x84,0xbe,0x90,0x90,0x9e,0xa8,0x88,0xbe,0x88,0x88,0x94,0x94,0xa2,
+/* 39929 0x9bf9 "鯹" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x54,0x55,0x7d,0x56,0x54,0x7d,0x00,0xaa,0xab,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 39930 0x9bfa "鯺" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x54,0x54,0x7c,0x55,0x56,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x24,0xf4,0x28,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 39931 0x9bfb "鯻" */
+0x20,0x20,0x73,0x90,0x20,0xfb,0xaa,0xaa,0xfb,0xa8,0xa9,0xfa,0x04,0xa8,0xa8,0x00,
+0x82,0x82,0xe2,0x82,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xaa,0xa2,0x82,0x8a,0x84,
+/* 39932 0x9bfc "鯼" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x28,0x92,0xaa,0x82,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 39933 0x9bfd "鯽" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xee,0xaa,0xaa,0xaa,0xea,0xaa,0xaa,0xea,0x8a,0xca,0xae,0xd8,0x88,0x08,0x08,
+/* 39934 0x9bfe "鯾" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x7e,0x48,0xbe,0xaa,0xaa,0xbe,0xaa,0xaa,0xbe,0xc8,0xa8,0x90,0x98,0xa4,0xc2,
+/* 39935 0x9bff "鯿" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x56,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 39936 0x9c00 "鰀" */
+0x20,0x23,0x78,0x49,0x90,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7d,0x01,0xaa,0xaa,0x01,
+0x1e,0xe0,0x44,0x24,0x88,0xfc,0x40,0x40,0xfe,0x80,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 39937 0x9c01 "鰁" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x10,0x20,0xfe,0x82,0xfe,0x82,0xfe,0x10,0x12,0xd4,0x58,0x54,0x94,0x92,0x50,0x20,
+/* 39938 0x9c02 "鰂" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7c,0x00,0xaa,0xab,0x02,
+0x02,0xe2,0x22,0x2a,0xea,0x2a,0x2a,0xea,0x2a,0x2a,0xea,0x02,0xc2,0xa2,0x2a,0x04,
+/* 39939 0x9c03 "鰃" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfc,0x00,0xfe,0x90,0x94,0x88,0xa8,0xc4,0x82,
+/* 39940 0x9c04 "鰄" */
+0x20,0x20,0x70,0x93,0x22,0xfb,0xaa,0xaa,0xfb,0xaa,0xaa,0xfa,0x02,0xab,0xaa,0x04,
+0x0c,0x0a,0x08,0xfe,0x08,0xf8,0x4a,0x4a,0xea,0xac,0xac,0x4c,0xaa,0x0a,0x16,0x22,
+/* 39941 0x9c05 "鰅" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x92,0x96,0xbe,0x82,0x8a,0x84,
+/* 39942 0x9c06 "鰆" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7d,0x56,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x04,0xfa,0x88,0x88,0xf8,0x88,0x88,0xf8,
+/* 39943 0x9c07 "鰇" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x55,0x7e,0x54,0x55,0x7c,0x00,0xab,0xaa,0x00,
+0x00,0xfc,0x48,0x30,0xfe,0x52,0x94,0x10,0x30,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 39944 0x9c08 "鰈" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x14,0x54,0x54,0xfe,0x54,0x54,0x5c,0x40,0x7e,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,
+/* 39945 0x9c09 "鰉" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,
+/* 39946 0x9c0a "鰊" */
+0x20,0x20,0x7b,0x48,0x91,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7c,0x00,0xab,0xaa,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 39947 0x9c0b "鰋" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x00,0xfe,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x10,0xfe,0x24,0x64,0x18,0x24,0x42,0xfe,
+/* 39948 0x9c0c "鰌" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x44,0x24,0x28,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xc6,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 39949 0x9c0d "鰍" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x55,0x56,0x7c,0x00,0xaa,0xaa,0x00,
+0x08,0x68,0x88,0x88,0xaa,0xac,0xe8,0xa8,0x88,0xc8,0xa8,0x88,0x94,0x94,0x94,0xa2,
+/* 39950 0x9c0e "鰎" */
+0x20,0x20,0x78,0x4b,0x90,0x7c,0x55,0x55,0x7f,0x54,0x54,0x7e,0x01,0xaa,0xaa,0x01,
+0x10,0x10,0x3c,0x94,0xfe,0x94,0x3c,0x10,0xbc,0x90,0xfe,0x90,0x90,0xc0,0xbe,0x00,
+/* 39951 0x9c0f "鰏" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 39952 0x9c10 "鰐" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x55,0x54,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,
+/* 39953 0x9c11 "鰑" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x55,0x7c,0x54,0x55,0x7e,0x00,0xab,0xaa,0x00,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,0x80,0xfe,0x2a,0x4a,0x92,0x22,0x54,0x88,
+/* 39954 0x9c12 "鰒" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x01,0xaa,0xaa,0x01,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 39955 0x9c13 "鰓" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7d,0x01,0xab,0xaa,0x00,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 39956 0x9c14 "鰔" */
+0x20,0x20,0x70,0x93,0x22,0xfa,0xaa,0xaa,0xfa,0xaa,0xaa,0xfa,0x02,0xaa,0xaa,0x04,
+0x08,0x0c,0x0a,0xfe,0x08,0x08,0xe8,0x0a,0x0a,0xec,0xac,0xa8,0xea,0x1a,0x26,0x42,
+/* 39957 0x9c15 "鰕" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x00,0xdc,0x44,0x44,0x44,0xdc,0x00,0x00,0xdc,0x14,0x14,0xd4,0x08,0x08,0x14,0x22,
+/* 39958 0x9c16 "鰖" */
+0x20,0x20,0x79,0x48,0x90,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x20,0xfe,0x40,0xfe,0x10,0xfe,0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,0x8a,0x84,
+/* 39959 0x9c17 "鰗" */
+0x20,0x20,0x78,0x4b,0x90,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x80,0x9e,0x92,0xf2,0x92,0x9e,0x92,0xd2,0x52,0x5e,0x52,0x52,0xd2,0x22,0x2a,0x44,
+/* 39960 0x9c18 "鰘" */
+0x20,0x20,0x79,0x49,0x92,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7d,0x00,0xaa,0xab,0x00,
+0x40,0x20,0xfe,0x02,0x04,0xfc,0x40,0x88,0xfc,0x24,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 39961 0x9c19 "鰙" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x55,0x7e,0x00,0xaa,0xaa,0x00,
+0x84,0x84,0xfe,0x84,0xa4,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 39962 0x9c1a "鰚" */
+0x20,0x20,0x79,0x49,0x92,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x02,0x04,0xfc,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x00,0xfe,0x00,
+/* 39963 0x9c1b "鰛" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x55,0x55,0x7d,0x01,0xab,0xab,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 39964 0x9c1c "鰜" */
+0x20,0x20,0x78,0x49,0x90,0x7d,0x54,0x57,0x7c,0x55,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 39965 0x9c1d "鰝" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8a,0x84,
+/* 39966 0x9c1e "鰞" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x40,0xfc,0x84,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x14,0x08,
+/* 39967 0x9c1f "鰟" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0xa2,0x10,0xfe,0x20,0x3c,0x24,0x44,0x54,0x88,
+/* 39968 0x9c20 "鰠" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x54,0x57,0x7c,0x55,0x55,0x7d,0x01,0xaa,0xab,0x00,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 39969 0x9c21 "鰡" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 39970 0x9c22 "鰢" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+/* 39971 0x9c23 "鰣" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x08,0x08,0xc8,0x7e,0x48,0x48,0x7e,0xc4,0x44,0x7e,0x44,0x64,0xd4,0x04,0x14,0x08,
+/* 39972 0x9c24 "鰤" */
+0x21,0x22,0x73,0x92,0x22,0xfa,0xab,0xaa,0xfa,0xab,0xaa,0xfa,0x02,0xab,0xaa,0x00,
+0x00,0x7e,0x88,0x88,0xbe,0xaa,0xaa,0x2a,0x2a,0xaa,0xaa,0xae,0x88,0x88,0x88,0x08,
+/* 39973 0x9c25 "鰥" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0x10,0x54,0x52,0x92,0x10,0x54,0x52,0x92,0x10,0x10,
+/* 39974 0x9c26 "鰦" */
+0x20,0x20,0x78,0x4b,0x90,0x7c,0x55,0x55,0x7e,0x57,0x54,0x7d,0x01,0xaa,0xab,0x00,
+0x84,0x44,0x48,0xfe,0x84,0x84,0x08,0x4a,0x52,0x9c,0x84,0x08,0x08,0x52,0xde,0x42,
+/* 39975 0x9c27 "鰧" */
+0x01,0x78,0x49,0x48,0x4b,0x79,0x4a,0x4c,0x49,0x7b,0x4d,0x49,0x49,0x49,0x48,0x99,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0x84,0xfa,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x00,0x54,
+/* 39976 0x9c28 "鰨" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x54,0x54,0x7d,0x54,0x55,0x7c,0x01,0xaa,0xaa,0x00,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0x00,0xdc,0x44,0x54,0xcc,0x54,0x44,0x54,0xc8,
+/* 39977 0x9c29 "鰩" */
+0x20,0x20,0x79,0x48,0x91,0x7c,0x54,0x55,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x04,0x1e,0xe0,0x02,0x22,0x94,0xfe,0x10,0x10,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 39978 0x9c2a "鰪" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xab,0x00,
+0x10,0x10,0x7e,0x10,0x10,0xfe,0x20,0x42,0xfe,0x00,0xfe,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 39979 0x9c2b "鰫" */
+0x20,0x20,0x79,0x49,0x90,0x7c,0x55,0x54,0x7c,0x55,0x56,0x7c,0x00,0xaa,0xaa,0x00,
+0x40,0x20,0xfe,0x02,0x50,0x88,0x24,0x50,0x88,0x04,0xfa,0x88,0x88,0x88,0xf8,0x88,
+/* 39980 0x9c2c "鰬" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x20,0x10,0xfe,0x44,0x28,0x10,0x28,0xc6,
+/* 39981 0x9c2d "鰭" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x54,0x7d,0x56,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x24,0xf4,0x28,0xfe,0x20,0x78,0xc2,0x3e,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 39982 0x9c2e "鰮" */
+0x20,0x20,0x78,0x48,0x90,0x7c,0x54,0x54,0x7c,0x55,0x55,0x7d,0x01,0xab,0xab,0x00,
+0x00,0xf8,0xa8,0xa8,0xd8,0x88,0xf8,0x00,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 39983 0x9c2f "鰯" */
+0x20,0x21,0x78,0x48,0x91,0x7d,0x55,0x55,0x7c,0x55,0x54,0x7c,0x01,0xaa,0xaa,0x00,
+0x00,0xdc,0x44,0x44,0xdc,0x10,0x10,0xdc,0x44,0x54,0xcc,0xcc,0x54,0x44,0x54,0xc8,
+/* 39984 0x9c30 "鰰" */
+0x22,0x21,0x79,0x48,0x93,0x7c,0x54,0x55,0x7d,0x57,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x08,0x08,0x08,0x3e,0xaa,0xaa,0xbe,0x2a,0xaa,0x6a,0x3e,0x2a,0x08,0x08,0x08,0x08,
+/* 39985 0x9c31 "鰱" */
+0x20,0x20,0x7a,0x49,0x91,0x7c,0x54,0x57,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x90,0x7e,0x00,
+/* 39986 0x9c32 "鰲" */
+0x08,0x7e,0x08,0xfe,0x10,0x1e,0x2a,0x4f,0x90,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xe6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39987 0x9c33 "鰳" */
+0x21,0x21,0x73,0x91,0x21,0xf8,0xab,0xaa,0xfa,0xab,0xa8,0xfb,0x00,0xa8,0xa8,0x00,
+0x48,0x48,0xe8,0x48,0xde,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xea,0x92,0x92,0xaa,0xc4,
+/* 39988 0x9c34 "鰴" */
+0x11,0x15,0x25,0x47,0x90,0x17,0x22,0x63,0xa4,0x27,0x2d,0x27,0x25,0x27,0x20,0x2a,
+0x10,0x50,0x50,0xd0,0x3e,0xa4,0x54,0x94,0x94,0xd4,0x54,0xc8,0x48,0xd4,0x14,0xa2,
+/* 39989 0x9c35 "鰵" */
+0x20,0x3f,0x40,0xbe,0x2a,0xff,0x4a,0x7f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x20,0x20,0x3e,0x48,0xa8,0x28,0x10,0xe8,0x46,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 39990 0x9c36 "鰶" */
+0x20,0x20,0x79,0x49,0x92,0x7d,0x54,0x55,0x7e,0x54,0x55,0x7c,0x00,0xab,0xaa,0x00,
+0x80,0x88,0xee,0x2a,0xaa,0x44,0x84,0x7a,0x00,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 39991 0x9c37 "鰷" */
+0x21,0x21,0x71,0x92,0x22,0xfe,0xaa,0xaa,0xfa,0xaa,0xaa,0xfa,0x02,0xaa,0xaa,0x02,
+0x10,0x1e,0x22,0x54,0x08,0x94,0xe2,0x88,0x88,0xbe,0x88,0xac,0x2a,0x4a,0x28,0x10,
+/* 39992 0x9c38 "鰸" */
+0x20,0x23,0x72,0x92,0x22,0xfa,0xaa,0xaa,0xfa,0xaa,0xaa,0xfa,0x02,0xaa,0xab,0x00,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xee,0xaa,0xaa,0xaa,0xee,0x00,0xfe,0x00,
+/* 39993 0x9c39 "鰹" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xab,0x00,
+0x00,0xee,0x4a,0xea,0x2a,0xe4,0x44,0x4a,0xf0,0x00,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 39994 0x9c3a "鰺" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x20,0x44,0xfe,0x44,0xaa,0xee,0x10,0x28,0x54,0xaa,0x50,0x24,0x48,0x10,0x60,
+/* 39995 0x9c3b "鰻" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0xaa,0xfe,0x00,0xfc,0x44,0x28,0x10,0x68,0x86,
+/* 39996 0x9c3c "鰼" */
+0x20,0x21,0x78,0x49,0x90,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x00,0xde,0x42,0x52,0xca,0x52,0x42,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 39997 0x9c3d "鰽" */
+0x20,0x20,0x79,0x48,0x91,0x7d,0x55,0x55,0x7d,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x50,0x50,0xfe,0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,
+/* 39998 0x9c3e "鰾" */
+0x20,0x23,0x78,0x49,0x91,0x7d,0x55,0x54,0x7d,0x54,0x57,0x7c,0x00,0xab,0xaa,0x00,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 39999 0x9c3f "鰿" */
+0x20,0x21,0x78,0x48,0x90,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x10,0xfe,0x10,0xfc,0x10,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x84,
+/* 40000 0x9c40 "鱀" */
+0x7d,0x44,0x7d,0x45,0x7c,0x48,0x54,0x6f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0xfc,0x20,0x20,0xfe,0x50,0x52,0x92,0xee,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 40001 0x9c41 "鱁" */
+0x20,0x21,0x78,0x48,0x90,0x7c,0x57,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x00,0x3e,0x88,0x90,0x2a,0x4a,0x1c,0x2c,0x4a,0x1a,0x2a,0x48,0x28,0x90,0x7e,0x00,
+/* 40002 0x9c42 "鱂" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x54,0x54,0x7f,0x55,0x55,0x7d,0x01,0xab,0xaa,0x04,
+0x48,0x48,0x5e,0x6a,0x54,0xc8,0x50,0x64,0xc4,0x7e,0x44,0x64,0x54,0x44,0x54,0x48,
+/* 40003 0x9c43 "鱃" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xab,0x00,
+0x84,0x48,0xfe,0x10,0xfc,0x20,0xfe,0x40,0x7c,0xa4,0x24,0xfc,0x44,0x44,0xfe,0x00,
+/* 40004 0x9c44 "鱄" */
+0x20,0x23,0x78,0x49,0x91,0x7d,0x55,0x55,0x7c,0x55,0x54,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x22,0xfe,0x08,0xfe,0x08,0x88,0x28,0x10,
+/* 40005 0x9c45 "鱅" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 40006 0x9c46 "鱆" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 40007 0x9c47 "鱇" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x20,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x92,0x54,0x38,0x54,0x92,0x30,
+/* 40008 0x9c48 "鱈" */
+0x20,0x21,0x78,0x4b,0x92,0x7d,0x54,0x55,0x7c,0x55,0x54,0x7d,0x00,0xaa,0xab,0x00,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 40009 0x9c49 "鱉" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x4f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0xe6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 40010 0x9c4a "鱊" */
+0x20,0x20,0x78,0x49,0x90,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0xfc,0x28,0x10,0xfe,0x52,0x94,0x50,0x20,0xfe,0xaa,0xc6,0xba,0xaa,0xba,0x82,0x86,
+/* 40011 0x9c4b "鱋" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x00,
+0x20,0x3c,0x20,0xfe,0x22,0x38,0xe4,0x1c,0x00,0x28,0xaa,0x6c,0x28,0x28,0xfe,0x00,
+/* 40012 0x9c4c "鱌" */
+0x20,0x20,0x79,0x49,0x93,0x7d,0x55,0x54,0x7c,0x55,0x54,0x7d,0x00,0xaa,0xab,0x00,
+0x80,0xf0,0x10,0xfc,0x24,0x24,0xfc,0x40,0xa4,0x58,0x98,0x34,0x54,0x92,0x50,0x20,
+/* 40013 0x9c4d "鱍" */
+0x20,0x21,0x78,0x4a,0x91,0x7e,0x55,0x54,0x7c,0x55,0x55,0x7d,0x00,0xaa,0xab,0x00,
+0x12,0xd4,0x48,0x8a,0x04,0x02,0xdc,0x54,0x62,0xc0,0x1e,0xc2,0x54,0x48,0x54,0xa2,
+/* 40014 0x9c4e "鱎" */
+0x20,0x21,0x78,0x4b,0x90,0x7d,0x56,0x54,0x7c,0x55,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x18,0xe0,0x40,0xfe,0x88,0x74,0x52,0x70,0x00,0xfc,0x04,0x74,0x54,0x74,0x04,0x0c,
+/* 40015 0x9c4f "鱏" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x10,
+/* 40016 0x9c50 "鱐" */
+0x20,0x21,0x70,0x93,0x20,0xf9,0xa8,0xaa,0xfb,0xaa,0xab,0xfa,0x03,0xaa,0xaa,0x04,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xaa,0xae,0x22,0xfe,0x22,0xae,0xaa,0xaa,0x22,
+/* 40017 0x9c51 "鱑" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x48,0x48,0xfc,0x48,0x48,0xfe,0x20,0xfc,0xa4,0xfc,0xa4,0xfc,0x00,0x48,0x84,0x02,
+/* 40018 0x9c52 "鱒" */
+0x20,0x20,0x79,0x48,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7c,0x01,0xaa,0xaa,0x00,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x9c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x88,0x48,0x18,
+/* 40019 0x9c53 "鱓" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7c,0x03,0xaa,0xaa,0x00,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,
+/* 40020 0x9c54 "鱔" */
+0x20,0x20,0x79,0x48,0x90,0x7c,0x55,0x54,0x7c,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x44,0x28,0xfe,0x10,0xfe,0x10,0xfe,0x92,0x54,0xfe,0x00,0xfe,0x82,0x82,0xfe,0x82,
+/* 40021 0x9c55 "鱕" */
+0x20,0x21,0x78,0x48,0x91,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x1c,0xe0,0xa4,0x68,0xfe,0xa8,0x24,0x02,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfc,0x84,
+/* 40022 0x9c56 "鱖" */
+0x20,0x23,0x72,0x93,0x22,0xfb,0xaa,0xaa,0xfb,0xab,0xab,0xfa,0x02,0xaa,0xac,0x09,
+0x00,0xfe,0x00,0x14,0xa4,0xf6,0x4a,0x42,0x50,0x54,0xf4,0x44,0x4a,0x8a,0x92,0x20,
+/* 40023 0x9c57 "鱗" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x54,0x55,0x7c,0x54,0x55,0x7c,0x00,0xaa,0xaa,0x01,
+0x10,0x92,0x54,0x10,0xfe,0x54,0x92,0x10,0x84,0xee,0x24,0xb4,0x5e,0x44,0x84,0x04,
+/* 40024 0x9c58 "鱘" */
+0x20,0x21,0x78,0x49,0x90,0x7d,0x54,0x55,0x7c,0x57,0x54,0x7d,0x00,0xaa,0xaa,0x00,
+0x00,0xfe,0x02,0xfe,0x02,0xfe,0x00,0xde,0x92,0xde,0x04,0xfe,0x84,0x44,0x54,0x08,
+/* 40025 0x9c59 "鱙" */
+0x20,0x20,0x78,0x48,0x91,0x7c,0x55,0x54,0x7c,0x55,0x54,0x7d,0x00,0xaa,0xaa,0x01,
+0x20,0x20,0xfc,0x20,0xfe,0x88,0xdc,0x88,0xc8,0xbc,0x00,0xfe,0x50,0x50,0x94,0x0c,
+/* 40026 0x9c5a "鱚" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x10,0x10,0xfe,0x10,0x7c,0x00,0x7c,0x44,0x7c,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,
+/* 40027 0x9c5b "鱛" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x00,
+0x44,0x24,0x28,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,
+/* 40028 0x9c5c "鱜" */
+0x22,0x22,0x74,0x95,0x29,0xfe,0xaa,0xac,0xfd,0xaf,0xaa,0xfa,0x04,0xac,0xa8,0x00,
+0x80,0x4e,0xea,0xaa,0xaa,0xea,0xac,0xaa,0xea,0x8a,0x8a,0xaa,0xac,0xe8,0xa8,0x08,
+/* 40029 0x9c5d "鱝" */
+0x20,0x21,0x78,0x48,0x93,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xab,0x02,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 40030 0x9c5e "鱞" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x57,0x54,0x7d,0x55,0x55,0x7c,0x00,0xab,0xaa,0x00,
+0x00,0xfc,0x54,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x62,0x94,0x88,0xa4,0xc2,
+/* 40031 0x9c5f "鱟" */
+0x0a,0x31,0x22,0x39,0x22,0xff,0x88,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x42,
+0x80,0x38,0x88,0x38,0x88,0xfe,0x02,0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x88,0x44,
+/* 40032 0x9c60 "鱠" */
+0x20,0x20,0x78,0x49,0x92,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x20,0x50,0x88,0x74,0x02,0xfc,0x24,0xac,0x24,0xfc,0x00,0xf8,0x88,0xf8,0x88,0xf8,
+/* 40033 0x9c61 "鱡" */
+0x20,0x20,0x73,0x92,0x22,0xfb,0xaa,0xaa,0xfb,0xaa,0xaa,0xfb,0x00,0xaa,0xac,0x00,
+0x08,0x0c,0x8a,0xfe,0x88,0xa8,0xa8,0xaa,0xfa,0xaa,0xac,0xac,0x2a,0xaa,0x56,0x22,
+/* 40034 0x9c62 "鱢" */
+0x20,0x20,0x78,0x48,0x90,0x7d,0x55,0x55,0x7d,0x54,0x57,0x7c,0x00,0xab,0xaa,0x00,
+0xf8,0x88,0x88,0xf8,0x00,0xdc,0x54,0x54,0xdc,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 40035 0x9c63 "鱣" */
+0x20,0x21,0x78,0x49,0x91,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x01,
+0x10,0xfe,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 40036 0x9c64 "鱤" */
+0x20,0x20,0x73,0x92,0x22,0xfa,0xaa,0xaa,0xfa,0xaa,0xac,0xf8,0x02,0xaa,0xac,0x00,
+0x14,0x12,0xfe,0x10,0xf0,0x14,0xf4,0xb8,0xea,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 40037 0x9c65 "鱥" */
+0x20,0x21,0x79,0x4b,0x90,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x01,
+0x20,0x38,0x20,0xfe,0x10,0x14,0xfe,0x10,0xf0,0x54,0x54,0xd4,0x68,0x4a,0x96,0x22,
+/* 40038 0x9c66 "鱦" */
+0x20,0x21,0x79,0x49,0x91,0x7c,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xab,0xaa,0x00,
+0x00,0xfc,0x54,0x54,0xdc,0x50,0xdc,0x54,0x54,0xdc,0x54,0x54,0xdc,0x50,0x52,0x3e,
+/* 40039 0x9c67 "鱧" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x54,0x55,0x7c,0x55,0x55,0x7d,0x00,0xaa,0xab,0x00,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 40040 0x9c68 "鱨" */
+0x21,0x20,0x7b,0x4a,0x90,0x7d,0x55,0x55,0x7c,0x54,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x24,0xa8,0xfe,0x8a,0xf8,0x0c,0xf0,0x02,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 40041 0x9c69 "鱩" */
+0x20,0x21,0x78,0x4b,0x92,0x7d,0x54,0x55,0x7c,0x55,0x55,0x7d,0x01,0xab,0xab,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,
+/* 40042 0x9c6a "鱪" */
+0x21,0x21,0x79,0x49,0x91,0x7c,0x55,0x54,0x7f,0x54,0x55,0x7e,0x00,0xaa,0xaa,0x00,
+0xfc,0x04,0xfc,0x04,0xfc,0x22,0xfc,0x28,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 40043 0x9c6b "鱫" */
+0x20,0x21,0x78,0x48,0x91,0x7d,0x54,0x55,0x7d,0x56,0x54,0x7c,0x00,0xab,0xaa,0x01,
+0x0e,0xf0,0xa2,0x54,0xfe,0x22,0x14,0x52,0x4a,0x38,0x40,0x7c,0x84,0x48,0x30,0xce,
+/* 40044 0x9c6c "鱬" */
+0x20,0x21,0x78,0x4b,0x92,0x7d,0x54,0x55,0x7c,0x57,0x54,0x7d,0x01,0xab,0xab,0x01,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfe,0x20,0xfc,0x54,0x54,0x54,0x0c,
+/* 40045 0x9c6d "鱭" */
+0x20,0x20,0x73,0x90,0x20,0xff,0xaa,0xaa,0xfd,0xa8,0xa9,0xf9,0x01,0xa9,0xa9,0x02,
+0x40,0x20,0xfe,0x88,0x52,0xac,0xaa,0xa8,0xac,0x00,0x04,0xfc,0x04,0xfc,0x04,0x04,
+/* 40046 0x9c6e "鱮" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x57,0x7c,0x00,0xaa,0xaa,0x01,
+0xa0,0x2c,0x34,0x24,0xac,0x34,0x54,0xdc,0x54,0x54,0xfe,0x00,0x48,0x44,0x82,0x02,
+/* 40047 0x9c6f "鱯" */
+0x20,0x21,0x78,0x48,0x90,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x01,0xaa,0xaa,0x01,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 40048 0x9c70 "鱰" */
+0x20,0x23,0x7a,0x4a,0x93,0x7c,0x55,0x54,0x7f,0x54,0x54,0x7d,0x02,0xaa,0xaa,0x00,
+0x00,0xfe,0x52,0x52,0xfe,0x24,0xfc,0x28,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,
+/* 40049 0x9c71 "鱱" */
+0x20,0x21,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x04,
+0x00,0xfe,0x28,0xfe,0x28,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x92,0xba,0x8a,0x84,
+/* 40050 0x9c72 "鱲" */
+0x21,0x22,0x71,0x90,0x23,0xfa,0xaa,0xaa,0xfb,0xaa,0xab,0xfa,0x03,0xaa,0xaa,0x03,
+0x24,0x48,0x24,0x00,0xfc,0x94,0x64,0x94,0xfc,0x48,0x68,0x48,0x6a,0x4a,0x46,0x62,
+/* 40051 0x9c73 "鱳" */
+0x21,0x21,0x72,0x92,0x23,0xf9,0xaa,0xab,0xf8,0xa8,0xab,0xf8,0x00,0xa9,0xaa,0x00,
+0x24,0x74,0x58,0xda,0xfe,0x54,0xda,0xfe,0xa2,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 40052 0x9c74 "鱴" */
+0x20,0x21,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0x44,0xfe,0x44,0x00,0xfe,0xaa,0xaa,0xfe,0x14,0xfe,0x90,0xd2,0xac,0xaa,0x96,0x22,
+/* 40053 0x9c75 "鱵" */
+0x21,0x21,0x71,0x92,0x24,0xf8,0xab,0xaa,0xfa,0xaa,0xaa,0xfa,0x02,0xaa,0xaa,0x04,
+0x10,0x10,0xde,0xa8,0x54,0x12,0xfe,0x10,0xf4,0x14,0xf4,0xa8,0xaa,0xfa,0x16,0x22,
+/* 40054 0x9c76 "鱶" */
+0x20,0x23,0x78,0x49,0x90,0x7f,0x54,0x55,0x7e,0x54,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x88,0xfe,0x20,0xfc,0x40,0xfe,0x88,0x24,0xfa,0x88,0xf8,0x88,0xfa,0x94,0xa8,0xc4,
+/* 40055 0x9c77 "鱷" */
+0x20,0x23,0x70,0x93,0x22,0xfa,0xab,0xa8,0xfb,0xa8,0xab,0xfa,0x02,0xab,0xa8,0x03,
+0x00,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,0x20,0xae,0xaa,0xaa,0xae,0x20,0xfe,
+/* 40056 0x9c78 "鱸" */
+0x20,0x20,0x78,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0xaa,0xaa,0x05,
+0x20,0x3e,0x20,0xfe,0x22,0xf8,0x22,0x7e,0x54,0x7c,0x54,0x7c,0x00,0xfe,0xaa,0xfe,
+/* 40057 0x9c79 "鱹" */
+0x20,0x23,0x78,0x48,0x91,0x7d,0x55,0x54,0x7d,0x56,0x54,0x7c,0x00,0xaa,0xaa,0x00,
+0x88,0xfe,0x88,0x00,0xdc,0x54,0xdc,0x88,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,
+/* 40058 0x9c7a "鱺" */
+0x20,0x20,0x7c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x00,0xaa,0xaa,0x01,
+0xee,0x00,0xee,0xaa,0xee,0xaa,0x10,0xfe,0xa8,0xfe,0xaa,0xfe,0xaa,0xbc,0xaa,0x36,
+/* 40059 0x9c7b "鱻" */
+0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x5e,0x24,0x7e,0x2a,0x3e,0x2a,0xbe,0x95,
+0xe0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0xa8,0x34,0x50,0xfc,0x54,0x7c,0x54,0x7c,0xaa,
+/* 40060 0x9c7c "鱼" */
+0x04,0x04,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x3f,0x21,0x21,0x3f,0x00,0x00,0xff,0x00,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x00,0xfe,0x00,
+/* 40061 0x9c7d "鱽" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1d,0xe1,0x42,
+0x00,0x00,0xfc,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x28,0x10,
+/* 40062 0x9c7e "鱾" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0xf8,0x88,0x80,0x80,0x80,0x82,0x82,0x7e,0x00,
+/* 40063 0x9c7f "鱿" */
+0x20,0x20,0x7c,0x44,0x88,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1d,0xe1,0x42,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x90,0x90,0x92,0x12,0x0e,0x00,
+/* 40064 0x9c80 "鲀" */
+0x20,0x20,0x7c,0x45,0x88,0x7d,0x55,0x55,0x7d,0x55,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0x24,0xfc,0x24,0x20,0x22,0x22,0x1e,0x00,
+/* 40065 0x9c81 "鲁" */
+0x08,0x1f,0x20,0x7f,0xa1,0x3f,0x21,0x3f,0x00,0xff,0x00,0x1f,0x10,0x1f,0x10,0x1f,
+0x00,0xe0,0x20,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,
+/* 40066 0x9c82 "鲂" */
+0x10,0x10,0x1e,0x23,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x71,0x22,
+0x20,0x10,0x10,0xfe,0x40,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x84,0x84,0x28,0x10,
+/* 40067 0x9c83 "鲃" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe0,0x40,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 40068 0x9c84 "鲄" */
+0x20,0x20,0x7d,0x44,0x88,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x00,0x1c,0xe0,0x40,
+0x00,0x00,0xfe,0x08,0x08,0xe8,0x28,0x28,0x28,0x28,0xe8,0x28,0x08,0x08,0x28,0x10,
+/* 40069 0x9c85 "鲅" */
+0x20,0x20,0x7c,0x44,0x89,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x01,0x1e,0xe0,0x40,
+0x50,0x48,0x48,0x40,0xfe,0x40,0x40,0x7c,0xa4,0xa4,0xa8,0x28,0x10,0x28,0x44,0x82,
+/* 40070 0x9c86 "鲆" */
+0x20,0x20,0x7d,0x44,0x88,0x7d,0x54,0x54,0x7c,0x57,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x00,0x00,0xfc,0x20,0x20,0x24,0xa4,0xa8,0x20,0xfe,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 40071 0x9c87 "鲇" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 40072 0x9c88 "鲈" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0f,0x71,0x22,
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x82,0x82,0x82,0xfe,0x82,0x80,0x80,0x00,0x00,0x00,
+/* 40073 0x9c89 "鲉" */
+0x20,0x20,0x7c,0x44,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,
+/* 40074 0x9c8a "鲊" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xab,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x40,0x40,0x40,0x7e,0xa0,0xa0,0x20,0x3e,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,
+/* 40075 0x9c8b "鲋" */
+0x20,0x20,0x7c,0x44,0x88,0x7d,0x56,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x44,0x44,0x44,0x84,0xbe,0x84,0x84,0xa4,0x94,0x94,0x84,0x84,0x84,0x84,0x94,0x88,
+/* 40076 0x9c8c "鲌" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x10,0x10,0x20,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 40077 0x9c8d "鲍" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 40078 0x9c8e "鲎" */
+0x22,0x11,0x00,0x7f,0x44,0x84,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,0x00,
+0x08,0x10,0x20,0xfc,0x04,0x08,0xc0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,
+/* 40079 0x9c8f "鲏" */
+0x20,0x20,0x7c,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1e,0xe2,0x44,
+0x10,0x10,0x10,0xfe,0x12,0x14,0x10,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 40080 0x9c90 "鲐" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xab,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 40081 0x9c91 "鲑" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x57,0x54,0x7c,0x54,0x55,0x7c,0x00,0x1c,0xe3,0x40,
+0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 40082 0x9c92 "鲒" */
+0x20,0x20,0x7c,0x47,0x88,0x7c,0x55,0x54,0x7c,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 40083 0x9c93 "鲓" */
+0x20,0x20,0x7d,0x44,0x88,0x7d,0x54,0x54,0x7d,0x56,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xfe,0x40,0x80,0xfc,0x04,0x04,0x28,0x10,
+/* 40084 0x9c94 "鲔" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x54,0x55,0x7e,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x20,0xfe,0x40,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0x94,0x88,
+/* 40085 0x9c95 "鲕" */
+0x20,0x21,0x7c,0x44,0x88,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x00,0xfe,0x20,0x20,0x40,0xfc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x04,0x0c,
+/* 40086 0x9c96 "鲖" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x04,0x74,0x04,0x04,0x74,0x54,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 40087 0x9c97 "鲗" */
+0x40,0x43,0x7a,0x8a,0x12,0xfa,0xaa,0xaa,0xfa,0xaa,0xaa,0xf8,0x01,0x19,0xe2,0x44,
+0x02,0xe2,0x22,0x2a,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0x82,0x42,0x22,0x0a,0x04,
+/* 40088 0x9c98 "鲘" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1e,0xe2,0x44,
+0x08,0x1c,0xe0,0x00,0x00,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 40089 0x9c99 "鲙" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x54,0x54,0x7c,0x57,0x54,0x7c,0x00,0x1d,0xe3,0x41,
+0x20,0x20,0x50,0x88,0x04,0x02,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0x04,0xfe,0x02,
+/* 40090 0x9c9a "鲚" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x00,0x1d,0xe1,0x42,
+0x40,0x20,0xfe,0x88,0x50,0x20,0x50,0x88,0x06,0x88,0x88,0x88,0x88,0x08,0x08,0x08,
+/* 40091 0x9c9b "鲛" */
+0x20,0x20,0x7c,0x45,0x88,0x7c,0x55,0x56,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x43,
+0x40,0x20,0x20,0xfe,0x00,0x88,0x04,0x02,0x88,0x88,0x50,0x50,0x20,0x50,0x88,0x06,
+/* 40092 0x9c9c "鲜" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x82,0x44,0x28,0xfe,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 40093 0x9c9d "鲝" */
+0x04,0x7f,0x01,0x3f,0x04,0xff,0x14,0x2f,0xd0,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,
+0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xc0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 40094 0x9c9e "鲞" */
+0x11,0x09,0x7f,0x02,0xff,0x08,0x34,0xcf,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,
+0x10,0x20,0xfc,0x00,0xfe,0x20,0x18,0xc6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 40095 0x9c9f "鲟" */
+0x20,0x21,0x7c,0x44,0x88,0x7c,0x54,0x55,0x7c,0x54,0x55,0x7c,0x00,0x1c,0xe0,0x40,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x08,0x08,0xfe,0x88,0x48,0x48,0x08,0x18,
+/* 40096 0x9ca0 "鲠" */
+0x20,0x21,0x7c,0x44,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x00,0x1c,0xe0,0x43,
+0x00,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0xa0,0x40,0xb0,0x0e,
+/* 40097 0x9ca1 "鲡" */
+0x40,0x43,0x78,0x88,0x13,0xfa,0xaa,0xaa,0xfb,0xaa,0xaa,0xfa,0x02,0x1a,0xe2,0x42,
+0x00,0xfe,0x00,0x00,0xde,0x52,0x52,0x52,0x5a,0xd6,0x52,0x52,0x52,0x52,0x52,0xd6,
+/* 40098 0x9ca2 "鲢" */
+0x40,0x42,0x79,0x89,0x10,0xf8,0xaf,0xa9,0xf9,0xa9,0xa9,0xf9,0x01,0x1a,0xe4,0x40,
+0x10,0x10,0x10,0x7e,0x20,0x28,0x48,0x7e,0x08,0x08,0xfe,0x08,0x08,0x88,0x7e,0x00,
+/* 40099 0x9ca3 "鲣" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe1,0x40,
+0x40,0x7e,0x52,0x52,0x54,0x48,0x54,0x62,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 40100 0x9ca4 "鲤" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7c,0x54,0x55,0x7c,0x00,0x1c,0xe3,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x00,
+/* 40101 0x9ca5 "鲥" */
+0x40,0x40,0x7b,0x8a,0x12,0xfa,0xaa,0xab,0xfa,0xaa,0xaa,0xfa,0x03,0x1a,0xe0,0x40,
+0x04,0x04,0xc4,0x44,0x7e,0x44,0x44,0xe4,0x54,0x54,0x44,0x44,0xc4,0x44,0x14,0x08,
+/* 40102 0x9ca6 "鲦" */
+0x20,0x20,0x7c,0x44,0x89,0x7c,0x54,0x57,0x7c,0x55,0x54,0x7d,0x01,0x1e,0xe0,0x40,
+0x40,0x40,0xf8,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x20,0x28,0x24,0x24,0xa0,0x40,
+/* 40103 0x9ca7 "鲧" */
+0x20,0x21,0x7c,0x44,0x88,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7c,0x01,0x1e,0xe0,0x40,
+0x0c,0xf0,0x20,0x44,0x88,0xf0,0x20,0x44,0xfe,0x22,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 40104 0x9ca8 "鲨" */
+0x20,0x12,0x44,0x20,0x08,0x73,0x28,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,
+0x40,0x48,0x44,0x14,0x60,0x80,0x00,0xc0,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 40105 0x9ca9 "鲩" */
+0x20,0x20,0x7d,0x45,0x8a,0x7c,0x54,0x54,0x7d,0x54,0x54,0x7c,0x00,0x1c,0xe1,0x42,
+0x20,0x10,0xfe,0x02,0x04,0xf8,0x00,0x00,0xfe,0x50,0x50,0x50,0x92,0x92,0x0e,0x00,
+/* 40106 0x9caa "鲪" */
+0x10,0x10,0x1e,0x22,0x25,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x01,0x0e,0x70,0x20,
+0x00,0xfc,0x24,0x24,0xfe,0x24,0x24,0xfc,0x40,0x40,0xfc,0xc4,0x44,0x44,0x7c,0x44,
+/* 40107 0x9cab "鲫" */
+0x40,0x43,0x7a,0x8a,0x12,0xfb,0xaa,0xaa,0xfa,0xab,0xaa,0xfa,0x02,0x1a,0xe3,0x40,
+0x00,0xde,0x52,0x52,0x52,0xd2,0x52,0x52,0x52,0xd2,0x1a,0x94,0x50,0xb0,0x10,0x10,
+/* 40108 0x9cac "鲬" */
+0x20,0x21,0x7c,0x44,0x88,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x00,0xf8,0x08,0xd0,0x20,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x24,0x24,0x0c,
+/* 40109 0x9cad "鲭" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x94,0x88,
+/* 40110 0x9cae "鲮" */
+0x20,0x20,0x7c,0x44,0x88,0x7d,0x54,0x54,0x7d,0x54,0x54,0x7d,0x00,0x1c,0xe0,0x41,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x48,0x84,0x22,0x78,0x88,0x48,0x50,0x20,0x50,0x8c,
+/* 40111 0x9caf "鲯" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x00,0x1c,0xe1,0x42,
+0x88,0x88,0xfc,0x88,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xfe,0x00,0x88,0x04,0x02,
+/* 40112 0x9cb0 "鲰" */
+0x20,0x23,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x03,0x1c,0xe0,0x40,
+0x00,0xe0,0x5c,0x54,0x54,0xd4,0x54,0x54,0xd4,0x54,0x48,0x68,0xc8,0x54,0x54,0x62,
+/* 40113 0x9cb1 "鲱" */
+0x20,0x20,0x7c,0x47,0x88,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x03,0x1c,0xe0,0x40,
+0x50,0x50,0x50,0xde,0x50,0x50,0x50,0xdc,0x50,0x50,0x50,0x50,0xde,0x50,0x50,0x50,
+/* 40114 0x9cb2 "鲲" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7c,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x12,0xd4,0x18,0x10,0x52,0x92,0x0e,
+/* 40115 0x9cb3 "鲳" */
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,
+/* 40116 0x9cb4 "鲴" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x00,0xfc,0x04,0x24,0x24,0xfc,0x24,0x24,0x74,0x54,0x54,0x74,0x04,0x04,0xfc,0x04,
+/* 40117 0x9cb5 "鲵" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x54,0x54,0x7c,0x00,0x1c,0xe1,0x42,
+0x00,0x40,0x9c,0x04,0x04,0xdc,0x04,0x04,0xfc,0x50,0x50,0x50,0x90,0x92,0x12,0x0e,
+/* 40118 0x9cb6 "鲶" */
+0x40,0x40,0x78,0x88,0x11,0xfa,0xa9,0xa8,0xf8,0xa8,0xa8,0xfa,0x02,0x1a,0xe4,0x40,
+0x20,0x20,0x50,0x88,0x44,0x22,0xf8,0x08,0x50,0x20,0xa4,0x82,0x8a,0x8a,0x78,0x00,
+/* 40119 0x9cb7 "鲷" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1e,0xe2,0x44,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 40120 0x9cb8 "鲸" */
+0x20,0x20,0x7d,0x44,0x88,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x01,0x1e,0xe0,0x40,
+0x40,0x20,0xfe,0x00,0x00,0xf8,0x88,0x88,0x88,0xf8,0x20,0xa8,0x24,0x22,0xa0,0x40,
+/* 40121 0x9cb9 "鲹" */
+0x20,0x20,0x7c,0x45,0x88,0x7f,0x54,0x55,0x7e,0x55,0x54,0x7c,0x01,0x1c,0xe0,0x43,
+0x40,0x48,0x84,0xfe,0x20,0xfe,0x88,0x24,0x42,0x88,0x10,0x62,0x84,0x18,0x60,0x80,
+/* 40122 0x9cba "鲺" */
+0x20,0x21,0x7c,0x44,0x89,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7c,0x00,0x1c,0xe1,0x40,
+0x00,0xfc,0x04,0x34,0xc4,0x44,0x44,0xf4,0x54,0x54,0xf4,0x44,0x54,0x76,0x96,0x02,
+/* 40123 0x9cbb "鲻" */
+0x20,0x20,0x7d,0x46,0x89,0x7c,0x54,0x54,0x7d,0x55,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x92,0x92,0x24,0x48,0x24,0x92,0x92,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,
+/* 40124 0x9cbc "鲼" */
+0x20,0x21,0x7c,0x44,0x8b,0x7c,0x54,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1c,0xe0,0x43,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0x00,0xfc,0x04,0x24,0x24,0x24,0x24,0x50,0x88,0x04,
+/* 40125 0x9cbd "鲽" */
+0x40,0x41,0x79,0x8b,0x11,0xf9,0xa9,0xa9,0xf9,0xa8,0xab,0xf8,0x00,0x19,0xe6,0x40,
+0x48,0x48,0x48,0xfe,0x48,0x48,0x78,0x00,0xfe,0x20,0xfe,0x70,0xa8,0x24,0x22,0x20,
+/* 40126 0x9cbe "鲾" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x82,
+/* 40127 0x9cbf "鲿" */
+0x20,0x21,0x7c,0x44,0x89,0x7d,0x54,0x54,0x7c,0x54,0x55,0x7c,0x00,0x1c,0xe1,0x40,
+0x20,0x24,0xa8,0x20,0xfe,0x02,0x00,0xf8,0x00,0x00,0xfe,0x20,0x40,0x88,0xfc,0x84,
+/* 40128 0x9cc0 "鳀" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2b,0x2a,0x3e,0x00,0x0e,0x71,0x22,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x20,0xa0,0xbc,0xa0,0x60,0x3e,
+/* 40129 0x9cc1 "鳁" */
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x7c,0x55,0x55,0x7d,0x01,0x1d,0xe3,0x40,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 40130 0x9cc2 "鳂" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7c,0x57,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0xfe,0x20,0x22,0x14,0x48,0x84,0x02,
+/* 40131 0x9cc3 "鳃" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7d,0x01,0x1d,0xe2,0x40,
+0x00,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x20,0x10,0x54,0x42,0x42,0x4a,0x38,0x00,
+/* 40132 0x9cc4 "鳄" */
+0x20,0x21,0x7d,0x45,0x89,0x7c,0x55,0x54,0x7d,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x00,0xdc,0x54,0x54,0xdc,0x00,0xfc,0x00,0xfe,0x80,0xfc,0x04,0x04,0x04,0x28,0x10,
+/* 40133 0x9cc5 "鳅" */
+0x40,0x40,0x7b,0x89,0x11,0xf9,0xab,0xa9,0xf9,0xab,0xad,0xf9,0x01,0x19,0xe1,0x41,
+0x08,0xc8,0x08,0x08,0x2a,0x2a,0xac,0x48,0x08,0x88,0x54,0x14,0x14,0x24,0x24,0x42,
+/* 40134 0x9cc6 "鳆" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x54,0x54,0x7c,0x54,0x54,0x7c,0x01,0x1c,0xe0,0x41,
+0x40,0x40,0xfe,0x80,0xfc,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc4,0x28,0x10,0x68,0x86,
+/* 40135 0x9cc7 "鳇" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x54,0x7f,0x54,0x54,0x7d,0x00,0x1c,0xe3,0x40,
+0x20,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,
+/* 40136 0x9cc8 "鳈" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x54,0x7c,0x57,0x54,0x7d,0x01,0x1e,0xe4,0x40,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x20,0x32,0xb4,0xa8,0x28,0x24,0x24,0xa2,0x40,
+/* 40137 0x9cc9 "鳉" */
+0x20,0x20,0x7c,0x46,0x89,0x7c,0x54,0x54,0x7d,0x56,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x90,0x90,0x9e,0xa2,0xd4,0x88,0x94,0xa4,0xfe,0x84,0xa4,0x94,0x94,0x84,0x94,0x88,
+/* 40138 0x9cca "鳊" */
+0x20,0x20,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x56,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x10,0xfe,0x02,0x02,0xfe,0x00,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xaa,0x86,
+/* 40139 0x9ccb "鳋" */
+0x20,0x21,0x7c,0x44,0x88,0x7c,0x54,0x57,0x7c,0x55,0x55,0x7d,0x01,0x1c,0xe3,0x40,
+0x00,0xfc,0xa4,0x88,0x50,0x20,0xd8,0x26,0x20,0xfc,0x24,0x24,0xfc,0x22,0xfe,0x02,
+/* 40140 0x9ccc "鳌" */
+0x08,0x7e,0x08,0xfe,0x10,0x1e,0x22,0x4f,0x90,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 40141 0x9ccd "鳍" */
+0x20,0x20,0x7d,0x44,0x8b,0x7c,0x54,0x55,0x7e,0x54,0x55,0x7d,0x01,0x1d,0xe1,0x41,
+0x40,0x44,0xf8,0x50,0xfe,0x40,0xf8,0x82,0x7e,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 40142 0x9cce "鳎" */
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x7d,0x54,0x55,0x7c,0x01,0x1c,0xe1,0x40,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0x00,0xdc,0x44,0x54,0xcc,0x54,0x44,0x54,0x88,
+/* 40143 0x9ccf "鳏" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x54,0x54,0x7c,0x55,0x54,0x7c,0x00,0x1d,0xe0,0x40,
+0x00,0xfc,0x54,0x54,0x54,0xfc,0x20,0xa8,0xa4,0x24,0x20,0xa8,0xa4,0x24,0x20,0x20,
+/* 40144 0x9cd0 "鳐" */
+0x20,0x20,0x7d,0x44,0x89,0x7c,0x54,0x55,0x7c,0x55,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x04,0x1e,0xe0,0x02,0x22,0x94,0xfe,0x10,0x10,0xfe,0x10,0x92,0x92,0x92,0xfe,0x02,
+/* 40145 0x9cd1 "鳑" */
+0x20,0x20,0x7d,0x44,0x88,0x7d,0x55,0x56,0x7c,0x55,0x54,0x7c,0x00,0x1c,0xe0,0x41,
+0x20,0x10,0xfe,0x84,0x48,0xfe,0x02,0x24,0x10,0xfe,0x40,0x7c,0x44,0x84,0x94,0x08,
+/* 40146 0x9cd2 "鳒" */
+0x20,0x20,0x7c,0x45,0x88,0x7d,0x54,0x57,0x7c,0x55,0x54,0x7c,0x01,0x1e,0xe0,0x40,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 40147 0x9cd3 "鳓" */
+0x41,0x41,0x7b,0x89,0x11,0xf8,0xab,0xaa,0xfa,0xab,0xa8,0xfb,0x00,0x18,0xe0,0x40,
+0x48,0x48,0xe8,0x48,0xde,0x8a,0xea,0xaa,0xaa,0xea,0x8a,0xea,0x92,0x92,0xaa,0xc4,
+/* 40148 0x9cd4 "鳔" */
+0x20,0x23,0x7c,0x45,0x89,0x7d,0x55,0x54,0x7d,0x54,0x57,0x7c,0x00,0x1d,0xe2,0x40,
+0x00,0xfe,0x50,0xfc,0x54,0x54,0xfc,0x00,0xfc,0x00,0xfe,0x20,0xa8,0x24,0xa2,0x40,
+/* 40149 0x9cd5 "鳕" */
+0x20,0x21,0x7c,0x47,0x8a,0x7d,0x54,0x55,0x7c,0x55,0x54,0x7d,0x00,0x1c,0xe1,0x40,
+0x00,0xfc,0x20,0xfe,0x22,0xac,0x20,0xac,0x00,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,
+/* 40150 0x9cd6 "鳖" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x4f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0xc6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 40151 0x9cd7 "鳗" */
+0x40,0x41,0x79,0x89,0x11,0xf9,0xa8,0xab,0xfa,0xab,0xa8,0xf9,0x00,0x18,0xe1,0x46,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x94,0xfc,0x00,0xf8,0x90,0x60,0x98,0x06,
+/* 40152 0x9cd8 "鳘" */
+0x20,0x3f,0x40,0xbe,0x2a,0xff,0x4a,0x7f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x00,0xff,
+0x20,0x20,0x7e,0xa8,0x28,0x10,0x28,0xc6,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfe,
+/* 40153 0x9cd9 "鳙" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x01,0x1e,0xe2,0x44,
+0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x54,0x4c,
+/* 40154 0x9cda "鳚" */
+0x40,0x43,0x7a,0x8a,0x13,0xfa,0xaa,0xaa,0xfa,0xab,0xaa,0xfa,0x05,0x1d,0xea,0x40,
+0x04,0xe4,0x24,0x24,0xee,0x04,0xe4,0x04,0x0c,0xf4,0x44,0x64,0x54,0x44,0x54,0xc8,
+/* 40155 0x9cdb "鳛" */
+0x20,0x21,0x7c,0x45,0x88,0x7d,0x54,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x00,0xde,0x42,0x52,0xca,0x52,0x42,0x20,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 40156 0x9cdc "鳜" */
+0x40,0x43,0x7a,0x8b,0x12,0xfb,0xaa,0xaa,0xfb,0xab,0xab,0xfa,0x02,0x1a,0xe4,0x49,
+0x00,0xfe,0x00,0x14,0xa4,0xf6,0x4a,0x42,0x50,0x54,0xf4,0x44,0x4a,0x8a,0x92,0x20,
+/* 40157 0x9cdd "鳝" */
+0x40,0x40,0x7b,0x88,0x11,0xf8,0xab,0xa9,0xf8,0xab,0xa8,0xf9,0x01,0x19,0xe1,0x41,
+0x88,0x50,0xfe,0x20,0xfc,0x20,0xfe,0x24,0xa8,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x04,
+/* 40158 0x9cde "鳞" */
+0x40,0x41,0x78,0x8b,0x10,0xf9,0xaa,0xa9,0xf9,0xa9,0xaa,0xfd,0x00,0x19,0xe2,0x44,
+0x20,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x04,0x04,0xde,0x44,0x54,0x9e,0x04,0x04,0x04,
+/* 40159 0x9cdf "鳟" */
+0x20,0x20,0x7d,0x44,0x89,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7c,0x01,0x1c,0xe0,0x40,
+0x88,0x50,0xfe,0x50,0xfc,0x54,0x9c,0x04,0xfc,0x04,0xfc,0x08,0xfe,0x88,0x48,0x18,
+/* 40160 0x9ce0 "鳠" */
+0x20,0x23,0x7c,0x44,0x89,0x7f,0x55,0x55,0x7d,0x55,0x55,0x7d,0x03,0x1c,0xe0,0x43,
+0x88,0xfe,0xa8,0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x88,0x70,0x8e,
+/* 40161 0x9ce1 "鳡" */
+0x40,0x40,0x7b,0x8a,0x12,0xfa,0xaa,0xaa,0xfa,0xaa,0xac,0xf8,0x02,0x1a,0xe4,0x40,
+0x14,0x12,0xfe,0x10,0xf0,0x14,0xf4,0xb8,0xea,0x16,0x42,0x24,0xa2,0x8a,0x78,0x00,
+/* 40162 0x9ce2 "鳢" */
+0x20,0x21,0x7d,0x45,0x89,0x7d,0x54,0x55,0x7c,0x55,0x55,0x7d,0x00,0x1c,0xe3,0x40,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfc,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 40163 0x9ce3 "鳣" */
+0x20,0x21,0x7c,0x45,0x89,0x7d,0x55,0x55,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x41,
+0x10,0xfe,0x00,0xfe,0x02,0x7a,0x4a,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x00,0xfe,
+/* 40164 0x9ce4 "鳤" */
+0x21,0x21,0x7d,0x46,0x88,0x7c,0x55,0x55,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x08,0x08,0xee,0x94,0x42,0x10,0xfe,0x02,0xf8,0x88,0xf8,0x80,0xfc,0x84,0xfc,0x84,
+/* 40165 0x9ce5 "鳥" */
+0x02,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x09,0x24,0x24,0x40,0x00,
+0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x24,0x94,0x94,0x28,0x10,
+/* 40166 0x9ce6 "鳦" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x00,0x00,0x3e,0x02,0x04,0x04,0x08,0x08,0x90,0x10,0xa0,0xa2,0xa2,0xa2,0x1e,0x00,
+/* 40167 0x9ce7 "鳧" */
+0x08,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x20,0x3f,0x52,0x89,0x1f,0x10,0x20,0xc0,
+0x00,0xe0,0x20,0xe0,0x20,0xe0,0x00,0xf8,0x00,0xf8,0x48,0x28,0xd8,0x42,0x42,0x3e,
+/* 40168 0x9ce8 "鳨" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x10,0x10,0x10,0x10,0x7e,0x12,0x12,0x12,0x92,0x12,0x92,0x92,0xa2,0xa2,0x4a,0x84,
+/* 40169 0x9ce9 "鳩" */
+0x20,0x20,0x21,0x21,0xf9,0x29,0x29,0x29,0x29,0x29,0x2b,0x2c,0x4a,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40170 0x9cea "鳪" */
+0x20,0x20,0x21,0x21,0x21,0x29,0x25,0x25,0x25,0x21,0x21,0x20,0x22,0x22,0x22,0x20,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40171 0x9ceb "鳫" */
+0x00,0x3f,0x21,0x22,0x27,0x24,0x27,0x24,0x27,0x24,0x27,0x24,0x27,0x40,0x4a,0x8a,
+0x00,0xfe,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x04,0xa4,0xac,
+/* 40172 0x9cec "鳬" */
+0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x0f,0x08,0x08,0x10,0x60,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x04,0x94,0x88,0x82,0x82,0x7e,
+/* 40173 0x9ced "鳭" */
+0x00,0x00,0xf9,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x29,0x28,0x4a,0x4a,0x9a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40174 0x9cee "鳮" */
+0x00,0x00,0x01,0xfd,0x05,0x05,0x49,0x29,0x11,0x11,0x29,0x24,0x46,0x82,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40175 0x9cef "鳯" */
+0x00,0x7f,0x44,0x5f,0x50,0x5f,0x50,0x5f,0x50,0x5f,0x50,0x5f,0x40,0xaa,0xaa,0x00,
+0x00,0xf8,0x08,0xc8,0x48,0xc8,0x48,0xc8,0x08,0xe8,0x08,0xea,0x2a,0xaa,0xa6,0x42,
+/* 40176 0x9cf0 "鳰" */
+0x00,0x00,0x81,0x41,0x21,0x21,0x11,0x11,0x29,0x29,0x25,0x24,0x42,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40177 0x9cf1 "鳱" */
+0x00,0x7c,0x11,0x11,0x11,0x11,0x11,0xff,0x11,0x11,0x11,0x10,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40178 0x9cf2 "鳲" */
+0x00,0x00,0x3d,0x25,0x25,0x25,0x3d,0x25,0x21,0x21,0x21,0x20,0x22,0x42,0x42,0x80,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40179 0x9cf3 "鳳" */
+0x3f,0x20,0x2f,0x22,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x2f,0x40,0x55,0x80,
+0xf8,0x08,0xe8,0x08,0xe8,0x28,0xe8,0x28,0xe8,0x08,0xf8,0x08,0xfa,0x1a,0x56,0x32,
+/* 40180 0x9cf4 "鳴" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x4a,0x02,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40181 0x9cf5 "鳵" */
+0x00,0xf8,0x49,0x49,0x49,0x49,0x49,0xf9,0x49,0x49,0x49,0x48,0x4a,0x4a,0x46,0x42,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40182 0x9cf6 "鳶" */
+0x04,0x02,0x01,0xff,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x20,0x10,0x3e,0xc0,0x22,0xfa,0x16,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40183 0x9cf7 "鳷" */
+0x10,0x10,0x11,0xff,0x11,0x11,0xfd,0x05,0x05,0x49,0x29,0x10,0x2a,0x46,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40184 0x9cf8 "鳸" */
+0x01,0x7f,0x40,0x7f,0x42,0x5f,0x50,0x5f,0x50,0x5f,0x50,0x5f,0x50,0x5f,0xaa,0x45,
+0x00,0xfc,0x04,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40185 0x9cf9 "鳹" */
+0x10,0x10,0x29,0x29,0x45,0xa5,0x11,0x11,0x01,0xfd,0x05,0x08,0x0a,0x12,0x12,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40186 0x9cfa "鳺" */
+0x10,0x10,0x11,0x7d,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x28,0x26,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40187 0x9cfb "鳻" */
+0x00,0x28,0x24,0x24,0x42,0x42,0x80,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x95,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40188 0x9cfc "鳼" */
+0x00,0x20,0x11,0x01,0xfd,0x09,0x09,0x49,0x29,0x11,0x11,0x28,0x2a,0x4a,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40189 0x9cfd "鳽" */
+0x00,0x7c,0x29,0x29,0x29,0x29,0x29,0xff,0x29,0x29,0x29,0x28,0x2a,0x2a,0x4a,0x88,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40190 0x9cfe "鳾" */
+0x00,0xfe,0x11,0x11,0x7d,0x55,0x55,0x55,0x55,0x55,0x55,0x5c,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40191 0x9cff "鳿" */
+0x00,0x00,0x7d,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1c,0xe2,0x42,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40192 0x9d00 "鴀" */
+0x00,0xfc,0x11,0x11,0x21,0x31,0x69,0x65,0xa5,0x21,0x21,0x20,0x22,0x22,0x22,0x20,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40193 0x9d01 "鴁" */
+0x00,0x0c,0x71,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x29,0x28,0x42,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40194 0x9d02 "鴂" */
+0x20,0x20,0x21,0xf9,0x29,0x29,0x29,0x29,0xfd,0x21,0x21,0x20,0x32,0x4a,0x4a,0x80,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40195 0x9d03 "鴃" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x10,0x10,0x10,0x10,0x7c,0x14,0x14,0x14,0x94,0x7e,0x90,0x90,0xa8,0xa8,0x44,0x82,
+/* 40196 0x9d04 "鴄" */
+0x00,0x00,0xfe,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0xaa,0xa6,0xc0,0x82,0xfa,0x02,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40197 0x9d05 "鴅" */
+0x00,0x78,0x49,0x49,0x69,0x59,0x49,0xfd,0x49,0x49,0x49,0x48,0x4a,0x4a,0x4a,0x98,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40198 0x9d06 "鴆" */
+0x10,0x10,0x11,0x7d,0x55,0x91,0x11,0x29,0x29,0x29,0x29,0x2c,0x4a,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40199 0x9d07 "鴇" */
+0x40,0x48,0x51,0x61,0x45,0x45,0x3d,0x11,0x11,0x11,0xfd,0x10,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40200 0x9d08 "鴈" */
+0x00,0x7f,0x44,0x45,0x49,0x49,0x59,0x69,0x49,0x49,0x49,0x49,0x48,0x4a,0x8a,0x08,
+0x00,0xfe,0x40,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x04,
+/* 40201 0x9d09 "鴉" */
+0x00,0xfc,0x09,0x49,0x49,0x49,0x89,0xff,0x19,0x19,0x29,0x28,0x4a,0x8a,0x2a,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40202 0x9d0a "鴊" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x51,0x5d,0x51,0x51,0x51,0x50,0x5e,0xf2,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40203 0x9d0b "鴋" */
+0x20,0x10,0x00,0xfe,0x20,0x20,0x3c,0x24,0x24,0x24,0x24,0x24,0x44,0x54,0x89,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40204 0x9d0c "鴌" */
+0x00,0x3f,0x01,0x7f,0x04,0x18,0xe2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0xf8,0x00,0xfc,0x40,0x30,0x0e,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40205 0x9d0d "鴍" */
+0x02,0x01,0x7f,0x08,0x07,0x18,0xe2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0x00,0xfc,0x20,0xc0,0x30,0x0e,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40206 0x9d0e "鴎" */
+0x00,0xfc,0x81,0x89,0xc9,0xa9,0x91,0x91,0xa9,0xa9,0xc9,0x80,0x82,0xfe,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40207 0x9d0f "鴏" */
+0x10,0x20,0x7c,0x44,0x7c,0x45,0x7d,0x42,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x50,0x54,0x52,0x92,0x90,0x9e,0xf0,0x90,0x90,0x90,0x90,0x90,0x8a,0x8a,0x86,0x82,
+/* 40208 0x9d10 "鴐" */
+0x10,0x7e,0x12,0x26,0xc2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x00,0x78,0x48,0x78,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40209 0x9d11 "鴑" */
+0x08,0x7e,0x12,0x0c,0x32,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x00,0x78,0x48,0x30,0xce,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40210 0x9d12 "鴒" */
+0x10,0x10,0x29,0x25,0x43,0x91,0x09,0x01,0xfd,0x05,0x09,0x50,0x22,0x12,0x12,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40211 0x9d13 "鴓" */
+0x20,0x10,0x14,0x04,0x24,0x24,0xaa,0xaa,0xa8,0x30,0x32,0x22,0x22,0x5e,0x81,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40212 0x9d14 "鴔" */
+0x08,0x1c,0xe1,0x01,0x21,0x11,0xfd,0x05,0x09,0x09,0x11,0x20,0x42,0xa2,0x1e,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40213 0x9d15 "鴕" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x10,0x08,0x08,0x7e,0x42,0x42,0x20,0x24,0xa8,0x30,0xa0,0xa2,0xa2,0xa2,0x1e,0x00,
+/* 40214 0x9d16 "鴖" */
+0x00,0x7e,0x42,0x42,0x7e,0x48,0x48,0x48,0x7e,0x48,0x48,0x48,0x4a,0x4a,0x67,0x42,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40215 0x9d17 "鴗" */
+0x20,0x10,0x11,0xfd,0x01,0x09,0x89,0x89,0x49,0x49,0x51,0x50,0x1e,0xe2,0x42,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40216 0x9d18 "鴘" */
+0x10,0x10,0x21,0x49,0xfd,0x05,0x29,0x29,0x29,0xfd,0x29,0x28,0x2a,0x4a,0x4a,0x88,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40217 0x9d19 "鴙" */
+0x20,0x20,0x21,0x7d,0x51,0x91,0x11,0x11,0xfd,0x11,0x11,0x28,0x26,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40218 0x9d1a "鴚" */
+0x10,0x20,0x7d,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x00,0x00,0xfe,0x04,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x04,0x14,0x08,
+/* 40219 0x9d1b "鴛" */
+0x20,0x3e,0x44,0xa8,0x12,0x3f,0xd0,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0xf8,0x88,0x9a,0x82,0x7e,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40220 0x9d1c "鴜" */
+0x08,0x2f,0x28,0x2f,0xf2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x44,0x78,0x42,0x3e,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40221 0x9d1d "鴝" */
+0x20,0x20,0x20,0x7e,0x42,0x82,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x02,0x02,0x15,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40222 0x9d1e "鴞" */
+0x00,0x78,0x49,0x49,0x49,0x79,0x01,0xfd,0x21,0x41,0x79,0x08,0x0a,0x0a,0x52,0x20,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40223 0x9d1f "鴟" */
+0x04,0x0e,0xf1,0x91,0x91,0x91,0xfd,0x91,0x91,0x91,0x91,0x88,0x8a,0xc6,0x92,0x08,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40224 0x9d20 "鴠" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x01,0x01,0x1c,0xe2,0x42,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40225 0x9d21 "鴡" */
+0x00,0x78,0x49,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x48,0x4e,0xf2,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40226 0x9d22 "鴢" */
+0x04,0x24,0x24,0x44,0x5f,0x94,0xe4,0x24,0x44,0x44,0x94,0xf4,0x18,0x08,0x12,0x21,
+0x08,0x10,0x3c,0x24,0xbc,0xa4,0xbc,0xa0,0xbe,0xa0,0xbe,0x82,0xaa,0xaa,0x82,0x0c,
+/* 40227 0x9d23 "鴣" */
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40228 0x9d24 "鴤" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x20,0x20,0x3c,0x44,0x68,0xa8,0x10,0x28,0xc4,0x82,0xa0,0x90,0x88,0xa0,0x10,0x08,
+/* 40229 0x9d25 "鴥" */
+0x10,0x20,0x7c,0x44,0x7c,0x45,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x20,0x10,0x10,0xfe,0x82,0x04,0x00,0x28,0x28,0x28,0x28,0x28,0x44,0x44,0x44,0x82,
+/* 40230 0x9d26 "鴦" */
+0x01,0x1f,0x11,0xff,0x02,0x1c,0xe2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0xf0,0x10,0xfe,0x80,0x70,0x0e,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40231 0x9d27 "鴧" */
+0x20,0x10,0x10,0xfe,0x82,0x84,0x00,0x78,0x48,0x48,0x48,0x4a,0x4e,0x4a,0x82,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40232 0x9d28 "鴨" */
+0x00,0x7c,0x55,0x55,0x55,0x7d,0x55,0x55,0x55,0x7d,0x55,0x10,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40233 0x9d29 "鴩" */
+0x10,0x10,0x51,0x51,0x7d,0x91,0x11,0x11,0xfd,0x11,0x11,0x28,0x26,0x42,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40234 0x9d2a "鴪" */
+0x20,0x10,0x10,0xfe,0x82,0x82,0x28,0x28,0x24,0x24,0x44,0x40,0x42,0x82,0x02,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40235 0x9d2b "鴫" */
+0x00,0x00,0xf9,0xa9,0xa9,0xa9,0xa9,0xf9,0xa9,0xa9,0xa9,0xa8,0xfa,0x8a,0x02,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40236 0x9d2c "鴬" */
+0x22,0x11,0x00,0x7f,0x42,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x08,0x10,0x20,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40237 0x9d2d "鴭" */
+0x10,0x20,0x79,0x49,0x49,0x49,0x79,0x41,0x41,0x79,0x49,0x48,0x4a,0x7a,0x4a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40238 0x9d2e "鴮" */
+0x10,0x10,0xfe,0x28,0x44,0x82,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x29,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40239 0x9d2f "鴯" */
+0x00,0xfe,0x10,0x10,0x20,0xfe,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xa2,0x8b,0x84,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40240 0x9d30 "鴰" */
+0x08,0x1c,0x70,0x10,0x10,0xfc,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40241 0x9d31 "鴱" */
+0x28,0x28,0xfd,0x29,0x29,0x01,0x05,0x45,0x29,0x29,0x11,0x10,0x2a,0x2a,0x4a,0x80,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40242 0x9d32 "鴲" */
+0x80,0x88,0xb0,0xc0,0x84,0x84,0x7c,0x00,0xf8,0x88,0x88,0xf8,0x8a,0x8a,0xfa,0x88,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40243 0x9d33 "鴳" */
+0x10,0x08,0x7e,0x42,0x94,0x10,0x10,0xfe,0x24,0x24,0x48,0x28,0x12,0x2a,0x46,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40244 0x9d34 "鴴" */
+0x10,0x10,0x27,0x40,0x90,0x10,0x2f,0x62,0xa2,0x22,0x22,0x22,0x22,0x22,0x2b,0x24,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0xfc,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40245 0x9d35 "鴵" */
+0x28,0x28,0x28,0x28,0xaa,0x6c,0x28,0x28,0x6c,0xaa,0x28,0x28,0x2a,0x4c,0x49,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40246 0x9d36 "鴶" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0x7c,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40247 0x9d37 "鴷" */
+0x7f,0x08,0x1e,0x22,0x54,0x08,0x32,0xdf,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x04,0x44,0x44,0x44,0x44,0x44,0x0c,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40248 0x9d38 "鴸" */
+0x10,0x50,0x51,0x7d,0x91,0x11,0x11,0xff,0x31,0x39,0x55,0x54,0x92,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40249 0x9d39 "鴹" */
+0x44,0x24,0x29,0xff,0x11,0x11,0x7d,0x11,0x11,0xff,0x11,0x10,0x22,0x22,0x42,0x80,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40250 0x9d3a "鴺" */
+0x10,0x10,0xfe,0x10,0x7c,0x14,0x7c,0x50,0x7e,0x12,0x12,0x16,0x28,0x24,0x45,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40251 0x9d3b "鴻" */
+0x00,0x80,0x40,0x1f,0x84,0x44,0x44,0x04,0x24,0x44,0xc4,0x47,0x5c,0x48,0x41,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40252 0x9d3c "鴼" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x10,0x10,0x3c,0x24,0x44,0x28,0x10,0x28,0xc6,0x00,0xbc,0xa4,0xa4,0xa4,0x3c,0x24,
+/* 40253 0x9d3d "鴽" */
+0x10,0xfe,0x22,0x1c,0xe2,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0x00,0x7c,0x44,0x7c,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40254 0x9d3e "鴾" */
+0x10,0x10,0x21,0x49,0xfd,0x45,0x11,0x51,0x7d,0x91,0x11,0xfc,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40255 0x9d3f "鴿" */
+0x20,0x20,0x51,0x49,0x85,0x01,0xf9,0x01,0x01,0xf9,0x89,0x88,0x8a,0xfa,0x8a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40256 0x9d40 "鵀" */
+0x08,0x13,0x30,0x57,0x90,0x13,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x18,0xe0,0x40,0xfc,0x40,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40257 0x9d41 "鵁" */
+0x20,0x10,0x01,0xfd,0x01,0x29,0x45,0x83,0x09,0x49,0x29,0x10,0x2a,0x4a,0x82,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40258 0x9d42 "鵂" */
+0x12,0x12,0x12,0x22,0x2f,0x62,0xa6,0x27,0x2a,0x2a,0x32,0x22,0x22,0x22,0x22,0x22,
+0x08,0x10,0x3c,0x24,0xbc,0x24,0x3c,0x20,0xbe,0xa0,0x3e,0x02,0x2a,0x2a,0x02,0x0c,
+/* 40259 0x9d43 "鵃" */
+0x10,0x20,0x79,0x49,0x69,0x59,0x49,0xf9,0x49,0x49,0x69,0x58,0x4a,0x4a,0x4a,0x98,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40260 0x9d44 "鵄" */
+0x00,0xfe,0x21,0x29,0x45,0xfd,0x15,0x11,0x11,0x7d,0x11,0x10,0x1e,0xe2,0x42,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40261 0x9d45 "鵅" */
+0x20,0x20,0x39,0x49,0x49,0xa9,0x11,0x29,0x45,0x85,0x79,0x48,0x4a,0x4a,0x7a,0x48,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40262 0x9d46 "鵆" */
+0x11,0x12,0x27,0x44,0x87,0x14,0x27,0x64,0xa7,0x24,0x27,0x20,0x25,0x25,0x28,0x21,
+0x00,0x00,0x9c,0x80,0x80,0x80,0xbe,0x08,0xc8,0x08,0xc8,0x48,0x48,0x48,0x68,0x90,
+/* 40263 0x9d47 "鵇" */
+0x20,0x20,0x3e,0x28,0x48,0x08,0x3c,0x28,0x28,0x28,0xfe,0x08,0x0a,0x0a,0x0a,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40264 0x9d48 "鵈" */
+0x00,0xfc,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x4d,0x78,0xca,0x0a,0x0a,0x08,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40265 0x9d49 "鵉" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x42,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x04,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40266 0x9d4a "鵊" */
+0x10,0x10,0xfe,0x10,0x10,0x54,0x54,0x54,0xba,0x11,0x10,0x28,0x28,0x44,0x85,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40267 0x9d4b "鵋" */
+0x00,0x7e,0x02,0x02,0x7e,0x40,0x41,0x41,0x3f,0x10,0x08,0x29,0xa2,0xa2,0x1f,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40268 0x9d4c "鵌" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xab,0x82,0x0c,
+0x10,0x10,0x28,0x28,0x44,0xba,0x10,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x20,
+/* 40269 0x9d4d "鵍" */
+0x20,0x10,0xfe,0x82,0x00,0x7c,0x00,0x00,0xfe,0x28,0x28,0x28,0x28,0x4a,0x4d,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40270 0x9d4e "鵎" */
+0x04,0x1e,0xe0,0x22,0x92,0x54,0x48,0x10,0xfc,0x24,0x44,0x28,0x10,0x28,0x45,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40271 0x9d4f "鵏" */
+0x10,0x14,0x10,0xfe,0x10,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x54,0x54,0x55,0x4c,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40272 0x9d50 "鵐" */
+0x00,0x00,0x7c,0x10,0x10,0x54,0x54,0x54,0xba,0x10,0x10,0x1c,0xe2,0x42,0x02,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40273 0x9d51 "鵑" */
+0x00,0xf8,0x89,0x89,0xf9,0x01,0xf9,0x89,0x89,0xf9,0x89,0x88,0xfa,0x8a,0x8a,0x98,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40274 0x9d52 "鵒" */
+0x00,0x48,0x45,0x95,0x11,0x29,0x45,0x81,0x79,0x49,0x49,0x48,0x4a,0x7a,0x4a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40275 0x9d53 "鵓" */
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x82,0x04,0x78,0x08,0x10,0x1e,0xf0,0x10,0x51,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40276 0x9d54 "鵔" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 40277 0x9d55 "鵕" */
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x12,0x2a,0x46,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40278 0x9d56 "鵖" */
+0x00,0x00,0x7d,0x45,0x45,0x7d,0x45,0x45,0x7d,0x41,0x51,0x48,0x56,0x62,0x42,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40279 0x9d57 "鵗" */
+0x42,0x24,0x18,0x24,0x52,0x10,0xff,0x20,0x28,0x7e,0xaa,0x2a,0x2a,0x2e,0x09,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40280 0x9d58 "鵘" */
+0x00,0x7e,0x12,0x12,0xff,0x12,0x12,0x7e,0x20,0x20,0x7e,0x62,0xa2,0x22,0x3f,0x22,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40281 0x9d59 "鵙" */
+0x00,0x78,0x49,0x49,0x79,0x49,0x49,0x79,0x49,0x49,0x79,0x00,0x52,0x4a,0x8a,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40282 0x9d5a "鵚" */
+0x0c,0x70,0x10,0xfe,0x10,0x38,0x54,0x92,0x00,0x38,0x28,0x28,0x2a,0x4c,0x49,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40283 0x9d5b "鵛" */
+0x00,0xfe,0x54,0x54,0xa8,0x54,0x54,0x00,0xfe,0x10,0x10,0x10,0x1e,0xf2,0x42,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40284 0x9d5c "鵜" */
+0x44,0x24,0x28,0xfc,0x14,0x14,0xfc,0x90,0x90,0xfe,0x32,0x32,0x52,0x96,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40285 0x9d5d "鵝" */
+0x04,0x36,0xe5,0x25,0x24,0xff,0x24,0x25,0x25,0x36,0xe6,0x24,0x2a,0x32,0xa1,0x40,
+0x10,0x20,0x7c,0x44,0x7c,0xc4,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0xc2,0x8c,
+/* 40286 0x9d5e "鵞" */
+0x02,0x3c,0x08,0xff,0x08,0x0e,0x78,0x08,0x1a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x40,0x50,0x48,0xfe,0x48,0x50,0x24,0x54,0x8c,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40287 0x9d5f "鵟" */
+0x28,0x11,0x68,0x14,0x24,0xd5,0x0a,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x00,0xfc,0x20,0xf8,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40288 0x9d60 "鵠" */
+0x10,0x50,0x50,0x7c,0x90,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x45,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40289 0x9d61 "鵡" */
+0x04,0x06,0x75,0x05,0x04,0xff,0x04,0x14,0x14,0x5c,0x54,0x54,0x55,0x5d,0xe3,0x41,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40290 0x9d62 "鵢" */
+0x10,0x20,0x79,0x49,0x79,0x49,0x79,0x49,0x49,0xf9,0x19,0x28,0x4a,0x8a,0x2a,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40291 0x9d63 "鵣" */
+0x10,0x10,0xfe,0x10,0x10,0x7c,0x54,0x54,0x54,0x7c,0x10,0x38,0x56,0x92,0x12,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40292 0x9d64 "鵤" */
+0x20,0x20,0x3c,0x44,0x48,0xbe,0x2a,0x2a,0x3e,0x2a,0x2a,0x3e,0x2a,0x2a,0x2b,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40293 0x9d65 "鵥" */
+0x49,0x2a,0x7f,0x08,0xff,0x08,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x04,0x24,0x24,0x24,0xa4,0x0c,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40294 0x9d66 "鵦" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x00,0xfc,0x04,0x04,0x7c,0x04,0x04,0xfe,0x10,0x92,0x54,0x38,0x54,0x92,0x50,0x20,
+/* 40295 0x9d67 "鵧" */
+0x44,0x28,0x01,0x7d,0x29,0x29,0x29,0x29,0xfd,0x29,0x29,0x28,0x2a,0x4a,0x4a,0x88,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40296 0x9d68 "鵨" */
+0x10,0x10,0x28,0x24,0x42,0xb8,0x10,0x10,0xfe,0x10,0x10,0x7c,0x44,0x44,0x7d,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40297 0x9d69 "鵩" */
+0x00,0x77,0x54,0x54,0x54,0x75,0x54,0x57,0x54,0x74,0x56,0x55,0x55,0x56,0x54,0xb4,
+0x08,0x90,0xbc,0xa4,0xbc,0xa4,0x3c,0xa0,0xbe,0xa0,0xbe,0x02,0x2a,0xaa,0x82,0x0c,
+/* 40298 0x9d6a "鵪" */
+0x10,0x10,0xfe,0x28,0x54,0x92,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x16,0x1a,0x12,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40299 0x9d6b "鵫" */
+0x10,0x10,0x1e,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x54,0x10,0xfe,0x12,0x12,0x12,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40300 0x9d6c "鵬" */
+0x00,0x77,0x55,0x55,0x55,0x77,0x55,0x55,0x55,0x77,0x55,0x55,0x55,0xb5,0x89,0x13,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40301 0x9d6d "鵭" */
+0x10,0x10,0x28,0x24,0x42,0xbc,0x10,0x10,0xfe,0x10,0x94,0x58,0x52,0x1e,0xf2,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40302 0x9d6e "鵮" */
+0x10,0x10,0x3e,0x22,0x44,0x80,0x10,0x66,0x42,0x42,0x66,0x42,0x42,0x7e,0x43,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40303 0x9d6f "鵯" */
+0x10,0x20,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7d,0x21,0x51,0xfc,0x12,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40304 0x9d70 "鵰" */
+0x00,0x7f,0x49,0x49,0x5d,0x49,0x7f,0x41,0x5d,0x55,0x55,0x5d,0x41,0x41,0x45,0x82,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40305 0x9d71 "鵱" */
+0x10,0x10,0x7c,0x10,0x10,0xfe,0x00,0x44,0x92,0x10,0x7c,0x10,0x12,0x1e,0xe2,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40306 0x9d72 "鵲" */
+0x28,0x28,0x28,0xfc,0x28,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40307 0x9d73 "鵳" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x40,0x5e,0x52,0x5e,0x52,0x5e,0x52,0x52,0x93,0x16,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40308 0x9d74 "鵴" */
+0x40,0x40,0x7e,0x82,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0b,0x04,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40309 0x9d75 "鵵" */
+0x20,0x20,0x3c,0x44,0x88,0x7e,0x52,0x52,0x7e,0x10,0x2c,0x2a,0x28,0x4a,0x4b,0x86,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40310 0x9d76 "鵶" */
+0x00,0xfe,0x28,0x28,0x28,0xee,0x82,0x82,0x82,0xee,0x28,0x28,0x2e,0xf0,0x41,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40311 0x9d77 "鵷" */
+0x10,0x08,0xff,0x81,0x40,0x77,0x55,0x55,0x55,0xb5,0x97,0x14,0x24,0x25,0x46,0x84,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40312 0x9d78 "鵸" */
+0x10,0x10,0xfe,0x10,0x28,0x44,0xfe,0x04,0x74,0x54,0x54,0x74,0x54,0x04,0x15,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40313 0x9d79 "鵹" */
+0x06,0x38,0x08,0x7e,0x1c,0x2a,0x4a,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40314 0x9d7a "鵺" */
+0x20,0x10,0xfe,0x28,0x28,0x4e,0x52,0xda,0x56,0x62,0x54,0x4c,0x48,0x54,0x65,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40315 0x9d7b "鵻" */
+0x10,0x20,0x7c,0x44,0x7d,0x46,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x50,0x48,0x80,0xfe,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x90,0x90,0xfe,0x80,0x80,
+/* 40316 0x9d7c "鵼" */
+0x20,0x10,0xfe,0x82,0x28,0x44,0x82,0x00,0x7c,0x10,0x10,0x10,0x1e,0xf2,0x42,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40317 0x9d7d "鵽" */
+0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,0x00,0xf7,0x11,0x55,0x22,0x55,0x89,0x10,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40318 0x9d7e "鵾" */
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x00,0x88,0xee,0x88,0x88,0xaa,0xcd,0x88,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40319 0x9d7f "鵿" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x03,0xaa,0xaa,0x82,0x0d,
+0x00,0xfe,0x82,0xfe,0x82,0xfe,0x00,0x14,0xe4,0x44,0x44,0xfe,0x44,0x44,0x84,0x04,
+/* 40320 0x9d80 "鶀" */
+0x10,0x20,0x7f,0x41,0x7f,0x41,0x7f,0x40,0x7f,0x40,0x7f,0x00,0xaa,0xaa,0x81,0x06,
+0x24,0x24,0x7e,0x24,0x24,0x3c,0x24,0x24,0xbc,0x24,0xa4,0xfe,0x80,0xa4,0x22,0x42,
+/* 40321 0x9d81 "鶁" */
+0x20,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x10,0x54,0x52,0x92,0x10,0x51,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40322 0x9d82 "鶂" */
+0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x28,0x28,0x28,0x28,0x4a,0x4c,0x89,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40323 0x9d83 "鶃" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0d,
+0x00,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40324 0x9d84 "鶄" */
+0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x55,0x48,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40325 0x9d85 "鶅" */
+0x00,0x54,0x55,0xa9,0xa9,0x55,0x55,0x01,0xf9,0xa9,0xa9,0xf8,0xaa,0xaa,0xfa,0x88,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40326 0x9d86 "鶆" */
+0x10,0x10,0x11,0x7d,0x11,0x55,0x55,0x55,0xbb,0x11,0x39,0x54,0x92,0x12,0x12,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40327 0x9d87 "鶇" */
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0x38,0x54,0x92,0x12,0x12,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40328 0x9d88 "鶈" */
+0x10,0x10,0xfe,0x10,0x7c,0x14,0xfe,0x14,0x7c,0x10,0xfc,0x24,0x44,0x28,0x31,0xc8,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40329 0x9d89 "鶉" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0x7c,0x04,0x08,0x1e,0xf2,0x12,0x52,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40330 0x9d8a "鶊" */
+0x10,0x08,0x7f,0x48,0x5e,0x4a,0x4a,0x7f,0x4a,0x4a,0x5e,0x48,0x54,0x92,0x22,0x40,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40331 0x9d8b "鶋" */
+0x00,0x7e,0x42,0x42,0x7e,0x48,0x48,0x7e,0x48,0x48,0x5c,0x54,0x54,0x54,0x5d,0x94,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40332 0x9d8c "鶌" */
+0x00,0x7f,0x41,0x41,0x7f,0x44,0x55,0x55,0x55,0x5f,0x44,0x55,0x55,0x57,0x9d,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40333 0x9d8d "鶍" */
+0x00,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x20,0x7e,0xaa,0x2a,0x4a,0x92,0x22,0x4b,0x04,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40334 0x9d8e "鶎" */
+0x20,0x10,0xfe,0x82,0x00,0x7c,0x00,0x00,0xfe,0x10,0x10,0x54,0x52,0x92,0x51,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40335 0x9d8f "鶏" */
+0x0e,0xf0,0x22,0x92,0x44,0x10,0x10,0x7c,0x10,0x10,0xfc,0x10,0x2a,0x26,0x42,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40336 0x9d90 "鶐" */
+0x08,0x8c,0x4a,0x48,0x3e,0x08,0xc8,0x5c,0x6a,0x48,0x48,0x48,0x4a,0x62,0x9a,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40337 0x9d91 "鶑" */
+0x2a,0x2c,0x49,0x14,0x22,0x5f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x2a,0x45,
+0xa4,0xa8,0x20,0x50,0x88,0xf4,0x10,0xf0,0x10,0xf0,0x00,0xfc,0x00,0xfc,0x44,0x2c,
+/* 40338 0x9d92 "鶒" */
+0x22,0x22,0xfa,0x22,0x27,0xfa,0xaa,0xaa,0xfa,0x22,0x72,0xaa,0x2a,0x24,0x24,0x29,
+0x08,0x10,0x3c,0x24,0xbc,0xa4,0xbc,0xa0,0xbe,0xa0,0xbe,0x82,0xaa,0xaa,0x82,0x8c,
+/* 40339 0x9d93 "鶓" */
+0x50,0x50,0xf9,0x51,0x51,0x01,0xf9,0xa9,0xa9,0xa9,0xf9,0xa8,0xaa,0xaa,0xfa,0x88,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40340 0x9d94 "鶔" */
+0x00,0x7e,0x24,0x18,0x7f,0x29,0x4a,0xa8,0x10,0x08,0xff,0x1c,0x2a,0x49,0x88,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40341 0x9d95 "鶕" */
+0x20,0x10,0x79,0x01,0x49,0x31,0xfd,0x01,0x79,0x49,0x49,0x78,0x4a,0x4a,0x7a,0x48,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40342 0x9d96 "鶖" */
+0x06,0x38,0x08,0x7e,0x08,0x1c,0x2a,0x48,0x0a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x10,0x10,0x52,0x54,0x90,0x28,0x28,0x44,0x82,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40343 0x9d97 "鶗" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x10,0x10,0x5e,0x52,0x52,0xb0,0x9f,0x00,
+0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x04,0xfe,0x00,
+/* 40344 0x9d98 "鶘" */
+0x20,0x27,0x25,0x75,0x25,0x27,0x25,0x75,0x55,0x57,0x55,0x55,0x75,0x49,0x09,0x13,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40345 0x9d99 "鶙" */
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x82,0x10,0x7c,0x54,0x54,0x54,0x5c,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40346 0x9d9a "鶚" */
+0x00,0xee,0xaa,0xaa,0xee,0x00,0x78,0x00,0xfc,0x20,0x40,0x78,0x0a,0x0a,0x2a,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40347 0x9d9b "鶛" */
+0x48,0x4a,0x6c,0x48,0x4a,0x6a,0x56,0x20,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7f,0x42,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40348 0x9d9c "鶜" */
+0x44,0xfe,0x44,0x00,0x7c,0x04,0x28,0x10,0xfe,0x32,0x54,0x90,0x12,0x12,0x52,0x20,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40349 0x9d9d "鶝" */
+0x00,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xff,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40350 0x9d9e "鶞" */
+0x02,0x07,0x3c,0x24,0x24,0x3f,0x24,0x2f,0x29,0x2f,0x29,0x2f,0x29,0x49,0x4f,0x89,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40351 0x9d9f "鶟" */
+0x20,0x10,0xfe,0x82,0x28,0x44,0x92,0x14,0x12,0xfe,0x10,0x10,0x2a,0x26,0x42,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40352 0x9da0 "鶠" */
+0x00,0xff,0x80,0xbf,0xa1,0xbf,0xa1,0xbf,0x88,0xff,0x92,0xb2,0x8c,0x92,0xa1,0xff,
+0x10,0xa0,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0xc0,0x7e,0x02,0xaa,0xaa,0x02,0x8c,
+/* 40353 0x9da1 "鶡" */
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x20,0x7e,0x92,0x52,0x6a,0x42,0x7a,0x02,0x15,0x08,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40354 0x9da2 "鶢" */
+0x0e,0xf0,0x22,0x92,0x54,0x48,0x7c,0x10,0xfe,0x20,0x3e,0x42,0x54,0x88,0x15,0x62,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40355 0x9da3 "鶣" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x40,0x7f,0x55,0x55,0x7f,0xd5,0x55,0x55,0x43,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40356 0x9da4 "鶤" */
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x12,0x12,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40357 0x9da5 "鶥" */
+0x00,0x7f,0x49,0x49,0x7f,0x40,0x5f,0x51,0x51,0x5f,0x51,0x5f,0x51,0x51,0x9f,0x11,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40358 0x9da6 "鶦" */
+0x10,0xff,0x10,0x7e,0x42,0x7e,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x7c,0x44,0x7c,0x44,0x7c,0x44,0x8c,0xf0,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40359 0x9da7 "鶧" */
+0x22,0x22,0x7f,0x22,0x2a,0x08,0x3e,0x2a,0x2a,0x2a,0xff,0x08,0x14,0x12,0x22,0x40,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40360 0x9da8 "鶨" */
+0x20,0x3c,0x44,0x78,0x08,0xfe,0x20,0x52,0x9c,0x2c,0x4a,0x98,0x2a,0x4a,0xaa,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40361 0x9da9 "鶩" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x98,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40362 0x9daa "鶪" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x7e,0x14,0x12,0xfe,0x10,0x2a,0x26,0x42,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40363 0x9dab "鶫" */
+0x10,0x10,0xfe,0x10,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0x38,0x54,0x92,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40364 0x9dac "鶬" */
+0x08,0x0c,0x12,0x29,0x44,0xbf,0x21,0x3f,0x21,0x3f,0x20,0x3f,0x51,0x51,0x9f,0x11,
+0x10,0x20,0x7c,0x44,0xfc,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40365 0x9dad "鶭" */
+0x20,0x44,0xf9,0x10,0x24,0xfe,0x00,0x55,0x82,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x10,0xfe,0x40,0x7c,0x84,0x84,0x14,0x08,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40366 0x9dae "鶮" */
+0x20,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xba,0xaa,0xba,0x82,0x8b,0x84,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40367 0x9daf "鶯" */
+0x08,0x2a,0x4d,0x14,0x22,0x7f,0x42,0x9f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x49,
+0x20,0xa4,0x28,0x50,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xfc,0x00,0xfc,0x04,0x2c,
+/* 40368 0x9db0 "鶰" */
+0x00,0x7c,0x44,0x44,0x7c,0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x28,0x45,0x84,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40369 0x9db1 "鶱" */
+0x01,0x7f,0x44,0x9f,0x04,0x3f,0x04,0xff,0x0a,0x1f,0x28,0xcf,0x08,0x0f,0x00,0x15,
+0x00,0xfe,0x42,0xf4,0x40,0xf8,0x40,0xfe,0x20,0xf0,0x28,0xe6,0x20,0xf8,0x08,0x58,
+/* 40370 0x9db2 "鶲" */
+0x28,0x44,0x92,0x20,0x48,0xfc,0x04,0x00,0xee,0x22,0xaa,0x66,0xaa,0x22,0xab,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40371 0x9db3 "鶳" */
+0x21,0x42,0xf3,0x92,0xf2,0x92,0xf3,0x82,0xfa,0x83,0xfa,0x0a,0xaa,0xab,0x8a,0x30,
+0x00,0x7e,0x88,0x88,0xbe,0xaa,0xaa,0x2a,0x2a,0xaa,0xaa,0xae,0x88,0x88,0x88,0x08,
+/* 40372 0x9db4 "鶴" */
+0x08,0x08,0x7f,0x55,0x12,0x3f,0x64,0xa4,0x3f,0x24,0x24,0x3f,0x24,0x24,0x3f,0x20,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40373 0x9db5 "鶵" */
+0x20,0x20,0x7f,0x91,0x55,0x7d,0x21,0x4a,0xa4,0x7f,0x91,0x55,0x7d,0x21,0x4a,0x84,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40374 0x9db6 "鶶" */
+0x10,0x08,0x7f,0x48,0x5e,0x4a,0x7f,0x4a,0x5e,0x48,0x5e,0x52,0x52,0x52,0x5f,0x92,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40375 0x9db7 "鶷" */
+0x20,0x10,0xfe,0x82,0x10,0x7c,0x10,0x7c,0x10,0xfe,0x10,0x7c,0x44,0x44,0x7d,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40376 0x9db8 "鶸" */
+0x00,0xee,0x22,0x22,0xee,0x88,0x88,0xee,0x22,0xaa,0x66,0x66,0xaa,0x22,0xab,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40377 0x9db9 "鶹" */
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0xff,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40378 0x9dba "鶺" */
+0x10,0x92,0x54,0xaa,0x44,0x82,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x45,0x4c,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40379 0x9dbb "鶻" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x44,0x55,0x48,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40380 0x9dbc "鶼" */
+0x22,0x14,0x00,0x7f,0x14,0x7f,0x15,0xff,0x15,0x7f,0x14,0x36,0x55,0x94,0x14,0x14,
+0x10,0x20,0x7c,0xc4,0x7c,0x44,0x7c,0xc0,0x7e,0x40,0x7e,0x02,0x2a,0xaa,0x42,0x0c,
+/* 40381 0x9dbd "鶽" */
+0x28,0x24,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7e,0x50,0x10,0xfe,0x12,0x12,0x12,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40382 0x9dbe "鶾" */
+0x10,0x10,0x11,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x10,0x12,0x12,0x10,
+0x80,0xfe,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x04,
+/* 40383 0x9dbf "鶿" */
+0x08,0x04,0x7f,0x12,0x3c,0x08,0x14,0x3e,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x40,0xfc,0x48,0xf0,0x20,0x50,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40384 0x9dc0 "鷀" */
+0x21,0x11,0x12,0xff,0x21,0x21,0x42,0x52,0x94,0xe7,0x21,0x42,0x42,0x94,0xf7,0x10,
+0x08,0x10,0x3c,0xe4,0x3c,0x24,0x3c,0xa0,0xbe,0x20,0x3e,0x02,0x2a,0xaa,0x82,0x8c,
+/* 40385 0x9dc1 "鷁" */
+0x22,0x14,0x00,0x7f,0x00,0x14,0x22,0x41,0x00,0x7f,0x55,0x55,0x55,0x57,0xfc,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0xaa,0x42,0x0c,
+/* 40386 0x9dc2 "鷂" */
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x3c,0x50,0x10,0xfe,0x10,0x54,0x54,0x5c,0x65,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40387 0x9dc3 "鷃" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x08,0xff,0x81,0x10,0xff,0x22,0x64,0x18,0x25,0xc2,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40388 0x9dc4 "鷄" */
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x45,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40389 0x9dc5 "鷅" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xfe,0x10,0x10,0xfe,0x38,0x54,0x92,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40390 0x9dc6 "鷆" */
+0x46,0x78,0x40,0x3f,0x00,0x5f,0x51,0x5f,0x51,0x5f,0x51,0x5f,0x40,0x7f,0x22,0x41,
+0x10,0x20,0xfc,0xc4,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0xaa,0x42,0x0c,
+/* 40391 0x9dc7 "鷇" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x92,0x7c,0x44,0x7c,0x44,0x7e,0x40,0x7f,0x01,0xab,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 40392 0x9dc8 "鷈" */
+0x20,0x40,0xf3,0x92,0xf2,0x92,0xf2,0x82,0xfa,0x82,0xfa,0x0a,0xaa,0xac,0x8d,0x3a,
+0x04,0x1e,0xf0,0x1e,0x10,0xfe,0x92,0x98,0xf2,0x8e,0x80,0xb8,0xa8,0xaa,0x4a,0x86,
+/* 40393 0x9dc9 "鷉" */
+0x03,0x7c,0x47,0x44,0x5f,0x55,0x56,0x5c,0x55,0x53,0x50,0x57,0x55,0x55,0xa9,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0xc2,0x0c,
+/* 40394 0x9dca "鷊" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x92,0x92,0x93,0x86,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40395 0x9dcb "鷋" */
+0x22,0x22,0xff,0x22,0x2a,0x14,0x22,0x5d,0x88,0x08,0x7f,0x08,0x2a,0x49,0xa8,0x10,
+0x08,0x10,0xbc,0x24,0x3c,0x24,0x3c,0x20,0xbe,0x20,0x3e,0x02,0x2a,0x2a,0x82,0x0c,
+/* 40396 0x9dcc "鷌" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x82,0x0c,
+0x00,0xfe,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x02,0xaa,0xaa,0xaa,0x82,0x14,0x08,
+/* 40397 0x9dcd "鷍" */
+0x10,0x20,0x7d,0x45,0x7d,0x45,0x7d,0x45,0x7d,0x11,0xfd,0x10,0x3a,0x56,0x92,0x10,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40398 0x9dce "鷎" */
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x28,0x54,0x92,0x7c,0x10,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40399 0x9dcf "鷏" */
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x28,0x45,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40400 0x9dd0 "鷐" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x00,0x7f,0x40,0x5e,0x40,0x7f,0x55,0x52,0x59,0x91,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40401 0x9dd1 "鷑" */
+0x44,0x44,0x77,0xaa,0x11,0x20,0x10,0xff,0x00,0x04,0x44,0x24,0x28,0x0e,0xf1,0x40,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40402 0x9dd2 "鷒" */
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x12,0xfe,0x08,0xfe,0x48,0x29,0x18,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40403 0x9dd3 "鷓" */
+0x10,0x08,0x7f,0x40,0x52,0x52,0x7f,0x52,0x52,0x5e,0x40,0x55,0x55,0x55,0x80,0x00,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40404 0x9dd4 "鷔" */
+0x08,0x7f,0x08,0x7e,0x08,0xff,0x10,0x1e,0x22,0x5f,0x90,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x20,0x7e,0x44,0xa4,0x28,0x10,0x28,0x44,0xf2,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40405 0x9dd5 "鷕" */
+0x00,0x79,0x4b,0x4d,0x49,0x49,0x79,0x01,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x90,0xfe,0x20,0xfc,0x20,0xfc,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40406 0x9dd6 "鷖" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40407 0x9dd7 "鷗" */
+0x00,0xfe,0x80,0x80,0xbc,0xa4,0xa4,0xbc,0x80,0xee,0xaa,0xaa,0xee,0x80,0xff,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40408 0x9dd8 "鷘" */
+0x08,0xff,0x08,0x7f,0x49,0x7f,0x2a,0x49,0x82,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0xa0,0x3e,0x44,0xa8,0x10,0x28,0x46,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40409 0x9dd9 "鷙" */
+0x08,0x7e,0x08,0xff,0x14,0x7f,0x08,0xff,0x0a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x20,0xf8,0x28,0x28,0x6a,0x2a,0x56,0x82,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40410 0x9dda "鷚" */
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x10,0x28,0x44,0x92,0x20,0xc8,0x32,0xc4,0x19,0xe0,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40411 0x9ddb "鷛" */
+0x02,0x3f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x22,0x2f,0x2a,0x2f,0x4a,0x4f,0x8a,0x09,
+0x08,0xd0,0x3c,0xa4,0xbc,0xe4,0xbc,0xa0,0x3e,0xa0,0xbe,0x82,0xaa,0xaa,0x82,0x8c,
+/* 40412 0x9ddc "鷜" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x21,0x72,0x0c,0xf3,
+0x10,0x20,0x7c,0xc4,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40413 0x9ddd "鷝" */
+0x00,0xfe,0x92,0xfe,0x92,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0xfe,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40414 0x9dde "鷞" */
+0x10,0x10,0xfe,0x10,0xba,0x54,0xba,0x10,0xba,0x54,0xba,0x10,0x2a,0x26,0x42,0x80,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40415 0x9ddf "鷟" */
+0x20,0x10,0xfd,0x20,0x3d,0x24,0x44,0x55,0x8a,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x80,0xfc,0x40,0xf8,0x20,0xfc,0x50,0x88,0x04,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40416 0x9de0 "鷠" */
+0x20,0x20,0x79,0x49,0x91,0x7d,0x55,0x55,0x7d,0x55,0x55,0x7c,0x02,0xaa,0xaa,0x00,
+0x40,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x00,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40417 0x9de1 "鷡" */
+0x20,0x20,0x7f,0xd5,0x55,0x55,0xff,0x55,0x55,0x55,0xff,0x00,0x6a,0x55,0x95,0x00,
+0x08,0x10,0xbc,0x24,0x3c,0x24,0xbc,0x20,0x3e,0x20,0xbe,0x02,0x2a,0x2a,0x02,0x0c,
+/* 40418 0x9de2 "鷢" */
+0x3f,0x28,0x25,0x3f,0x22,0x2a,0x2f,0x22,0x25,0x2f,0x24,0x27,0x24,0x47,0x40,0x8a,
+0xfe,0x90,0x10,0xde,0x22,0x88,0x88,0x94,0x22,0xf0,0x10,0xf0,0x10,0xfc,0x04,0xac,
+/* 40419 0x9de3 "鷣" */
+0x00,0xfe,0x28,0xfe,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40420 0x9de4 "鷤" */
+0x00,0xee,0xaa,0xaa,0xee,0x00,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x12,0x12,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40421 0x9de5 "鷥" */
+0x10,0x24,0x78,0x14,0x7e,0x00,0x54,0x55,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x48,0xf0,0x28,0xfc,0x20,0xa8,0x64,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40422 0x9de6 "鷦" */
+0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0xaa,0xab,0x00,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40423 0x9de7 "鷧" */
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0x82,0x7c,0x00,0x7c,0x44,0x7c,0x44,0x28,0x0f,0xf0,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40424 0x9de8 "鷨" */
+0x44,0x44,0xfe,0x44,0x00,0xfe,0x54,0x54,0xfe,0x54,0x54,0xfe,0x10,0xfe,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40425 0x9de9 "鷩" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x41,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0x46,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40426 0x9dea "鷪" */
+0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x7f,0x42,0x9f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x00,0xf8,0x88,0xf8,0x88,0xf8,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40427 0x9deb "鷫" */
+0x08,0x7f,0x09,0xff,0x09,0x7f,0x08,0xaa,0xeb,0x88,0xff,0x88,0xeb,0xaa,0xaa,0x08,
+0x08,0x10,0x3c,0xa4,0x3c,0x24,0x3c,0xa0,0xbe,0xa0,0xbe,0x82,0xaa,0xaa,0x82,0x8c,
+/* 40428 0x9dec "鷬" */
+0x28,0x28,0x7c,0x28,0x28,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x00,0x28,0x45,0x82,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40429 0x9ded "鷭" */
+0x0e,0xf0,0x92,0x54,0xfe,0x38,0x54,0x82,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7d,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40430 0x9dee "鷮" */
+0x06,0x78,0x10,0xff,0x22,0x5d,0x94,0x1c,0x00,0x7f,0x41,0x5d,0x55,0x5d,0x41,0x43,
+0x10,0x20,0x7c,0xc4,0x7c,0x44,0xfc,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40431 0x9def "鷯" */
+0x08,0x08,0x7f,0x08,0x55,0x22,0x41,0xbe,0x22,0x3e,0x22,0x3e,0x08,0x2a,0x49,0x18,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0xc0,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40432 0x9df0 "鷰" */
+0x04,0xff,0x04,0x17,0xf0,0x17,0x34,0xd7,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x40,0xfe,0x40,0xd2,0x1c,0xd0,0x52,0xce,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40433 0x9df1 "鷱" */
+0x20,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x10,0x92,0x54,0x92,0x10,0xfe,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40434 0x9df2 "鷲" */
+0x08,0x7f,0x00,0x3e,0x22,0x3e,0x49,0x98,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x28,0x24,0xfe,0x20,0x50,0x50,0x52,0x8e,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40435 0x9df3 "鷳" */
+0xee,0xaa,0xee,0xaa,0xee,0x82,0xba,0xaa,0xba,0xaa,0xba,0xaa,0xaa,0xda,0x83,0x86,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40436 0x9df4 "鷴" */
+0x00,0xee,0xaa,0xee,0xaa,0xee,0x92,0x92,0xfe,0x92,0xba,0xd6,0x92,0x92,0x8b,0x84,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40437 0x9df5 "鷵" */
+0x00,0x7f,0x41,0x41,0x7f,0x48,0x5d,0x4a,0x7f,0x48,0x5e,0x72,0x5e,0x52,0x5f,0x92,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40438 0x9df6 "鷶" */
+0x00,0xfe,0xaa,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x00,0x29,0x44,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40439 0x9df7 "鷷" */
+0x22,0x14,0xff,0x14,0x7f,0x55,0x63,0x5d,0x41,0x7f,0x04,0xff,0x44,0x24,0x25,0x0c,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40440 0x9df8 "鷸" */
+0x7e,0x14,0x08,0xff,0x29,0x4a,0xa8,0x10,0x7f,0x55,0x63,0x5d,0x55,0x5d,0x41,0x43,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40441 0x9df9 "鷹" */
+0x00,0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x21,0x27,0x24,0x27,0x44,0x47,0x80,0x0a,
+0x80,0xfe,0x50,0xfc,0x90,0xfc,0x90,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x04,0xac,
+/* 40442 0x9dfa "鷺" */
+0x00,0x3e,0x23,0x3e,0x09,0x2e,0x28,0x7e,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x40,0xfc,0x48,0x30,0xce,0x78,0x48,0x78,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40443 0x9dfb "鷻" */
+0x21,0x40,0xf3,0x90,0xf3,0x92,0xf3,0x80,0xfb,0x80,0xf8,0x08,0xab,0xa8,0x8a,0x31,
+0x08,0x88,0xc8,0x10,0xde,0x64,0xd4,0x14,0xd4,0x54,0x94,0xe8,0x88,0x94,0x94,0x22,
+/* 40444 0x9dfc "鷼" */
+0x00,0xee,0xaa,0xee,0xaa,0xee,0x82,0xba,0xaa,0xba,0xaa,0xba,0xaa,0x82,0x8b,0x84,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40445 0x9dfd "鷽" */
+0x0a,0x31,0x22,0x38,0x22,0x39,0x22,0x7f,0x42,0x9f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x80,0x38,0x88,0x38,0x88,0x38,0x88,0xfe,0x02,0xf4,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40446 0x9dfe "鷾" */
+0x10,0xfe,0x44,0x28,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0x0a,0xa9,0xa5,0x1c,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40447 0x9dff "鷿" */
+0x3e,0x22,0x3e,0x20,0x7e,0xa2,0x3e,0x22,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x10,0xfe,0x44,0x28,0xfe,0x10,0xfc,0x10,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40448 0x9e00 "鸀" */
+0x00,0x7f,0x55,0x55,0x7f,0x20,0x7f,0x91,0x7d,0x55,0x55,0x7d,0x11,0x7d,0x05,0x02,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40449 0x9e01 "鸁" */
+0x01,0xff,0x20,0x3f,0x00,0x3f,0x20,0x3f,0x02,0x77,0x54,0x77,0x54,0x77,0x50,0xb5,
+0x00,0xfe,0x00,0xf8,0x00,0xf8,0x08,0xf8,0x00,0x9c,0x94,0x94,0x9c,0xd6,0x56,0x62,
+/* 40450 0x9e02 "鸂" */
+0x03,0xbc,0x44,0x11,0x84,0x49,0x5e,0x04,0x29,0x5f,0xc4,0x5f,0x44,0x4a,0x51,0x20,
+0x10,0x20,0xfc,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x8c,
+/* 40451 0x9e03 "鸃" */
+0x21,0x40,0xf3,0x90,0xf1,0x90,0xf3,0x80,0xf9,0x80,0xfb,0x08,0xa8,0xab,0x88,0x31,
+0x04,0x88,0xfe,0x20,0xfc,0x20,0xfe,0x54,0x92,0x90,0xfe,0x90,0xd4,0x8a,0x96,0xa2,
+/* 40452 0x9e04 "鸄" */
+0x10,0x7e,0x4a,0x7e,0x10,0xff,0x20,0x3e,0x42,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xc6,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40453 0x9e05 "鸅" */
+0x00,0x7f,0x55,0x7f,0x08,0x7f,0x08,0xff,0x22,0x14,0x7f,0x08,0xff,0x08,0x09,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0xc0,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40454 0x9e06 "鸆" */
+0x08,0x0f,0x08,0x7f,0x49,0x7c,0x49,0x5f,0x52,0x5e,0x40,0x5e,0x48,0x7f,0x52,0xa1,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40455 0x9e07 "鸇" */
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x01,0xfe,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40456 0x9e08 "鸈" */
+0x14,0x55,0x36,0x14,0xff,0x22,0x14,0x7f,0x08,0x7f,0x08,0xff,0x1c,0x2a,0x49,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40457 0x9e09 "鸉" */
+0x11,0x11,0xfd,0x31,0x59,0x94,0x11,0x12,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x52,0xaa,0xf4,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40458 0x9e0a "鸊" */
+0x02,0x79,0x49,0x4b,0x48,0x7a,0x41,0x47,0x79,0x69,0xab,0xa9,0x29,0x39,0x29,0x01,
+0x08,0x10,0x3c,0xa4,0x3c,0xa4,0x3c,0xe0,0x3e,0x20,0xbe,0x02,0x2a,0x2a,0x02,0x0c,
+/* 40459 0x9e0b "鸋" */
+0x08,0xff,0x91,0x4a,0xa5,0x1c,0x00,0x7f,0x55,0xff,0x00,0x7f,0x08,0x08,0x29,0x10,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0xc0,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40460 0x9e0c "鸌" */
+0x10,0x21,0x7c,0x44,0x7c,0x45,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xab,0xaa,0x82,0x0d,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 40461 0x9e0d "鸍" */
+0x00,0xff,0x49,0x88,0xff,0x88,0xdd,0xaa,0xdd,0x88,0xdd,0xaa,0xdd,0x88,0x8a,0x81,
+0x08,0x90,0x3c,0xa4,0xfc,0xa4,0xbc,0xa0,0xbe,0xa0,0xbe,0x82,0xaa,0xaa,0x82,0x0c,
+/* 40462 0x9e0e "鸎" */
+0x3e,0x22,0x3e,0x22,0x3e,0x22,0x3e,0x14,0x22,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0xf8,0x88,0xf8,0x88,0xf8,0x88,0xf8,0x50,0x88,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40463 0x9e0f "鸏" */
+0x24,0xff,0x24,0xff,0x81,0x7e,0x00,0xff,0x10,0x28,0xd5,0x2e,0xd5,0x24,0xd5,0x08,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0xc0,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40464 0x9e10 "鸐" */
+0x00,0xee,0x22,0xaa,0x66,0xaa,0x00,0x24,0x7f,0xc8,0x7e,0x48,0x7e,0x48,0x7f,0x40,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40465 0x9e11 "鸑" */
+0x51,0x27,0x50,0x97,0x30,0x57,0x94,0x57,0x22,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x0c,0x8a,0x08,0xbe,0x08,0x88,0x94,0xa4,0x02,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40466 0x9e12 "鸒" */
+0x1a,0x23,0x3a,0x23,0x38,0x22,0xff,0x10,0x22,0xdf,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x38,0x88,0x38,0x88,0xb8,0x88,0xfe,0x10,0x08,0xf6,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40467 0x9e13 "鸓" */
+0x00,0x7f,0x49,0x7f,0x49,0x7f,0x41,0x00,0xff,0xaa,0xaa,0xff,0xaa,0xaa,0xff,0x88,
+0x08,0x10,0x3c,0x24,0x3c,0x24,0x3c,0x20,0xbe,0xa0,0xbe,0x82,0xaa,0xaa,0x82,0x8c,
+/* 40468 0x9e14 "鸔" */
+0x21,0x41,0xf9,0x89,0xf9,0x88,0xf9,0x80,0xfd,0x80,0xfd,0x06,0x54,0x54,0x85,0x18,
+0xfc,0x04,0xfc,0x04,0xfc,0x88,0xfc,0x88,0xfe,0x88,0x24,0xaa,0x70,0xa8,0x24,0x60,
+/* 40469 0x9e15 "鸕" */
+0x08,0x0f,0x08,0x7f,0x48,0x7e,0x48,0x5f,0x55,0x5f,0x55,0x5f,0x40,0xbf,0x2a,0x7f,
+0x08,0x90,0x3c,0xa4,0xbc,0x24,0xbc,0xa0,0x3e,0x20,0x3e,0x02,0x2a,0xaa,0x82,0xcc,
+/* 40470 0x9e16 "鸖" */
+0x7f,0x08,0xff,0x88,0x6b,0x08,0x6b,0x24,0x7f,0xc8,0x7f,0x48,0x7f,0x48,0x7f,0x40,
+0x08,0x10,0xbc,0xa4,0x3c,0x24,0x3c,0x20,0xbe,0x20,0x3e,0x02,0x2a,0x2a,0x82,0x0c,
+/* 40471 0x9e17 "鸗" */
+0x08,0x3e,0x14,0xff,0x22,0x3e,0x22,0x26,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x40,0x7c,0x40,0x78,0x08,0x78,0x42,0x3e,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40472 0x9e18 "鸘" */
+0xfe,0x10,0xfe,0x92,0x54,0x10,0x54,0x00,0x2e,0xfa,0x2e,0x7a,0xae,0x2a,0x2f,0x2a,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40473 0x9e19 "鸙" */
+0x10,0x28,0x44,0xba,0x00,0xfe,0xaa,0xfe,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xab,0x86,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40474 0x9e1a "鸚" */
+0x00,0x77,0x55,0x77,0x55,0x77,0x55,0x77,0x22,0x55,0x10,0xff,0x22,0x64,0x1d,0xe3,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40475 0x9e1b "鸛" */
+0x44,0xfe,0x44,0x00,0xee,0xaa,0xee,0x24,0x7e,0xc8,0x7e,0x48,0x7e,0x48,0x7f,0x40,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xaa,0x02,0x0c,
+/* 40476 0x9e1c "鸜" */
+0x77,0x55,0x77,0x55,0x77,0x55,0x77,0x22,0x7f,0xa4,0x3f,0x24,0x3f,0x24,0x3f,0x20,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0xfe,0x40,0x7e,0x02,0x2a,0x2a,0xc2,0x0c,
+/* 40477 0x9e1d "鸝" */
+0x77,0x00,0x77,0x55,0x77,0x55,0x08,0x7f,0x54,0x7f,0x55,0x7f,0x55,0x5e,0x55,0x9b,
+0x10,0x20,0x7c,0x44,0x7c,0x44,0x7c,0x40,0x7e,0x40,0x7e,0x02,0x2a,0x2a,0x42,0x0c,
+/* 40478 0x9e1e "鸞" */
+0x21,0x4f,0xf0,0x23,0x48,0xfb,0x02,0xab,0x02,0x1f,0x10,0x1f,0x10,0x1f,0x52,0x89,
+0x08,0xd2,0x3c,0x88,0x12,0xbe,0x80,0xaa,0x00,0xf0,0x10,0xf0,0x10,0xfc,0x44,0x2c,
+/* 40479 0x9e1f "鸟" */
+0x01,0x02,0x1f,0x10,0x12,0x11,0x11,0x10,0x10,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0xf0,0x10,0x10,0x10,0x50,0x20,0x00,0xfc,0x04,0x04,0xe4,0x04,0x28,0x10,
+/* 40480 0x9e20 "鸠" */
+0x20,0x20,0x20,0x20,0xfc,0x24,0x24,0x24,0x24,0x24,0x25,0x26,0x45,0x40,0x80,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40481 0x9e21 "鸡" */
+0x00,0x00,0x00,0xfc,0x04,0x04,0x48,0x28,0x10,0x10,0x28,0x24,0x45,0x80,0x00,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40482 0x9e22 "鸢" */
+0x04,0x04,0x02,0xff,0x00,0x00,0x02,0x1f,0x14,0x12,0x10,0x1f,0x00,0x7f,0x00,0x00,
+0x20,0x10,0x3e,0xc0,0x80,0x42,0x32,0xee,0x20,0x60,0x00,0xf8,0x08,0x88,0x28,0x10,
+/* 40483 0x9e23 "鸣" */
+0x00,0x00,0x79,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x78,0x48,0x03,0x00,0x00,0x00,
+0x20,0x40,0xfc,0x04,0x44,0x24,0x24,0x0c,0x00,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40484 0x9e24 "鸤" */
+0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x22,0x20,0x20,0x20,0x20,0x21,0x40,0x40,0x80,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40485 0x9e25 "鸥" */
+0x00,0x7e,0x40,0x44,0x64,0x54,0x48,0x48,0x54,0x54,0x64,0x40,0x41,0x7e,0x00,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40486 0x9e26 "鸦" */
+0x00,0x7e,0x04,0x24,0x24,0x24,0x44,0x7f,0x0c,0x14,0x14,0x24,0x45,0x84,0x14,0x08,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40487 0x9e27 "鸧" */
+0x08,0x08,0x14,0x12,0x21,0x40,0xbe,0x22,0x22,0x22,0x2a,0x24,0x21,0x21,0x1f,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40488 0x9e28 "鸨" */
+0x40,0x48,0x50,0x60,0x44,0x44,0x3c,0x10,0x10,0x10,0xfe,0x10,0x11,0x10,0x10,0x10,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40489 0x9e29 "鸩" */
+0x08,0x08,0x08,0x7f,0x49,0x08,0x08,0x14,0x14,0x14,0x14,0x25,0x26,0x44,0x80,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40490 0x9e2a "鸪" */
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x7c,0x44,0x44,0x44,0x45,0x7c,0x44,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40491 0x9e2b "鸫" */
+0x10,0x10,0x10,0xff,0x20,0x28,0x48,0x48,0x7e,0x08,0x2c,0x2a,0x49,0x89,0x28,0x10,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40492 0x9e2c "鸬" */
+0x10,0x10,0x1e,0x10,0x10,0x7c,0x44,0x44,0x44,0x7c,0x44,0x40,0x41,0x40,0x80,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40493 0x9e2d "鸭" */
+0x00,0xfe,0x92,0x92,0x92,0xfe,0x92,0x92,0x92,0xfe,0x92,0x10,0x11,0x10,0x10,0x10,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40494 0x9e2e "鸮" */
+0x00,0x7e,0x42,0x42,0x42,0x7e,0x00,0xff,0x20,0x40,0x7e,0x02,0x03,0x02,0x14,0x08,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40495 0x9e2f "鸯" */
+0x01,0x1f,0x11,0x11,0xff,0x02,0x1c,0xe2,0x04,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x00,0xf0,0x10,0x10,0xfe,0x80,0x70,0x0e,0x00,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40496 0x9e30 "鸰" */
+0x10,0x10,0x28,0x24,0x42,0x91,0x08,0x08,0xfe,0x02,0x44,0x28,0x11,0x08,0x08,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40497 0x9e31 "鸱" */
+0x01,0x07,0x7c,0x44,0x44,0x44,0x44,0x7f,0x44,0x44,0x44,0x42,0x42,0x52,0x69,0x44,
+0x10,0xa0,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0xfa,0x82,0x8a,0x84,
+/* 40498 0x9e32 "鸲" */
+0x20,0x20,0x40,0x7e,0x82,0x02,0x7a,0x4a,0x4a,0x4a,0x7a,0x4a,0x03,0x02,0x14,0x08,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40499 0x9e33 "鸳" */
+0x10,0x3e,0x42,0xa2,0x14,0x18,0xe2,0x1f,0x14,0x12,0x10,0x1f,0x00,0x7f,0x00,0x00,
+0x00,0xf8,0x88,0xaa,0x92,0x7e,0x00,0xe0,0x20,0x60,0x00,0xf8,0x08,0x88,0x28,0x10,
+/* 40500 0x9e34 "鸴" */
+0x22,0x11,0x00,0x7f,0x41,0x82,0x1f,0x10,0x12,0x11,0x10,0x1f,0x00,0x00,0x7f,0x00,
+0x08,0x10,0x20,0xfe,0x02,0x04,0xf0,0x10,0x10,0x50,0x20,0xfc,0x04,0x04,0xd4,0x08,
+/* 40501 0x9e35 "鸵" */
+0x10,0x20,0x7c,0x44,0x54,0x45,0x54,0x48,0x40,0x7e,0x02,0x02,0xfa,0x02,0x14,0x08,
+0x20,0x10,0x10,0xfe,0x82,0x04,0x40,0x48,0x50,0x60,0x40,0x42,0x42,0x42,0x3e,0x00,
+/* 40502 0x9e36 "鸶" */
+0x10,0x24,0x78,0x10,0x7e,0x00,0xff,0x02,0x04,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x20,0x48,0xf0,0x20,0xfc,0x00,0xfe,0x00,0x00,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40503 0x9e37 "鸷" */
+0x10,0x10,0xfb,0x10,0x19,0xf0,0x11,0x52,0x24,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x80,0x80,0xf0,0x90,0x90,0x94,0x54,0x0c,0x04,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40504 0x9e38 "鸸" */
+0x00,0x7f,0x08,0x08,0x10,0x7f,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x51,0x45,0x42,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40505 0x9e39 "鸹" */
+0x04,0x0e,0x38,0x08,0x08,0xff,0x08,0x08,0x3e,0x22,0x22,0x22,0x23,0x3e,0x22,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40506 0x9e3a "鸺" */
+0x12,0x12,0x12,0x22,0x2f,0x62,0xa6,0x27,0x2a,0x2a,0x32,0x22,0x22,0x22,0x22,0x22,
+0x08,0x10,0x3e,0x22,0xb2,0x2a,0x22,0x26,0xa0,0xbe,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40507 0x9e3b "鸻" */
+0x10,0x10,0x27,0x40,0x90,0x10,0x2f,0x62,0xa2,0x22,0x22,0x22,0x22,0x22,0x2a,0x24,
+0x10,0x20,0x7c,0x44,0x64,0x54,0xc4,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40508 0x9e3c "鸼" */
+0x08,0x10,0x3e,0x22,0x32,0x2a,0x2a,0xfe,0x22,0x32,0x2a,0x2a,0x23,0x42,0x4a,0x84,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40509 0x9e3d "鸽" */
+0x10,0x10,0x28,0x24,0x42,0x80,0x7c,0x00,0x00,0x7c,0x44,0x44,0x45,0x7c,0x44,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40510 0x9e3e "鸾" */
+0x02,0x01,0xff,0x04,0x14,0x24,0x42,0x1f,0x14,0x12,0x10,0x1f,0x00,0x7f,0x00,0x00,
+0x00,0x00,0xfe,0x40,0x50,0x48,0x04,0xe0,0x20,0x60,0x00,0xf8,0x08,0x88,0x28,0x10,
+/* 40511 0x9e3f "鸿" */
+0x00,0x80,0x40,0x1f,0x84,0x44,0x44,0x04,0x24,0x44,0xc4,0x47,0x5c,0x48,0x40,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40512 0x9e40 "鹀" */
+0x00,0x00,0x7f,0x08,0x08,0x2a,0x2a,0x2a,0x5d,0x49,0x88,0x08,0x0f,0xf0,0x40,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40513 0x9e41 "鹁" */
+0x10,0x10,0xfe,0x10,0x10,0xfe,0x82,0x04,0x78,0x08,0x10,0x1e,0xf1,0x10,0x50,0x20,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40514 0x9e42 "鹂" */
+0x00,0xff,0x00,0x00,0xf7,0x94,0x94,0x94,0xd6,0xb5,0x94,0x94,0x94,0x94,0x94,0xb5,
+0x08,0x90,0x3e,0x22,0xb2,0xaa,0xa2,0xa6,0xa0,0xbe,0x82,0x82,0xfa,0x82,0x8a,0x84,
+/* 40515 0x9e43 "鹃" */
+0x00,0x3e,0x22,0x22,0x3e,0x00,0x7f,0x41,0x41,0x7f,0x41,0x41,0x7f,0x41,0x45,0x42,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40516 0x9e44 "鹄" */
+0x08,0x48,0x48,0x7f,0x88,0x08,0x08,0xff,0x00,0x00,0x7e,0x42,0x42,0x42,0x7e,0x42,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40517 0x9e45 "鹅" */
+0x04,0x36,0xe5,0x25,0x24,0xff,0x24,0x25,0x25,0x36,0xe6,0x24,0x2a,0x32,0xa1,0x40,
+0x10,0x20,0x7c,0x44,0x64,0xd4,0x44,0x4c,0x40,0x7e,0x02,0x02,0xfa,0x82,0x8a,0x84,
+/* 40518 0x9e46 "鹆" */
+0x28,0x24,0x42,0x92,0x10,0x28,0x44,0x82,0x7c,0x44,0x44,0x44,0x45,0x7c,0x44,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40519 0x9e47 "鹇" */
+0x40,0x2f,0x01,0x49,0x49,0x49,0x7f,0x49,0x5d,0x6b,0x49,0x49,0x49,0x41,0x45,0x42,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40520 0x9e48 "鹈" */
+0x44,0x24,0x28,0xfc,0x14,0x14,0xfc,0x90,0x90,0xfe,0x32,0x32,0x53,0x96,0x10,0x10,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40521 0x9e49 "鹉" */
+0x04,0x06,0x75,0x05,0x04,0xff,0x04,0x14,0x14,0x5c,0x54,0x54,0x55,0x5d,0xe3,0x41,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40522 0x9e4a "鹊" */
+0x24,0x24,0x24,0xff,0x24,0x24,0xff,0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+0x10,0x20,0x7c,0x44,0x64,0x54,0xc4,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40523 0x9e4b "鹋" */
+0x22,0x22,0xff,0x22,0x22,0x00,0x7f,0x49,0x49,0x49,0x7f,0x49,0x49,0x49,0x7f,0x41,
+0x08,0x10,0xbe,0x22,0x32,0x2a,0x22,0x26,0x20,0x3e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40524 0x9e4c "鹌" */
+0x08,0x08,0xff,0x14,0x22,0x49,0x88,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x0a,0x0c,0x08,
+0x08,0x10,0xbe,0x22,0x32,0x2a,0xa2,0x26,0x20,0x3e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40525 0x9e4d "鹍" */
+0x00,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x00,0x44,0x77,0x44,0x44,0x55,0x66,0x44,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40526 0x9e4e "鹎" */
+0x10,0x20,0x7f,0x49,0x49,0x7f,0x49,0x51,0x7f,0x24,0x44,0xff,0x04,0x04,0x04,0x04,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x82,0x7a,0x02,0x0a,0x04,
+/* 40527 0x9e4f "鹏" */
+0x00,0x77,0x55,0x55,0x55,0x77,0x55,0x55,0x55,0x77,0x55,0x55,0x55,0xb5,0x89,0x13,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40528 0x9e50 "鹐" */
+0x10,0x10,0x3e,0x22,0x44,0x80,0x10,0x66,0x42,0x42,0x66,0x42,0x43,0x7e,0x42,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40529 0x9e51 "鹑" */
+0x10,0x08,0xff,0x00,0x7e,0x42,0x7e,0x00,0x7e,0x04,0x08,0x0f,0xf8,0x08,0x28,0x10,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40530 0x9e52 "鹒" */
+0x10,0x08,0x7f,0x48,0x5e,0x4a,0x4a,0x7f,0x4a,0x4a,0x5e,0x48,0x54,0x92,0x22,0x40,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40531 0x9e53 "鹓" */
+0x10,0x08,0xff,0x81,0x40,0x77,0x55,0x55,0x55,0xb5,0x97,0x14,0x24,0x25,0x46,0x84,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40532 0x9e54 "鹔" */
+0x08,0x08,0x7f,0x09,0xff,0x09,0x7f,0x08,0x49,0x49,0x5d,0x6b,0x49,0x49,0x89,0x09,
+0x10,0x20,0x7c,0x44,0xe4,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40533 0x9e55 "鹕" */
+0x20,0x27,0x24,0xfc,0x24,0x27,0x24,0x74,0x54,0x57,0x54,0x54,0x74,0x08,0x0a,0x11,
+0x08,0x90,0xbe,0xa2,0xb2,0xaa,0xa2,0xa6,0xa0,0xbe,0x82,0x82,0xfa,0x82,0x8a,0x04,
+/* 40534 0x9e56 "鹖" */
+0x00,0x7e,0x42,0x7e,0x42,0x7e,0x20,0x7f,0x89,0x49,0x55,0x41,0x7d,0x01,0x0a,0x04,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40535 0x9e57 "鹗" */
+0x00,0x77,0x55,0x55,0x77,0x00,0x7f,0x00,0xff,0x20,0x3f,0x01,0x01,0x01,0x0a,0x04,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0xc0,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40536 0x9e58 "鹘" */
+0x00,0x7c,0x44,0x74,0x54,0xfe,0x82,0x7c,0x44,0x7c,0x44,0x7c,0x45,0x44,0x54,0x48,
+0x20,0x40,0xfc,0x84,0xa4,0x94,0x94,0x8c,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40537 0x9e59 "鹙" */
+0x06,0x38,0x08,0x7e,0x19,0x2c,0x4a,0x1f,0x14,0x12,0x10,0x1f,0x00,0x7f,0x00,0x00,
+0x20,0x20,0xa4,0xa8,0x20,0x50,0x88,0xe4,0x20,0x60,0x00,0xf8,0x08,0x88,0x28,0x10,
+/* 40538 0x9e5a "鹚" */
+0x21,0x11,0x12,0xff,0x21,0x21,0x42,0x52,0x94,0xe7,0x21,0x42,0x42,0x94,0xf7,0x10,
+0x08,0x10,0x3e,0xe2,0x32,0x2a,0x22,0xa6,0xa0,0x3e,0x02,0x02,0x7a,0x82,0x8a,0x84,
+/* 40539 0x9e5b "鹛" */
+0x00,0x7f,0x49,0x49,0x7f,0x40,0x5f,0x51,0x51,0x5f,0x51,0x5f,0x51,0x51,0x9f,0x11,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40540 0x9e5c "鹜" */
+0x00,0x7e,0x24,0x18,0xff,0x29,0x4a,0x9a,0x04,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x20,0x20,0x7e,0xa4,0x28,0x10,0x28,0xc6,0x00,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40541 0x9e5d "鹝" */
+0x00,0xfe,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x82,0xaa,0x92,0xfe,0x93,0x92,0x92,0x86,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40542 0x9e5e "鹞" */
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x3c,0x50,0x10,0xfe,0x10,0x54,0x55,0x5c,0x64,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40543 0x9e5f "鹟" */
+0x28,0x44,0x92,0x20,0x48,0xfc,0x04,0x00,0xee,0x22,0xaa,0x66,0xab,0x22,0xaa,0x44,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40544 0x9e60 "鹠" */
+0x20,0xde,0x8a,0xca,0xaa,0xd2,0xa6,0x00,0xfe,0x92,0x92,0xfe,0x93,0x92,0xfe,0x82,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40545 0x9e61 "鹡" */
+0x10,0x92,0x54,0xaa,0x44,0x82,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,0x44,0x4c,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40546 0x9e62 "鹢" */
+0x22,0x14,0x00,0x7f,0x00,0x14,0x22,0x41,0x00,0x7f,0x55,0x55,0x55,0x57,0xfc,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x82,0x0a,0x04,
+/* 40547 0x9e63 "鹣" */
+0x22,0x14,0x00,0x7f,0x14,0x7f,0x15,0xff,0x15,0x7f,0x14,0x36,0x55,0x94,0x14,0x14,
+0x10,0x20,0x7c,0xc4,0x64,0x54,0x44,0xcc,0x40,0x7e,0x02,0x02,0x7a,0x82,0x0a,0x04,
+/* 40548 0x9e64 "鹤" */
+0x08,0x08,0x7f,0x55,0x12,0x3f,0x64,0xa4,0x3f,0x24,0x24,0x3f,0x24,0x24,0x3f,0x20,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40549 0x9e65 "鹥" */
+0x7f,0x48,0x5f,0x64,0x5f,0x4a,0x51,0x7f,0x04,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x78,0x48,0x4c,0x80,0x78,0x48,0x30,0x4c,0x00,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40550 0x9e66 "鹦" */
+0x00,0x77,0x55,0x55,0x55,0x55,0x22,0x55,0x08,0xff,0x12,0x22,0x34,0x0c,0x32,0xc1,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40551 0x9e67 "鹧" */
+0x10,0x08,0x7f,0x40,0x52,0x52,0x7f,0x52,0x52,0x5e,0x40,0x55,0x55,0x55,0x80,0x00,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40552 0x9e68 "鹨" */
+0x00,0x77,0x11,0x55,0x33,0x55,0x0c,0x33,0xc4,0x18,0x62,0x0c,0x71,0x06,0x18,0xe0,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0xc0,0x7e,0x02,0x82,0x7a,0x02,0x0a,0x04,
+/* 40553 0x9e69 "鹩" */
+0x08,0x08,0x7f,0x08,0x55,0x22,0x41,0xbe,0x22,0x3e,0x22,0x3e,0x08,0x2a,0x49,0x18,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0xcc,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40554 0x9e6a "鹪" */
+0x28,0x24,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x7e,0x41,0xaa,0xaa,0x00,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40555 0x9e6b "鹫" */
+0x08,0x7f,0x00,0x3e,0x22,0x3e,0x49,0x9a,0x04,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x28,0x24,0xfe,0x20,0x50,0x50,0x52,0x8e,0x00,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40556 0x9e6c "鹬" */
+0x7e,0x14,0x08,0xff,0x29,0x4a,0xa8,0x10,0x7f,0x55,0x63,0x5d,0x55,0x5d,0x41,0x43,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40557 0x9e6d "鹭" */
+0x00,0x3e,0x23,0x3e,0x09,0x2e,0x28,0x7e,0x04,0x1f,0x12,0x11,0x1f,0x00,0x7f,0x00,
+0x40,0xfc,0x48,0x30,0xce,0x78,0x48,0x78,0x00,0xe0,0x20,0x60,0xfc,0x04,0xd4,0x08,
+/* 40558 0x9e6e "鹮" */
+0x00,0xfe,0xaa,0xaa,0xfe,0x00,0xfe,0x00,0x7c,0x44,0x7c,0x2a,0x65,0xa2,0x31,0x20,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40559 0x9e6f "鹯" */
+0x10,0xfe,0x00,0xfe,0x82,0xba,0xaa,0xfe,0x00,0x7c,0x44,0x7c,0x45,0x7c,0x00,0xfe,
+0x20,0x40,0xfc,0x84,0xa4,0x84,0x94,0x88,0x80,0xfe,0x02,0x02,0xfa,0x02,0x14,0x08,
+/* 40560 0x9e70 "鹰" */
+0x00,0x3f,0x22,0x24,0x2d,0x36,0x24,0x24,0x21,0x27,0x24,0x24,0x47,0x40,0x9f,0x00,
+0x80,0xfe,0x50,0xfc,0x90,0xfc,0x90,0xfc,0x00,0xf0,0x90,0x20,0xfc,0x04,0xd4,0x08,
+/* 40561 0x9e71 "鹱" */
+0x10,0x21,0x7c,0x44,0x64,0x55,0x44,0x4c,0x40,0x7c,0x04,0x04,0xf5,0x04,0x14,0x09,
+0x44,0xfe,0x54,0x48,0xfe,0x90,0xfe,0x90,0xfe,0x90,0xfe,0x80,0xfe,0x44,0x38,0xc6,
+/* 40562 0x9e72 "鹲" */
+0x24,0xff,0x24,0xff,0x81,0x7e,0x00,0xff,0x10,0x28,0xd5,0x2e,0xd5,0x24,0xd4,0x08,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0xfe,0x02,0x02,0x7a,0x82,0x0a,0x04,
+/* 40563 0x9e73 "鹳" */
+0x22,0xff,0x22,0xf7,0x94,0xf7,0x28,0x24,0x7f,0x48,0xff,0x48,0x7f,0x48,0x7f,0x40,
+0x08,0x90,0x3e,0xa2,0xb2,0xaa,0x22,0x26,0xa0,0x3e,0x02,0x02,0x7a,0x02,0x8a,0x04,
+/* 40564 0x9e74 "鹴" */
+0x7f,0x08,0x7f,0x49,0x2a,0x08,0x2a,0x00,0x27,0xfd,0x27,0x75,0xaf,0x25,0x27,0x25,
+0x10,0x20,0x7c,0x44,0x64,0x54,0x44,0x4c,0x40,0x7e,0x02,0x02,0x7a,0x02,0x0a,0x04,
+/* 40565 0x9e75 "鹵" */
+0x01,0x01,0x01,0x01,0x01,0x3f,0x20,0x29,0x24,0x22,0x29,0x22,0x24,0x29,0x3f,0x20,
+0x00,0x00,0xfe,0x00,0x00,0xf8,0x08,0x28,0x48,0x88,0x28,0x88,0x48,0x28,0xf8,0x08,
+/* 40566 0x9e76 "鹶" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x93,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x00,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 40567 0x9e77 "鹷" */
+0x10,0x10,0x1e,0x10,0x10,0xff,0x92,0xc6,0xab,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x00,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 40568 0x9e78 "鹸" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x00,
+0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0xfe,0x92,0x92,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 40569 0x9e79 "鹹" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x01,
+0x0c,0x0a,0x08,0xfe,0x88,0x88,0xfa,0x8a,0x8a,0xec,0xac,0xac,0xea,0x8a,0x96,0x22,
+/* 40570 0x9e7a "鹺" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xff,0x82,0x00,
+0x44,0x24,0x28,0xfe,0x10,0x7c,0x10,0xfe,0x20,0x20,0x7c,0x50,0x90,0x10,0xfe,0x00,
+/* 40571 0x9e7b "鹻" */
+0x10,0x10,0x1e,0x11,0x10,0xfe,0x92,0xc7,0xaa,0xd6,0xaa,0xc6,0x93,0xfe,0x82,0x00,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 40572 0x9e7c "鹼" */
+0x10,0x10,0x1e,0x10,0x10,0xfe,0x92,0xc6,0xaa,0xd6,0xaa,0xc6,0x92,0xfe,0x82,0x01,
+0x10,0x10,0x28,0x44,0x82,0x7c,0x00,0xee,0xaa,0xaa,0xee,0x44,0x44,0xaa,0xaa,0x12,
+/* 40573 0x9e7d "鹽" */
+0x01,0xf9,0xa2,0xa4,0xf8,0x8b,0x8a,0xfa,0xa3,0xa2,0xa2,0xfb,0x00,0x3f,0x24,0xff,
+0x00,0xfe,0x20,0x3e,0x20,0xfe,0xaa,0x52,0x26,0x52,0xaa,0xfe,0x00,0xf8,0x48,0xfe,
+/* 40574 0x9e7e "鹾" */
+0x20,0x20,0x3c,0x21,0x20,0xfc,0x84,0x95,0xd4,0xa4,0xd4,0x95,0x86,0xfc,0x85,0x00,
+0x84,0x44,0x48,0xfe,0x20,0xfc,0x20,0xfe,0x40,0x80,0xfe,0x10,0x10,0x10,0xfe,0x00,
+/* 40575 0x9e7f "鹿" */
+0x01,0x00,0x3f,0x22,0x22,0x3f,0x22,0x22,0x3f,0x28,0x28,0x2f,0x48,0x48,0x8b,0x0c,
+0x00,0x80,0xfe,0x20,0x20,0xfc,0x24,0x24,0xfc,0x40,0x44,0x58,0x60,0x44,0x44,0x3c,
+/* 40576 0x9e80 "麀" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x28,0x2f,0x20,0x28,0x4f,0x48,0x87,
+0x00,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x78,0x42,0x3e,0x00,0x78,0x82,0x02,0xfe,
+/* 40577 0x9e81 "麁" */
+0x01,0x02,0x0f,0x70,0x03,0x1d,0xe0,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x00,0x00,0xf0,0x60,0x80,0x00,0x80,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 40578 0x9e82 "麂" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x28,0x2f,0x20,0x23,0x42,0x44,0x98,
+0x00,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0x78,0x42,0x3e,0x00,0xf0,0x10,0x12,0x0e,
+/* 40579 0x9e83 "麃" */
+0x01,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x28,0x2b,0x2c,0x40,0x4a,0x89,0x11,
+0x00,0x80,0xfe,0x20,0xfc,0x24,0xfc,0x44,0x48,0x74,0x44,0x3c,0x00,0x48,0x24,0x24,
+/* 40580 0x9e84 "麄" */
+0x04,0x08,0x30,0xdf,0x04,0x09,0x10,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x40,0x20,0x18,0xf6,0x10,0x50,0xa0,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 40581 0x9e85 "麅" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x2f,0x30,0x2f,0x28,0x4f,0x48,0x87,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x00,0xf8,0x08,0xc8,0x68,0xd0,0x02,0xfe,
+/* 40582 0x9e86 "麆" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x20,0x27,0x24,0x27,0x24,0x47,0x44,0xbf,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,
+/* 40583 0x9e87 "麇" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x20,0x23,0x20,0x4f,0x41,0x8e,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x08,0xf0,0x40,0xfe,0x50,0x4e,
+/* 40584 0x9e88 "麈" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x20,0x2f,0x20,0x47,0x40,0x9f,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x80,0xfe,0x40,0xfc,0x40,0xfe,
+/* 40585 0x9e89 "麉" */
+0x00,0x7c,0x10,0x10,0xfe,0x11,0x10,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x00,0x7c,0x10,0x10,0xfe,0x10,0x90,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 40586 0x9e8a "麊" */
+0x11,0x09,0x7f,0x05,0x19,0x61,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x10,0x20,0xfc,0x40,0x30,0x0c,0x80,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 40587 0x9e8b "麋" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x27,0x22,0x21,0x2f,0x41,0x42,0x8c,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x48,0x50,0xfe,0x50,0x48,0x46,
+/* 40588 0x9e8c "麌" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x27,0x24,0x27,0x20,0x2f,0x20,0x5f,0x42,0x9c,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xf0,0x10,0xf0,0x00,0xf8,0x80,0xfc,0x20,0x1c,
+/* 40589 0x9e8d "麍" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x20,0x3f,0x22,0x24,0x2f,0x44,0x48,0x90,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x40,0xfe,0x00,0x08,0xfc,0x94,0x92,0x8e,
+/* 40590 0x9e8e "麎" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x20,0x2f,0x28,0x2b,0x28,0x4f,0x4a,0x93,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x00,0xfc,0x00,0xfc,0x00,0xfe,0x28,0x9e,
+/* 40591 0x9e8f "麏" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x21,0x3f,0x21,0x2f,0x22,0x47,0x4a,0x93,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfc,0x04,0xfe,0x04,0xfc,0x00,0xfc,0x04,0xfc,
+/* 40592 0x9e90 "麐" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x20,0x2f,0x21,0x20,0x2f,0x43,0x42,0x83,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x40,0xfe,0x10,0xe0,0x1e,0xf8,0x08,0xf8,
+/* 40593 0x9e91 "麑" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x21,0x2e,0x28,0x2f,0x28,0x4f,0x42,0x9c,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x22,0xbe,0x00,0x78,0x08,0x78,0x08,0xf8,0x22,0x1e,
+/* 40594 0x9e92 "麒" */
+0x08,0x7f,0x55,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5e,0x55,0x54,0x5c,0x56,0x80,
+0x44,0x44,0xfe,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0xfe,0x00,0x28,0x44,0x82,
+/* 40595 0x9e93 "麓" */
+0x08,0x08,0x7e,0x1c,0x2a,0xc9,0x08,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x20,0x20,0xfc,0x70,0xa8,0x26,0xa0,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 40596 0x9e94 "麔" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x22,0x27,0x2d,0x32,0x2d,0x30,0x27,0x44,0x44,0x87,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xb0,0x28,0x24,0xfe,0x00,0xf8,0x08,0x08,0xf8,
+/* 40597 0x9e95 "麕" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x28,0x2b,0x28,0x2f,0x2a,0x4c,0x4f,0x88,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfc,0x24,0xc4,0x84,0xf4,0xa4,0x94,0xfc,0x04,
+/* 40598 0x9e96 "麖" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x3f,0x20,0x2f,0x28,0x2f,0x20,0x48,0x52,0x81,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x80,0x88,0x84,0x00,
+/* 40599 0x9e97 "麗" */
+0x3f,0x00,0x3e,0x22,0x32,0x2b,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x8f,
+0x7e,0x00,0x7c,0x44,0x64,0x54,0x80,0xfc,0x40,0xf8,0x48,0xf8,0x44,0x78,0x42,0x3e,
+/* 40600 0x9e98 "麘" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x20,0x3f,0x24,0x2f,0x34,0x47,0x44,0x87,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x10,0xe0,0x80,0xfc,0x90,0xf8,0x16,0xf0,0x10,0xf0,
+/* 40601 0x9e99 "麙" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x20,0x2f,0x28,0x2b,0x28,0x2b,0x4a,0x4b,0x90,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0x28,0xfe,0x20,0xa4,0x28,0xac,0x94,0xac,0x44,
+/* 40602 0x9e9a "麚" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x29,0x2f,0x28,0x2f,0x28,0x4f,0x48,0x88,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0x7c,0x04,0x7c,0x00,0x7c,0x44,0x28,0x30,0xce,
+/* 40603 0x9e9b "麛" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x21,0x2f,0x28,0x2f,0x21,0x41,0x45,0x82,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0x7e,0x24,0x3c,0x24,0x3c,0x26,0x7c,0x04,0x04,
+/* 40604 0x9e9c "麜" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x21,0x27,0x25,0x27,0x20,0x4f,0x41,0x86,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfe,0x10,0xfc,0x14,0xfc,0x40,0xfe,0x50,0x4c,
+/* 40605 0x9e9d "麝" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x24,0x27,0x24,0x2f,0x29,0x2f,0x29,0x5f,0x45,0x9b,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x20,0xbc,0x22,0x9e,0x08,0x7e,0x48,0x28,0x08,0x18,
+/* 40606 0x9e9e "麞" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x27,0x21,0x2f,0x22,0x23,0x22,0x4f,0x40,0x80,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0xfc,0x10,0xfe,0x08,0xf8,0x08,0xfe,0x40,0x40,
+/* 40607 0x9e9f "麟" */
+0x08,0x7f,0x54,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5e,0x54,0x55,0x5c,0x56,0x81,
+0x10,0x54,0x38,0xfe,0x10,0x38,0x56,0x90,0x84,0xee,0xa4,0xb4,0x5e,0x44,0x84,0x04,
+/* 40608 0x9ea0 "麠" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x28,0x3f,0x20,0x2f,0x28,0x4f,0x48,0xbf,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x88,0xf8,0x88,0xfe,0x00,0xf8,0x88,0xf8,0x88,0xfe,
+/* 40609 0x9ea1 "麡" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x2f,0x20,0x2f,0x25,0x25,0x2b,0x44,0x47,0x88,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x40,0xfe,0xa0,0x5e,0x54,0x54,0x5a,0x08,0xf8,0x08,
+/* 40610 0x9ea2 "麢" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x20,0x27,0x20,0x2f,0x28,0x23,0x20,0x4e,0x4a,0x8e,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x00,0xfc,0x40,0xfe,0x42,0x58,0x00,0xee,0xaa,0xee,
+/* 40611 0x9ea3 "麣" */
+0x13,0xfe,0xab,0xa8,0xff,0xaa,0xaa,0xfe,0xab,0xaa,0xbe,0xaa,0xaa,0xba,0xad,0x00,
+0xde,0x52,0xde,0x00,0xfe,0x00,0xc8,0x4e,0xea,0xb2,0xea,0xaa,0xea,0xb4,0xe4,0x2a,
+/* 40612 0x9ea4 "麤" */
+0x00,0x3f,0x22,0x3f,0x22,0x3f,0x48,0xff,0x54,0x7f,0x55,0x7f,0x52,0x5b,0x52,0x9b,
+0x80,0xfe,0x20,0xfc,0x24,0xfc,0x10,0x7e,0x48,0x7e,0x4a,0x7e,0x64,0x76,0xa4,0x36,
+/* 40613 0x9ea5 "麥" */
+0x01,0x7f,0x09,0x09,0x15,0x23,0x05,0x09,0x32,0xc7,0x08,0x13,0x00,0x01,0x06,0x38,
+0x00,0xfc,0x20,0x20,0x50,0x88,0x40,0x20,0x18,0xe6,0x20,0x40,0x80,0x40,0x20,0x00,
+/* 40614 0x9ea6 "麦" */
+0x01,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,0x08,0x1f,0x28,0x44,0x03,0x1c,0xe0,
+0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0xf0,0x20,0x40,0x80,0x70,0x0e,
+/* 40615 0x9ea7 "麧" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x20,0x20,0x40,0x7e,0x80,0x00,0x7c,0x04,0x08,0x10,0x20,0x40,0x42,0x42,0x3e,0x00,
+/* 40616 0x9ea8 "麨" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x10,0x10,0x10,0x10,0x54,0x52,0x52,0x90,0x10,0x14,0x04,0x08,0x08,0x10,0x20,0xc0,
+/* 40617 0x9ea9 "麩" */
+0x10,0x10,0xfe,0x54,0x55,0xba,0x10,0x38,0x55,0xa2,0x3c,0x44,0xa8,0x10,0x29,0xc2,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 40618 0x9eaa "麪" */
+0x10,0x11,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x00,0xfe,0x20,0x20,0xa0,0xbc,0xa4,0xa4,0xa4,0xfc,0x04,0x04,0x04,0x04,0x28,0x10,
+/* 40619 0x9eab "麫" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x00,0xfe,0x10,0x10,0x50,0x5e,0x50,0x50,0x50,0x7e,0x02,0x02,0x02,0x02,0x14,0x08,
+/* 40620 0x9eac "麬" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x11,0x29,0xc2,
+0x10,0x10,0x10,0xfe,0x92,0x94,0x90,0xfc,0xa4,0xa4,0xa8,0xa8,0x90,0x28,0x44,0x82,
+/* 40621 0x9ead "麭" */
+0x10,0x10,0xfe,0x54,0x55,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 40622 0x9eae "麮" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x10,0x10,0x10,0x7e,0x10,0x10,0x10,0xfe,0x10,0x10,0x20,0x28,0x44,0xfe,0x42,0x00,
+/* 40623 0x9eaf "麯" */
+0x10,0x10,0xfe,0x54,0x55,0xbb,0x11,0x39,0x55,0xa3,0x3d,0x45,0xa9,0x11,0x29,0xc1,
+0x50,0x50,0x50,0x50,0xfc,0x54,0x54,0x54,0x54,0xfc,0x54,0x54,0x54,0x54,0xfc,0x04,
+/* 40624 0x9eb0 "麰" */
+0x10,0x10,0xfe,0x54,0x55,0xba,0x10,0x38,0x54,0xa3,0x3c,0x45,0xa8,0x10,0x28,0xc0,
+0x20,0x20,0x48,0x84,0xfe,0x12,0x90,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 40625 0x9eb1 "麱" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x14,0x12,0xfe,0x10,0x10,0xfe,0x92,0x92,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 40626 0x9eb2 "麲" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x61,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x50,0x50,0x52,0x92,0x0e,
+/* 40627 0x9eb3 "麳" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x10,0x10,0x10,0xfe,0x10,0x54,0x54,0x54,0xba,0x10,0x38,0x54,0x92,0x10,0x10,0x10,
+/* 40628 0x9eb4 "麴" */
+0x10,0x10,0xfe,0x55,0x56,0xba,0x10,0x38,0x55,0xa2,0x3c,0x44,0xa9,0x10,0x28,0xc0,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 40629 0x9eb5 "麵" */
+0x08,0x08,0xff,0x2a,0x2a,0x5d,0x88,0x1c,0x2a,0x50,0x1e,0x22,0x54,0x08,0x14,0x60,
+0x00,0xfe,0x10,0x20,0xfe,0xaa,0xaa,0xba,0xaa,0xaa,0xba,0xaa,0xaa,0xaa,0xfe,0x82,
+/* 40630 0x9eb6 "麶" */
+0x10,0x10,0xfe,0x54,0x54,0xba,0x10,0x38,0x54,0xa2,0x3c,0x44,0xa8,0x10,0x28,0xc0,
+0x20,0x10,0xfe,0x28,0x92,0xaa,0x82,0xfe,0x10,0xfe,0xa2,0xaa,0xba,0x82,0x8a,0x84,
+/* 40631 0x9eb7 "麷" */
+0x10,0x11,0xfe,0x57,0x56,0xbb,0x12,0x3b,0x54,0xa3,0x3c,0x45,0xa9,0x11,0x28,0xc3,
+0xa8,0xfc,0xaa,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x88,0xfe,
+/* 40632 0x9eb8 "麸" */
+0x10,0x10,0xfe,0x10,0x7d,0x10,0xfe,0x20,0x3d,0x44,0x48,0xa8,0x10,0x28,0x41,0x82,
+0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 40633 0x9eb9 "麹" */
+0x10,0x10,0xfe,0x11,0x7e,0x10,0xfe,0x20,0x3d,0x44,0x48,0xa8,0x11,0x28,0x40,0x80,
+0x80,0x80,0xfe,0x02,0x22,0xaa,0x72,0x22,0xfe,0x22,0x72,0xaa,0x22,0x22,0x0a,0x04,
+/* 40634 0x9eba "麺" */
+0x10,0x11,0xfe,0x10,0x7d,0x11,0xff,0x21,0x3d,0x45,0x49,0xa9,0x11,0x29,0x41,0x81,
+0x00,0xfe,0x20,0x40,0xfc,0x54,0x54,0x74,0x54,0x54,0x74,0x54,0x54,0x54,0xfc,0x04,
+/* 40635 0x9ebb "麻" */
+0x01,0x00,0x3f,0x22,0x22,0x22,0x3f,0x22,0x26,0x27,0x2a,0x2a,0x52,0x42,0x82,0x02,
+0x00,0x80,0xfe,0x10,0x10,0x10,0xbe,0x10,0x10,0x38,0xb4,0x54,0x92,0x10,0x10,0x10,
+/* 40636 0x9ebc "麼" */
+0x01,0x00,0x3f,0x22,0x22,0x2f,0x23,0x26,0x2a,0x21,0x22,0x27,0x40,0x43,0x8f,0x00,
+0x00,0x80,0xfe,0x10,0x10,0xbc,0x18,0xb4,0x52,0x00,0x10,0xe0,0xc0,0x08,0xfc,0x04,
+/* 40637 0x9ebd "麽" */
+0x01,0x00,0x3f,0x22,0x22,0x2f,0x23,0x26,0x2a,0x21,0x22,0x24,0x49,0x42,0x87,0x00,
+0x00,0x80,0xfe,0x10,0x10,0xbc,0x18,0xb4,0x52,0x00,0x40,0x80,0x10,0x08,0xfc,0x04,
+/* 40638 0x9ebe "麾" */
+0x01,0x00,0x3f,0x22,0x2f,0x26,0x2b,0x32,0x20,0x2f,0x20,0x2f,0x20,0x5f,0x40,0x80,
+0x00,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x78,0x80,0xf8,0x80,0xfc,0x82,0x82,0x7e,
+/* 40639 0x9ebf "麿" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x20,0x27,0x24,0x27,0x20,0x2f,0x48,0x48,0x8f,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0x00,0xf8,0x08,0xf8,0x00,0xfc,0x04,0x04,0xfc,
+/* 40640 0x9ec0 "黀" */
+0x01,0x00,0x3f,0x22,0x2f,0x26,0x2b,0x32,0x3f,0x29,0x2f,0x29,0x2f,0x49,0x5f,0x81,
+0x00,0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0x80,0x7c,0x24,0x24,0x28,0x90,0x28,0x46,
+/* 40641 0x9ec1 "黁" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x2f,0x20,0x3f,0x24,0x2f,0x34,0x47,0x44,0x87,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x12,0xe0,0x80,0xfc,0x90,0xf8,0x16,0xf0,0x10,0xf0,
+/* 40642 0x9ec2 "黂" */
+0x00,0x3f,0x24,0x3f,0x26,0x2d,0x34,0x2f,0x22,0x2f,0x22,0x2f,0x28,0x4f,0x44,0x88,
+0x80,0xfe,0x10,0x7c,0x38,0x54,0x92,0xf8,0xa0,0xfc,0x20,0xf8,0x88,0xf8,0x10,0x08,
+/* 40643 0x9ec3 "黃" */
+0x08,0x7f,0x08,0x0f,0x00,0xff,0x01,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x08,0x10,
+0x20,0xfc,0x20,0xe0,0x00,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x20,0x10,
+/* 40644 0x9ec4 "黄" */
+0x04,0x3f,0x04,0x04,0xff,0x01,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x08,0x10,0x20,
+0x40,0xf8,0x40,0x40,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x20,0x10,0x08,
+/* 40645 0x9ec5 "黅" */
+0x22,0x22,0x7f,0x22,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0x22,0x21,0x41,
+0x10,0x10,0x10,0x28,0x28,0xc4,0x44,0xa2,0x10,0x10,0x7c,0x04,0x08,0x08,0x10,0x10,
+/* 40646 0x9ec6 "黆" */
+0x22,0x22,0x7f,0x22,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0x22,0x21,0x41,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40647 0x9ec7 "黇" */
+0x22,0x22,0x7f,0x22,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0x22,0x21,0x41,
+0x10,0x10,0x10,0x10,0x1e,0x90,0x10,0x10,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40648 0x9ec8 "黈" */
+0x22,0x22,0x7f,0x22,0x22,0xff,0x08,0x7f,0x49,0x7f,0x49,0x7f,0x00,0x22,0x21,0x41,
+0x20,0x10,0x00,0xfe,0x10,0x90,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 40649 0x9ec9 "黉" */
+0x11,0x08,0x7f,0x44,0x9f,0x04,0x7f,0x01,0x1f,0x11,0x1f,0x11,0x1f,0x04,0x08,0x10,
+0x08,0x90,0xfe,0x42,0xf4,0x40,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x40,0x20,0x10,
+/* 40650 0x9eca "黊" */
+0x28,0x28,0x7c,0x28,0x28,0xfe,0x11,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x29,0x44,
+0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,0x20,0x20,0xf8,0x20,0x20,0x20,0xfc,0x00,
+/* 40651 0x9ecb "黋" */
+0x10,0x10,0x95,0x54,0x58,0x13,0xfc,0x29,0x29,0x29,0x29,0x29,0x28,0x49,0x4a,0x87,
+0x88,0x88,0xfc,0x88,0x88,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x88,0x04,0x02,0xfe,
+/* 40652 0x9ecc "黌" */
+0x0a,0x31,0x22,0x39,0x22,0xff,0x84,0x3f,0x04,0xff,0x11,0x1f,0x11,0x1f,0x08,0x10,
+0x80,0x38,0x88,0x38,0x88,0xfe,0x42,0xf8,0x40,0xfe,0x10,0xf0,0x10,0xf0,0x20,0x10,
+/* 40653 0x9ecd "黍" */
+0x00,0x3f,0x01,0x7f,0x09,0x11,0x22,0xc4,0x09,0x31,0xcb,0x05,0x19,0x61,0x05,0x02,
+0xf8,0x00,0x00,0xfc,0x20,0x10,0x88,0x44,0x20,0x18,0x26,0xc0,0x30,0x08,0x00,0x00,
+/* 40654 0x9ece "黎" */
+0x06,0x38,0x08,0x7e,0x1c,0x2a,0x49,0x02,0x0c,0x31,0xc9,0x05,0x09,0x11,0x25,0x02,
+0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0x80,0x60,0x18,0x26,0x40,0x20,0x10,0x08,0x00,
+/* 40655 0x9ecf "黏" */
+0x0c,0x70,0x10,0xfe,0x38,0x54,0x90,0x28,0x55,0x91,0x55,0x39,0x55,0x93,0x51,0x21,
+0x20,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,
+/* 40656 0x9ed0 "黐" */
+0x0c,0x70,0x11,0xfe,0x39,0x55,0x91,0x29,0x54,0x91,0x55,0x39,0x55,0x93,0x51,0x21,
+0x40,0x20,0xfc,0x50,0x24,0x54,0x04,0xfc,0x20,0xfc,0x44,0x54,0x74,0x04,0x14,0x08,
+/* 40657 0x9ed1 "黑" */
+0x00,0x3f,0x21,0x29,0x25,0x3f,0x01,0x01,0x3f,0x01,0x01,0xff,0x00,0x48,0x44,0x84,
+0x00,0xf8,0x08,0x28,0x48,0xf8,0x00,0x00,0xf8,0x00,0x00,0xfe,0x00,0x88,0x44,0x44,
+/* 40658 0x9ed2 "黒" */
+0x00,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x3f,0x01,0x01,0xff,0x00,0x24,0x22,0x42,0x80,
+0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x00,0x00,0xfe,0x00,0x88,0x44,0x44,0x04,
+/* 40659 0x9ed3 "黓" */
+0x00,0x7f,0x49,0x6b,0x5d,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x00,0x55,0x4a,0x80,
+0x28,0x24,0x24,0x20,0x2e,0xf0,0x20,0x20,0x20,0x20,0xa0,0x10,0x12,0x0a,0x86,0x02,
+/* 40660 0x9ed4 "黔" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xff,0x12,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x20,0x20,0x50,0x50,0x88,0x44,0x22,0x20,0xf8,0x08,0x08,0x10,0x10,0x20,0x20,
+/* 40661 0x9ed5 "黕" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x81,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x10,0x28,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40662 0x9ed6 "黖" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x81,
+0x00,0xfe,0x10,0x10,0x90,0x90,0x90,0xfe,0x10,0x10,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40663 0x9ed7 "黗" */
+0x00,0xfe,0x92,0xd7,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x20,0x20,0xfc,0x20,0xa8,0xa8,0xa8,0xa8,0xa8,0xf8,0x22,0x22,0x22,0x1e,0x00,
+/* 40664 0x9ed8 "默" */
+0x00,0xfe,0x92,0xd6,0xba,0x93,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa9,0x82,
+0x20,0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x20,0x50,0x50,0x50,0x88,0x88,0x04,0x02,
+/* 40665 0x9ed9 "黙" */
+0x00,0x7f,0x49,0x7f,0x49,0x7f,0x08,0x7f,0x08,0x0f,0xf0,0x00,0x24,0x22,0x42,0x80,
+0x10,0x14,0x12,0x10,0x7e,0x10,0x28,0x28,0x44,0x44,0x82,0x00,0x88,0x44,0x44,0x04,
+/* 40666 0x9eda "黚" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x44,0x44,0x44,0x44,0xfe,0x44,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40667 0x9edb "黛" */
+0x08,0x10,0x30,0xd7,0x10,0x10,0x00,0x3f,0x29,0x25,0x3f,0x01,0x7f,0x01,0xff,0x44,
+0x90,0x88,0x7e,0xc0,0x22,0x1a,0x06,0xf8,0x28,0x48,0xf8,0x00,0xfc,0x00,0xfe,0x44,
+/* 40668 0x9edc "黜" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0x92,0x92,0x92,0x92,0xfe,0x10,0x10,0x92,0x92,0x92,0x92,0x92,0xfe,0x02,
+/* 40669 0x9edd "黝" */
+0x00,0xfe,0x92,0xd6,0xba,0x93,0xff,0x10,0xfe,0x11,0x1f,0xe1,0x02,0xaa,0xa8,0x80,
+0x10,0x50,0x50,0x90,0xfc,0x54,0xd4,0x94,0x94,0x14,0x54,0xd4,0x54,0x24,0x34,0x48,
+/* 40670 0x9ede "點" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0xfe,0x82,0x82,0x82,0x82,0x82,0xfe,0x82,
+/* 40671 0x9edf "黟" */
+0x00,0xfe,0x92,0xd6,0xbb,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x20,0x7c,0x84,0x48,0x30,0x20,0x48,0x90,0x3e,0x42,0xa4,0x18,0x10,0x20,0xc0,
+/* 40672 0x9ee0 "黠" */
+0x00,0xfe,0x92,0xd7,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x20,0x20,0xfe,0x20,0x20,0xfc,0x00,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 40673 0x9ee1 "黡" */
+0x3f,0x20,0x3f,0x21,0x26,0x38,0x2f,0x2a,0x29,0x2f,0x20,0x2f,0x40,0x5f,0x8a,0x11,
+0xfc,0x90,0xfc,0x40,0x30,0x0c,0xf8,0xa8,0xc8,0xf8,0x80,0xf8,0x80,0xfc,0x48,0x24,
+/* 40674 0x9ee2 "黢" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0x20,0x44,0xfe,0x28,0x44,0xa2,0x3c,0x44,0x44,0xa8,0x10,0x28,0x44,0x82,
+/* 40675 0x9ee3 "黣" */
+0x00,0xfe,0x92,0xd6,0xbb,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x40,0x40,0x7e,0x80,0x7c,0x44,0x64,0x54,0xfe,0x44,0xa4,0x94,0xfe,0x04,0x28,0x10,
+/* 40676 0x9ee4 "黤" */
+0x00,0xfe,0x93,0xd6,0xba,0x93,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x20,0xfe,0x50,0xa8,0x26,0xf8,0xa8,0xa8,0xf8,0xa8,0xa8,0xf8,0xaa,0x22,0x1e,
+/* 40677 0x9ee5 "黥" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x7c,0x10,0x54,0x52,0x92,0x10,0x50,0x20,
+/* 40678 0x9ee6 "黦" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1f,0xe0,0x02,0xaa,0xa8,0x81,
+0x20,0x10,0xfe,0x82,0x40,0x4e,0x6a,0xaa,0xaa,0xaa,0x6c,0x28,0x4a,0x4a,0x8a,0x06,
+/* 40679 0x9ee7 "黧" */
+0x06,0x38,0x08,0x7e,0x1c,0x2a,0x48,0x3f,0x29,0x25,0x3f,0x01,0x7f,0x01,0xff,0x44,
+0x40,0x7c,0x94,0x24,0x44,0x94,0x08,0xf8,0x28,0x48,0xf8,0x00,0xfc,0x00,0xfe,0x44,
+/* 40680 0x9ee8 "黨" */
+0x11,0x09,0x7f,0x40,0x9f,0x10,0x3f,0x29,0x25,0x3f,0x01,0x3f,0x01,0xff,0x24,0x42,
+0x10,0x20,0xfe,0x02,0xf4,0x10,0xf8,0x28,0x48,0xf8,0x00,0xf8,0x00,0xfe,0x48,0x24,
+/* 40681 0x9ee9 "黩" */
+0x00,0xfe,0x92,0xd6,0xba,0x93,0xfe,0x10,0xfe,0x10,0x1e,0xe1,0x02,0xaa,0xa8,0x81,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x02,0x54,0x30,0x90,0x50,0xfe,0x28,0x44,0x82,0x02,
+/* 40682 0x9eea "黪" */
+0x00,0xfe,0x92,0xd6,0xba,0x93,0xfe,0x11,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x81,
+0x20,0x28,0x44,0xfe,0x20,0xfe,0x88,0x14,0x22,0x48,0x10,0x22,0xc4,0x18,0x60,0x80,
+/* 40683 0x9eeb "黫" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa9,0x80,
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,
+/* 40684 0x9eec "黬" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x81,
+0x0c,0x0a,0x08,0xfe,0x88,0x88,0xfa,0x8a,0x8a,0xec,0xac,0xac,0xea,0x8a,0x96,0x22,
+/* 40685 0x9eed "黭" */
+0x00,0xfe,0x92,0xd6,0xbb,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x03,0xaa,0xa8,0x81,
+0x20,0x30,0x48,0x84,0x7a,0x00,0xfc,0x84,0x84,0xfc,0x48,0x48,0xfe,0x48,0x88,0x08,
+/* 40686 0x9eee "黮" */
+0x00,0xfe,0x93,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x11,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x48,0x48,0xfc,0x48,0x78,0x48,0x78,0x48,0x48,0xfe,0x80,0xa8,0xc4,0x80,0xfe,0x00,
+/* 40687 0x9eef "黯" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x20,0x10,0xfe,0x00,0x44,0x28,0xfe,0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,
+/* 40688 0x9ef0 "黰" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x28,0x44,0x82,
+/* 40689 0x9ef1 "黱" */
+0x01,0x78,0x49,0x48,0x4b,0x79,0x4b,0x4d,0x49,0x79,0x48,0x49,0x48,0x4b,0x49,0x9a,
+0x24,0xa8,0xfc,0x40,0xfe,0x08,0xfc,0xae,0x74,0xfc,0x20,0xfc,0x20,0xfe,0x54,0x2a,
+/* 40690 0x9ef2 "黲" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0x20,0x44,0xfe,0x44,0xaa,0xee,0x10,0x28,0x54,0xaa,0x50,0x24,0x48,0x10,0x60,
+/* 40691 0x9ef3 "黳" */
+0x7f,0x48,0x5e,0x64,0x5f,0x4a,0x7f,0x00,0x3f,0x29,0x25,0x3f,0x01,0xff,0x24,0x42,
+0x78,0x48,0x86,0x78,0x48,0x30,0x4c,0x00,0xf8,0x28,0x48,0xf8,0x00,0xfe,0x48,0x24,
+/* 40692 0x9ef4 "黴" */
+0x11,0x15,0x25,0x47,0x90,0x17,0x20,0x6f,0xa9,0x2d,0x2b,0x2f,0x21,0x2f,0x20,0x2a,
+0x10,0x50,0x50,0xd0,0x3e,0xa4,0x54,0xd4,0x54,0xd4,0x54,0xc8,0x08,0xd4,0x14,0xa2,
+/* 40693 0x9ef5 "黵" */
+0x00,0xfe,0x92,0xd7,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x81,
+0x40,0x7c,0x84,0xfe,0xa2,0xc8,0xfe,0x80,0xbe,0x80,0xbe,0x80,0xbe,0xa2,0xbe,0x22,
+/* 40694 0x9ef6 "黶" */
+0x3f,0x28,0x2f,0x20,0x2f,0x28,0x2f,0x28,0x29,0x20,0x2f,0x29,0x2f,0x40,0x5f,0x89,
+0xfe,0x88,0x8a,0x08,0xbe,0x88,0x88,0x94,0xa2,0x00,0xfe,0x52,0xfe,0x40,0xfe,0x24,
+/* 40695 0x9ef7 "黷" */
+0x00,0xfe,0x92,0xd6,0xba,0x92,0xfe,0x10,0xfe,0x10,0x1e,0xe0,0x02,0xaa,0xa8,0x80,
+0x10,0xfe,0x10,0x7c,0x00,0xfe,0xaa,0xfe,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x28,0x44,
+/* 40696 0x9ef8 "黸" */
+0x00,0xf8,0xa8,0xab,0xfa,0xab,0xfa,0x22,0xfa,0x22,0x3a,0xe2,0x0a,0xa5,0xa5,0x0b,
+0x40,0x7c,0x40,0xfc,0x44,0xf0,0x44,0xfc,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,
+/* 40697 0x9ef9 "黹" */
+0x04,0x24,0x14,0x04,0xff,0x01,0x11,0x09,0x3f,0x21,0x25,0x25,0x29,0x21,0x21,0x21,
+0x40,0x48,0x50,0x40,0xfe,0x00,0x10,0x20,0xf8,0x08,0x48,0x28,0x28,0x08,0x28,0x10,
+/* 40698 0x9efa "黺" */
+0x14,0x55,0x36,0x14,0xff,0x49,0x2a,0x7f,0x49,0x49,0x5d,0x6b,0x49,0x49,0x49,0x4b,
+0x08,0x28,0x28,0x28,0x44,0x44,0x82,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 40699 0x9efb "黻" */
+0x14,0x55,0x36,0x14,0xff,0x49,0x2a,0x7f,0x49,0x49,0x5d,0x6b,0x49,0x49,0x49,0x4b,
+0x28,0x24,0x24,0x20,0x7e,0x20,0x20,0x3c,0x34,0x54,0x54,0x54,0x88,0x88,0x14,0x22,
+/* 40700 0x9efc "黼" */
+0x14,0x55,0x36,0x14,0xff,0x49,0x2a,0x7f,0x49,0x49,0x5d,0x6b,0x49,0x49,0x49,0x4b,
+0x14,0x12,0x7e,0x10,0x10,0x7e,0x52,0x52,0x7e,0x52,0x52,0x7e,0x52,0x52,0x52,0x46,
+/* 40701 0x9efd "黽" */
+0x00,0x3f,0x22,0x22,0x3e,0x02,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x22,0x02,0x01,
+0x00,0xf8,0x88,0x88,0xf8,0x80,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x8a,0x82,0xfe,
+/* 40702 0x9efe "黾" */
+0x1f,0x10,0x10,0x1f,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x01,0x01,0x00,
+0xf0,0x10,0x10,0xf0,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x0a,0x02,0x02,0xfe,
+/* 40703 0x9eff "黿" */
+0x1f,0x00,0xff,0x08,0x30,0xdf,0x12,0x1e,0x02,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0xf0,0x00,0xfe,0x44,0x3c,0xf0,0x90,0xf0,0x80,0xf8,0x88,0xf8,0x88,0xfa,0x82,0xfe,
+/* 40704 0x9f00 "鼀" */
+0x01,0x3f,0x01,0xff,0x10,0x3f,0x52,0x1e,0x02,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xf8,0x00,0xfe,0x10,0xf8,0x94,0xf0,0x80,0xf8,0x88,0xf8,0x88,0xfa,0x82,0xfe,
+/* 40705 0x9f01 "鼁" */
+0x01,0x3f,0x01,0xff,0x04,0x1f,0x00,0x1f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xf8,0x00,0xfe,0x20,0xf0,0x00,0xf0,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40706 0x9f02 "鼂" */
+0x00,0x1f,0x10,0x1f,0x10,0xff,0x00,0x1f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,0xf0,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40707 0x9f03 "鼃" */
+0x01,0x3f,0x01,0xff,0x01,0x3f,0x01,0xff,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xf8,0x00,0xfe,0x00,0xf8,0x00,0xfe,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40708 0x9f04 "鼄" */
+0x09,0x0f,0x11,0x7f,0x05,0x19,0xe1,0x1f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xf0,0x00,0xfc,0x40,0x30,0x0e,0xf0,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40709 0x9f05 "鼅" */
+0x20,0x3f,0x48,0xff,0x14,0x22,0x41,0x1f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0x7c,0x44,0xc4,0x7c,0x44,0x00,0xf0,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40710 0x9f06 "鼆" */
+0x00,0xfd,0x85,0x01,0x79,0x48,0x79,0x49,0x79,0x21,0x11,0xfd,0x01,0x51,0x48,0x88,
+0x00,0xfc,0x54,0x54,0xdc,0x50,0xdc,0x54,0x54,0xdc,0x54,0x54,0xdc,0x50,0x52,0x3e,
+/* 40711 0x9f07 "鼇" */
+0x08,0x7e,0x08,0xfe,0x10,0x1e,0x22,0x5f,0x92,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x20,0x20,0x7e,0xc4,0x28,0x10,0x28,0xf6,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40712 0x9f08 "鼈" */
+0x49,0x2a,0x7f,0x49,0x5d,0x6b,0x49,0x5f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x20,0x3e,0x48,0x48,0xa8,0x10,0x28,0xf6,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40713 0x9f09 "鼉" */
+0x00,0x3e,0x22,0x3f,0x11,0x1f,0x11,0xff,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x00,0xf8,0x88,0xf8,0x10,0xf0,0x10,0xfe,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40714 0x9f0a "鼊" */
+0x00,0x7e,0x42,0x7e,0x40,0x7e,0xa2,0x3f,0x12,0x3e,0x22,0x3e,0x22,0x3e,0x02,0x01,
+0x10,0x7c,0x28,0xfe,0x10,0x7c,0x10,0xf0,0x90,0xf8,0x88,0xf8,0x88,0xf8,0x82,0xfe,
+/* 40715 0x9f0b "鼋" */
+0x1f,0x00,0xff,0x08,0x30,0xdf,0x10,0x1f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0xf0,0x00,0xfe,0x44,0x3c,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 40716 0x9f0c "鼌" */
+0x00,0x1f,0x10,0x1f,0x10,0xff,0x00,0x1f,0x10,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x00,0xf0,0x10,0xf0,0x10,0xfe,0x00,0xf0,0x10,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 40717 0x9f0d "鼍" */
+0x00,0x3e,0x22,0x3f,0x11,0x1f,0x11,0xff,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x01,0x00,
+0x00,0xf8,0x88,0xf8,0x10,0xf0,0x10,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xfa,0x02,0xfe,
+/* 40718 0x9f0e "鼎" */
+0x0f,0x08,0x0f,0x48,0x4f,0x48,0x4f,0x40,0x7c,0x04,0x04,0xfc,0x24,0x24,0x44,0x84,
+0xe0,0x20,0xe0,0x24,0xe4,0x24,0xe4,0x04,0x7c,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,
+/* 40719 0x9f0f "鼏" */
+0x7f,0x40,0x8f,0x08,0x0f,0x08,0x4f,0x48,0x4f,0x40,0x7c,0x04,0xfc,0x24,0x44,0x84,
+0xfe,0x02,0xe4,0x20,0xe0,0x20,0xe4,0x24,0xe4,0x04,0x7c,0x40,0x7c,0x44,0x44,0x44,
+/* 40720 0x9f10 "鼐" */
+0x7f,0x10,0x10,0x2f,0x48,0x8f,0x08,0x4f,0x48,0x4f,0x40,0x7c,0x04,0xfc,0x24,0x44,
+0xf8,0x08,0x1e,0xe2,0x2a,0xe4,0x20,0xe4,0x24,0xe4,0x04,0x7c,0x40,0x7c,0x44,0x44,
+/* 40721 0x9f11 "鼑" */
+0x01,0x01,0x01,0x1f,0x10,0x1f,0x10,0x5f,0x50,0x5f,0x40,0x7c,0x04,0xfc,0x24,0x44,
+0x00,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf4,0x14,0xf4,0x04,0x7c,0x40,0x7c,0x44,0x44,
+/* 40722 0x9f12 "鼒" */
+0x00,0x7f,0x04,0x19,0x6f,0x08,0x0f,0x48,0x4f,0x48,0x4f,0x7c,0x04,0xfc,0x24,0xc4,
+0x80,0xfc,0x80,0x80,0xe0,0x20,0xe0,0x24,0xe4,0x24,0xe4,0x7c,0x40,0x7c,0x44,0x44,
+/* 40723 0x9f13 "鼓" */
+0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,0x40,
+0x10,0x10,0x10,0xfe,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 40724 0x9f14 "鼔" */
+0x08,0x08,0xff,0x08,0x08,0x7e,0x00,0x7e,0x42,0x42,0x7e,0x42,0x24,0x0f,0xf0,0x40,
+0x10,0x10,0x10,0x1e,0x10,0x10,0xfc,0x44,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 40725 0x9f15 "鼕" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x1e,0xe8,0x1f,0x28,0x07,0x18,0xe1,0x0c,0x03,
+0x10,0x7e,0x10,0x7c,0x04,0x48,0x38,0x44,0x00,0xf0,0x20,0xc0,0x30,0x8e,0x40,0x00,
+/* 40726 0x9f16 "鼖" */
+0x01,0x7f,0x09,0xff,0x08,0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0x1e,0xe0,
+0x00,0xfc,0x20,0xfe,0x20,0x10,0x10,0xfe,0x10,0xfc,0x44,0x48,0x28,0x10,0x28,0xc6,
+/* 40727 0x9f17 "鼗" */
+0x24,0x14,0x24,0x08,0x70,0x08,0xff,0x08,0x7e,0x00,0x7e,0x42,0x7e,0x24,0x1e,0xe0,
+0x90,0xa0,0x94,0x84,0x7c,0x10,0x10,0xfe,0x10,0xfc,0x44,0x48,0x28,0x10,0x28,0xc6,
+/* 40728 0x9f18 "鼘" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0xfe,0x24,0x3c,0x20,0x3f,0x20,0x3c,0x24,0x44,
+0x10,0x7e,0x10,0x7c,0x44,0x28,0x18,0xe6,0x48,0x78,0x08,0xf8,0x08,0x78,0x48,0x48,
+/* 40729 0x9f19 "鼙" */
+0x08,0xff,0x08,0x7f,0x41,0x7f,0x22,0x1f,0xff,0x11,0x1f,0x12,0x1f,0x04,0x7f,0x00,
+0x10,0x7e,0x10,0x7c,0x44,0x28,0x10,0x28,0xf6,0x10,0xf0,0x10,0xf0,0x40,0xfc,0x40,
+/* 40730 0x9f1a "鼚" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x1e,0xef,0x08,0x0f,0x08,0xff,0x11,0x14,0x18,
+0x10,0x7e,0x10,0x7c,0x04,0x48,0x38,0x44,0xf0,0x00,0xf0,0x00,0xfe,0x10,0xe0,0x1c,
+/* 40731 0x9f1b "鼛" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x7e,0x22,0x54,0x08,0x37,0xc0,0x1f,0x10,0x1f,
+0x10,0x7e,0x10,0x7c,0x44,0x38,0x44,0xa2,0x38,0x24,0x20,0xfe,0x00,0xf0,0x10,0xf0,
+/* 40732 0x9f1c "鼜" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x7f,0x09,0x07,0xf9,0x1f,0x11,0x1f,0x01,0x7f,
+0x10,0x7e,0x10,0x7c,0x44,0x38,0x44,0xf2,0x20,0xc0,0x3e,0xf0,0x10,0xf0,0x08,0xfc,
+/* 40733 0x9f1d "鼝" */
+0x24,0x14,0x87,0x44,0x17,0x24,0x4f,0x90,0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0xfe,
+0xa4,0xa4,0xbc,0x04,0xfc,0x04,0xbc,0xa4,0x10,0x7e,0x10,0x7c,0x44,0x28,0x18,0xe6,
+/* 40734 0x9f1e "鼞" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0xfe,0x11,0x7f,0x48,0x8f,0x01,0x1f,0x01,0x7f,
+0x10,0x7e,0x10,0x7c,0x44,0x28,0x18,0xe6,0x10,0xfe,0x22,0xe4,0x00,0xf0,0x00,0xfc,
+/* 40735 0x9f1f "鼟" */
+0x08,0xff,0x08,0x7e,0x42,0x7e,0x24,0x7e,0x04,0x2b,0x10,0x2f,0xc8,0x0f,0x04,0x7f,
+0x10,0x7e,0x10,0x7c,0x44,0x38,0xd4,0xa2,0x44,0xa8,0x10,0xe8,0x26,0xe0,0x40,0xfc,
+/* 40736 0x9f20 "鼠" */
+0x06,0x38,0x20,0x3e,0x20,0x20,0x3f,0x00,0x29,0x25,0x21,0x29,0x25,0x21,0x2d,0x31,
+0x00,0xf8,0x08,0xf8,0x08,0x08,0xf8,0x00,0x48,0x28,0x08,0x48,0x2a,0x0a,0x66,0x82,
+/* 40737 0x9f21 "鼡" */
+0x22,0x11,0x11,0x00,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x21,0x41,0x41,0x80,
+0x08,0x08,0x10,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x0a,0x0a,0x06,0x02,
+/* 40738 0x9f22 "鼢" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x01,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x08,0x28,0x28,0x28,0x44,0x44,0x82,0x7c,0x24,0x24,0x24,0x24,0x44,0x44,0x94,0x08,
+/* 40739 0x9f23 "鼣" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x14,0x12,0x12,0x10,0xfe,0x10,0x10,0x10,0x28,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 40740 0x9f24 "鼤" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x10,0x10,0xfe,0x44,0x44,0x44,0x44,0x44,0x28,0x28,0x10,0x10,0x28,0x44,0x82,
+/* 40741 0x9f25 "鼥" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x28,0x24,0x24,0x20,0xfe,0x20,0x20,0x3c,0x34,0x54,0x54,0x54,0x88,0x88,0x14,0x22,
+/* 40742 0x9f26 "鼦" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x54,0x48,0x80,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40743 0x9f27 "鼧" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x10,0x10,0xfe,0x82,0x84,0x40,0x44,0x48,0x50,0x60,0x42,0x42,0x42,0x3e,0x00,
+/* 40744 0x9f28 "鼨" */
+0x20,0xce,0x82,0xee,0x82,0x83,0xfe,0x00,0x92,0x93,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x20,0x3e,0x42,0xc4,0x28,0x10,0x28,0x44,0x82,0x30,0x08,0x04,0x60,0x10,0x08,
+/* 40745 0x9f29 "鼩" */
+0x20,0xce,0x82,0xee,0x82,0x83,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x40,0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0x94,0x94,0xf4,0x94,0x04,0x28,0x10,
+/* 40746 0x9f2a "鼪" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x10,0x50,0x50,0x7c,0x50,0x90,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 40747 0x9f2b "鼫" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xdb,0x92,0xda,0x92,0x93,0xd9,
+0x00,0x00,0xfe,0x10,0x10,0x20,0x20,0x7c,0x44,0xc4,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40748 0x9f2c "鼬" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x10,0x10,0x10,0xfe,0x92,0x92,0x92,0x92,0xfe,0x92,0x92,0x92,0x92,0xfe,0x82,
+/* 40749 0x9f2d "鼭" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x10,0x10,0x7c,0x10,0x10,0xfe,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 40750 0x9f2e "鼮" */
+0x20,0xcc,0x85,0xec,0x84,0x84,0xfc,0x01,0xa8,0xf9,0xa9,0xf8,0xa8,0xa9,0xfa,0xa4,
+0x00,0x06,0xd8,0x48,0x48,0x88,0x9e,0xc8,0x48,0x48,0x48,0x9e,0x80,0x40,0x3e,0x00,
+/* 40751 0x9f2f "鼯" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0xfe,0x10,0x10,0x7c,0x24,0x24,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 40752 0x9f30 "鼰" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,0x28,0x24,0x42,0x82,
+/* 40753 0x9f31 "鼱" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x54,0x48,
+/* 40754 0x9f32 "鼲" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 40755 0x9f33 "鼳" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0xfe,0x82,0xfe,0x82,0xfe,0x82,0xfe,0x14,0x12,0xfe,0x10,0x28,0x28,0x44,0x82,
+/* 40756 0x9f34 "鼴" */
+0x20,0xcd,0x85,0xed,0x85,0x85,0xfd,0x01,0xa9,0xf9,0xa9,0xf9,0xa9,0xa9,0xfb,0xa5,
+0x00,0xfe,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x10,0xfe,0x24,0x64,0x18,0x24,0x42,0xfe,
+/* 40757 0x9f35 "鼵" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x10,0xfe,0x82,0x44,0x92,0x14,0x12,0xfe,0x10,0x28,0x28,0x28,0x44,0x44,0x82,
+/* 40758 0x9f36 "鼶" */
+0x20,0xcc,0x85,0xed,0x85,0x85,0xfd,0x01,0xa9,0xf9,0xa9,0xf9,0xaa,0xa8,0xfa,0xa4,
+0x08,0x3c,0xd0,0x1c,0x10,0x7c,0x54,0x58,0x70,0x54,0x4c,0x40,0x78,0xa8,0x2a,0x46,
+/* 40759 0x9f37 "鼷" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x0e,0xf0,0x22,0x92,0x44,0x20,0x44,0xf8,0x10,0x24,0xfe,0x10,0xfe,0x28,0x44,0x82,
+/* 40760 0x9f38 "鼸" */
+0x20,0xcc,0x84,0xed,0x84,0x85,0xfc,0x03,0xa8,0xf9,0xa8,0xf8,0xa9,0xaa,0xfa,0xa4,
+0x88,0x50,0x00,0xfe,0x50,0xfc,0x54,0xfe,0x54,0xfc,0x50,0xd8,0x54,0x52,0x50,0x50,
+/* 40761 0x9f39 "鼹" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x10,0xfe,0x82,0x10,0xfe,0x24,0x68,0x10,0x28,0x44,
+/* 40762 0x9f3a "鼺" */
+0x20,0xcd,0x85,0xed,0x85,0x85,0xfd,0x00,0xab,0xfa,0xaa,0xfb,0xaa,0xaa,0xfb,0xa6,
+0x00,0xfc,0x24,0xfc,0x24,0xfc,0x04,0x00,0xfe,0xaa,0xaa,0xfe,0xaa,0xaa,0xfe,0x22,
+/* 40763 0x9f3b "鼻" */
+0x02,0x1f,0x10,0x1f,0x10,0x1f,0x00,0x3f,0x21,0x3f,0x21,0x3f,0x00,0xff,0x08,0x10,
+0x00,0xf0,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x20,0x20,
+/* 40764 0x9f3c "鼼" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x04,0x04,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x4c,0x74,0x44,0x04,0x84,0x04,0x04,
+/* 40765 0x9f3d "鼽" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x20,0x20,0x20,0x20,0xf8,0x28,0x28,0x28,0x28,0x28,0x28,0x2a,0x2a,0xca,0x46,0x80,
+/* 40766 0x9f3e "鼾" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x10,0x10,
+/* 40767 0x9f3f "鼿" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x00,0x00,0x7c,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x28,0x2a,0x2a,0xaa,0x46,0x80,
+/* 40768 0x9f40 "齀" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x00,0x7c,0x20,0x20,0x20,0x38,0x28,0x28,0x58,0x48,0x48,0x48,0x5a,0xea,0x4a,0x06,
+/* 40769 0x9f41 "齁" */
+0x10,0x3e,0x22,0x3e,0x22,0x3f,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x40,0x40,0x40,0xfc,0x84,0x04,0x74,0x54,0x54,0x54,0x74,0x54,0x04,0x84,0x28,0x10,
+/* 40770 0x9f42 "齂" */
+0x20,0x7c,0x44,0x7c,0x45,0x7c,0x00,0xfe,0x93,0xfe,0x92,0xfe,0x01,0xfe,0x44,0x84,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,
+/* 40771 0x9f43 "齃" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x93,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x84,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfe,0x12,0x92,0xaa,0x82,0xfa,0x02,0x14,0x08,
+/* 40772 0x9f44 "齄" */
+0x10,0x3e,0x22,0x3e,0x22,0x3e,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x00,0xff,0x22,0x42,
+0x10,0x10,0xfe,0x38,0x54,0x92,0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x80,0xfe,0x00,
+/* 40773 0x9f45 "齅" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x85,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x28,0x24,0xfe,0x20,0x50,0x88,0x06,
+/* 40774 0x9f46 "齆" */
+0x20,0x7d,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x84,
+0x92,0x24,0x92,0x00,0x7c,0x44,0x7c,0x00,0xfe,0x92,0x92,0xfe,0x80,0x82,0x82,0x7e,
+/* 40775 0x9f47 "齇" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x85,
+0x20,0x3c,0x20,0xfe,0xa2,0xb8,0xe4,0x9c,0x80,0xbc,0xa4,0xbc,0xa4,0xbc,0xa4,0x7e,
+/* 40776 0x9f48 "齈" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x92,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x85,
+0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x80,0xbe,0x80,0xfe,0xa8,0xaa,0xa4,0x32,
+/* 40777 0x9f49 "齉" */
+0x20,0xfb,0x89,0xf9,0x88,0xfb,0x03,0xf9,0xa8,0xfb,0xa8,0xfb,0x00,0xf9,0x52,0x90,
+0x20,0xfe,0x24,0xfc,0x20,0xfe,0x56,0xdc,0x88,0xfe,0x88,0xfe,0x94,0x88,0xa4,0xc2,
+/* 40778 0x9f4a "齊" */
+0x02,0x01,0x7f,0x04,0x02,0x7d,0x25,0x25,0x45,0x8d,0x10,0x1f,0x10,0x1f,0x10,0x20,
+0x00,0x00,0xfc,0x40,0x8c,0x70,0x50,0x50,0x48,0x66,0x10,0xf0,0x10,0xf0,0x10,0x10,
+/* 40779 0x9f4b "齋" */
+0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x20,0x3f,0x20,0x3f,0x21,0x25,0x25,0x49,0x81,
+0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x08,0xf8,0x08,0xf8,0x08,0x48,0x28,0x28,0x08,
+/* 40780 0x9f4c "齌" */
+0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x20,0x3f,0x20,0x3f,0x20,0x25,0x29,0x42,0x8c,
+0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x08,0xf8,0x08,0xf8,0x08,0x28,0x48,0x88,0x48,
+/* 40781 0x9f4d "齍" */
+0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x20,0x3f,0x20,0x3f,0x40,0x3f,0x24,0x24,0xff,
+0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x48,0x48,0xfe,
+/* 40782 0x9f4e "齎" */
+0x01,0xff,0x02,0x7d,0x25,0x25,0x4d,0x20,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x4f,0x84,
+0x00,0xfe,0x84,0x78,0x50,0x48,0x64,0x08,0xf8,0x08,0xe8,0x28,0xe8,0x28,0xe8,0x48,
+/* 40783 0x9f4f "齏" */
+0x01,0xff,0x02,0x7d,0x25,0x4d,0xa0,0x3f,0x22,0x2e,0x22,0x2e,0x22,0x4e,0x42,0x8f,
+0x00,0xfe,0x88,0x70,0x48,0x66,0x08,0xf8,0x88,0xe8,0x88,0xe8,0x88,0xe8,0x88,0xe8,
+/* 40784 0x9f50 "齐" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x0c,0x30,0xc8,0x08,0x08,0x08,0x08,0x10,0x10,0x20,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x60,0x18,0x26,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+/* 40785 0x9f51 "齑" */
+0x02,0x01,0x7f,0x08,0x04,0x03,0x1c,0xe2,0x2e,0x22,0x2e,0x22,0x2e,0x22,0x5f,0x80,
+0x00,0x00,0xfc,0x20,0x40,0x80,0x70,0x8e,0xe8,0x88,0xe8,0x88,0xe8,0x88,0xf8,0x08,
+/* 40786 0x9f52 "齒" */
+0x01,0x11,0x11,0x11,0x11,0xff,0x04,0x24,0x2a,0x31,0x3f,0x24,0x2a,0x31,0x3f,0x00,
+0x00,0x00,0xf8,0x00,0x00,0xfe,0x40,0x48,0xa8,0x18,0xf8,0x48,0xa8,0x18,0xf8,0x08,
+/* 40787 0x9f53 "齓" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x22,0x1e,0x00,
+/* 40788 0x9f54 "齔" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x20,0x20,0x20,0x20,0x22,0x24,0x28,0x30,0x20,0x60,0xa0,0x22,0x22,0x22,0x1e,0x00,
+/* 40789 0x9f55 "齕" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x20,0x20,0x20,0x7e,0x40,0x80,0x3c,0x04,0x08,0x10,0x20,0x40,0x42,0x42,0x3e,0x00,
+/* 40790 0x9f56 "齖" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9f,0xe2,0x02,
+0x00,0xfc,0x08,0x48,0x48,0x48,0x88,0xfe,0x18,0x28,0x28,0x48,0x88,0x08,0x28,0x10,
+/* 40791 0x9f57 "齗" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x88,
+/* 40792 0x9f58 "齘" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x10,0x10,0x10,0x28,0x28,0x44,0xaa,0x28,0x28,0x28,0x28,0x28,0x28,0x48,0x48,0x88,
+/* 40793 0x9f59 "齙" */
+0x10,0x50,0x5c,0x50,0xff,0x2a,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x40,0x40,0xfc,0x84,0x04,0xf4,0x94,0x94,0xf4,0x84,0x94,0x88,0x82,0x82,0x7e,0x00,
+/* 40794 0x9f5a "齚" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x20,0x20,0x20,0x3e,0x50,0x50,0x90,0x1e,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,
+/* 40795 0x9f5b "齛" */
+0x10,0x50,0x5c,0x50,0xfe,0x29,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x28,0xa8,0xa8,0xa8,0xa8,0xfe,0xa8,0xa8,0xa8,0xa8,0xb8,0x80,0x80,0x80,0xfe,0x00,
+/* 40796 0x9f5c "齜" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x03,
+0x08,0x28,0x28,0x28,0xa8,0xaa,0xbc,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0xba,0xea,0x86,
+/* 40797 0x9f5d "齝" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xab,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x20,0x20,0x20,0x40,0x48,0x84,0xfe,0x82,0x00,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 40798 0x9f5e "齞" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,0x28,0x24,0x44,0x42,0x82,
+/* 40799 0x9f5f "齟" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0xfe,0x00,
+/* 40800 0x9f60 "齠" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x54,0x48,0x80,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40801 0x9f61 "齡" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x10,0x10,0x10,0x28,0x28,0x54,0x8a,0x08,0x7c,0x04,0x08,0x28,0x10,0x10,0x08,0x08,
+/* 40802 0x9f62 "齢" */
+0x08,0x28,0x2e,0x28,0x28,0xff,0x00,0x49,0x6b,0x49,0x7f,0x5d,0x6b,0x4f,0x79,0x00,
+0x10,0x10,0x10,0x28,0x28,0x54,0x8a,0x08,0x7c,0x04,0x08,0x28,0x10,0x10,0x08,0x08,
+/* 40803 0x9f63 "齣" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x20,0x20,0x20,0x7c,0x44,0x84,0x74,0x54,0x54,0x54,0x74,0x54,0x04,0x04,0x28,0x10,
+/* 40804 0x9f64 "齤" */
+0x11,0x09,0x7f,0x04,0xff,0x11,0x29,0xc9,0x7f,0x04,0x2a,0x3f,0x24,0x2a,0x3f,0x00,
+0x10,0x20,0xfc,0x00,0xfe,0x10,0xe8,0x06,0xfc,0x40,0xa8,0xf8,0x48,0xa8,0xf8,0x08,
+/* 40805 0x9f65 "齥" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0x20,0x20,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xfc,0x20,0x24,0x18,0x12,0x6a,0x86,0x02,
+/* 40806 0x9f66 "齦" */
+0x08,0x08,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x41,0x7f,0x00,
+0x00,0x7c,0x44,0x44,0x7c,0x44,0x44,0x7c,0x50,0x52,0x54,0x48,0x54,0x66,0x42,0x00,
+/* 40807 0x9f67 "齧" */
+0x08,0x7f,0x08,0x3e,0x08,0x7f,0x09,0x09,0x7f,0x04,0x2a,0x3f,0x24,0x2a,0x3f,0x00,
+0x00,0x7c,0x24,0x24,0x44,0x54,0xe8,0x00,0xfc,0x40,0xa8,0xf8,0x48,0xa8,0xf8,0x08,
+/* 40808 0x9f68 "齨" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x20,0x4c,0x44,0x44,0x44,0x44,0x6c,0x44,0x44,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 40809 0x9f69 "齩" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd7,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x20,0x10,0x10,0xfe,0x00,0x44,0x82,0x00,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 40810 0x9f6a "齪" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x10,0x10,0x50,0x5e,0x50,0x50,0x70,0x9e,0x00,
+/* 40811 0x9f6b "齫" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x00,0xfe,0x92,0x92,0x92,0xfe,0x92,0xb2,0xba,0xd6,0x92,0x92,0x92,0x82,0xfe,0x82,
+/* 40812 0x9f6c "齬" */
+0x08,0x28,0x2f,0x28,0xff,0x14,0x55,0x6b,0x41,0x7f,0x55,0x55,0x6b,0x4f,0x71,0x01,
+0x00,0xfc,0x10,0x10,0x7c,0x24,0x24,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,
+/* 40813 0x9f6d "齭" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0x00,0x32,0xcc,0x88,0x88,0xe8,0xae,0xaa,0xaa,0xea,0x8a,0x8a,0x8a,0x8a,0x12,0x22,
+/* 40814 0x9f6e "齮" */
+0x10,0x50,0x5d,0x50,0xfe,0x28,0xab,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x20,0x20,0xfc,0x20,0x50,0x88,0xfe,0x08,0xe8,0xa8,0xa8,0xe8,0xa8,0x08,0x28,0x10,
+/* 40815 0x9f6f "齯" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x03,
+0x00,0x20,0xce,0x82,0x82,0xee,0x82,0x82,0xfe,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40816 0x9f70 "齰" */
+0x10,0x50,0x5c,0x51,0xfe,0x28,0xab,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x48,0x48,0x48,0xfe,0x48,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 40817 0x9f71 "齱" */
+0x10,0x51,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xab,0xd6,0x9e,0xe2,0x02,
+0x00,0xf0,0xae,0xaa,0xea,0xaa,0xaa,0xea,0xaa,0xaa,0xb4,0xe4,0x24,0x2a,0x2a,0x30,
+/* 40818 0x9f72 "齲" */
+0x10,0x51,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x0e,0xf0,0x10,0xfe,0x92,0x92,0xfe,0x10,0xfe,0x92,0x9a,0x96,0xfe,0x82,0x8a,0x84,
+/* 40819 0x9f73 "齳" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x00,0xfe,0x92,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 40820 0x9f74 "齴" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0x20,0x10,0xfe,0x44,0x28,0xfe,0x88,0x90,0xa4,0x88,0x90,0xa2,0x84,0x88,0x10,0x60,
+/* 40821 0x9f75 "齵" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x00,0x7c,0x54,0x54,0x7c,0x54,0x54,0x7c,0x10,0xfe,0x92,0x96,0xbe,0x82,0x8a,0x84,
+/* 40822 0x9f76 "齶" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x00,0xee,0xaa,0xaa,0xee,0x00,0x7c,0x00,0xfe,0x20,0x40,0x7c,0x04,0x04,0x28,0x10,
+/* 40823 0x9f77 "齷" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0x00,0xfe,0x82,0x82,0xfe,0x80,0xbe,0x90,0x94,0xbe,0x8a,0x88,0xbe,0x88,0x08,0x7e,
+/* 40824 0x9f78 "齸" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe3,0x02,
+0x44,0x28,0x00,0xfe,0x00,0x28,0x44,0x82,0x00,0xfe,0xaa,0xaa,0xaa,0xaa,0xfe,0x00,
+/* 40825 0x9f79 "齹" */
+0x08,0x04,0x7f,0x01,0xff,0x04,0x1f,0xe0,0x1f,0x01,0x09,0x09,0x7f,0x24,0x2a,0x3f,
+0x20,0x40,0xfc,0x00,0xfe,0x00,0xf8,0x80,0xfc,0x00,0xf0,0x00,0xfc,0x48,0xa8,0xf8,
+/* 40826 0x9f7a "齺" */
+0x10,0x50,0x5c,0x51,0xfe,0x28,0xaa,0xd6,0x83,0xfe,0xab,0xaa,0xd6,0x9e,0xe2,0x03,
+0x40,0x40,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x48,0xfe,0x22,0xaa,0xfa,0x42,0x94,0x08,
+/* 40827 0x9f7b "齻" */
+0x10,0x50,0x5c,0x50,0xfe,0x28,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x7c,0x44,0xfe,0x28,0x44,0x82,
+/* 40828 0x9f7c "齼" */
+0x10,0x50,0x5d,0x50,0xfe,0x29,0xaa,0xd6,0x83,0xfe,0xaa,0xaa,0xd6,0x9f,0xe2,0x02,
+0x88,0x88,0xfe,0x88,0xdc,0xaa,0x88,0x00,0xfe,0x22,0xa0,0xbc,0xa0,0x60,0x3e,0x00,
+/* 40829 0x9f7d "齽" */
+0x10,0x50,0x5d,0x50,0xfe,0x29,0xaa,0xd6,0x82,0xfe,0xaa,0xaa,0xd6,0x9e,0xe2,0x02,
+0x44,0x44,0xee,0x44,0xee,0x54,0x44,0x00,0x7c,0x00,0xfe,0x10,0x54,0x92,0x50,0x20,
+/* 40830 0x9f7e "齾" */
+0x0f,0x08,0x7f,0x49,0x7e,0x49,0x7f,0x52,0x9e,0x04,0x7f,0x04,0x2a,0x31,0x3f,0x00,
+0x14,0x12,0x10,0x7e,0x10,0x28,0x28,0x44,0xfa,0x80,0xfe,0x40,0xa4,0x14,0xfc,0x04,
+/* 40831 0x9f7f "齿" */
+0x01,0x01,0x11,0x11,0x11,0x11,0xff,0x00,0x21,0x21,0x22,0x24,0x28,0x20,0x3f,0x00,
+0x00,0x00,0xf8,0x00,0x00,0x00,0xfe,0x00,0x08,0x08,0x88,0x48,0x28,0x08,0xf8,0x08,
+/* 40832 0x9f80 "龀" */
+0x08,0x08,0x28,0x2f,0x28,0x28,0xff,0x00,0x49,0x49,0x55,0x63,0x41,0x47,0x79,0x01,
+0x20,0x20,0x20,0x22,0x22,0x24,0x28,0x30,0x20,0x60,0xa0,0x22,0x22,0x22,0x1e,0x00,
+/* 40833 0x9f81 "龁" */
+0x08,0x08,0x28,0x2f,0x28,0x28,0xff,0x00,0x49,0x49,0x55,0x63,0x41,0x47,0x79,0x01,
+0x20,0x20,0x20,0x7e,0x40,0x80,0x3c,0x04,0x08,0x10,0x20,0x40,0x42,0x42,0x3e,0x00,
+/* 40834 0x9f82 "龂" */
+0x08,0x08,0x28,0x2f,0x28,0x28,0xff,0x00,0x49,0x49,0x55,0x63,0x41,0x47,0x79,0x01,
+0x00,0x0c,0x70,0x40,0x40,0x40,0x7e,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x88,
+/* 40835 0x9f83 "龃" */
+0x08,0x08,0x28,0x2f,0x28,0x28,0xff,0x00,0x49,0x49,0x55,0x63,0x41,0x47,0x79,0x01,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x44,0xfe,0x00,
+/* 40836 0x9f84 "龄" */
+0x10,0x10,0x50,0x5e,0x50,0x51,0xfe,0x00,0x93,0x92,0xaa,0xc6,0x82,0x8e,0xf2,0x02,
+0x20,0x20,0x50,0x50,0x88,0x24,0x12,0x10,0xfc,0x04,0x08,0x88,0x50,0x20,0x10,0x10,
+/* 40837 0x9f85 "龅" */
+0x10,0x10,0x50,0x5e,0x50,0x51,0xfe,0x00,0x92,0x92,0xaa,0xc6,0x82,0x8e,0xf2,0x02,
+0x40,0x40,0x7c,0x84,0x84,0xf4,0x94,0x94,0x94,0xf4,0x84,0xa8,0x92,0x82,0x7e,0x00,
+/* 40838 0x9f86 "龆" */
+0x08,0x08,0x28,0x2f,0x28,0x28,0xff,0x00,0x49,0x49,0x55,0x63,0x41,0x47,0x79,0x01,
+0x00,0xfe,0x22,0x22,0x22,0x22,0x4a,0x44,0x80,0x7e,0x42,0x42,0x42,0x42,0x7e,0x42,
+/* 40839 0x9f87 "龇" */
+0x10,0x10,0x50,0x5e,0x50,0x50,0xfe,0x00,0x92,0x92,0xaa,0xc6,0x82,0x8e,0xf2,0x03,
+0x08,0x28,0x28,0x28,0xa8,0xaa,0xbc,0xa8,0xa8,0xa8,0xa8,0xa8,0xaa,0xba,0xea,0x86,
+/* 40840 0x9f88 "龈" */
+0x10,0x10,0x50,0x5e,0x50,0x50,0xfe,0x00,0x92,0x92,0xaa,0xc6,0x82,0x8e,0xf2,0x02,
+0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xa4,0xc2,0x80,
+/* 40841 0x9f89 "龉" */
+0x10,0x11,0x50,0x5e,0x50,0x50,0xfe,0x01,0x92,0x92,0xaa,0xc6,0x82,0x8e,0xf2,0x02,
+0x00,0xfc,0x20,0x20,0xfc,0x44,0x44,0xfe,0x00,0x00,0xfc,0x84,0x84,0x84,0xfc,0x84,
+/* 40842 0x9f8a "龊" */
+0x08,0x08,0x28,0x2f,0x28,0x28,0xff,0x00,0x49,0x49,0x55,0x63,0x41,0x47,0x79,0x01,
+0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x10,0x10,0x50,0x5e,0x50,0x50,0x70,0x9e,0x00,
+/* 40843 0x9f8b "龋" */
+0x10,0x11,0x50,0x5e,0x50,0x50,0xfe,0x00,0x92,0x92,0xaa,0xc6,0x82,0x8e,0xf2,0x02,
+0x0e,0xf0,0x10,0xfe,0x92,0x92,0xfe,0x10,0xfe,0x92,0x9a,0x96,0xfe,0x82,0x8a,0x84,
+/* 40844 0x9f8c "龌" */
+0x10,0x10,0x50,0x5e,0x50,0x50,0xfe,0x00,0x92,0x92,0xaa,0xc6,0x82,0x8e,0xf3,0x02,
+0x00,0xfe,0x82,0x82,0xfe,0x80,0xfe,0x90,0xa4,0xfe,0x92,0x90,0xfc,0x90,0x10,0xfe,
+/* 40845 0x9f8d "龍" */
+0x10,0x08,0x7e,0x24,0x18,0xff,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x42,0x42,0x4a,0x44,
+0x40,0x40,0x7e,0x40,0x7e,0x02,0x7e,0x40,0x7e,0x40,0x7e,0x40,0x7e,0x40,0x42,0x3e,
+/* 40846 0x9f8e "龎" */
+0x00,0x3f,0x22,0x2f,0x25,0x22,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x48,0x48,0x89,
+0x00,0xfe,0x20,0xbc,0x20,0x3c,0x84,0x3c,0xa0,0xbc,0xa0,0xbc,0xa0,0xbc,0xa2,0x9e,
+/* 40847 0x9f8f "龏" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x08,0x08,0xff,0x08,0x10,0x20,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x78,0x42,0x3e,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 40848 0x9f90 "龐" */
+0x00,0x7f,0x42,0x5f,0x49,0x46,0x7f,0x40,0x5f,0x50,0x5f,0x50,0x5f,0x50,0x52,0x91,
+0x80,0xfe,0x20,0xbc,0x20,0x3c,0x84,0x3c,0xa0,0xbc,0xa0,0xbc,0xa0,0xbc,0xa2,0x1e,
+/* 40849 0x9f91 "龑" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x00,0x3f,0x02,0xff,0x08,0x70,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x78,0x42,0x3e,0x00,0xf8,0x00,0xfe,0x60,0x1c,
+/* 40850 0x9f92 "龒" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x00,0x3f,0x00,0xff,0x11,0x23,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x42,0x3e,0x00,0xf8,0x00,0xfe,0x10,0x08,
+/* 40851 0x9f93 "龓" */
+0x21,0x20,0xfb,0x20,0x42,0x79,0x4b,0xc8,0x7b,0x4a,0x4b,0x7a,0x4b,0x4a,0x4a,0x5a,
+0x10,0x90,0xde,0x10,0x5e,0x82,0xde,0x10,0xde,0x50,0xde,0x50,0xde,0x50,0x52,0xce,
+/* 40852 0x9f94 "龔" */
+0x08,0x7f,0x14,0xff,0x22,0x3e,0x22,0x3e,0x22,0x26,0x04,0x3f,0x04,0xff,0x08,0x10,
+0x40,0x7c,0x40,0x7c,0x04,0x7c,0x40,0x78,0x42,0x3e,0x40,0xf8,0x40,0xfe,0x20,0x10,
+/* 40853 0x9f95 "龕" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x08,0x3e,0x14,0xff,0x22,0x3e,0x22,0x26,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x40,0x7c,0x40,0x78,0x08,0x78,0x42,0x3e,
+/* 40854 0x9f96 "龖" */
+0x88,0x4e,0xf8,0xa8,0x4e,0xf2,0x0e,0xe8,0xae,0xa8,0xee,0xa8,0xee,0xa8,0xaa,0xa6,
+0x88,0x4e,0xf8,0xa8,0x4e,0xf2,0x0e,0xe8,0xae,0xa8,0xee,0xa8,0xee,0xa8,0xaa,0xa6,
+/* 40855 0x9f97 "龗" */
+0x3f,0x01,0x7f,0x49,0x84,0x3b,0x2a,0x3b,0x08,0x3e,0x14,0xff,0x22,0x3e,0x22,0x26,
+0xf8,0x00,0xfe,0x22,0x14,0xb8,0xa8,0xb8,0x40,0x7c,0x40,0x78,0x08,0x78,0x42,0x3e,
+/* 40856 0x9f98 "龘" */
+0x08,0x3e,0x14,0xff,0x22,0x3e,0x22,0x48,0xe8,0xae,0xf8,0x0e,0xe2,0xae,0xe8,0xae,
+0x40,0x7c,0x40,0x78,0x08,0x78,0x42,0x7e,0xe8,0xae,0xf8,0x0e,0xe2,0xae,0xe8,0xae,
+/* 40857 0x9f99 "龙" */
+0x04,0x04,0x04,0x04,0xff,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x11,0x22,0x44,0x80,
+0x20,0x10,0x10,0x00,0xfe,0x80,0x88,0x88,0x90,0xa0,0xc0,0x82,0x82,0x82,0x7e,0x00,
+/* 40858 0x9f9a "龚" */
+0x04,0x04,0x7f,0x09,0x09,0x17,0x20,0xc4,0x04,0x3f,0x04,0x04,0xff,0x08,0x10,0x20,
+0x20,0x10,0xfc,0x20,0xc4,0x04,0xfc,0x40,0x40,0xf8,0x40,0x40,0xfe,0x20,0x10,0x08,
+/* 40859 0x9f9b "龛" */
+0x01,0x06,0x18,0xef,0x00,0x1f,0x10,0x1f,0x04,0x04,0xff,0x09,0x11,0x21,0x4f,0x80,
+0x00,0xc0,0x30,0xee,0x00,0xf0,0x10,0xf0,0x40,0x20,0xfe,0x10,0x60,0x84,0x04,0xfc,
+/* 40860 0x9f9c "龜" */
+0x04,0x3f,0x20,0x3e,0x02,0x7a,0x0a,0xfe,0x0a,0x7a,0x02,0x7a,0x0a,0xfe,0x0a,0x79,
+0x00,0xf8,0x08,0xf8,0x80,0x80,0xfc,0x94,0xd4,0xa4,0xa4,0xd4,0x94,0xfc,0x82,0xfe,
+/* 40861 0x9f9d "龝" */
+0x10,0xe7,0x24,0x27,0x20,0xfe,0x22,0x37,0x6a,0x66,0xa0,0x26,0x22,0x27,0x22,0x26,
+0x80,0xfc,0x04,0xbc,0xa0,0xbe,0xa2,0xb6,0xaa,0xaa,0xb6,0xa2,0xbe,0xa0,0xa2,0x7e,
+/* 40862 0x9f9e "龞" */
+0x49,0x2a,0x7f,0x5d,0x6b,0x45,0x3f,0x20,0x3e,0x02,0x7a,0x0a,0xfe,0x0a,0x7a,0x01,
+0x20,0x3e,0x48,0xa8,0x10,0x6e,0xf8,0x08,0xf8,0x80,0xf8,0xd8,0xa8,0xd8,0x8a,0xfe,
+/* 40863 0x9f9f "龟" */
+0x04,0x04,0x0f,0x10,0x20,0x7f,0xa1,0x21,0x3f,0x21,0x21,0x3f,0x21,0x01,0x01,0x00,
+0x00,0x00,0xe0,0x20,0x40,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x02,0x02,0xfe,
+/* 40864 0x9fa0 "龠" */
+0x01,0x02,0x0c,0x30,0xdf,0x00,0x3b,0x2a,0x3b,0x00,0x3f,0x24,0x3f,0x24,0x24,0x20,
+0x00,0x80,0x60,0x18,0xf6,0x00,0xb8,0xa8,0xb8,0x00,0xf8,0x88,0xf8,0x88,0xa8,0x10,
+/* 40865 0x9fa1 "龡" */
+0x08,0x08,0x14,0x22,0x5d,0x80,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,0x55,0x43,
+0x10,0x10,0x10,0x10,0x3e,0xa2,0x44,0x90,0x10,0x10,0x10,0x28,0x28,0x24,0x44,0x82,
+/* 40866 0x9fa2 "龢" */
+0x08,0x08,0x14,0x22,0x5d,0x80,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,0x55,0x43,
+0x08,0x1c,0xf0,0x10,0x10,0x90,0x7c,0x10,0x38,0x34,0x54,0x54,0x92,0x10,0x10,0x10,
+/* 40867 0x9fa3 "龣" */
+0x08,0x08,0x14,0x22,0x5d,0x80,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,0x55,0x43,
+0x00,0xfc,0x04,0x04,0x7c,0x84,0x04,0xfe,0x10,0x92,0x54,0x38,0x54,0x92,0x50,0x20,
+/* 40868 0x9fa4 "龤" */
+0x08,0x08,0x14,0x22,0x5d,0x80,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,0x55,0x43,
+0x48,0x4a,0x6c,0x48,0x4a,0xea,0x56,0x20,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x42,
+/* 40869 0x9fa5 "龥" */
+0x08,0x08,0x14,0x22,0x5d,0x80,0x7f,0x55,0x7f,0x00,0x7f,0x55,0x7f,0x55,0x55,0x43,
+0x00,0x7e,0x08,0x10,0x7c,0xc4,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x28,0x44,0x82,
+/* 40870 0x9fa6 "龦" */
+0x11,0x10,0x10,0x13,0x16,0x5a,0x50,0x90,0x10,0x11,0x11,0x29,0x25,0x45,0x40,0x80,
+0x24,0xa4,0xa8,0xfe,0x02,0xfa,0x88,0xf8,0x20,0xfc,0x24,0x24,0x24,0x2c,0x20,0x20,
+/* 40871 0x9fa7 "龧" */
+0x01,0x01,0x79,0x49,0x49,0x48,0x79,0x48,0x4f,0x48,0x4b,0x7d,0x49,0x01,0x01,0x01,
+0xfc,0x04,0xfc,0x04,0xfc,0x44,0xf8,0x50,0xff,0x80,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 40872 0x9fa8 "龨" */
+0x00,0x3f,0x22,0x24,0x2f,0x34,0x24,0x27,0x24,0x27,0x24,0x24,0x27,0x24,0x3f,0x00,
+0x00,0xfc,0x80,0x40,0xfc,0x40,0x40,0xf8,0x40,0xf8,0x40,0x40,0xfc,0x00,0xfc,0x00,
+/* 40873 0x9fa9 "龩" */
+0x04,0x04,0xff,0x04,0x24,0xff,0x24,0x3c,0x08,0x7e,0x4a,0x7e,0x08,0xff,0x08,0x09,
+0x20,0x20,0xff,0x20,0x0c,0x70,0x40,0x40,0x7f,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 40874 0x9faa "龪" */
+0x08,0x08,0x08,0x7e,0x08,0x08,0xff,0x08,0x08,0x0e,0x28,0x28,0x28,0x5b,0x48,0x87,
+0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x50,0x50,0x50,0x48,0x88,0x84,0x02,0x00,0xff,
+/* 40875 0x9fab "龫" */
+0x10,0x10,0xff,0x10,0x7e,0x52,0x53,0x7e,0x52,0x52,0x7e,0x10,0xff,0x10,0x10,0x10,
+0x10,0x10,0x10,0x28,0x44,0x82,0x7c,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x10,
+/* 40876 0x9fac "龬" */
+0x10,0x13,0x1a,0x26,0x22,0x7f,0x92,0x12,0x7f,0x12,0x16,0x5a,0x32,0x1e,0xe2,0x02,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 40877 0x9fad "龭" */
+0x7d,0x51,0x7d,0x51,0x51,0x7d,0x50,0x50,0x7e,0x02,0x56,0x53,0x82,0x02,0x14,0x09,
+0xfe,0x22,0xfe,0x22,0x22,0xfe,0x48,0x48,0xfc,0x48,0x48,0xfe,0x00,0x48,0x84,0x02,
+/* 40878 0x9fae "龮" */
+0x7f,0x51,0x7c,0x51,0x52,0x7c,0x50,0x50,0x7e,0x02,0x56,0x52,0x82,0x03,0x14,0x09,
+0xde,0x4a,0xc6,0x4a,0x52,0xfc,0xa4,0xfc,0xa4,0xfc,0x48,0xfe,0x48,0xfe,0x84,0x02,
+/* 40879 0x9faf "龯" */
+0x10,0x10,0x28,0x25,0x41,0xb9,0x11,0x11,0x7d,0x11,0x15,0x59,0x31,0x1e,0xf2,0x44,
+0x28,0x24,0x20,0xfe,0x20,0x20,0x24,0x24,0x28,0x18,0x10,0x10,0x2a,0x2a,0x46,0x82,
+/* 40880 0x9fb0 "龰" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x11,0x11,0x11,0x11,0x11,0x2d,0x43,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 40881 0x9fb1 "龱" */
+0x00,0x7f,0x40,0x40,0x48,0x44,0x42,0x41,0x40,0x41,0x42,0x44,0x58,0x40,0x7f,0x40,
+0x00,0xfc,0x04,0x24,0x24,0x24,0x44,0x44,0x84,0x44,0x24,0x14,0x14,0x04,0xfc,0x04,
+/* 40882 0x9fb2 "龲" */
+0x10,0x10,0x29,0x25,0x41,0xbd,0x11,0x11,0x7d,0x11,0x15,0x59,0x31,0x1e,0xe2,0x44,
+0x20,0x10,0xfe,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x7c,0x10,0xfe,0x10,0x10,0x10,
+/* 40883 0x9fb3 "龳" */
+0x10,0x10,0x7e,0x10,0x10,0xfe,0x24,0x52,0x10,0x7e,0x10,0x10,0x10,0x1e,0xe1,0x00,
+0x10,0x10,0xfc,0x10,0x10,0xfe,0x48,0x94,0x10,0x7c,0x10,0x10,0x10,0x10,0xfe,0x00,
+/* 40884 0x9fb4 "龴" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x08,0x10,0x20,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 40885 0x9fb5 "龵" */
+0x00,0x7f,0x01,0x3f,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,
+0xf8,0x00,0x00,0xf8,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40886 0x9fb6 "龶" */
+0x01,0x01,0x7f,0x01,0x3f,0x01,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40887 0x9fb7 "龷" */
+0x08,0x08,0x7f,0x08,0x08,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40888 0x9fb8 "龸" */
+0x01,0x11,0x09,0x01,0x7f,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x00,0xfe,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40889 0x9fb9 "龹" */
+0x11,0x09,0x01,0x3f,0x01,0x02,0x7f,0x08,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+0x10,0x20,0x00,0xfc,0x00,0x00,0xfe,0x20,0x10,0x08,0x06,0x00,0x00,0x00,0x00,0x00,
+/* 40890 0x9fba "龺" */
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x54,0x10,0xfe,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40891 0x9fbb "龻" */
+0x20,0x27,0x48,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x00,0x00,0x00,0x00,0x00,0x00,
+0x88,0xe8,0x12,0xdc,0x08,0xd2,0x3e,0xc0,0x52,0xd2,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40892 0x9fbc "龼" */
+0x00,0x20,0x20,0x27,0x24,0x23,0xfa,0x24,0x21,0x23,0x25,0x21,0x39,0xc1,0x01,0x01,
+0x40,0x7c,0x40,0xfe,0x02,0xfc,0x64,0x92,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x08,0xf8,
+/* 40893 0x9fbd "龽" */
+0x10,0x10,0x10,0x11,0x56,0x55,0x55,0x99,0x11,0x11,0x11,0x29,0x24,0x45,0x41,0x82,
+0x80,0x80,0xfc,0x08,0x10,0xfc,0x24,0x24,0xfc,0x24,0x24,0xfc,0x00,0x54,0x2a,0x2a,
+/* 40894 0x9fbe "龾" */
+0x08,0x08,0x08,0x7f,0x4a,0x48,0x48,0x7e,0x42,0x62,0x54,0x4d,0x88,0x94,0x22,0x40,
+0x40,0x40,0x7e,0x42,0xa2,0xaa,0x72,0xfe,0x22,0x72,0xaa,0x22,0x22,0x02,0x0a,0x04,
+/* 40895 0x9fbf "龿" */
+0x08,0x08,0xff,0x08,0x04,0x08,0x0b,0x10,0x30,0x57,0x90,0x13,0x10,0x10,0x17,0x10,
+0x20,0x20,0xfe,0x20,0x40,0x40,0xf8,0x40,0x40,0xfc,0x40,0xf8,0x40,0x40,0xfe,0x00,
+/* 40896 0x9fc0 "鿀" */
+0x04,0xff,0x04,0x7f,0x50,0x5e,0x65,0x4a,0x7f,0x00,0xff,0x04,0x3f,0x24,0x2b,0x3f,
+0x20,0xfe,0x20,0x78,0x48,0x86,0x78,0x48,0x30,0xc8,0xfe,0x40,0xf8,0x48,0xa8,0xf8,
+/* 40897 0x9fc1 "鿁" */
+0x20,0x10,0x00,0xfc,0x03,0x78,0x00,0x78,0x00,0x7b,0x48,0x48,0x48,0x79,0x4a,0x04,
+0x90,0x90,0x90,0x90,0xfc,0x90,0x90,0x90,0x90,0xfe,0x00,0x00,0x90,0x08,0x04,0x04,
+/* 40898 0x9fc2 "鿂" */
+0x10,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x54,0x54,0x7c,0x54,0x10,0xfe,0x10,0x11,0x10,
+0x20,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0xae,0x52,0x0c,
+/* 40899 0x9fc3 "鿃" */
+0x00,0x00,0xf7,0x90,0x92,0xf1,0x91,0x92,0xf4,0x90,0x90,0x90,0xf1,0x92,0x04,0x08,
+0x40,0x40,0xfc,0x40,0x50,0x48,0x48,0xd4,0x60,0x40,0xa0,0xa0,0x10,0x08,0x04,0x02,
+/* 40900 0x9fc4 "鿄" */
+0x10,0x0b,0x40,0x22,0x09,0x10,0x61,0x22,0x25,0x01,0xff,0x05,0x09,0x31,0xc1,0x01,
+0x00,0xfc,0x44,0x44,0x84,0xc4,0x08,0x28,0x10,0x00,0xfe,0x40,0x20,0x18,0x06,0x00,
+/* 40901 0x9fc5 "鿅" */
+0x21,0x10,0x03,0xfa,0x09,0x10,0x11,0x38,0x54,0x91,0x16,0x11,0x10,0x10,0x10,0x10,
+0xfc,0x20,0xfe,0x22,0xac,0x20,0x8c,0x20,0x50,0x88,0x26,0xf8,0x08,0xd0,0x20,0x10,
+/* 40902 0x9fc6 "鿆" */
+0x40,0x20,0x00,0xf8,0x0b,0x10,0x20,0x30,0x68,0xa1,0x21,0x21,0x22,0x22,0x24,0x20,
+0x40,0x40,0x40,0x40,0xfe,0x80,0x80,0xfc,0x84,0x44,0x48,0x28,0x10,0x28,0x44,0x82,
+/* 40903 0x9fc7 "鿇" */
+0x08,0x08,0x11,0x12,0x35,0x50,0x90,0x17,0x10,0x10,0x13,0x10,0x10,0x10,0x11,0x10,
+0x80,0xf8,0x10,0x20,0xfc,0x44,0x44,0xfe,0x44,0x44,0xfc,0x44,0x40,0x40,0x40,0x80,
+/* 40904 0x9fc8 "鿈" */
+0x08,0x09,0x11,0x21,0x49,0x09,0x11,0x31,0x51,0x91,0x11,0x11,0x12,0x12,0x14,0x18,
+0x00,0xfc,0x04,0x04,0x04,0xfc,0x24,0x20,0x20,0x10,0x10,0x10,0x08,0x08,0x04,0x02,
+/* 40905 0x9fc9 "鿉" */
+0x08,0x0b,0x10,0x20,0x48,0x08,0x13,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x17,0x10,
+0x00,0xfe,0x40,0x40,0x40,0x40,0xf8,0x48,0x48,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 40906 0x9fca "鿊" */
+0x08,0x08,0xff,0x08,0x08,0x20,0x10,0x10,0x81,0x41,0x49,0x11,0x11,0x61,0x21,0x27,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0xfe,
+/* 40907 0x9fcb "鿋" */
+0x20,0x17,0x00,0xfb,0x08,0x1b,0x16,0x3b,0x55,0x9f,0x10,0x13,0x12,0x12,0x13,0x12,
+0x40,0xfe,0x40,0xfc,0x00,0xf8,0x08,0xf8,0x10,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,
+/* 40908 0x9fcc "鿌" */
+0x00,0x40,0x2f,0x20,0x80,0x43,0x4a,0x0b,0x12,0x13,0xe0,0x22,0x22,0x24,0x29,0x00,
+0x80,0x40,0xfe,0x00,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0x48,0x44,0x42,0x42,0x80,
+/* 40909 0x9fcd "鿍" */
+0x20,0x20,0x20,0x21,0x22,0xf8,0x21,0x26,0x20,0x21,0x3c,0xe2,0x43,0x00,0x00,0x00,
+0x80,0x80,0xfc,0x08,0x90,0x60,0x98,0x26,0x20,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,
+/* 40910 0x9fce "鿎" */
+0x00,0x00,0xfa,0x21,0x21,0x40,0x78,0x4f,0xc9,0x49,0x49,0x49,0x79,0x4a,0x44,0x00,
+0x10,0x10,0x10,0x10,0x7e,0x10,0x10,0x28,0x28,0x24,0x44,0x42,0x02,0x80,0x7e,0x00,
+/* 40911 0x9fcf "鿏" */
+0x10,0x10,0x3d,0x20,0x41,0xbc,0x10,0x13,0xfc,0x10,0x10,0x11,0x14,0x18,0x10,0x07,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0x20,0xfe,0x40,0x7c,0x84,0x48,0x50,0x20,0xd8,0x06,
+/* 40912 0x9fd0 "鿐" */
+0x20,0x24,0x72,0x90,0x24,0xfa,0xaa,0xa8,0xf9,0xaa,0xae,0xfa,0x02,0xaa,0xaa,0x00,
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+/* 40913 0x9fd1 "鿑" */
+0x00,0x47,0x20,0x20,0x00,0x08,0x08,0x13,0x10,0xe0,0x20,0x20,0x20,0x20,0x27,0x00,
+0x00,0xfe,0x40,0x40,0x40,0x40,0x40,0xfc,0x40,0x40,0x48,0x44,0x44,0x40,0xfe,0x00,
+/* 40914 0x9fd2 "鿒" */
+0x08,0x08,0xff,0x08,0x7f,0x02,0x1f,0x10,0x11,0x11,0x11,0x12,0x02,0x04,0x18,0x60,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x80,0x60,0x10,0x08,
+/* 40915 0x9fd3 "鿓" */
+0x08,0x08,0xff,0x08,0x7f,0x04,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x08,0x10,0x20,
+0x20,0x20,0xfe,0x20,0xfc,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x10,0x08,
+/* 40916 0x9fd4 "鿔" */
+0x20,0x23,0x3c,0x21,0x41,0x7d,0x90,0x13,0xfc,0x11,0x11,0x11,0x15,0x18,0x10,0x00,
+0x00,0xfe,0x08,0xe8,0x28,0xe8,0x00,0xfe,0x08,0xe8,0x28,0x28,0xe8,0x08,0x28,0x10,
+/* 40917 0x9fd5 "鿕" */
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x54,0x54,0x7f,0x54,0x54,0x7c,0x01,0x1d,0xe2,0x44,
+0x00,0xfc,0x84,0x84,0xa4,0x94,0x94,0x84,0xfe,0x84,0x84,0x84,0x04,0x04,0x14,0x08,
+/* 40918 0x9fd6 "鿖" */
+0x01,0x01,0x02,0x04,0x08,0x30,0xcf,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,0xff,
+0x00,0x00,0x80,0x40,0x20,0x18,0xe6,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x00,0xfe,
+/* 40919 0x9fd7 "鿗" */
+0x01,0x02,0x04,0x08,0x30,0xc8,0x0b,0x08,0x17,0x30,0x53,0x90,0x11,0x12,0x00,0xff,
+0x00,0x80,0x40,0x20,0x18,0x06,0xf0,0x90,0xfe,0x90,0xf0,0x80,0x00,0x00,0x00,0xfe,
+/* 40920 0x9fd8 "鿘" */
+0x10,0x1f,0x15,0x25,0x25,0x7f,0xa5,0x25,0x25,0x2f,0x25,0x24,0x24,0x28,0x28,0x30,
+0x10,0x10,0x28,0x28,0x44,0x44,0xba,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40921 0x9fd9 "鿙" */
+0x10,0x1f,0x15,0x25,0x25,0x7f,0xa5,0x25,0x25,0x2f,0x25,0x24,0x24,0x28,0x28,0x33,
+0x10,0x10,0xfe,0x10,0x7c,0xc4,0x44,0x44,0x7c,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40922 0x9fda "鿚" */
+0x20,0x3e,0x2a,0x4a,0x4a,0xff,0x4a,0x4a,0x4a,0x5f,0x4a,0x48,0x48,0x50,0x50,0x60,
+0x50,0x50,0x5c,0x54,0xf4,0x48,0x48,0x74,0xd4,0x62,0x5c,0x54,0x54,0x54,0x5c,0x54,
+/* 40923 0x9fdb "鿛" */
+0x04,0x84,0x5e,0x44,0x05,0x3e,0x4a,0x51,0x68,0xce,0x52,0x6a,0x44,0x4c,0x52,0x21,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40924 0x9fdc "鿜" */
+0x48,0x44,0x44,0x40,0xff,0x40,0x72,0x52,0x52,0xca,0x4a,0x4a,0x44,0x44,0x5f,0xc0,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40925 0x9fdd "鿝" */
+0x40,0x5f,0x55,0x55,0xf5,0x5f,0x48,0xc4,0xff,0xc8,0x4e,0x4a,0x4a,0x52,0x5a,0x64,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40926 0x9fde "鿞" */
+0x02,0xe2,0x42,0x4a,0x6b,0xaa,0xaa,0xaa,0xea,0xaa,0x2a,0x2a,0x42,0x42,0x4a,0x84,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40927 0x9fdf "鿟" */
+0x11,0x39,0xe1,0x25,0x25,0x25,0xfd,0x25,0x65,0x75,0x6d,0xa5,0xa1,0x21,0x25,0x22,
+0x20,0x20,0x20,0x3e,0x42,0x44,0x90,0x10,0x54,0x54,0x52,0x92,0x92,0x10,0x50,0x20,
+/* 40928 0x9fe0 "鿠" */
+0x12,0x32,0xe2,0x2a,0x2b,0x2a,0xfa,0x2a,0x6a,0x7a,0x6a,0xaa,0xa2,0x22,0x2a,0x24,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40929 0x9fe1 "鿡" */
+0x00,0xfe,0xaa,0xaa,0xff,0x24,0x2a,0x5f,0xda,0x2f,0x5a,0xff,0x0a,0xaa,0xaf,0x88,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40930 0x9fe2 "鿢" */
+0x00,0xff,0x55,0x55,0x75,0x56,0x56,0x75,0x55,0x55,0x55,0x7d,0xd6,0x14,0x14,0x14,
+0x10,0x10,0x28,0x28,0x44,0x44,0xba,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x44,
+/* 40931 0x9fe3 "鿣" */
+0x00,0xff,0x55,0x55,0x75,0x56,0x56,0x75,0x55,0x55,0x55,0x7d,0xd6,0x14,0x14,0x15,
+0x10,0x10,0xfe,0x10,0x7c,0x44,0x44,0x44,0x7c,0x28,0x28,0x28,0x48,0x4a,0x8a,0x06,
+/* 40932 0x9fe4 "鿤" */
+0x00,0xff,0x55,0x55,0x75,0x56,0x56,0x75,0x55,0x55,0x55,0x7d,0xd6,0x14,0x14,0x14,
+0x50,0x50,0x5c,0x54,0xf4,0x48,0x48,0x74,0xd4,0x62,0x5c,0x54,0x54,0x54,0x5c,0x54,
+/* 40933 0x9fe5 "鿥" */
+0x40,0x2e,0xea,0xaa,0xab,0xec,0xac,0xaa,0xea,0x9a,0xea,0xaa,0x9c,0xb8,0xd8,0x88,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40934 0x9fe6 "鿦" */
+0x51,0x51,0xfa,0x52,0x25,0xf9,0xaa,0xaa,0xae,0xfa,0x22,0x22,0x52,0x4a,0x4b,0x82,
+0x44,0x54,0x54,0x54,0xfe,0x1a,0x0a,0xfa,0x0a,0xea,0xaa,0xa4,0xb4,0xaa,0x0a,0x0a,
+/* 40935 0x9fe7 "鿧" */
+0x04,0xee,0xaa,0xba,0xa4,0xca,0xd1,0xae,0xa4,0xa4,0xbf,0xc4,0x8e,0x84,0x9f,0x80,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40936 0x9fe8 "鿨" */
+0x00,0x7e,0x10,0xfe,0x91,0x56,0x10,0xd6,0x00,0x7e,0x4a,0x4a,0x7e,0x4a,0x4a,0x7e,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40937 0x9fe9 "鿩" */
+0x20,0x3c,0x24,0x7e,0xd3,0x7e,0x52,0x7e,0x2a,0xd5,0x7e,0x42,0x7e,0x42,0x7e,0x42,
+0x00,0xfe,0x54,0x92,0xfe,0x92,0xd6,0xba,0xd6,0x92,0xd6,0xba,0xd6,0x92,0x9a,0x84,
+/* 40938 0x9fea "鿪" */
+0x21,0x10,0x17,0x00,0xf1,0x16,0x11,0x16,0x11,0x16,0x28,0x47,0x00,0x24,0x22,0x42,
+0x10,0xa0,0xfc,0x80,0x48,0xd0,0x68,0xa8,0x24,0xa4,0x40,0xfe,0x00,0x44,0x22,0x22,
+/* 40939 0x9feb "鿫" */
+0x20,0x3f,0x40,0x9f,0x00,0x7f,0x08,0x7f,0x55,0x4e,0x7f,0x4e,0x55,0xff,0x0a,0xf1,
+0x00,0xfc,0x00,0xf0,0x00,0xf0,0x10,0xd0,0x50,0x50,0xd0,0x52,0x4a,0xea,0x06,0xe2,
+/* 40940 0x9fec "鿬" */
+0x00,0x01,0xfd,0x11,0x11,0x21,0x3d,0x65,0x65,0xa5,0x25,0x25,0x3d,0x25,0x21,0x00,
+0x00,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x24,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,
+/* 40941 0x9fed "鿭" */
+0x10,0x10,0x3c,0x20,0x41,0xbd,0x12,0x10,0xfc,0x10,0x10,0x11,0x15,0x1a,0x10,0x00,
+0x80,0x80,0x80,0xfe,0x02,0x04,0x20,0x20,0xa8,0xa4,0xa4,0x22,0x22,0x22,0xa0,0x40,
+/* 40942 0x9fee "鿮" */
+0x00,0x3f,0x22,0x22,0x2f,0x22,0x23,0x20,0x2f,0x28,0x23,0x22,0x42,0x42,0x82,0x00,
+0x80,0xfe,0x48,0x48,0xfe,0x48,0xf8,0x00,0xfe,0x42,0xf8,0x48,0x48,0x68,0x50,0x40,
+/* 40943 0x9fef "鿯" */
+0x00,0x50,0x7e,0x50,0x95,0x38,0xd1,0x12,0x0c,0x31,0xc9,0x05,0x7f,0x03,0x0d,0x71,
+0x00,0x80,0xfe,0xaa,0x2a,0x4a,0x12,0x86,0x60,0x18,0x26,0x40,0xfc,0x80,0x60,0x1c,
+/* 40944 0x9ff0 "鿰" */
+0x02,0x42,0x22,0x2f,0x82,0x4f,0x48,0x0f,0x28,0x2f,0x42,0xdf,0x42,0x42,0x42,0x42,
+0x10,0x10,0x10,0xbe,0x10,0x90,0xbc,0x90,0x90,0xbe,0x12,0xd2,0x1a,0x14,0x10,0x10,
+/* 40945 0x9ff1 "鿱" */
+0x00,0x00,0xfd,0x11,0x11,0x11,0x11,0x7d,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x00,
+0x00,0x00,0xfc,0x24,0x24,0x24,0x24,0xfc,0x04,0x00,0x00,0x00,0x02,0x02,0xfe,0x00,
+/* 40946 0x9ff2 "鿲" */
+0x00,0xfd,0x00,0x00,0x7d,0x45,0x46,0x44,0x7d,0x00,0x44,0x28,0x2e,0xf0,0x41,0x02,
+0x48,0xfe,0x48,0x00,0xfe,0x02,0x24,0x20,0xfc,0x24,0x24,0x44,0x44,0x84,0x28,0x10,
+/* 40947 0x9ff3 "鿳" */
+0x20,0x21,0x73,0x92,0x23,0xfa,0xaa,0xaf,0xfa,0xaa,0xab,0xfa,0x02,0xaa,0xaa,0x04,
+0x90,0x08,0xc8,0x7e,0x62,0xd4,0x50,0xd0,0x52,0x54,0x58,0xd0,0x52,0x52,0x52,0xce,
+/* 40948 0x9ff4 "鿴" */
+0x20,0x20,0x7c,0x44,0x89,0x7e,0x54,0x54,0x7c,0x57,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x40,0x40,0x7c,0x84,0x88,0x50,0x20,0x50,0x88,0x06,0x60,0x10,0x08,0xc0,0x20,0x10,
+/* 40949 0x9ff5 "鿵" */
+0x20,0x20,0x7c,0x45,0x88,0x7c,0x54,0x55,0x7c,0x54,0x54,0x7c,0x02,0x1e,0xe2,0x44,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x20,0xfc,0x00,0x40,0x20,0xa4,0x82,0x8a,0x8a,0x78,
+/* 40950 0x9ff6 "鿶" */
+0x10,0x10,0x1e,0x22,0x24,0x7e,0xaa,0x2a,0x3e,0x2a,0x2a,0x3e,0x00,0x0e,0x70,0x20,
+0x20,0x10,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0xa2,0xa4,0x98,0x90,0x88,0xc4,0x82,
+/* 40951 0x9ff7 "鿷" */
+0x20,0x20,0x7c,0x44,0x88,0x7c,0x55,0x54,0x7c,0x54,0x54,0x7c,0x00,0x1c,0xe0,0x40,
+0x20,0x10,0xfc,0x00,0x84,0x48,0xfe,0x00,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 40952 0x9ff8 "鿸" */
+0x40,0x41,0x7b,0x8a,0x13,0xfa,0xaa,0xaf,0xfa,0xaa,0xab,0xfa,0x02,0x1a,0xe2,0x44,
+0x90,0x08,0xc8,0x7e,0x62,0xd4,0x50,0xd0,0x52,0x54,0x58,0xd0,0x52,0x52,0x52,0xce,
+/* 40953 0x9ff9 "鿹" */
+0x40,0x40,0x7b,0x8a,0x10,0xfa,0xaa,0xac,0xf8,0xab,0xa8,0xf9,0x01,0x1d,0xe1,0x40,
+0x40,0x20,0xfe,0x42,0x28,0x94,0xaa,0xca,0xf8,0x00,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 40954 0x9ffa "鿺" */
+0x10,0x10,0xfe,0x10,0x7c,0x10,0xfe,0x20,0x3c,0x44,0x48,0xa8,0x11,0x28,0x44,0x80,
+0x20,0x40,0xf8,0x88,0xc8,0xa8,0x88,0x98,0x80,0xfc,0x04,0x04,0xf4,0x04,0x14,0x08,
+/* 40955 0x9ffb "鿻" */
+0x20,0xce,0x82,0xee,0x82,0x82,0xfe,0x00,0x92,0x93,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x20,0x20,0x20,0xfe,0x20,0x50,0x50,0x7e,0xd2,0x52,0x52,0x52,0x5a,0x54,0x10,0x10,
+/* 40956 0x9ffc "鿼" */
+0x20,0xce,0x82,0xee,0x83,0x82,0xfe,0x00,0x92,0x92,0xda,0x92,0xda,0x92,0x93,0xd9,
+0x80,0x80,0x80,0x8e,0xea,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,0xae,0x2a,0x40,
+/* 40957 0x9ffd "鿽" */
+0x00,0x00,0x07,0xf5,0x92,0x91,0x91,0x92,0x94,0x90,0xf0,0x90,0x00,0x00,0x00,0x00,
+0x80,0x40,0xfe,0x0a,0x04,0x00,0xfc,0x80,0x80,0xf8,0x80,0x80,0xfc,0x80,0x80,0x80,
+/* 40958 0x9ffe "鿾" */
+0x02,0x21,0x27,0x24,0x24,0xf7,0x24,0x24,0x27,0x24,0x25,0x34,0xe5,0x46,0x04,0x00,
+0x00,0x1e,0xd2,0x52,0x54,0xd4,0x58,0x54,0xd2,0x12,0x12,0x9a,0x54,0x50,0x10,0x10,
+/* 40959 0x9fff "鿿" */
+0x01,0x7f,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x06,0x19,0xe9,0x05,0x19,0x61,0x03,
+0x10,0xfc,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xc0,0x30,0x2e,0xc0,0x30,0x08,0x00,
+/* 40960 0xa000 "ꀀ" */
+0x00,0x00,0x00,0x00,0x10,0x1f,0x10,0x10,0x10,0x10,0x7c,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 40961 0xa001 "ꀁ" */
+0x00,0x03,0x04,0x00,0x10,0x1f,0x10,0x7c,0x12,0x12,0x7c,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 40962 0xa002 "ꀂ" */
+0x00,0x00,0x00,0x00,0x10,0x1f,0x10,0x7c,0x12,0x12,0x7c,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 40963 0xa003 "ꀃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0x04,0x0a,0x0a,0x04,0x3b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 40964 0xa004 "ꀄ" */
+0x00,0x00,0x00,0x00,0x13,0x14,0x0c,0x07,0x04,0x04,0x0e,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x60,0xc0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 40965 0xa005 "ꀅ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x03,0x04,0x04,0x03,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 40966 0xa006 "ꀆ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x03,0x04,0x04,0x03,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 40967 0xa007 "ꀇ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x09,0x0a,0x0a,0x0a,0x0a,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xf0,0x90,0x80,0x80,0x80,0x80,0x90,0xf0,0x10,0x00,0x00,
+/* 40968 0xa008 "ꀈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x31,0x0d,0x03,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40969 0xa009 "ꀉ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x0d,0x03,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xa0,0x60,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 40970 0xa00a "ꀊ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x0d,0x03,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xa0,0x60,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 40971 0xa00b "ꀋ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x1a,0x06,0x02,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x00,0x30,0x40,0x40,0xc0,0x40,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40972 0xa00c "ꀌ" */
+0x00,0x03,0x04,0x00,0x10,0x11,0x11,0x11,0x10,0x1f,0x10,0x11,0x11,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 40973 0xa00d "ꀍ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x11,0x10,0x1f,0x10,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 40974 0xa00e "ꀎ" */
+0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x20,0x50,0x50,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 40975 0xa00f "ꀏ" */
+0x00,0x00,0x00,0x00,0x0f,0x11,0x11,0x0f,0x01,0x07,0x08,0x07,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 40976 0xa010 "ꀐ" */
+0x00,0x03,0x04,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x48,0x28,0x18,0x00,0x00,
+0x00,0x80,0x40,0x00,0x70,0x88,0x88,0x88,0xa8,0xa8,0xa8,0x88,0x88,0x70,0x00,0x00,
+/* 40977 0xa011 "ꀑ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x48,0x28,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0xa8,0xa8,0xa8,0x88,0x88,0x70,0x00,0x00,
+/* 40978 0xa012 "ꀒ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x48,0x28,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
+/* 40979 0xa013 "ꀓ" */
+0x00,0x03,0x04,0x00,0x00,0x38,0x04,0x08,0x1f,0x08,0x04,0x38,0x03,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x58,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 40980 0xa014 "ꀔ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x08,0x1f,0x08,0x04,0x38,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 40981 0xa015 "ꀕ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x00,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 40982 0xa016 "ꀖ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x05,0x04,0x04,0x05,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x50,0xe0,0xe0,0x50,0x40,0x40,0x80,0x00,0x00,
+/* 40983 0xa017 "ꀗ" */
+0x00,0x03,0x04,0x00,0x10,0x11,0x12,0x12,0x12,0x1f,0x12,0x12,0x11,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0xf0,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 40984 0xa018 "ꀘ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x12,0x12,0x12,0x1f,0x12,0x12,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 40985 0xa019 "ꀙ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x05,0x07,0x05,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 40986 0xa01a "ꀚ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x23,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x40,0x40,0xf8,0x40,0x40,0x20,0x18,0x00,0x00,
+/* 40987 0xa01b "ꀛ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x10,0x11,0x11,0x12,0x14,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 40988 0xa01c "ꀜ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x11,0x11,0x12,0x14,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x20,0x50,0x90,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 40989 0xa01d "ꀝ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x90,0x88,0x88,0x90,0xe0,0x90,0x88,0x88,0x10,0x00,0x00,
+/* 40990 0xa01e "ꀞ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x0f,0x08,0x08,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 40991 0xa01f "ꀟ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x0f,0x08,0x08,0x00,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0xe0,0x20,0x20,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 40992 0xa020 "ꀠ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x0f,0x08,0x08,0x00,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 40993 0xa021 "ꀡ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x0f,0x08,0x08,0x00,0x00,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0x00,0x00,0x40,0x20,0x10,0x00,0x00,
+/* 40994 0xa022 "ꀢ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x09,0x00,0x00,0x01,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0xd0,0x90,0x90,0xd0,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 40995 0xa023 "ꀣ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x00,0x00,0x01,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0xd0,0x90,0x90,0xd0,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 40996 0xa024 "ꀤ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 40997 0xa025 "ꀥ" */
+0x00,0x00,0x00,0x00,0x00,0x17,0x09,0x14,0x10,0x14,0x09,0x17,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 40998 0xa026 "ꀦ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x08,0x0b,0x09,0x09,0x0b,0x08,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x20,0xa0,0x20,0x20,0xa0,0x20,0x20,0xc0,0x00,0x00,
+/* 40999 0xa027 "ꀧ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x0b,0x09,0x09,0x0b,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xa0,0x20,0x20,0xa0,0x20,0x20,0xc0,0x00,0x00,
+/* 41000 0xa028 "ꀨ" */
+0x00,0x00,0x00,0x00,0x1f,0x01,0x01,0x1f,0x00,0x00,0x1f,0x01,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,
+/* 41001 0xa029 "ꀩ" */
+0x00,0x03,0x04,0x00,0x0e,0x11,0x11,0x01,0x01,0x00,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0x10,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41002 0xa02a "ꀪ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x01,0x01,0x00,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41003 0xa02b "ꀫ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x09,0x05,0x03,0x03,0x05,0x09,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x20,0x40,0x80,0x80,0x40,0x20,0x00,0xe0,0x00,0x00,
+/* 41004 0xa02c "ꀬ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41005 0xa02d "ꀭ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41006 0xa02e "ꀮ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41007 0xa02f "ꀯ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x05,0x05,0x05,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41008 0xa030 "ꀰ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x08,0x0b,0x08,0x0b,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x80,0x80,0xe0,0x80,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41009 0xa031 "ꀱ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0b,0x08,0x0b,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0xe0,0x80,0xe0,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41010 0xa032 "ꀲ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x1b,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x90,0x50,0x20,0x20,0x50,0x90,0x00,0x00,0x00,
+/* 41011 0xa033 "ꀳ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x60,0x80,0x60,0x10,0x60,0x80,0x60,0x00,0x00,
+/* 41012 0xa034 "ꀴ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x60,0x80,0x60,0x10,0x60,0x80,0x60,0x00,0x00,
+/* 41013 0xa035 "ꀵ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x1c,0x08,0x08,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41014 0xa036 "ꀶ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x1f,0x22,0x4a,0x42,0x4a,0x22,0x1f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x28,0x24,0xe0,0x20,0xa0,0x20,0xa0,0x20,0xe0,0x00,0x00,
+/* 41015 0xa037 "ꀷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x22,0x4a,0x42,0x4a,0x22,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0xe0,0x20,0xa0,0x20,0xa0,0x20,0xe0,0x00,0x00,
+/* 41016 0xa038 "ꀸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x3f,0x20,0x3f,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0xc0,0x40,0xc0,0x40,0xc0,0x40,0xc0,0x00,0x00,
+/* 41017 0xa039 "ꀹ" */
+0x00,0x03,0x04,0x00,0x01,0x02,0x12,0x12,0x12,0x17,0x1a,0x02,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41018 0xa03a "ꀺ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x12,0x12,0x12,0x17,0x1a,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41019 0xa03b "ꀻ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x0a,0x0a,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x50,0x00,0x00,0x00,0x00,
+/* 41020 0xa03c "ꀼ" */
+0x00,0x03,0x04,0x00,0x0e,0x11,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x50,0x00,0x00,0x00,0x00,
+/* 41021 0xa03d "ꀽ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x50,0x00,0x00,0x00,0x00,
+/* 41022 0xa03e "ꀾ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x08,0x07,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 41023 0xa03f "ꀿ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41024 0xa040 "ꁀ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41025 0xa041 "ꁁ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41026 0xa042 "ꁂ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x80,0x00,0x00,0x00,
+/* 41027 0xa043 "ꁃ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x0f,0x08,0x07,0x00,0x0a,0x0a,0x0a,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x80,0xa0,0xa0,0xa0,0x80,0x00,0x00,
+/* 41028 0xa044 "ꁄ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0f,0x08,0x07,0x00,0x0a,0x0a,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x80,0xa0,0xa0,0xa0,0x80,0x00,0x00,
+/* 41029 0xa045 "ꁅ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x0f,0x09,0x07,0x00,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41030 0xa046 "ꁆ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x1c,0x08,0x1c,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa0,0x90,0x90,0xa0,0xc0,0xa0,0x90,0x90,0x20,0x00,0x00,
+/* 41031 0xa047 "ꁇ" */
+0x00,0x03,0x04,0x00,0x09,0x09,0x09,0x05,0x03,0x00,0x0f,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x40,0x80,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41032 0xa048 "ꁈ" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x05,0x03,0x00,0x0f,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x40,0x80,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41033 0xa049 "ꁉ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0f,0x08,0x07,0x00,0x07,0x00,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x80,0xf0,0x80,0xf0,0x80,0x00,0x00,
+/* 41034 0xa04a "ꁊ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x60,0xa0,0x20,0x00,0x00,
+/* 41035 0xa04b "ꁋ" */
+0x00,0x03,0x04,0x00,0x0f,0x10,0x10,0x0f,0x10,0x10,0x0f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x20,0x20,0xe0,0x20,0x20,0xe0,0x20,0x20,0xe0,0x00,0x00,
+/* 41036 0xa04c "ꁌ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x08,0x08,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x00,
+/* 41037 0xa04d "ꁍ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x0a,0x0a,0x08,0x07,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41038 0xa04e "ꁎ" */
+0x00,0x03,0x04,0x00,0x0e,0x11,0x11,0x15,0x15,0x15,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x50,0x50,0xf0,0x50,0x50,0x00,0x00,0x00,0x00,0x00,
+/* 41039 0xa04f "ꁏ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x15,0x15,0x15,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0xf0,0x50,0x50,0x00,0x00,0x00,0x00,0x00,
+/* 41040 0xa050 "ꁐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41041 0xa051 "ꁑ" */
+0x00,0x03,0x04,0x00,0x00,0x30,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x30,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x18,0x28,0x48,0xa8,0x28,0xa8,0x48,0x28,0x18,0x00,0x00,
+/* 41042 0xa052 "ꁒ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0xa8,0x28,0xa8,0x48,0x28,0x18,0x00,0x00,
+/* 41043 0xa053 "ꁓ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x1c,0x08,0x08,0x08,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0xa0,0xa0,0xa0,0xa0,0x80,0x80,0x00,0x00,
+/* 41044 0xa054 "ꁔ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x08,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xa0,0x90,0x80,0x80,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41045 0xa055 "ꁕ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41046 0xa056 "ꁖ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x07,0x04,0x07,0x04,0x03,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0x40,0xc0,0x40,0x80,0x10,0x10,0xe0,0x00,0x00,
+/* 41047 0xa057 "ꁗ" */
+0x00,0x03,0x04,0x00,0x01,0x11,0x09,0x05,0x03,0x03,0x05,0x09,0x11,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 41048 0xa058 "ꁘ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x09,0x05,0x03,0x03,0x05,0x09,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 41049 0xa059 "ꁙ" */
+0x00,0x00,0x00,0x00,0x37,0x08,0x14,0x12,0x12,0x12,0x12,0x14,0x08,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd8,0x20,0x50,0x90,0x90,0x90,0x90,0x50,0x20,0xd8,0x00,0x00,
+/* 41050 0xa05a "ꁚ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x11,0x0e,0x00,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 41051 0xa05b "ꁛ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x0d,0x0b,0x09,0x09,0x09,0x68,0x18,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x78,0x80,0x18,0x20,0x78,0x20,0x18,0x80,0x78,0x00,0x00,
+/* 41052 0xa05c "ꁜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3c,0x40,0x8c,0x90,0xbc,0x90,0x8c,0x40,0x3c,0x00,0x00,0x00,
+/* 41053 0xa05d "ꁝ" */
+0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x02,0x02,0x0f,0x02,0x02,0x04,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x40,0x40,0xf0,0x40,0x40,0x20,0x18,0x00,0x00,
+/* 41054 0xa05e "ꁞ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x0f,0x04,0x02,0x03,0x02,0x04,0x0f,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0xf0,0x20,0x40,0xc0,0x40,0x20,0xf0,0x0c,0x00,0x00,
+/* 41055 0xa05f "ꁟ" */
+0x00,0x03,0x04,0x00,0x00,0x04,0x02,0x47,0x2a,0x12,0x2a,0x47,0x02,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x06,0x0a,0x12,0xa2,0x42,0xa2,0x12,0x0a,0x06,0x00,0x00,
+/* 41056 0xa060 "ꁠ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x47,0x2a,0x12,0x2a,0x47,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x0a,0x12,0xa2,0x42,0xa2,0x12,0x0a,0x06,0x00,0x00,
+/* 41057 0xa061 "ꁡ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0xe0,0x00,0x00,0xf0,0x00,0x00,
+/* 41058 0xa062 "ꁢ" */
+0x00,0x03,0x04,0x00,0x0c,0x0a,0x09,0x00,0x0f,0x00,0x0f,0x00,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0xa0,0xa0,0xa0,0x20,0xa0,0x20,0xa0,0x20,0xa0,0x60,0x00,0x00,
+/* 41059 0xa063 "ꁣ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x00,0x0f,0x00,0x0f,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xa0,0xa0,0xa0,0x20,0xa0,0x20,0xa0,0x20,0xa0,0x60,0x00,0x00,
+/* 41060 0xa064 "ꁤ" */
+0x00,0x00,0x00,0x00,0x03,0x14,0x14,0x14,0x04,0x04,0x14,0x14,0x14,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x50,0x50,0x50,0x40,0x40,0x50,0x50,0x50,0x80,0x00,0x00,
+/* 41061 0xa065 "ꁥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x90,0x90,0x90,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41062 0xa066 "ꁦ" */
+0x00,0x03,0x04,0x00,0x01,0x09,0x05,0x03,0x05,0x09,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41063 0xa067 "ꁧ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x05,0x03,0x05,0x09,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41064 0xa068 "ꁨ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x01,0x07,0x08,0x11,0x11,0x01,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x00,0xc0,0x20,0x10,0x10,0x00,0x20,0xc0,0x00,0x00,
+/* 41065 0xa069 "ꁩ" */
+0x00,0x03,0x04,0x00,0x06,0x05,0x34,0x2c,0x23,0x20,0x20,0x07,0x00,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0xd0,0x10,0x10,0xd0,0x30,0x80,0x00,0x80,0x00,0x00,
+/* 41066 0xa06a "ꁪ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x1a,0x16,0x11,0x10,0x10,0x03,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x68,0x08,0x88,0x68,0x18,0xc0,0x00,0xc0,0x00,0x00,
+/* 41067 0xa06b "ꁫ" */
+0x00,0x00,0x00,0x00,0x31,0x29,0x25,0x23,0x00,0x3f,0x00,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x44,0x48,0x50,0x60,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41068 0xa06c "ꁬ" */
+0x00,0x00,0x00,0x00,0x30,0x08,0x08,0x30,0x03,0x02,0x32,0x0a,0x0a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x4c,0x50,0x50,0x4c,0x40,0xc0,0x0c,0x10,0x10,0x0c,0x00,0x00,
+/* 41069 0xa06d "ꁭ" */
+0x00,0x03,0x04,0x00,0x00,0x01,0x01,0x0d,0x0b,0x09,0x09,0x29,0x19,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x90,0x50,0x30,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41070 0xa06e "ꁮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x14,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0xc8,0xa8,0x98,0x80,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41071 0xa06f "ꁯ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x00,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x88,0x80,0x90,0x90,0x90,0x80,0x80,0x00,0x00,0x00,
+/* 41072 0xa070 "ꁰ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x01,0x02,0x02,0x02,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0xa0,0x60,0xc0,0x20,0xa0,0xa0,0x00,0x00,
+/* 41073 0xa071 "ꁱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x01,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xa0,0x60,0xc0,0x20,0xa0,0xa0,0x00,0x00,
+/* 41074 0xa072 "ꁲ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x05,0x05,0x04,0x07,0x04,0x15,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0xd0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0xc0,0x00,0x00,
+/* 41075 0xa073 "ꁳ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x11,0x1d,0x13,0x00,0x00,
+0x00,0x80,0x40,0x00,0x90,0x70,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41076 0xa074 "ꁴ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x11,0x1d,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x70,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41077 0xa075 "ꁵ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x0d,0x03,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,
+/* 41078 0xa076 "ꁶ" */
+0x00,0x00,0x00,0x00,0x03,0x0a,0x0a,0x0a,0x02,0x02,0x0b,0x0a,0x0a,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0xa0,0xa0,0xe0,0xa0,0xa0,0x00,0x00,0x00,
+/* 41079 0xa077 "ꁷ" */
+0x00,0x03,0x04,0x00,0x07,0x09,0x0f,0x09,0x07,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0xe0,0x20,0xc0,0x00,0x40,0x50,0x10,0xe0,0x00,0x00,
+/* 41080 0xa078 "ꁸ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x0f,0x09,0x07,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xe0,0x20,0xc0,0x00,0x40,0x50,0x10,0xe0,0x00,0x00,
+/* 41081 0xa079 "ꁹ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x11,0x10,0x11,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc8,0x40,0x40,0xf0,0x40,0xf0,0x40,0x40,0x00,0x00,
+/* 41082 0xa07a "ꁺ" */
+0x00,0x07,0x08,0x00,0x1f,0x02,0x02,0x02,0x1f,0x02,0x02,0x1f,0x02,0x02,0x00,0x00,
+0x00,0x00,0x80,0x00,0xc0,0x20,0x10,0x00,0xc0,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 41083 0xa07b "ꁻ" */
+0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x02,0x1f,0x02,0x02,0x1f,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0xc0,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 41084 0xa07c "ꁼ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x0f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,
+/* 41085 0xa07d "ꁽ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x20,0x20,0x20,0x20,0x24,0x24,0x1b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x84,0xfc,0x84,0x94,0x94,0x80,0x00,0x00,0x00,
+/* 41086 0xa07e "ꁾ" */
+0x00,0x03,0x04,0x00,0x00,0x04,0x04,0x1f,0x02,0x01,0x02,0x1f,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x40,0x40,0xf0,0x80,0x00,0x80,0xf0,0x40,0x40,0x00,0x00,
+/* 41087 0xa07f "ꁿ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x1f,0x02,0x01,0x02,0x1f,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xf0,0x80,0x00,0x80,0xf0,0x40,0x40,0x00,0x00,
+/* 41088 0xa080 "ꂀ" */
+0x00,0x00,0x00,0x10,0x14,0x14,0x12,0x12,0x11,0x12,0x12,0x14,0x14,0x10,0x00,0x00,
+0x00,0x00,0x00,0x10,0x50,0x50,0x90,0x90,0x10,0x90,0x90,0x50,0x50,0x10,0x00,0x00,
+/* 41089 0xa081 "ꂁ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x0e,0x12,0x22,0x22,0x22,0x02,0x02,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x68,0x18,0x40,0x40,0x40,0x40,0x18,0x68,0x88,0x00,0x00,
+/* 41090 0xa082 "ꂂ" */
+0x03,0x04,0x00,0x11,0x11,0x0e,0x00,0x01,0x01,0x07,0x01,0x01,0x10,0x0f,0x00,0x00,
+0x80,0x40,0x00,0x10,0x10,0xe0,0x00,0x00,0x00,0xc0,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 41091 0xa083 "ꂃ" */
+0x00,0x00,0x00,0x11,0x11,0x0e,0x00,0x01,0x01,0x07,0x01,0x01,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x00,0x00,0xc0,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 41092 0xa084 "ꂄ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x01,0x01,0x11,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 41093 0xa085 "ꂅ" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x09,0x09,0x09,0x09,0x09,0x09,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x30,0x10,0x00,0xf0,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 41094 0xa086 "ꂆ" */
+0x00,0x03,0x04,0x00,0x09,0x0a,0x02,0x0e,0x12,0x12,0x0e,0x02,0x0a,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41095 0xa087 "ꂇ" */
+0x00,0x00,0x00,0x00,0x09,0x0a,0x02,0x0e,0x12,0x12,0x0e,0x02,0x0a,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41096 0xa088 "ꂈ" */
+0x00,0x00,0x00,0x00,0x01,0x07,0x09,0x11,0x11,0x11,0x11,0x09,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0x50,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 41097 0xa089 "ꂉ" */
+0x00,0x03,0x04,0x00,0x38,0x45,0x45,0x44,0x44,0x47,0x44,0x44,0x45,0x39,0x00,0x00,
+0x00,0x80,0x40,0x00,0x38,0x44,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0x38,0x00,0x00,
+/* 41098 0xa08a "ꂊ" */
+0x00,0x00,0x00,0x00,0x38,0x45,0x45,0x44,0x44,0x47,0x44,0x44,0x45,0x39,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0xc4,0x44,0x44,0x44,0x38,0x00,0x00,
+/* 41099 0xa08b "ꂋ" */
+0x00,0x00,0x00,0x07,0x08,0x09,0x0a,0x0a,0x0b,0x0a,0x0a,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x70,0x80,0xa0,0xa0,0x80,0xe0,0x80,0xa0,0xa0,0x80,0x70,0x00,0x00,
+/* 41100 0xa08c "ꂌ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x50,0x50,0x10,0x50,0x50,0x10,0x50,0x50,0x20,0xc0,0x00,0x00,
+/* 41101 0xa08d "ꂍ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x10,0x50,0x50,0x10,0x50,0x50,0x20,0xc0,0x00,0x00,
+/* 41102 0xa08e "ꂎ" */
+0x00,0x00,0x00,0x00,0x63,0x14,0x13,0x14,0x63,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41103 0xa08f "ꂏ" */
+0x00,0x03,0x04,0x00,0x31,0x29,0x25,0x23,0x3f,0x23,0x25,0x29,0x31,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x18,0x28,0x48,0x88,0xf8,0x88,0x48,0x28,0x18,0x00,0x00,0x00,
+/* 41104 0xa090 "ꂐ" */
+0x00,0x00,0x00,0x01,0x31,0x29,0x25,0x23,0x3f,0x23,0x25,0x29,0x31,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0xf8,0x88,0x48,0x28,0x18,0x00,0x00,0x00,
+/* 41105 0xa091 "ꂑ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x09,0x09,0x09,0x09,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 41106 0xa092 "ꂒ" */
+0x00,0x03,0x04,0x00,0x11,0x09,0x07,0x01,0x1f,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x20,0xc0,0x00,0xf0,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41107 0xa093 "ꂓ" */
+0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x01,0x1f,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0xf0,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41108 0xa094 "ꂔ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x12,0x12,0x12,0x13,0x14,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x90,0x90,0x90,0x50,0x20,0xc0,0x00,0x00,
+/* 41109 0xa095 "ꂕ" */
+0x00,0x03,0x04,0x00,0x15,0x15,0x11,0x09,0x07,0x01,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x50,0x50,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41110 0xa096 "ꂖ" */
+0x00,0x00,0x00,0x00,0x15,0x15,0x11,0x09,0x07,0x01,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41111 0xa097 "ꂗ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x09,0x09,0x09,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x50,0x30,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41112 0xa098 "ꂘ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x05,0x04,0x07,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x20,0x10,0x80,0x48,0x48,0x00,0x00,
+/* 41113 0xa099 "ꂙ" */
+0x00,0x03,0x04,0x00,0x00,0x30,0x2c,0x23,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x10,0xd0,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+/* 41114 0xa09a "ꂚ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x2c,0x23,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0xd0,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+/* 41115 0xa09b "ꂛ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x04,0x04,0x3f,0x04,0x04,0x08,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41116 0xa09c "ꂜ" */
+0x00,0x03,0x04,0x00,0x02,0x02,0x12,0x0a,0x04,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x48,0x50,0x60,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41117 0xa09d "ꂝ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x12,0x0a,0x04,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x48,0x50,0x60,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41118 0xa09e "ꂞ" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 41119 0xa09f "ꂟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x12,0x15,0x12,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0xc0,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41120 0xa0a0 "ꂠ" */
+0x00,0x03,0x04,0x00,0x01,0x11,0x11,0x01,0x0f,0x11,0x25,0x25,0x11,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x88,0x48,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 41121 0xa0a1 "ꂡ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x11,0x01,0x0f,0x11,0x25,0x25,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x88,0x48,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 41122 0xa0a2 "ꂢ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x01,0x00,0x01,0x02,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x80,0x40,0x20,0xa0,0x20,0xc0,0x00,0x00,
+/* 41123 0xa0a3 "ꂣ" */
+0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0xa0,0x20,0xa0,0x80,0x40,0x20,0xe0,0x00,0x00,
+/* 41124 0xa0a4 "ꂤ" */
+0x00,0x03,0x04,0x00,0x00,0x09,0x09,0x00,0x09,0x09,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41125 0xa0a5 "ꂥ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x00,0x09,0x09,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41126 0xa0a6 "ꂦ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x15,0x15,0x11,0x11,0x15,0x15,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x50,0x50,0x10,0x10,0x50,0x50,0x20,0xc0,0x00,0x00,
+/* 41127 0xa0a7 "ꂧ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x10,0x08,0x07,0x00,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41128 0xa0a8 "ꂨ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x10,0x08,0x07,0x00,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41129 0xa0a9 "ꂩ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x09,0x09,0x09,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41130 0xa0aa "ꂪ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x09,0x09,0x09,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41131 0xa0ab "ꂫ" */
+0x00,0x00,0x00,0x08,0x08,0x00,0x08,0x08,0x00,0x08,0x08,0x03,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x50,0x50,0x10,0x50,0x50,0x10,0x50,0x50,0x10,0xd0,0x30,0x00,0x00,
+/* 41132 0xa0ac "ꂬ" */
+0x00,0x03,0x04,0x00,0x07,0x09,0x0f,0x09,0x07,0x01,0x05,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0xe0,0x20,0xc0,0x00,0x40,0x50,0x10,0xe0,0x00,0x00,
+/* 41133 0xa0ad "ꂭ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x0f,0x09,0x07,0x01,0x05,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xe0,0x20,0xc0,0x00,0x40,0x50,0x10,0xe0,0x00,0x00,
+/* 41134 0xa0ae "ꂮ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x16,0x12,0x11,0x17,0x10,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xd0,0x90,0x10,0xd0,0x10,0x90,0x20,0xc0,0x00,0x00,
+/* 41135 0xa0af "ꂯ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x03,0x12,0x0a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0xd0,0x30,0x00,0x30,0xc0,0x00,0xc0,0x30,0x00,0x00,0x00,
+/* 41136 0xa0b0 "ꂰ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x03,0x12,0x0a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xd0,0x30,0x00,0x30,0xc0,0x00,0xc0,0x30,0x00,0x00,0x00,
+/* 41137 0xa0b1 "ꂱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x0f,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc8,0xa8,0x98,0x80,0xf8,0x80,0xf8,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41138 0xa0b2 "ꂲ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x14,0x22,0x21,0x21,0x22,0x14,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x50,0x88,0x28,0x28,0x88,0x50,0x20,0xc0,0x00,0x00,
+/* 41139 0xa0b3 "ꂳ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x14,0x22,0x21,0x21,0x22,0x14,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x50,0x88,0x28,0x28,0x88,0x50,0x20,0xc0,0x00,0x00,
+/* 41140 0xa0b4 "ꂴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0xc8,0xa8,0x98,0x80,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41141 0xa0b5 "ꂵ" */
+0x00,0x00,0x00,0x00,0x18,0x17,0x12,0x12,0x12,0x12,0x1f,0x12,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc8,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x00,0x00,
+/* 41142 0xa0b6 "ꂶ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x04,0x04,0x1f,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x40,0x40,0xf0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41143 0xa0b7 "ꂷ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x1f,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0xf0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41144 0xa0b8 "ꂸ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x01,0x07,0x01,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,
+/* 41145 0xa0b9 "ꂹ" */
+0x00,0x00,0x00,0x12,0x11,0x10,0x12,0x11,0x10,0x12,0x11,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x90,0x10,0x10,0x90,0x10,0x10,0x90,0x20,0xc0,0x00,0x00,
+/* 41146 0xa0ba "ꂺ" */
+0x00,0x03,0x04,0x00,0x00,0x06,0x05,0x04,0x04,0x14,0x0c,0x00,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x80,0xc0,0xb0,0x80,0xc0,0xb0,0x80,0x80,0x00,0x00,
+/* 41147 0xa0bb "ꂻ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x14,0x0c,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0xc0,0xb0,0x80,0xc0,0xb0,0x80,0x80,0x00,0x00,
+/* 41148 0xa0bc "ꂼ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x1f,0x04,0x1f,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0xc4,0x54,0x54,0x54,0x54,0x44,0x44,0x38,0x00,0x00,
+/* 41149 0xa0bd "ꂽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x12,0x12,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41150 0xa0be "ꂾ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0xc0,0x20,0xc0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41151 0xa0bf "ꂿ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0xc0,0x20,0xc0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41152 0xa0c0 "ꃀ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x00,0x00,0x00,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41153 0xa0c1 "ꃁ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x0f,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x18,0x24,0x24,0xe4,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 41154 0xa0c2 "ꃂ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x0f,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x24,0xe4,0x24,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 41155 0xa0c3 "ꃃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x0a,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x88,0x88,0x90,0xe0,0x90,0x88,0x88,0x90,0x80,0x00,0x00,
+/* 41156 0xa0c4 "ꃄ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x24,0x14,0x0c,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41157 0xa0c5 "ꃅ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x12,0x0a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41158 0xa0c6 "ꃆ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x03,0x00,0x01,0x02,0x01,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x50,0xe0,0x40,0xf0,0x48,0xf0,0x40,0x40,0x80,0x00,0x00,
+/* 41159 0xa0c7 "ꃇ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x80,0xf0,0x80,0x80,0x80,0xf0,0x80,0x80,0x80,0x00,0x00,
+/* 41160 0xa0c8 "ꃈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xf0,0x80,0x80,0x80,0xf0,0x80,0x80,0x80,0x00,0x00,
+/* 41161 0xa0c9 "ꃉ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x0f,0x08,0x09,0x08,0x0f,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0x00,0x70,0x80,0x40,0x80,0x70,0x00,0x00,0x00,
+/* 41162 0xa0ca "ꃊ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x10,0x08,0x07,0x00,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41163 0xa0cb "ꃋ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x08,0x07,0x00,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41164 0xa0cc "ꃌ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x0f,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x20,0x00,0x00,
+/* 41165 0xa0cd "ꃍ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x1e,0x08,0x1e,0x08,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0xf0,0x20,0xf0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41166 0xa0ce "ꃎ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x04,0x07,0x04,0x00,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41167 0xa0cf "ꃏ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x04,0x07,0x04,0x00,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41168 0xa0d0 "ꃐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0f,0x08,0x00,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41169 0xa0d1 "ꃑ" */
+0x00,0x00,0x00,0x09,0x0a,0x0a,0x09,0x08,0x0f,0x08,0x09,0x0a,0x6a,0x19,0x00,0x00,
+0x00,0x00,0x00,0x20,0xb0,0xac,0x20,0x20,0xe0,0x20,0x20,0xa0,0xa0,0x20,0x00,0x00,
+/* 41170 0xa0d2 "ꃒ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x10,0x01,0x09,0x09,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x08,0x88,0x68,0x18,0x40,0x48,0x48,0x10,0xe0,0x00,0x00,
+/* 41171 0xa0d3 "ꃓ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x01,0x09,0x09,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x40,0x48,0x48,0x10,0xe0,0x00,0x00,
+/* 41172 0xa0d4 "ꃔ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x02,0x0a,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x20,0xa8,0x88,0x10,0xe0,0x00,0x00,
+/* 41173 0xa0d5 "ꃕ" */
+0x00,0x03,0x04,0x00,0x01,0x00,0x18,0x05,0x02,0x02,0x05,0x18,0x00,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0xa0,0xe0,0x20,0x20,0x20,0x20,0xe0,0xa0,0x20,0x00,0x00,
+/* 41174 0xa0d6 "ꃖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x01,0x02,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x70,0x90,0x10,0x10,0x90,0x70,0x50,0x90,0x00,0x00,
+/* 41175 0xa0d7 "ꃗ" */
+0x00,0x00,0x00,0x00,0x09,0x05,0x07,0x09,0x11,0x11,0x09,0x07,0x05,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41176 0xa0d8 "ꃘ" */
+0x00,0x00,0x00,0x00,0x03,0x12,0x12,0x12,0x02,0x02,0x12,0x12,0x12,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 41177 0xa0d9 "ꃙ" */
+0x00,0x03,0x04,0x00,0x08,0x28,0x28,0x28,0x18,0x08,0x0f,0x08,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x28,0x28,0x28,0x30,0x20,0xe0,0x20,0x20,0x20,0x00,0x00,
+/* 41178 0xa0da "ꃚ" */
+0x00,0x00,0x00,0x00,0x08,0x28,0x28,0x28,0x18,0x08,0x0f,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x28,0x28,0x28,0x30,0x20,0xe0,0x20,0x20,0x20,0x00,0x00,
+/* 41179 0xa0db "ꃛ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x18,0x16,0x11,0x16,0x18,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x10,0x60,0x80,0x60,0x10,0x40,0x40,0x00,0x00,
+/* 41180 0xa0dc "ꃜ" */
+0x00,0x03,0x04,0x00,0x00,0x01,0x39,0x05,0x23,0x23,0x05,0x39,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41181 0xa0dd "ꃝ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x39,0x05,0x23,0x23,0x05,0x39,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41182 0xa0de "ꃞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0xa0,0xc0,0x90,0xa0,0xc0,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41183 0xa0df "ꃟ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x15,0x09,0x17,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41184 0xa0e0 "ꃠ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x15,0x09,0x17,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41185 0xa0e1 "ꃡ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x07,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 41186 0xa0e2 "ꃢ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x08,0x07,0x01,0x19,0x15,0x13,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41187 0xa0e3 "ꃣ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x80,0x40,0x00,0x18,0x20,0x40,0x40,0xc0,0x40,0x40,0x40,0x20,0x18,0x00,0x00,
+/* 41188 0xa0e4 "ꃤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x40,0xc0,0x40,0x40,0x40,0x20,0x18,0x00,0x00,
+/* 41189 0xa0e5 "ꃥ" */
+0x00,0x00,0x00,0x00,0x1c,0x13,0x11,0x01,0x01,0x09,0x09,0x09,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x70,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 41190 0xa0e6 "ꃦ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x01,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41191 0xa0e7 "ꃧ" */
+0x00,0x03,0x04,0x00,0x09,0x05,0x13,0x13,0x05,0x09,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x40,0x90,0x90,0x40,0x20,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41192 0xa0e8 "ꃨ" */
+0x00,0x00,0x00,0x00,0x09,0x05,0x13,0x13,0x05,0x09,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x90,0x90,0x40,0x20,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41193 0xa0e9 "ꃩ" */
+0x00,0x00,0x00,0x00,0x3f,0x01,0x01,0x09,0x09,0x09,0x09,0x01,0x01,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0xf8,0x00,0x00,
+/* 41194 0xa0ea "ꃪ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x1f,0x10,0x10,0x1f,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0xf0,0x10,0x10,0xf0,0x10,0x20,0xc0,0x00,0x00,
+/* 41195 0xa0eb "ꃫ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x13,0x14,0x08,0x14,0x13,0x10,0x10,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x90,0x50,0x20,0x50,0x90,0x10,0x10,0x10,0x00,0x00,
+/* 41196 0xa0ec "ꃬ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x13,0x14,0x08,0x14,0x13,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x90,0x50,0x20,0x50,0x90,0x10,0x10,0x10,0x00,0x00,
+/* 41197 0xa0ed "ꃭ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x32,0x0e,0x03,0x0e,0x32,0x1a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x38,0xc8,0x08,0xc8,0x38,0x00,0x00,0x00,0x00,
+/* 41198 0xa0ee "ꃮ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x1a,0x16,0x13,0x12,0x12,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x48,0x48,0xc8,0x68,0x58,0x40,0x40,0x80,0x00,0x00,
+/* 41199 0xa0ef "ꃯ" */
+0x00,0x03,0x04,0x00,0x00,0x0c,0x12,0x12,0x12,0x0c,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41200 0xa0f0 "ꃰ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x0c,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x88,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41201 0xa0f1 "ꃱ" */
+0x00,0x00,0x00,0x00,0x01,0x1f,0x21,0x21,0x11,0x0f,0x11,0x21,0x21,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x24,0xa4,0x74,0x2c,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41202 0xa0f2 "ꃲ" */
+0x00,0x03,0x04,0x00,0x01,0x00,0x0c,0x10,0x11,0x10,0x0c,0x00,0x00,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 41203 0xa0f3 "ꃳ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x0c,0x10,0x11,0x10,0x0c,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 41204 0xa0f4 "ꃴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x14,0x08,0x15,0x22,0x05,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x20,0xa0,0x20,0x20,0x20,0xa0,0x40,0x00,0x00,
+/* 41205 0xa0f5 "ꃵ" */
+0x03,0x04,0x00,0x1c,0x03,0x04,0x08,0x3e,0x08,0x3e,0x08,0x04,0x03,0x1c,0x00,0x00,
+0x80,0x40,0x00,0x70,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x70,0x00,0x00,
+/* 41206 0xa0f6 "ꃶ" */
+0x00,0x00,0x00,0x1c,0x03,0x04,0x08,0x3e,0x08,0x3e,0x08,0x04,0x03,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x70,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x70,0x00,0x00,
+/* 41207 0xa0f7 "ꃷ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x01,0x02,0x04,0x09,0x11,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0xe0,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x00,0x00,
+/* 41208 0xa0f8 "ꃸ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x01,0x02,0x1f,0x04,0x1f,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 41209 0xa0f9 "ꃹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x1f,0x04,0x1f,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 41210 0xa0fa "ꃺ" */
+0x00,0x00,0x00,0x01,0x01,0x21,0x21,0x11,0x4f,0x41,0x4f,0x11,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x28,0x08,0x10,0xe4,0x04,0xe4,0x10,0x08,0x08,0x00,0x00,
+/* 41211 0xa0fb "ꃻ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x08,0x07,0x00,0x08,0x08,0x09,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41212 0xa0fc "ꃼ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x07,0x00,0x08,0x08,0x09,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41213 0xa0fd "ꃽ" */
+0x00,0x00,0x00,0x00,0x01,0x21,0x21,0x11,0x0f,0x01,0x0f,0x11,0x25,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x48,0x08,0x10,0xe4,0x04,0xe4,0x10,0x08,0x08,0x00,0x00,
+/* 41214 0xa0fe "ꃾ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x09,0x07,0x11,0x11,0x01,0x1f,0x01,0x1f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x20,0xc0,0x10,0x10,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 41215 0xa0ff "ꃿ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x11,0x11,0x01,0x1f,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x10,0x10,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 41216 0xa100 "ꄀ" */
+0x00,0x00,0x00,0x00,0x00,0x32,0x2a,0x26,0x00,0x00,0x32,0x2a,0x26,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x84,0x84,0x88,0xf0,0x88,0x84,0x84,0x88,0x80,0x00,0x00,
+/* 41217 0xa101 "ꄁ" */
+0x00,0x03,0x04,0x00,0x00,0x04,0x02,0x12,0x0c,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41218 0xa102 "ꄂ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x12,0x0c,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41219 0xa103 "ꄃ" */
+0x00,0x00,0x01,0x02,0x01,0x00,0x11,0x11,0x0e,0x04,0x05,0x05,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x10,0x10,0xe0,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41220 0xa104 "ꄄ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x80,0x40,0x00,0x1c,0x20,0x4c,0x50,0xd0,0x50,0x50,0x4c,0x20,0x1c,0x00,0x00,
+/* 41221 0xa105 "ꄅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x34,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x20,0x4c,0x50,0xd0,0x50,0x50,0x4c,0x20,0x1c,0x00,0x00,
+/* 41222 0xa106 "ꄆ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x72,0x4e,0x41,0x42,0x42,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x42,0x42,0x82,0x72,0x4e,0x20,0x20,0x20,0x00,0x00,
+/* 41223 0xa107 "ꄇ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xf8,0x00,0x20,0x20,0x20,0x00,0x00,
+/* 41224 0xa108 "ꄈ" */
+0x00,0x00,0x03,0x04,0x00,0x10,0x08,0x04,0x12,0x11,0x12,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 41225 0xa109 "ꄉ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x12,0x11,0x12,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 41226 0xa10a "ꄊ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x1a,0x15,0x10,0x51,0x32,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x84,0x44,0x24,0x14,0x0c,0x00,0x00,
+/* 41227 0xa10b "ꄋ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x08,0x0e,0x09,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41228 0xa10c "ꄌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0e,0x09,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0xa0,0xa0,0xa0,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41229 0xa10d "ꄍ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x09,0x09,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41230 0xa10e "ꄎ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41231 0xa10f "ꄏ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41232 0xa110 "ꄐ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41233 0xa111 "ꄑ" */
+0x03,0x04,0x00,0x01,0x01,0x01,0x07,0x05,0x03,0x03,0x05,0x07,0x01,0x19,0x07,0x00,
+0x80,0x40,0x00,0xc0,0x30,0x00,0xc0,0x40,0x80,0x80,0x40,0xc0,0x00,0x00,0x00,0x00,
+/* 41234 0xa112 "ꄒ" */
+0x00,0x00,0x01,0x01,0x01,0x07,0x05,0x03,0x03,0x05,0x07,0x01,0x19,0x07,0x00,0x00,
+0x00,0x00,0xc0,0x30,0x00,0xc0,0x40,0x80,0x80,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41235 0xa113 "ꄓ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x03,0x04,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0xe0,0x90,0x88,0x88,0x00,0x00,
+/* 41236 0xa114 "ꄔ" */
+0x00,0x00,0x00,0x00,0x04,0x08,0x09,0x07,0x09,0x08,0x04,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x10,0x10,0x10,0x90,0x10,0x10,0x90,0x70,0x00,0x00,
+/* 41237 0xa115 "ꄕ" */
+0x00,0x03,0x04,0x00,0x1e,0x21,0x21,0x1e,0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0xc0,0x80,0xf0,0x80,0xf0,0x80,0x88,0x70,0x00,0x00,
+/* 41238 0xa116 "ꄖ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x1e,0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xc0,0x80,0xf0,0x80,0xf0,0x80,0x88,0x70,0x00,0x00,
+/* 41239 0xa117 "ꄗ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,
+/* 41240 0xa118 "ꄘ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x05,0x05,0x05,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41241 0xa119 "ꄙ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x05,0x05,0x05,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41242 0xa11a "ꄚ" */
+0x00,0x00,0x0f,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0xe0,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41243 0xa11b "ꄛ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x27,0x20,0x20,0x27,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x80,0xf0,0x80,0x80,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41244 0xa11c "ꄜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x13,0x10,0x10,0x13,0x00,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xf8,0x40,0x40,0xf8,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41245 0xa11d "ꄝ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x1f,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 41246 0xa11e "ꄞ" */
+0x00,0x03,0x04,0x00,0x08,0x04,0x24,0x18,0x00,0x07,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x80,0x80,0x80,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41247 0xa11f "ꄟ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x24,0x18,0x00,0x07,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41248 0xa120 "ꄠ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x07,0x00,0x07,0x08,0x08,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x90,0x10,0x90,0x50,0x50,0x10,0xd0,0x30,0x00,0x00,
+/* 41249 0xa121 "ꄡ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x03,0x04,0x04,0x04,0x04,0x03,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x90,0x10,0x10,0x10,0x10,0x90,0x10,0xe0,0x00,0x00,
+/* 41250 0xa122 "ꄢ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x00,0x1f,0x00,0x00,0x1f,0x00,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x00,0xe0,0x10,0x10,0xe0,0x00,0x40,0x40,0x00,0x00,
+/* 41251 0xa123 "ꄣ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x1f,0x00,0x00,0x1f,0x00,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x00,0xe0,0x10,0x10,0xe0,0x00,0x40,0x40,0x00,0x00,
+/* 41252 0xa124 "ꄤ" */
+0x00,0x00,0x00,0x0f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x0f,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x90,0x10,0x90,0x10,0x90,0x10,0x10,0xe0,0x00,0x00,
+/* 41253 0xa125 "ꄥ" */
+0x00,0x00,0x00,0x00,0x71,0x09,0x09,0x10,0x60,0x10,0x09,0x09,0x09,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x10,0x0c,0x10,0x20,0x20,0x20,0x1c,0x00,0x00,
+/* 41254 0xa126 "ꄦ" */
+0x03,0x04,0x00,0x00,0x0f,0x00,0x0f,0x00,0x0f,0x00,0x03,0x02,0x02,0x02,0x00,0x00,
+0x80,0x40,0x00,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41255 0xa127 "ꄧ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x0f,0x00,0x0f,0x00,0x03,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41256 0xa128 "ꄨ" */
+0x00,0x00,0x00,0x00,0x08,0x0a,0x0a,0x08,0x0a,0x0a,0x08,0x4a,0x2a,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0xc4,0xb4,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41257 0xa129 "ꄩ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x80,0x60,0x00,0x80,0x60,0x00,0x00,0x00,0x00,
+/* 41258 0xa12a "ꄪ" */
+0x00,0x03,0x04,0x00,0x01,0x11,0x11,0x11,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x80,0x60,0x18,0x80,0x60,0x18,0x00,0x00,0x00,
+/* 41259 0xa12b "ꄫ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x11,0x11,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x80,0x60,0x18,0x80,0x60,0x18,0x00,0x00,0x00,
+/* 41260 0xa12c "ꄬ" */
+0x00,0x00,0x00,0x00,0x3c,0x41,0x41,0x3c,0x41,0x41,0x3c,0x41,0x41,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x04,0x04,0x78,0x04,0x04,0x78,0x04,0x04,0x78,0x00,0x00,
+/* 41261 0xa12d "ꄭ" */
+0x00,0x03,0x04,0x00,0x12,0x0a,0x07,0x07,0x0a,0x12,0x0f,0x02,0x07,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x48,0x88,0x08,0x08,0x88,0x48,0x88,0x08,0x88,0x78,0x00,0x00,
+/* 41262 0xa12e "ꄮ" */
+0x00,0x00,0x00,0x00,0x12,0x0a,0x07,0x07,0x0a,0x12,0x0f,0x02,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x48,0x88,0x08,0x08,0x88,0x48,0x88,0x08,0x88,0x78,0x00,0x00,
+/* 41263 0xa12f "ꄯ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x03,0x02,0x02,0x02,0x0f,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0xc0,0x30,0x00,0x80,0x40,0x40,0x00,0x00,
+/* 41264 0xa130 "ꄰ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x20,0x20,0x00,0x80,0x70,0x00,0x00,0x00,
+/* 41265 0xa131 "ꄱ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41266 0xa132 "ꄲ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41267 0xa133 "ꄳ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x16,0x15,0x14,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0xf0,0x40,0x50,0x50,0xd0,0x00,0x00,0x00,
+/* 41268 0xa134 "ꄴ" */
+0x00,0x03,0x04,0x00,0x01,0x0d,0x0b,0x09,0x09,0x29,0x19,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x28,0x28,0xf8,0x28,0x28,0x00,0x00,0x00,0x00,
+/* 41269 0xa135 "ꄵ" */
+0x00,0x00,0x00,0x00,0x01,0x0d,0x0b,0x09,0x09,0x29,0x19,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x28,0x28,0xf8,0x28,0x28,0x00,0x00,0x00,0x00,
+/* 41270 0xa136 "ꄶ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x04,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 41271 0xa137 "ꄷ" */
+0x00,0x03,0x04,0x00,0x10,0x08,0x04,0x10,0x08,0x04,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41272 0xa138 "ꄸ" */
+0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x10,0x08,0x04,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41273 0xa139 "ꄹ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x0f,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0xe8,0x98,0x80,0xf8,0x80,0x80,0xf8,0x00,0x00,
+/* 41274 0xa13a "ꄺ" */
+0x00,0x03,0x04,0x00,0x21,0x21,0x3f,0x21,0x21,0x01,0x0f,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x08,0xf8,0x08,0x08,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41275 0xa13b "ꄻ" */
+0x00,0x00,0x00,0x00,0x21,0x21,0x3f,0x21,0x21,0x01,0x0f,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0xf8,0x08,0x08,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41276 0xa13c "ꄼ" */
+0x00,0x00,0x00,0x00,0x01,0x21,0x3f,0x21,0x01,0x07,0x09,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0xf8,0x08,0x00,0xc0,0x20,0x10,0x10,0x10,0x00,0x00,
+/* 41277 0xa13d "ꄽ" */
+0x00,0x00,0x00,0x00,0x1f,0x01,0x07,0x09,0x09,0x09,0x09,0x07,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0xf0,0x00,0x00,
+/* 41278 0xa13e "ꄾ" */
+0x03,0x04,0x00,0x1f,0x01,0x31,0x0d,0x03,0x0d,0x31,0x01,0x1f,0x01,0x1f,0x00,0x00,
+0x80,0x40,0x00,0xf0,0x00,0x1c,0x64,0x84,0x64,0x1c,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 41279 0xa13f "ꄿ" */
+0x00,0x00,0x00,0x1f,0x01,0x31,0x0d,0x03,0x0d,0x31,0x01,0x1f,0x01,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x1c,0x64,0x84,0x64,0x1c,0x00,0xf0,0x00,0xf0,0x00,0x00,
+/* 41280 0xa140 "ꅀ" */
+0x00,0x00,0x0f,0x01,0x0f,0x01,0x39,0x27,0x21,0x21,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x00,0xe0,0x00,0xe0,0x00,0x08,0x08,0xc8,0x38,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41281 0xa141 "ꅁ" */
+0x00,0x03,0x04,0x00,0x0f,0x01,0x03,0x05,0x09,0x09,0x09,0x09,0x05,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 41282 0xa142 "ꅂ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x03,0x05,0x09,0x09,0x09,0x09,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 41283 0xa143 "ꅃ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x0f,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x00,0x00,
+/* 41284 0xa144 "ꅄ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x09,0x07,0x00,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x20,0xc0,0x00,0x20,0x20,0x00,0x00,
+/* 41285 0xa145 "ꅅ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x1f,0x11,0x11,0x09,0x07,0x00,0x09,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0xf0,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x00,0x00,
+/* 41286 0xa146 "ꅆ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x1f,0x11,0x11,0x09,0x07,0x00,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0x10,0x20,0xc0,0x00,0x20,0x20,0x00,0x00,
+/* 41287 0xa147 "ꅇ" */
+0x00,0x00,0x00,0x03,0x02,0x02,0x0f,0x02,0x02,0x10,0x0f,0x00,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x10,0xd0,0x30,0x80,0x00,0x00,0x40,0x80,0x00,0x40,0x40,0x00,0x00,
+/* 41288 0xa148 "ꅈ" */
+0x00,0x03,0x04,0x00,0x0e,0x01,0x02,0x04,0x05,0x05,0x04,0x02,0x01,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0xe0,0x00,0x00,
+/* 41289 0xa149 "ꅉ" */
+0x00,0x00,0x00,0x00,0x0e,0x01,0x02,0x04,0x05,0x05,0x04,0x02,0x01,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0xe0,0x00,0x00,
+/* 41290 0xa14a "ꅊ" */
+0x00,0x00,0x00,0x00,0x08,0x0f,0x28,0x18,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0xd0,0x48,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41291 0xa14b "ꅋ" */
+0x00,0x00,0x00,0x1f,0x10,0x08,0x05,0x05,0x03,0x05,0x05,0x08,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x40,0x80,0x10,0x10,0xf0,0x10,0x10,0x80,0x40,0xc0,0x00,0x00,
+/* 41292 0xa14c "ꅌ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x09,0x07,0x01,0x11,0x11,0x11,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41293 0xa14d "ꅍ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x09,0x07,0x01,0x11,0x11,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41294 0xa14e "ꅎ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x08,0x07,0x08,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x88,0x88,0xf8,0x88,0x88,0x80,0x80,0x80,0x00,0x00,
+/* 41295 0xa14f "ꅏ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41296 0xa150 "ꅐ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41297 0xa151 "ꅑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x08,0x08,0x88,0x68,0x18,0x00,0x90,0x90,0x00,0x00,
+/* 41298 0xa152 "ꅒ" */
+0x00,0x03,0x04,0x00,0x00,0x08,0x0f,0x08,0x00,0x00,0x08,0x0e,0x09,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41299 0xa153 "ꅓ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x0f,0x08,0x00,0x00,0x08,0x0e,0x09,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41300 0xa154 "ꅔ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x09,0x09,0x08,0x08,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41301 0xa155 "ꅕ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x21,0x17,0x11,0x17,0x21,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x08,0xd0,0x10,0xd0,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 41302 0xa156 "ꅖ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x21,0x17,0x11,0x17,0x21,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x08,0xd0,0x10,0xd0,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 41303 0xa157 "ꅗ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x13,0x12,0x0c,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc8,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41304 0xa158 "ꅘ" */
+0x00,0x03,0x04,0x00,0x0c,0x12,0x12,0x0c,0x00,0x1f,0x00,0x07,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x50,0x48,0x40,0x40,0xf8,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41305 0xa159 "ꅙ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0c,0x00,0x1f,0x00,0x07,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x40,0x40,0xf8,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41306 0xa15a "ꅚ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x18,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0xa8,0xa8,0xa8,0xa8,0xf0,0xa0,0xa0,0xa0,0x80,0x00,0x00,
+/* 41307 0xa15b "ꅛ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x0f,0x08,0x07,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xf0,0x40,0xf0,0x40,0xf0,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41308 0xa15c "ꅜ" */
+0x03,0x04,0x00,0x04,0x09,0x12,0x12,0x12,0x11,0x08,0x03,0x02,0x02,0x02,0x00,0x00,
+0x80,0x40,0x00,0x00,0x90,0x50,0x50,0x50,0x90,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41309 0xa15d "ꅝ" */
+0x00,0x00,0x00,0x04,0x09,0x12,0x12,0x12,0x11,0x08,0x03,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x50,0x50,0x50,0x90,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41310 0xa15e "ꅞ" */
+0x00,0x00,0x04,0x08,0x10,0x14,0x14,0x11,0x11,0x08,0x03,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x50,0x50,0x10,0x10,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41311 0xa15f "ꅟ" */
+0x00,0x03,0x04,0x00,0x18,0x24,0x24,0x24,0x19,0x02,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x28,0x24,0x20,0xe0,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 41312 0xa160 "ꅠ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x19,0x02,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x20,0xe0,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 41313 0xa161 "ꅡ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x29,0x29,0x26,0x10,0x0f,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0xc0,0x00,0x00,
+/* 41314 0xa162 "ꅢ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x05,0x05,0x03,0x05,0x05,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x20,0x20,0xe0,0x20,0x20,0x80,0x80,0x00,0x00,
+/* 41315 0xa163 "ꅣ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 41316 0xa164 "ꅤ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 41317 0xa165 "ꅥ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 41318 0xa166 "ꅦ" */
+0x00,0x03,0x04,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41319 0xa167 "ꅧ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41320 0xa168 "ꅨ" */
+0x00,0x00,0x00,0x00,0x09,0x11,0x11,0x09,0x01,0x1f,0x01,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41321 0xa169 "ꅩ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x1f,0x01,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41322 0xa16a "ꅪ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x1f,0x01,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41323 0xa16b "ꅫ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x21,0x21,0x11,0x0f,0x01,0x0f,0x11,0x21,0x21,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x28,0x08,0x10,0xe0,0x00,0xe0,0x10,0x08,0x08,0x00,
+/* 41324 0xa16c "ꅬ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x0f,0x10,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0xf0,0x00,0xe0,0x10,0x08,0x08,0x00,0x00,
+/* 41325 0xa16d "ꅭ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x09,0x07,0x01,0x19,0x15,0x13,0x10,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x40,0x40,0x80,0x00,0x00,
+/* 41326 0xa16e "ꅮ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x01,0x19,0x15,0x13,0x10,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x40,0x40,0x80,0x00,0x00,
+/* 41327 0xa16f "ꅯ" */
+0x00,0x00,0x00,0x04,0x25,0x25,0x04,0x64,0x1c,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x60,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41328 0xa170 "ꅰ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x1f,0x02,0x1f,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0x30,0x00,0xc8,0x08,0xc8,0x00,0x00,0x00,0x00,
+/* 41329 0xa171 "ꅱ" */
+0x00,0x03,0x04,0x00,0x00,0x01,0x01,0x01,0x0d,0x0b,0x29,0x19,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x88,0x68,0x18,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,
+/* 41330 0xa172 "ꅲ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x0d,0x0b,0x29,0x19,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,
+/* 41331 0xa173 "ꅳ" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x04,0x03,0x04,0x08,0x01,0x01,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x40,0x20,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 41332 0xa174 "ꅴ" */
+0x00,0x03,0x04,0x00,0x03,0x05,0x05,0x35,0x2f,0x25,0x25,0x05,0x05,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x48,0x48,0xe8,0x58,0x40,0x40,0x80,0x00,0x00,
+/* 41333 0xa175 "ꅵ" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x05,0x35,0x2f,0x25,0x25,0x05,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x48,0x48,0xe8,0x58,0x40,0x40,0x80,0x00,0x00,
+/* 41334 0xa176 "ꅶ" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x55,0x22,0x08,0x14,0x14,0x09,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 41335 0xa177 "ꅷ" */
+0x00,0x03,0x04,0x00,0x00,0x22,0x22,0x08,0x08,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41336 0xa178 "ꅸ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x08,0x08,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41337 0xa179 "ꅹ" */
+0x03,0x04,0x00,0x01,0x05,0x03,0x00,0x0e,0x01,0x02,0x01,0x0e,0x00,0x01,0x05,0x03,
+0x80,0x40,0x00,0x80,0x40,0x00,0x00,0xe0,0x00,0x80,0x00,0xe0,0x00,0x80,0x40,0x00,
+/* 41338 0xa17a "ꅺ" */
+0x00,0x01,0x05,0x03,0x00,0x0e,0x01,0x02,0x01,0x0e,0x00,0x01,0x05,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0xe0,0x00,0x80,0x00,0xe0,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 41339 0xa17b "ꅻ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x12,0x11,0x08,0x0f,0x08,0x10,0x12,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc4,0xa8,0x88,0x10,0xf0,0x10,0xc8,0xa8,0x84,0x00,0x00,
+/* 41340 0xa17c "ꅼ" */
+0x00,0x00,0x00,0x03,0x04,0x33,0x40,0x33,0x04,0x03,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x60,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41341 0xa17d "ꅽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x24,0x08,0x08,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x40,0xc8,0x48,0x40,0x40,0x48,0xc8,0x00,0x00,
+/* 41342 0xa17e "ꅾ" */
+0x00,0x03,0x04,0x00,0x00,0x0a,0x0a,0x0a,0x00,0x0e,0x00,0x04,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x90,0x90,0x00,0x00,
+/* 41343 0xa17f "ꅿ" */
+0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x0a,0x00,0x0e,0x00,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x90,0x90,0x00,0x00,
+/* 41344 0xa180 "ꆀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x12,0x0c,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0xa0,0xc0,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41345 0xa181 "ꆁ" */
+0x00,0x03,0x04,0x00,0x00,0x01,0x01,0x07,0x05,0x15,0x0d,0x01,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0x10,0x10,0x90,0x50,0x30,0x10,0x10,0xe0,0x00,0x00,
+/* 41346 0xa182 "ꆂ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x05,0x15,0x0d,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x90,0x50,0x30,0x10,0x10,0xe0,0x00,0x00,
+/* 41347 0xa183 "ꆃ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x07,0x04,0x05,0x06,0x07,0x34,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x98,0x60,0xc0,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 41348 0xa184 "ꆄ" */
+0x03,0x04,0x00,0x06,0x05,0x14,0x0c,0x00,0x00,0x01,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x80,0x40,0x00,0x60,0x50,0xc8,0x60,0x50,0x40,0xf0,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41349 0xa185 "ꆅ" */
+0x00,0x00,0x00,0x06,0x05,0x14,0x0c,0x00,0x00,0x01,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x60,0x50,0xc8,0x60,0x50,0x40,0xf0,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41350 0xa186 "ꆆ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x17,0x11,0x17,0x01,0x0d,0x0b,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0xc0,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41351 0xa187 "ꆇ" */
+0x00,0x03,0x04,0x00,0x1d,0x03,0x01,0x01,0x03,0x1d,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41352 0xa188 "ꆈ" */
+0x00,0x00,0x00,0x00,0x1d,0x03,0x01,0x01,0x03,0x1d,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41353 0xa189 "ꆉ" */
+0x00,0x00,0x00,0x00,0x08,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x50,0x50,0x50,0x50,0x10,0x10,0xe0,0x00,0x00,
+/* 41354 0xa18a "ꆊ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x90,0x90,0xf0,0x90,0x90,0xf0,0x90,0x90,0x00,0x00,0x00,
+/* 41355 0xa18b "ꆋ" */
+0x03,0x04,0x00,0x3e,0x41,0x08,0x3e,0x08,0x41,0x3e,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x80,0x40,0x00,0x60,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41356 0xa18c "ꆌ" */
+0x00,0x00,0x00,0x3e,0x41,0x08,0x3e,0x08,0x41,0x3e,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x60,0x58,0x46,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41357 0xa18d "ꆍ" */
+0x00,0x00,0x00,0x00,0x24,0x18,0x00,0x24,0x18,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41358 0xa18e "ꆎ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x0d,0x03,0x01,0x0d,0x03,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41359 0xa18f "ꆏ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x0d,0x03,0x01,0x0d,0x03,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41360 0xa190 "ꆐ" */
+0x00,0x00,0x00,0x00,0x31,0x0d,0x03,0x31,0x0d,0x03,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41361 0xa191 "ꆑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x0a,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41362 0xa192 "ꆒ" */
+0x03,0x04,0x00,0x12,0x0c,0x00,0x12,0x0c,0x00,0x12,0x0c,0x00,0x1c,0x03,0x00,0x00,
+0x80,0x40,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41363 0xa193 "ꆓ" */
+0x00,0x00,0x00,0x12,0x0c,0x00,0x12,0x0c,0x00,0x12,0x0c,0x00,0x1c,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41364 0xa194 "ꆔ" */
+0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x0a,0x00,0x11,0x0e,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41365 0xa195 "ꆕ" */
+0x00,0x03,0x04,0x00,0x00,0x14,0x14,0x14,0x00,0x1c,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x80,0x80,0xe0,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41366 0xa196 "ꆖ" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x00,0x1c,0x00,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0xe0,0x90,0x90,0x90,0x80,0x80,0x00,0x00,
+/* 41367 0xa197 "ꆗ" */
+0x00,0x00,0x04,0x04,0x03,0x18,0x16,0x11,0x10,0x10,0x00,0x03,0x04,0x04,0x00,0x00,
+0x00,0x00,0x10,0x10,0xe0,0x88,0x88,0x88,0xe8,0x98,0x80,0xe0,0x90,0x90,0x00,0x00,
+/* 41368 0xa198 "ꆘ" */
+0x03,0x04,0x00,0x08,0x08,0x07,0x01,0x0f,0x11,0x11,0x0f,0x01,0x07,0x08,0x08,0x00,
+0x80,0x40,0x00,0x20,0x20,0xc0,0x10,0xf0,0x00,0x00,0xf0,0x00,0xc0,0x20,0x20,0x00,
+/* 41369 0xa199 "ꆙ" */
+0x00,0x00,0x08,0x08,0x07,0x01,0x0f,0x11,0x11,0x0f,0x01,0x07,0x08,0x08,0x00,0x00,
+0x00,0x00,0x20,0x20,0xc0,0x10,0xf0,0x00,0x00,0xf0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41370 0xa19a "ꆚ" */
+0x00,0x00,0x00,0x00,0x17,0x08,0x17,0x10,0x10,0x10,0x08,0x07,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x20,0xd0,0x10,0x10,0x10,0x20,0xc0,0x10,0xe0,0x00,0x00,
+/* 41371 0xa19b "ꆛ" */
+0x03,0x04,0x00,0x03,0x04,0x04,0x03,0x31,0x2d,0x23,0x21,0x21,0x03,0x05,0x05,0x00,
+0x80,0x40,0x00,0x80,0x40,0x40,0x80,0x10,0x10,0x10,0xd0,0x30,0x80,0x40,0x40,0x00,
+/* 41372 0xa19c "ꆜ" */
+0x00,0x00,0x01,0x02,0x02,0x01,0x18,0x16,0x11,0x10,0x10,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x20,0xc0,0x88,0x88,0x88,0xe8,0x98,0xc0,0xa0,0xa0,0x00,0x00,
+/* 41373 0xa19d "ꆝ" */
+0x00,0x00,0x00,0x00,0x08,0x07,0x00,0x03,0x02,0x02,0x02,0x07,0x0a,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0x10,0xd0,0x30,0x00,0x00,0x80,0x80,0x00,0x00,
+/* 41374 0xa19e "ꆞ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x0b,0x0a,0x0a,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x90,0xd0,0xb0,0x80,0x80,0x00,0x00,0x00,
+/* 41375 0xa19f "ꆟ" */
+0x00,0x03,0x04,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x90,0x90,0x80,0x90,0x90,0x80,0x90,0x90,0x80,0x00,0x00,
+/* 41376 0xa1a0 "ꆠ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x90,0x90,0x80,0x90,0x90,0x80,0x90,0x90,0x80,0x00,0x00,
+/* 41377 0xa1a1 "ꆡ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x00,0x00,0x00,0x00,0x1c,0x13,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xa8,0xa8,0xa8,0x70,0x20,0x20,0xc0,0x00,0x00,
+/* 41378 0xa1a2 "ꆢ" */
+0x03,0x04,0x00,0x0e,0x01,0x02,0x04,0x04,0x0f,0x04,0x05,0x05,0x02,0x01,0x0e,0x00,
+0x80,0x40,0x00,0xe0,0x00,0x80,0x40,0x40,0xe0,0x40,0x40,0x40,0x80,0x00,0xe0,0x00,
+/* 41379 0xa1a3 "ꆣ" */
+0x00,0x00,0x0e,0x01,0x02,0x04,0x04,0x0f,0x04,0x05,0x05,0x02,0x01,0x0e,0x00,0x00,
+0x00,0x00,0xe0,0x00,0x80,0x40,0x40,0xe0,0x40,0x40,0x40,0x80,0x00,0xe0,0x00,0x00,
+/* 41380 0xa1a4 "ꆤ" */
+0x00,0x00,0x00,0x00,0x27,0x28,0x10,0x18,0x17,0x10,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc8,0x28,0x10,0x30,0xd0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41381 0xa1a5 "ꆥ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x24,0x24,0xf8,0x20,0x24,0x24,0xf8,0x20,0x20,0x00,0x00,
+/* 41382 0xa1a6 "ꆦ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x24,0x24,0xf8,0x20,0x24,0x24,0xf8,0x20,0x20,0x00,0x00,
+/* 41383 0xa1a7 "ꆧ" */
+0x00,0x00,0x00,0x00,0x27,0x28,0x10,0x18,0x17,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc8,0x28,0x10,0x30,0xd0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41384 0xa1a8 "ꆨ" */
+0x03,0x04,0x00,0x07,0x08,0x10,0x1e,0x11,0x10,0x11,0x1e,0x10,0x08,0x07,0x00,0x00,
+0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0xd0,0x30,0xd0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41385 0xa1a9 "ꆩ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x1e,0x11,0x10,0x11,0x1e,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xd0,0x30,0xd0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41386 0xa1aa "ꆪ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x1f,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0xf0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41387 0xa1ab "ꆫ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x1f,0x01,0x1d,0x13,0x10,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41388 0xa1ac "ꆬ" */
+0x00,0x03,0x04,0x00,0x04,0x09,0x09,0x04,0x00,0x04,0x09,0x09,0x09,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0xf0,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 41389 0xa1ad "ꆭ" */
+0x00,0x00,0x00,0x00,0x04,0x09,0x09,0x04,0x00,0x04,0x09,0x09,0x09,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 41390 0xa1ae "ꆮ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x0f,0x01,0x09,0x08,0x01,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41391 0xa1af "ꆯ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x14,0x08,0x17,0x20,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x50,0x20,0xd0,0x08,0x00,
+/* 41392 0xa1b0 "ꆰ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x14,0x08,0x17,0x20,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x50,0x20,0xd0,0x08,0x00,
+/* 41393 0xa1b1 "ꆱ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x03,0x02,0x02,0x07,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xe0,0x40,0x40,0xc0,0x00,0x00,0x80,0x80,0x00,0x00,
+/* 41394 0xa1b2 "ꆲ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x09,0x07,0x01,0x39,0x27,0x21,0x21,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41395 0xa1b3 "ꆳ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x04,0x03,0x00,0x1c,0x13,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0x90,0xe0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41396 0xa1b4 "ꆴ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x06,0x05,0x04,0x04,0x04,0x04,0x14,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x30,0x28,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41397 0xa1b5 "ꆵ" */
+0x00,0x03,0x04,0x00,0x02,0x1a,0x16,0x53,0x32,0x02,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41398 0xa1b6 "ꆶ" */
+0x00,0x00,0x00,0x00,0x02,0x1a,0x16,0x53,0x32,0x02,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41399 0xa1b7 "ꆷ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x31,0x2d,0x23,0x21,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x70,0x00,0x48,0x48,0xc8,0x78,0x40,0x00,0x00,0x00,
+/* 41400 0xa1b8 "ꆸ" */
+0x00,0x03,0x04,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x00,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41401 0xa1b9 "ꆹ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x00,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41402 0xa1ba "ꆺ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x11,0x11,0x1f,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0xf0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41403 0xa1bb "ꆻ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x0a,0x08,0x08,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xa0,0xa0,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41404 0xa1bc "ꆼ" */
+0x00,0x03,0x04,0x00,0x00,0x04,0x04,0x04,0x00,0x04,0x0a,0x0a,0x06,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41405 0xa1bd "ꆽ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x00,0x04,0x0a,0x0a,0x06,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41406 0xa1be "ꆾ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x09,0x06,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41407 0xa1bf "ꆿ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x28,0x28,0x20,0x28,0xe8,0x20,0x28,0x28,0x20,0x00,0x00,
+/* 41408 0xa1c0 "ꇀ" */
+0x00,0x03,0x04,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x09,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41409 0xa1c1 "ꇁ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x09,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41410 0xa1c2 "ꇂ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x23,0x18,0x23,0x18,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xb0,0x8c,0xe0,0x80,0xe0,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41411 0xa1c3 "ꇃ" */
+0x00,0x05,0x05,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x50,0x50,0x10,0xd0,0x30,0x10,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 41412 0xa1c4 "ꇄ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x03,0x05,0x05,0x13,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x80,0x40,0x40,0x90,0x10,0x20,0xc0,0x00,0x00,
+/* 41413 0xa1c5 "ꇅ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x03,0x05,0x05,0x13,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x80,0x40,0x40,0x90,0x10,0x20,0xc0,0x00,0x00,
+/* 41414 0xa1c6 "ꇆ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x0f,0x14,0x24,0x24,0x0f,0x14,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xe0,0x50,0x48,0x48,0xe0,0x50,0x48,0x88,0x00,0x00,
+/* 41415 0xa1c7 "ꇇ" */
+0x00,0x00,0x00,0x00,0x14,0x15,0x11,0x08,0x07,0x01,0x0f,0x01,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x10,0x20,0xc0,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,
+/* 41416 0xa1c8 "ꇈ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x07,0x09,0x09,0x07,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41417 0xa1c9 "ꇉ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x07,0x09,0x09,0x07,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41418 0xa1ca "ꇊ" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x05,0x09,0x0f,0x09,0x0f,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0xe0,0x20,0xe0,0x20,0x20,0xc0,0x00,0x00,
+/* 41419 0xa1cb "ꇋ" */
+0x00,0x03,0x04,0x00,0x04,0x09,0x09,0x08,0x04,0x00,0x06,0x05,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 41420 0xa1cc "ꇌ" */
+0x00,0x00,0x00,0x00,0x04,0x09,0x09,0x08,0x04,0x00,0x06,0x05,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 41421 0xa1cd "ꇍ" */
+0x00,0x00,0x00,0x00,0x18,0x17,0x10,0x10,0x01,0x01,0x00,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0xe8,0x18,0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 41422 0xa1ce "ꇎ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x12,0x12,0x10,0x10,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x90,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41423 0xa1cf "ꇏ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x0e,0x04,0x04,0x05,0x05,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0xe0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41424 0xa1d0 "ꇐ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x04,0x04,0x05,0x05,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41425 0xa1d1 "ꇑ" */
+0x00,0x00,0x00,0x10,0x08,0x1c,0x22,0x49,0x48,0x49,0x22,0x1c,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
+/* 41426 0xa1d2 "ꇒ" */
+0x00,0x03,0x04,0x20,0x11,0x09,0x04,0x02,0x01,0x02,0x04,0x09,0x11,0x20,0x00,0x00,
+0x00,0x80,0x40,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 41427 0xa1d3 "ꇓ" */
+0x00,0x00,0x00,0x20,0x11,0x09,0x04,0x02,0x01,0x02,0x04,0x09,0x11,0x20,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,
+/* 41428 0xa1d4 "ꇔ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x07,0x00,0x0c,0x0b,0x08,0x6a,0x1a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x84,0x84,0x88,0xf0,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41429 0xa1d5 "ꇕ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0x80,0x00,0x10,0xe0,0x00,0x00,
+/* 41430 0xa1d6 "ꇖ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0x80,0x00,0x10,0xe0,0x00,0x00,
+/* 41431 0xa1d7 "ꇗ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x06,0x05,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41432 0xa1d8 "ꇘ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x04,0x03,0x00,0x00,
+0x00,0xc0,0x20,0x00,0xc0,0x20,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,
+/* 41433 0xa1d9 "ꇙ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,
+/* 41434 0xa1da "ꇚ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x00,0x00,0x00,0x00,0x38,0x26,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x48,0x48,0x48,0x78,0x48,0x48,0x48,0x80,0x00,0x00,
+/* 41435 0xa1db "ꇛ" */
+0x00,0x07,0x08,0x00,0x03,0x04,0x08,0x01,0x01,0x01,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0xc0,0x20,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41436 0xa1dc "ꇜ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x01,0x01,0x01,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41437 0xa1dd "ꇝ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x07,0x21,0x21,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0xc0,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 41438 0xa1de "ꇞ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x11,0x01,0x07,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0xc0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41439 0xa1df "ꇟ" */
+0x00,0x03,0x04,0x00,0x14,0x14,0x13,0x08,0x07,0x01,0x01,0x01,0x09,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x50,0x50,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41440 0xa1e0 "ꇠ" */
+0x00,0x00,0x00,0x00,0x14,0x14,0x13,0x08,0x07,0x01,0x01,0x01,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41441 0xa1e1 "ꇡ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x25,0x25,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x68,0x18,0x00,0xf0,0x00,0x48,0x48,0x10,0xe0,0x00,0x00,
+/* 41442 0xa1e2 "ꇢ" */
+0x00,0x00,0x00,0x00,0x14,0x13,0x08,0x07,0x00,0x00,0x07,0x08,0x13,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x90,0x20,0xc0,0x00,0x00,0xc0,0x20,0x90,0x50,0x00,0x00,
+/* 41443 0xa1e3 "ꇣ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x08,0x07,0x00,0x00,0x07,0x08,0x10,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41444 0xa1e4 "ꇤ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x07,0x00,0x00,0x07,0x08,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41445 0xa1e5 "ꇥ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x14,0x13,0x10,0x13,0x14,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0x90,0x10,0x90,0x50,0x10,0x20,0xc0,0x00,0x00,
+/* 41446 0xa1e6 "ꇦ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x11,0x0a,0x04,0x0a,0x11,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0xa0,0x2c,0x30,0x30,0x30,0x30,0xac,0x60,0x00,0x00,
+/* 41447 0xa1e7 "ꇧ" */
+0x00,0x03,0x04,0x00,0x00,0x40,0x20,0x11,0x0a,0x04,0x0a,0x11,0x20,0x40,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x6c,0xb0,0x30,0x2c,0x20,0x2c,0x30,0xb0,0x6c,0x00,0x00,
+/* 41448 0xa1e8 "ꇨ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x11,0x0a,0x04,0x0a,0x11,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x6c,0xb0,0x30,0x2c,0x20,0x2c,0x30,0xb0,0x6c,0x00,0x00,
+/* 41449 0xa1e9 "ꇩ" */
+0x00,0x00,0x00,0x07,0x08,0x12,0x12,0x10,0x1f,0x10,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x90,0x90,0x10,0xf0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41450 0xa1ea "ꇪ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x3b,0x11,0x15,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0xb8,0x10,0x50,0x50,0x10,0xe0,0x00,0x00,
+/* 41451 0xa1eb "ꇫ" */
+0x00,0x03,0x04,0x00,0x31,0x0d,0x01,0x31,0x0d,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41452 0xa1ec "ꇬ" */
+0x00,0x00,0x00,0x00,0x31,0x0d,0x01,0x31,0x0d,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41453 0xa1ed "ꇭ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x1f,0x00,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41454 0xa1ee "ꇮ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x10,0xf0,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 41455 0xa1ef "ꇯ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x09,0x09,0x09,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41456 0xa1f0 "ꇰ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x09,0x09,0x09,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41457 0xa1f1 "ꇱ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x09,0x09,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41458 0xa1f2 "ꇲ" */
+0x00,0x00,0x00,0x00,0x19,0x05,0x03,0x03,0x03,0x03,0x03,0x05,0x19,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x50,0x50,0x10,0xf0,0x10,0x50,0x50,0x10,0xe0,0x00,0x00,
+/* 41459 0xa1f3 "ꇳ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41460 0xa1f4 "ꇴ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41461 0xa1f5 "ꇵ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x14,0x17,0x14,0x14,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0xd0,0x50,0x50,0x90,0x20,0xc0,0x00,0x00,
+/* 41462 0xa1f6 "ꇶ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x14,0x08,0x17,0x20,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x50,0x20,0xd0,0x08,0x00,
+/* 41463 0xa1f7 "ꇷ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x14,0x08,0x17,0x20,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x50,0x20,0xd0,0x08,0x00,
+/* 41464 0xa1f8 "ꇸ" */
+0x00,0x00,0x00,0x00,0x04,0x05,0x04,0x05,0x04,0x05,0x04,0x04,0x05,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0xe0,0x00,0x60,0x80,0x00,0x00,0x00,
+/* 41465 0xa1f9 "ꇹ" */
+0x00,0x03,0x04,0x00,0x01,0x02,0x02,0x04,0x1f,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0x90,0x90,0x60,0x00,0x00,
+/* 41466 0xa1fa "ꇺ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x0f,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x10,0x10,0x90,0x90,0x60,0x00,0x00,
+/* 41467 0xa1fb "ꇻ" */
+0x00,0x00,0x00,0x1f,0x10,0x09,0x05,0x02,0x01,0x02,0x05,0x09,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0xf0,0x00,0x00,
+/* 41468 0xa1fc "ꇼ" */
+0x00,0x03,0x04,0x00,0x00,0x01,0x01,0x01,0x31,0x2d,0x23,0x21,0x21,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x88,0x68,0x18,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 41469 0xa1fd "ꇽ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x31,0x2d,0x23,0x21,0x21,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 41470 0xa1fe "ꇾ" */
+0x00,0x00,0x00,0x00,0x01,0x31,0x29,0x25,0x23,0x23,0x25,0x29,0x31,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x88,0x48,0x28,0x18,0x00,0x00,0x00,
+/* 41471 0xa1ff "ꇿ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x40,0x40,0x40,0x40,0x18,0x60,0x80,0x00,0x00,
+/* 41472 0xa200 "ꈀ" */
+0x00,0x00,0x03,0x04,0x00,0x10,0x08,0x04,0x02,0x1f,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x18,0x28,0x48,0x88,0xf8,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 41473 0xa201 "ꈁ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x1f,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0xf8,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 41474 0xa202 "ꈂ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x09,0x09,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x10,0xf0,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 41475 0xa203 "ꈃ" */
+0x00,0x03,0x04,0x00,0x00,0x11,0x11,0x11,0x04,0x04,0x04,0x00,0x03,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x58,0x40,0x40,0x40,0x70,0x48,0x48,0x48,0xc0,0x00,0x00,
+/* 41476 0xa204 "ꈄ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x04,0x04,0x04,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x40,0x40,0x40,0x70,0x48,0x48,0x48,0xc0,0x00,0x00,
+/* 41477 0xa205 "ꈅ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x05,0x03,0x01,0x0d,0x03,0x07,0x08,0x08,0x00,0x00,
+0x00,0x00,0x80,0x60,0x00,0x80,0x40,0x80,0x00,0x00,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41478 0xa206 "ꈆ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x1e,0x02,0x02,0x03,0x02,0x1e,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xd0,0x30,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41479 0xa207 "ꈇ" */
+0x03,0x04,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x06,0x01,0x00,0x00,
+0x80,0x40,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 41480 0xa208 "ꈈ" */
+0x00,0x00,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 41481 0xa209 "ꈉ" */
+0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x0f,0x12,0x12,0x12,0x0f,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41482 0xa20a "ꈊ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x13,0x11,0x11,0x0e,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x90,0x10,0x10,0xe0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41483 0xa20b "ꈋ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41484 0xa20c "ꈌ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41485 0xa20d "ꈍ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x08,0x07,0x00,0x11,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41486 0xa20e "ꈎ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x09,0x07,0x01,0x01,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41487 0xa20f "ꈏ" */
+0x00,0x03,0x04,0x00,0x00,0x1a,0x16,0x12,0x13,0x12,0x00,0x03,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x50,0x50,0x50,0x50,0xd0,0x10,0x10,0xd0,0x30,0x00,0x00,
+/* 41488 0xa210 "ꈐ" */
+0x00,0x00,0x00,0x02,0x1a,0x16,0x12,0x13,0x12,0x02,0x00,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x50,0x50,0x50,0x50,0xd0,0x10,0x10,0x10,0xd0,0x30,0x00,0x00,
+/* 41489 0xa211 "ꈑ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x90,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41490 0xa212 "ꈒ" */
+0x03,0x04,0x00,0x00,0x06,0x05,0x04,0x1f,0x04,0x14,0x0c,0x00,0x03,0x00,0x00,0x00,
+0x80,0x40,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41491 0xa213 "ꈓ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x0f,0x02,0x0a,0x06,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xa0,0x20,0xa0,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41492 0xa214 "ꈔ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x0c,0x10,0x11,0x11,0x0d,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x60,0x10,0x10,0x10,0x60,0x00,0x00,0x00,
+/* 41493 0xa215 "ꈕ" */
+0x00,0x03,0x04,0x00,0x00,0x08,0x05,0x05,0x05,0x08,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0xa0,0x20,0x20,0x20,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41494 0xa216 "ꈖ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x05,0x05,0x05,0x08,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x20,0x20,0x20,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41495 0xa217 "ꈗ" */
+0x00,0x03,0x04,0x00,0x0f,0x10,0x16,0x09,0x16,0x10,0x16,0x09,0x16,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0xd0,0x48,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41496 0xa218 "ꈘ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x16,0x09,0x16,0x10,0x16,0x09,0x16,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0xd0,0x48,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41497 0xa219 "ꈙ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x1c,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x38,0x20,0x20,0x00,0x00,
+/* 41498 0xa21a "ꈚ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x1a,0x16,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 41499 0xa21b "ꈛ" */
+0x03,0x04,0x00,0x07,0x08,0x08,0x07,0x00,0x08,0x07,0x00,0x07,0x00,0x07,0x00,0x00,
+0x80,0x40,0x00,0xe0,0x10,0x00,0xe0,0x10,0x10,0xe0,0x80,0xf0,0x80,0xf0,0x80,0x00,
+/* 41500 0xa21c "ꈜ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x08,0x07,0x00,0x07,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x00,0xe0,0x10,0x10,0xe0,0x80,0xf0,0x80,0xf0,0x80,0x00,
+/* 41501 0xa21d "ꈝ" */
+0x00,0x00,0x00,0x00,0x21,0x21,0x21,0x21,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x40,0x80,0x80,0x80,0x40,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 41502 0xa21e "ꈞ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x00,0x0c,0x03,0x00,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0xe0,0x10,0x10,0x00,0x00,
+/* 41503 0xa21f "ꈟ" */
+0x00,0x03,0x04,0x00,0x18,0x24,0x04,0x04,0x04,0x04,0x0f,0x14,0x24,0x23,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x48,0x40,0x40,0x40,0x40,0xe0,0x50,0x48,0x88,0x00,0x00,
+/* 41504 0xa220 "ꈠ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x04,0x04,0x0f,0x14,0x24,0x23,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x40,0x40,0x40,0xe0,0x50,0x48,0x88,0x00,0x00,
+/* 41505 0xa221 "ꈡ" */
+0x00,0x00,0x0f,0x10,0x11,0x11,0x10,0x0f,0x01,0x1f,0x01,0x1f,0x05,0x03,0x00,0x00,
+0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41506 0xa222 "ꈢ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x31,0x2d,0x23,0x21,0x21,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,
+/* 41507 0xa223 "ꈣ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41508 0xa224 "ꈤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41509 0xa225 "ꈥ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41510 0xa226 "ꈦ" */
+0x00,0x00,0x00,0x00,0x0a,0x0a,0x00,0x1f,0x00,0x0a,0x0a,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41511 0xa227 "ꈧ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x10,0x10,0x11,0x11,0x10,0x10,0x11,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41512 0xa228 "ꈨ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x10,0x10,0x11,0x11,0x10,0x10,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41513 0xa229 "ꈩ" */
+0x00,0x00,0x00,0x00,0x19,0x25,0x24,0x27,0x24,0x25,0x25,0x18,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41514 0xa22a "ꈪ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x15,0x15,0x15,0x0f,0x05,0x09,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41515 0xa22b "ꈫ" */
+0x03,0x04,0x00,0x18,0x06,0x01,0x06,0x18,0x00,0x18,0x06,0x01,0x06,0x18,0x00,0x00,
+0x80,0x40,0x00,0x30,0xd0,0x10,0xd0,0x30,0x00,0x30,0xd0,0x10,0xd0,0x30,0x00,0x00,
+/* 41516 0xa22c "ꈬ" */
+0x00,0x00,0x00,0x18,0x06,0x01,0x06,0x18,0x00,0x18,0x06,0x01,0x06,0x18,0x00,0x00,
+0x00,0x00,0x00,0x30,0xd0,0x10,0xd0,0x30,0x00,0x30,0xd0,0x10,0xd0,0x30,0x00,0x00,
+/* 41517 0xa22d "ꈭ" */
+0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x06,0x18,0x01,0x01,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xd0,0x10,0xd0,0x30,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41518 0xa22e "ꈮ" */
+0x03,0x04,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x80,0x40,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 41519 0xa22f "ꈯ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 41520 0xa230 "ꈰ" */
+0x00,0x03,0x04,0x00,0x06,0x3d,0x44,0x44,0x24,0x1c,0x24,0x44,0x44,0x3c,0x00,0x00,
+0x00,0x80,0x40,0x00,0x18,0x94,0x72,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41521 0xa231 "ꈱ" */
+0x00,0x00,0x00,0x00,0x06,0x3d,0x44,0x44,0x24,0x1c,0x24,0x44,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x94,0x72,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41522 0xa232 "ꈲ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x07,0x04,0x05,0x06,0x0c,0x14,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 41523 0xa233 "ꈳ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x10,0x10,0x10,0x1f,0x12,0x12,0x12,0x12,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x58,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41524 0xa234 "ꈴ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x10,0x10,0x10,0x1f,0x12,0x12,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41525 0xa235 "ꈵ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x10,0x20,0x20,0xe0,0x20,0x20,0x10,0x0c,0x00,0x00,0x00,
+/* 41526 0xa236 "ꈶ" */
+0x03,0x04,0x01,0x0f,0x11,0x11,0x0f,0x21,0x21,0x0f,0x11,0x11,0x0f,0x01,0x00,0x00,
+0x80,0x40,0x00,0xe0,0x10,0x10,0xe0,0x08,0x08,0xe0,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 41527 0xa237 "ꈷ" */
+0x00,0x00,0x01,0x0f,0x11,0x11,0x0f,0x21,0x21,0x0f,0x11,0x11,0x0f,0x01,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x08,0x08,0xe0,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 41528 0xa238 "ꈸ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41529 0xa239 "ꈹ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x0f,0x09,0x07,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xe0,0x20,0xc0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41530 0xa23a "ꈺ" */
+0x03,0x04,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x03,0x02,0x0f,0x12,0x12,0x00,0x00,
+0x80,0x40,0x00,0xe0,0x10,0x10,0x10,0xe0,0x80,0x80,0x00,0x80,0x40,0x40,0x00,0x00,
+/* 41531 0xa23b "ꈻ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x03,0x02,0x0f,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x80,0x80,0x00,0x80,0x40,0x40,0x00,0x00,
+/* 41532 0xa23c "ꈼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x1e,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x80,0x80,0x40,0x38,0x40,0x80,0x80,0x80,0x78,0x00,0x00,
+/* 41533 0xa23d "ꈽ" */
+0x03,0x04,0x00,0x00,0x00,0x00,0x07,0x08,0x12,0x12,0x12,0x08,0x07,0x00,0x00,0x00,
+0x80,0x40,0x00,0x70,0x80,0x90,0x90,0x80,0x70,0x00,0x70,0x80,0x90,0x90,0x80,0x70,
+/* 41534 0xa23e "ꈾ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x12,0x12,0x12,0x08,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x70,0x80,0x90,0x90,0x80,0x70,0x00,0x70,0x80,0x90,0x90,0x80,0x70,0x00,0x00,
+/* 41535 0xa23f "ꈿ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb8,0x40,0xa0,0xa0,0xb8,0xa0,0xa0,0xa0,0x40,0xb8,0x00,0x00,
+/* 41536 0xa240 "ꉀ" */
+0x00,0x00,0x00,0x00,0x08,0x2a,0x1a,0x19,0x18,0x1a,0x1a,0x29,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa8,0xb0,0x30,0x30,0xb0,0xb0,0x28,0x20,0xc0,0x00,0x00,
+/* 41537 0xa241 "ꉁ" */
+0x00,0x00,0x03,0x04,0x00,0x06,0x01,0x02,0x02,0x0f,0x02,0x02,0x01,0x06,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0xe0,0x00,0xc0,0x00,0xe0,0x00,0xc0,0x00,0xe0,0x00,0x00,
+/* 41538 0xa242 "ꉂ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x02,0x02,0x0f,0x02,0x02,0x01,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xc0,0x00,0xe0,0x00,0xc0,0x00,0xe0,0x00,0x00,
+/* 41539 0xa243 "ꉃ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x03,0x00,0x07,0x00,0x07,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xe0,0x80,0xf0,0x80,0xf0,0x80,0x80,0x00,0x00,0x00,
+/* 41540 0xa244 "ꉄ" */
+0x00,0x03,0x04,0x00,0x14,0x14,0x14,0x15,0x16,0x14,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x90,0x90,0x90,0x90,0x90,0xa0,0xc0,0x00,0x00,
+/* 41541 0xa245 "ꉅ" */
+0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x15,0x16,0x14,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x90,0x90,0x90,0x90,0x90,0xa0,0xc0,0x00,0x00,
+/* 41542 0xa246 "ꉆ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x09,0x08,0x00,0x00,0x0e,0x09,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x90,0x70,0x00,0x00,0x10,0x90,0x70,0x00,0x00,0x00,
+/* 41543 0xa247 "ꉇ" */
+0x03,0x04,0x00,0x01,0x31,0x29,0x24,0x22,0x21,0x22,0x24,0x29,0x31,0x01,0x00,0x00,
+0x80,0x40,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,0x00,
+/* 41544 0xa248 "ꉈ" */
+0x00,0x00,0x00,0x01,0x31,0x29,0x24,0x22,0x21,0x22,0x24,0x29,0x31,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,0x00,
+/* 41545 0xa249 "ꉉ" */
+0x00,0x00,0x00,0x1f,0x00,0x07,0x08,0x08,0x08,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x40,0xc0,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41546 0xa24a "ꉊ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x09,0x00,0x0f,0x00,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41547 0xa24b "ꉋ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x40,0x90,0x90,0xf0,0x80,0x80,0x40,0x30,0x00,0x00,0x00,
+/* 41548 0xa24c "ꉌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x40,0x90,0x90,0xf0,0x80,0x80,0x40,0x30,0x00,0x00,0x00,
+/* 41549 0xa24d "ꉍ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa0,0xa0,0x80,0xf0,0x80,0xa0,0xa0,0x80,0x00,0x00,0x00,
+/* 41550 0xa24e "ꉎ" */
+0x00,0x00,0x00,0x00,0x10,0x20,0x24,0x22,0x11,0x00,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0xe0,0x80,0x80,0x00,0x00,0x00,
+/* 41551 0xa24f "ꉏ" */
+0x00,0x03,0x04,0x00,0x10,0x20,0x24,0x22,0x11,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41552 0xa250 "ꉐ" */
+0x00,0x00,0x00,0x00,0x10,0x20,0x24,0x22,0x11,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41553 0xa251 "ꉑ" */
+0x00,0x00,0x00,0x00,0x12,0x22,0x24,0x22,0x11,0x02,0x02,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41554 0xa252 "ꉒ" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x1c,0x00,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0x70,0x00,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 41555 0xa253 "ꉓ" */
+0x00,0x03,0x04,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 41556 0xa254 "ꉔ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 41557 0xa255 "ꉕ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41558 0xa256 "ꉖ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x07,0x08,0x07,0x00,0x0f,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xa0,0x20,0x20,0xa0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41559 0xa257 "ꉗ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x09,0x05,0x03,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41560 0xa258 "ꉘ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x09,0x05,0x03,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41561 0xa259 "ꉙ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 41562 0xa25a "ꉚ" */
+0x03,0x04,0x00,0x09,0x09,0x07,0x0f,0x11,0x11,0x11,0x0f,0x07,0x09,0x09,0x00,0x00,
+0x80,0x40,0x00,0x20,0x20,0xc0,0xe0,0x10,0x10,0x10,0xe0,0xc0,0x20,0x20,0x00,0x00,
+/* 41563 0xa25b "ꉛ" */
+0x00,0x00,0x00,0x09,0x09,0x07,0x0f,0x11,0x11,0x11,0x0f,0x07,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xc0,0xe0,0x10,0x10,0x10,0xe0,0xc0,0x20,0x20,0x00,0x00,
+/* 41564 0xa25c "ꉜ" */
+0x00,0x00,0x00,0x00,0x01,0x31,0x2d,0x23,0x21,0x01,0x31,0x2d,0x23,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41565 0xa25d "ꉝ" */
+0x00,0x03,0x04,0x00,0x01,0x05,0x05,0x05,0x01,0x09,0x05,0x13,0x11,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x40,0x40,0x40,0x10,0x10,0xe0,0x00,0x00,
+/* 41566 0xa25e "ꉞ" */
+0x00,0x00,0x00,0x00,0x01,0x05,0x05,0x05,0x01,0x09,0x05,0x13,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x40,0x40,0x40,0x10,0x10,0xe0,0x00,0x00,
+/* 41567 0xa25f "ꉟ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x11,0x11,0x7d,0x11,0x11,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x08,0x08,0x3e,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 41568 0xa260 "ꉠ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x38,0x26,0x21,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x28,0x28,0xa8,0x70,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 41569 0xa261 "ꉡ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x06,0x05,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x88,0x88,0x88,0xe8,0x98,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41570 0xa262 "ꉢ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x06,0x05,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0xe8,0x98,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41571 0xa263 "ꉣ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x3e,0x08,0x08,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xe0,0x90,0x88,0x88,0x88,0x90,0xe0,0x80,0x80,0x00,0x00,
+/* 41572 0xa264 "ꉤ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x24,0x22,0x01,0x01,0x22,0x24,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x48,0x88,0x00,0x00,0x88,0x48,0x10,0xe0,0x00,0x00,
+/* 41573 0xa265 "ꉥ" */
+0x03,0x04,0x00,0x03,0x04,0x05,0x05,0x04,0x07,0x04,0x02,0x01,0x02,0x04,0x00,0x00,
+0x80,0x40,0x00,0x80,0x40,0x40,0x40,0x40,0xc0,0x40,0x80,0x00,0x80,0x40,0x00,0x00,
+/* 41574 0xa266 "ꉦ" */
+0x00,0x00,0x00,0x03,0x04,0x05,0x05,0x04,0x07,0x04,0x02,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0xc0,0x40,0x80,0x00,0x80,0x40,0x00,0x00,
+/* 41575 0xa267 "ꉧ" */
+0x00,0x00,0x00,0x00,0x1c,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x70,0x00,0x00,
+/* 41576 0xa268 "ꉨ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x04,0x07,0x08,0x09,0x09,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x40,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41577 0xa269 "ꉩ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x07,0x08,0x09,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41578 0xa26a "ꉪ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x12,0x0c,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x90,0xa0,0xc0,0xe0,0x90,0x90,0x90,0xe0,0x80,0x00,0x00,
+/* 41579 0xa26b "ꉫ" */
+0x00,0x03,0x04,0x00,0x00,0x02,0x02,0x0f,0x02,0x02,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41580 0xa26c "ꉬ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x0f,0x02,0x02,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xa0,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41581 0xa26d "ꉭ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0xd0,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 41582 0xa26e "ꉮ" */
+0x00,0x00,0x00,0x00,0x09,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41583 0xa26f "ꉯ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41584 0xa270 "ꉰ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41585 0xa271 "ꉱ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x0f,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0xd0,0x70,0x40,0x40,0x00,0x80,0x40,0x40,0x00,0x00,
+/* 41586 0xa272 "ꉲ" */
+0x00,0x03,0x04,0x00,0x01,0x02,0x03,0x02,0x31,0x2c,0x23,0x02,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xa0,0xe0,0xa0,0xc0,0x80,0xc0,0x20,0x90,0x90,0x00,0x00,
+/* 41587 0xa273 "ꉳ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x18,0x16,0x11,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x50,0xf0,0x50,0xe0,0x40,0xe0,0x10,0x48,0x48,0x00,0x00,
+/* 41588 0xa274 "ꉴ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x18,0x16,0x11,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x40,0xe0,0x10,0x48,0x48,0x00,0x00,
+/* 41589 0xa275 "ꉵ" */
+0x00,0x00,0x00,0x00,0x09,0x15,0x15,0x09,0x01,0x1f,0x01,0x1f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,0x00,
+/* 41590 0xa276 "ꉶ" */
+0x00,0x03,0x04,0x00,0x01,0x19,0x05,0x13,0x2b,0x2b,0x13,0x05,0x19,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41591 0xa277 "ꉷ" */
+0x00,0x00,0x00,0x00,0x01,0x19,0x05,0x13,0x2b,0x2b,0x13,0x05,0x19,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41592 0xa278 "ꉸ" */
+0x00,0x00,0x00,0x00,0x01,0x1f,0x09,0x15,0x09,0x1f,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41593 0xa279 "ꉹ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x08,0x07,0x08,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0x40,0x80,0x80,0x80,0x40,0x38,0x00,0x00,0x00,0x00,
+/* 41594 0xa27a "ꉺ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x13,0x14,0x14,0x14,0x14,0x13,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x90,0x50,0x50,0x50,0x50,0x90,0x20,0xc0,0x00,0x00,
+/* 41595 0xa27b "ꉻ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x13,0x14,0x14,0x14,0x14,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x50,0x50,0x50,0x50,0x90,0x20,0xc0,0x00,0x00,
+/* 41596 0xa27c "ꉼ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x05,0x02,0x05,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x90,0x28,0x28,0x28,0x90,0x40,0x20,0x00,0x00,
+/* 41597 0xa27d "ꉽ" */
+0x00,0x03,0x04,0x00,0x0c,0x0b,0x08,0x08,0x08,0x1c,0x2a,0x2a,0x2a,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x28,0xe4,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41598 0xa27e "ꉾ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x08,0x1c,0x2a,0x2a,0x2a,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0xe4,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41599 0xa27f "ꉿ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0e,0x04,0x0e,0x04,0x03,0x04,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 41600 0xa280 "ꊀ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x0e,0x0b,0x2a,0x1a,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x24,0xa4,0x74,0x2c,0xa0,0xa0,0x20,0xc0,0x00,0x00,
+/* 41601 0xa281 "ꊁ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x07,0x00,0x00,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41602 0xa282 "ꊂ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x07,0x00,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41603 0xa283 "ꊃ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41604 0xa284 "ꊄ" */
+0x00,0x03,0x04,0x00,0x0e,0x01,0x01,0x02,0x02,0x02,0x01,0x05,0x02,0x0d,0x00,0x00,
+0x00,0x80,0x40,0x00,0x70,0x80,0x80,0x50,0x50,0x50,0x80,0x80,0x40,0x30,0x00,0x00,
+/* 41605 0xa285 "ꊅ" */
+0x00,0x00,0x00,0x00,0x0e,0x01,0x01,0x02,0x02,0x02,0x01,0x05,0x02,0x0d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x80,0x80,0x50,0x50,0x50,0x80,0x80,0x40,0x30,0x00,0x00,
+/* 41606 0xa286 "ꊆ" */
+0x00,0x00,0x00,0x01,0x01,0x0f,0x01,0x0f,0x01,0x0f,0x01,0x03,0x05,0x05,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x30,0x80,0x40,0x40,0x40,0x80,0x00,0x80,0x40,0x40,0x00,0x00,
+/* 41607 0xa287 "ꊇ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x08,0x07,0x00,0x03,0x00,0x0b,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x90,0xa0,0xc0,0x80,0xe0,0x80,0xe0,0x80,0x00,0x00,0x00,
+/* 41608 0xa288 "ꊈ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x03,0x00,0x0b,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0xa0,0xc0,0x80,0xe0,0x80,0xe0,0x80,0x00,0x00,0x00,
+/* 41609 0xa289 "ꊉ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x0a,0x06,0x06,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0xa0,0x20,0xa0,0x80,0x40,0x40,0x00,0x00,
+/* 41610 0xa28a "ꊊ" */
+0x03,0x04,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x18,0x06,0x03,0x04,0x04,0x00,0x00,
+0x80,0x40,0x00,0x00,0xc0,0xb0,0x88,0x80,0x80,0x80,0x80,0xe0,0x90,0x90,0x00,0x00,
+/* 41611 0xa28b "ꊋ" */
+0x00,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x18,0x06,0x00,0x03,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xb0,0x88,0x80,0x80,0x80,0x80,0x80,0xe0,0x90,0x90,0x00,0x00,
+/* 41612 0xa28c "ꊌ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x1d,0x13,0x11,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x40,0x40,0x10,0x90,0x70,0x00,0x00,0x00,0x00,
+/* 41613 0xa28d "ꊍ" */
+0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x01,0x15,0x15,0x1f,0x15,0x15,0x01,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41614 0xa28e "ꊎ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x04,0x13,0x11,0x11,0x0e,0x04,0x0a,0x0a,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x40,0x90,0x10,0x10,0xe0,0x40,0xa0,0xa0,0x00,0x00,
+/* 41615 0xa28f "ꊏ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x13,0x11,0x11,0x0e,0x04,0x0a,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x90,0x10,0x10,0xe0,0x40,0xa0,0xa0,0x00,0x00,
+/* 41616 0xa290 "ꊐ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x09,0x09,0x09,0x09,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x30,0x10,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 41617 0xa291 "ꊑ" */
+0x00,0x03,0x04,0x00,0x14,0x14,0x14,0x1f,0x14,0x14,0x14,0x01,0x00,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xf0,0x40,0xf0,0x00,0x00,
+/* 41618 0xa292 "ꊒ" */
+0x00,0x00,0x00,0x00,0x14,0x14,0x14,0x1f,0x14,0x14,0x14,0x01,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xf8,0x40,0x40,0x40,0xf0,0x40,0xf0,0x00,0x00,
+/* 41619 0xa293 "ꊓ" */
+0x00,0x00,0x00,0x00,0x01,0x15,0x15,0x15,0x1f,0x15,0x15,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41620 0xa294 "ꊔ" */
+0x00,0x00,0x00,0x00,0x01,0x1d,0x03,0x0b,0x0b,0x03,0x1d,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x70,0x80,0xa0,0xa0,0x80,0x70,0x00,0x00,
+/* 41621 0xa295 "ꊕ" */
+0x00,0x03,0x04,0x00,0x00,0x07,0x08,0x10,0x14,0x14,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x00,0x00,
+/* 41622 0xa296 "ꊖ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x14,0x14,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x00,0x00,
+/* 41623 0xa297 "ꊗ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x13,0x11,0x11,0x0e,0x00,0x00,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x90,0x10,0x10,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 41624 0xa298 "ꊘ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x0e,0x04,0x04,0x0e,0x04,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41625 0xa299 "ꊙ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x0e,0x04,0x04,0x0e,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41626 0xa29a "ꊚ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x3c,0x24,0xfc,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 41627 0xa29b "ꊛ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x0f,0x01,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xe0,0x00,0x80,0x40,0x20,0xe0,0x00,0x00,
+/* 41628 0xa29c "ꊜ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x08,0x09,0x0a,0x0c,0x0a,0x69,0x58,0x40,0x00,0x00,
+0x00,0x80,0x40,0x00,0x04,0x74,0xac,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41629 0xa29d "ꊝ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x09,0x0a,0x0c,0x0a,0x69,0x58,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x74,0xac,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41630 0xa29e "ꊞ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x0f,0x10,0x10,0x0f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x10,0x10,0xe0,0x10,0x10,0xe0,0x00,0x00,
+/* 41631 0xa29f "ꊟ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x17,0x11,0x11,0x17,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0xd0,0x10,0x10,0xd0,0x00,0x00,0x00,0x00,
+/* 41632 0xa2a0 "ꊠ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x17,0x11,0x11,0x17,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xd0,0x10,0x10,0xd0,0x00,0x00,0x00,0x00,
+/* 41633 0xa2a1 "ꊡ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x0b,0x0a,0x09,0x08,0x09,0x02,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x40,0xc0,0x00,0xe0,0x20,0x40,0x80,0x40,0x20,0x00,0x00,
+/* 41634 0xa2a2 "ꊢ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xa0,0xa0,0xc0,0x80,0xa0,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 41635 0xa2a3 "ꊣ" */
+0x00,0x00,0x03,0x04,0x00,0x06,0x01,0x06,0x01,0x00,0x06,0x01,0x06,0x01,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x40,0xc0,0x40,0xc0,0x00,0x40,0xc0,0x40,0xc0,0x00,0x00,
+/* 41636 0xa2a4 "ꊤ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x01,0x06,0x01,0x00,0x06,0x01,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0xc0,0x40,0xc0,0x00,0x40,0xc0,0x40,0xc0,0x00,0x00,
+/* 41637 0xa2a5 "ꊥ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x00,0x00,0x07,0x08,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41638 0xa2a6 "ꊦ" */
+0x00,0x00,0x03,0x04,0x00,0x60,0x50,0x48,0x05,0x02,0x05,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x30,0x54,0x94,0x18,0x10,0x14,0x94,0x58,0x30,0x00,0x00,
+/* 41639 0xa2a7 "ꊧ" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x05,0x02,0x05,0x08,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x54,0x94,0x18,0x10,0x14,0x94,0x58,0x30,0x00,0x00,
+/* 41640 0xa2a8 "ꊨ" */
+0x00,0x00,0x00,0x02,0x01,0x00,0x01,0x02,0x03,0x12,0x0a,0x07,0x0a,0x12,0x00,0x00,
+0x00,0x00,0x00,0x48,0x50,0xe0,0x50,0x48,0x40,0xc0,0x80,0x00,0x80,0x40,0x00,0x00,
+/* 41641 0xa2a9 "ꊩ" */
+0x00,0x00,0x03,0x04,0x00,0x04,0x04,0x02,0x02,0x01,0x02,0x0a,0x08,0x07,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x40,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x40,0x00,0x00,
+/* 41642 0xa2aa "ꊪ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x02,0x0a,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x40,0x00,0x00,
+/* 41643 0xa2ab "ꊫ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x00,0x09,0x09,0x00,0x09,0x09,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,
+/* 41644 0xa2ac "ꊬ" */
+0x00,0x03,0x04,0x00,0x03,0x24,0x24,0x02,0x21,0x22,0x04,0x24,0x24,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x0c,0x10,0x20,0xe0,0x20,0x10,0x0c,0x00,0xc0,0x00,0x00,
+/* 41645 0xa2ad "ꊭ" */
+0x00,0x00,0x00,0x00,0x03,0x24,0x24,0x02,0x21,0x22,0x04,0x24,0x24,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x0c,0x10,0x20,0xe0,0x20,0x10,0x0c,0x00,0xc0,0x00,0x00,
+/* 41646 0xa2ae "ꊮ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x12,0x12,0x12,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc8,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41647 0xa2af "ꊯ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x1f,0x02,0x02,0x02,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0xc0,0x30,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41648 0xa2b0 "ꊰ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x1f,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41649 0xa2b1 "ꊱ" */
+0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x20,0xe0,0x00,0x00,
+/* 41650 0xa2b2 "ꊲ" */
+0x00,0x00,0x00,0x1e,0x11,0x10,0x11,0x11,0x11,0x11,0x11,0x15,0x53,0x30,0x00,0x00,
+0x00,0x00,0x00,0x08,0xcc,0x3a,0x88,0x48,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 41651 0xa2b3 "ꊳ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x50,0x50,0x50,0x60,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41652 0xa2b4 "ꊴ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x50,0x50,0x50,0x60,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41653 0xa2b5 "ꊵ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x0f,0x10,0x1f,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x00,0x80,0x40,0xc0,0x40,0x80,0x00,0x00,
+/* 41654 0xa2b6 "ꊶ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x16,0x11,0x10,0x16,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x90,0x90,0x90,0x90,0x90,0x20,0xc0,0x00,0x00,
+/* 41655 0xa2b7 "ꊷ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x11,0x11,0x11,0x15,0x13,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x90,0x50,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41656 0xa2b8 "ꊸ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x11,0x11,0x11,0x15,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x90,0x50,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41657 0xa2b9 "ꊹ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x13,0x02,0x02,0x0a,0x06,0x1c,0x13,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x28,0xa8,0x28,0x30,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41658 0xa2ba "ꊺ" */
+0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x07,0x09,0x07,0x01,0x19,0x07,0x00,0x00,
+0x80,0x40,0x00,0xc0,0x30,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41659 0xa2bb "ꊻ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x07,0x09,0x07,0x01,0x19,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x30,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41660 0xa2bc "ꊼ" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x02,0x02,0x04,0x04,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x20,0x00,0x00,
+/* 41661 0xa2bd "ꊽ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x0f,0x2a,0x1a,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x28,0x28,0x28,0xe8,0x38,0x28,0x28,0xc0,0x00,0x00,
+/* 41662 0xa2be "ꊾ" */
+0x00,0x03,0x04,0x00,0x01,0x02,0x02,0x02,0x0f,0x2a,0x1a,0x02,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x28,0x28,0x28,0xe8,0x38,0x28,0x28,0xc0,0x00,0x00,
+/* 41663 0xa2bf "ꊿ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x0f,0x2a,0x1a,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x28,0x28,0x28,0xe8,0x38,0x28,0x28,0xc0,0x00,0x00,
+/* 41664 0xa2c0 "ꋀ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x1f,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x10,0x00,0x00,
+/* 41665 0xa2c1 "ꋁ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x13,0x10,0x13,0x10,0x13,0x10,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x90,0x50,0x90,0x50,0x90,0x10,0x20,0xc0,0x00,0x00,
+/* 41666 0xa2c2 "ꋂ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x13,0x10,0x13,0x10,0x13,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x50,0x90,0x50,0x90,0x10,0x20,0xc0,0x00,0x00,
+/* 41667 0xa2c3 "ꋃ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x04,0x15,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x40,0x50,0x50,0x10,0xe0,0x00,0x00,
+/* 41668 0xa2c4 "ꋄ" */
+0x00,0x00,0x00,0x00,0x11,0x22,0x22,0x12,0x0e,0x12,0x22,0x22,0x12,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc4,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x24,0xc4,0x00,0x00,
+/* 41669 0xa2c5 "ꋅ" */
+0x00,0x00,0x03,0x04,0x00,0x40,0x20,0x11,0x4a,0x44,0x4a,0x11,0x20,0x40,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x60,0xa0,0x24,0x24,0x3c,0x24,0x24,0xa0,0x60,0x00,0x00,
+/* 41670 0xa2c6 "ꋆ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x11,0x4a,0x44,0x4a,0x11,0x20,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0xa0,0x24,0x24,0x3c,0x24,0x24,0xa0,0x60,0x00,0x00,
+/* 41671 0xa2c7 "ꋇ" */
+0x00,0x00,0x00,0x00,0x10,0x13,0x10,0x08,0x07,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41672 0xa2c8 "ꋈ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x80,0x00,0x00,0x00,
+/* 41673 0xa2c9 "ꋉ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x90,0x90,0x90,0xf0,0x90,0x90,0x90,0x80,0x00,0x00,0x00,
+/* 41674 0xa2ca "ꋊ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x01,0x0c,0x0a,0x09,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x80,0x40,0x20,0x00,0x00,
+/* 41675 0xa2cb "ꋋ" */
+0x00,0x00,0x03,0x04,0x00,0x04,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x40,0x40,0x80,0xa0,0x20,0xa0,0x80,0x40,0x40,0x00,0x00,
+/* 41676 0xa2cc "ꋌ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0xa0,0x20,0xa0,0x80,0x40,0x40,0x00,0x00,
+/* 41677 0xa2cd "ꋍ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41678 0xa2ce "ꋎ" */
+0x00,0x03,0x04,0x00,0x18,0x06,0x01,0x06,0x18,0x01,0x01,0x07,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0xc0,0x00,0xc0,0x30,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 41679 0xa2cf "ꋏ" */
+0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x06,0x18,0x01,0x01,0x07,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xc0,0x00,0xc0,0x30,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 41680 0xa2d0 "ꋐ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x15,0x14,0x14,0x04,0x07,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x58,0x40,0xc0,0x40,0x40,0x40,0x00,0x00,
+/* 41681 0xa2d1 "ꋑ" */
+0x00,0x03,0x04,0x10,0x08,0x24,0x10,0x08,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x50,0x48,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41682 0xa2d2 "ꋒ" */
+0x00,0x00,0x00,0x10,0x08,0x24,0x10,0x08,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 41683 0xa2d3 "ꋓ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x05,0x05,0x04,0x05,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xa0,0x60,0x00,0x20,0x20,0x00,0x20,0x20,0x00,0x00,
+/* 41684 0xa2d4 "ꋔ" */
+0x00,0x00,0x00,0x0f,0x01,0x11,0x09,0x05,0x11,0x09,0x05,0x11,0x09,0x05,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x40,0x20,0x10,0x40,0x20,0x10,0x40,0x20,0x10,0x00,0x00,
+/* 41685 0xa2d5 "ꋕ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x17,0x01,0x01,0x05,0x05,0x05,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0xd0,0x00,0x00,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 41686 0xa2d6 "ꋖ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x17,0x01,0x01,0x05,0x05,0x05,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0xd0,0x00,0x00,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 41687 0xa2d7 "ꋗ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x11,0x01,0x01,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x40,0x40,0x40,0x00,0x00,
+/* 41688 0xa2d8 "ꋘ" */
+0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x12,0x0a,0x07,0x0a,0x12,0x02,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x68,0xa8,0x38,0xa8,0x68,0x00,0xc0,0x00,0x00,
+/* 41689 0xa2d9 "ꋙ" */
+0x00,0x00,0x03,0x04,0x00,0x11,0x11,0x0a,0x0a,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x50,0x50,0x00,0x50,0x50,0x00,0x00,0x00,0x00,
+/* 41690 0xa2da "ꋚ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x0a,0x0a,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x00,0x50,0x50,0x00,0x00,0x00,0x00,
+/* 41691 0xa2db "ꋛ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x0a,0x0a,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x00,0x70,0x00,0x00,0x00,0x00,0x00,
+/* 41692 0xa2dc "ꋜ" */
+0x03,0x04,0x00,0x03,0x02,0x02,0x0f,0x02,0x0f,0x02,0x07,0x08,0x08,0x07,0x00,0x00,
+0x80,0x40,0x10,0x10,0xd0,0x30,0x80,0x00,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 41693 0xa2dd "ꋝ" */
+0x00,0x00,0x00,0x03,0x02,0x02,0x0f,0x02,0x0f,0x02,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x10,0x10,0xd0,0x30,0x80,0x00,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 41694 0xa2de "ꋞ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x11,0x11,0x09,0x07,0x04,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x10,0x10,0x20,0xc0,0x40,0x20,0x20,0x00,0x00,
+/* 41695 0xa2df "ꋟ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x0f,0x08,0x0f,0x08,0x07,0x01,0x01,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0xe0,0x20,0xe0,0x20,0xc0,0x00,0x10,0xe0,0x00,0x00,
+/* 41696 0xa2e0 "ꋠ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0f,0x08,0x0f,0x08,0x07,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xe0,0x20,0xe0,0x20,0xc0,0x00,0x10,0xe0,0x00,0x00,
+/* 41697 0xa2e1 "ꋡ" */
+0x00,0x00,0x00,0x00,0x0f,0x11,0x11,0x0f,0x11,0x11,0x0f,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x00,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 41698 0xa2e2 "ꋢ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x02,0x02,0x07,0x08,0x08,0x07,0x10,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0xc0,0x30,0x00,0x00,0x80,0x80,0x00,0x40,0x80,0x00,0x00,
+/* 41699 0xa2e3 "ꋣ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x07,0x08,0x08,0x07,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x00,0x80,0x80,0x00,0x40,0x80,0x00,0x00,
+/* 41700 0xa2e4 "ꋤ" */
+0x00,0x00,0x01,0x01,0x01,0x0f,0x11,0x11,0x11,0x0f,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x80,0x60,0x00,0x28,0x28,0xf8,0x28,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41701 0xa2e5 "ꋥ" */
+0x00,0x03,0x04,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x80,0x60,0x00,0xa0,0xa0,0xe0,0xa0,0xa0,0x00,0x00,0x00,
+/* 41702 0xa2e6 "ꋦ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0xa0,0xa0,0xe0,0xa0,0xa0,0x00,0x00,0x00,
+/* 41703 0xa2e7 "ꋧ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x04,0x08,0x10,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x40,0x20,0x10,0x40,0x20,0x10,0x00,0x00,
+/* 41704 0xa2e8 "ꋨ" */
+0x03,0x04,0x00,0x00,0x03,0x02,0x02,0x02,0x0a,0x06,0x03,0x06,0x0a,0x02,0x00,0x00,
+0x80,0x40,0x00,0x10,0x10,0xd0,0x30,0x00,0x60,0xa0,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 41705 0xa2e9 "ꋩ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x0a,0x06,0x03,0x06,0x0a,0x02,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xd0,0x30,0x00,0x60,0xa0,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 41706 0xa2ea "ꋪ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x09,0x0e,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0xe0,0x60,0xa0,0x20,0x20,0x00,0x00,
+/* 41707 0xa2eb "ꋫ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x04,0x0f,0x14,0x14,0x14,0x14,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41708 0xa2ec "ꋬ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x07,0x0a,0x0a,0x0a,0x0a,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41709 0xa2ed "ꋭ" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x80,0xc0,0x30,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41710 0xa2ee "ꋮ" */
+0x00,0x00,0x03,0x04,0x00,0x04,0x04,0x04,0x00,0x0f,0x00,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x40,0x40,0x40,0x00,0xe0,0x00,0x40,0x40,0x40,0x00,0x00,
+/* 41711 0xa2ef "ꋯ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x00,0x0f,0x00,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x00,0xe0,0x00,0x40,0x40,0x40,0x00,0x00,
+/* 41712 0xa2f0 "ꋰ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x09,0x09,0x01,0x01,0x09,0x09,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0x00,0x00,0x00,
+/* 41713 0xa2f1 "ꋱ" */
+0x00,0x03,0x04,0x00,0x11,0x15,0x15,0x11,0x1f,0x11,0x15,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0x00,0x00,0x00,
+/* 41714 0xa2f2 "ꋲ" */
+0x00,0x00,0x00,0x00,0x11,0x15,0x15,0x11,0x1f,0x11,0x15,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0x00,0x00,0x00,
+/* 41715 0xa2f3 "ꋳ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0x00,0x00,0x00,
+/* 41716 0xa2f4 "ꋴ" */
+0x00,0x00,0x00,0x00,0x01,0x07,0x01,0x00,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41717 0xa2f5 "ꋵ" */
+0x00,0x03,0x04,0x01,0x07,0x01,0x00,0x01,0x01,0x01,0x07,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x00,0x00,0x80,0x60,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41718 0xa2f6 "ꋶ" */
+0x00,0x00,0x00,0x01,0x07,0x01,0x00,0x01,0x01,0x01,0x07,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x80,0x60,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41719 0xa2f7 "ꋷ" */
+0x00,0x00,0x00,0x00,0x09,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x48,0x48,0x00,0x48,0x48,0x00,0x00,0x00,
+/* 41720 0xa2f8 "ꋸ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x03,0x11,0x13,0x0d,0x01,0x0d,0x03,0x0d,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x80,0x10,0x90,0x60,0x00,0x60,0x80,0x60,0x00,0x00,
+/* 41721 0xa2f9 "ꋹ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x03,0x11,0x13,0x0d,0x01,0x0d,0x03,0x0d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x10,0x90,0x60,0x00,0x60,0x80,0x60,0x00,0x00,
+/* 41722 0xa2fa "ꋺ" */
+0x00,0x03,0x04,0x00,0x00,0x03,0x02,0x02,0x02,0x0f,0x12,0x12,0x12,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0xd0,0x30,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41723 0xa2fb "ꋻ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x0f,0x12,0x12,0x12,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0x30,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41724 0xa2fc "ꋼ" */
+0x00,0x03,0x04,0x00,0x00,0x03,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0xe0,0x80,0x00,0x80,0x60,0x00,0x40,0x40,0x00,0x00,0x00,
+/* 41725 0xa2fd "ꋽ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xe0,0x80,0x00,0x80,0x60,0x00,0x40,0x40,0x00,0x00,0x00,
+/* 41726 0xa2fe "ꋾ" */
+0x00,0x03,0x04,0x00,0x01,0x07,0x01,0x11,0x11,0x0e,0x00,0x01,0x07,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 41727 0xa2ff "ꋿ" */
+0x00,0x00,0x00,0x00,0x01,0x07,0x01,0x11,0x11,0x0e,0x00,0x01,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 41728 0xa300 "ꌀ" */
+0x00,0x00,0x01,0x07,0x41,0x4c,0x34,0x04,0x03,0x01,0x07,0x01,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x04,0x64,0x58,0x40,0x80,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,
+/* 41729 0xa301 "ꌁ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x1f,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41730 0xa302 "ꌂ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x1f,0x11,0x11,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41731 0xa303 "ꌃ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x12,0x12,0x09,0x00,0x09,0x12,0x12,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 41732 0xa304 "ꌄ" */
+0x00,0x03,0x04,0x00,0x02,0x02,0x03,0x03,0x02,0x02,0x03,0x03,0x02,0x02,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x80,0x00,0xc0,0x20,0x20,0xc0,0x00,0x80,0x40,0x00,0x00,
+/* 41733 0xa305 "ꌅ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x03,0x03,0x02,0x02,0x03,0x03,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0xc0,0x20,0x20,0xc0,0x00,0x80,0x40,0x00,0x00,
+/* 41734 0xa306 "ꌆ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x14,0x1f,0x14,0x14,0x1f,0x14,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x50,0xf0,0x50,0x50,0xf0,0x50,0x20,0xc0,0x00,0x00,
+/* 41735 0xa307 "ꌇ" */
+0x00,0x03,0x04,0x00,0x10,0x14,0x14,0x14,0x10,0x11,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x50,0x50,0x50,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41736 0xa308 "ꌈ" */
+0x00,0x00,0x00,0x00,0x10,0x14,0x14,0x14,0x10,0x11,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x50,0x50,0x50,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41737 0xa309 "ꌉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0x20,0x24,0x22,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0x00,0x00,
+/* 41738 0xa30a "ꌊ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x1f,0x10,0x1f,0x08,0x07,0x08,0x11,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0xf0,0x10,0xf0,0x20,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41739 0xa30b "ꌋ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x1f,0x10,0x1f,0x08,0x07,0x08,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xf0,0x10,0xf0,0x20,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41740 0xa30c "ꌌ" */
+0x00,0x00,0x00,0x00,0x03,0x12,0x12,0x12,0x02,0x02,0x12,0x12,0x12,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41741 0xa30d "ꌍ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x02,0x01,0x18,0x20,0x40,0x48,0x46,0x21,0x00,0x00,
+0x00,0x80,0x40,0x00,0x44,0x44,0x48,0xf0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41742 0xa30e "ꌎ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x01,0x18,0x20,0x40,0x48,0x46,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x44,0x48,0xf0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41743 0xa30f "ꌏ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x01,0x01,0x07,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x80,0x40,0x40,0x40,0x00,0x00,
+/* 41744 0xa310 "ꌐ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb8,0xc0,0xc0,0xb8,0x80,0xb8,0xc0,0xc0,0xb8,0x80,0x00,0x00,
+/* 41745 0xa311 "ꌑ" */
+0x00,0x03,0x04,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x90,0xf0,0x90,0x80,0x80,0x90,0xf0,0x90,0x80,0x00,0x00,
+/* 41746 0xa312 "ꌒ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x90,0xf0,0x90,0x80,0x80,0x90,0xf0,0x90,0x80,0x00,0x00,
+/* 41747 0xa313 "ꌓ" */
+0x00,0x0f,0x10,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x90,0x50,0x10,0xd0,0x30,0x10,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 41748 0xa314 "ꌔ" */
+0x00,0x03,0x04,0x00,0x06,0x05,0x04,0x04,0x05,0x05,0x05,0x05,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x80,0x60,0x00,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41749 0xa315 "ꌕ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x05,0x05,0x05,0x05,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41750 0xa316 "ꌖ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x0a,0x09,0x08,0x09,0x0a,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 41751 0xa317 "ꌗ" */
+0x00,0x00,0x00,0x03,0x04,0x05,0x04,0x02,0x01,0x00,0x02,0x01,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x00,0x80,0x00,0x80,0x40,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41752 0xa318 "ꌘ" */
+0x00,0x03,0x04,0x00,0x11,0x09,0x05,0x11,0x09,0x05,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x00,0x40,0x20,0x10,0x40,0x20,0x10,0x00,0x00,
+/* 41753 0xa319 "ꌙ" */
+0x00,0x00,0x00,0x00,0x11,0x09,0x05,0x11,0x09,0x05,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x40,0x20,0x10,0x40,0x20,0x10,0x00,0x00,
+/* 41754 0xa31a "ꌚ" */
+0x00,0x00,0x00,0x07,0x08,0x0a,0x0a,0x08,0x07,0x00,0x02,0x02,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x80,0x80,0x00,0xc0,0x20,0xa0,0xa0,0x20,0xc0,0x00,0x00,
+/* 41755 0xa31b "ꌛ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x00,0x07,0x08,0x08,0x07,0x00,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41756 0xa31c "ꌜ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x07,0x08,0x08,0x07,0x00,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41757 0xa31d "ꌝ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x13,0x02,0x02,0x12,0x12,0x12,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x50,0x50,0x50,0xc0,0x00,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 41758 0xa31e "ꌞ" */
+0x00,0x00,0x00,0x08,0x08,0x07,0x00,0x11,0x11,0x0e,0x00,0x07,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xc0,0x00,0x10,0x10,0xe0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41759 0xa31f "ꌟ" */
+0x00,0x03,0x04,0x00,0x02,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x40,0x00,0xe0,0x00,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 41760 0xa320 "ꌠ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41761 0xa321 "ꌡ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x3e,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41762 0xa322 "ꌢ" */
+0x00,0x03,0x04,0x00,0x01,0x09,0x09,0x1d,0x09,0x09,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x20,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x20,0x00,0x00,
+/* 41763 0xa323 "ꌣ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x09,0x1d,0x09,0x09,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x20,0x00,0x00,
+/* 41764 0xa324 "ꌤ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x01,0x07,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0xc0,0x00,0x00,0x00,
+/* 41765 0xa325 "ꌥ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x10,0x10,0x08,0x07,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41766 0xa326 "ꌦ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x08,0x07,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41767 0xa327 "ꌧ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x07,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xf0,0x80,0x80,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41768 0xa328 "ꌨ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x10,0x08,0x07,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41769 0xa329 "ꌩ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x08,0x07,0x00,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41770 0xa32a "ꌪ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x1f,0x11,0x01,0x01,0x11,0x1f,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 41771 0xa32b "ꌫ" */
+0x00,0x03,0x04,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x05,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0xa0,0x60,0x00,0x40,0x40,0xf0,0x40,0x40,0x00,0x00,
+/* 41772 0xa32c "ꌬ" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x05,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xa0,0x60,0x00,0x40,0x40,0xf0,0x40,0x40,0x00,0x00,
+/* 41773 0xa32d "ꌭ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x1e,0x02,0x02,0x02,0x02,0x1e,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0x30,0x00,0x20,0x20,0xf8,0x20,0x20,0x00,0x00,
+/* 41774 0xa32e "ꌮ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x11,0x15,0x05,0x01,0x05,0x05,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x08,0x88,0x68,0x18,0x40,0x40,0x40,0x10,0xe0,0x00,0x00,
+/* 41775 0xa32f "ꌯ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x11,0x15,0x05,0x01,0x05,0x05,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x40,0x40,0x40,0x10,0xe0,0x00,0x00,
+/* 41776 0xa330 "ꌰ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x02,0x02,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0xa0,0xa0,0x80,0xf0,0x00,0x00,
+/* 41777 0xa331 "ꌱ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x13,0x0d,0x01,0x05,0x15,0x15,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x90,0x60,0x00,0x40,0x50,0x50,0x10,0xe0,0x00,0x00,
+/* 41778 0xa332 "ꌲ" */
+0x00,0x03,0x04,0x00,0x0f,0x10,0x10,0x0f,0x21,0x21,0x0f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0x10,0xe0,0x08,0x08,0xe0,0x10,0x10,0xe0,0x00,0x00,
+/* 41779 0xa333 "ꌳ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x0f,0x21,0x21,0x0f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x08,0x08,0xe0,0x10,0x10,0xe0,0x00,0x00,
+/* 41780 0xa334 "ꌴ" */
+0x00,0x00,0x00,0x0f,0x10,0x10,0x0f,0x01,0x1f,0x01,0x0f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x00,0xf0,0x00,0xe0,0x10,0x10,0xe0,0x00,0x00,
+/* 41781 0xa335 "ꌵ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x1f,0x11,0x11,0x11,0x1f,0x11,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41782 0xa336 "ꌶ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x10,0x1f,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0xf0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41783 0xa337 "ꌷ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x1f,0x11,0x11,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xf0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41784 0xa338 "ꌸ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x12,0x15,0x15,0x15,0x12,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41785 0xa339 "ꌹ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41786 0xa33a "ꌺ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 41787 0xa33b "ꌻ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x11,0x11,0x15,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x50,0x10,0x90,0x50,0x50,0x20,0xc0,0x00,0x00,
+/* 41788 0xa33c "ꌼ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x04,0x04,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xf8,0x40,0x40,0x78,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41789 0xa33d "ꌽ" */
+0x00,0x03,0x04,0x00,0x1c,0x13,0x10,0x02,0x0f,0x02,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x50,0xc0,0x40,0xc0,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41790 0xa33e "ꌾ" */
+0x00,0x00,0x00,0x00,0x1c,0x13,0x10,0x02,0x0f,0x02,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc0,0x40,0xc0,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 41791 0xa33f "ꌿ" */
+0x00,0x00,0x00,0x04,0x03,0x00,0x04,0x03,0x18,0x16,0x13,0x14,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x90,0xe0,0x80,0x90,0xe0,0x80,0x80,0xe0,0x10,0x90,0x90,0x00,0x00,
+/* 41792 0xa340 "ꍀ" */
+0x00,0x00,0x00,0x00,0x11,0x15,0x15,0x11,0x15,0x15,0x11,0x15,0x15,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x10,0x20,0x00,0x00,
+/* 41793 0xa341 "ꍁ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x07,0x09,0x09,0x09,0x37,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0xd8,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41794 0xa342 "ꍂ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x09,0x09,0x09,0x37,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0xd8,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 41795 0xa343 "ꍃ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x22,0x02,0x0f,0x02,0x02,0x38,0x26,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x48,0x40,0xc8,0x48,0x40,0x48,0x48,0x80,0x00,0x00,
+/* 41796 0xa344 "ꍄ" */
+0x03,0x04,0x00,0x0e,0x11,0x11,0x11,0x01,0x01,0x0f,0x00,0x09,0x09,0x09,0x00,0x00,
+0x80,0x40,0x00,0xe0,0x10,0x10,0x10,0x00,0x00,0xe0,0x00,0x20,0x20,0x20,0x00,0x00,
+/* 41797 0xa345 "ꍅ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x01,0x01,0x0f,0x00,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x00,0x00,0xe0,0x00,0x20,0x20,0x20,0x00,0x00,
+/* 41798 0xa346 "ꍆ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x15,0x15,0x15,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x70,0x80,0xa0,0xa0,0x80,0x70,0x00,0x70,0x80,0xa0,0xa0,0x80,0x70,0x00,
+/* 41799 0xa347 "ꍇ" */
+0x03,0x04,0x01,0x01,0x04,0x04,0x18,0x16,0x11,0x10,0x10,0x04,0x05,0x01,0x00,0x00,
+0x80,0x40,0x00,0x00,0x40,0x40,0x10,0x10,0x10,0xd0,0x30,0x40,0x40,0x00,0x00,0x00,
+/* 41800 0xa348 "ꍈ" */
+0x00,0x00,0x01,0x01,0x04,0x04,0x18,0x16,0x11,0x10,0x10,0x04,0x05,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x10,0x10,0x10,0xd0,0x30,0x40,0x40,0x00,0x00,0x00,
+/* 41801 0xa349 "ꍉ" */
+0x00,0x00,0x00,0x00,0x03,0x3a,0x06,0x12,0x12,0x12,0x12,0x06,0x3a,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x18,0x68,0x88,0x00,0x00,
+/* 41802 0xa34a "ꍊ" */
+0x00,0x03,0x04,0x00,0x05,0x05,0x25,0x19,0x01,0x01,0x3f,0x01,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 41803 0xa34b "ꍋ" */
+0x00,0x00,0x00,0x00,0x05,0x05,0x25,0x19,0x01,0x01,0x3f,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 41804 0xa34c "ꍌ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x01,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41805 0xa34d "ꍍ" */
+0x00,0x00,0x00,0x00,0x05,0x05,0x25,0x19,0x01,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41806 0xa34e "ꍎ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x12,0x12,0x10,0x1f,0x10,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x50,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x00,0x00,
+/* 41807 0xa34f "ꍏ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x12,0x12,0x10,0x1f,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x00,0x00,
+/* 41808 0xa350 "ꍐ" */
+0x00,0x00,0x00,0x00,0x01,0x05,0x04,0x02,0x1e,0x11,0x12,0x02,0x04,0x05,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x90,0x10,0xf0,0x80,0x40,0x40,0x00,0x00,
+/* 41809 0xa351 "ꍑ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x05,0x25,0x21,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x40,0x48,0x08,0x10,0xe0,0x00,0x00,
+/* 41810 0xa352 "ꍒ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x05,0x05,0x25,0x21,0x11,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x48,0x08,0x10,0xe0,0x00,0x00,
+/* 41811 0xa353 "ꍓ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x05,0x05,0x25,0x21,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x48,0x08,0x10,0xe0,0x00,0x00,
+/* 41812 0xa354 "ꍔ" */
+0x00,0x00,0x00,0x00,0x15,0x15,0x15,0x11,0x15,0x15,0x15,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x10,0x50,0x50,0x50,0x10,0x20,0xc0,0x00,0x00,
+/* 41813 0xa355 "ꍕ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x24,0x14,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0xc4,0x44,0x44,0x44,0x44,0x54,0x54,0x38,0x10,0x00,
+/* 41814 0xa356 "ꍖ" */
+0x00,0x03,0x04,0x00,0x01,0x0f,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0x90,0x68,0x28,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41815 0xa357 "ꍗ" */
+0x00,0x00,0x00,0x00,0x01,0x0f,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x68,0x28,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41816 0xa358 "ꍘ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x04,0x0a,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x40,0xa0,0xa0,0x40,0x00,0x00,
+/* 41817 0xa359 "ꍙ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x1a,0x06,0x02,0x1a,0x06,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0xe8,0x28,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41818 0xa35a "ꍚ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x1a,0x06,0x02,0x1a,0x06,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xe8,0x28,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41819 0xa35b "ꍛ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x08,0x07,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x00,0xc0,0x20,0x20,0xc0,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41820 0xa35c "ꍜ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x09,0x07,0x01,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x20,0xc0,0x10,0x10,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41821 0xa35d "ꍝ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x01,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x10,0x10,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41822 0xa35e "ꍞ" */
+0x00,0x00,0x00,0x0e,0x09,0x08,0x00,0x0e,0x09,0x08,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x10,0x90,0x70,0x00,0x10,0x90,0x70,0x00,0x10,0x90,0x70,0x00,0x00,
+/* 41823 0xa35f "ꍟ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x12,0x12,0x13,0x12,0x12,0x12,0x02,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0xe0,0x00,0x00,0x18,0x60,0x80,0x00,0x00,
+/* 41824 0xa360 "ꍠ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x12,0x12,0x13,0x12,0x12,0x12,0x02,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xe0,0x00,0x00,0x18,0x60,0x80,0x00,0x00,
+/* 41825 0xa361 "ꍡ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x0f,0x09,0x05,0x03,0x03,0x05,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0xe0,0x20,0x40,0x80,0x80,0x40,0x20,0x00,0x00,
+/* 41826 0xa362 "ꍢ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x07,0x09,0x07,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0xc0,0x20,0xc0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41827 0xa363 "ꍣ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x07,0x09,0x07,0x01,0x07,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0xc0,0x20,0xc0,0x00,0xc0,0x20,0x20,0x00,0x00,
+/* 41828 0xa364 "ꍤ" */
+0x00,0x00,0x00,0x01,0x03,0x05,0x04,0x05,0x03,0x01,0x03,0x05,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 41829 0xa365 "ꍥ" */
+0x00,0x00,0x00,0x00,0x30,0x2c,0x23,0x20,0x24,0x24,0x20,0x3f,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa8,0x98,0x88,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41830 0xa366 "ꍦ" */
+0x00,0x03,0x04,0x00,0x0c,0x0a,0x08,0x28,0x18,0x0c,0x0a,0x08,0x28,0x18,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x28,0x20,0x20,0xa0,0x60,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41831 0xa367 "ꍧ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x08,0x28,0x18,0x0c,0x0a,0x08,0x28,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x20,0x20,0xa0,0x60,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41832 0xa368 "ꍨ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x12,0x08,0x05,0x02,0x05,0x08,0x12,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x50,0x90,0x10,0x1c,0x10,0x90,0x50,0x30,0x00,0x00,
+/* 41833 0xa369 "ꍩ" */
+0x00,0x00,0x00,0x00,0x18,0x15,0x11,0x10,0x1f,0x10,0x11,0x91,0x50,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x14,0x12,0x10,0xf0,0x10,0x10,0x10,0x50,0x30,0x00,0x00,
+/* 41834 0xa36a "ꍪ" */
+0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,
+0x80,0x40,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0x88,0x88,0x88,0xe8,0x98,0x00,0x00,
+/* 41835 0xa36b "ꍫ" */
+0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0x88,0x88,0x88,0xe8,0x98,0x00,0x00,
+/* 41836 0xa36c "ꍬ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x0f,0x08,0x08,0x08,0x69,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x2c,0x20,0x20,0xe0,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41837 0xa36d "ꍭ" */
+0x00,0x00,0x00,0x00,0x1f,0x11,0x09,0x05,0x13,0x11,0x13,0x05,0x09,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x90,0x10,0x90,0x40,0x20,0x10,0x00,0x00,
+/* 41838 0xa36e "ꍮ" */
+0x00,0x03,0x04,0x00,0x1f,0x11,0x09,0x05,0x03,0x1f,0x02,0x04,0x09,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0xf0,0x10,0x20,0x40,0x80,0xf0,0x80,0x40,0x20,0x10,0x00,0x00,
+/* 41839 0xa36f "ꍯ" */
+0x00,0x00,0x00,0x00,0x1f,0x11,0x09,0x05,0x03,0x1f,0x02,0x04,0x09,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x80,0xf0,0x80,0x40,0x20,0x10,0x00,0x00,
+/* 41840 0xa370 "ꍰ" */
+0x00,0x00,0x00,0x00,0x1f,0x11,0x09,0x05,0x3b,0x27,0x22,0x04,0x09,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x40,0x88,0xc8,0xb8,0x40,0x20,0x10,0x00,0x00,
+/* 41841 0xa371 "ꍱ" */
+0x00,0x03,0x04,0x00,0x0e,0x11,0x11,0x15,0x15,0x15,0x15,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x28,0x28,0xf8,0x28,0xf8,0x28,0x28,0x00,0x00,0x00,0x00,
+/* 41842 0xa372 "ꍲ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x15,0x15,0x15,0x15,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x28,0x28,0xf8,0x28,0xf8,0x28,0x28,0x00,0x00,0x00,0x00,
+/* 41843 0xa373 "ꍳ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x0a,0x0a,0x0a,0x0a,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x80,0xf0,0x80,0x80,0xf0,0x80,0xa0,0x20,0x00,0x00,
+/* 41844 0xa374 "ꍴ" */
+0x00,0x03,0x04,0x00,0x0c,0x0b,0x08,0x08,0x08,0x3e,0x08,0x08,0x68,0x18,0x00,0x00,
+0x00,0x80,0x40,0x00,0x04,0x34,0x2c,0x20,0x20,0x20,0x20,0x2c,0x34,0x04,0x00,0x00,
+/* 41845 0xa375 "ꍵ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x08,0x3e,0x08,0x08,0x68,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x34,0x2c,0x20,0x20,0x20,0x20,0x2c,0x34,0x04,0x00,0x00,
+/* 41846 0xa376 "ꍶ" */
+0x00,0x00,0x1c,0x01,0x05,0x05,0x01,0x0e,0x00,0x0f,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x10,0xc8,0xa8,0x98,0x80,0x80,0x80,0xf8,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41847 0xa377 "ꍷ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x01,0x02,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0xc0,0x20,0x20,0xc0,0x00,0x00,
+/* 41848 0xa378 "ꍸ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x01,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0xc0,0x20,0x20,0xc0,0x00,0x00,
+/* 41849 0xa379 "ꍹ" */
+0x00,0x00,0x00,0x00,0x05,0x05,0x01,0x07,0x01,0x05,0x04,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x50,0x10,0xd0,0x10,0x50,0x50,0x10,0x90,0x70,0x00,0x00,
+/* 41850 0xa37a "ꍺ" */
+0x03,0x04,0x00,0x1c,0x03,0x0b,0x0b,0x03,0x1d,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x80,0x40,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 41851 0xa37b "ꍻ" */
+0x00,0x00,0x00,0x1c,0x03,0x0b,0x0b,0x03,0x1d,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 41852 0xa37c "ꍼ" */
+0x00,0x03,0x04,0x00,0x03,0x12,0x12,0x3a,0x12,0x12,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0xe8,0x24,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41853 0xa37d "ꍽ" */
+0x00,0x00,0x00,0x00,0x03,0x12,0x12,0x3a,0x12,0x12,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xe8,0x24,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41854 0xa37e "ꍾ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x09,0x15,0x15,0x15,0x09,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41855 0xa37f "ꍿ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x09,0x15,0x15,0x15,0x09,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x00,0xf0,0x00,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 41856 0xa380 "ꎀ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x11,0x11,0x11,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x48,0x48,0x30,0x00,0xf8,0x00,0x30,0x48,0x48,0x00,0x00,0x00,
+/* 41857 0xa381 "ꎁ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x07,0x08,0x0f,0x08,0x08,0x09,0x09,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0xc0,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41858 0xa382 "ꎂ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x07,0x08,0x0f,0x08,0x08,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41859 0xa383 "ꎃ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x04,0x04,0x01,0x01,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0x50,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41860 0xa384 "ꎄ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x3f,0x01,0x11,0x7d,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41861 0xa385 "ꎅ" */
+0x00,0x03,0x04,0x00,0x0f,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41862 0xa386 "ꎆ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 41863 0xa387 "ꎇ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x03,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0xe0,0x80,0x80,0x00,0x00,0x00,
+/* 41864 0xa388 "ꎈ" */
+0x00,0x00,0x00,0x00,0x18,0x14,0x12,0x10,0x11,0x11,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x30,0x00,0x00,
+/* 41865 0xa389 "ꎉ" */
+0x00,0x03,0x04,0x00,0x08,0x14,0x14,0x14,0x08,0x05,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x50,0x50,0x50,0x20,0x40,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41866 0xa38a "ꎊ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x14,0x08,0x05,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x50,0x20,0x40,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 41867 0xa38b "ꎋ" */
+0x00,0x00,0x00,0x00,0x36,0x08,0x14,0x14,0x14,0x3f,0x14,0x14,0x08,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd8,0x20,0x50,0x50,0x50,0xf8,0x50,0x50,0x20,0xd8,0x00,0x00,
+/* 41868 0xa38c "ꎌ" */
+0x00,0x03,0x04,0x00,0x01,0x00,0x06,0x08,0x09,0x09,0x08,0x06,0x00,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 41869 0xa38d "ꎍ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x06,0x08,0x09,0x09,0x08,0x06,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 41870 0xa38e "ꎎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xa8,0xa8,0xa8,0xf8,0xa8,0xa8,0xa8,0x80,0x00,0x00,0x00,
+/* 41871 0xa38f "ꎏ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x40,0x40,0x40,0x50,0x50,0x50,0xd0,0x00,0x00,0x00,
+/* 41872 0xa390 "ꎐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x50,0x50,0x50,0xd0,0x00,0x00,0x00,
+/* 41873 0xa391 "ꎑ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x03,0x04,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0xa0,0xa0,0xa0,0x80,0x80,0x80,0x00,0x00,
+/* 41874 0xa392 "ꎒ" */
+0x00,0x03,0x04,0x00,0x08,0x09,0x1d,0x09,0x09,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41875 0xa393 "ꎓ" */
+0x00,0x00,0x00,0x00,0x08,0x09,0x1d,0x09,0x09,0x01,0x07,0x09,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,
+/* 41876 0xa394 "ꎔ" */
+0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x10,0x1f,0x10,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41877 0xa395 "ꎕ" */
+0x00,0x03,0x04,0x00,0x03,0x14,0x14,0x04,0x0f,0x04,0x14,0x14,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x50,0x50,0x40,0xe0,0x40,0x50,0x50,0x40,0x80,0x00,0x00,
+/* 41878 0xa396 "ꎖ" */
+0x00,0x00,0x00,0x00,0x03,0x14,0x14,0x04,0x0f,0x04,0x14,0x14,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x50,0x50,0x40,0xe0,0x40,0x50,0x50,0x40,0x80,0x00,0x00,
+/* 41879 0xa397 "ꎗ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x06,0x0a,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x50,0x60,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 41880 0xa398 "ꎘ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x09,0x01,0x07,0x01,0x01,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0xd0,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41881 0xa399 "ꎙ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x01,0x07,0x01,0x01,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xd0,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41882 0xa39a "ꎚ" */
+0x00,0x00,0x02,0x02,0x03,0x06,0x0a,0x01,0x00,0x00,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x20,0x20,0xe0,0x30,0x30,0xd0,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 41883 0xa39b "ꎛ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x09,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0xf0,0x00,0x20,0x20,0x00,0x00,0x00,
+/* 41884 0xa39c "ꎜ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x34,0x2c,0x20,0x00,0x00,
+0x00,0x80,0x40,0x00,0x04,0x34,0x2c,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41885 0xa39d "ꎝ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x34,0x2c,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x34,0x2c,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41886 0xa39e "ꎞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0xb0,0xc0,0xf0,0xc0,0xb0,0x80,0x00,0x00,
+/* 41887 0xa39f "ꎟ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0b,0x0a,0x08,0x08,0x0b,0x0a,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xa0,0xe0,0x80,0x80,0xa0,0xe0,0x80,0x00,0x00,0x00,
+/* 41888 0xa3a0 "ꎠ" */
+0x00,0x03,0x04,0x10,0x28,0x2f,0x28,0x10,0x00,0x10,0x28,0x2f,0x28,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41889 0xa3a1 "ꎡ" */
+0x00,0x00,0x00,0x10,0x28,0x2f,0x28,0x10,0x00,0x10,0x28,0x2f,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 41890 0xa3a2 "ꎢ" */
+0x00,0x00,0x00,0x08,0x08,0x04,0x13,0x11,0x7d,0x11,0x11,0x0d,0x0b,0x08,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x40,0x90,0x10,0x7c,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 41891 0xa3a3 "ꎣ" */
+0x00,0x03,0x04,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41892 0xa3a4 "ꎤ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41893 0xa3a5 "ꎥ" */
+0x00,0x00,0x00,0x00,0x09,0x05,0x03,0x03,0x05,0x09,0x01,0x0d,0x0b,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x50,0x90,0x90,0x50,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41894 0xa3a6 "ꎦ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x08,0x0f,0x08,0x0a,0x0c,0x18,0x28,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41895 0xa3a7 "ꎧ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0f,0x08,0x0a,0x0c,0x18,0x28,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 41896 0xa3a8 "ꎨ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x0f,0x08,0x08,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xf8,0x00,0x00,
+/* 41897 0xa3a9 "ꎩ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0xc0,0x00,0x00,0xe0,0x10,0x48,0xa8,0xa0,0x40,0x00,0x00,
+/* 41898 0xa3aa "ꎪ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x1a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0xe0,0x10,0x48,0xa8,0xa0,0x40,0x00,0x00,
+/* 41899 0xa3ab "ꎫ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 41900 0xa3ac "ꎬ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x29,0x29,0x29,0x3f,0x29,0x29,0x29,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41901 0xa3ad "ꎭ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x29,0x29,0x29,0x3f,0x29,0x29,0x29,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41902 0xa3ae "ꎮ" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x0f,0x09,0x09,0x09,0x0f,0x49,0x29,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0xe4,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x00,0x00,
+/* 41903 0xa3af "ꎯ" */
+0x00,0x03,0x04,0x00,0x0f,0x01,0x0f,0x01,0x09,0x05,0x03,0x03,0x05,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0xe0,0x00,0x20,0x40,0x80,0x80,0x40,0x20,0x00,0x00,
+/* 41904 0xa3b0 "ꎰ" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x0f,0x01,0x09,0x05,0x03,0x03,0x05,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x20,0x40,0x80,0x80,0x40,0x20,0x00,0x00,
+/* 41905 0xa3b1 "ꎱ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x02,0x01,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0xe8,0x98,0x80,0xa0,0xc0,0xc0,0xa0,0x00,0x00,
+/* 41906 0xa3b2 "ꎲ" */
+0x00,0x00,0x00,0x00,0x09,0x11,0x11,0x09,0x07,0x09,0x11,0x11,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x30,0x00,0x20,0x20,0x20,0x20,0x00,0x30,0xc0,0x00,0x00,
+/* 41907 0xa3b3 "ꎳ" */
+0x03,0x04,0x00,0x05,0x05,0x04,0x13,0x11,0x11,0x0e,0x05,0x05,0x04,0x03,0x00,0x00,
+0x80,0x40,0x00,0x40,0x40,0x40,0x90,0x10,0x10,0xe0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41908 0xa3b4 "ꎴ" */
+0x00,0x00,0x00,0x05,0x05,0x04,0x13,0x11,0x11,0x0e,0x05,0x05,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x40,0x90,0x10,0x10,0xe0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 41909 0xa3b5 "ꎵ" */
+0x00,0x00,0x00,0x00,0x00,0x19,0x25,0x22,0x1d,0x00,0x1d,0x22,0x25,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x84,0x44,0x24,0x14,0x0c,0x00,0x00,
+/* 41910 0xa3b6 "ꎶ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x18,0x16,0x11,0x12,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xa0,0xa0,0xa0,0x80,0x80,0xc0,0x20,0x90,0x90,0x00,0x00,
+/* 41911 0xa3b7 "ꎷ" */
+0x00,0x03,0x04,0x10,0x11,0x1f,0x11,0x11,0x01,0x19,0x17,0x11,0x11,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x40,0x40,0x50,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41912 0xa3b8 "ꎸ" */
+0x00,0x00,0x00,0x10,0x11,0x1f,0x11,0x11,0x01,0x19,0x17,0x11,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x40,0x40,0x50,0x10,0xd0,0x30,0x00,0x00,0x00,
+/* 41913 0xa3b9 "ꎹ" */
+0x00,0x00,0x00,0x1c,0x03,0x0b,0x0b,0x03,0x1d,0x01,0x19,0x17,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x40,0x40,0x40,0x10,0x10,0xd0,0x30,0x00,0x00,
+/* 41914 0xa3ba "ꎺ" */
+0x00,0x00,0x00,0x00,0x01,0x09,0x05,0x03,0x09,0x05,0x03,0x09,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x20,0x40,0x80,0x20,0x40,0x80,0x00,0x00,
+/* 41915 0xa3bb "ꎻ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x28,0x28,0x28,0x28,0x28,0x28,0x30,0xe0,0x20,0x20,0x00,0x00,
+/* 41916 0xa3bc "ꎼ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x28,0x28,0x28,0x28,0x28,0x28,0x30,0xe0,0x20,0x20,0x00,0x00,
+/* 41917 0xa3bd "ꎽ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x06,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x80,0x80,0x00,0x80,0x80,0x00,0x00,
+/* 41918 0xa3be "ꎾ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x90,0x60,0x60,0xa0,0x20,0x20,0xa0,0x60,0x60,0x90,0x00,0x00,
+/* 41919 0xa3bf "ꎿ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x60,0x60,0xa0,0x20,0x20,0xa0,0x60,0x60,0x90,0x00,0x00,
+/* 41920 0xa3c0 "ꏀ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x1a,0x16,0x13,0x12,0x12,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x28,0x28,0xa8,0x68,0x38,0x20,0x20,0x20,0x00,0x00,
+/* 41921 0xa3c1 "ꏁ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x02,0x01,0x02,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 41922 0xa3c2 "ꏂ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x01,0x02,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 41923 0xa3c3 "ꏃ" */
+0x00,0x00,0x00,0x04,0x04,0x02,0x01,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x90,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 41924 0xa3c4 "ꏄ" */
+0x00,0x03,0x04,0x10,0x11,0x12,0x04,0x14,0x17,0x14,0x04,0x14,0x12,0x11,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 41925 0xa3c5 "ꏅ" */
+0x00,0x00,0x00,0x08,0x08,0x09,0x02,0x0a,0x0b,0x0a,0x02,0x0a,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 41926 0xa3c6 "ꏆ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x07,0x09,0x11,0x17,0x11,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xc0,0x20,0x10,0xd0,0x10,0x10,0x00,0x00,0x00,
+/* 41927 0xa3c7 "ꏇ" */
+0x00,0x03,0x04,0x00,0x0e,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x48,0x48,0x30,0xf8,0x30,0x48,0x48,0x00,0x00,0x00,0x00,
+/* 41928 0xa3c8 "ꏈ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x48,0x30,0xf8,0x30,0x48,0x48,0x00,0x00,0x00,0x00,
+/* 41929 0xa3c9 "ꏉ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x09,0x0a,0x0a,0x0a,0x0a,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x60,0x00,0x00,
+/* 41930 0xa3ca "ꏊ" */
+0x00,0x03,0x04,0x00,0x0c,0x0a,0x08,0x09,0x0a,0x0a,0x09,0x08,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41931 0xa3cb "ꏋ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x08,0x09,0x0a,0x0a,0x09,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xa0,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41932 0xa3cc "ꏌ" */
+0x00,0x00,0x00,0x00,0x10,0x12,0x11,0x10,0x1f,0x10,0x11,0x12,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0xf0,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,
+/* 41933 0xa3cd "ꏍ" */
+0x00,0x00,0x00,0x04,0x02,0x01,0x22,0x14,0x08,0x14,0x22,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x40,0x80,0x00,0x88,0x50,0x20,0x50,0x88,0x00,0x80,0x40,0x00,0x00,
+/* 41934 0xa3ce "ꏎ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x09,0x0a,0x0a,0x0a,0x0a,0x09,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x80,0xc0,0xa0,0xa0,0xa0,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 41935 0xa3cf "ꏏ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x09,0x0a,0x0a,0x0a,0x0a,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xa0,0xa0,0xa0,0xa0,0xc0,0x80,0x00,0x00,0x00,
+/* 41936 0xa3d0 "ꏐ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x12,0x2a,0x29,0x2a,0x12,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x90,0xa8,0x28,0xa8,0x90,0x40,0x40,0x00,0x00,
+/* 41937 0xa3d1 "ꏑ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x04,0x03,0x09,0x05,0x03,0x03,0x05,0x09,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x40,0x40,0x80,0x30,0x50,0x90,0x90,0x50,0x30,0x00,0x00,
+/* 41938 0xa3d2 "ꏒ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x09,0x05,0x03,0x03,0x05,0x09,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x30,0x50,0x90,0x90,0x50,0x30,0x00,0x00,
+/* 41939 0xa3d3 "ꏓ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x12,0x0b,0x06,0x0b,0x12,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xd0,0x50,0x50,0x50,0xd0,0x10,0xe0,0x00,0x00,
+/* 41940 0xa3d4 "ꏔ" */
+0x00,0x00,0x09,0x05,0x03,0x03,0x05,0x09,0x05,0x05,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x20,0x40,0x80,0x80,0x40,0x20,0x40,0x40,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 41941 0xa3d5 "ꏕ" */
+0x00,0x03,0x04,0x00,0x07,0x31,0x2d,0x23,0x21,0x21,0x01,0x05,0x05,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x10,0x10,0x10,0xd0,0x30,0x00,0x40,0x40,0x00,0x00,0x00,
+/* 41942 0xa3d6 "ꏖ" */
+0x00,0x00,0x00,0x00,0x03,0x18,0x16,0x11,0x10,0x10,0x00,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x88,0x88,0x88,0xe8,0x98,0x80,0xa0,0xa0,0x80,0x00,0x00,
+/* 41943 0xa3d7 "ꏗ" */
+0x00,0x00,0x00,0x00,0x1e,0x01,0x09,0x05,0x03,0x03,0x05,0x09,0x01,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x50,0x90,0x90,0x50,0x30,0x00,0x00,0x00,0x00,
+/* 41944 0xa3d8 "ꏘ" */
+0x00,0x03,0x04,0x00,0x09,0x05,0x03,0x03,0x05,0x09,0x01,0x05,0x05,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x40,0x80,0x80,0x40,0x20,0x00,0x40,0x40,0x00,0x00,0x00,
+/* 41945 0xa3d9 "ꏙ" */
+0x00,0x00,0x00,0x00,0x09,0x05,0x03,0x03,0x05,0x09,0x01,0x05,0x05,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x80,0x40,0x20,0x00,0x40,0x40,0x00,0x00,0x00,
+/* 41946 0xa3da "ꏚ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x00,0x03,0x02,0x07,0x0a,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x00,0x48,0x48,0x50,0xe0,0x40,0xc0,0x00,0x80,0x40,0x40,0x00,0x00,
+/* 41947 0xa3db "ꏛ" */
+0x00,0x03,0x04,0x00,0x06,0x05,0x04,0x04,0x05,0x07,0x05,0x05,0x07,0x05,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0xa0,0x60,0x00,0x20,0xf0,0x20,0x20,0xf0,0x20,0x00,0x00,
+/* 41948 0xa3dc "ꏜ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x05,0x07,0x05,0x05,0x07,0x05,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x00,0x20,0xf0,0x20,0x20,0xf0,0x20,0x00,0x00,
+/* 41949 0xa3dd "ꏝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x26,0x15,0x0c,0x3f,0x06,0x05,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x20,0xa0,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 41950 0xa3de "ꏞ" */
+0x00,0x03,0x04,0x00,0x00,0x18,0x04,0x02,0x02,0x02,0x02,0x04,0x18,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x00,0x00,
+/* 41951 0xa3df "ꏟ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x02,0x02,0x02,0x04,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x80,0x80,0x78,0x00,0x00,
+/* 41952 0xa3e0 "ꏠ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x01,0x0d,0x0b,0x09,0x09,0x01,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x20,0x20,0xa0,0x60,0x00,0x20,0xc0,0x00,0x00,
+/* 41953 0xa3e1 "ꏡ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x31,0x2c,0x23,0x20,0x20,0x01,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x10,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 41954 0xa3e2 "ꏢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x88,0x08,0x88,0x68,0x18,0x80,0x80,0x80,0x00,0x00,
+/* 41955 0xa3e3 "ꏣ" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x1f,0x00,0x00,
+0x00,0x00,0xf8,0x20,0xa0,0xa0,0x20,0xa0,0x60,0x00,0x80,0x80,0x00,0xf8,0x00,0x00,
+/* 41956 0xa3e4 "ꏤ" */
+0x00,0x00,0x00,0x07,0x04,0x04,0x35,0x0c,0x04,0x35,0x0c,0x04,0x35,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x30,0xe8,0x24,0xa0,0x60,0x20,0xa0,0x60,0x20,0xa0,0x60,0x00,0x00,
+/* 41957 0xa3e5 "ꏥ" */
+0x00,0x03,0x04,0x00,0x08,0x09,0x09,0x08,0x0f,0x08,0x09,0x69,0x58,0x40,0x00,0x00,
+0x00,0x80,0x40,0x00,0x04,0x34,0x2c,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41958 0xa3e6 "ꏦ" */
+0x00,0x00,0x00,0x00,0x08,0x09,0x09,0x08,0x0f,0x08,0x09,0x69,0x58,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x34,0x2c,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 41959 0xa3e7 "ꏧ" */
+0x00,0x00,0x00,0x00,0x0e,0x01,0x02,0x0f,0x02,0x02,0x0f,0x02,0x01,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x80,0xe0,0x80,0x80,0xe0,0x80,0x00,0xf0,0x00,0x00,
+/* 41960 0xa3e8 "ꏨ" */
+0x00,0x00,0x10,0x17,0x08,0x17,0x10,0x11,0x11,0x10,0x17,0x08,0x17,0x10,0x00,0x00,
+0x00,0x00,0x10,0xd0,0x20,0xd0,0x10,0x10,0x10,0x10,0xd0,0x20,0xd0,0x10,0x00,0x00,
+/* 41961 0xa3e9 "ꏩ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x13,0x11,0x11,0x0e,0x00,0x01,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0x90,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41962 0xa3ea "ꏪ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x13,0x11,0x11,0x0e,0x00,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x90,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41963 0xa3eb "ꏫ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x13,0x12,0x12,0x12,0x1a,0x16,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x58,0x60,0xc0,0x40,0x40,0x40,0x60,0x58,0x80,0x00,0x00,
+/* 41964 0xa3ec "ꏬ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x01,0x01,0x07,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 41965 0xa3ed "ꏭ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x0e,0x00,0x01,0x01,0x09,0x09,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41966 0xa3ee "ꏮ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x01,0x01,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41967 0xa3ef "ꏯ" */
+0x00,0x00,0x00,0x04,0x04,0x03,0x11,0x11,0x0e,0x00,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x80,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41968 0xa3f0 "ꏰ" */
+0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x11,0x17,0x11,0x15,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x90,0x50,0x10,0xd0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41969 0xa3f1 "ꏱ" */
+0x00,0x03,0x04,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x00,0x40,0xa0,0xa0,0xa0,0xa0,0x40,0x00,0xe0,0x00,0x00,
+/* 41970 0xa3f2 "ꏲ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x40,0xa0,0xa0,0xa0,0xa0,0x40,0x00,0xe0,0x00,0x00,
+/* 41971 0xa3f3 "ꏳ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x09,0x0a,0x0a,0x0a,0x0a,0x09,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x30,0x10,0x80,0x80,0x80,0x80,0x10,0x20,0xc0,0x00,0x00,
+/* 41972 0xa3f4 "ꏴ" */
+0x00,0x03,0x04,0x00,0x10,0x11,0x11,0x11,0x11,0x11,0x15,0x13,0x08,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x90,0x50,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41973 0xa3f5 "ꏵ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x11,0x11,0x11,0x11,0x15,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0x50,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41974 0xa3f6 "ꏶ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x09,0x11,0x11,0x17,0x11,0x11,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41975 0xa3f7 "ꏷ" */
+0x00,0x03,0x04,0x00,0x03,0x02,0x02,0x0a,0x0a,0x0a,0x0a,0x0a,0x02,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x00,
+/* 41976 0xa3f8 "ꏸ" */
+0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x0a,0x0a,0x0a,0x0a,0x0a,0x02,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x00,
+/* 41977 0xa3f9 "ꏹ" */
+0x00,0x00,0x00,0x0e,0x09,0x08,0x08,0x08,0x0b,0x08,0x08,0x08,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x80,0x80,0xe0,0x80,0x80,0x00,0xc0,0x00,0x00,0x00,
+/* 41978 0xa3fa "ꏺ" */
+0x00,0x03,0x04,0x00,0x00,0x01,0x09,0x11,0x11,0x17,0x11,0x11,0x09,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41979 0xa3fb "ꏻ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x09,0x11,0x11,0x17,0x11,0x11,0x09,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 41980 0xa3fc "ꏼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x23,0x24,0x1c,0x24,0x24,0x13,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x20,0xe0,0x20,0xa0,0xa0,0x20,0xe0,0x00,0x00,
+/* 41981 0xa3fd "ꏽ" */
+0x00,0x00,0x03,0x04,0x00,0x04,0x04,0x02,0x0a,0x09,0x0a,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x40,0x40,0x80,0xa0,0x20,0xa0,0x80,0x40,0x40,0x00,0x00,
+/* 41982 0xa3fe "ꏾ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x0a,0x09,0x0a,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0xa0,0x20,0xa0,0x80,0x40,0x40,0x00,0x00,
+/* 41983 0xa3ff "ꏿ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x11,0x11,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41984 0xa400 "ꐀ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x20,0x11,0x0a,0x07,0x0a,0x11,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xa4,0x24,0x18,0xf8,0x18,0x24,0xa4,0x80,0x00,0x00,
+/* 41985 0xa401 "ꐁ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x24,0x14,0x0c,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x88,0x88,0x50,0x20,0xf8,0x20,0x50,0x88,0x88,0x00,0x00,
+/* 41986 0xa402 "ꐂ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x24,0x14,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x88,0x88,0x50,0x20,0xf8,0x20,0x50,0x88,0x88,0x00,0x00,
+/* 41987 0xa403 "ꐃ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0a,0x07,0x0a,0x11,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x48,0x30,0xf8,0x30,0x48,0x48,0x00,0x00,0x00,
+/* 41988 0xa404 "ꐄ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x00,0x03,0x00,0x0b,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xe0,0x00,0x00,
+/* 41989 0xa405 "ꐅ" */
+0x00,0x03,0x04,0x00,0x10,0x10,0x10,0x11,0x10,0x1f,0x10,0x10,0x11,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,0x00,
+/* 41990 0xa406 "ꐆ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x11,0x10,0x1f,0x10,0x10,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,0x00,0x00,
+/* 41991 0xa407 "ꐇ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x11,0x10,0x1f,0x10,0x11,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0x10,0x10,0xf0,0x10,0x20,0xc0,0x00,0x00,
+/* 41992 0xa408 "ꐈ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x11,0x11,0x01,0x01,0x11,0x11,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 41993 0xa409 "ꐉ" */
+0x00,0x03,0x04,0x00,0x0e,0x19,0x15,0x11,0x11,0x17,0x11,0x15,0x19,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x20,0x50,0xd0,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 41994 0xa40a "ꐊ" */
+0x00,0x00,0x00,0x00,0x0e,0x19,0x15,0x11,0x11,0x17,0x11,0x15,0x19,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0xd0,0x50,0x20,0x00,0x00,0x00,0x00,
+/* 41995 0xa40b "ꐋ" */
+0x00,0x00,0x00,0x00,0x07,0x09,0x11,0x10,0x10,0x10,0x12,0x14,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x90,0x50,0x20,0xc0,0x00,0x00,
+/* 41996 0xa40c "ꐌ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xf0,0x80,0xf0,0x80,0xf0,0x80,0x80,0x00,0x00,0x00,
+/* 41997 0xa40d "ꐍ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x11,0x09,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41998 0xa40e "ꐎ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x11,0x09,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 41999 0xa40f "ꐏ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x0e,0x10,0x10,0x0b,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x90,0x90,0x90,0x10,0x10,0xd0,0x30,0x00,0x00,
+/* 42000 0xa410 "ꐐ" */
+0x00,0x03,0x04,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x12,0x0a,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x90,0xa0,0xc0,0x00,0x00,
+/* 42001 0xa411 "ꐑ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x12,0x0a,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x90,0xa0,0xc0,0x00,0x00,
+/* 42002 0xa412 "ꐒ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x09,0x05,0x03,0x03,0x05,0x09,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x88,0x48,0x28,0x18,0x00,0x00,0x00,
+/* 42003 0xa413 "ꐓ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x04,0x03,0x01,0x0d,0x0b,0x08,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42004 0xa414 "ꐔ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x04,0x03,0x01,0x0d,0x0b,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42005 0xa415 "ꐕ" */
+0x00,0x00,0x00,0x09,0x0a,0x09,0x04,0x03,0x01,0x0d,0x0b,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x20,0xa0,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42006 0xa416 "ꐖ" */
+0x03,0x04,0x00,0x18,0x14,0x13,0x13,0x15,0x19,0x01,0x09,0x05,0x03,0x05,0x09,0x00,
+0x80,0x40,0x00,0x30,0x50,0x90,0x90,0x50,0x30,0x00,0x20,0x40,0x80,0x40,0x20,0x00,
+/* 42007 0xa417 "ꐗ" */
+0x00,0x00,0x18,0x14,0x13,0x13,0x15,0x19,0x01,0x09,0x05,0x03,0x05,0x09,0x00,0x00,
+0x00,0x00,0x30,0x50,0x90,0x90,0x50,0x30,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0x00,
+/* 42008 0xa418 "ꐘ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x04,0x03,0x09,0x09,0x03,0x04,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x20,0x20,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 42009 0xa419 "ꐙ" */
+0x00,0x03,0x04,0x00,0x04,0x04,0x1f,0x04,0x04,0x04,0x04,0x1f,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0xf0,0x40,0x40,0x40,0x40,0xf0,0x40,0x40,0x00,0x00,
+/* 42010 0xa41a "ꐚ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x1f,0x04,0x04,0x04,0x04,0x1f,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xf0,0x40,0x40,0x40,0x40,0xf0,0x40,0x40,0x00,0x00,
+/* 42011 0xa41b "ꐛ" */
+0x00,0x00,0x00,0x18,0x04,0x1f,0x04,0x18,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42012 0xa41c "ꐜ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x04,0x03,0x01,0x05,0x05,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x40,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 42013 0xa41d "ꐝ" */
+0x00,0x03,0x04,0x00,0x18,0x24,0x04,0x04,0x03,0x0f,0x01,0x01,0x09,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0x30,0x48,0x40,0x40,0x80,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42014 0xa41e "ꐞ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x03,0x0f,0x01,0x01,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x40,0x80,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42015 0xa41f "ꐟ" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x04,0x03,0x01,0x09,0x09,0x09,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
+/* 42016 0xa420 "ꐠ" */
+0x03,0x04,0x00,0x18,0x04,0x12,0x12,0x12,0x04,0x18,0x03,0x04,0x09,0x09,0x00,0x00,
+0x80,0x40,0x00,0x30,0x40,0x90,0x90,0x90,0x40,0x30,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 42017 0xa421 "ꐡ" */
+0x00,0x00,0x00,0x18,0x04,0x12,0x12,0x12,0x04,0x18,0x03,0x04,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x30,0x40,0x90,0x90,0x90,0x40,0x30,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 42018 0xa422 "ꐢ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x08,0x14,0x14,0x08,0x01,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x10,0xe0,0x00,0x00,0xe0,0x10,0x08,0x08,0x00,0x00,
+/* 42019 0xa423 "ꐣ" */
+0x00,0x00,0x00,0x00,0x0c,0x0a,0x09,0x1c,0x2a,0x2a,0x08,0x1c,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0xc4,0xb4,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42020 0xa424 "ꐤ" */
+0x00,0x03,0x04,0x00,0x18,0x16,0x11,0x10,0x7c,0x10,0x7c,0x10,0x10,0x10,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42021 0xa425 "ꐥ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x7c,0x10,0x7c,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x8c,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42022 0xa426 "ꐦ" */
+0x00,0x00,0x00,0x18,0x04,0x02,0x02,0x02,0x04,0x18,0x03,0x04,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x30,0x40,0x80,0x80,0x80,0x40,0x30,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 42023 0xa427 "ꐧ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x01,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,
+/* 42024 0xa428 "ꐨ" */
+0x03,0x04,0x00,0x00,0x07,0x08,0x0f,0x08,0x07,0x01,0x01,0x02,0x04,0x04,0x00,0x00,
+0x80,0x40,0x00,0x10,0xf0,0x80,0xf0,0x80,0xf0,0x00,0xc0,0xa0,0x90,0x90,0x00,0x00,
+/* 42025 0xa429 "ꐩ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x0f,0x08,0x07,0x00,0x01,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x10,0xf0,0x80,0xf0,0x80,0xf0,0x80,0xc0,0xa0,0x90,0x90,0x00,0x00,
+/* 42026 0xa42a "ꐪ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x09,0x09,0x04,0x09,0x09,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42027 0xa42b "ꐫ" */
+0x00,0x03,0x04,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x01,0x02,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0xf0,0x80,0x80,0xf0,0x80,0xc0,0xa0,0x90,0x90,0x00,0x00,
+/* 42028 0xa42c "ꐬ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x01,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xf0,0x80,0x80,0xf0,0x80,0xc0,0xa0,0x90,0x90,0x00,0x00,
+/* 42029 0xa42d "ꐭ" */
+0x00,0x00,0x00,0x00,0x38,0x26,0x21,0x25,0x05,0x01,0x39,0x27,0x21,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0xc8,0x38,0x00,0x40,0x48,0x08,0xc8,0x38,0x00,0x00,
+/* 42030 0xa42e "ꐮ" */
+0x00,0x03,0x04,0x00,0x0e,0x04,0x04,0x04,0x03,0x01,0x07,0x01,0x09,0x06,0x00,0x00,
+0x00,0x80,0x40,0x00,0xe0,0x40,0x40,0x40,0x80,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 42031 0xa42f "ꐯ" */
+0x00,0x00,0x00,0x00,0x0e,0x04,0x04,0x04,0x03,0x01,0x07,0x01,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x40,0x40,0x40,0x80,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 42032 0xa430 "ꐰ" */
+0x00,0x00,0x0a,0x0a,0x0f,0x0a,0x0a,0x00,0x0a,0x0a,0x0f,0x0a,0x0a,0x00,0x00,0x00,
+0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42033 0xa431 "ꐱ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x80,0x80,0x80,0xf0,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42034 0xa432 "ꐲ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x09,0x07,0x01,0x01,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42035 0xa433 "ꐳ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x09,0x07,0x01,0x01,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42036 0xa434 "ꐴ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xf8,0x24,0x24,0x38,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 42037 0xa435 "ꐵ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x09,0x09,0x09,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x20,0x20,0x20,0x00,0xe0,0x00,0x00,
+/* 42038 0xa436 "ꐶ" */
+0x03,0x04,0x00,0x03,0x04,0x05,0x05,0x1e,0x15,0x14,0x05,0x05,0x04,0x03,0x00,0x00,
+0x80,0x40,0x00,0x80,0x40,0x40,0x40,0x50,0x50,0xf0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42039 0xa437 "ꐷ" */
+0x00,0x00,0x00,0x03,0x04,0x05,0x05,0x1e,0x15,0x14,0x05,0x05,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x50,0x50,0xf0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42040 0xa438 "ꐸ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x01,0x0f,0x01,0x05,0x15,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0xe0,0x00,0x40,0x50,0x10,0xe0,0x00,0x00,
+/* 42041 0xa439 "ꐹ" */
+0x00,0x03,0x04,0x00,0x06,0x05,0x04,0x04,0x07,0x04,0x00,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0xd0,0x40,0x40,0xc0,0x40,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42042 0xa43a "ꐺ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x07,0x04,0x00,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0xd0,0x40,0x40,0xc0,0x40,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42043 0xa43b "ꐻ" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x45,0x42,0x45,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x54,0x94,0x10,0x14,0x14,0x90,0x54,0x34,0x00,0x00,
+/* 42044 0xa43c "ꐼ" */
+0x00,0x00,0x03,0x04,0x00,0x60,0x50,0x48,0x45,0x42,0x45,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x30,0x54,0x92,0x12,0x1c,0x12,0x92,0x54,0x30,0x00,0x00,
+/* 42045 0xa43d "ꐽ" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x45,0x42,0x45,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x30,0x54,0x92,0x12,0x1c,0x12,0x92,0x54,0x30,0x00,0x00,
+/* 42046 0xa43e "ꐾ" */
+0x00,0x00,0x00,0x00,0x0e,0x01,0x02,0x02,0x0e,0x0b,0x0a,0x02,0x01,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x80,0x80,0xa0,0xa0,0xe0,0x80,0x00,0xe0,0x00,0x00,
+/* 42047 0xa43f "ꐿ" */
+0x03,0x04,0x00,0x01,0x02,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x80,0x40,0x00,0xe0,0x00,0x40,0x40,0x00,0xe0,0x00,0x40,0x40,0x00,0xe0,0x00,0x00,
+/* 42048 0xa440 "ꑀ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x40,0x40,0x00,0xe0,0x00,0x40,0x40,0x00,0xe0,0x00,0x00,
+/* 42049 0xa441 "ꑁ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x0f,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x20,0x10,0x90,0x10,0x20,0x00,0x00,0xc0,0x00,0x00,
+/* 42050 0xa442 "ꑂ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x03,0x18,0x20,0x4c,0x4b,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x58,0x40,0xf8,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 42051 0xa443 "ꑃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x0c,0x10,0x26,0x25,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x2c,0x20,0xfc,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,
+/* 42052 0xa444 "ꑄ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x08,0x06,0x01,0x00,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xd0,0x50,0x20,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 42053 0xa445 "ꑅ" */
+0x03,0x04,0x00,0x04,0x02,0x01,0x01,0x02,0x04,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x80,0x40,0x00,0x90,0xa0,0xc0,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42054 0xa446 "ꑆ" */
+0x00,0x00,0x00,0x04,0x02,0x01,0x01,0x02,0x04,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0x90,0xa0,0xc0,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42055 0xa447 "ꑇ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x01,0x01,0x01,0x01,0x01,0x09,0x05,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42056 0xa448 "ꑈ" */
+0x03,0x04,0x00,0x02,0x1a,0x06,0x02,0x1a,0x06,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x80,0x40,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42057 0xa449 "ꑉ" */
+0x00,0x00,0x00,0x02,0x1a,0x06,0x02,0x1a,0x06,0x00,0x18,0x16,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42058 0xa44a "ꑊ" */
+0x00,0x00,0x00,0x11,0x11,0x0f,0x01,0x0f,0x11,0x11,0x01,0x0d,0x0b,0x08,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0xe0,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42059 0xa44b "ꑋ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 42060 0xa44c "ꑌ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x1f,0x01,0x1f,0x01,0x1f,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0xf0,0x00,0xf0,0x00,0xf0,0x00,0x00,0x00,
+/* 42061 0xa44d "ꑍ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 42062 0xa44e "ꑎ" */
+0x00,0x00,0x00,0x00,0x60,0x12,0x0a,0x09,0x08,0x0f,0x08,0x09,0x12,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x48,0x50,0x90,0x10,0xf0,0x10,0x90,0x48,0x46,0x00,0x00,
+/* 42063 0xa44f "ꑏ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x49,0x2a,0x1a,0x00,0x00,
+0x00,0x80,0x40,0x00,0x86,0x88,0x90,0x10,0x10,0xf0,0x10,0x90,0x48,0x46,0x00,0x00,
+/* 42064 0xa450 "ꑐ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x49,0x2a,0x1a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x86,0x88,0x90,0x10,0x10,0xf0,0x10,0x90,0x48,0x46,0x00,0x00,
+/* 42065 0xa451 "ꑑ" */
+0x00,0x00,0x00,0x00,0x61,0x11,0x09,0x08,0x08,0x0f,0x08,0x09,0x11,0x61,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x10,0x20,0x20,0x20,0xe0,0x20,0x20,0x10,0x0c,0x00,0x00,
+/* 42066 0xa452 "ꑒ" */
+0x03,0x04,0x00,0x03,0x04,0x09,0x09,0x04,0x03,0x00,0x0f,0x00,0x01,0x06,0x0f,0x00,
+0x80,0x40,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0xf0,0x60,0x80,0x00,0xf0,0x00,
+/* 42067 0xa453 "ꑓ" */
+0x00,0x00,0x03,0x04,0x09,0x09,0x04,0x03,0x00,0x0f,0x00,0x01,0x06,0x0f,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0xf0,0x60,0x80,0x00,0xf0,0x00,0x00,
+/* 42068 0xa454 "ꑔ" */
+0x00,0x00,0x08,0x28,0x24,0x23,0x10,0x0f,0x21,0x21,0x3f,0x21,0x21,0x01,0x00,0x00,
+0x00,0x00,0x20,0x28,0x48,0x88,0x10,0xe0,0x08,0x08,0xf8,0x08,0x08,0x00,0x00,0x00,
+/* 42069 0xa455 "ꑕ" */
+0x00,0x00,0x00,0x00,0x31,0x09,0x05,0x05,0x05,0x05,0x05,0x05,0x09,0x31,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x18,0x00,0x00,
+/* 42070 0xa456 "ꑖ" */
+0x00,0x03,0x04,0x00,0x0d,0x0b,0x09,0x01,0x0d,0x0b,0x09,0x01,0x19,0x07,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0xa0,0x60,0x00,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 42071 0xa457 "ꑗ" */
+0x00,0x01,0x01,0x01,0x0d,0x0b,0x09,0x01,0x0d,0x0b,0x09,0x01,0x19,0x07,0x00,0x00,
+0x00,0x80,0x60,0x00,0x20,0xa0,0x60,0x00,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 42072 0xa458 "ꑘ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42073 0xa459 "ꑙ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x11,0x11,0x1f,0x11,0x11,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0xf0,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 42074 0xa45a "ꑚ" */
+0x00,0x03,0x04,0x00,0x08,0x08,0x0e,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x80,0x80,0x80,0xc0,0xb0,0x80,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 42075 0xa45b "ꑛ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x0e,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0xc0,0xb0,0x80,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 42076 0xa45c "ꑜ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xf0,0x80,0x80,0x80,0xf0,0x80,0x90,0x90,0x90,0x00,0x00,
+/* 42077 0xa45d "ꑝ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x04,0x02,0x01,0x02,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x40,0x80,0x00,0x80,0x40,0x00,0x00,
+/* 42078 0xa45e "ꑞ" */
+0x00,0x00,0x03,0x04,0x00,0x11,0x11,0x0a,0x0a,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x80,0x40,0x00,0x08,0x08,0x08,0x08,0x68,0x58,0x40,0x40,0x40,0x00,0x00,
+/* 42079 0xa45f "ꑟ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x0a,0x0a,0x04,0x0a,0x0a,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x68,0x58,0x40,0x40,0x40,0x00,0x00,
+/* 42080 0xa460 "ꑠ" */
+0x00,0x00,0x00,0x06,0x09,0x06,0x00,0x06,0x09,0x06,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 42081 0xa461 "ꑡ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x04,0x05,0x03,0x01,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 42082 0xa462 "ꑢ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x0e,0x04,0x04,0x04,0x15,0x15,0x08,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0xe0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42083 0xa463 "ꑣ" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x04,0x04,0x04,0x15,0x15,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42084 0xa464 "ꑤ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x14,0x14,0x08,0x14,0x14,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x68,0x58,0x40,0xe0,0x40,0xe0,0x40,0x00,0x00,
+/* 42085 0xa465 "ꑥ" */
+0x00,0x03,0x04,0x00,0x09,0x09,0x04,0x03,0x04,0x08,0x0f,0x08,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0x20,0x20,0x40,0x80,0x40,0x20,0xe0,0x20,0x40,0x80,0x00,0x00,
+/* 42086 0xa466 "ꑦ" */
+0x00,0x00,0x00,0x00,0x09,0x09,0x04,0x03,0x04,0x08,0x0f,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x40,0x20,0xe0,0x20,0x40,0x80,0x00,0x00,
+/* 42087 0xa467 "ꑧ" */
+0x00,0x00,0x00,0x11,0x11,0x0e,0x00,0x04,0x03,0x00,0x14,0x13,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x40,0x80,0x00,0x50,0x90,0x20,0xc0,0x00,0x00,
+/* 42088 0xa468 "ꑨ" */
+0x00,0x03,0x04,0x00,0x06,0x05,0x04,0x04,0x0e,0x15,0x15,0x0e,0x04,0x04,0x00,0x00,
+0x00,0x80,0x40,0x00,0x60,0x50,0xc8,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 42089 0xa469 "ꑩ" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x0e,0x15,0x15,0x0e,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x50,0xc8,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 42090 0xa46a "ꑪ" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x96,0x5a,0x32,0x5a,0x96,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x58,0xc6,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 42091 0xa46b "ꑫ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x03,0x01,0x0d,0x0b,0x09,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x00,0x20,0xa0,0x60,0x00,0x00,0xe0,0x00,0x00,
+/* 42092 0xa46c "ꑬ" */
+0x00,0x03,0x04,0x00,0x01,0x01,0x31,0x2d,0x23,0x21,0x21,0x01,0x01,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0x00,0x00,0x10,0x10,0x10,0xd0,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 42093 0xa46d "ꑭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x88,0x88,0x88,0xe8,0x98,0x80,0x80,0x80,0x00,0x00,
+/* 42094 0xa46e "ꑮ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xc0,0x88,0x88,0x88,0xe8,0x98,0x80,0x80,0x00,0x00,
+/* 42095 0xa46f "ꑯ" */
+0x00,0x03,0x04,0x00,0x11,0x11,0x11,0x09,0x07,0x31,0x2d,0x23,0x21,0x21,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0x10,0x20,0xc0,0x10,0x10,0x10,0xd0,0x30,0x00,0x00,
+/* 42096 0xa470 "ꑰ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x04,0x03,0x18,0x16,0x11,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0x90,0xe0,0x88,0x88,0x88,0xe8,0x98,0x00,0x00,
+/* 42097 0xa471 "ꑱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x24,0x3f,0x24,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0xc8,0xa8,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42098 0xa472 "ꑲ" */
+0x00,0x03,0x04,0x00,0x28,0x29,0x3a,0x28,0x28,0x00,0x00,0x03,0x02,0x02,0x00,0x00,
+0x00,0x80,0x40,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x84,0x64,0x18,0x00,0x00,
+/* 42099 0xa473 "ꑳ" */
+0x00,0x00,0x00,0x00,0x28,0x29,0x3a,0x28,0x28,0x00,0x00,0x03,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x04,0x04,0x84,0x64,0x18,0x00,0x00,
+/* 42100 0xa474 "ꑴ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x09,0x05,0x03,0x05,0x09,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x00,0x20,0x40,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 42101 0xa475 "ꑵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x38,0x15,0x15,0x38,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x64,0x54,0x4c,0xc0,0xe0,0x40,0x40,0xe0,0xc0,0x00,0x00,
+/* 42102 0xa476 "ꑶ" */
+0x00,0x03,0x04,0x00,0x00,0x03,0x02,0x02,0x02,0x1f,0x02,0x1f,0x02,0x02,0x00,0x00,
+0x00,0x80,0x40,0x00,0x10,0x10,0xd0,0x30,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 42103 0xa477 "ꑷ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x1f,0x02,0x1f,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0xd0,0x30,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 42104 0xa478 "ꑸ" */
+0x00,0x01,0x01,0x01,0x07,0x09,0x15,0x13,0x15,0x09,0x07,0x01,0x19,0x07,0x00,0x00,
+0x00,0xc0,0x30,0x00,0xc0,0x20,0x50,0x90,0x50,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 42105 0xa479 "ꑹ" */
+0x00,0x00,0x00,0x00,0x12,0x12,0x0c,0x00,0x0c,0x12,0x12,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0xc0,0xb0,0x80,0xc0,0xb0,0x80,0x80,0x00,0x00,
+/* 42106 0xa47a "ꑺ" */
+0x00,0x03,0x04,0x00,0x0c,0x12,0x12,0x1e,0x12,0x12,0x0c,0x00,0x06,0x01,0x00,0x00,
+0x00,0x80,0x40,0x00,0xc0,0xb0,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 42107 0xa47b "ꑻ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1e,0x12,0x12,0x0c,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0xe0,0x90,0x90,0x90,0x80,0x00,0x00,
+/* 42108 0xa47c "ꑼ" */
+0x00,0x00,0x00,0x02,0x0f,0x02,0x00,0x0f,0x10,0x10,0x1f,0x10,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xa0,0x20,0x20,0xa0,0x60,0x00,0x00,0x20,0x40,0x80,0x00,0x00,
+/* 42109 0xa47d "ꑽ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x00,0x12,0x12,0x0c,0x00,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xb0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42110 0xa47e "ꑾ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x08,0x08,0x0f,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x80,0x40,0x00,0xd0,0x30,0x10,0x00,0x80,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 42111 0xa47f "ꑿ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x0f,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x30,0x10,0x00,0x80,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 42112 0xa480 "ꒀ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x04,0x03,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x20,0x40,0x80,0x10,0x10,0xe0,0x00,0x00,
+/* 42113 0xa481 "ꒁ" */
+0x00,0x00,0x01,0x01,0x01,0x0d,0x0b,0x09,0x01,0x07,0x01,0x0d,0x0b,0x08,0x00,0x00,
+0x00,0x00,0x80,0x60,0x00,0x20,0xa0,0x60,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42114 0xa482 "ꒂ" */
+0x03,0x04,0x00,0x11,0x11,0x17,0x11,0x11,0x08,0x07,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x80,0x40,0x00,0x10,0x10,0xd0,0x10,0x10,0x20,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42115 0xa483 "ꒃ" */
+0x00,0x00,0x00,0x11,0x11,0x17,0x11,0x11,0x08,0x07,0x01,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xd0,0x10,0x10,0x20,0xc0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42116 0xa484 "ꒄ" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x0f,0x09,0x09,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xa0,0x60,0x00,0x00,
+/* 42117 0xa485 "ꒅ" */
+0x03,0x04,0x00,0x01,0x01,0x01,0x0d,0x0b,0x09,0x01,0x07,0x01,0x0d,0x03,0x00,0x00,
+0x80,0x40,0x00,0x80,0x60,0x00,0x20,0xa0,0x60,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 42118 0xa486 "ꒆ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x0d,0x0b,0x09,0x01,0x07,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x00,0x20,0xa0,0x60,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 42119 0xa487 "ꒇ" */
+0x00,0x00,0x00,0x09,0x09,0x04,0x03,0x00,0x0f,0x00,0x03,0x04,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0xe0,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 42120 0xa488 "ꒈ" */
+0x00,0x03,0x04,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x00,0x00,
+/* 42121 0xa489 "ꒉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x00,0x00,
+/* 42122 0xa48a "ꒊ" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x09,0x10,0x10,0x10,0x09,0x07,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x80,0x70,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 42123 0xa48b "ꒋ" */
+0x03,0x04,0x00,0x39,0x05,0x05,0x39,0x01,0x1f,0x01,0x39,0x05,0x05,0x39,0x00,0x00,
+0x80,0x40,0x00,0x38,0x40,0x40,0x38,0x00,0xf0,0x00,0x38,0x40,0x40,0x38,0x00,0x00,
+/* 42124 0xa48c "ꒌ" */
+0x00,0x00,0x00,0x39,0x05,0x05,0x39,0x01,0x1f,0x01,0x39,0x05,0x05,0x39,0x00,0x00,
+0x00,0x00,0x00,0x38,0x40,0x40,0x38,0x00,0xf0,0x00,0x38,0x40,0x40,0x38,0x00,0x00,
+/* 42125 0xa48d "꒍" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42126 0xa48e "꒎" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42127 0xa48f "꒏" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x73,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42128 0xa490 "꒐" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42129 0xa491 "꒑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,
+/* 42130 0xa492 "꒒" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x05,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,
+/* 42131 0xa493 "꒓" */
+0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42132 0xa494 "꒔" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42133 0xa495 "꒕" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42134 0xa496 "꒖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 42135 0xa497 "꒗" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x31,0x2d,0x23,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42136 0xa498 "꒘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc8,0xa8,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42137 0xa499 "꒙" */
+0x00,0x00,0x00,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42138 0xa49a "꒚" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,
+/* 42139 0xa49b "꒛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42140 0xa49c "꒜" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x00,0x00,0x00,0x00,0x0e,0x09,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x60,0x00,0x00,
+/* 42141 0xa49d "꒝" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd0,0x30,0x10,0x00,0x00,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 42142 0xa49e "꒞" */
+0x00,0x00,0x00,0x00,0x0e,0x09,0x08,0x08,0x08,0x08,0x08,0x08,0x09,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0xa0,0x60,0x00,0x00,0x00,0x00,0x60,0xa0,0x20,0x00,0x00,
+/* 42143 0xa49f "꒟" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42144 0xa4a0 "꒠" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42145 0xa4a1 "꒡" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42146 0xa4a2 "꒢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x00,0x00,
+/* 42147 0xa4a3 "꒣" */
+0x00,0x00,0x00,0x00,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42148 0xa4a4 "꒤" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 42149 0xa4a5 "꒥" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42150 0xa4a6 "꒦" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42151 0xa4a7 "꒧" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x08,0x08,0x08,0x08,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42152 0xa4a8 "꒨" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 42153 0xa4a9 "꒩" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42154 0xa4aa "꒪" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42155 0xa4ab "꒫" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42156 0xa4ac "꒬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42157 0xa4ad "꒭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0xa0,0x90,0x80,0xc0,0xa0,0x90,0x80,0x80,0x80,0x00,0x00,
+/* 42158 0xa4ae "꒮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0xc8,0xa8,0x98,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42159 0xa4af "꒯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 42160 0xa4b0 "꒰" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x01,0x02,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42161 0xa4b1 "꒱" */
+0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42162 0xa4b2 "꒲" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x04,0x04,0x03,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,0xe0,0x00,0x00,
+/* 42163 0xa4b3 "꒳" */
+0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42164 0xa4b4 "꒴" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x4c,0x34,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x44,0x64,0x58,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 42165 0xa4b5 "꒵" */
+0x00,0x00,0x00,0x00,0x1c,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42166 0xa4b6 "꒶" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0xb8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42167 0xa4b7 "꒷" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42168 0xa4b8 "꒸" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x90,0xa0,0xc0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42169 0xa4b9 "꒹" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x0f,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x20,0x20,0xc0,0x00,0x00,
+/* 42170 0xa4ba "꒺" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x60,0x60,0xa0,0x20,0x20,0xa0,0x60,0x60,0x90,0x00,0x00,
+/* 42171 0xa4bb "꒻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x03,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42172 0xa4bc "꒼" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x40,0x00,0x00,
+/* 42173 0xa4bd "꒽" */
+0x00,0x00,0x00,0x00,0x0c,0x02,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x80,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x20,0x00,0x00,
+/* 42174 0xa4be "꒾" */
+0x00,0x00,0x00,0x0f,0x08,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x20,0xe0,0x00,0x00,
+/* 42175 0xa4bf "꒿" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x22,0x21,0x22,0x24,0x28,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 42176 0xa4c0 "꓀" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 42177 0xa4c1 "꓁" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x02,0x01,0x02,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x88,0x48,0x28,0x18,0x00,0x00,
+/* 42178 0xa4c2 "꓂" */
+0x00,0x00,0x00,0x00,0x00,0x19,0x25,0x22,0x1d,0x00,0x1d,0x22,0x25,0x19,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x84,0x44,0x24,0x14,0x0c,0x00,0x00,
+/* 42179 0xa4c3 "꓃" */
+0x00,0x00,0x00,0x0f,0x08,0x04,0x04,0x02,0x02,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x40,0x40,0x80,0x80,0x00,0x80,0x80,0x40,0x40,0x00,0x00,
+/* 42180 0xa4c4 "꓄" */
+0x00,0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42181 0xa4c5 "꓅" */
+0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42182 0xa4c6 "꓆" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42183 0xa4c7 "꓇" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 42184 0xa4c8 "꓈" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 42185 0xa4c9 "꓉" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 42186 0xa4ca "꓊" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 42187 0xa4cb "꓋" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 42188 0xa4cc "꓌" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42189 0xa4cd "꓍" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42190 0xa4ce "꓎" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42191 0xa4cf "꓏" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42192 0xa4d0 "ꓐ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42193 0xa4d1 "ꓑ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42194 0xa4d2 "ꓒ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x3e,0x42,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42195 0xa4d3 "ꓓ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42196 0xa4d4 "ꓔ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42197 0xa4d5 "ꓕ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42198 0xa4d6 "ꓖ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x4e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42199 0xa4d7 "ꓗ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42200 0xa4d8 "ꓘ" */
+0x00,0x00,0x00,0x00,0x42,0x22,0x12,0x0a,0x06,0x06,0x0a,0x12,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42201 0xa4d9 "ꓙ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42202 0xa4da "ꓚ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42203 0xa4db "ꓛ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x02,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42204 0xa4dc "ꓜ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42205 0xa4dd "ꓝ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42206 0xa4de "ꓞ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x3e,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42207 0xa4df "ꓟ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42208 0xa4e0 "ꓠ" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x62,0x52,0x52,0x4a,0x4a,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42209 0xa4e1 "ꓡ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42210 0xa4e2 "ꓢ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42211 0xa4e3 "ꓣ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42212 0xa4e4 "ꓤ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x22,0x12,0x3e,0x42,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42213 0xa4e5 "ꓥ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x22,0x22,0x41,0x41,0x41,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42214 0xa4e6 "ꓦ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x22,0x22,0x22,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42215 0xa4e7 "ꓧ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42216 0xa4e8 "ꓨ" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x72,0x02,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42217 0xa4e9 "ꓩ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42218 0xa4ea "ꓪ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42219 0xa4eb "ꓫ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42220 0xa4ec "ꓬ" */
+0x00,0x00,0x00,0x00,0x41,0x41,0x22,0x22,0x14,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42221 0xa4ed "ꓭ" */
+0x00,0x00,0x00,0x00,0x3e,0x42,0x42,0x42,0x42,0x3e,0x42,0x42,0x42,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42222 0xa4ee "ꓮ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42223 0xa4ef "ꓯ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42224 0xa4f0 "ꓰ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42225 0xa4f1 "ꓱ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x3e,0x02,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42226 0xa4f2 "ꓲ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42227 0xa4f3 "ꓳ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42228 0xa4f4 "ꓴ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42229 0xa4f5 "ꓵ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42230 0xa4f6 "ꓶ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42231 0xa4f7 "ꓷ" */
+0x00,0x00,0x00,0x00,0x1e,0x22,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42232 0xa4f8 "ꓸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42233 0xa4f9 "ꓹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42234 0xa4fa "ꓺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42235 0xa4fb "ꓻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x62,0x02,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42236 0xa4fc "ꓼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x08,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42237 0xa4fd "ꓽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42238 0xa4fe "꓾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,0x00,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42239 0xa4ff "꓿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42240 0xa500 "ꔀ" */
+0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x19,0x25,0x25,0x19,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x00,0xe0,0x00,0x00,
+/* 42241 0xa501 "ꔁ" */
+0x00,0x00,0x00,0x0f,0x01,0x0f,0x01,0x19,0x25,0x19,0x01,0x0f,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xe0,0x00,0x30,0x48,0x30,0x00,0xe0,0x00,0xe0,0x00,0x00,
+/* 42242 0xa502 "ꔂ" */
+0x00,0x00,0x00,0x24,0x24,0x1a,0x01,0x01,0x02,0x02,0x02,0x01,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x20,0x48,0x90,0x60,0x00,0x00,
+/* 42243 0xa503 "ꔃ" */
+0x00,0x00,0x00,0x3e,0x08,0x08,0x04,0x03,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xa0,0x20,0xe0,0x20,0x20,0x20,0xf8,0x00,0x00,
+/* 42244 0xa504 "ꔄ" */
+0x00,0x00,0x00,0x3e,0x08,0x3e,0x04,0x03,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xa0,0x20,0xe0,0x20,0xf8,0x20,0xf8,0x00,0x00,
+/* 42245 0xa505 "ꔅ" */
+0x00,0x00,0x00,0x38,0x44,0x47,0x45,0x39,0x01,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42246 0xa506 "ꔆ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x13,0x01,0x39,0x45,0x47,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x90,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x00,
+/* 42247 0xa507 "ꔇ" */
+0x00,0x00,0x00,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x60,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0xf8,0x00,0x00,
+/* 42248 0xa508 "ꔈ" */
+0x00,0x00,0x00,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x60,0x60,0xa0,0x20,0x20,0x20,0xa8,0x20,0x20,0xf8,0x00,0x00,
+/* 42249 0xa509 "ꔉ" */
+0x00,0x00,0x00,0x1f,0x01,0x01,0x05,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42250 0xa50a "ꔊ" */
+0x00,0x00,0x00,0x1f,0x01,0x01,0x05,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x40,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42251 0xa50b "ꔋ" */
+0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42252 0xa50c "ꔌ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42253 0xa50d "ꔍ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x01,0x01,0x01,0x07,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0xc0,0x00,0xc0,0x00,0x00,
+/* 42254 0xa50e "ꔎ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0x78,0x40,0x40,0x40,0x78,0x00,0x00,
+/* 42255 0xa50f "ꔏ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xf8,0x40,0x40,0x40,0x78,0x40,0x40,0x40,0x78,0x00,0x00,
+/* 42256 0xa510 "ꔐ" */
+0x00,0x00,0x00,0x49,0x49,0x37,0x01,0x01,0x01,0x03,0x05,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x54,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42257 0xa511 "ꔑ" */
+0x00,0x00,0x00,0x49,0x49,0x37,0x01,0x01,0x01,0x03,0x05,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x50,0x54,0xa8,0x00,0x20,0x00,0x00,0x00,0x00,
+/* 42258 0xa512 "ꔒ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x48,0x78,0x48,0x40,0x40,0x40,0x00,0x00,
+/* 42259 0xa513 "ꔓ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x48,0x78,0x48,0x40,0x40,0x10,0xe0,0x00,0x00,
+/* 42260 0xa514 "ꔔ" */
+0x00,0x00,0x00,0x06,0x0a,0x12,0x22,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 42261 0xa515 "ꔕ" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x08,0x00,0x00,
+/* 42262 0xa516 "ꔖ" */
+0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42263 0xa517 "ꔗ" */
+0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0xe0,0x00,0x00,
+/* 42264 0xa518 "ꔘ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x00,0x01,0x01,0x01,0x00,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x00,0x00,
+/* 42265 0xa519 "ꔙ" */
+0x00,0x00,0x00,0x10,0x1f,0x10,0x00,0x01,0x01,0x01,0x00,0x10,0x1f,0x10,0x00,0x00,
+0x00,0x00,0x00,0x10,0xf0,0x10,0x00,0x00,0x00,0x00,0x00,0x10,0xf0,0x10,0x00,0x00,
+/* 42266 0xa51a "ꔚ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x3e,0x3e,0x3e,0x3e,0x3e,0x1c,0x48,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0xf8,0xf8,0xf8,0xf8,0xf8,0x70,0x24,0xd8,0x00,0x00,
+/* 42267 0xa51b "ꔛ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x22,0x14,0x48,0x37,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x50,0x24,0xd8,0x00,0x00,
+/* 42268 0xa51c "ꔜ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x3f,0x20,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xe0,0x08,0xe0,0x00,0x40,0x00,0x00,0x00,0x00,
+/* 42269 0xa51d "ꔝ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xe8,0x00,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 42270 0xa51e "ꔞ" */
+0x00,0x00,0x00,0xa0,0xa0,0xa0,0xa4,0xaa,0xaa,0xaa,0xa4,0xfb,0xa0,0xa0,0x00,0x00,
+0x00,0x00,0x00,0x0a,0x0a,0x0a,0x4a,0xaa,0xaa,0xaa,0x4a,0xbe,0x0a,0x0a,0x00,0x00,
+/* 42271 0xa51f "ꔟ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x2c,0x32,0x21,0x22,0x22,0x22,0x21,0x20,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x68,0x98,0x08,0x88,0x88,0x88,0x08,0x08,0x00,0x00,
+/* 42272 0xa520 "ꔠ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x3f,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42273 0xa521 "ꔡ" */
+0x00,0x00,0x00,0x06,0x09,0x0a,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x60,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x78,0x00,0x00,
+/* 42274 0xa522 "ꔢ" */
+0x00,0x00,0x00,0x08,0x14,0x22,0x09,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x10,0x28,0x44,0x90,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42275 0xa523 "ꔣ" */
+0x00,0x00,0x00,0x08,0x00,0x1c,0x22,0x22,0x22,0x22,0x22,0x14,0x48,0x37,0x00,0x00,
+0x00,0x00,0x00,0x20,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x50,0x24,0xd8,0x00,0x00,
+/* 42276 0xa524 "ꔤ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x48,0x78,0x48,0x40,0x40,0x40,0xf0,0x00,0x00,
+/* 42277 0xa525 "ꔥ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x50,0x44,0x7c,0x44,0x50,0x40,0x40,0xf0,0x00,0x00,
+/* 42278 0xa526 "ꔦ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x04,0x07,0x04,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x44,0xfc,0x44,0x40,0x40,0x40,0xf0,0x00,0x00,
+/* 42279 0xa527 "ꔧ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x01,0x02,0x02,0x01,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x40,0x40,0x80,0x00,0x20,0xc0,0x00,0x00,
+/* 42280 0xa528 "ꔨ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x12,0x12,0x0d,0x00,0x00,0x05,0x02,0x01,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0xc0,0x70,0xc8,0x48,0x30,0x00,0x00,
+/* 42281 0xa529 "ꔩ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x12,0x12,0x0d,0x00,0x00,0x05,0x02,0x01,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x40,0xc0,0x70,0xca,0x32,0x0c,0x00,0x00,
+/* 42282 0xa52a "ꔪ" */
+0x00,0x00,0x00,0x0e,0x0f,0x0f,0x0f,0x0e,0x0c,0x0e,0x0f,0x0f,0x0f,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0xe0,0x80,0x00,0x00,0x00,0x80,0xe0,0x80,0x00,0x00,0x00,
+/* 42283 0xa52b "ꔫ" */
+0x00,0x00,0x00,0x30,0x49,0x3e,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x8c,0x52,0x3c,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x00,0x00,
+/* 42284 0xa52c "ꔬ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0a,0x0f,0x0a,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0xf0,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 42285 0xa52d "ꔭ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0a,0x0f,0x0a,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x10,0xf0,0x10,0x50,0x00,0x00,0x00,0x00,0x00,
+/* 42286 0xa52e "ꔮ" */
+0x00,0x00,0x00,0x03,0x0d,0x11,0x13,0x24,0x24,0x23,0x14,0x18,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x90,0x48,0x48,0x88,0x50,0x30,0x60,0x80,0x00,0x00,
+/* 42287 0xa52f "ꔯ" */
+0x00,0x00,0x00,0x3f,0x01,0x01,0x05,0x01,0x0f,0x01,0x05,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x00,0x00,0x40,0x00,0xe0,0x00,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 42288 0xa530 "ꔰ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x05,0x01,0x3f,0x01,0x05,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xf8,0x00,0x40,0x00,0x00,0x00,0x00,0x00,
+/* 42289 0xa531 "ꔱ" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x1e,0x10,0x10,0x10,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 42290 0xa532 "ꔲ" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x11,0x1e,0x10,0x11,0x11,0x0e,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x10,0x10,0xe0,0x00,0x10,0x10,0xe0,0x80,0x00,0x00,0x00,
+/* 42291 0xa533 "ꔳ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x80,0x80,0x10,0x00,0x24,0x04,0x88,0x70,0x00,0x00,
+/* 42292 0xa534 "ꔴ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x88,0x80,0x10,0x00,0x24,0x04,0x88,0x70,0x00,0x00,
+/* 42293 0xa535 "ꔵ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x09,0x0a,0x0c,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x50,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42294 0xa536 "ꔶ" */
+0x00,0x00,0x00,0x08,0x0a,0x08,0x09,0x0a,0x0c,0x08,0x0a,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x50,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42295 0xa537 "ꔷ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x07,0x03,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xe0,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 42296 0xa538 "ꔸ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x07,0x03,0x01,0x00,0x07,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xe0,0xc0,0x80,0x00,0x10,0xe0,0x00,0x00,
+/* 42297 0xa539 "ꔹ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x17,0x03,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xe0,0xe8,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 42298 0xa53a "ꔺ" */
+0x00,0x00,0x00,0x01,0x02,0x01,0x44,0x45,0x3b,0x01,0x00,0x01,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa2,0x22,0xdc,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 42299 0xa53b "ꔻ" */
+0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x14,0x1f,0x14,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x28,0xe8,0x28,0x28,0x00,0x00,0x00,0x00,0x00,
+/* 42300 0xa53c "ꔼ" */
+0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x14,0x1f,0x14,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0x28,0xe8,0x28,0xa8,0x00,0x00,0x00,0x00,0x00,
+/* 42301 0xa53d "ꔽ" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x01,0x18,0x24,0x18,0x01,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x80,0x00,0x80,0x60,0x10,0x60,0x80,0x00,0x80,0x60,0x00,0x00,
+/* 42302 0xa53e "ꔾ" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x01,0x18,0x24,0x18,0x01,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x80,0x00,0x80,0x60,0x14,0x60,0x80,0x00,0x80,0x60,0x00,0x00,
+/* 42303 0xa53f "ꔿ" */
+0x00,0x00,0x00,0x03,0x04,0x0f,0x08,0x08,0x08,0x09,0x0a,0x0c,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xc0,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42304 0xa540 "ꕀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4c,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x64,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42305 0xa541 "ꕁ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x04,0x4c,0x33,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x40,0x64,0x98,0x00,0x00,0x00,0x00,0x00,
+/* 42306 0xa542 "ꕂ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x04,0x4c,0x33,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x64,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42307 0xa543 "ꕃ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x08,0x08,0x09,0x0a,0x0c,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42308 0xa544 "ꕄ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x08,0x08,0x09,0x0a,0x0c,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0xa0,0x20,0xc0,0x00,0x00,
+/* 42309 0xa545 "ꕅ" */
+0x00,0x00,0x00,0x24,0x24,0x1b,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0xa8,0x88,0xf8,0x88,0xa8,0x80,0x00,0x00,0x00,
+/* 42310 0xa546 "ꕆ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x21,0x21,0x21,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x38,0x40,0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x40,0x38,0x00,0x00,
+/* 42311 0xa547 "ꕇ" */
+0x00,0x00,0x00,0x07,0x00,0x07,0x04,0x04,0x05,0x06,0x00,0x03,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0xe0,0x00,0x30,0xd0,0x10,0x10,0xf0,0x00,0xf0,0x00,0x00,
+/* 42312 0xa548 "ꕈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x08,0x00,0x00,
+/* 42313 0xa549 "ꕉ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x01,0x05,0x01,0x05,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x40,0x00,0x40,0x00,0x00,0x00,0x00,
+/* 42314 0xa54a "ꕊ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x22,0x21,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x88,0x08,0x90,0x60,0x00,0x00,
+/* 42315 0xa54b "ꕋ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x04,0x22,0x21,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x44,0x40,0x40,0x88,0x08,0x90,0x64,0x00,0x00,
+/* 42316 0xa54c "ꕌ" */
+0x00,0x00,0x00,0x44,0x44,0x4e,0x35,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x22,0x22,0x72,0xac,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42317 0xa54d "ꕍ" */
+0x00,0x00,0x00,0x00,0x01,0x44,0x44,0x4e,0x37,0x04,0x04,0x05,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x44,0x44,0xe4,0xd8,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 42318 0xa54e "ꕎ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x80,0x80,0x00,0x00,0x04,0x04,0x88,0x70,0x00,0x00,
+/* 42319 0xa54f "ꕏ" */
+0x00,0x00,0x00,0x24,0x24,0x1b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0xb0,0xc8,0x80,0xb0,0xc8,0x00,0x00,
+/* 42320 0xa550 "ꕐ" */
+0x00,0x00,0x00,0x22,0x22,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0xa8,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42321 0xa551 "ꕑ" */
+0x00,0x00,0x00,0x38,0x44,0x42,0x42,0x32,0x0f,0x02,0x02,0x04,0x08,0x70,0x00,0x00,
+0x00,0x00,0x00,0x0e,0x10,0x20,0x40,0x40,0xf0,0x4c,0x42,0x42,0x22,0x1c,0x00,0x00,
+/* 42322 0xa552 "ꕒ" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x22,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x20,0x3c,0x24,0x24,0x24,0x3c,0x20,0x20,0xe0,0x00,0x00,
+/* 42323 0xa553 "ꕓ" */
+0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x24,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x88,0x88,0xb0,0x80,0x80,0xf0,0x08,0x08,0x30,0x00,0x00,
+/* 42324 0xa554 "ꕔ" */
+0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0xf0,0x00,0x00,
+/* 42325 0xa555 "ꕕ" */
+0x00,0x00,0x03,0x0c,0x18,0x14,0x22,0x21,0x22,0x14,0x18,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x80,0x60,0x30,0x50,0x88,0x08,0x88,0x50,0x30,0x60,0x80,0x00,0x00,0x00,
+/* 42326 0xa556 "ꕖ" */
+0x00,0x00,0x00,0x01,0x01,0x02,0x12,0x04,0x04,0x08,0x08,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x90,0x40,0x40,0x20,0x20,0x10,0x10,0xf0,0x00,0x00,
+/* 42327 0xa557 "ꕗ" */
+0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 42328 0xa558 "ꕘ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x01,0x01,0x01,0x01,0x01,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x00,
+/* 42329 0xa559 "ꕙ" */
+0x00,0x00,0x00,0x10,0x11,0x12,0x10,0x10,0x1f,0x10,0x10,0x12,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x08,0x70,0x40,0xc0,0x40,0x70,0x08,0x08,0xf0,0x00,0x00,
+/* 42330 0xa55a "ꕚ" */
+0x00,0x00,0x00,0x11,0x11,0x13,0x0d,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42331 0xa55b "ꕛ" */
+0x00,0x00,0x00,0x17,0x11,0x13,0x0d,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0xd0,0x10,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42332 0xa55c "ꕜ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x11,0x11,0x12,0x0c,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x98,0x68,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 42333 0xa55d "ꕝ" */
+0x00,0x00,0x00,0x00,0x02,0x00,0x22,0x22,0x25,0x18,0x00,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x14,0x14,0x14,0x14,0x14,0x34,0xd4,0x14,0x14,0x14,0x14,0x00,0x00,
+/* 42334 0xa55e "ꕞ" */
+0x00,0x00,0x00,0x0a,0x0a,0x0a,0x0b,0x0a,0x0a,0x0b,0x0a,0x0a,0x0a,0x0a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42335 0xa55f "ꕟ" */
+0x00,0x00,0x00,0x0a,0x0a,0x0a,0x0b,0x0a,0x0a,0x0b,0x0a,0x02,0x07,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 42336 0xa560 "ꕠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x30,0x08,0x08,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 42337 0xa561 "ꕡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x22,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x30,0x88,0x08,0xf0,0x20,0x24,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 42338 0xa562 "ꕢ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 42339 0xa563 "ꕣ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0f,0x03,0x04,0x04,0x14,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0xe0,0x80,0x40,0x40,0x50,0x80,0x00,0x00,0x00,
+/* 42340 0xa564 "ꕤ" */
+0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x0f,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 42341 0xa565 "ꕥ" */
+0x00,0x00,0x00,0x01,0x00,0x0e,0x11,0x11,0x4f,0x11,0x11,0x0e,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0xe4,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 42342 0xa566 "ꕦ" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x01,0x07,0x19,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0xc0,0x40,0x80,0x00,0x00,0x30,0x48,0x88,0x88,0x70,0x00,0x00,
+/* 42343 0xa567 "ꕧ" */
+0x00,0x00,0x00,0x1f,0x03,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x80,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x00,0x00,
+/* 42344 0xa568 "ꕨ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x1f,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0xf0,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,0x00,
+/* 42345 0xa569 "ꕩ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x48,0x49,0x37,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x80,0x80,0x00,0x00,0x04,0x04,0x88,0x70,0x00,0x00,
+/* 42346 0xa56a "ꕪ" */
+0x00,0x00,0x00,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42347 0xa56b "ꕫ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x01,0x01,0x02,0x0c,0x10,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x00,
+/* 42348 0xa56c "ꕬ" */
+0x00,0x00,0x00,0x1f,0x22,0x22,0x22,0x22,0x1f,0x22,0x22,0x22,0x22,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x88,0x88,0x88,0x88,0xf0,0x88,0x88,0x88,0x88,0xf0,0x00,0x00,
+/* 42349 0xa56d "ꕭ" */
+0x00,0x00,0x00,0x44,0x44,0x4e,0x35,0x04,0x04,0x04,0x44,0x44,0x4a,0x31,0x00,0x00,
+0x00,0x00,0x00,0x22,0x22,0x72,0xac,0x20,0x20,0x20,0x22,0x22,0x52,0x8c,0x00,0x00,
+/* 42350 0xa56e "ꕮ" */
+0x00,0x00,0x00,0x30,0x48,0x44,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x18,0x24,0x44,0xf8,0x40,0x40,0x40,0x40,0x20,0x20,0x10,0x00,0x00,
+/* 42351 0xa56f "ꕯ" */
+0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42352 0xa570 "ꕰ" */
+0x00,0x00,0x00,0x44,0x44,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x40,0x40,0x7c,0x44,0x44,0x44,0x44,0x7c,0x00,0x00,
+/* 42353 0xa571 "ꕱ" */
+0x00,0x00,0x00,0x10,0x1f,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x88,0xf8,0x88,0x80,0x80,0x80,0xc0,0x00,0x00,
+/* 42354 0xa572 "ꕲ" */
+0x00,0x00,0x00,0x10,0x1f,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0xa0,0x88,0xf8,0x88,0xa0,0x80,0x80,0xc0,0x00,0x00,
+/* 42355 0xa573 "ꕳ" */
+0x00,0x00,0x00,0x10,0x1f,0x10,0x00,0x08,0x0f,0x08,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x88,0xf8,0x88,0x80,0x80,0x80,0xc0,0x00,0x00,
+/* 42356 0xa574 "ꕴ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xf8,0x88,0x80,0x80,0x80,0xc0,0x00,0x00,
+/* 42357 0xa575 "ꕵ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x08,0xf8,0x88,0xa0,0x80,0x80,0xc0,0x00,0x00,
+/* 42358 0xa576 "ꕶ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x08,0x0c,0x0b,0x00,0x00,
+0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 42359 0xa577 "ꕷ" */
+0x00,0x00,0x00,0x03,0x04,0x09,0x08,0x04,0x03,0x00,0x00,0x09,0x0c,0x0b,0x00,0x00,
+0x00,0x00,0x00,0x90,0x50,0x30,0x10,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 42360 0xa578 "ꕸ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x10,0x12,0x10,0x11,0x16,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x60,0x00,0x00,0x60,0x90,0x10,0x60,0x00,0x00,
+/* 42361 0xa579 "ꕹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x7c,0x7f,0x7c,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x3e,0xfe,0x3c,0x1c,0x00,0x00,0x00,0x00,0x00,
+/* 42362 0xa57a "ꕺ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 42363 0xa57b "ꕻ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x28,0x04,0x04,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x28,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 42364 0xa57c "ꕼ" */
+0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x00,0x00,
+/* 42365 0xa57d "ꕽ" */
+0x00,0x00,0x00,0x21,0x21,0x23,0x1d,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x88,0x70,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42366 0xa57e "ꕾ" */
+0x00,0x00,0x00,0x21,0x21,0x23,0x1d,0x01,0x01,0x0f,0x01,0x0f,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x88,0x70,0x00,0x00,0xe0,0x00,0xe0,0x00,0x00,0x00,0x00,
+/* 42367 0xa57f "ꕿ" */
+0x00,0x00,0x00,0x00,0x11,0x02,0x02,0x02,0x12,0x02,0x02,0x02,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42368 0xa580 "ꖀ" */
+0x00,0x00,0x00,0x00,0x11,0x02,0x02,0x02,0x12,0x02,0x02,0x02,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42369 0xa581 "ꖁ" */
+0x00,0x00,0x00,0x44,0x44,0x4e,0x35,0x04,0x04,0x04,0x04,0x04,0x04,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x22,0x22,0x72,0xac,0x20,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
+/* 42370 0xa582 "ꖂ" */
+0x00,0x00,0x00,0x44,0x44,0x4e,0x35,0x04,0x04,0x04,0x04,0x04,0x04,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x22,0x22,0x72,0xac,0x20,0x20,0xa0,0x20,0x20,0x20,0x70,0x00,0x00,
+/* 42371 0xa583 "ꖃ" */
+0x00,0x00,0x00,0x24,0x24,0x1b,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x98,0xa8,0xc8,0x88,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 42372 0xa584 "ꖄ" */
+0x00,0x00,0x00,0x24,0x24,0x1b,0x00,0x01,0x02,0x04,0x04,0x03,0x1c,0x23,0x00,0x00,
+0x00,0x00,0x00,0x80,0x98,0xa8,0xc8,0x88,0x80,0x80,0x80,0x00,0x40,0x80,0x00,0x00,
+/* 42373 0xa585 "ꖅ" */
+0x00,0x00,0x00,0x0f,0x01,0x41,0x41,0x41,0x7f,0x41,0x41,0x41,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0x00,0xe0,0x00,0x00,
+/* 42374 0xa586 "ꖆ" */
+0x00,0x00,0x00,0x24,0x24,0x1b,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0xf0,0xa8,0xa8,0x90,0x80,0x00,0x00,0x00,
+/* 42375 0xa587 "ꖇ" */
+0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0xf8,0x00,0x00,
+/* 42376 0xa588 "ꖈ" */
+0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0xe0,0x20,0x20,0xa8,0x20,0xf8,0x00,0x00,
+/* 42377 0xa589 "ꖉ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x02,0x01,0x02,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42378 0xa58a "ꖊ" */
+0x00,0x00,0x00,0x03,0x04,0x14,0x04,0x02,0x01,0x02,0x04,0x14,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x50,0x40,0x80,0x00,0x80,0x40,0x50,0x40,0x80,0x00,0x00,
+/* 42379 0xa58b "ꖋ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x09,0x01,0x01,0x01,0x09,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,
+/* 42380 0xa58c "ꖌ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x09,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42381 0xa58d "ꖍ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x12,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x48,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+/* 42382 0xa58e "ꖎ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 42383 0xa58f "ꖏ" */
+0x00,0x00,0x00,0x30,0x48,0x44,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x18,0x24,0x44,0xf8,0x40,0x40,0x40,0x40,0x20,0x20,0xf0,0x00,0x00,
+/* 42384 0xa590 "ꖐ" */
+0x00,0x00,0x00,0x30,0x48,0x44,0x3f,0x04,0x04,0x04,0x08,0x08,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x18,0x24,0x44,0xf8,0x40,0x40,0x40,0x20,0x28,0xf8,0x08,0x00,0x00,
+/* 42385 0xa591 "ꖑ" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0xf8,0x88,0x88,0x88,0x88,0x88,0x08,0x08,0x00,0x00,
+/* 42386 0xa592 "ꖒ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x38,0x7c,0x7f,0x7c,0x38,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x7c,0xfc,0x7c,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 42387 0xa593 "ꖓ" */
+0x00,0x00,0x00,0x49,0x49,0x37,0x01,0x01,0x01,0x03,0x05,0x09,0x09,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x78,0x84,0x24,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 42388 0xa594 "ꖔ" */
+0x00,0x00,0x00,0x0f,0x01,0x01,0x09,0x01,0x01,0x01,0x09,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x20,0x00,0x00,0x00,0x20,0x00,0x00,0xe0,0x00,0x00,
+/* 42389 0xa595 "ꖕ" */
+0x00,0x00,0x00,0x21,0x21,0x23,0x1d,0x01,0x01,0x05,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x88,0x70,0x00,0x00,0xf4,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 42390 0xa596 "ꖖ" */
+0x00,0x00,0x00,0x42,0x42,0x47,0x3a,0x02,0x02,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0xe8,0x20,0xf8,0x20,0xf8,0x00,0x00,
+/* 42391 0xa597 "ꖗ" */
+0x00,0x00,0x00,0x42,0x42,0x47,0x3a,0x02,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0xe0,0x20,0x20,0x20,0xf8,0x00,0x00,
+/* 42392 0xa598 "ꖘ" */
+0x00,0x00,0x00,0x03,0x0c,0x10,0x13,0x24,0x24,0x22,0x91,0x92,0x4c,0x33,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x90,0x48,0x48,0x88,0x12,0x92,0x64,0x98,0x00,0x00,
+/* 42393 0xa599 "ꖙ" */
+0x00,0x00,0x00,0x21,0x21,0x23,0x1d,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x88,0x70,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 42394 0xa59a "ꖚ" */
+0x00,0x00,0x00,0x42,0x42,0x47,0x3a,0x02,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0xe0,0x00,0x00,0xe0,0x20,0xf8,0x20,0xf8,0x00,0x00,
+/* 42395 0xa59b "ꖛ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x3f,0x04,0x04,0x04,0x3f,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x00,0x00,
+/* 42396 0xa59c "ꖜ" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42397 0xa59d "ꖝ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0a,0x07,0x0a,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x10,0x00,0x00,0x00,0x00,
+/* 42398 0xa59e "ꖞ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0a,0x07,0x0a,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0xf0,0x08,0x48,0x10,0x00,0x00,0x00,0x00,
+/* 42399 0xa59f "ꖟ" */
+0x00,0x00,0x00,0x10,0x29,0x2b,0x1d,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42400 0xa5a0 "ꖠ" */
+0x00,0x00,0x00,0x10,0x29,0x2b,0x1d,0x01,0x01,0x01,0x05,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x88,0x70,0x00,0x00,0x00,0x40,0x00,0x00,0xe0,0x00,0x00,
+/* 42401 0xa5a1 "ꖡ" */
+0x00,0x00,0x00,0x10,0x29,0x2b,0x1d,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x28,0xa8,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42402 0xa5a2 "ꖢ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x39,0x45,0x47,0x45,0x39,0x01,0x02,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x60,0x80,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 42403 0xa5a3 "ꖣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x47,0x46,0x3a,0x02,0x04,0x1b,0x00,0x00,
+0x00,0x00,0x00,0x18,0x20,0x40,0x5c,0x62,0xe2,0x62,0x5c,0x40,0x80,0x00,0x00,0x00,
+/* 42404 0xa5a4 "ꖤ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x07,0x02,0x02,0x03,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x40,0x00,0xe0,0x00,0x40,0x00,0x00,0x00,
+/* 42405 0xa5a5 "ꖥ" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0e,0x04,0x04,0x07,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0x20,0xe0,0x20,0xa0,0x00,0x00,0x00,
+/* 42406 0xa5a6 "ꖦ" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x13,0x13,0x15,0x15,0x19,0x00,0x00,
+0x00,0x00,0x00,0x30,0x50,0x50,0x90,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 42407 0xa5a7 "ꖧ" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x51,0x13,0x13,0x15,0x15,0x19,0x00,0x00,
+0x00,0x00,0x00,0x30,0x50,0x50,0x90,0x90,0x14,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+/* 42408 0xa5a8 "ꖨ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+/* 42409 0xa5a9 "ꖩ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x00,0x00,0x07,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x10,0xe0,0x00,0x00,
+/* 42410 0xa5aa "ꖪ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x12,0x10,0x1f,0x10,0x12,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+/* 42411 0xa5ab "ꖫ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x48,0x70,0x40,0x00,0x00,
+/* 42412 0xa5ac "ꖬ" */
+0x00,0x00,0x00,0x0c,0x14,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x10,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42413 0xa5ad "ꖭ" */
+0x00,0x00,0x00,0x0c,0x14,0x04,0x04,0x04,0x00,0x00,0x00,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x10,0x00,0x80,0x80,0xa0,0x80,0x80,0x00,0x00,
+/* 42414 0xa5ae "ꖮ" */
+0x00,0x00,0x00,0x0c,0x14,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x10,0x00,0x80,0x80,0x80,0x80,0xe0,0x00,0x00,
+/* 42415 0xa5af "ꖯ" */
+0x00,0x00,0x00,0x0c,0x14,0x04,0x04,0x04,0x00,0x00,0x00,0x02,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0x30,0x50,0x10,0x10,0x10,0x00,0x80,0x80,0xa0,0x80,0xe0,0x00,0x00,
+/* 42416 0xa5b0 "ꖰ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x15,0x11,0x1f,0x11,0x15,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+/* 42417 0xa5b1 "ꖱ" */
+0x00,0x00,0x00,0x00,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x11,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+/* 42418 0xa5b2 "ꖲ" */
+0x00,0x00,0x00,0x00,0x00,0x15,0x15,0x15,0x1f,0x15,0x15,0x15,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+/* 42419 0xa5b3 "ꖳ" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x15,0x14,0x1f,0x14,0x15,0x14,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+/* 42420 0xa5b4 "ꖴ" */
+0x00,0x00,0x00,0x03,0x0c,0x10,0x10,0x20,0x21,0x20,0x10,0x10,0x0c,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x10,0x08,0x08,0x08,0x10,0x10,0x60,0x80,0x00,0x00,
+/* 42421 0xa5b5 "ꖵ" */
+0x00,0x00,0x00,0x03,0x04,0x05,0x04,0x03,0x01,0x01,0x05,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x40,0x00,0x00,0xc0,0x00,0x00,
+/* 42422 0xa5b6 "ꖶ" */
+0x00,0x00,0x00,0x03,0x04,0x05,0x04,0x03,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42423 0xa5b7 "ꖷ" */
+0x00,0x00,0x00,0x04,0x08,0x08,0x04,0x03,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42424 0xa5b8 "ꖸ" */
+0x00,0x00,0x00,0x1f,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,
+/* 42425 0xa5b9 "ꖹ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x09,0x08,0x08,0x09,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 42426 0xa5ba "ꖺ" */
+0x00,0x00,0x00,0x11,0x11,0x1e,0x10,0x11,0x11,0x1e,0x10,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x10,0x10,0xe0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42427 0xa5bb "ꖻ" */
+0x00,0x00,0x00,0x38,0x04,0x02,0x02,0x02,0x22,0x02,0x02,0x02,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x38,0x40,0x80,0x80,0x80,0x90,0x80,0x80,0x80,0x40,0x38,0x00,0x00,
+/* 42428 0xa5bc "ꖼ" */
+0x00,0x00,0x00,0x39,0x04,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x04,0x39,0x00,0x00,
+0x00,0x00,0x00,0x38,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x40,0x38,0x00,0x00,
+/* 42429 0xa5bd "ꖽ" */
+0x00,0x00,0x00,0x22,0x1d,0x22,0x1d,0x22,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0xd0,0x30,0xd0,0x30,0xd0,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+/* 42430 0xa5be "ꖾ" */
+0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x7c,0x00,0x00,
+/* 42431 0xa5bf "ꖿ" */
+0x00,0x00,0x00,0x11,0x11,0x0e,0x00,0x11,0x11,0x0e,0x00,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x10,0x10,0xe0,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42432 0xa5c0 "ꗀ" */
+0x00,0x00,0x00,0x22,0x1d,0x22,0x1d,0x22,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x30,0xd0,0x30,0xd0,0x30,0xd0,0x10,0x10,0x7c,0x10,0x7c,0x00,0x00,
+/* 42433 0xa5c1 "ꗁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x47,0x46,0x3a,0x02,0x04,0x1b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0xe2,0x62,0x5c,0x40,0x80,0x00,0x00,0x00,
+/* 42434 0xa5c2 "ꗂ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x3a,0x46,0x47,0x46,0x3a,0x02,0x04,0x1b,0x00,0x00,
+0x00,0x00,0x00,0xd8,0x20,0x40,0x5c,0x62,0xe2,0x62,0x5c,0x40,0x80,0x00,0x00,0x00,
+/* 42435 0xa5c3 "ꗃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x07,0x0f,0x1f,0x0f,0x07,0x02,0x00,0x00,
+0x00,0x00,0x00,0x30,0x48,0x88,0x10,0x00,0x00,0x80,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 42436 0xa5c4 "ꗄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x12,0x07,0x0f,0x1f,0x0f,0x07,0x02,0x00,0x00,
+0x00,0x00,0x00,0x30,0x48,0x88,0x10,0x40,0x00,0x80,0xc0,0x80,0x00,0x00,0x00,0x00,
+/* 42437 0xa5c5 "ꗅ" */
+0x00,0x00,0x00,0x22,0x22,0x1d,0x00,0x22,0x22,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x30,0xd0,0x10,0x10,0x30,0xd0,0x10,0x10,0x10,0x7c,0x00,0x00,
+/* 42438 0xa5c6 "ꗆ" */
+0x00,0x00,0x00,0x22,0x22,0x1d,0x00,0x22,0x22,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x30,0xd0,0x10,0x10,0x30,0xd0,0x10,0x54,0x10,0x7c,0x00,0x00,
+/* 42439 0xa5c7 "ꗇ" */
+0x00,0x00,0x00,0x0f,0x02,0x02,0x04,0x04,0x08,0x48,0x30,0x1f,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x80,0x80,0x40,0x40,0x20,0x24,0x18,0xf0,0x20,0x40,0x00,0x00,
+/* 42440 0xa5c8 "ꗈ" */
+0x00,0x00,0x00,0x07,0x00,0x07,0x01,0x02,0x04,0x28,0x5f,0x28,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0xc0,0x00,0x80,0x40,0x28,0xf4,0x28,0x50,0x20,0x00,0x00,
+/* 42441 0xa5c9 "ꗉ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0f,0x04,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xf0,0x20,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 42442 0xa5ca "ꗊ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x0f,0x04,0x03,0x04,0x0f,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0xf0,0x20,0xc0,0x20,0xf0,0x20,0xc0,0x00,0x00,0x00,
+/* 42443 0xa5cb "ꗋ" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 42444 0xa5cc "ꗌ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x48,0x50,0x60,0xc0,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42445 0xa5cd "ꗍ" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x80,0x00,0x00,0xf0,0x00,0x80,0x00,0x00,0xf0,0x00,0x00,
+/* 42446 0xa5ce "ꗎ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x00,0x04,0x01,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0xc0,0x48,0x50,0x60,0xc8,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 42447 0xa5cf "ꗏ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 42448 0xa5d0 "ꗐ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x03,0x00,0x07,0x08,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0xc0,0x20,0x20,0xc0,0x00,0x10,0xe0,0x00,0x00,
+/* 42449 0xa5d1 "ꗑ" */
+0x00,0x00,0x00,0x0c,0x12,0x21,0x22,0x02,0x02,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x08,0x88,0x80,0x80,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42450 0xa5d2 "ꗒ" */
+0x00,0x00,0x00,0x0c,0x12,0x21,0x22,0x02,0x02,0x01,0x01,0x05,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x08,0x88,0x80,0x80,0x00,0x00,0x40,0x00,0xc0,0x00,0x00,
+/* 42451 0xa5d3 "ꗓ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,0x02,0x02,0x02,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x30,0x30,0x00,0xe0,0x30,0x30,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 42452 0xa5d4 "ꗔ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x0b,0x02,0x02,0x02,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x30,0x30,0x00,0xe0,0x34,0x30,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 42453 0xa5d5 "ꗕ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,0x02,0x02,0x0f,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x30,0x30,0x00,0xe0,0x30,0x30,0x00,0x80,0x00,0x80,0x00,0x00,
+/* 42454 0xa5d6 "ꗖ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x0b,0x02,0x02,0x0f,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x30,0x30,0x00,0xe0,0x34,0x30,0x00,0x80,0x00,0x80,0x00,0x00,
+/* 42455 0xa5d7 "ꗗ" */
+0x00,0x00,0x00,0x03,0x02,0x02,0x03,0x02,0x02,0x03,0x02,0x0a,0x02,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0xe0,0x10,0x10,0xe0,0x00,0x80,0x00,0x80,0x00,0x00,
+/* 42456 0xa5d8 "ꗘ" */
+0x00,0x00,0x00,0x07,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x08,0xf0,0x08,0x08,0xf0,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42457 0xa5d9 "ꗙ" */
+0x00,0x00,0x00,0x07,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x15,0x05,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x08,0xf0,0x08,0x08,0xf0,0x00,0x40,0x00,0xc0,0x00,0x00,
+/* 42458 0xa5da "ꗚ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x90,0x10,0xe0,0x10,0x90,0x10,0xe0,0x00,0x00,0x00,
+/* 42459 0xa5db "ꗛ" */
+0x00,0x00,0x00,0x01,0x06,0x08,0x08,0x09,0x0e,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x60,0x00,0xc0,0x20,0xc0,0x00,0xf0,0x08,0x30,0x00,0x00,
+/* 42460 0xa5dc "ꗜ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x40,0x44,0x64,0x5b,0x40,0x44,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x40,0x04,0x44,0x4c,0xb4,0x04,0x20,0x00,0x00,0x00,0x00,
+/* 42461 0xa5dd "ꗝ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x10,0x00,0x00,
+/* 42462 0xa5de "ꗞ" */
+0x00,0x00,0x00,0x1f,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x80,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0xf0,0x00,0x00,
+/* 42463 0xa5df "ꗟ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x0a,0x0a,0x0e,0x0b,0x00,0x00,
+0x00,0x00,0x00,0xd0,0x50,0x70,0x50,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 42464 0xa5e0 "ꗠ" */
+0x00,0x00,0x00,0x38,0x44,0x42,0x02,0x02,0x07,0x08,0x10,0x20,0x59,0x66,0x00,0x00,
+0x00,0x00,0x00,0x70,0x88,0x84,0x04,0x04,0xf8,0x10,0x20,0x40,0xb2,0xcc,0x00,0x00,
+/* 42465 0xa5e1 "ꗡ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x0c,0x14,0x14,0x14,0x08,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0xa0,0xa0,0xc8,0x50,0x20,0x50,0x50,0x50,0x20,0x00,0x00,
+/* 42466 0xa5e2 "ꗢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x4c,0x4b,0x30,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x02,0x02,0x92,0x92,0x92,0x6e,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 42467 0xa5e3 "ꗣ" */
+0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x0b,0x0c,0x0b,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x10,0x08,0x34,0xc0,0x00,0x00,0x00,0xc0,0x34,0x08,0x10,0x00,0x00,
+/* 42468 0xa5e4 "ꗤ" */
+0x00,0x00,0x00,0x08,0x14,0x14,0x14,0x08,0x15,0x26,0x0a,0x0a,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0xa0,0xa0,0xc8,0x50,0x20,0x50,0x50,0x50,0x20,0x00,0x00,
+/* 42469 0xa5e5 "ꗥ" */
+0x00,0x00,0x00,0x08,0x14,0x14,0x14,0x48,0x15,0x26,0x0a,0x0a,0x0a,0x04,0x00,0x00,
+0x00,0x00,0x00,0x40,0xa0,0xa0,0xa0,0xca,0x50,0x20,0x50,0x50,0x50,0x20,0x00,0x00,
+/* 42470 0xa5e6 "ꗦ" */
+0x00,0x00,0x00,0x0c,0x12,0x21,0x22,0x02,0x02,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x08,0x88,0x80,0x80,0x00,0x00,0x20,0x20,0xc0,0x00,0x00,
+/* 42471 0xa5e7 "ꗧ" */
+0x00,0x00,0x00,0x0c,0x12,0x21,0x22,0x02,0x02,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x90,0x08,0x88,0x80,0x80,0x00,0x00,0x28,0x30,0xc0,0x00,0x00,
+/* 42472 0xa5e8 "ꗨ" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x03,0x00,0x00,0x00,0x03,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0xc0,0x20,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42473 0xa5e9 "ꗩ" */
+0x00,0x00,0x00,0x00,0x03,0x0c,0x03,0x00,0x08,0x00,0x03,0x0c,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0xc0,0x24,0xc0,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42474 0xa5ea "ꗪ" */
+0x00,0x00,0x00,0x10,0x11,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x11,0x10,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 42475 0xa5eb "ꗫ" */
+0x00,0x00,0x00,0x10,0x14,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x14,0x10,0x00,0x00,
+0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x70,0x00,0x00,
+/* 42476 0xa5ec "ꗬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x47,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0xe2,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,
+/* 42477 0xa5ed "ꗭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x47,0x44,0x38,0x00,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0xe2,0x22,0x1c,0x00,0x40,0x00,0x00,0x00,
+/* 42478 0xa5ee "ꗮ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x38,0x44,0x47,0x44,0x38,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xc4,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+/* 42479 0xa5ef "ꗯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x4c,0x43,0x42,0x44,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x84,0x84,0x64,0x1c,0x00,0x00,0x00,0x00,0x00,
+/* 42480 0xa5f0 "ꗰ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x70,0x4c,0x43,0x42,0x44,0x48,0x51,0x60,0x00,0x00,
+0x00,0x00,0x00,0x0c,0x14,0x24,0x44,0x84,0x84,0x64,0x1c,0x00,0x00,0x00,0x00,0x00,
+/* 42481 0xa5f1 "ꗱ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x30,0x00,0x00,
+/* 42482 0xa5f2 "ꗲ" */
+0x00,0x00,0x00,0x00,0x03,0x06,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0b,0x0c,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x30,0x00,0x00,
+/* 42483 0xa5f3 "ꗳ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x42,0x41,0x7f,0x41,0x42,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x84,0x04,0xfc,0x04,0x84,0x40,0x40,0x80,0x00,0x00,
+/* 42484 0xa5f4 "ꗴ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x52,0x41,0x7f,0x41,0x52,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x94,0x04,0xfc,0x04,0x94,0x40,0x40,0x80,0x00,0x00,
+/* 42485 0xa5f5 "ꗵ" */
+0x00,0x00,0x00,0x00,0x03,0x14,0x1f,0x14,0x03,0x14,0x1f,0x14,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x28,0xf8,0x28,0xc0,0x28,0xf8,0x28,0xc0,0x00,0x00,0x00,
+/* 42486 0xa5f6 "ꗶ" */
+0x00,0x00,0x00,0x00,0x03,0x44,0x7f,0x44,0x13,0x44,0x7f,0x44,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x22,0xfe,0x22,0xc8,0x22,0xfe,0x22,0xc0,0x00,0x00,0x00,
+/* 42487 0xa5f7 "ꗷ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42488 0xa5f8 "ꗸ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x01,0x01,0x01,0x01,0x00,0x07,0x08,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 42489 0xa5f9 "ꗹ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x01,0x01,0x09,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,
+/* 42490 0xa5fa "ꗺ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x11,0x10,0x10,0x10,0x11,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 42491 0xa5fb "ꗻ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x45,0x45,0x3b,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0xb8,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42492 0xa5fc "ꗼ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x45,0x45,0x3b,0x01,0x11,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0xb8,0x00,0x10,0x00,0x00,0x00,0x00,
+/* 42493 0xa5fd "ꗽ" */
+0x00,0x00,0x00,0x01,0x01,0x11,0x01,0x45,0x45,0x3b,0x01,0x11,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x44,0x44,0xb8,0x00,0x10,0x00,0x00,0x00,0x00,
+/* 42494 0xa5fe "ꗾ" */
+0x00,0x00,0x00,0x07,0x01,0x11,0x01,0x45,0x05,0x3b,0x01,0x11,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x10,0x00,0x44,0x44,0xb8,0x00,0x10,0x00,0xc0,0x00,0x00,
+/* 42495 0xa5ff "ꗿ" */
+0x00,0x00,0x00,0x0f,0x10,0x20,0x07,0x04,0x07,0x04,0x07,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0xf8,0x00,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 42496 0xa600 "ꘀ" */
+0x00,0x00,0x00,0x0f,0x10,0x20,0x07,0x04,0x07,0x04,0x07,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x20,0x00,0xe8,0x00,0x20,0x80,0x80,0x00,0x00,0x00,
+/* 42497 0xa601 "ꘁ" */
+0x00,0x00,0x00,0x0f,0x10,0x20,0x07,0x04,0x07,0x04,0x07,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x28,0x08,0xf8,0x08,0x28,0x80,0x80,0x00,0x00,0x00,
+/* 42498 0xa602 "ꘂ" */
+0x00,0x00,0x00,0x0f,0x10,0x20,0x07,0x04,0x07,0x04,0x07,0x20,0x10,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x88,0x08,0x08,0xf8,0x08,0x08,0x88,0x80,0x00,0x00,0x00,
+/* 42499 0xa603 "ꘃ" */
+0x00,0x00,0x00,0x21,0x21,0x13,0x0d,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42500 0xa604 "ꘄ" */
+0x00,0x00,0x00,0x21,0x21,0x13,0x0d,0x01,0x01,0x01,0x05,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x40,0x00,0x00,0xc0,0x00,0x00,
+/* 42501 0xa605 "ꘅ" */
+0x00,0x00,0x00,0x21,0x21,0x13,0x0d,0x01,0x01,0x05,0x01,0x07,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x90,0x60,0x00,0x00,0x40,0x00,0xc0,0x00,0xc0,0x00,0x00,
+/* 42502 0xa606 "ꘆ" */
+0x00,0x00,0x00,0x21,0x21,0x13,0x0d,0x01,0x01,0x01,0x07,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0xc0,0x00,0x00,0xc0,0x00,0x00,
+/* 42503 0xa607 "ꘇ" */
+0x00,0x00,0x00,0x21,0x21,0x13,0x0d,0x01,0x01,0x01,0x01,0x09,0x0f,0x08,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x90,0x60,0x00,0x00,0x00,0x00,0x20,0xe0,0x20,0x00,0x00,
+/* 42504 0xa608 "ꘈ" */
+0x00,0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,
+0x00,0x00,0x00,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x00,0x00,
+/* 42505 0xa609 "ꘉ" */
+0x00,0x00,0x00,0x1e,0x01,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x1e,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0xf0,0x00,0x00,
+/* 42506 0xa60a "ꘊ" */
+0x00,0x00,0x00,0x21,0x21,0x13,0x0d,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x08,0x08,0x90,0x60,0x00,0x00,0xf0,0x50,0xf0,0x50,0xf0,0x00,0x00,
+/* 42507 0xa60b "ꘋ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x80,0x80,0x00,0x38,0x44,0x44,0x88,0x70,0x00,0x00,
+/* 42508 0xa60c "ꘌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 42509 0xa60d "꘍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x00,0x00,
+/* 42510 0xa60e "꘎" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x01,0x0f,0x01,0x02,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x40,0x80,0xf0,0x80,0x40,0x20,0x00,0x00,0x00,0x00,
+/* 42511 0xa60f "꘏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x43,0x52,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x94,0x84,0xc4,0xb8,0x00,0x00,
+/* 42512 0xa610 "ꘐ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x64,0x64,0x1c,0x04,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x16,0x1e,0x10,0x10,0x10,0xd6,0xce,0x00,0x00,
+/* 42513 0xa611 "ꘑ" */
+0x00,0x00,0x00,0x11,0x11,0x0e,0x04,0x04,0x04,0x04,0x04,0x15,0x15,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x40,0x40,0x40,0x40,0x40,0x50,0x50,0xe0,0x00,0x00,
+/* 42514 0xa612 "ꘒ" */
+0x00,0x00,0x00,0x06,0x18,0x60,0x18,0x06,0x01,0x06,0x18,0x60,0x18,0x06,0x00,0x00,
+0x00,0x00,0x00,0x0c,0x30,0xc0,0x30,0x0c,0xfe,0x0c,0x30,0xc0,0x30,0x0c,0x00,0x00,
+/* 42515 0xa613 "ꘓ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x04,0x03,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,
+/* 42516 0xa614 "ꘔ" */
+0x00,0x00,0x00,0x22,0x22,0x1d,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x60,0xa0,0x20,0x20,0xe4,0x38,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 42517 0xa615 "ꘕ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x45,0x42,0x25,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x14,0x14,0x94,0x94,0x94,0x14,0x14,0x14,0xfc,0x14,0x14,0x00,0x00,
+/* 42518 0xa616 "ꘖ" */
+0x00,0x00,0x00,0x0f,0x08,0x09,0x08,0x08,0x09,0x08,0x08,0x09,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,
+/* 42519 0xa617 "ꘗ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x12,0x0a,0x06,0x00,0x00,
+0x00,0x00,0x00,0x18,0x28,0x48,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 42520 0xa618 "ꘘ" */
+0x00,0x00,0x00,0x03,0x0d,0x31,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x70,0x98,0x18,0x00,0x70,0x98,0x18,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 42521 0xa619 "ꘙ" */
+0x00,0x00,0x00,0x0f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0xf0,0x08,0x08,0x30,0x00,0x00,0xe0,0x00,0x00,
+/* 42522 0xa61a "ꘚ" */
+0x00,0x00,0x00,0x11,0x00,0x19,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x11,0x00,0x00,
+0x00,0x00,0x00,0x10,0x00,0x98,0x20,0x20,0x20,0x20,0x20,0x98,0x00,0x10,0x00,0x00,
+/* 42523 0xa61b "ꘛ" */
+0x00,0x00,0x00,0x12,0x12,0x0d,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0xc0,0x80,0x80,0x00,0x00,0xfc,0x04,0x88,0x70,0x00,0x00,
+/* 42524 0xa61c "ꘜ" */
+0x00,0x00,0x00,0x3f,0x21,0x11,0x11,0x09,0x09,0x05,0x05,0x03,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 42525 0xa61d "ꘝ" */
+0x00,0x00,0x00,0x0f,0x08,0x0c,0x0b,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x90,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42526 0xa61e "ꘞ" */
+0x00,0x00,0x00,0x44,0x44,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x60,0xa0,0x24,0x20,0x3e,0x20,0x24,0x20,0x20,0x20,0x00,0x00,
+/* 42527 0xa61f "ꘟ" */
+0x00,0x00,0x00,0x1c,0x22,0x22,0x1c,0x08,0x05,0x03,0x04,0x04,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x10,0xe0,0x00,0x00,0x80,0x00,0x00,
+/* 42528 0xa620 "꘠" */
+0x00,0x00,0x00,0x11,0x11,0x0e,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 42529 0xa621 "꘡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42530 0xa622 "꘢" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x01,0x05,0x01,0x05,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x00,0x40,0x00,0x40,0x00,0x64,0x98,0x00,0x00,
+/* 42531 0xa623 "꘣" */
+0x00,0x00,0x00,0x38,0x44,0x47,0x44,0x38,0x03,0x00,0x00,0x03,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 42532 0xa624 "꘤" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x09,0x09,0x09,0x0f,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x20,0x20,0x20,0x00,0x00,
+/* 42533 0xa625 "꘥" */
+0x00,0x00,0x00,0x0c,0x0a,0x09,0x08,0x08,0x08,0x09,0x0a,0x0c,0x0c,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0x00,0x00,
+/* 42534 0xa626 "꘦" */
+0x00,0x00,0x00,0x01,0x02,0x1f,0x04,0x04,0x04,0x04,0x05,0x06,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x80,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42535 0xa627 "꘧" */
+0x00,0x00,0x00,0x0c,0x13,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x40,0x40,0x40,0x40,0x40,0xe0,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 42536 0xa628 "꘨" */
+0x00,0x00,0x00,0x04,0x00,0x00,0x04,0x04,0x04,0x03,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x20,0x00,0x00,0x20,0x20,0x20,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,
+/* 42537 0xa629 "꘩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x11,0x11,0x0e,0x00,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0x70,0x88,0x88,0x70,0x20,0x40,0x80,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 42538 0xa62a "ꘪ" */
+0x00,0x00,0x00,0x30,0x48,0x44,0x3f,0x04,0x04,0x04,0x04,0x48,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x18,0x24,0x44,0xf8,0x40,0x40,0x40,0x40,0x24,0x28,0x10,0x00,0x00,
+/* 42539 0xa62b "ꘫ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x10,0x10,0xe0,0x00,0x00,
+/* 42540 0xa62c "꘬" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42541 0xa62d "꘭" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42542 0xa62e "꘮" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42543 0xa62f "꘯" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42544 0xa630 "꘰" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 42545 0xa631 "꘱" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 42546 0xa632 "꘲" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 42547 0xa633 "꘳" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 42548 0xa634 "꘴" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 42549 0xa635 "꘵" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 42550 0xa636 "꘶" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 42551 0xa637 "꘷" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 42552 0xa638 "꘸" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 42553 0xa639 "꘹" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 42554 0xa63a "꘺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 42555 0xa63b "꘻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 42556 0xa63c "꘼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42557 0xa63d "꘽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42558 0xa63e "꘾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42559 0xa63f "꘿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42560 0xa640 "Ꙁ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x40,0x7e,0x3a,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42561 0xa641 "ꙁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x3a,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42562 0xa642 "Ꙃ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x7c,0x20,0x40,0x40,0x7e,0x3a,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42563 0xa643 "ꙃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x7e,0x10,0x20,0x40,0x7e,0x3a,0x44,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42564 0xa644 "Ꙅ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x0c,0x30,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42565 0xa645 "ꙅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x0c,0x30,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42566 0xa646 "Ꙇ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42567 0xa647 "ꙇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42568 0xa648 "Ꙉ" */
+0x00,0x00,0x00,0x00,0x10,0x38,0x10,0x10,0x38,0x44,0x82,0x82,0x82,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42569 0xa649 "ꙉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x38,0x10,0x38,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42570 0xa64a "Ꙋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x3c,0x4a,0x52,0x4a,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42571 0xa64b "ꙋ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x44,0x44,0x28,0x10,0x28,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42572 0xa64c "Ꙍ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x41,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x78,0x00,0x00,
+/* 42573 0xa64d "ꙍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x40,0x40,0x40,0x41,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x04,0x04,0x04,0x04,0x84,0x78,0x00,0x00,
+/* 42574 0xa64e "Ꙏ" */
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x10,0x1e,0x11,0x11,0x11,0x11,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42575 0xa64f "ꙏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x1e,0x11,0x11,0x11,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42576 0xa650 "Ꙑ" */
+0x00,0x00,0x00,0x00,0xe2,0x22,0x22,0x22,0x32,0x2a,0x2a,0x2a,0x2a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42577 0xa651 "ꙑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xe2,0x22,0x22,0x32,0x2a,0x2a,0x2a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42578 0xa652 "Ꙓ" */
+0x00,0x00,0x00,0x00,0x50,0x7e,0x50,0x50,0x5c,0x52,0x52,0x52,0x52,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42579 0xa653 "ꙓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x7e,0x50,0x50,0x5c,0x52,0x52,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42580 0xa654 "Ꙕ" */
+0x00,0x00,0x00,0x00,0x32,0x4a,0x4a,0x4a,0x4e,0x4a,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42581 0xa655 "ꙕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x4a,0x4e,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42582 0xa656 "Ꙗ" */
+0x00,0x00,0x00,0x00,0x88,0x94,0xa2,0xa2,0xfe,0xa2,0xa2,0xa2,0xa2,0xa2,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42583 0xa657 "ꙗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x42,0x42,0x4e,0x72,0x52,0x52,0x4e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42584 0xa658 "Ꙙ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x14,0x14,0x22,0x3e,0x22,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42585 0xa659 "ꙙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x14,0x22,0x3e,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42586 0xa65a "Ꙛ" */
+0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x14,0x08,0x1c,0x22,0x7f,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42587 0xa65b "ꙛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x14,0x3e,0x41,0x7f,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42588 0xa65c "Ꙝ" */
+0x00,0x00,0x00,0x00,0x48,0x48,0x54,0x54,0x52,0x7e,0x62,0x41,0x41,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42589 0xa65d "ꙝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x4a,0x4a,0x51,0x7f,0x51,0x51,0x5f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42590 0xa65e "Ꙟ" */
+0x00,0x00,0x00,0x01,0x03,0x05,0x05,0x09,0x09,0x29,0x11,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 42591 0xa65f "ꙟ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x2a,0x2a,0xa9,0x49,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42592 0xa660 "Ꙡ" */
+0x00,0x00,0x00,0x00,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x7f,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42593 0xa661 "ꙡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x7e,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42594 0xa662 "Ꙣ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x3f,0x20,0x20,
+0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xc0,0x40,0x40,
+/* 42595 0xa663 "ꙣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0x08,0x08,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0xc0,0x40,0x00,
+/* 42596 0xa664 "Ꙥ" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42597 0xa665 "ꙥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 42598 0xa666 "Ꙧ" */
+0x00,0x00,0x00,0x00,0x21,0x21,0x33,0x33,0x2d,0x2d,0x21,0x21,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42599 0xa667 "ꙧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x33,0x33,0x2d,0x2d,0x21,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42600 0xa668 "Ꙩ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x5a,0x5a,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42601 0xa669 "ꙩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x5a,0x5a,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42602 0xa66a "Ꙫ" */
+0x00,0x00,0x00,0x00,0x7c,0x82,0x82,0x82,0x82,0xaa,0x82,0x82,0x82,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42603 0xa66b "ꙫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x41,0x41,0x55,0x41,0x41,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42604 0xa66c "Ꙭ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x2d,0x2d,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x84,0xb4,0xb4,0x84,0x84,0x84,0x78,0x00,0x00,
+/* 42605 0xa66d "ꙭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x2d,0x2d,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x84,0xb4,0xb4,0x84,0x84,0x78,0x00,0x00,
+/* 42606 0xa66e "ꙮ" */
+0x0e,0x11,0x15,0x11,0x0e,0x39,0x46,0x56,0x46,0x39,0x0e,0x11,0x15,0x11,0x0e,0x00,
+0x70,0x88,0xa8,0x88,0x70,0xce,0x31,0xb5,0x31,0xce,0x70,0x88,0xa8,0x88,0x70,0x00,
+/* 42607 0xa66f "꙯" */
+0x00,0x7e,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42608 0xa670 "꙰" */
+0x00,0x02,0x01,0x2a,0x10,0x28,0x00,0xa0,0x40,0xa0,0x00,0x00,0x28,0x12,0x29,0x02,
+0x00,0x80,0x00,0xa8,0x10,0x28,0x00,0x14,0x08,0x14,0x00,0x00,0x28,0x90,0x28,0x80,
+/* 42609 0xa671 "꙱" */
+0x00,0x7e,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42610 0xa672 "꙲" */
+0x01,0x01,0x07,0x01,0x01,0x00,0xf0,0x00,0x00,0xf0,0x00,0x00,0xf0,0x05,0x05,0x05,
+0x00,0x00,0xc0,0x00,0x00,0x00,0x1e,0x00,0x00,0x1e,0x00,0x00,0x1e,0x40,0x40,0x40,
+/* 42611 0xa673 "꙳" */
+0x10,0x28,0xee,0x82,0x44,0x82,0xee,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42612 0xa674 "ꙴ" */
+0x00,0x1c,0x22,0x38,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42613 0xa675 "ꙵ" */
+0x00,0x22,0x26,0x2a,0x32,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42614 0xa676 "ꙶ" */
+0x00,0x14,0x00,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42615 0xa677 "ꙷ" */
+0x00,0x22,0x14,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42616 0xa678 "ꙸ" */
+0x00,0x30,0x10,0x1c,0x12,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42617 0xa679 "ꙹ" */
+0x00,0x42,0x42,0x72,0x4a,0x72,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42618 0xa67a "ꙺ" */
+0x00,0x20,0x20,0x38,0x24,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42619 0xa67b "ꙻ" */
+0x00,0x54,0x54,0x54,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42620 0xa67c "꙼" */
+0x00,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42621 0xa67d "꙽" */
+0x00,0x0a,0x0a,0x06,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42622 0xa67e "꙾" */
+0x00,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42623 0xa67f "ꙿ" */
+0x00,0x0a,0x0a,0x06,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42624 0xa680 "Ꚁ" */
+0x00,0x10,0x10,0x10,0x1e,0x12,0x12,0x12,0x22,0x22,0x22,0x42,0x42,0xff,0x81,0x81,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42625 0xa681 "ꚁ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x1e,0x12,0x22,0x22,0x42,0x42,0x42,0x7f,0x41,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42626 0xa682 "Ꚃ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x20,0x10,0x08,0x04,0x02,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42627 0xa683 "ꚃ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x20,0x10,0x10,0x08,0x08,0x04,0x24,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42628 0xa684 "Ꚅ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x3f,0x04,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x46,0x48,0x48,0x50,0xe0,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+/* 42629 0xa685 "ꚅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x3f,0x04,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x46,0x48,0x50,0xe0,0x50,0x48,0x44,0x42,0x00,0x00,
+/* 42630 0xa686 "Ꚇ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x6e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42631 0xa687 "ꚇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x6e,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42632 0xa688 "Ꚉ" */
+0x00,0x00,0x00,0x00,0x1c,0x14,0x14,0x14,0x24,0x24,0x24,0x46,0x49,0xfa,0x81,0x86,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42633 0xa689 "ꚉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x14,0x24,0x24,0x44,0x46,0x49,0x7a,0x41,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42634 0xa68a "Ꚋ" */
+0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x16,0x19,0x11,0x11,0x11,0x11,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42635 0xa68b "ꚋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x16,0x19,0x11,0x11,0x11,0x05,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42636 0xa68c "Ꚍ" */
+0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42637 0xa68d "ꚍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x12,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42638 0xa68e "Ꚏ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x39,0x41,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42639 0xa68f "ꚏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x39,0x41,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42640 0xa690 "Ꚑ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x38,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42641 0xa691 "ꚑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x38,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42642 0xa692 "Ꚓ" */
+0x00,0x00,0x00,0x00,0xfa,0x22,0x22,0x22,0x22,0x26,0x1a,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42643 0xa693 "ꚓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfa,0x22,0x22,0x22,0x26,0x1a,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42644 0xa694 "Ꚕ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x40,0x58,0x64,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42645 0xa695 "ꚕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x40,0x40,0x58,0x64,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42646 0xa696 "Ꚗ" */
+0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xfe,0x39,0x41,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42647 0xa697 "ꚗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0xfe,0x39,0x41,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42648 0xa698 "Ꚙ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x78,0x00,0x00,
+/* 42649 0xa699 "ꚙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x84,0x84,0x84,0x84,0x78,0x00,0x00,
+/* 42650 0xa69a "Ꚛ" */
+0x00,0x00,0x00,0x00,0x7c,0x92,0x92,0x92,0xfe,0x92,0x92,0x92,0x92,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42651 0xa69b "ꚛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x49,0x49,0x7f,0x49,0x49,0x49,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42652 0xa69c "ꚜ" */
+0x00,0x00,0x00,0x00,0x00,0x70,0x10,0x1c,0x12,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42653 0xa69d "ꚝ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x38,0x24,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42654 0xa69e "ꚞ" */
+0x08,0x1c,0x2a,0x2a,0x2a,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42655 0xa69f "ꚟ" */
+0x00,0x4c,0x50,0x7c,0x50,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42656 0xa6a0 "ꚠ" */
+0x00,0x00,0x00,0x00,0x08,0x0c,0x0a,0x08,0x08,0x08,0x08,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42657 0xa6a1 "ꚡ" */
+0x00,0x00,0x00,0x00,0x42,0x46,0x46,0x4a,0x4a,0x52,0x52,0x62,0x62,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42658 0xa6a2 "ꚢ" */
+0x00,0x00,0x00,0x7c,0x00,0x7c,0x00,0x38,0x44,0x82,0x82,0x82,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42659 0xa6a3 "ꚣ" */
+0x00,0x00,0x00,0x00,0x04,0x34,0x48,0x48,0x52,0x50,0x20,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42660 0xa6a4 "ꚤ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x20,0x24,0x22,0x62,0x52,0x8c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42661 0xa6a5 "ꚥ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x48,0x40,0x7c,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42662 0xa6a6 "ꚦ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x7c,0x02,0x02,0x7c,0x00,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42663 0xa6a7 "ꚧ" */
+0x00,0x00,0x00,0x00,0x7c,0x04,0x08,0x08,0x10,0x10,0x30,0x30,0x48,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42664 0xa6a8 "ꚨ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x04,0x04,0x08,0x08,0x08,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42665 0xa6a9 "ꚩ" */
+0x00,0x00,0x00,0x00,0x40,0x8c,0x92,0xa2,0xa2,0x84,0x78,0x00,0x00,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42666 0xa6aa "ꚪ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0xa4,0x78,0x20,0x24,0x20,0x24,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42667 0xa6ab "ꚫ" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x54,0x90,0x10,0x50,0x10,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42668 0xa6ac "ꚬ" */
+0x00,0x00,0x00,0x00,0x40,0x1c,0x22,0x22,0x2a,0x2a,0x24,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42669 0xa6ad "ꚭ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x7e,0x22,0x12,0x22,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42670 0xa6ae "ꚮ" */
+0x00,0x00,0x00,0x00,0x40,0x50,0x40,0x78,0x04,0x04,0x78,0x40,0x50,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42671 0xa6af "ꚯ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x60,0x00,0x48,0x60,0x50,0x48,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42672 0xa6b0 "ꚰ" */
+0x00,0x00,0x00,0x00,0x70,0x4c,0x42,0x4c,0x70,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42673 0xa6b1 "ꚱ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42674 0xa6b2 "ꚲ" */
+0x00,0x00,0x00,0x00,0x92,0x82,0x44,0x44,0x28,0x28,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42675 0xa6b3 "ꚳ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42676 0xa6b4 "ꚴ" */
+0x00,0x00,0x00,0x00,0x88,0x88,0x88,0x8a,0x88,0x8e,0x50,0x52,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42677 0xa6b5 "ꚵ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0x82,0x44,0x38,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42678 0xa6b6 "ꚶ" */
+0x00,0x00,0x00,0x00,0x48,0x48,0x48,0x48,0x4a,0x48,0x48,0x4a,0x48,0x78,0x48,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42679 0xa6b7 "ꚷ" */
+0x00,0x00,0x00,0x00,0x02,0x00,0x2c,0x34,0x64,0xa6,0x20,0x28,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42680 0xa6b8 "ꚸ" */
+0x00,0x00,0x00,0x00,0x30,0x40,0x80,0x98,0x84,0x42,0x32,0x02,0x04,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42681 0xa6b9 "ꚹ" */
+0x00,0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x12,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42682 0xa6ba "ꚺ" */
+0x00,0x00,0x00,0x00,0x60,0x12,0x18,0x24,0x44,0x44,0x24,0x18,0x10,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42683 0xa6bb "ꚻ" */
+0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x78,0x48,0x48,0x4e,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42684 0xa6bc "ꚼ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0xc0,0x30,0x0c,0x02,0x0c,0x30,0xc0,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42685 0xa6bd "ꚽ" */
+0x00,0x00,0x00,0x02,0x04,0x08,0x18,0x24,0x02,0x02,0x02,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42686 0xa6be "ꚾ" */
+0x00,0x00,0x00,0x00,0x50,0x50,0x50,0x50,0x7c,0x14,0x14,0x14,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42687 0xa6bf "ꚿ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x22,0x72,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42688 0xa6c0 "ꛀ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x7e,0x02,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42689 0xa6c1 "ꛁ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x42,0x02,0x02,0x02,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42690 0xa6c2 "ꛂ" */
+0x00,0x00,0x00,0x00,0x40,0x5e,0x40,0x5e,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42691 0xa6c3 "ꛃ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x04,0x54,0x54,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42692 0xa6c4 "ꛄ" */
+0x00,0x00,0x00,0x00,0x46,0x5a,0x62,0x62,0x5a,0x46,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42693 0xa6c5 "ꛅ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x4a,0x48,0x58,0x68,0x48,0x48,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42694 0xa6c6 "ꛆ" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x7a,0x06,0x06,0x06,0x7a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42695 0xa6c7 "ꛇ" */
+0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x42,0x20,0x10,0x08,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42696 0xa6c8 "ꛈ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x92,0x92,0x54,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42697 0xa6c9 "ꛉ" */
+0x00,0x00,0x00,0x00,0x7c,0x04,0x08,0x08,0x10,0x10,0x20,0x20,0x40,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42698 0xa6ca "ꛊ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x24,0x2a,0x22,0x52,0x4c,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42699 0xa6cb "ꛋ" */
+0x00,0x00,0x00,0x00,0x3e,0x18,0x28,0x48,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42700 0xa6cc "ꛌ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x38,0x44,0x18,0x04,0x44,0x38,0x00,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42701 0xa6cd "ꛍ" */
+0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x04,0x08,0x30,0x20,0xf8,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42702 0xa6ce "ꛎ" */
+0x00,0x00,0x00,0x00,0x10,0x28,0x28,0x28,0x44,0x44,0x44,0x44,0x82,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42703 0xa6cf "ꛏ" */
+0x00,0x00,0x00,0x00,0x38,0x00,0x82,0xc6,0xaa,0xaa,0x92,0x00,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42704 0xa6d0 "ꛐ" */
+0x00,0x00,0x00,0x00,0x3e,0x40,0x40,0x40,0x3e,0x00,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42705 0xa6d1 "ꛑ" */
+0x00,0x00,0x00,0x00,0x32,0x08,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42706 0xa6d2 "ꛒ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x04,0x04,0x28,0x10,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42707 0xa6d3 "ꛓ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0xa4,0x78,0x20,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42708 0xa6d4 "ꛔ" */
+0x00,0x00,0x00,0x00,0x10,0x12,0x10,0x10,0x38,0x54,0x92,0x92,0x92,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42709 0xa6d5 "ꛕ" */
+0x00,0x00,0x00,0x00,0x60,0x50,0x48,0x44,0x40,0x40,0x44,0x48,0x50,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42710 0xa6d6 "ꛖ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x78,0x48,0x48,0x48,0x48,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42711 0xa6d7 "ꛗ" */
+0x00,0x00,0x00,0x00,0x38,0x54,0x92,0x92,0x92,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42712 0xa6d8 "ꛘ" */
+0x00,0x00,0x00,0x00,0xc2,0xa2,0x92,0x86,0x86,0x4a,0x4a,0x52,0x52,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42713 0xa6d9 "ꛙ" */
+0x00,0x00,0x00,0x00,0x18,0x28,0x4a,0x0c,0x18,0x28,0x48,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42714 0xa6da "ꛚ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x48,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42715 0xa6db "ꛛ" */
+0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42716 0xa6dc "ꛜ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x18,0x24,0x44,0x54,0x54,0x24,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42717 0xa6dd "ꛝ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x88,0x8a,0x48,0x38,0x08,0x08,0x08,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42718 0xa6de "ꛞ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42719 0xa6df "ꛟ" */
+0x00,0x00,0x00,0x00,0x82,0x82,0x44,0x44,0x44,0x44,0x28,0x28,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42720 0xa6e0 "ꛠ" */
+0x00,0x00,0x00,0x00,0x30,0x28,0x24,0x22,0x24,0x28,0x30,0x60,0xa0,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42721 0xa6e1 "ꛡ" */
+0x00,0x00,0x00,0x00,0x00,0x62,0x94,0x88,0x8a,0x74,0x00,0x00,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42722 0xa6e2 "ꛢ" */
+0x00,0x00,0x00,0x20,0x10,0x08,0x10,0x20,0x20,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42723 0xa6e3 "ꛣ" */
+0x00,0x00,0x00,0x00,0x40,0x7c,0x44,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42724 0xa6e4 "ꛤ" */
+0x00,0x00,0x00,0x04,0x62,0x11,0x09,0x0a,0x08,0x08,0x10,0x10,0x20,0xc0,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42725 0xa6e5 "ꛥ" */
+0x00,0x00,0x00,0x00,0x0e,0x10,0x70,0x50,0x4e,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42726 0xa6e6 "ꛦ" */
+0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x78,0x04,0x02,0x02,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42727 0xa6e7 "ꛧ" */
+0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x78,0x04,0x02,0x02,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42728 0xa6e8 "ꛨ" */
+0x00,0x00,0x00,0x00,0x70,0x50,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42729 0xa6e9 "ꛩ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x78,0x04,0x02,0x02,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42730 0xa6ea "ꛪ" */
+0x00,0x00,0x00,0x00,0x18,0x28,0x48,0x08,0x3c,0x02,0x02,0x02,0x04,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42731 0xa6eb "ꛫ" */
+0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x04,0x08,0x30,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42732 0xa6ec "ꛬ" */
+0x00,0x00,0x00,0x00,0x10,0x18,0x14,0x12,0x10,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42733 0xa6ed "ꛭ" */
+0x00,0x00,0x00,0x00,0x70,0x08,0x04,0x04,0x48,0x30,0x28,0x24,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42734 0xa6ee "ꛮ" */
+0x00,0x00,0x00,0x00,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42735 0xa6ef "ꛯ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x42,0x22,0x04,0x18,0x20,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42736 0xa6f0 "꛰" */
+0x00,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42737 0xa6f1 "꛱" */
+0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42738 0xa6f2 "꛲" */
+0x00,0x00,0x00,0x00,0x20,0x00,0x08,0x04,0x04,0x02,0x02,0x02,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42739 0xa6f3 "꛳" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x08,0x08,0x10,0x10,0x24,0x20,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42740 0xa6f4 "꛴" */
+0x00,0x00,0x00,0x00,0x22,0x22,0x22,0x22,0x44,0x55,0x44,0x88,0x88,0x88,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42741 0xa6f5 "꛵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x10,0x10,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42742 0xa6f6 "꛶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf4,0x24,0x48,0x4a,0x90,0x90,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42743 0xa6f7 "꛷" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x92,0x54,0x38,0x10,0x00,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42744 0xa6f8 "꛸" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 42745 0xa6f9 "꛹" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 42746 0xa6fa "꛺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 42747 0xa6fb "꛻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 42748 0xa6fc "꛼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42749 0xa6fd "꛽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42750 0xa6fe "꛾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42751 0xa6ff "꛿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42752 0xa700 "꜀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42753 0xa701 "꜁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x00,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42754 0xa702 "꜂" */
+0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42755 0xa703 "꜃" */
+0x00,0x00,0x00,0x00,0x1c,0x20,0x20,0x1c,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42756 0xa704 "꜄" */
+0x00,0x00,0x00,0x00,0x38,0x04,0x04,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42757 0xa705 "꜅" */
+0x00,0x00,0x00,0x00,0x38,0x04,0x04,0x38,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42758 0xa706 "꜆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x04,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42759 0xa707 "꜇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x04,0x04,0x38,0x00,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42760 0xa708 "꜈" */
+0x00,0x00,0x00,0x00,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42761 0xa709 "꜉" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x50,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42762 0xa70a "꜊" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x50,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42763 0xa70b "꜋" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42764 0xa70c "꜌" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42765 0xa70d "꜍" */
+0x00,0x00,0x00,0x00,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42766 0xa70e "꜎" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42767 0xa70f "꜏" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x14,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42768 0xa710 "꜐" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x14,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42769 0xa711 "꜑" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42770 0xa712 "꜒" */
+0x00,0x00,0x00,0x00,0x1e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42771 0xa713 "꜓" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42772 0xa714 "꜔" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42773 0xa715 "꜕" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42774 0xa716 "꜖" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42775 0xa717 "ꜗ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x50,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42776 0xa718 "ꜘ" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42777 0xa719 "ꜙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42778 0xa71a "ꜚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42779 0xa71b "ꜛ" */
+0x00,0x00,0x00,0x00,0x10,0x38,0x7c,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42780 0xa71c "ꜜ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7c,0x38,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42781 0xa71d "ꜝ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42782 0xa71e "ꜞ" */
+0x00,0x00,0x00,0x10,0x00,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42783 0xa71f "ꜟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x10,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42784 0xa720 "꜠" */
+0x00,0x7e,0x50,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42785 0xa721 "꜡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0x50,0x7e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42786 0xa722 "Ꜣ" */
+0x00,0x00,0x70,0x78,0x04,0x04,0x38,0x00,0x00,0x70,0x78,0x04,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42787 0xa723 "ꜣ" */
+0x00,0x00,0x00,0x30,0x38,0x04,0x04,0x18,0x00,0x30,0x38,0x04,0x04,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42788 0xa724 "Ꜥ" */
+0x00,0x00,0x00,0x00,0x38,0x7c,0x60,0x40,0x40,0x40,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42789 0xa725 "ꜥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x7c,0x60,0x40,0x40,0x40,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42790 0xa726 "Ꜧ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x42,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42791 0xa727 "ꜧ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x42,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42792 0xa728 "Ꜩ" */
+0x00,0x00,0x00,0x00,0x3f,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0xf8,0x10,0x20,0x40,0x70,0x08,0x08,0x08,0xf0,
+/* 42793 0xa729 "ꜩ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x3f,0x08,0x08,0x08,0x08,0x08,0x06,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x08,0x10,0x20,0x38,0x04,0x04,0x84,0x78,
+/* 42794 0xa72a "Ꜫ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x48,0x50,0x30,0x4c,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42795 0xa72b "ꜫ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x20,0x20,0x18,0x20,0x20,0x20,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42796 0xa72c "Ꜭ" */
+0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0x44,0x7c,0x04,0x04,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42797 0xa72d "ꜭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0x7c,0x04,0x04,0x04,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42798 0xa72e "Ꜯ" */
+0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x48,0x88,0xfe,0x08,0x08,0x4b,0x31,0x01,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42799 0xa72f "ꜯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x18,0x28,0x48,0xfe,0x08,0x0b,0x09,0x49,0x32,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42800 0xa730 "ꜰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x40,0x40,0x78,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42801 0xa731 "ꜱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42802 0xa732 "Ꜳ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x21,0x21,0x3f,0x21,0x21,0x21,0x21,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,
+/* 42803 0xa733 "ꜳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x1f,0x21,0x21,0x23,0x1d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0xf8,0x08,0x08,0x18,0xe8,0x00,0x00,
+/* 42804 0xa734 "Ꜵ" */
+0x00,0x00,0x00,0x00,0x0c,0x13,0x13,0x21,0x21,0x3f,0x21,0x21,0x21,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 42805 0xa735 "ꜵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x1f,0x21,0x21,0x23,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 42806 0xa736 "Ꜷ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x21,0x21,0x3f,0x21,0x21,0x21,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 42807 0xa737 "ꜷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x1f,0x21,0x21,0x23,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0xe8,0x00,0x00,
+/* 42808 0xa738 "Ꜹ" */
+0x00,0x00,0x00,0x00,0x0e,0x12,0x12,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0x00,0x00,
+/* 42809 0xa739 "ꜹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x1f,0x21,0x21,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x90,0x90,0x90,0x60,0x60,0x00,0x00,
+/* 42810 0xa73a "Ꜻ" */
+0x00,0x00,0x00,0x00,0x0e,0x12,0x12,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x10,0xf8,0xa0,0xa0,0x40,0x40,0x00,0x00,
+/* 42811 0xa73b "ꜻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x1f,0x21,0x21,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0xfc,0x90,0x90,0x60,0x60,0x00,0x00,
+/* 42812 0xa73c "Ꜽ" */
+0x00,0x00,0x00,0x00,0x0e,0x12,0x12,0x21,0x21,0x3f,0x20,0x20,0x20,0x20,0x04,0x03,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x10,0x10,0x10,0xa0,0xa0,0x40,0x40,0x80,0x00,
+/* 42813 0xa73d "ꜽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x1f,0x21,0x21,0x22,0x1c,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x90,0x90,0x90,0x60,0x60,0x20,0xc0,
+/* 42814 0xa73e "Ꜿ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x1a,0x1a,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42815 0xa73f "ꜿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x1a,0x1a,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42816 0xa740 "Ꝁ" */
+0x00,0x00,0x00,0x00,0x42,0xe4,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42817 0xa741 "ꝁ" */
+0x00,0x00,0x00,0x40,0xf0,0x40,0x44,0x48,0x50,0x60,0x50,0x48,0x44,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42818 0xa742 "Ꝃ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x60,0x60,0x54,0x48,0x54,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42819 0xa743 "ꝃ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x54,0x48,0x54,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42820 0xa744 "Ꝅ" */
+0x00,0x00,0x00,0x00,0x42,0xe4,0x48,0x50,0x60,0x60,0x54,0x48,0x54,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42821 0xa745 "ꝅ" */
+0x00,0x00,0x00,0x40,0xf0,0x40,0x44,0x48,0x50,0x60,0x54,0x48,0x54,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42822 0xa746 "Ꝇ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x20,0x20,0x20,0x20,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42823 0xa747 "ꝇ" */
+0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42824 0xa748 "Ꝉ" */
+0x00,0x00,0x00,0x00,0x40,0xf0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42825 0xa749 "ꝉ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42826 0xa74a "Ꝋ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0xff,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42827 0xa74b "ꝋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0xff,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42828 0xa74c "Ꝍ" */
+0x00,0x00,0x00,0x02,0x75,0x89,0x8e,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42829 0xa74d "ꝍ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x75,0x89,0x8e,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42830 0xa74e "Ꝏ" */
+0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 42831 0xa74f "ꝏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x21,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,
+/* 42832 0xa750 "Ꝑ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x40,0x40,0x40,0xf0,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42833 0xa751 "ꝑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0xf0,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42834 0xa752 "Ꝓ" */
+0x00,0x00,0x00,0x00,0x1e,0x11,0x11,0x11,0x7e,0x90,0x90,0x90,0x50,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42835 0xa753 "ꝓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x16,0x19,0x11,0x11,0x11,0x11,0x79,0x96,0x90,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42836 0xa754 "Ꝕ" */
+0x00,0x00,0x00,0x00,0x4e,0xa9,0x29,0x29,0x1e,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42837 0xa755 "ꝕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4a,0xad,0x29,0x29,0x29,0x29,0x1d,0x0a,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42838 0xa756 "Ꝗ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x5a,0x64,0x3d,0x02,0x05,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42839 0xa757 "ꝗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x42,0x42,0x46,0x3a,0x07,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42840 0xa758 "Ꝙ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x10,0x10,0x10,0x16,0x19,0x0f,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x80,0x90,0x88,0x88,0x88,0x90,0x90,0x20,0x40,0x80,0x40,
+/* 42841 0xa759 "ꝙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x10,0x10,0x10,0x11,0x0e,0x01,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x88,0x88,0x88,0x90,0x90,0xa0,0xc0,0x80,0x80,
+/* 42842 0xa75a "Ꝛ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x02,0x04,0x08,0x08,0x04,0x04,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42843 0xa75b "ꝛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x1c,0x10,0x08,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42844 0xa75c "Ꝝ" */
+0x00,0x00,0x00,0x00,0x78,0x84,0x04,0x04,0x08,0x10,0x22,0x42,0x84,0xfe,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42845 0xa75d "ꝝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x08,0x12,0x22,0x44,0x7e,0x04,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42846 0xa75e "Ꝟ" */
+0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x32,0x32,0x22,0x54,0x54,0x88,0x88,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42847 0xa75f "ꝟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4a,0x4a,0x52,0x34,0x64,0x64,0x98,0x98,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42848 0xa760 "Ꝡ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42849 0xa761 "ꝡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x49,0x49,0x49,0x49,0x49,0x49,0x37,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42850 0xa762 "Ꝣ" */
+0x00,0x00,0x00,0x3c,0x40,0x40,0x40,0x3e,0x04,0x08,0x10,0x1c,0x02,0x02,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42851 0xa763 "ꝣ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x40,0x3c,0x08,0x10,0x20,0x38,0x04,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42852 0xa764 "Ꝥ" */
+0x00,0x00,0x50,0x60,0xc0,0x78,0x44,0x42,0x42,0x44,0x78,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42853 0xa765 "ꝥ" */
+0x00,0x00,0x00,0x50,0x60,0x40,0xdc,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42854 0xa766 "Ꝧ" */
+0x00,0x00,0x00,0x40,0x40,0x78,0x44,0x42,0x42,0x44,0x78,0x40,0xf0,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42855 0xa767 "ꝧ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x62,0x5c,0xf0,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42856 0xa768 "Ꝩ" */
+0x00,0x00,0x00,0x00,0x44,0x44,0x44,0x48,0x48,0x50,0x50,0x60,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42857 0xa769 "ꝩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x22,0x24,0x24,0x28,0x30,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42858 0xa76a "Ꝫ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x18,0x04,0x04,0x04,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42859 0xa76b "ꝫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x18,0x04,0x04,0x04,0x04,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42860 0xa76c "Ꝭ" */
+0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x7c,0x10,0x10,0x10,0x10,0x50,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42861 0xa76d "ꝭ" */
+0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x7c,0x10,0x10,0x10,0x10,0x10,0x10,0x50,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42862 0xa76e "Ꝯ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x4a,0x32,0x02,0x02,0x04,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42863 0xa76f "ꝯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x4a,0x32,0x02,0x02,0x04,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42864 0xa770 "ꝰ" */
+0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x4a,0x32,0x02,0x04,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42865 0xa771 "ꝱ" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x1d,0x23,0x21,0x21,0x21,0x21,0x23,0x1d,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x10,0x24,0xf8,0x40,0x80,
+/* 42866 0xa772 "ꝲ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3f,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x48,0xf0,0x80,0x00,
+/* 42867 0xa773 "ꝳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x10,0x24,0xf8,0x40,0x80,
+/* 42868 0xa774 "ꝴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x43,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x48,0xf0,0x80,0x00,
+/* 42869 0xa775 "ꝵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x19,0x12,0x10,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x20,0x20,0x40,0x90,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42870 0xa776 "ꝶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x50,0x48,0x44,0x43,0x00,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x48,0xf0,0x80,0x00,
+/* 42871 0xa777 "ꝷ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x7f,0x11,0x12,0x10,0x10,0x10,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x40,0x90,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42872 0xa778 "ꝸ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x38,0x1c,0x22,0x42,0x02,0xfc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42873 0xa779 "Ꝺ" */
+0x00,0x00,0x00,0x00,0xfc,0x22,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42874 0xa77a "ꝺ" */
+0x00,0x00,0x40,0x30,0x08,0x04,0x02,0x3e,0x42,0x42,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42875 0xa77b "Ꝼ" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x40,0x40,0x40,0x40,0x40,0x78,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42876 0xa77c "ꝼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x20,0x20,0x20,0x20,0x38,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42877 0xa77d "Ᵹ" */
+0x00,0x00,0x00,0x00,0x7e,0x04,0x08,0x10,0x10,0x08,0x38,0x44,0x44,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42878 0xa77e "Ꝿ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x1c,0x10,0x08,0x08,0x10,0x20,0x7e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42879 0xa77f "ꝿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x3c,0x10,0x08,0x08,0x10,0x20,0x7e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42880 0xa780 "Ꞁ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42881 0xa781 "ꞁ" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42882 0xa782 "Ꞃ" */
+0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42883 0xa783 "ꞃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x42,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42884 0xa784 "Ꞅ" */
+0x00,0x00,0x00,0x00,0x2e,0x30,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42885 0xa785 "ꞅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2e,0x30,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42886 0xa786 "Ꞇ" */
+0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42887 0xa787 "ꞇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42888 0xa788 "ꞈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42889 0xa789 "꞉" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42890 0xa78a "꞊" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x00,0x3c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42891 0xa78b "Ꞌ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42892 0xa78c "ꞌ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42893 0xa78d "Ɥ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42894 0xa78e "ꞎ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x38,0x48,0x3e,0x08,0x08,0x08,0x08,0x08,0x06,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42895 0xa78f "ꞏ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x3c,0x3c,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42896 0xa790 "Ꞑ" */
+0x00,0x00,0x00,0x00,0x44,0x64,0x64,0x54,0x54,0x4c,0x4c,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42897 0xa791 "ꞑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x58,0x64,0x44,0x44,0x44,0x44,0x44,0x46,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42898 0xa792 "Ꞓ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x20,0x70,0x20,0x20,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42899 0xa793 "ꞓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x20,0x70,0x20,0x20,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42900 0xa794 "ꞔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3e,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42901 0xa795 "ꞕ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x42,0x42,0x43,0x01,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42902 0xa796 "Ꞗ" */
+0x00,0x00,0x00,0x00,0x1c,0x12,0x12,0x12,0x3c,0x52,0x52,0x52,0x12,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42903 0xa797 "ꞗ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x1c,0x32,0x52,0x52,0x52,0x5c,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42904 0xa798 "Ꞙ" */
+0x00,0x00,0x00,0x00,0x7e,0x40,0xf0,0x40,0x7c,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42905 0xa799 "ꞙ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x7c,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42906 0xa79a "Ꞛ" */
+0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x22,0x12,0x22,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42907 0xa79b "ꞛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x32,0x22,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42908 0xa79c "Ꞝ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x42,0x22,0x12,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42909 0xa79d "ꞝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x42,0x32,0x22,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42910 0xa79e "Ꞟ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x22,0x12,0x22,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42911 0xa79f "ꞟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x32,0x22,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42912 0xa7a0 "Ꞡ" */
+0x00,0x00,0x00,0x00,0x3d,0x42,0x46,0x48,0x50,0x66,0x42,0xc2,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42913 0xa7a1 "ꞡ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x3a,0x47,0x7c,0xc4,0x38,0x20,0x3c,0x42,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42914 0xa7a2 "Ꞣ" */
+0x00,0x00,0x00,0x00,0x42,0x44,0x48,0x50,0x62,0x64,0x58,0x68,0xc4,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42915 0xa7a3 "ꞣ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x44,0x48,0x50,0x60,0x56,0x78,0xc4,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42916 0xa7a4 "Ꞥ" */
+0x00,0x00,0x00,0x00,0x42,0x62,0x63,0x56,0x5a,0x6a,0xca,0x46,0x46,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42917 0xa7a5 "ꞥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x63,0x4e,0x72,0xc2,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42918 0xa7a6 "Ꞧ" */
+0x00,0x00,0x00,0x00,0x7c,0x47,0x5a,0xe2,0x7c,0x48,0x44,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42919 0xa7a7 "ꞧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x50,0x60,0x40,0xc0,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42920 0xa7a8 "Ꞩ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x4c,0x30,0xcc,0x02,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42921 0xa7a9 "ꞩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x26,0x18,0x66,0x01,0x21,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42922 0xa7aa "Ɦ" */
+0x00,0x00,0x00,0x00,0x62,0xa2,0xa2,0x22,0x3e,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42923 0xa7ab "Ɜ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x02,0x02,0x1c,0x02,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42924 0xa7ac "Ɡ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x4a,0x32,0x04,0x78,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42925 0xa7ad "Ɬ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x30,0x50,0x54,0x38,0x10,0x10,0x1e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42926 0xa7ae "Ɪ" */
+0x00,0x00,0x00,0x00,0x7f,0x49,0x49,0x08,0x08,0x08,0x08,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42927 0xa7af "ꞯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x42,0x5a,0x66,0x3c,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42928 0xa7b0 "Ʞ" */
+0x00,0x00,0x00,0x00,0x42,0x22,0x12,0x0a,0x06,0x06,0x0a,0x12,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42929 0xa7b1 "Ʇ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42930 0xa7b2 "Ʝ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x04,0x24,0x54,0x4c,0x38,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42931 0xa7b3 "Ꭓ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x18,0x24,0x24,0x42,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42932 0xa7b4 "Ꞵ" */
+0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x42,0x7c,0x42,0x42,0x42,0x42,0x7c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42933 0xa7b5 "ꞵ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x48,0x58,0x44,0x42,0x42,0x52,0x4c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42934 0xa7b6 "Ꞷ" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x41,0x41,0x41,0x41,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42935 0xa7b7 "ꞷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x55,0x41,0x41,0x49,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42936 0xa7b8 "Ꞹ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x43,0x42,0x46,0x4a,0x52,0x62,0x42,0xbc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42937 0xa7b9 "ꞹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x43,0x42,0x46,0x4a,0x52,0x62,0x46,0xba,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42938 0xa7ba "Ꞻ" */
+0x00,0x00,0x00,0x60,0x28,0x54,0x14,0x22,0x22,0x3e,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42939 0xa7bb "ꞻ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x3c,0x42,0x02,0x3e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42940 0xa7bc "Ꞽ" */
+0x00,0x00,0x00,0x60,0x3e,0x48,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42941 0xa7bd "ꞽ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42942 0xa7be "Ꞿ" */
+0x00,0x00,0x00,0xc0,0x62,0xa2,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42943 0xa7bf "ꞿ" */
+0x00,0x00,0x18,0x08,0x10,0x00,0x42,0x42,0x42,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42944 0xa7c0 "Ꟁ" */
+0x00,0x00,0x10,0x10,0x7c,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x7c,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42945 0xa7c1 "ꟁ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x7c,0x82,0x82,0x82,0x82,0x82,0x82,0x7c,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42946 0xa7c2 "Ꟃ" */
+0x00,0x00,0x00,0x01,0x41,0x41,0x41,0x22,0x22,0x22,0x15,0x15,0x08,0x08,0x00,0x00,
+0x00,0x00,0x80,0x00,0x70,0x88,0x08,0x08,0x70,0x08,0x08,0x08,0x88,0x70,0x00,0x00,
+/* 42947 0xa7c3 "ꟃ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x42,0x43,0x42,0x26,0x25,0x25,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x70,0x08,0x08,0x88,0x70,0x00,0x00,
+/* 42948 0xa7c4 "Ꞔ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x46,0x3a,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42949 0xa7c5 "Ʂ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x0c,0x02,0x42,0x62,0x5c,0x40,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42950 0xa7c6 "Ᶎ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x04,0x08,0x10,0x20,0x40,0x42,0x7e,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42951 0xa7c7 "Ꟈ" */
+0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x7e,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42952 0xa7c8 "ꟈ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x3a,0x46,0x42,0x7e,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42953 0xa7c9 "Ꟊ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x20,0x10,0x7e,0x04,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42954 0xa7ca "ꟊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x30,0x7e,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42955 0xa7cb "Ɤ" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 42956 0xa7cc "Ꟍ" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42957 0xa7cd "ꟍ" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42958 0xa7ce "꟎" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42959 0xa7cf "꟏" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42960 0xa7d0 "Ꟑ" */
+0x00,0x00,0x00,0x00,0xfe,0x44,0x44,0x44,0x38,0x10,0x08,0x04,0x44,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42961 0xa7d1 "ꟑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x44,0x44,0x44,0x38,0x08,0x04,0x44,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42962 0xa7d2 "꟒" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 42963 0xa7d3 "ꟓ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x5c,0x62,0x42,0x7c,0x42,0x42,0x62,0x5c,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42964 0xa7d4 "꟔" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 42965 0xa7d5 "ꟕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x5c,0x62,0x42,0x42,0x5c,0x60,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42966 0xa7d6 "Ꟗ" */
+0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x48,0x48,0x44,0x44,0x44,0x48,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42967 0xa7d7 "ꟗ" */
+0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0xe4,0x24,0x22,0x22,0x22,0x24,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42968 0xa7d8 "Ꟙ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x40,0x30,0x3c,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42969 0xa7d9 "ꟙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x3c,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42970 0xa7da "Ꟛ" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 42971 0xa7db "ꟛ" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 42972 0xa7dc "Ƛ" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42973 0xa7dd "꟝" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42974 0xa7de "꟞" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42975 0xa7df "꟟" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42976 0xa7e0 "꟠" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 42977 0xa7e1 "꟡" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 42978 0xa7e2 "꟢" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 42979 0xa7e3 "꟣" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 42980 0xa7e4 "꟤" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 42981 0xa7e5 "꟥" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 42982 0xa7e6 "꟦" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 42983 0xa7e7 "꟧" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 42984 0xa7e8 "꟨" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 42985 0xa7e9 "꟩" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 42986 0xa7ea "꟪" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 42987 0xa7eb "꟫" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 42988 0xa7ec "꟬" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 42989 0xa7ed "꟭" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 42990 0xa7ee "꟮" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 42991 0xa7ef "꟯" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 42992 0xa7f0 "꟰" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 42993 0xa7f1 "꟱" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 42994 0xa7f2 "ꟲ" */
+0x00,0x3c,0x42,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42995 0xa7f3 "ꟳ" */
+0x00,0x7e,0x40,0x40,0x7c,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42996 0xa7f4 "ꟴ" */
+0x00,0x3c,0x42,0x42,0x52,0x4a,0x3c,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42997 0xa7f5 "Ꟶ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42998 0xa7f6 "ꟶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 42999 0xa7f7 "ꟷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x7e,0x42,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43000 0xa7f8 "ꟸ" */
+0x00,0x00,0x00,0x42,0xff,0x42,0x7e,0x42,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43001 0xa7f9 "ꟹ" */
+0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x4f,0x48,0x37,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43002 0xa7fa "ꟺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43003 0xa7fb "ꟻ" */
+0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x3e,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43004 0xa7fc "ꟼ" */
+0x00,0x00,0x00,0x00,0x3e,0x42,0x42,0x42,0x3e,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43005 0xa7fd "ꟽ" */
+0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43006 0xa7fe "ꟾ" */
+0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43007 0xa7ff "ꟿ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x28,0x28,0x28,0x45,0x45,0x82,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x41,0x41,0x41,0xa2,0xa2,0xa2,0x14,0x14,0x08,0x08,0x00,0x00,
+/* 43008 0xa800 "ꠀ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x08,0x00,0x00,0x00,
+/* 43009 0xa801 "ꠁ" */
+0x00,0x00,0x00,0xff,0x04,0x05,0x06,0x04,0x01,0x06,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 43010 0xa802 "ꠂ" */
+0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43011 0xa803 "ꠃ" */
+0x00,0x00,0x00,0xff,0x08,0x11,0x22,0x24,0x20,0x21,0x20,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0xe0,0x10,0x10,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 43012 0xa804 "ꠄ" */
+0x0e,0x01,0x00,0xff,0x10,0x10,0x10,0x11,0x1e,0x10,0x10,0x10,0x08,0x00,0x00,0x00,
+0x00,0x00,0x80,0xff,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43013 0xa805 "ꠅ" */
+0x00,0x00,0x00,0xff,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x18,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0xc0,0x40,0x40,0xc0,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 43014 0xa806 "꠆" */
+0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0xa0,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43015 0xa807 "ꠇ" */
+0x00,0x00,0x00,0xff,0x22,0x22,0x23,0x2e,0x32,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43016 0xa808 "ꠈ" */
+0x00,0x00,0x00,0xff,0x26,0x2a,0x33,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43017 0xa809 "ꠉ" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x04,0x0c,0x14,0x14,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x00,0x00,0x00,
+/* 43018 0xa80a "ꠊ" */
+0x00,0x00,0x00,0xff,0x00,0x03,0x04,0x03,0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0xc0,0x40,0x40,0x40,0xc0,0x40,0x40,0x40,0xe0,0x00,0x00,0x00,
+/* 43019 0xa80b "ꠋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43020 0xa80c "ꠌ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x02,0x04,0x08,0x06,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0xc0,0x20,0x00,0x00,0x00,
+/* 43021 0xa80d "ꠍ" */
+0x00,0x00,0x00,0xff,0x10,0x11,0x12,0x14,0x19,0x02,0x04,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x80,0x80,0x80,0xe0,0x90,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 43022 0xa80e "ꠎ" */
+0x00,0x00,0x00,0xff,0x08,0x10,0x21,0x21,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0x20,0xe0,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43023 0xa80f "ꠏ" */
+0x00,0x00,0x00,0xff,0x20,0x26,0x2a,0x32,0x02,0x02,0x02,0x02,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x28,0x28,0x48,0x48,0x90,0x90,0x20,0x00,0x00,0x00,
+/* 43024 0xa810 "ꠐ" */
+0x00,0x00,0x00,0xff,0x07,0x08,0x08,0x04,0x01,0x02,0x04,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x80,0x40,0x80,0x00,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43025 0xa811 "ꠑ" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x0b,0x0c,0x08,0x08,0x09,0x0a,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43026 0xa812 "ꠒ" */
+0x00,0x00,0x00,0xff,0x01,0x01,0x09,0x11,0x11,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x60,0x90,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43027 0xa813 "ꠓ" */
+0x00,0x00,0x00,0xff,0x08,0x08,0x09,0x0a,0x0a,0x08,0x08,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x80,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43028 0xa814 "ꠔ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x18,0x1f,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0x20,0x00,0x00,0x00,
+/* 43029 0xa815 "ꠕ" */
+0x00,0x00,0x00,0xff,0x00,0x02,0x06,0x2b,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x20,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43030 0xa816 "ꠖ" */
+0x00,0x00,0x00,0xff,0x10,0x11,0x12,0x14,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x40,0x30,0x00,0x00,0x00,
+/* 43031 0xa817 "ꠗ" */
+0x00,0x00,0x00,0xff,0x20,0x20,0x13,0x0d,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x08,0x00,0x00,0x00,
+/* 43032 0xa818 "ꠘ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x02,0x05,0x05,0x05,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43033 0xa819 "ꠙ" */
+0x00,0x00,0x00,0xff,0x20,0x20,0x21,0x22,0x24,0x28,0x30,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43034 0xa81a "ꠚ" */
+0x00,0x00,0x00,0xff,0x40,0x41,0x42,0x44,0x48,0x50,0x60,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0xc0,0x70,0x48,0x50,0x60,0x50,0x48,0x40,0x20,0x00,0x00,0x00,
+/* 43035 0xa81b "ꠛ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x40,0x40,0xc0,0xc0,0x40,0x40,0x40,0x20,0x00,0x00,0x00,
+/* 43036 0xa81c "ꠜ" */
+0x00,0x00,0x00,0xff,0x01,0x02,0x04,0x1e,0x25,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0xe0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43037 0xa81d "ꠝ" */
+0x00,0x00,0x00,0xff,0x40,0x20,0x11,0x0a,0x04,0x0a,0x0a,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43038 0xa81e "ꠞ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43039 0xa81f "ꠟ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x01,0x12,0x0c,0x00,0x01,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0xa0,0x20,0x20,0x90,0x00,0x00,0x00,
+/* 43040 0xa820 "ꠠ" */
+0x00,0x00,0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x60,0x90,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43041 0xa821 "ꠡ" */
+0x00,0x00,0x00,0xff,0x00,0x0e,0x11,0x11,0x02,0x05,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x10,0x30,0x50,0x90,0x10,0x10,0x90,0x90,0x08,0x00,0x00,0x00,
+/* 43042 0xa822 "ꠢ" */
+0x00,0x00,0x00,0xff,0x20,0x20,0x21,0x22,0x24,0x28,0x31,0x22,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x60,0xa0,0x20,0x20,0x20,0xa0,0x20,0x20,0x90,0x00,0x00,0x00,
+/* 43043 0xa823 "ꠣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+/* 43044 0xa824 "ꠤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x0c,0x12,0x02,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+/* 43045 0xa825 "ꠥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x10,0xe0,0x00,
+/* 43046 0xa826 "ꠦ" */
+0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43047 0xa827 "ꠧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x04,0x02,0x0f,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+/* 43048 0xa828 "꠨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43049 0xa829 "꠩" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43050 0xa82a "꠪" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43051 0xa82b "꠫" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0c,0x00,0x0c,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x60,0x00,0x60,0x90,0x90,0x60,0x00,0x00,0x00,
+/* 43052 0xa82c "꠬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,
+/* 43053 0xa82d "꠭" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43054 0xa82e "꠮" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43055 0xa82f "꠯" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43056 0xa830 "꠰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43057 0xa831 "꠱" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 43058 0xa832 "꠲" */
+0x00,0x00,0x00,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+/* 43059 0xa833 "꠳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43060 0xa834 "꠴" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x00,0x00,0x03,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x00,0x70,0x80,0x00,0x00,0x00,0x00,
+/* 43061 0xa835 "꠵" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x1c,0x00,0x03,0x1c,0x00,0x03,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x80,0x00,0x70,0x80,0x00,0x70,0x80,0x00,0x00,0x00,0x00,
+/* 43062 0xa836 "꠶" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43063 0xa837 "꠷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43064 0xa838 "꠸" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 43065 0xa839 "꠹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x70,0x80,0x80,0x80,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43066 0xa83a "꠺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43067 0xa83b "꠻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43068 0xa83c "꠼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43069 0xa83d "꠽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43070 0xa83e "꠾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43071 0xa83f "꠿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43072 0xa840 "ꡀ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x7f,0x40,0x40,0x7f,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0xfe,0x00,0x00,0xfe,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43073 0xa841 "ꡁ" */
+0x00,0x00,0x00,0x4f,0x48,0x48,0x48,0x78,0x48,0x48,0x4f,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0xfe,0x00,0x00,0x00,
+/* 43074 0xa842 "ꡂ" */
+0x00,0x00,0x00,0x7f,0x40,0x4f,0x48,0x48,0x78,0x48,0x48,0x48,0x4f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0xf8,0x00,0x00,0x00,
+/* 43075 0xa843 "ꡃ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,
+/* 43076 0xa844 "ꡄ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,
+/* 43077 0xa845 "ꡅ" */
+0x00,0x00,0x00,0x41,0x41,0x41,0x41,0x41,0x7f,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,
+/* 43078 0xa846 "ꡆ" */
+0x00,0x00,0x00,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,
+/* 43079 0xa847 "ꡇ" */
+0x00,0x00,0x00,0x7f,0x41,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x80,0x40,0x20,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43080 0xa848 "ꡈ" */
+0x00,0x00,0x00,0x40,0x40,0x41,0x41,0x40,0x7f,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x74,0x88,0x00,0x00,0xc0,0xfc,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
+/* 43081 0xa849 "ꡉ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x71,0x49,0x45,0x43,0x43,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0xc4,0x24,0x14,0x0c,0x0c,0x04,0x00,0x00,0x00,
+/* 43082 0xa84a "ꡊ" */
+0x00,0x00,0x00,0x40,0x40,0x41,0x41,0x71,0x49,0x45,0x43,0x43,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43083 0xa84b "ꡋ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x41,0x42,0x44,0x44,0x44,0x44,0x43,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x60,0x80,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43084 0xa84c "ꡌ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,
+/* 43085 0xa84d "ꡍ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x7e,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43086 0xa84e "ꡎ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x7f,0x41,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,
+/* 43087 0xa84f "ꡏ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x7f,0x42,0x44,0x44,0x44,0x44,0x43,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x60,0x80,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43088 0xa850 "ꡐ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x41,0x42,0x7e,0x42,0x41,0x40,0x47,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x80,0x80,0xe0,0x10,0x08,0x48,0x88,0x10,0xe0,0x00,0x00,0x00,
+/* 43089 0xa851 "ꡑ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x41,0x43,0x40,0x40,0x40,0x40,0x43,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x40,0x80,0x00,0xe0,0x10,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 43090 0xa852 "ꡒ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x41,0x41,0x41,0x7f,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x02,0x02,0x02,0xfe,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 43091 0xa853 "ꡓ" */
+0x00,0x00,0x00,0x40,0x44,0x44,0x47,0x7c,0x47,0x44,0x44,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xd0,0x10,0x10,0x10,0xd0,0x30,0x00,0xff,0x00,0x00,0x00,
+/* 43092 0xa854 "ꡔ" */
+0x00,0x00,0x00,0x7c,0x43,0x40,0x41,0x42,0x42,0x42,0x41,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1f,0x60,0x80,0x40,0x20,0x20,0x20,0xc0,0x00,0xfe,0x00,0x00,0x00,
+/* 43093 0xa855 "ꡕ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 43094 0xa856 "ꡖ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43095 0xa857 "ꡗ" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0xe0,0x10,0x08,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 43096 0xa858 "ꡘ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 43097 0xa859 "ꡙ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x7f,0x41,0x41,0x41,0x40,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0xfc,0x00,0x00,0x00,
+/* 43098 0xa85a "ꡚ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x41,0x41,0x41,0x41,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 43099 0xa85b "ꡛ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x23,0x2c,0x30,0x28,0x24,0x22,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x30,0xc0,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43100 0xa85c "ꡜ" */
+0x00,0x00,0x00,0x41,0x42,0x44,0x44,0x42,0x41,0x60,0x51,0x4a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe2,0x14,0x08,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43101 0xa85d "ꡝ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x23,0x2c,0x30,0x2b,0x24,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x30,0xc0,0x00,0x00,0xf0,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 43102 0xa85e "ꡞ" */
+0x00,0x00,0x00,0x7f,0x41,0x42,0x44,0x48,0x48,0x48,0x48,0x44,0x43,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x80,0x00,0x00,0x40,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43103 0xa85f "ꡟ" */
+0x00,0x00,0x00,0x40,0x41,0x42,0x44,0x7c,0x44,0x43,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x88,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 43104 0xa860 "ꡠ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43105 0xa861 "ꡡ" */
+0x00,0x00,0x00,0x40,0x40,0x43,0x4c,0x70,0x70,0x4c,0x43,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x30,0xc0,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x00,0x00,0x00,
+/* 43106 0xa862 "ꡢ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x78,0x47,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
+/* 43107 0xa863 "ꡣ" */
+0x00,0x00,0x00,0x7f,0x41,0x41,0x41,0x71,0x49,0x45,0x43,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x04,0x04,0x04,0xc4,0x24,0x14,0x0c,0x00,0xff,0x00,0x00,0x00,
+/* 43108 0xa864 "ꡤ" */
+0x00,0x00,0x00,0x43,0x44,0x44,0x44,0x42,0x41,0x60,0x51,0x4a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0xcf,0x31,0x11,0x09,0x09,0x05,0x85,0x03,0x03,0x01,0x00,0x00,0x00,
+/* 43109 0xa865 "ꡥ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x47,0x78,0x40,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,
+/* 43110 0xa866 "ꡦ" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0xf0,0x00,0x00,0x00,
+/* 43111 0xa867 "ꡧ" */
+0x00,0x00,0x00,0x1f,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x44,0x24,0x14,0x0c,0x00,0x00,0x00,
+/* 43112 0xa868 "ꡨ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x02,0x02,0x02,0x04,0x04,0x08,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 43113 0xa869 "ꡩ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x7f,0x40,0x41,0x41,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfc,0xc0,0x00,0x00,0x88,0x74,0x00,0x00,0x00,
+/* 43114 0xa86a "ꡪ" */
+0x00,0x00,0x00,0x41,0x43,0x43,0x45,0x49,0x71,0x41,0x41,0x41,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x0c,0x0c,0x14,0x24,0xc4,0x04,0x04,0x04,0xff,0x00,0x00,0x00,
+/* 43115 0xa86b "ꡫ" */
+0x00,0x00,0x00,0x41,0x43,0x43,0x45,0x49,0x71,0x41,0x41,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,
+/* 43116 0xa86c "ꡬ" */
+0x00,0x00,0x00,0x43,0x44,0x44,0x44,0x44,0x42,0x41,0x40,0x40,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x80,0x60,0xf0,0x00,0x00,0x00,
+/* 43117 0xa86d "ꡭ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x08,0x06,0x01,0x00,0x00,0x00,0x01,0x06,0x08,0x00,
+0x00,0x00,0x00,0xfe,0x06,0x18,0x60,0x80,0xfc,0x02,0x02,0x02,0xfc,0x00,0x00,0x00,
+/* 43118 0xa86e "ꡮ" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x41,0x41,0x41,0x46,0x58,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+/* 43119 0xa86f "ꡯ" */
+0x00,0x00,0x00,0x41,0x42,0x44,0x44,0x42,0x41,0x60,0x51,0x4a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x04,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43120 0xa870 "ꡰ" */
+0x00,0x00,0x00,0x40,0x43,0x44,0x44,0x42,0x41,0x60,0x51,0x4a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0x3f,0x51,0x91,0x09,0x09,0x05,0x85,0x03,0x03,0x01,0x00,0x00,0x00,
+/* 43121 0xa871 "ꡱ" */
+0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x06,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43122 0xa872 "ꡲ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43123 0xa873 "ꡳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x1f,0x3f,0x1f,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x10,0x18,0x18,0x18,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 43124 0xa874 "꡴" */
+0x00,0x00,0x00,0x7f,0x40,0x40,0x41,0x41,0x41,0x7f,0x00,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0xff,0x00,0x00,0x00,
+/* 43125 0xa875 "꡵" */
+0x00,0x00,0x7f,0x40,0x41,0x7f,0x00,0x7f,0x40,0x41,0x7f,0x00,0x7f,0x00,0x00,0x00,
+0x00,0x00,0xff,0x01,0x01,0x01,0x01,0xff,0x01,0x01,0x01,0x01,0xff,0x00,0x00,0x00,
+/* 43126 0xa876 "꡶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43127 0xa877 "꡷" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 43128 0xa878 "꡸" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43129 0xa879 "꡹" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43130 0xa87a "꡺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43131 0xa87b "꡻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43132 0xa87c "꡼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43133 0xa87d "꡽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43134 0xa87e "꡾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43135 0xa87f "꡿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43136 0xa880 "ꢀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43137 0xa881 "ꢁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x00,0x04,0x0a,0x0a,0x04,0x00,0x00,0x00,
+/* 43138 0xa882 "ꢂ" */
+0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x02,0x7c,0x80,0x80,0x81,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43139 0xa883 "ꢃ" */
+0x00,0x00,0x00,0x00,0x36,0x49,0x49,0x02,0x7c,0x81,0x80,0x81,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 43140 0xa884 "ꢄ" */
+0x00,0x00,0x00,0x00,0x63,0x94,0xa4,0x82,0x61,0x81,0x81,0x82,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43141 0xa885 "ꢅ" */
+0x00,0x00,0x00,0x00,0x63,0x94,0xa7,0x82,0x61,0x81,0x81,0x82,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43142 0xa886 "ꢆ" */
+0x00,0x00,0x00,0x00,0xcf,0x30,0x29,0x4c,0x92,0x82,0x82,0x84,0x78,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43143 0xa887 "ꢇ" */
+0x00,0x00,0x00,0x00,0xce,0x31,0x28,0x4c,0x92,0x82,0x82,0x84,0x78,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43144 0xa888 "ꢈ" */
+0x00,0x00,0x00,0x00,0x4c,0x92,0x92,0x62,0x04,0x78,0x80,0x81,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43145 0xa889 "ꢉ" */
+0x00,0x00,0x00,0x00,0x4c,0x92,0x92,0x62,0x04,0x79,0x80,0x81,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,
+/* 43146 0xa88a "ꢊ" */
+0x00,0x00,0x00,0x00,0x77,0x88,0x88,0x80,0x80,0xbe,0x84,0x88,0x47,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43147 0xa88b "ꢋ" */
+0x00,0x00,0x00,0x00,0x77,0x88,0x88,0x80,0x80,0xbe,0x84,0x88,0x47,0x06,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43148 0xa88c "ꢌ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x80,0x93,0x94,0x94,0x8f,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43149 0xa88d "ꢍ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x80,0xa4,0xaa,0xaa,0x9c,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43150 0xa88e "ꢎ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x80,0xa9,0xaa,0xaa,0x97,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43151 0xa88f "ꢏ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x9e,0xa1,0x91,0x86,0x99,0x41,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43152 0xa890 "ꢐ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x9c,0xa2,0x92,0x84,0x9a,0x42,0x3c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43153 0xa891 "ꢑ" */
+0x00,0x00,0x00,0x00,0x3f,0x40,0x90,0xa9,0x8a,0xb2,0x8f,0x49,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43154 0xa892 "ꢒ" */
+0x00,0x00,0x00,0x00,0x27,0x58,0x50,0x28,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43155 0xa893 "ꢓ" */
+0x00,0x00,0x00,0x00,0x84,0x4a,0x27,0x24,0x48,0x49,0x92,0x92,0x61,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xa0,0xc0,0x40,0x40,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43156 0xa894 "ꢔ" */
+0x00,0x00,0x00,0x00,0x67,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x73,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43157 0xa895 "ꢕ" */
+0x00,0x00,0x00,0x00,0x62,0x95,0xa5,0x82,0x65,0x85,0x88,0x88,0x73,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43158 0xa896 "ꢖ" */
+0x00,0x00,0x00,0x00,0x7f,0x80,0x80,0xb8,0x44,0xb8,0x80,0x80,0x43,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43159 0xa897 "ꢗ" */
+0x00,0x00,0x00,0x00,0x61,0x92,0x50,0x10,0xf8,0x41,0x81,0x82,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43160 0xa898 "ꢘ" */
+0x00,0x00,0x00,0x00,0x63,0x94,0xa2,0x80,0x70,0x81,0x81,0x82,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43161 0xa899 "ꢙ" */
+0x00,0x00,0x00,0x00,0x77,0x88,0x88,0x80,0xa0,0xd0,0x90,0x94,0x63,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43162 0xa89a "ꢚ" */
+0x00,0x00,0x00,0x00,0x77,0x88,0x94,0xa2,0xa2,0x94,0x88,0x94,0x49,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43163 0xa89b "ꢛ" */
+0x00,0x00,0x00,0x00,0x3c,0x42,0x89,0x95,0x95,0x8f,0x91,0x92,0x4c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43164 0xa89c "ꢜ" */
+0x00,0x00,0x00,0x00,0xff,0x40,0x38,0x06,0x71,0x88,0x90,0x81,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43165 0xa89d "ꢝ" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x80,0x80,0x80,0x80,0x80,0x41,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43166 0xa89e "ꢞ" */
+0x00,0x00,0x00,0x00,0x7f,0x01,0x22,0x47,0x88,0x80,0x80,0x41,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43167 0xa89f "ꢟ" */
+0x00,0x00,0x00,0x00,0x02,0x85,0x44,0x25,0x52,0x40,0x40,0x21,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43168 0xa8a0 "ꢠ" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x8c,0x92,0x92,0xba,0x82,0x44,0x39,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43169 0xa8a1 "ꢡ" */
+0x00,0x00,0x00,0x00,0x3e,0x41,0x80,0x80,0x80,0x80,0x80,0x40,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43170 0xa8a2 "ꢢ" */
+0x00,0x00,0x00,0x00,0x33,0x48,0x10,0x21,0x42,0x34,0x08,0x14,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43171 0xa8a3 "ꢣ" */
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x48,0x10,0x62,0x81,0x83,0x7c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,
+/* 43172 0xa8a4 "ꢤ" */
+0x00,0x00,0x00,0x00,0x63,0x94,0xa0,0x80,0x60,0x80,0x80,0x81,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43173 0xa8a5 "ꢥ" */
+0x00,0x00,0x00,0x00,0x3d,0x42,0x83,0x82,0x82,0xa2,0x52,0x52,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43174 0xa8a6 "ꢦ" */
+0x00,0x00,0x00,0x00,0x43,0xa0,0x10,0x11,0x21,0x22,0x42,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43175 0xa8a7 "ꢧ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x43,0x42,0x84,0x94,0x88,0x41,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43176 0xa8a8 "ꢨ" */
+0x00,0x00,0x00,0x00,0xb6,0xb9,0x61,0x02,0x7c,0x81,0x80,0x80,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43177 0xa8a9 "ꢩ" */
+0x00,0x00,0x00,0x00,0x4d,0x92,0x92,0x90,0x90,0x90,0x90,0x90,0x61,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43178 0xa8aa "ꢪ" */
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x44,0x18,0x60,0x80,0xb8,0x47,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43179 0xa8ab "ꢫ" */
+0x00,0x00,0x00,0x00,0x43,0xa0,0x50,0x11,0x21,0x22,0x42,0x44,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43180 0xa8ac "ꢬ" */
+0x00,0x00,0x00,0x00,0xf7,0x14,0x12,0x22,0x21,0x41,0x40,0xf8,0xc7,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43181 0xa8ad "ꢭ" */
+0x00,0x00,0x00,0x00,0x77,0x88,0x88,0x80,0x80,0x80,0x80,0x80,0x63,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43182 0xa8ae "ꢮ" */
+0x00,0x00,0x00,0x00,0xe3,0x80,0x41,0x22,0x14,0x08,0x14,0x14,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43183 0xa8af "ꢯ" */
+0x00,0x00,0x00,0x00,0x39,0x44,0x84,0x94,0xa8,0x94,0x84,0x84,0x63,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43184 0xa8b0 "ꢰ" */
+0x00,0x00,0x00,0x00,0x61,0x92,0xd2,0xa1,0x82,0x82,0x84,0x44,0x39,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43185 0xa8b1 "ꢱ" */
+0x00,0x00,0x00,0x00,0x48,0xb5,0x99,0x91,0x88,0x88,0x84,0x84,0x83,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43186 0xa8b2 "ꢲ" */
+0x00,0x00,0x00,0x00,0xff,0x10,0x20,0x71,0xa8,0x90,0x80,0x41,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43187 0xa8b3 "ꢳ" */
+0x00,0x00,0x00,0x00,0x6b,0x94,0x94,0x80,0x80,0x80,0x80,0x81,0x66,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43188 0xa8b4 "ꢴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0x0e,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 43189 0xa8b5 "ꢵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x2e,0x12,0x14,0x04,0x08,0x08,0x10,0x10,0x0c,0x00,0x00,0x00,
+/* 43190 0xa8b6 "ꢶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x3c,0x42,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43191 0xa8b7 "ꢷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x0a,0x04,0x00,0x00,0x00,
+/* 43192 0xa8b8 "ꢸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x2a,0x3a,0x34,0x10,0x28,0x28,0x28,0x10,0x00,0x00,0x00,
+/* 43193 0xa8b9 "ꢹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x50,0x34,0x3a,0x34,0x10,0x28,0x28,0x28,0x10,0x00,0x00,0x00,
+/* 43194 0xa8ba "ꢺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x2a,0x24,0x20,0x1c,0x02,0x02,0x22,0x1c,0x00,0x00,0x00,
+/* 43195 0xa8bb "ꢻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x2a,0x24,0x20,0x1c,0x02,0x02,0x22,0x1c,0x40,0x3c,0x02,
+/* 43196 0xa8bc "ꢼ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xdc,0x22,0x22,0x22,0x26,0x2a,0x2a,0x2a,0xa4,0x00,0x00,0x00,
+/* 43197 0xa8bd "ꢽ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x02,0x01,0x00,
+0x00,0x00,0x00,0x00,0xdc,0x22,0x22,0x22,0x26,0x2a,0x2a,0x2a,0xa4,0x00,0xf0,0x08,
+/* 43198 0xa8be "ꢾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x16,0x0a,0x02,0x02,0x04,0x08,0x00,0x00,0x00,
+/* 43199 0xa8bf "ꢿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0x22,0x14,0x04,0x08,0x08,0x12,0x12,0x0c,0x00,0x00,0x00,
+/* 43200 0xa8c0 "ꣀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x26,0x1a,0x02,0x02,0x0a,0x16,0x0c,0x00,0x00,0x00,
+/* 43201 0xa8c1 "ꣁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3e,0x22,0x12,0x04,0x38,0x08,0x08,0x0a,0x04,0x00,0x00,0x00,
+/* 43202 0xa8c2 "ꣂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7e,0x46,0x2a,0x0a,0x72,0x0a,0x0a,0x0a,0x04,0x00,0x00,0x00,
+/* 43203 0xa8c3 "ꣃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe4,0x9a,0x1a,0x1c,0x18,0x18,0x38,0x5a,0x24,0x00,0x00,0x00,
+/* 43204 0xa8c4 "꣄" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x08,
+/* 43205 0xa8c5 "ꣅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x04,0x0a,0x0a,0x04,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43206 0xa8c6 "꣆" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 43207 0xa8c7 "꣇" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43208 0xa8c8 "꣈" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43209 0xa8c9 "꣉" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43210 0xa8ca "꣊" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43211 0xa8cb "꣋" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43212 0xa8cc "꣌" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43213 0xa8cd "꣍" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43214 0xa8ce "꣎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43215 0xa8cf "꣏" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 43216 0xa8d0 "꣐" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 43217 0xa8d1 "꣑" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xc0,0x40,0x80,0x80,0x80,0x60,0x00,0x00,0x00,
+/* 43218 0xa8d2 "꣒" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x00,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xc0,0x00,0x80,0x40,0x30,0x00,0x00,0x00,
+/* 43219 0xa8d3 "꣓" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x01,0x00,0x00,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x80,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43220 0xa8d4 "꣔" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x40,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43221 0xa8d5 "꣕" */
+0x00,0x00,0x00,0x00,0x06,0x08,0x08,0x08,0x07,0x00,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x20,0x40,0x70,0x88,0x88,0x08,0x08,0x10,0x00,0x00,0x00,
+/* 43222 0xa8d6 "꣖" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 43223 0xa8d7 "꣗" */
+0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xa0,0xa0,0x60,0x20,0x20,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43224 0xa8d8 "꣘" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x06,0x05,0x05,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x40,0x00,0x00,0x00,
+/* 43225 0xa8d9 "꣙" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x04,0x08,0x09,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x40,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43226 0xa8da "꣚" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43227 0xa8db "꣛" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43228 0xa8dc "꣜" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43229 0xa8dd "꣝" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43230 0xa8de "꣞" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43231 0xa8df "꣟" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43232 0xa8e0 "꣠" */
+0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43233 0xa8e1 "꣡" */
+0x01,0x02,0x01,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x80,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43234 0xa8e2 "꣢" */
+0x01,0x02,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x80,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43235 0xa8e3 "꣣" */
+0x01,0x00,0x01,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x80,0x40,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43236 0xa8e4 "꣤" */
+0x00,0x04,0x02,0x01,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x80,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43237 0xa8e5 "꣥" */
+0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0xe0,0x20,0x10,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43238 0xa8e6 "꣦" */
+0x00,0x01,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x00,0xc0,0x00,0xe0,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43239 0xa8e7 "꣧" */
+0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0xa0,0x60,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43240 0xa8e8 "꣨" */
+0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43241 0xa8e9 "꣩" */
+0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x20,0xc0,0x40,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43242 0xa8ea "꣪" */
+0x1c,0x02,0x0c,0x23,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x40,0x40,0xc0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43243 0xa8eb "꣫" */
+0x07,0x00,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x40,0x80,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43244 0xa8ec "꣬" */
+0x0f,0x00,0x03,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xf0,0x80,0x80,0xe0,0x90,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43245 0xa8ed "꣭" */
+0x07,0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x40,0xc0,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43246 0xa8ee "꣮" */
+0x0f,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xc0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43247 0xa8ef "꣯" */
+0x07,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x80,0x80,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43248 0xa8f0 "꣰" */
+0x03,0x04,0x0f,0x04,0x05,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0xc0,0x40,0xc0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43249 0xa8f1 "꣱" */
+0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x80,0x40,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43250 0xa8f2 "ꣲ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43251 0xa8f3 "ꣳ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0xe0,0x00,0xe0,0x10,0x08,0x08,0x08,0x00,0x00,
+/* 43252 0xa8f4 "ꣴ" */
+0x00,0x00,0x00,0x00,0x04,0x03,0x00,0x00,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x50,0x10,0xe0,0x00,0x50,0x10,0xe0,0x00,0x60,0x10,0x08,0x08,
+/* 43253 0xa8f5 "ꣵ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0xe0,0x00,0xe0,0x10,0x10,0x60,0x10,0x08,0x00,
+/* 43254 0xa8f6 "ꣶ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0xe0,0x00,0xe0,0x10,0xe0,0x10,0xe0,0x40,0x20,
+/* 43255 0xa8f7 "ꣷ" */
+0x00,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x01,0x00,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x10,0x10,0xe0,0x00,0xe0,0x00,0x80,0x40,0x80,0x00,0x00,
+/* 43256 0xa8f8 "꣸" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x14,0x0c,0x04,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 43257 0xa8f9 "꣹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x04,0x04,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 43258 0xa8fa "꣺" */
+0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43259 0xa8fb "ꣻ" */
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43260 0xa8fc "꣼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x18,0x0c,0x06,0x03,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x8c,0xe6,0xe6,0x06,0x0c,0xf8,0xf0,0x00,0x00,
+/* 43261 0xa8fd "ꣽ" */
+0x00,0x25,0x11,0x0e,0x00,0x1f,0x00,0x00,0x1f,0x18,0x18,0x08,0x00,0x40,0x30,0x0f,
+0x00,0x38,0x64,0x64,0x60,0xe0,0x60,0x60,0xe0,0x60,0x60,0x60,0x60,0x60,0x60,0x80,
+/* 43262 0xa8fe "ꣾ" */
+0x13,0x08,0x07,0xff,0x0c,0x0c,0x0c,0x0c,0x0c,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0xe0,0x10,0xf8,0xff,0x30,0x30,0x30,0x30,0x60,0x00,0x00,0x80,0x60,0x10,0x18,0x18,
+/* 43263 0xa8ff "ꣿ" */
+0x13,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43264 0xa900 "꤀" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43265 0xa901 "꤁" */
+0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x1f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x00,0x3c,0x44,0xf8,0x00,0x00,0x00,
+/* 43266 0xa902 "꤂" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43267 0xa903 "꤃" */
+0x00,0x00,0x00,0x00,0x0f,0x08,0x08,0x00,0x00,0x01,0x02,0x04,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x18,0x28,0x48,0xf0,0x00,0x00,0x00,
+/* 43268 0xa904 "꤄" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x16,0x18,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x60,0x00,0x00,0x00,
+/* 43269 0xa905 "꤅" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43270 0xa906 "꤆" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x11,0x16,0x18,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x68,0x88,0x08,0x08,0x38,0x48,0x48,0x30,0x00,0x00,0x00,
+/* 43271 0xa907 "꤇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 43272 0xa908 "꤈" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0xf8,0x00,0x00,0x00,
+/* 43273 0xa909 "꤉" */
+0x00,0x00,0x00,0x00,0x1c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43274 0xa90a "ꤊ" */
+0x00,0x00,0x00,0x00,0x3c,0x04,0x05,0x06,0x0c,0x14,0x24,0x24,0x38,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 43275 0xa90b "ꤋ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x3f,0x00,0x00,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x04,0xfc,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43276 0xa90c "ꤌ" */
+0x00,0x00,0x00,0x00,0x11,0x12,0x14,0x18,0x1f,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+/* 43277 0xa90d "ꤍ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x00,0x00,0x00,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43278 0xa90e "ꤎ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x0b,0x04,0x0b,0x10,0x20,0x3e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x88,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 43279 0xa90f "ꤏ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x03,0x02,0x02,0x02,0x02,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x88,0x48,0x28,0x28,0x18,0x08,0x00,0x00,0x00,
+/* 43280 0xa910 "ꤐ" */
+0x00,0x00,0x00,0x00,0x10,0x11,0x16,0x18,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x20,0x40,0x20,0x10,0x70,0x00,0x00,0x00,0x00,
+/* 43281 0xa911 "ꤑ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x00,0x00,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x04,0x04,0xf8,0x00,0x04,0xf8,0x00,0x00,0x00,
+/* 43282 0xa912 "ꤒ" */
+0x00,0x00,0x00,0x00,0x0c,0x0b,0x08,0x08,0x09,0x0a,0x0c,0x09,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x80,0x40,0xc0,0x40,0x80,0x00,0x00,0x00,
+/* 43283 0xa913 "ꤓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x38,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 43284 0xa914 "ꤔ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x0f,0x00,0x18,0x10,0x1f,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x00,0xf0,0x08,0x08,0xf0,0x00,0x80,0x00,0x00,0x00,
+/* 43285 0xa915 "ꤕ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x21,0x26,0x38,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x18,0x60,0x80,0x00,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43286 0xa916 "ꤖ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x10,0x13,0x14,0x18,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x00,0xe0,0x20,0x20,0x20,0x10,0x00,0x00,0x00,
+/* 43287 0xa917 "ꤗ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x21,0x22,0x24,0x28,0x30,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x88,0x48,0x28,0x18,0xf0,0x00,0x00,0x00,
+/* 43288 0xa918 "ꤘ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x18,0x28,0x48,0xf0,0x00,0x00,0x00,
+/* 43289 0xa919 "ꤙ" */
+0x00,0x00,0x00,0x00,0x08,0x09,0x0a,0x0c,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x70,0x90,0x90,0x60,0x00,0x00,0x00,
+/* 43290 0xa91a "ꤚ" */
+0x00,0x00,0x00,0x00,0x08,0x09,0x0a,0x0c,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x60,
+/* 43291 0xa91b "ꤛ" */
+0x00,0x00,0x00,0x00,0x20,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x1e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 43292 0xa91c "ꤜ" */
+0x00,0x00,0x00,0x00,0x20,0x21,0x21,0x21,0x21,0x1e,0x00,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 43293 0xa91d "ꤝ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x1c,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,
+/* 43294 0xa91e "ꤞ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x20,0x1f,0x00,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x00,0x00,0x04,0xfc,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43295 0xa91f "ꤟ" */
+0x00,0x00,0x00,0x00,0x0e,0x12,0x14,0x18,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x30,0x50,0x90,0x10,0x10,0x60,0x00,0x00,0x00,
+/* 43296 0xa920 "ꤠ" */
+0x00,0x00,0x00,0x00,0x60,0x58,0x46,0x41,0x00,0x00,0x40,0x40,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x34,0xc4,0x04,0x04,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43297 0xa921 "ꤡ" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x00,0x18,0x16,0x11,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x88,0x68,0x18,0x00,0x00,0x00,
+/* 43298 0xa922 "ꤢ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x20,0x1e,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x00,0x00,0x00,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43299 0xa923 "ꤣ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x13,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x18,0x28,0xc8,0x08,0x08,0x00,0x00,0x00,
+/* 43300 0xa924 "ꤤ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x20,0x00,0x01,0x02,0x0c,0x30,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x0c,0x34,0x44,0x84,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43301 0xa925 "ꤥ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x30,0x2c,0x23,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x0c,0x34,0xc4,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,
+/* 43302 0xa926 "ꤦ" */
+0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43303 0xa927 "ꤧ" */
+0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43304 0xa928 "ꤨ" */
+0x01,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43305 0xa929 "ꤩ" */
+0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43306 0xa92a "ꤪ" */
+0x09,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43307 0xa92b "꤫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43308 0xa92c "꤬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,
+/* 43309 0xa92d "꤭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc0,
+/* 43310 0xa92e "꤮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43311 0xa92f "꤯" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43312 0xa930 "ꤰ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x05,0x04,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43313 0xa931 "ꤱ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43314 0xa932 "ꤲ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x11,0x11,0x22,0x22,0x44,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x88,0x88,0x10,0x10,0xa0,0xa0,0x40,0x40,0x00,0x00,0x00,
+/* 43315 0xa933 "ꤳ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x06,0x05,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43316 0xa934 "ꤴ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x06,0x05,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x40,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43317 0xa935 "ꤵ" */
+0x00,0x00,0x00,0x00,0x03,0x05,0x05,0x09,0x09,0x11,0x11,0x21,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x14,0x14,0x24,0x24,0x44,0x44,0x84,0x84,0x00,0x00,0x00,
+/* 43318 0xa936 "ꤶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43319 0xa937 "ꤷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43320 0xa938 "ꤸ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x21,0x12,0x0a,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x80,0x80,0x00,0x08,0x90,0xa0,0x40,0x00,0x00,0x00,
+/* 43321 0xa939 "ꤹ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x06,0x05,0x08,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x90,0x48,0x20,0x10,0xa0,0x40,0x00,0x00,0x00,
+/* 43322 0xa93a "ꤺ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x09,0x14,0x12,0x21,0x20,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x48,0x84,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43323 0xa93b "ꤻ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x11,0x10,0x20,0x20,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0xa8,0xa8,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43324 0xa93c "ꤼ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x08,0x08,0x10,0x10,0x21,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x28,0xe4,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43325 0xa93d "ꤽ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x08,0x08,0x10,0x18,0x25,0x23,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x28,0xe4,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43326 0xa93e "ꤾ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x88,0x90,0x90,0xa0,0xa0,0xc0,0xc0,0x80,0x00,0x00,0x00,
+/* 43327 0xa93f "ꤿ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x20,0x20,0x10,0x11,0x0a,0x0a,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x04,0x08,0x08,0x10,0x10,0xa0,0xa0,0x40,0x00,0x00,0x00,
+/* 43328 0xa940 "ꥀ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x04,0x08,0x08,0x10,0x10,0x21,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x20,0xe0,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43329 0xa941 "ꥁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x22,0x12,0x0c,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0xa0,0x90,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43330 0xa942 "ꥂ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x08,0x0c,0x12,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 43331 0xa943 "ꥃ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x04,0x09,0x09,0x12,0x12,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x10,0x90,0x48,0x48,0x24,0x24,0x00,0x00,0x00,
+/* 43332 0xa944 "ꥄ" */
+0x00,0x00,0x00,0x00,0x0d,0x15,0x14,0x14,0x15,0x15,0x26,0x26,0x24,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0x44,0x84,0x88,0x48,0x48,0x28,0x28,0x10,0x00,0x00,0x00,
+/* 43333 0xa945 "ꥅ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x11,0x11,0x22,0x32,0x4c,0x44,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x44,0xa8,0xa8,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43334 0xa946 "ꥆ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x04,0x06,0x0a,0x09,0x11,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa0,0xa0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43335 0xa947 "ꥇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43336 0xa948 "ꥈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43337 0xa949 "ꥉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43338 0xa94a "ꥊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x08,0x14,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43339 0xa94b "ꥋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43340 0xa94c "ꥌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43341 0xa94d "ꥍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0xa0,0xa0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43342 0xa94e "ꥎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x0a,
+/* 43343 0xa94f "ꥏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43344 0xa950 "ꥐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43345 0xa951 "ꥑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x22,0x14,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43346 0xa952 "ꥒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x02,
+/* 43347 0xa953 "꥓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x04,0x0a,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43348 0xa954 "꥔" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 43349 0xa955 "꥕" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 43350 0xa956 "꥖" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 43351 0xa957 "꥗" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43352 0xa958 "꥘" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43353 0xa959 "꥙" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43354 0xa95a "꥚" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43355 0xa95b "꥛" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43356 0xa95c "꥜" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43357 0xa95d "꥝" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43358 0xa95e "꥞" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43359 0xa95f "꥟" */
+0x00,0x00,0x00,0x00,0x00,0x09,0x09,0x05,0x12,0x0e,0x01,0x02,0x0c,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x30,0x40,0x80,0x70,0x48,0xa0,0x90,0x90,0x00,0x00,0x00,
+/* 43360 0xa960 "ꥠ" */
+0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43361 0xa961 "ꥡ" */
+0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43362 0xa962 "ꥢ" */
+0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43363 0xa963 "ꥣ" */
+0x00,0x3e,0x20,0x20,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x08,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43364 0xa964 "ꥤ" */
+0x00,0x7c,0x04,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43365 0xa965 "ꥥ" */
+0x00,0x3d,0x04,0x3c,0x20,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xdc,0x44,0x44,0x44,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43366 0xa966 "ꥦ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43367 0xa967 "ꥧ" */
+0x00,0x3d,0x05,0x3d,0x21,0x3d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xdc,0x10,0x10,0x10,0xdc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43368 0xa968 "ꥨ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43369 0xa969 "ꥩ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x44,0x44,0x7c,0x44,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43370 0xa96a "ꥪ" */
+0x00,0x3d,0x05,0x3d,0x21,0x3d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x54,0x54,0xdc,0x54,0xdc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43371 0xa96b "ꥫ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x44,0x7c,0x44,0x7c,0x38,0x44,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43372 0xa96c "ꥬ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43373 0xa96d "ꥭ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x08,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43374 0xa96e "ꥮ" */
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43375 0xa96f "ꥯ" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43376 0xa970 "ꥰ" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x40,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43377 0xa971 "ꥱ" */
+0x00,0x3e,0x22,0x22,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43378 0xa972 "ꥲ" */
+0x00,0x29,0x29,0x39,0x2a,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3c,0x20,0x3c,0xa0,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43379 0xa973 "ꥳ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x04,0x7c,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43380 0xa974 "ꥴ" */
+0x00,0x22,0x22,0x3e,0x22,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43381 0xa975 "ꥵ" */
+0x00,0x08,0x08,0x08,0x15,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x92,0x92,0x9e,0x52,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43382 0xa976 "ꥶ" */
+0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x3e,0x02,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43383 0xa977 "ꥷ" */
+0x00,0x1c,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43384 0xa978 "ꥸ" */
+0x00,0x3f,0x04,0x08,0x15,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xec,0x7f,0x8c,0x52,0x2c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43385 0xa979 "ꥹ" */
+0x00,0x3e,0x20,0x3e,0x20,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x7c,0x40,0x7c,0x40,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43386 0xa97a "ꥺ" */
+0x00,0x3e,0x14,0x14,0x14,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0xfc,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43387 0xa97b "ꥻ" */
+0x00,0x0c,0x3f,0x0c,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43388 0xa97c "ꥼ" */
+0x00,0x3e,0x00,0x0c,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfc,0x00,0x30,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43389 0xa97d "꥽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43390 0xa97e "꥾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43391 0xa97f "꥿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43392 0xa980 "ꦀ" */
+0x11,0x0a,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x88,0x50,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43393 0xa981 "ꦁ" */
+0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43394 0xa982 "ꦂ" */
+0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43395 0xa983 "ꦃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x05,0x02,0x06,0x01,0x01,0x01,0x01,0x01,0x02,
+/* 43396 0xa984 "ꦄ" */
+0x00,0x00,0x00,0x00,0x30,0x40,0x80,0xb0,0x88,0xb0,0x88,0x89,0x72,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0xa4,0xfe,0x24,0xa4,0x64,0x00,0x00,0x00,
+/* 43397 0xa985 "ꦅ" */
+0x00,0x00,0x00,0x00,0x38,0x45,0x45,0x44,0x44,0x44,0x45,0x24,0x27,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0xd8,0x24,0x24,0x04,0x04,0x04,0x04,0x84,0x84,0x80,0x60,0x10,
+/* 43398 0xa986 "ꦆ" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x55,0x50,0x50,0x50,0x54,0x52,0x5e,0x06,0x09,0x00,
+0x00,0x00,0x00,0x00,0x88,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x74,0x00,0x80,0x40,
+/* 43399 0xa987 "ꦇ" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x55,0x50,0x50,0x50,0x54,0x58,0x5b,0x04,0x02,0x0c,
+0x00,0x00,0x00,0x00,0x88,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x74,0x00,0x00,0x00,
+/* 43400 0xa988 "ꦈ" */
+0x00,0x00,0x00,0x00,0x38,0x45,0x45,0x44,0x44,0x44,0x45,0x24,0x27,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd8,0x24,0x24,0x04,0x04,0x04,0x04,0x84,0x88,0x30,0x46,0x78,
+/* 43401 0xa989 "ꦉ" */
+0x00,0x00,0x00,0x00,0x30,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x4e,0x04,0x0f,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x80,
+/* 43402 0xa98a "ꦊ" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x48,0x4a,0x49,0x4f,0x00,0x07,0x08,0x09,0x06,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x08,0x08,0x1c,0x28,0x48,0x88,0x08,0x88,0x70,
+/* 43403 0xa98b "ꦋ" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x48,0x4a,0x49,0x4f,0x00,0x07,0x08,0x09,0x06,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x08,0x0c,0x1a,0x2a,0x4c,0x8a,0x0a,0x8c,0x70,
+/* 43404 0xa98c "ꦌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x0a,0x11,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x70,0x88,0x00,0x00,0x00,
+/* 43405 0xa98d "ꦍ" */
+0x00,0x03,0x04,0x03,0x00,0x01,0x00,0x07,0x0a,0x11,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x80,0x40,0x80,0x00,0x70,0x88,0x00,0x00,0x00,
+/* 43406 0xa98e "ꦎ" */
+0x00,0x00,0x00,0x00,0x39,0x49,0x90,0x90,0x90,0x90,0x4f,0x00,0x03,0x04,0x09,0x0e,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x90,0x90,0x90,0x90,0x20,0x40,0x80,0x38,0xc0,0x00,
+/* 43407 0xa98f "ꦏ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x54,0x54,0x54,0x54,0x5e,0x55,0x55,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x88,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x74,0x00,0x00,0x00,
+/* 43408 0xa990 "ꦐ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x54,0x54,0x54,0x54,0x5e,0x55,0x55,0x06,0x09,0x00,
+0x00,0x00,0x00,0x00,0x88,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x74,0x00,0x80,0x40,
+/* 43409 0xa991 "ꦑ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x54,0x54,0x54,0x54,0x5e,0x55,0x55,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x84,0x48,0x50,0x50,0x50,0x50,0x50,0x50,0x60,0x00,0x00,0x00,
+/* 43410 0xa992 "ꦒ" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x4a,0x4a,0x2a,0x0a,0x0a,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xe8,0x00,0x00,0x00,
+/* 43411 0xa993 "ꦓ" */
+0x00,0x00,0x00,0x00,0x23,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x5c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x14,0x14,0x14,0x14,0x14,0x54,0x54,0xa0,0x00,0x00,0x00,
+/* 43412 0xa994 "ꦔ" */
+0x00,0x00,0x00,0x00,0x38,0x45,0x45,0x44,0x44,0x44,0x44,0x24,0x27,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd8,0x24,0x24,0x04,0x04,0x04,0x84,0x44,0xc4,0x00,0x00,0x00,
+/* 43413 0xa995 "ꦕ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x4e,0x55,0x55,0x48,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xc8,0x00,0x00,0x00,
+/* 43414 0xa996 "ꦖ" */
+0x00,0x00,0x00,0x00,0x10,0x22,0x45,0x49,0x4a,0x52,0x54,0x55,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x52,0x55,0x96,0xa5,0x2a,0x10,0x00,0x00,0x00,
+/* 43415 0xa997 "ꦗ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x45,0x45,0x45,0x45,0x45,0x24,0x27,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x1c,0xe0,0xc0,0x30,0x08,0x88,0x80,0x00,0x00,0x00,
+/* 43416 0xa998 "ꦘ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x45,0x45,0x45,0x45,0x45,0x24,0x27,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x1c,0xe0,0xc0,0x30,0x08,0x88,0x80,0x80,0x60,0x10,
+/* 43417 0xa999 "ꦙ" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x48,0x4a,0x49,0x4f,0x00,0x07,0x08,0x08,0x07,
+0x08,0x14,0x14,0x0e,0x45,0xa5,0xa6,0x24,0x24,0x24,0x24,0x44,0x84,0x08,0xc8,0x30,
+/* 43418 0xa99a "ꦚ" */
+0x00,0x00,0x00,0x00,0x45,0xaa,0xaa,0xa0,0xa8,0xa4,0xbc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x7e,0xda,0xda,0xda,0xda,0xda,0xda,0x00,0x00,0x00,0x00,0x00,
+/* 43419 0xa99b "ꦛ" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x48,0x48,0x48,0x4b,0x4c,0x47,0x08,0x08,0x07,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x08,0x08,0x08,0x08,0x88,0x08,0x40,0x40,0x80,
+/* 43420 0xa99c "ꦜ" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x48,0x48,0x48,0x49,0x4a,0x4f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x08,0x08,0x08,0x88,0x48,0x88,0x00,0x00,0x00,
+/* 43421 0xa99d "ꦝ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x90,0x90,0x90,0x90,0x92,0x92,0x4d,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x90,0x50,0x50,0x50,0x50,0x50,0x50,0x90,0x00,0x00,0x00,
+/* 43422 0xa99e "ꦞ" */
+0x00,0x00,0x00,0x00,0x39,0x48,0x90,0x90,0x90,0x90,0x92,0x92,0x4d,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43423 0xa99f "ꦟ" */
+0x00,0x00,0x00,0x00,0x22,0x55,0x55,0x55,0x55,0x35,0x15,0x15,0x1d,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x48,0xb4,0xb4,0xb4,0xb4,0xb4,0xb4,0xb4,0xb4,0x00,0x00,0x00,
+/* 43424 0xa9a0 "ꦠ" */
+0x00,0x00,0x00,0x00,0x27,0x54,0x54,0x54,0x53,0x50,0x50,0x50,0x5f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xcc,0x34,0x34,0x34,0x34,0xb4,0xb4,0xb4,0x34,0x00,0x00,0x00,
+/* 43425 0xa9a1 "ꦡ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x90,0x90,0x90,0x92,0x95,0x91,0x4f,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x90,0x50,0x50,0x50,0x50,0x50,0x50,0x90,0x00,0x40,0x80,
+/* 43426 0xa9a2 "ꦢ" */
+0x00,0x00,0x00,0x00,0x39,0x4a,0x92,0x92,0x92,0x92,0x93,0x96,0x49,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x90,0x00,0x00,0x00,
+/* 43427 0xa9a3 "ꦣ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x90,0x90,0x90,0x90,0x92,0x92,0x4d,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x90,0x50,0x50,0x50,0x50,0x50,0x50,0x90,0x00,0x00,0x00,
+/* 43428 0xa9a4 "ꦤ" */
+0x00,0x00,0x00,0x00,0x39,0x4a,0x92,0x92,0x92,0x9f,0x92,0x92,0x51,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x90,0x90,0x10,0x00,0x00,0x00,
+/* 43429 0xa9a5 "ꦥ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x23,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0x00,0x00,
+/* 43430 0xa9a6 "ꦦ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x90,0x90,0x90,0x90,0x92,0x92,0x4d,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x50,0x20,0x30,0x48,0x48,0x90,0x00,0x00,0x00,
+/* 43431 0xa9a7 "ꦧ" */
+0x00,0x00,0x00,0x00,0x62,0x95,0x95,0x90,0x90,0x90,0x94,0x92,0x5f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x9c,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x64,0x00,0x00,0x00,
+/* 43432 0xa9a8 "ꦨ" */
+0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x04,0x4f,0x74,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x48,0x48,0x40,0x40,0xe0,0x58,0x44,0xc0,0x00,0x00,0x00,
+/* 43433 0xa9a9 "ꦩ" */
+0x00,0x00,0x00,0x00,0x3f,0x48,0x48,0x48,0x47,0x48,0x48,0x48,0x27,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xc4,0x00,0x00,0x00,
+/* 43434 0xa9aa "ꦪ" */
+0x00,0x00,0x00,0x00,0x39,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x2e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xce,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x00,0x00,0x00,
+/* 43435 0xa9ab "ꦫ" */
+0x00,0x00,0x00,0x00,0x3c,0x22,0x12,0x02,0x04,0x08,0x1c,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x00,0x00,0x00,
+/* 43436 0xa9ac "ꦬ" */
+0x00,0x00,0x00,0x00,0x64,0x9b,0x9b,0x9b,0x5b,0x1b,0x1b,0x1b,0x1b,0x00,0x00,0x00,
+0x0c,0x12,0x0e,0x02,0x92,0x6a,0x6a,0x6a,0x6a,0x6a,0x6a,0x6a,0x6e,0x00,0x00,0x00,
+/* 43437 0xa9ad "ꦭ" */
+0x00,0x00,0x00,0x00,0x39,0x4a,0x92,0x92,0x92,0x92,0x92,0x92,0x4e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x64,0x00,0x00,0x00,
+/* 43438 0xa9ae "ꦮ" */
+0x00,0x00,0x00,0x00,0x1c,0x24,0x48,0x48,0x48,0x48,0x48,0x48,0x27,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x88,0x48,0x48,0x48,0x48,0x48,0x48,0x88,0x00,0x00,0x00,
+/* 43439 0xa9af "ꦯ" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x54,0x54,0x55,0x36,0x17,0x14,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0xc8,0xc8,0xc8,0xc8,0xc8,0xfc,0xca,0xc8,0x00,0x00,0x00,
+/* 43440 0xa9b0 "ꦰ" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x90,0x91,0x92,0x93,0x90,0x90,0x4f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x48,0x48,0x48,0x48,0xfc,0x4a,0x48,0x88,0x00,0x00,0x00,
+/* 43441 0xa9b1 "ꦱ" */
+0x00,0x00,0x00,0x00,0x3c,0x44,0x84,0x84,0x84,0x8e,0x95,0x95,0x48,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x3c,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xc4,0x00,0x00,0x00,
+/* 43442 0xa9b2 "ꦲ" */
+0x00,0x00,0x00,0x00,0x39,0x49,0x91,0x91,0x91,0x91,0x91,0x91,0x4e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x64,0x64,0x64,0x64,0x64,0x64,0x64,0x64,0x00,0x00,0x00,
+/* 43443 0xa9b3 "꦳" */
+0x00,0x02,0x01,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x80,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43444 0xa9b4 "ꦴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x01,0x02,0x02,0x04,0x05,0x07,0x00,0x00,0x00,
+/* 43445 0xa9b5 "ꦵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x02,0x02,0x01,0x09,0x06,0x00,0x00,0x00,0x00,
+/* 43446 0xa9b6 "ꦶ" */
+0x01,0x02,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0x10,0x10,0x70,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43447 0xa9b7 "ꦷ" */
+0x01,0x02,0x05,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0xe0,0x10,0x30,0xd0,0x70,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43448 0xa9b8 "ꦸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x05,0x05,0x05,0x05,0x05,0x05,0x19,0x3e,
+/* 43449 0xa9b9 "ꦹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x0f,0x14,0x14,0x0e,0x05,0x05,0x05,0x05,0x19,0x3e,
+/* 43450 0xa9ba "ꦺ" */
+0x00,0x00,0x00,0x00,0x48,0xb4,0xb4,0xb4,0xb4,0xb4,0xb4,0xb4,0x34,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43451 0xa9bb "ꦻ" */
+0x18,0x20,0x10,0x08,0x30,0x00,0x48,0xb4,0xb4,0xb4,0xb4,0xb4,0x34,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43452 0xa9bc "ꦼ" */
+0x07,0x08,0x08,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43453 0xa9bd "ꦽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x02,0x01,0x01,0x01,0x32,0x34,0x58,
+/* 43454 0xa9be "ꦾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x03,
+0x0e,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x2a,0x2a,0xca,0x0a,0x0a,0xca,0x31,
+/* 43455 0xa9bf "ꦿ" */
+0x18,0x20,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x40,0x20,0x18,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x1c,0x02,0x02,0xfc,
+/* 43456 0xa9c0 "꧀" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,
+0x0e,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x0a,0x8a,0x0a,0xca,0x31,
+/* 43457 0xa9c1 "꧁" */
+0x00,0x00,0x06,0x04,0x04,0x02,0x61,0x40,0x20,0x1f,0x00,0x06,0x04,0x03,0x00,0x00,
+0x00,0x06,0x0a,0x08,0x08,0x08,0xe0,0x04,0x6a,0x84,0x10,0x12,0x22,0xc2,0x0a,0x0c,
+/* 43458 0xa9c2 "꧂" */
+0x00,0x30,0x50,0x43,0x44,0x48,0x08,0x21,0x56,0x20,0x07,0x10,0x10,0x10,0x50,0x60,
+0x00,0x00,0x00,0xc0,0x20,0x60,0x00,0xf8,0x04,0x02,0x86,0x40,0x20,0x20,0x60,0x00,
+/* 43459 0xa9c3 "꧃" */
+0x28,0xd5,0xc5,0xc5,0xd5,0xf5,0x01,0x1d,0x21,0x2f,0xa5,0x99,0x81,0x81,0x41,0x3e,
+0x00,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0xe6,0x9f,0x87,0xc7,0xd7,0xa9,
+/* 43460 0xa9c4 "꧄" */
+0x68,0xd5,0xc5,0xc5,0xd5,0xf5,0x81,0x9d,0xa1,0xaf,0xa5,0x99,0x81,0x81,0x41,0x3e,
+0x00,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0xe6,0x9f,0x87,0xc7,0xd7,0xa9,
+/* 43461 0xa9c5 "꧅" */
+0x30,0x40,0xe8,0xd5,0xc5,0xf5,0x81,0x9d,0xa1,0xaf,0xa5,0x99,0x81,0x81,0x41,0x3e,
+0x00,0x06,0x06,0x86,0x86,0x86,0x86,0x86,0x86,0x86,0xe6,0x9f,0x87,0xc7,0xd7,0xa9,
+/* 43462 0xa9c6 "꧆" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 43463 0xa9c7 "꧇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x03,0x00,0x00,0x02,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43464 0xa9c8 "꧈" */
+0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x01,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 43465 0xa9c9 "꧉" */
+0x00,0x00,0x00,0x00,0x33,0x08,0x04,0x02,0x01,0x01,0x00,0x06,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x10,0x88,0xe8,0x98,0x00,0x00,0x00,
+/* 43466 0xa9ca "꧊" */
+0x00,0x00,0x00,0x00,0x06,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
+/* 43467 0xa9cb "꧋" */
+0x00,0x00,0x00,0x00,0x19,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x30,
+/* 43468 0xa9cc "꧌" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x06,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x10,0x20,0x40,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
+/* 43469 0xa9cd "꧍" */
+0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x02,0x04,
+0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x30,0x80,0x40,0x40,0x00,0x00,
+/* 43470 0xa9ce "꧎" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43471 0xa9cf "ꧏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x02,0x02,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43472 0xa9d0 "꧐" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 43473 0xa9d1 "꧑" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x4a,0x4a,0x2a,0x0a,0x0a,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xa8,0xe8,0x00,0x00,0x00,
+/* 43474 0xa9d2 "꧒" */
+0x00,0x00,0x00,0x00,0x31,0x4a,0x4a,0x48,0x4a,0x49,0x4f,0x00,0x07,0x08,0x09,0x06,
+0x00,0x00,0x00,0x00,0xb0,0x48,0x48,0x08,0x08,0x1c,0x28,0x48,0x88,0x08,0x88,0x70,
+/* 43475 0xa9d3 "꧓" */
+0x00,0x00,0x00,0x00,0x23,0x54,0x54,0x50,0x54,0x52,0x5e,0x00,0x0f,0x10,0x11,0x0e,
+0x00,0x00,0x00,0x00,0x67,0x95,0x95,0x15,0x15,0x25,0x45,0x85,0x05,0x05,0x85,0x79,
+/* 43476 0xa9d4 "꧔" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0xc0,0x20,0xc0,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43477 0xa9d5 "꧕" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0b,0x08,0x0b,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xa0,0x20,0xa0,0xa0,0x20,0x20,0x20,0x18,
+/* 43478 0xa9d6 "꧖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x0a,0x11,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x70,0x88,0x00,0x00,0x00,
+/* 43479 0xa9d7 "꧗" */
+0x00,0x00,0x00,0x00,0x39,0x4a,0x92,0x92,0x92,0x92,0x92,0x92,0x4e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xdc,0x54,0x54,0x54,0x54,0x54,0x54,0x54,0x64,0x00,0x00,0x00,
+/* 43480 0xa9d8 "꧘" */
+0x00,0x00,0x00,0x00,0x38,0x48,0x90,0x90,0x90,0x90,0x92,0x92,0x4d,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x50,0x20,0x30,0x48,0x48,0x90,0x00,0x00,0x00,
+/* 43481 0xa9d9 "꧙" */
+0x00,0x00,0x00,0x00,0x39,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x2e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xce,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x32,0x00,0x00,0x00,
+/* 43482 0xa9da "꧚" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43483 0xa9db "꧛" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43484 0xa9dc "꧜" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43485 0xa9dd "꧝" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43486 0xa9de "꧞" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 43487 0xa9df "꧟" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x23,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x00,0x00,0x00,
+/* 43488 0xa9e0 "ꧠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x44,0x82,0x02,0xf2,0x8c,0x78,0x00,0x00,0x00,0x00,
+/* 43489 0xa9e1 "ꧡ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0xa1,0x21,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43490 0xa9e2 "ꧢ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x4a,0x29,0x25,0x23,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43491 0xa9e3 "ꧣ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x00,0x01,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0xd2,0x20,0x20,0xfc,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43492 0xa9e4 "ꧤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc6,0x08,0x10,0x10,0x16,0x29,0xc6,0x00,0x00,0x00,0x00,
+/* 43493 0xa9e5 "ꧥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x70,0x88,0x80,0x70,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43494 0xa9e6 "ꧦ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x90,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43495 0xa9e7 "ꧧ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x22,0x2c,0x20,0x20,0x20,0x38,
+/* 43496 0xa9e8 "ꧨ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x18,0x20,0x20,0xac,0x32,0x21,0x21,0x21,0x72,0xac,0x20,0x20,0x20,0xe0,
+/* 43497 0xa9e9 "ꧩ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x2d,0x21,0x42,0x0c,0x00,0x00,0x00,0x00,
+/* 43498 0xa9ea "ꧪ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x12,0x21,0x2d,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 43499 0xa9eb "ꧫ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x2d,0x21,0x12,0x8c,0x00,0x00,0x00,0x00,
+/* 43500 0xa9ec "ꧬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x25,0x51,0x51,0x8e,0x00,0x00,0x00,0x00,
+/* 43501 0xa9ed "ꧭ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0xad,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 43502 0xa9ee "ꧮ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0xad,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43503 0xa9ef "ꧯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0xca,0xa2,0x44,0x00,0x00,0x00,0x00,0x00,
+/* 43504 0xa9f0 "꧰" */
+0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 43505 0xa9f1 "꧱" */
+0x00,0x03,0x04,0x0e,0x09,0x06,0x00,0x03,0x04,0x0e,0x09,0x06,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x10,0x10,0x20,0x00,0xc0,0x20,0x10,0x10,0x20,0x40,0x70,0x00,0x00,
+/* 43506 0xa9f2 "꧲" */
+0x00,0x08,0x08,0x08,0x04,0x03,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x10,0x10,0x10,0x20,0xd0,0x10,0xd0,0x20,0x00,0x00,0x00,0x20,0xc0,0x00,0x00,
+/* 43507 0xa9f3 "꧳" */
+0x00,0x03,0x04,0x00,0x00,0x06,0x05,0x04,0x05,0x06,0x00,0x00,0x04,0x03,0x00,0x00,
+0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0xe0,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,
+/* 43508 0xa9f4 "꧴" */
+0x00,0x07,0x08,0x08,0x08,0x08,0x07,0x00,0x07,0x08,0x08,0x08,0x08,0x07,0x00,0x00,
+0x00,0xc0,0x20,0x00,0x00,0x60,0xa0,0x20,0xa0,0x60,0x00,0x00,0x20,0xc0,0x00,0x00,
+/* 43509 0xa9f5 "꧵" */
+0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x0b,0x0c,0x08,0x08,0x08,0x04,0x02,0x00,0x00,
+0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0x40,0x00,0x00,
+/* 43510 0xa9f6 "꧶" */
+0x00,0x00,0x02,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x08,0x04,0x03,0x00,
+0x00,0x00,0x40,0x20,0x10,0x10,0x10,0x30,0xd0,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,
+/* 43511 0xa9f7 "꧷" */
+0x00,0x00,0x07,0x08,0x10,0x1c,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x38,0x00,0x00,
+/* 43512 0xa9f8 "꧸" */
+0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 43513 0xa9f9 "꧹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x88,0x04,0x04,0x04,0x88,0x70,0x00,0x00,0x00,0x00,
+/* 43514 0xa9fa "ꧺ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0xa1,0x21,0x12,0x8c,0x00,0x00,0x00,0x00,
+/* 43515 0xa9fb "ꧻ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x2d,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 43516 0xa9fc "ꧼ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x2d,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43517 0xa9fd "ꧽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x48,0x84,0x02,0x32,0x02,0x84,0x78,0x00,0x00,0x00,0x00,
+/* 43518 0xa9fe "ꧾ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x18,0x20,0x20,0xac,0x32,0x21,0x2d,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43519 0xa9ff "꧿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43520 0xaa00 "ꨀ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x22,0x29,0x34,0x18,0x13,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x06,0xc9,0x29,0x32,0x80,0x80,0xc0,0xa0,0x00,0x00,0x00,0x00,
+/* 43521 0xaa01 "ꨁ" */
+0x00,0x00,0x00,0x00,0x0c,0x13,0x10,0x28,0x50,0x07,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x40,0x80,0x20,0x50,0x90,0x00,0x00,0x00,
+/* 43522 0xaa02 "ꨂ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x01,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 43523 0xaa03 "ꨃ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x09,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x38,0x44,0x44,0x48,0x20,0x10,0x08,0x28,0x58,0x30,0x20,0x40,0xe0,0x00,0x00,0x00,
+/* 43524 0xaa04 "ꨄ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x18,0x14,0x08,0x00,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x30,0xc0,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 43525 0xaa05 "ꨅ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x1c,0x0a,0x04,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xc0,0x20,0xf0,0x28,0xc0,0x00,0x00,0x00,
+/* 43526 0xaa06 "ꨆ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x10,0x08,0x08,0x08,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43527 0xaa07 "ꨇ" */
+0x00,0x00,0x00,0x00,0x1b,0x24,0x24,0x20,0x11,0x12,0x14,0x15,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x92,0x52,0x64,0xc0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43528 0xaa08 "ꨈ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x10,0x11,0x0a,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x10,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 43529 0xaa09 "ꨉ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x14,0x04,0x08,0x09,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x84,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43530 0xaa0a "ꨊ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x16,0x01,0x01,0x01,0x03,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x28,0x50,0x30,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43531 0xaa0b "ꨋ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x16,0x01,0x01,0x01,0x03,0x04,0x04,0x04,0x03,
+0x00,0x00,0x00,0x00,0x28,0x50,0x30,0x10,0x10,0x20,0x40,0x80,0x30,0x48,0x90,0x00,
+/* 43532 0xaa0c "ꨌ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x11,0x01,0x0f,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43533 0xaa0d "ꨍ" */
+0x00,0x00,0x00,0x00,0x18,0x25,0x25,0x15,0x06,0x1c,0x24,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x86,0x49,0x49,0x44,0x4c,0x94,0x88,0x90,0x60,0x00,0x00,0x00,
+/* 43534 0xaa0e "ꨎ" */
+0x00,0x00,0x00,0x00,0x38,0x45,0x45,0x2c,0x02,0x02,0x02,0x07,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xd8,0x24,0x24,0x88,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43535 0xaa0f "ꨏ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x05,0x13,0x2b,0x27,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0xa4,0xa4,0xa8,0x20,0x90,0x50,0x30,0xe0,0x00,0x00,0x00,
+/* 43536 0xaa10 "ꨐ" */
+0x00,0x00,0x00,0x00,0x19,0x26,0x40,0x40,0x40,0x40,0x29,0x15,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x86,0x49,0x31,0x22,0x60,0xa0,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43537 0xaa11 "ꨑ" */
+0x00,0x00,0x00,0x00,0x19,0x26,0x40,0x40,0x40,0x40,0x29,0x15,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x86,0x49,0x31,0x22,0x60,0xa0,0x20,0x20,0xc4,0x4a,0x48,0x30,
+/* 43538 0xaa12 "ꨒ" */
+0x00,0x00,0x00,0x00,0x19,0x26,0x40,0x40,0x40,0x40,0x29,0x15,0x29,0x02,0x01,0x02,
+0x00,0x00,0x00,0x00,0x86,0x49,0x31,0x22,0x60,0xa0,0x20,0x20,0xc4,0x4a,0x48,0x30,
+/* 43539 0xaa13 "ꨓ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x10,0x10,0x16,0x19,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43540 0xaa14 "ꨔ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x09,0x02,0x04,0x04,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x28,0x58,0x30,0x20,0x40,0xc0,0x00,0x00,0x00,
+/* 43541 0xaa15 "ꨕ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x16,0x01,0x01,0x01,0x03,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x50,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43542 0xaa16 "ꨖ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0a,0x02,0x04,0x04,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x50,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43543 0xaa17 "ꨗ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x11,0x01,0x0f,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x08,0x08,0x08,0x90,0x60,0x40,0x00,0x00,0x00,
+/* 43544 0xaa18 "ꨘ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x11,0x01,0x0f,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x08,0x08,0x08,0x90,0x60,0x48,0x94,0x90,0x60,
+/* 43545 0xaa19 "ꨙ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x11,0x01,0x0f,0x12,0x12,0x0c,0x08,0x09,0x06,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x08,0x08,0x08,0x90,0x60,0x00,0xc0,0x20,0x00,
+/* 43546 0xaa1a "ꨚ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x04,0x24,0x54,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43547 0xaa1b "ꨛ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x16,0x01,0x01,0x01,0x03,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x28,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43548 0xaa1c "ꨜ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x09,0x0a,0x4a,0xaa,0x91,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x08,0x28,0x58,0x30,0x10,0xe0,0x00,0x00,0x00,
+/* 43549 0xaa1d "ꨝ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x50,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 43550 0xaa1e "ꨞ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x10,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43551 0xaa1f "ꨟ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x28,0x0a,0x11,0x12,0x0c,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x84,0x80,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 43552 0xaa20 "ꨠ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x14,0x05,0x08,0x09,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x48,0x40,0x80,0x40,0x40,0x48,0x94,0x90,0x60,
+/* 43553 0xaa21 "ꨡ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x14,0x05,0x08,0x09,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x48,0x40,0x80,0x50,0x20,0x50,0x50,0x20,0x00,
+/* 43554 0xaa22 "ꨢ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x24,0x04,0x02,0x02,0x02,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x84,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43555 0xaa23 "ꨣ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x90,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43556 0xaa24 "ꨤ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x10,0x10,0x10,0x12,0x0d,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0xc4,0x04,0x04,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43557 0xaa25 "ꨥ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x14,0x04,0x08,0x09,0x06,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x48,0x40,0xd0,0x20,0x50,0x50,0x20,0x00,0x00,
+/* 43558 0xaa26 "ꨦ" */
+0x00,0x00,0x00,0x00,0x0c,0x12,0x2a,0x52,0x02,0x04,0x04,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x24,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43559 0xaa27 "ꨧ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x02,0x12,0x2a,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0xc4,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43560 0xaa28 "ꨨ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x02,0x12,0x2a,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x98,0x28,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43561 0xaa29 "ꨩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x44,0x48,0x20,0x18,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43562 0xaa2a "ꨪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x1c,0x22,0x41,0x4d,0x32,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43563 0xaa2b "ꨫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x1c,0x22,0x49,0x41,0x4d,0x32,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43564 0xaa2c "ꨬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x38,0x45,0x8e,0x9a,0x64,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43565 0xaa2d "ꨭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x1c,0x20,
+/* 43566 0xaa2e "ꨮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43567 0xaa2f "ꨯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x80,0xa0,0x50,0xa0,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43568 0xaa30 "ꨰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x90,0x80,0xa0,0x50,0x20,0x08,0x70,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43569 0xaa31 "ꨱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x1c,0x20,0x24,0x18,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43570 0xaa32 "ꨲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x08,
+/* 43571 0xaa33 "ꨳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x08,0x04,0x32,0x0a,0x12,0x3c,
+/* 43572 0xaa34 "ꨴ" */
+0x58,0xa8,0x88,0x10,0x20,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x82,0x4a,0x34,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43573 0xaa35 "ꨵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x0c,
+/* 43574 0xaa36 "ꨶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x05,0x02,0x05,0x05,0x05,0x02,
+/* 43575 0xaa37 "꨷" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43576 0xaa38 "꨸" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43577 0xaa39 "꨹" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43578 0xaa3a "꨺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43579 0xaa3b "꨻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43580 0xaa3c "꨼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43581 0xaa3d "꨽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43582 0xaa3e "꨾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43583 0xaa3f "꨿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43584 0xaa40 "ꩀ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x10,0x08,0x08,0x08,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43585 0xaa41 "ꩁ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x11,0x20,0x20,0x20,0x20,0x2c,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43586 0xaa42 "ꩂ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x16,0x01,0x01,0x01,0x03,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x50,0x50,0x30,0x18,0x24,0x44,0x88,0x10,0x00,0x00,0x00,
+/* 43587 0xaa43 "ꩃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x04,0x08,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43588 0xaa44 "ꩄ" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x11,0x01,0x0f,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x84,0x08,0x08,0x10,0x20,0x00,0x00,0x00,
+/* 43589 0xaa45 "ꩅ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x10,0x10,0x16,0x19,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x08,0x08,0x10,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 43590 0xaa46 "ꩆ" */
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x22,0x02,0x1e,0x25,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x12,0x12,0x14,0x24,0xc8,0x90,0x00,0x00,0x00,
+/* 43591 0xaa47 "ꩇ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x02,0x12,0x2a,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x08,0x08,0x10,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 43592 0xaa48 "ꩈ" */
+0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x24,0x04,0x02,0x02,0x02,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x6c,0x92,0x92,0x82,0x42,0x44,0x44,0x88,0x10,0x00,0x00,0x00,
+/* 43593 0xaa49 "ꩉ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x84,0x84,0x88,0x88,0x10,0x20,0x00,0x00,0x00,
+/* 43594 0xaa4a "ꩊ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x20,0x20,0x20,0x24,0x2a,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x00,0x00,0x00,
+/* 43595 0xaa4b "ꩋ" */
+0x00,0x00,0x00,0x00,0x1c,0x12,0x2a,0x52,0x02,0x04,0x04,0x03,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x78,0x84,0x84,0x44,0x44,0x48,0x88,0x10,0x20,0x00,0x00,0x00,
+/* 43596 0xaa4c "ꩌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43597 0xaa4d "ꩍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x05,0x01,0x02,0x04,0x04,0x00,0x00,0x00,
+/* 43598 0xaa4e "꩎" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43599 0xaa4f "꩏" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43600 0xaa50 "꩐" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 43601 0xaa51 "꩑" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x3c,0x0c,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43602 0xaa52 "꩒" */
+0x00,0x03,0x04,0x08,0x13,0x24,0x24,0x28,0x29,0x2a,0x27,0x10,0x0f,0x00,0x00,0x00,
+0x02,0x84,0x78,0x00,0xb8,0x44,0x44,0x04,0x04,0x88,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 43603 0xaa53 "꩓" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x20,0x20,0x20,0x24,0x2a,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x08,0x08,0x10,0x24,0x4a,0x4a,0x30,0x00,0x00,0x00,
+/* 43604 0xaa54 "꩔" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x20,0x7c,0x22,0x22,0x1c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x04,0x08,0x08,0x90,0x50,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43605 0xaa55 "꩕" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x10,0x09,0x02,0x00,0x03,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x40,0x40,0x80,0x40,0x00,0x00,0x00,
+/* 43606 0xaa56 "꩖" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x08,0x08,0x90,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43607 0xaa57 "꩗" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x04,0x04,0x84,0x84,0x88,0x88,0x10,0x60,0x88,0x94,0x60,
+/* 43608 0xaa58 "꩘" */
+0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x11,0x01,0x0f,0x12,0x12,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x84,0x08,0x08,0x10,0x60,0x88,0x94,0x60,
+/* 43609 0xaa59 "꩙" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x24,0x08,0x10,0x10,0x10,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x44,0x84,0x88,0x88,0x10,0x60,0x88,0x94,0x60,
+/* 43610 0xaa5a "꩚" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43611 0xaa5b "꩛" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43612 0xaa5c "꩜" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x24,0x13,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 43613 0xaa5d "꩝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43614 0xaa5e "꩞" */
+0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 43615 0xaa5f "꩟" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0x10,0x10,0x00,0x00,0x00,
+/* 43616 0xaa60 "ꩠ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x23,0x25,0x29,0x4a,0x0c,0x00,0x00,0x00,0x00,
+/* 43617 0xaa61 "ꩡ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x02,0x01,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x52,0x0c,0x00,0x00,0x00,0x00,
+/* 43618 0xaa62 "ꩢ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x02,0x02,0x42,0xa4,0x18,0x00,0x00,0x00,0x00,
+/* 43619 0xaa63 "ꩣ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0xa1,0xa1,0xa1,0x52,0x0c,0x00,0x00,0x00,0x00,
+/* 43620 0xaa64 "ꩤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x21,0x21,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43621 0xaa65 "ꩥ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x21,0x21,0x21,0x62,0xac,0x20,0x20,0x20,0xe0,
+/* 43622 0xaa66 "ꩦ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0xa1,0x21,0x42,0x8c,0x00,0x00,0x00,0x00,
+/* 43623 0xaa67 "ꩧ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0xa1,0x21,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43624 0xaa68 "ꩨ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x23,0xa5,0x29,0x4a,0x8c,0x00,0x00,0x00,0x00,
+/* 43625 0xaa69 "ꩩ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0xb9,0x25,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43626 0xaa6a "ꩪ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x39,0x25,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43627 0xaa6b "ꩫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x82,0xc2,0xa2,0x44,0x00,0x00,0x00,0x00,0x00,
+/* 43628 0xaa6c "ꩬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x31,0x49,0x49,0x86,0x00,0x00,0x00,0x00,
+/* 43629 0xaa6d "ꩭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0xa1,0x61,0x21,0x22,0x2c,0x20,0x20,0x20,0xc0,
+/* 43630 0xaa6e "ꩮ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x06,0x05,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x42,0x21,0x21,0xa1,0x92,0x8c,0x00,0x00,0x00,0x00,
+/* 43631 0xaa6f "ꩯ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0xa4,0x42,0x42,0x42,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 43632 0xaa70 "ꩰ" */
+0x00,0x03,0x04,0x00,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x00,0xe0,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43633 0xaa71 "ꩱ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x05,0x05,0x05,0x02,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x8c,0x52,0x21,0x21,0x21,0x42,0x0c,0x00,0x00,0x00,0x00,
+/* 43634 0xaa72 "ꩲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x05,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x4c,0xb2,0x11,0x11,0x11,0x2a,0x0c,0x00,0x00,0x00,0x00,
+/* 43635 0xaa73 "ꩳ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x82,0x81,0x41,0x21,0x12,0x0c,0x00,0x00,0x00,0x00,
+/* 43636 0xaa74 "ꩴ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x03,0x04,0x03,
+0x30,0x48,0x40,0x20,0x10,0x08,0xc8,0xa8,0xa8,0xa8,0xc8,0x88,0x88,0x88,0xc8,0x30,
+/* 43637 0xaa75 "ꩵ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x25,0x42,0x42,0x22,0x14,0x60,0x00,0x03,0x04,0x03,
+0x18,0x24,0x20,0x10,0x08,0xc4,0x24,0x14,0x14,0x14,0x24,0xc4,0x84,0x84,0xe4,0x18,
+/* 43638 0xaa76 "ꩶ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x45,0x02,0x02,0x02,0x02,0x02,0x02,0x32,0x42,0x3c,
+0x0c,0x12,0x10,0x08,0x04,0xe2,0x12,0x0a,0x0a,0x0a,0x0a,0x32,0x22,0x62,0xb2,0x4c,
+/* 43639 0xaa77 "꩷" */
+0x00,0x06,0x09,0x08,0x04,0x0f,0x10,0x20,0x20,0x20,0x10,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf0,0x90,0x50,0x50,0x50,0x50,0x5c,0x40,0x40,0x40,0x70,
+/* 43640 0xaa78 "꩸" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x27,0x10,0x10,0x10,0x27,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x0c,0x12,0xa0,0x20,0x20,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,0x00,
+/* 43641 0xaa79 "꩹" */
+0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0xa0,0x20,0x20,0x20,0x38,
+/* 43642 0xaa7a "ꩺ" */
+0x00,0x00,0x00,0x07,0x08,0x09,0x0a,0x0c,0x0c,0x0c,0x0a,0x09,0x08,0x08,0x08,0x07,
+0x00,0x00,0x20,0xc0,0x00,0x8c,0x42,0x21,0x21,0x21,0x12,0x9c,0x10,0x10,0x10,0xe0,
+/* 43643 0xaa7b "ꩻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x03,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43644 0xaa7c "ꩼ" */
+0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43645 0xaa7d "ꩽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43646 0xaa7e "ꩾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x71,0x89,0x05,0xe5,0x15,0x89,0x79,0x09,0x09,0x0d,0x1a,
+/* 43647 0xaa7f "ꩿ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x07,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x11,0xa9,0x45,0x45,0xc5,0xad,0x15,0x05,0x05,0x0d,0x1a,
+/* 43648 0xaa80 "ꪀ" */
+0x00,0x00,0x00,0x00,0x18,0x08,0x08,0x08,0x09,0x09,0x0a,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x50,0x90,0x90,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 43649 0xaa81 "ꪁ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x09,0x06,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x28,0x48,0x88,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 43650 0xaa82 "ꪂ" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x11,0x09,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x04,0x08,0x88,0x88,0x88,0x88,0x88,0x08,0xf0,0x08,0x08,0x88,0x70,
+/* 43651 0xaa83 "ꪃ" */
+0x00,0x00,0x00,0x66,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x1d,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x1c,0x22,0x42,0x42,0x42,0x42,0x42,0x4c,0x82,0x02,0x02,0x22,0x1c,
+/* 43652 0xaa84 "ꪄ" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x71,0x29,0x29,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x90,0x90,0x90,0x10,0x1c,0x32,0xcc,0x00,0x00,0x00,0x00,
+/* 43653 0xaa85 "ꪅ" */
+0x00,0x00,0x00,0x08,0x05,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x08,0x08,0x08,0x08,0x08,0x30,0x08,0x08,0x08,0x08,0xf0,
+/* 43654 0xaa86 "ꪆ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x1c,0x0a,0x0a,0x04,0x00,0x00,0x04,0x03,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 43655 0xaa87 "ꪇ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x04,0x03,
+0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x60,0xa0,0x20,0x20,0x20,0x40,0x80,
+/* 43656 0xaa88 "ꪈ" */
+0x00,0x00,0x00,0xdb,0x4c,0x48,0x48,0x48,0x48,0x49,0x4a,0x31,0x00,0x00,0x00,0x00,
+0x06,0x08,0x0e,0x09,0x86,0x88,0x88,0x88,0x88,0xea,0x95,0x0a,0x00,0x00,0x00,0x00,
+/* 43657 0xaa89 "ꪉ" */
+0x02,0x04,0x08,0x13,0x14,0x14,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 43658 0xaa8a "ꪊ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x30,0x48,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xe0,0xd0,0x60,0x00,0x00,0x00,
+/* 43659 0xaa8b "ꪋ" */
+0x00,0x00,0x00,0x02,0x05,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x28,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x12,0x0c,
+/* 43660 0xaa8c "ꪌ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x09,0x06,0x00,0x00,0x00,
+0x00,0x3c,0x42,0x80,0x80,0x60,0x80,0x80,0x80,0x80,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 43661 0xaa8d "ꪍ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x03,
+0x00,0x3c,0x42,0x80,0x80,0x60,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00,
+/* 43662 0xaa8e "ꪎ" */
+0x00,0x00,0x00,0x30,0x08,0x04,0x02,0x01,0x01,0x22,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x08,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x18,0x00,0x00,0x00,0x00,
+/* 43663 0xaa8f "ꪏ" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x71,0x29,0x29,0x10,0x00,0x00,0x00,0x00,
+0x07,0x08,0x10,0x10,0x10,0x90,0x90,0x90,0x10,0x1c,0x32,0xcc,0x00,0x00,0x00,0x00,
+/* 43664 0xaa90 "ꪐ" */
+0x00,0x00,0x00,0x66,0x23,0x22,0x22,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xd8,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0x04,0x04,0x84,0x78,
+/* 43665 0xaa91 "ꪑ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x78,0x14,0x0c,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x70,0x88,0x88,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xf0,
+/* 43666 0xaa92 "ꪒ" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x1e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+/* 43667 0xaa93 "ꪓ" */
+0x00,0x00,0x00,0x60,0x21,0x22,0x22,0x22,0x22,0x23,0x26,0x19,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x10,0x10,0x10,0x10,0x90,0x50,0x90,0x10,0x10,0x12,0x0c,
+/* 43668 0xaa94 "ꪔ" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x78,0x14,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x70,0x88,0x88,0x08,0x08,0x08,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43669 0xaa95 "ꪕ" */
+0x00,0x00,0x00,0x30,0x48,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x48,0xb0,0x00,0x00,0x00,0x00,
+/* 43670 0xaa96 "ꪖ" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x70,0x28,0x28,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x88,0x88,0x70,
+/* 43671 0xaa97 "ꪗ" */
+0x00,0x00,0x00,0x0c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x30,0x50,0x90,0x10,0x10,0x12,0x0c,
+/* 43672 0xaa98 "ꪘ" */
+0x00,0x00,0x00,0xdb,0x4c,0x48,0x48,0x48,0x48,0x49,0x4a,0x31,0x00,0x00,0x00,0x00,
+0x02,0x04,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0xea,0x95,0x0a,0x00,0x00,0x00,0x00,
+/* 43673 0xaa99 "ꪙ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x20,0x40,0x80,0x80,0x80,0x80,0xe0,0xd0,0x60,0x00,0x00,0x00,
+/* 43674 0xaa9a "ꪚ" */
+0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43675 0xaa9b "ꪛ" */
+0x00,0x00,0x00,0x00,0x32,0x12,0x12,0x12,0x12,0x12,0x12,0x0d,0x00,0x00,0x00,0x00,
+0x04,0x08,0x08,0x08,0x48,0x48,0x48,0x48,0x48,0x48,0x48,0xb0,0x00,0x00,0x00,0x00,
+/* 43676 0xaa9c "ꪜ" */
+0x00,0x00,0x00,0x30,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x18,0x24,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43677 0xaa9d "ꪝ" */
+0x00,0x00,0x00,0x00,0x31,0x11,0x11,0x11,0x11,0x11,0x11,0x0e,0x00,0x00,0x00,0x00,
+0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0xe0,0x00,0x00,0x00,0x00,
+/* 43678 0xaa9e "ꪞ" */
+0x00,0x00,0x00,0x00,0x00,0x60,0x14,0x1a,0x10,0x10,0x10,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x3c,0x42,0x80,0x80,0x60,0x80,0x80,0x80,0x80,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 43679 0xaa9f "ꪟ" */
+0x00,0x00,0x00,0x01,0x62,0x22,0x22,0x22,0x22,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,
+0x04,0x08,0x08,0x08,0x88,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x08,0x08,0x30,0x00,
+/* 43680 0xaaa0 "ꪠ" */
+0x00,0x04,0x04,0x1b,0x30,0x08,0x09,0x09,0x09,0x09,0x08,0x07,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x80,0x80,0x00,0x00,0x00,0x60,0x90,0x60,0x00,0x00,0x00,0x00,
+/* 43681 0xaaa1 "ꪡ" */
+0x00,0x00,0x00,0x00,0x63,0x25,0x25,0x29,0x29,0x31,0x31,0x20,0x00,0x00,0x00,0x00,
+0x00,0x1c,0x22,0x20,0x20,0x20,0x20,0x20,0x20,0x38,0x64,0x98,0x00,0x00,0x00,0x00,
+/* 43682 0xaaa2 "ꪢ" */
+0x00,0x00,0x00,0x6d,0x26,0x24,0x24,0x24,0x24,0x24,0x25,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x01,0x82,0x44,0x44,0x44,0x44,0x42,0xe2,0x52,0x8c,0x00,0x00,0x00,0x00,
+/* 43683 0xaaa3 "ꪣ" */
+0x00,0x00,0x00,0x38,0x44,0x04,0x04,0x04,0x04,0x0e,0x15,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x08,0x08,0x08,0xf0,0x00,0x00,0x00,0x00,
+/* 43684 0xaaa4 "ꪤ" */
+0x02,0x02,0x0d,0x38,0x44,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x0c,0x12,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43685 0xaaa5 "ꪥ" */
+0x02,0x02,0x0d,0x38,0x44,0x04,0x04,0x04,0x04,0x04,0x02,0x01,0x00,0x00,0x00,0x00,
+0x08,0x10,0xa0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43686 0xaaa6 "ꪦ" */
+0x00,0x00,0x00,0x23,0x14,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 43687 0xaaa7 "ꪧ" */
+0x00,0x00,0x00,0x23,0x14,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x58,0x34,0x38,0x10,0x08,0x00,0x00,
+/* 43688 0xaaa8 "ꪨ" */
+0x00,0x00,0x00,0xcd,0x46,0x44,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x12,0x0c,
+/* 43689 0xaaa9 "ꪩ" */
+0x00,0x00,0x00,0x07,0x08,0x08,0x00,0x01,0x00,0x00,0x0d,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x90,0x20,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43690 0xaaaa "ꪪ" */
+0x00,0x00,0x00,0xdb,0x4c,0x48,0x48,0x48,0x48,0x48,0x48,0x30,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x70,0x88,0x84,0x84,0x84,0x84,0x84,0xa4,0x98,0x00,0x00,0x00,0x00,
+/* 43691 0xaaab "ꪫ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x00,0x00,0x00,0x08,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 43692 0xaaac "ꪬ" */
+0x00,0x00,0x00,0xcc,0x55,0x4e,0x44,0x44,0x44,0x44,0x44,0x38,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x22,0x24,0x18,0x00,0x00,0x00,0x00,
+/* 43693 0xaaad "ꪭ" */
+0x00,0x00,0x00,0x30,0x11,0x12,0x12,0x12,0x14,0x14,0x14,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x08,0x08,0x08,0x08,0x08,0x48,0x30,0x00,0x00,0x00,0x00,
+/* 43694 0xaaae "ꪮ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x02,0x01,0x00,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x50,0x90,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,
+/* 43695 0xaaaf "ꪯ" */
+0x00,0x03,0x04,0x04,0x02,0x01,0x00,0x04,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xc0,0x20,0x10,0x10,0xf8,0x14,0x14,0x24,0xc4,0x04,0x04,0x04,0x04,0x88,0x70,
+/* 43696 0xaab0 "ꪰ" */
+0x00,0x04,0x08,0x08,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43697 0xaab1 "ꪱ" */
+0x00,0x00,0x00,0x07,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
+/* 43698 0xaab2 "ꪲ" */
+0x00,0x01,0x01,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43699 0xaab3 "ꪳ" */
+0x08,0x14,0x17,0x08,0x10,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43700 0xaab4 "ꪴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x0e,0x22,0x1c,0x00,
+/* 43701 0xaab5 "ꪵ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x40,0x80,0x80,0x80,0x80,0x80,0x80,0x60,0x00,0x00,0x00,0x00,
+/* 43702 0xaab6 "ꪶ" */
+0x00,0x01,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0xe0,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43703 0xaab7 "ꪷ" */
+0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43704 0xaab8 "ꪸ" */
+0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0xa0,0x40,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43705 0xaab9 "ꪹ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 43706 0xaaba "ꪺ" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x01,0x01,0x02,0x04,0x00,0x00,0x00,0x00,
+0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0xc0,0x00,0xc0,0xa0,0x40,0x00,0x00,0x00,0x00,
+/* 43707 0xaabb "ꪻ" */
+0x00,0x06,0x09,0x08,0x08,0x04,0x03,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x90,0xe0,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43708 0xaabc "ꪼ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x02,0x01,0x00,0x01,0x02,0x02,0x04,0x06,
+0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0x00,0x00,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 43709 0xaabd "ꪽ" */
+0x00,0x00,0x00,0x00,0x00,0x31,0x4a,0x08,0x08,0x08,0x08,0x09,0x06,0x00,0x00,0x00,
+0x00,0x20,0x40,0x80,0x90,0xe0,0x80,0x80,0x80,0x80,0xc0,0x20,0xc0,0x00,0x00,0x00,
+/* 43710 0xaabe "ꪾ" */
+0x03,0x02,0x0e,0x09,0x38,0x27,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x88,0x70,0x20,0xc0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43711 0xaabf "꪿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x40,0x40,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43712 0xaac0 "ꫀ" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x04,0x07,0x04,0x04,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x20,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 43713 0xaac1 "꫁" */
+0x00,0x00,0x06,0x09,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43714 0xaac2 "ꫂ" */
+0x00,0x00,0x00,0x07,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,
+0x00,0x00,0x00,0x80,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x80,0x00,0x00,
+/* 43715 0xaac3 "꫃" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 43716 0xaac4 "꫄" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 43717 0xaac5 "꫅" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 43718 0xaac6 "꫆" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 43719 0xaac7 "꫇" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43720 0xaac8 "꫈" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43721 0xaac9 "꫉" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43722 0xaaca "꫊" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43723 0xaacb "꫋" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43724 0xaacc "꫌" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43725 0xaacd "꫍" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43726 0xaace "꫎" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43727 0xaacf "꫏" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43728 0xaad0 "꫐" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 43729 0xaad1 "꫑" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 43730 0xaad2 "꫒" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 43731 0xaad3 "꫓" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 43732 0xaad4 "꫔" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 43733 0xaad5 "꫕" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 43734 0xaad6 "꫖" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 43735 0xaad7 "꫗" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43736 0xaad8 "꫘" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43737 0xaad9 "꫙" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43738 0xaada "꫚" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43739 0xaadb "ꫛ" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x23,0x7d,0x29,0x29,0x10,0x00,0x00,0x00,0x00,
+0x07,0x08,0x10,0x12,0x0c,0x84,0xb8,0xc8,0x08,0x1c,0x2a,0xcc,0x00,0x00,0x00,0x00,
+/* 43740 0xaadc "ꫜ" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x71,0x29,0x29,0x10,0x00,0x00,0x00,0x00,
+0x07,0x08,0x10,0x12,0x0c,0x84,0x88,0x88,0x08,0x1c,0x2a,0xcc,0x00,0x00,0x00,0x00,
+/* 43741 0xaadd "ꫝ" */
+0x02,0x04,0x08,0x08,0x0b,0x04,0x0a,0x09,0x08,0x1c,0x0a,0x0a,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0xe0,0x50,0x48,0x48,0x30,0x00,0x00,0x00,
+/* 43742 0xaade "꫞" */
+0x1f,0x21,0x45,0x10,0x01,0x0a,0x05,0x5a,0x4a,0x4a,0x64,0x00,0x14,0x41,0x3e,0x00,
+0x7c,0x84,0x08,0x50,0x02,0x04,0x54,0xac,0xa4,0xa4,0x98,0x00,0x50,0x04,0xf8,0x00,
+/* 43743 0xaadf "꫟" */
+0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x1f,0x20,0x07,0x08,0x11,0x0e,0x00,
+0x00,0x70,0x80,0x00,0x20,0xc0,0x40,0x80,0x80,0xe0,0x90,0xe0,0x80,0xc0,0xa0,0xc0,
+/* 43744 0xaae0 "ꫠ" */
+0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x08,0x00,0x00,0x13,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x90,0x70,0x00,0x00,0x00,
+/* 43745 0xaae1 "ꫡ" */
+0x00,0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43746 0xaae2 "ꫢ" */
+0x00,0x00,0x00,0x00,0x1c,0x24,0x17,0x10,0x10,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x90,0xa0,0x20,0x20,0x40,0x40,0x40,0x30,0x00,0x00,0x00,
+/* 43747 0xaae3 "ꫣ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x02,0x02,0x02,0x34,0x4c,0x4c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x90,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43748 0xaae4 "ꫤ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x10,0x20,0x50,0x89,0x85,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x0c,0x92,0xa2,0x42,0xa2,0x12,0x0a,0x92,0x62,0x00,0x00,0x00,
+/* 43749 0xaae5 "ꫥ" */
+0x00,0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x0f,0x09,0x0f,0x09,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xe0,0x20,0xe0,0x20,0xe0,0x00,0x00,0x00,
+/* 43750 0xaae6 "ꫦ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x18,0x25,0x42,0x40,0x20,0x20,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x20,0x10,0x10,0x20,0x20,0x40,0x00,0x00,0x00,
+/* 43751 0xaae7 "ꫧ" */
+0x00,0x00,0x00,0x00,0x18,0x24,0x22,0x21,0x22,0x24,0x28,0x24,0x23,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x88,0x08,0x88,0x48,0x28,0x48,0x88,0x00,0x00,0x00,
+/* 43752 0xaae8 "ꫨ" */
+0x00,0x00,0x00,0x00,0x3f,0x10,0x13,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0xf0,0x10,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,
+/* 43753 0xaae9 "ꫩ" */
+0x00,0x00,0x00,0x00,0x7f,0x22,0x14,0x08,0x14,0x22,0x22,0x14,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x88,0x50,0x20,0x50,0x88,0x88,0x50,0x20,0x00,0x00,0x00,
+/* 43754 0xaaea "ꫪ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0xe0,0x20,0x20,0x20,0xe0,0x00,0x00,0x00,
+/* 43755 0xaaeb "ꫫ" */
+0x00,0x60,0x90,0x90,0x7c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43756 0xaaec "ꫬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x90,0x60,0x00,
+/* 43757 0xaaed "ꫭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x80,0x40,0x20,0x60,0xa0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43758 0xaaee "ꫮ" */
+0x00,0x60,0x90,0x70,0x20,0x20,0x38,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43759 0xaaef "ꫯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x0c,0x12,0x1c,0x08,0x08,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 43760 0xaaf0 "꫰" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43761 0xaaf1 "꫱" */
+0x00,0x00,0x00,0x00,0x10,0x0c,0x03,0x00,0x03,0x0c,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x60,0x80,0x00,0x80,0x60,0x10,0x00,0x00,0x00,0x00,0x00,
+/* 43762 0xaaf2 "ꫲ" */
+0x00,0x00,0x02,0x01,0x00,0x01,0x02,0x00,0x00,0x01,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x80,0x20,0xc0,0x00,0xc0,0x20,0x20,0x40,0x80,0x00,0x20,0xc0,0x00,0x00,0x00,
+/* 43763 0xaaf3 "ꫳ" */
+0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x00,0x00,0x00,
+/* 43764 0xaaf4 "ꫴ" */
+0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x40,0x80,0x00,0x80,0x60,0x00,0x00,0x00,
+/* 43765 0xaaf5 "ꫵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x04,0x04,0x04,0x00,0x00,0x00,0x00,0x00,
+/* 43766 0xaaf6 "꫶" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,
+/* 43767 0xaaf7 "꫷" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43768 0xaaf8 "꫸" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43769 0xaaf9 "꫹" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43770 0xaafa "꫺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43771 0xaafb "꫻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43772 0xaafc "꫼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43773 0xaafd "꫽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43774 0xaafe "꫾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43775 0xaaff "꫿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43776 0xab00 "꬀" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 43777 0xab01 "ꬁ" */
+0x00,0x00,0x06,0x06,0x07,0x0f,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xfc,0xcc,0xc0,0xc0,0xc0,0x00,0x00,
+/* 43778 0xab02 "ꬂ" */
+0x00,0x00,0x06,0x06,0x07,0x0f,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 43779 0xab03 "ꬃ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x06,0x06,0x07,0x07,0x06,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0xc0,0xe0,0x30,0x30,0xf0,0xf0,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 43780 0xab04 "ꬄ" */
+0x00,0x00,0x06,0x06,0x07,0x0f,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 43781 0xab05 "ꬅ" */
+0x00,0x00,0x03,0x03,0x01,0x03,0x06,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x00,0x80,0xc0,0xe0,0x30,0x30,0xf0,0xf0,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 43782 0xab06 "ꬆ" */
+0x00,0x00,0x01,0x01,0x01,0x03,0x06,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x00,0x00,
+0x00,0x00,0x80,0x80,0xc0,0xe0,0x30,0x30,0xf0,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,
+/* 43783 0xab07 "꬇" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43784 0xab08 "꬈" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43785 0xab09 "ꬉ" */
+0x06,0x06,0x07,0x0f,0x18,0x1f,0x18,0x0d,0x06,0x1f,0x30,0x30,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0xc0,0xc0,0xfc,0x8c,0x80,0x00,0x00,
+/* 43786 0xab0a "ꬊ" */
+0x06,0x06,0x07,0x0f,0x18,0x1f,0x18,0x0d,0x06,0x1f,0x30,0x30,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0xc0,0xc0,0xc0,0x98,0xf8,0x00,0x00,
+/* 43787 0xab0b "ꬋ" */
+0x03,0x03,0x03,0x07,0x0c,0x0f,0x0c,0x06,0x03,0x0f,0x0c,0x0c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xc0,0x40,0xc0,0x40,0x80,0x00,0xf0,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 43788 0xab0c "ꬌ" */
+0x06,0x06,0x07,0x0f,0x18,0x1f,0x18,0x0d,0x06,0x06,0x06,0x03,0x3f,0x30,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0xf0,0x98,0xf0,0x00,0x00,
+/* 43789 0xab0d "ꬍ" */
+0x06,0x06,0x07,0x0f,0x18,0x1f,0x18,0x0d,0x06,0x06,0x06,0x03,0x3f,0x30,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0xf8,0x98,0x00,0x00,0x00,0x00,0x00,0xf0,0x30,0x00,0x00,
+/* 43790 0xab0e "ꬎ" */
+0x03,0x03,0x07,0x0c,0x0f,0x0c,0x06,0x03,0x07,0x0c,0x18,0x18,0x18,0x18,0x00,0x00,
+0x00,0x80,0xc0,0x40,0xc0,0x40,0x80,0x00,0xf0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43791 0xab0f "꬏" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43792 0xab10 "꬐" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 43793 0xab11 "ꬑ" */
+0x60,0x7f,0x40,0x18,0x18,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x30,0xf0,0x10,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xfc,0xcc,0xcc,0xc0,0xc0,0x00,0x00,
+/* 43794 0xab12 "ꬒ" */
+0x60,0x7f,0x40,0x18,0x18,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x30,0xf0,0x10,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 43795 0xab13 "ꬓ" */
+0x30,0x3f,0x20,0x0c,0x0c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,
+0x18,0xf8,0x08,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x60,0x60,0x60,0x00,0x00,
+/* 43796 0xab14 "ꬔ" */
+0x60,0x7f,0x40,0x18,0x18,0x18,0x18,0x1f,0x1f,0x18,0x18,0x18,0x18,0x18,0x00,0x00,
+0x30,0xf0,0x10,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xc0,0xf8,0xcc,0xf8,0x00,0x00,
+/* 43797 0xab15 "ꬕ" */
+0x30,0x3f,0x20,0x00,0x1c,0x36,0x36,0x06,0x07,0x07,0x06,0x06,0x06,0x06,0x00,0x00,
+0x18,0xf8,0x08,0x00,0x30,0x30,0x30,0x30,0xf0,0xf0,0x30,0x30,0x30,0x30,0x00,0x00,
+/* 43798 0xab16 "ꬖ" */
+0x30,0x3f,0x20,0x0c,0x0c,0x0c,0x0c,0x0f,0x0f,0x0c,0x0c,0x0c,0x0c,0x0c,0x00,0x00,
+0x18,0xf8,0x08,0x60,0x60,0x60,0x60,0xe0,0xe0,0x60,0x60,0x00,0x00,0x00,0x00,0x00,
+/* 43799 0xab17 "꬗" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43800 0xab18 "꬘" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 43801 0xab19 "꬙" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 43802 0xab1a "꬚" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 43803 0xab1b "꬛" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 43804 0xab1c "꬜" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43805 0xab1d "꬝" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43806 0xab1e "꬞" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43807 0xab1f "꬟" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43808 0xab20 "ꬠ" */
+0x60,0x7f,0x40,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x30,0xf0,0x10,0x00,0x80,0xc0,0x60,0x30,0x30,0x30,0x38,0xb6,0xb2,0xbe,0x00,0x00,
+/* 43809 0xab21 "ꬡ" */
+0x60,0x7f,0x40,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x30,0xf0,0x10,0x00,0x80,0xc0,0x60,0x30,0x3f,0x33,0x38,0xb4,0xb2,0xbe,0x00,0x00,
+/* 43810 0xab22 "ꬢ" */
+0x60,0x7f,0x40,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x30,0xf0,0x10,0x00,0x80,0xc0,0x60,0x30,0x30,0x30,0x30,0xb0,0xb3,0xbf,0x00,0x00,
+/* 43811 0xab23 "ꬣ" */
+0x30,0x3f,0x20,0x0f,0x1f,0x31,0x61,0x79,0x65,0x7d,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0xf8,0x08,0xe0,0xf0,0x18,0x18,0x98,0x58,0xd8,0x18,0x34,0x32,0x3e,0x00,0x00,
+/* 43812 0xab24 "ꬤ" */
+0x60,0x7f,0x40,0x00,0x1f,0x3f,0x62,0xc2,0xc2,0xc2,0xf3,0xda,0xca,0xfb,0x00,0x00,
+0x30,0xf0,0x10,0x00,0x80,0xc0,0x60,0x3f,0x39,0x37,0x30,0xbc,0xb2,0xbe,0x00,0x00,
+/* 43813 0xab25 "ꬥ" */
+0x60,0x7f,0x40,0x1f,0x7f,0xc6,0xe6,0x97,0xf3,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
+0x30,0xf0,0x10,0xc0,0xe0,0x30,0x38,0x24,0x3c,0x00,0x80,0x40,0x20,0xe0,0x00,0x00,
+/* 43814 0xab26 "ꬦ" */
+0x30,0x3f,0x20,0x0f,0x1f,0x1a,0x32,0x23,0x62,0x62,0x73,0x68,0x64,0x7c,0x00,0x00,
+0x18,0xf8,0x08,0xe0,0xf0,0x18,0x18,0x18,0x94,0x52,0x9c,0x00,0x00,0x00,0x00,0x00,
+/* 43815 0xab27 "꬧" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 43816 0xab28 "ꬨ" */
+0x00,0x18,0x1f,0x10,0x01,0x03,0x06,0x06,0x03,0x07,0x0e,0x0c,0x0c,0x0c,0x00,0x00,
+0x00,0x18,0xf8,0x08,0x80,0xc0,0x60,0x60,0xc0,0xe0,0x70,0x30,0x30,0x30,0x00,0x00,
+/* 43817 0xab29 "ꬩ" */
+0x00,0x60,0x7f,0x40,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x60,0xe0,0x20,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xfc,0xcc,0xc0,0x00,0x00,
+/* 43818 0xab2a "ꬪ" */
+0x00,0x60,0x7f,0x40,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x60,0xe0,0x20,0x00,0x00,0x80,0x80,0x00,0x80,0xc0,0xc0,0xcc,0xfc,0x00,0x00,
+/* 43819 0xab2b "ꬫ" */
+0x30,0x3f,0x20,0x03,0x07,0x0c,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x00,0x00,0x00,0x00,
+0x30,0xf0,0x10,0x00,0x80,0xc0,0xc0,0x80,0xc0,0xc0,0xe0,0x60,0x60,0x60,0x00,0x00,
+/* 43820 0xab2c "ꬬ" */
+0x00,0x30,0x3f,0x20,0x03,0x07,0x0c,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x18,0x00,0x00,
+0x00,0x60,0xe0,0x20,0x00,0x80,0xc0,0xc0,0x80,0xc0,0xe0,0x78,0x6c,0x78,0x00,0x00,
+/* 43821 0xab2d "ꬭ" */
+0x00,0x30,0x3f,0x20,0x06,0x0f,0x19,0x19,0x0f,0x1f,0x39,0x30,0x30,0x30,0x00,0x00,
+0x00,0x60,0xe0,0x20,0x00,0x00,0xf8,0x98,0x00,0x80,0xc0,0xc0,0xc0,0xc0,0x00,0x00,
+/* 43822 0xab2e "ꬮ" */
+0x30,0x3f,0x20,0x03,0x07,0x0c,0x0c,0x07,0x0f,0x1c,0x18,0x18,0x18,0x18,0x00,0x00,
+0x60,0xe0,0x20,0x00,0x80,0xc0,0xc0,0x80,0xc0,0xe0,0x60,0x60,0x00,0x00,0x00,0x00,
+/* 43823 0xab2f "꬯" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x7d,0x61,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43824 0xab30 "ꬰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x4c,0x44,0xfe,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43825 0xab31 "ꬱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x92,0x10,0x70,0x9e,0x92,0x92,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43826 0xab32 "ꬲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x44,0x48,0x52,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43827 0xab33 "ꬳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x7e,0x40,0xfe,0x40,0x3e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43828 0xab34 "ꬴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x7e,0xa0,0xa0,0xa2,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43829 0xab35 "ꬵ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x7c,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43830 0xab36 "ꬶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0x46,0x42,0x42,0x3e,0x02,0x12,0x2a,0x1c,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43831 0xab37 "ꬷ" */
+0x00,0x00,0x00,0x00,0x30,0x10,0x14,0x12,0x7c,0x90,0x50,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43832 0xab38 "ꬸ" */
+0x00,0x00,0x00,0x00,0x30,0x10,0x12,0x7c,0x90,0x12,0x7c,0x90,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43833 0xab39 "ꬹ" */
+0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x38,0x54,0x54,0x38,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43834 0xab3a "ꬺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x52,0x52,0x52,0x52,0x57,0x5a,0x54,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43835 0xab3b "ꬻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x47,0x4a,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43836 0xab3c "ꬼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x62,0x42,0x42,0x42,0x44,0x44,0x4e,0x14,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43837 0xab3d "ꬽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x44,0x44,0x44,0x44,0x28,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43838 0xab3e "ꬾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x28,0x4c,0x54,0x54,0x64,0x28,0x50,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43839 0xab3f "ꬿ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x3c,0x46,0x0a,0x0a,0x12,0x12,0x62,0x3c,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43840 0xab40 "ꭀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x90,0x90,0x9e,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43841 0xab41 "ꭁ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x5c,0xa6,0x26,0x2a,0xea,0xb2,0xb2,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43842 0xab42 "ꭂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x12,0x12,0xfe,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43843 0xab43 "ꭃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x92,0x92,0x92,0x92,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43844 0xab44 "ꭄ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x9c,0xa6,0xa6,0xaa,0xaa,0xb2,0xa2,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43845 0xab45 "ꭅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x38,0x44,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43846 0xab46 "ꭆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x50,0x50,0x48,0x48,0x09,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43847 0xab47 "ꭇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x30,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43848 0xab48 "ꭈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x6a,0x4a,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43849 0xab49 "ꭉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0x32,0x22,0x20,0x20,0x70,0xa0,0xa0,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43850 0xab4a "ꭊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x35,0x25,0x20,0x20,0x70,0xa0,0xa0,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43851 0xab4b "ꭋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x5a,0x42,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43852 0xab4c "ꭌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xcc,0xb4,0x84,0x06,0x05,0x05,0x05,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43853 0xab4d "ꭍ" */
+0x00,0x00,0x00,0x0c,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43854 0xab4e "ꭎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43855 0xab4f "ꭏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0xfe,0x44,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43856 0xab50 "ꭐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x82,0x82,0x92,0x92,0x92,0x92,0x6e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43857 0xab51 "ꭑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xec,0x92,0x92,0x92,0x92,0x82,0x82,0x92,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43858 0xab52 "ꭒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0xa2,0xa2,0x22,0x22,0x22,0x26,0x1a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43859 0xab53 "ꭓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0x24,0x42,0x42,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43860 0xab54 "ꭔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x84,0x84,0x48,0x48,0x30,0x30,0x4c,0x4a,0x8a,0x84,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43861 0xab55 "ꭕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x24,0x18,0x18,0x24,0xa4,0xc2,0x82,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43862 0xab56 "ꭖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x84,0x84,0x48,0x30,0x30,0x4a,0x85,0x85,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43863 0xab57 "ꭗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x21,0x12,0x0c,0x0c,0x12,0x21,0x41,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43864 0xab58 "ꭘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x1a,0x25,0x45,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43865 0xab59 "ꭙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x21,0x12,0x0c,0x0c,0x12,0x21,0xa1,0xc0,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43866 0xab5a "ꭚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x42,0x42,0x26,0x1a,0x02,0x02,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43867 0xab5b "꭛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x38,0x00,0x38,0x44,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43868 0xab5c "ꭜ" */
+0x00,0x00,0x00,0x40,0x40,0x58,0x64,0x44,0x44,0x44,0x04,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43869 0xab5d "ꭝ" */
+0x00,0x00,0x00,0x70,0x14,0x12,0x7c,0x90,0x50,0x10,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43870 0xab5e "ꭞ" */
+0x00,0x00,0x00,0x38,0x08,0x08,0x3a,0x4c,0x08,0x08,0x3e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43871 0xab5f "ꭟ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0xa2,0x22,0x26,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43872 0xab60 "ꭠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x50,0x50,0x5c,0x52,0x52,0x52,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43873 0xab61 "ꭡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x52,0x7e,0x50,0x50,0x52,0x4c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43874 0xab62 "ꭢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x92,0x12,0x1e,0x10,0x10,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43875 0xab63 "ꭣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0x92,0x92,0x92,0x92,0x92,0x92,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43876 0xab64 "ꭤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x46,0x42,0x42,0x42,0x46,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43877 0xab65 "ꭥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x82,0x82,0x82,0x44,0x28,0x28,0xee,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43878 0xab66 "ꭦ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x7e,0xa2,0xa4,0xa4,0xa8,0xa8,0xb0,0x7e,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43879 0xab67 "ꭧ" */
+0x00,0x00,0x00,0x00,0x40,0x40,0x46,0xf9,0x48,0x44,0x42,0x41,0x51,0x2e,0x08,0x06,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43880 0xab68 "ꭨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x05,0x1e,0x24,0x04,0x44,0x4c,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43881 0xab69 "ꭩ" */
+0x00,0x00,0x00,0x00,0x00,0x22,0x36,0x55,0x49,0x49,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43882 0xab6a "꭪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x7c,0x04,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43883 0xab6b "꭫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7c,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43884 0xab6c "꭬" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 43885 0xab6d "꭭" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 43886 0xab6e "꭮" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 43887 0xab6f "꭯" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 43888 0xab70 "ꭰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43889 0xab71 "ꭱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x50,0x48,0x44,0x43,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43890 0xab72 "ꭲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43891 0xab73 "ꭳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x08,0x14,0x12,0x21,0x51,0x55,0x26,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43892 0xab74 "ꭴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x4b,0x49,0x4e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43893 0xab75 "ꭵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x00,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43894 0xab76 "ꭶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x20,0x7f,0x04,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43895 0xab77 "ꭷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x02,0x22,0x52,0x52,0x62,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43896 0xab78 "ꭸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x4c,0x54,0x76,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43897 0xab79 "ꭹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x26,0x1a,0x02,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43898 0xab7a "ꭺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x7e,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43899 0xab7b "ꭻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43900 0xab7c "ꭼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x7c,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43901 0xab7d "ꭽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x48,0xa8,0xbb,0x49,0x0a,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43902 0xab7e "ꭾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x02,0x02,0x42,0x7c,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43903 0xab7f "ꭿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x3e,0x22,0x22,0xaa,0xcc,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43904 0xab80 "ꮀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x3e,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43905 0xab81 "ꮁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43906 0xab82 "ꮂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x30,0xb7,0xb4,0x48,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43907 0xab83 "ꮃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x5a,0x5a,0x66,0x66,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43908 0xab84 "ꮄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43909 0xab85 "ꮅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x52,0x4c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43910 0xab86 "ꮆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x20,0x40,0x50,0x5c,0x52,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43911 0xab87 "ꮇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x66,0x66,0x5a,0x5a,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43912 0xab88 "ꮈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x72,0x1e,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43913 0xab89 "ꮉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x0a,0x15,0x20,0x3c,0x52,0x52,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43914 0xab8a "ꮊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x4a,0x4a,0x4e,0x4a,0x4a,0x4a,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43915 0xab8b "ꮋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x7e,0x42,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43916 0xab8c "ꮌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x38,0x44,0x02,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43917 0xab8d "ꮍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x47,0x42,0x42,0x26,0x1a,0x02,0xe2,0x44,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43918 0xab8e "ꮎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x42,0x42,0x7e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43919 0xab8f "ꮏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0xf0,0x40,0x40,0x4e,0x44,0x3c,0x04,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43920 0xab90 "ꮐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x84,0x80,0x80,0x9e,0x84,0x84,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43921 0xab91 "ꮑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x12,0x22,0xa2,0xa2,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43922 0xab92 "ꮒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x5c,0x62,0x42,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43923 0xab93 "ꮓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x08,0x10,0x20,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43924 0xab94 "ꮔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0xe4,0x04,0xe4,0x44,0x3c,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43925 0xab95 "ꮕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x4a,0x4d,0x49,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43926 0xab96 "ꮖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43927 0xab97 "ꮗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x02,0x42,0x4a,0x4a,0x4a,0x34,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43928 0xab98 "ꮘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x19,0x29,0x2a,0x48,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43929 0xab99 "ꮙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xa3,0xa5,0x66,0x24,0x14,0x14,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43930 0xab9a "ꮚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x02,0x9a,0xa2,0xa2,0xa2,0x5c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43931 0xab9b "ꮛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x3c,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43932 0xab9c "ꮜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x42,0x42,0x7e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43933 0xab9d "ꮝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x22,0x02,0x1a,0xd2,0xb2,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43934 0xab9e "ꮞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x0c,0x14,0x24,0x44,0x7e,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43935 0xab9f "ꮟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7c,0x42,0x42,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43936 0xaba0 "ꮠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0b,0x5d,0x68,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43937 0xaba1 "ꮡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x64,0x9a,0xe2,0x40,0x98,0x84,0x84,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43938 0xaba2 "ꮢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x5c,0x48,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43939 0xaba3 "ꮣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43940 0xaba4 "ꮤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0xaa,0x92,0xb2,0xca,0xca,0x86,0x82,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43941 0xaba5 "ꮥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x47,0x20,0x1f,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43942 0xaba6 "ꮦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x90,0x10,0x10,0x12,0x11,0x11,0x0e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43943 0xaba7 "ꮧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0c,0x14,0x24,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43944 0xaba8 "ꮨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x0c,0x14,0x24,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43945 0xaba9 "ꮩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x82,0x44,0x44,0x28,0x28,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43946 0xabaa "ꮪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x30,0x0c,0x02,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43947 0xabab "ꮫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x49,0x42,0x60,0x50,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43948 0xabac "ꮬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x18,0x24,0x22,0x55,0x55,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43949 0xabad "ꮭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x22,0x42,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43950 0xabae "ꮮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43951 0xabaf "ꮯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x40,0x40,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43952 0xabb0 "ꮰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x44,0xa4,0x7e,0x24,0x24,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43953 0xabb1 "ꮱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x66,0x99,0x9a,0x28,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43954 0xabb2 "ꮲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x42,0x42,0x7c,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43955 0xabb3 "ꮳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x47,0x40,0x40,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43956 0xabb4 "ꮴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xf1,0x91,0x12,0x12,0x14,0x14,0x18,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43957 0xabb5 "ꮵ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x43,0x4d,0x74,0x44,0x44,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43958 0xabb6 "ꮶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x48,0x50,0x60,0x60,0x50,0x48,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43959 0xabb7 "ꮷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x3e,0x42,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43960 0xabb8 "ꮸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x4a,0x45,0x40,0x40,0x45,0x4a,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43961 0xabb9 "ꮹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x44,0x40,0x40,0x4e,0x44,0x3b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43962 0xabba "ꮺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x55,0x53,0x51,0x31,0x19,0x95,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43963 0xabbb "ꮻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x72,0x52,0x5e,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43964 0xabbc "ꮼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x32,0x49,0x49,0x71,0x41,0x41,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43965 0xabbd "ꮽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x0a,0x06,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43966 0xabbe "ꮾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x42,0x40,0x40,0x7c,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43967 0xabbf "ꮿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x21,0x01,0x01,0x5d,0x49,0x49,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43968 0xabc0 "ꯀ" */
+0x00,0x00,0x00,0x00,0x7f,0x24,0x24,0x25,0x26,0x24,0x2c,0x34,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0xb0,0xd0,0x90,0x90,0x90,0x90,0x90,0xf0,0x00,0x00,0x00,
+/* 43969 0xabc1 "ꯁ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x10,0x10,0x10,0x08,0x08,0x04,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x84,0x04,0x04,0x08,0x08,0x10,0x20,0x00,0x00,0x00,
+/* 43970 0xabc2 "ꯂ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x07,0x08,0x10,0x10,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x20,0x20,0xa0,0x60,0x00,0x00,0x40,0x80,0x00,0x00,0x00,
+/* 43971 0xabc3 "ꯃ" */
+0x00,0x00,0x00,0x00,0x7f,0x24,0x24,0x24,0x3f,0x24,0x25,0x25,0x24,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xe0,0xc0,0x00,0x10,0xe0,0x00,0x00,0x00,
+/* 43972 0xabc4 "ꯄ" */
+0x00,0x00,0x00,0x00,0x7f,0x44,0x24,0x24,0x14,0x14,0x14,0x54,0x64,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x88,0x90,0x90,0xa0,0xa0,0xa0,0xa8,0x98,0x00,0x00,0x00,
+/* 43973 0xabc5 "ꯅ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x08,0x08,0x10,0x10,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x10,0x10,0x20,0x40,0x08,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 43974 0xabc6 "ꯆ" */
+0x00,0x00,0x00,0x00,0x3f,0x20,0x10,0x10,0x08,0x0f,0x08,0x28,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0x20,0x20,0x40,0xc0,0x40,0x50,0x30,0x00,0x00,0x00,
+/* 43975 0xabc7 "ꯇ" */
+0x00,0x00,0x00,0x01,0x1f,0x11,0x08,0x08,0x04,0x04,0x24,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x80,0x00,0xf0,0x08,0x90,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43976 0xabc8 "ꯈ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x08,0x05,0x06,0x04,0x04,0x04,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0xc0,0x20,0x28,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43977 0xabc9 "ꯉ" */
+0x00,0x00,0x00,0x00,0x07,0x04,0x04,0x04,0x64,0x94,0x14,0x24,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x90,0x90,0x90,0x90,0x90,0x90,0x90,0xf0,0x00,0x00,0x00,
+/* 43978 0xabca "ꯊ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x08,0x10,0x10,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0x88,0x84,0x84,0x48,0x30,0x00,0x00,0x00,
+/* 43979 0xabcb "ꯋ" */
+0x00,0x00,0x00,0x00,0x3f,0x20,0x10,0x10,0x09,0x08,0x08,0x08,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0xa0,0x60,0x20,0x18,0x00,0x00,0x00,
+/* 43980 0xabcc "ꯌ" */
+0x00,0x00,0x00,0x00,0x7f,0x08,0x10,0x13,0x0d,0x02,0x04,0x08,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xff,0x08,0x04,0x64,0x58,0x40,0x20,0x24,0x18,0x00,0x00,0x00,
+/* 43981 0xabcd "ꯍ" */
+0x00,0x00,0x00,0x00,0x7f,0x00,0x01,0x02,0x04,0x08,0x09,0x11,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0xc0,0x00,0x00,0x00,
+/* 43982 0xabce "ꯎ" */
+0x00,0x00,0x00,0x00,0x3f,0x10,0x10,0x08,0x07,0x00,0x08,0x15,0x12,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x00,0x70,0x90,0xe0,0x10,0x88,0x48,0x30,0x00,0x00,0x00,
+/* 43983 0xabcf "ꯏ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x08,0x06,0x05,0x04,0x04,0x05,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x80,0x60,0x10,0x10,0xe0,0x00,0x00,0x00,
+/* 43984 0xabd0 "ꯐ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x1f,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x20,0x40,0x80,0x00,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 43985 0xabd1 "ꯑ" */
+0x00,0x00,0x00,0x00,0x3f,0x12,0x12,0x12,0x12,0x12,0x0a,0x0a,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x40,0x40,0x40,0x40,0x40,0x48,0x50,0xe0,0x00,0x00,0x00,
+/* 43986 0xabd2 "ꯒ" */
+0x00,0x00,0x00,0x00,0x1f,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x20,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 43987 0xabd3 "ꯓ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x30,0xc0,0x40,0x30,0x00,
+/* 43988 0xabd4 "ꯔ" */
+0x00,0x00,0x00,0x00,0x0e,0x11,0x10,0x1f,0x10,0x10,0x10,0x10,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x70,0x88,0x88,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43989 0xabd5 "ꯕ" */
+0x00,0x00,0x00,0x00,0x0f,0x04,0x02,0x01,0x02,0x04,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xe0,0x40,0x80,0x00,0x80,0x40,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43990 0xabd6 "ꯖ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x10,0xe0,0x00,0x00,0x20,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 43991 0xabd7 "ꯗ" */
+0x00,0x00,0x00,0x00,0x0f,0x04,0x02,0x01,0x02,0x04,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x48,0x88,0x10,0x90,0x50,0x30,0x48,0x84,0x00,0x00,0x00,
+/* 43992 0xabd8 "ꯘ" */
+0x00,0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x04,0x1f,0x24,0x24,0x18,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0xc0,0x80,0x90,0x60,0x00,0x00,0x00,
+/* 43993 0xabd9 "ꯙ" */
+0x00,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x08,0x10,0x10,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xfc,0x40,0x40,0x40,0x40,0x40,0xc0,0x40,0x40,0x00,0x00,0x00,
+/* 43994 0xabda "ꯚ" */
+0x00,0x00,0x00,0x00,0x1f,0x02,0x02,0x12,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,
+/* 43995 0xabdb "ꯛ" */
+0x00,0x00,0x00,0x00,0x3f,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x48,0x48,0x40,0x40,0x40,0x40,0x40,0xc0,0x00,0x00,0x00,
+/* 43996 0xabdc "ꯜ" */
+0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x10,0x10,0x10,0x10,0x10,0xd0,0x30,0x10,0x00,0x00,0x00,
+/* 43997 0xabdd "ꯝ" */
+0x00,0x00,0x00,0x00,0x3f,0x10,0x10,0x1f,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0xe0,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 43998 0xabde "ꯞ" */
+0x00,0x00,0x00,0x00,0x3f,0x21,0x11,0x11,0x09,0x09,0x09,0x29,0x31,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0x20,0x20,0x28,0x18,0x00,0x00,0x00,
+/* 43999 0xabdf "ꯟ" */
+0x00,0x00,0x00,0x00,0x3f,0x04,0x09,0x12,0x12,0x11,0x08,0x08,0x07,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf8,0x90,0x20,0x00,0x20,0xc0,0x08,0x10,0xe0,0x00,0x00,0x00,
+/* 44000 0xabe0 "ꯠ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x21,0x22,0x3f,0x02,0x02,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x00,0x80,0x40,0x40,0x40,0x80,0x00,0x00,0x00,
+/* 44001 0xabe1 "ꯡ" */
+0x00,0x00,0x00,0x00,0x1f,0x09,0x09,0x09,0x09,0x09,0x09,0x09,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xe0,0x00,0x00,0x00,
+/* 44002 0xabe2 "ꯢ" */
+0x00,0x00,0x00,0x00,0x1f,0x10,0x08,0x07,0x04,0x04,0x09,0x09,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,
+/* 44003 0xabe3 "ꯣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x18,0x04,0x1c,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44004 0xabe4 "ꯤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x06,0x09,0x09,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 44005 0xabe5 "ꯥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44006 0xabe6 "ꯦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44007 0xabe7 "ꯧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x15,0x0e,0x04,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44008 0xabe8 "ꯨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x20,
+/* 44009 0xabe9 "ꯩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x25,0x15,0x0e,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44010 0xabea "ꯪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x02,0x05,0x05,0x03,0x01,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44011 0xabeb "꯫" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+/* 44012 0xabec "꯬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x00,
+/* 44013 0xabed "꯭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,
+/* 44014 0xabee "꯮" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 44015 0xabef "꯯" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 44016 0xabf0 "꯰" */
+0x00,0x00,0x03,0x0c,0x10,0x10,0x20,0x20,0x10,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x20,0x10,0x10,0x20,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,
+/* 44017 0xabf1 "꯱" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xc0,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0x00,
+/* 44018 0xabf2 "꯲" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xc0,0x00,0x60,0x90,0x50,0x90,0x00,0x00,0x00,
+/* 44019 0xabf3 "꯳" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x04,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xcc,0x12,0x6a,0xa8,0xa8,0x10,0x00,0x00,0x00,
+/* 44020 0xabf4 "꯴" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x40,0x80,0x00,0x00,0xc0,0x20,0x40,0x80,0x00,0x00,0x00,
+/* 44021 0xabf5 "꯵" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x22,0x25,0x15,0x0e,0x04,0x04,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44022 0xabf6 "꯶" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x22,0x25,0x15,0x0e,0x04,0x05,0x06,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 44023 0xabf7 "꯷" */
+0x00,0x00,0x00,0x00,0x0c,0x11,0x09,0x01,0x03,0x05,0x08,0x09,0x06,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x30,0x48,0x50,0x20,0xd0,0x08,0x88,0x10,0x20,0x00,0x00,0x00,
+/* 44024 0xabf8 "꯸" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x22,0x25,0x15,0x0e,0x04,0x14,0x0c,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 44025 0xabf9 "꯹" */
+0x00,0x00,0x00,0x00,0x0f,0x10,0x22,0x25,0x15,0x0e,0x04,0x1f,0x24,0x18,0x00,0x00,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x20,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 44026 0xabfa "꯺" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 44027 0xabfb "꯻" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 44028 0xabfc "꯼" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 44029 0xabfd "꯽" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 44030 0xabfe "꯾" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 44031 0xabff "꯿" */
+0x00,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 44032 0xac00 "가" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44033 0xac01 "각" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44034 0xac02 "갂" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44035 0xac03 "갃" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44036 0xac04 "간" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44037 0xac05 "갅" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44038 0xac06 "갆" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44039 0xac07 "갇" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44040 0xac08 "갈" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44041 0xac09 "갉" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44042 0xac0a "갊" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44043 0xac0b "갋" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44044 0xac0c "갌" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44045 0xac0d "갍" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44046 0xac0e "갎" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44047 0xac0f "갏" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44048 0xac10 "감" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44049 0xac11 "갑" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44050 0xac12 "값" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44051 0xac13 "갓" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44052 0xac14 "갔" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44053 0xac15 "강" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44054 0xac16 "갖" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44055 0xac17 "갗" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44056 0xac18 "갘" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44057 0xac19 "같" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44058 0xac1a "갚" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44059 0xac1b "갛" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44060 0xac1c "개" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44061 0xac1d "객" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44062 0xac1e "갞" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44063 0xac1f "갟" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44064 0xac20 "갠" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44065 0xac21 "갡" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44066 0xac22 "갢" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44067 0xac23 "갣" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44068 0xac24 "갤" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44069 0xac25 "갥" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44070 0xac26 "갦" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44071 0xac27 "갧" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44072 0xac28 "갨" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44073 0xac29 "갩" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44074 0xac2a "갪" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44075 0xac2b "갫" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44076 0xac2c "갬" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44077 0xac2d "갭" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44078 0xac2e "갮" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44079 0xac2f "갯" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44080 0xac30 "갰" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44081 0xac31 "갱" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44082 0xac32 "갲" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44083 0xac33 "갳" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44084 0xac34 "갴" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44085 0xac35 "갵" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44086 0xac36 "갶" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44087 0xac37 "갷" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44088 0xac38 "갸" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x84,0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44089 0xac39 "갹" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44090 0xac3a "갺" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44091 0xac3b "갻" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44092 0xac3c "갼" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44093 0xac3d "갽" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44094 0xac3e "갾" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44095 0xac3f "갿" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44096 0xac40 "걀" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44097 0xac41 "걁" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44098 0xac42 "걂" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44099 0xac43 "걃" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44100 0xac44 "걄" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44101 0xac45 "걅" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44102 0xac46 "걆" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44103 0xac47 "걇" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44104 0xac48 "걈" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44105 0xac49 "걉" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44106 0xac4a "걊" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44107 0xac4b "걋" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44108 0xac4c "걌" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44109 0xac4d "걍" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44110 0xac4e "걎" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44111 0xac4f "걏" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44112 0xac50 "걐" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44113 0xac51 "걑" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44114 0xac52 "걒" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44115 0xac53 "걓" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44116 0xac54 "걔" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x92,0x12,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44117 0xac55 "걕" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44118 0xac56 "걖" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44119 0xac57 "걗" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44120 0xac58 "걘" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44121 0xac59 "걙" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44122 0xac5a "걚" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44123 0xac5b "걛" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44124 0xac5c "걜" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44125 0xac5d "걝" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44126 0xac5e "걞" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44127 0xac5f "걟" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44128 0xac60 "걠" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44129 0xac61 "걡" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44130 0xac62 "걢" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44131 0xac63 "걣" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44132 0xac64 "걤" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44133 0xac65 "걥" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44134 0xac66 "걦" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44135 0xac67 "걧" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44136 0xac68 "걨" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44137 0xac69 "걩" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44138 0xac6a "걪" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44139 0xac6b "걫" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44140 0xac6c "걬" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44141 0xac6d "걭" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44142 0xac6e "걮" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44143 0xac6f "걯" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44144 0xac70 "거" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0xbc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44145 0xac71 "걱" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44146 0xac72 "걲" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44147 0xac73 "걳" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44148 0xac74 "건" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44149 0xac75 "걵" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44150 0xac76 "걶" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44151 0xac77 "걷" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44152 0xac78 "걸" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44153 0xac79 "걹" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44154 0xac7a "걺" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44155 0xac7b "걻" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44156 0xac7c "걼" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44157 0xac7d "걽" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44158 0xac7e "걾" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44159 0xac7f "걿" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44160 0xac80 "검" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44161 0xac81 "겁" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44162 0xac82 "겂" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44163 0xac83 "것" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44164 0xac84 "겄" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44165 0xac85 "겅" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44166 0xac86 "겆" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44167 0xac87 "겇" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44168 0xac88 "겈" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44169 0xac89 "겉" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44170 0xac8a "겊" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44171 0xac8b "겋" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44172 0xac8c "게" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44173 0xac8d "겍" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44174 0xac8e "겎" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44175 0xac8f "겏" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44176 0xac90 "겐" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44177 0xac91 "겑" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44178 0xac92 "겒" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44179 0xac93 "겓" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44180 0xac94 "겔" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44181 0xac95 "겕" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44182 0xac96 "겖" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44183 0xac97 "겗" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44184 0xac98 "겘" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44185 0xac99 "겙" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44186 0xac9a "겚" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44187 0xac9b "겛" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44188 0xac9c "겜" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44189 0xac9d "겝" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44190 0xac9e "겞" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44191 0xac9f "겟" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44192 0xaca0 "겠" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44193 0xaca1 "겡" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44194 0xaca2 "겢" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44195 0xaca3 "겣" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44196 0xaca4 "겤" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44197 0xaca5 "겥" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44198 0xaca6 "겦" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44199 0xaca7 "겧" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44200 0xaca8 "겨" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x84,0x04,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44201 0xaca9 "격" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44202 0xacaa "겪" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44203 0xacab "겫" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44204 0xacac "견" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44205 0xacad "겭" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44206 0xacae "겮" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44207 0xacaf "겯" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44208 0xacb0 "결" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44209 0xacb1 "겱" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44210 0xacb2 "겲" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44211 0xacb3 "겳" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44212 0xacb4 "겴" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44213 0xacb5 "겵" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44214 0xacb6 "겶" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44215 0xacb7 "겷" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44216 0xacb8 "겸" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44217 0xacb9 "겹" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44218 0xacba "겺" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44219 0xacbb "겻" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44220 0xacbc "겼" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44221 0xacbd "경" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44222 0xacbe "겾" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44223 0xacbf "겿" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44224 0xacc0 "곀" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44225 0xacc1 "곁" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44226 0xacc2 "곂" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44227 0xacc3 "곃" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44228 0xacc4 "계" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x92,0x12,0x72,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44229 0xacc5 "곅" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44230 0xacc6 "곆" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44231 0xacc7 "곇" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44232 0xacc8 "곈" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44233 0xacc9 "곉" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44234 0xacca "곊" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44235 0xaccb "곋" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44236 0xaccc "곌" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44237 0xaccd "곍" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44238 0xacce "곎" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44239 0xaccf "곏" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44240 0xacd0 "곐" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44241 0xacd1 "곑" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44242 0xacd2 "곒" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44243 0xacd3 "곓" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44244 0xacd4 "곔" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44245 0xacd5 "곕" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44246 0xacd6 "곖" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44247 0xacd7 "곗" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44248 0xacd8 "곘" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44249 0xacd9 "곙" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44250 0xacda "곚" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44251 0xacdb "곛" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44252 0xacdc "곜" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44253 0xacdd "곝" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44254 0xacde "곞" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44255 0xacdf "곟" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44256 0xace0 "고" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x80,0x80,0xff,0x00,0x00,
+/* 44257 0xace1 "곡" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44258 0xace2 "곢" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44259 0xace3 "곣" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44260 0xace4 "곤" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 44261 0xace5 "곥" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44262 0xace6 "곦" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44263 0xace7 "곧" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44264 0xace8 "골" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44265 0xace9 "곩" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44266 0xacea "곪" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44267 0xaceb "곫" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44268 0xacec "곬" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44269 0xaced "곭" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44270 0xacee "곮" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44271 0xacef "곯" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44272 0xacf0 "곰" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44273 0xacf1 "곱" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44274 0xacf2 "곲" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44275 0xacf3 "곳" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44276 0xacf4 "곴" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44277 0xacf5 "공" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44278 0xacf6 "곶" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44279 0xacf7 "곷" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44280 0xacf8 "곸" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44281 0xacf9 "곹" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44282 0xacfa "곺" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44283 0xacfb "곻" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x84,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44284 0xacfc "과" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,
+/* 44285 0xacfd "곽" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44286 0xacfe "곾" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44287 0xacff "곿" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44288 0xad00 "관" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44289 0xad01 "괁" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44290 0xad02 "괂" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44291 0xad03 "괃" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44292 0xad04 "괄" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44293 0xad05 "괅" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44294 0xad06 "괆" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44295 0xad07 "괇" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44296 0xad08 "괈" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44297 0xad09 "괉" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44298 0xad0a "괊" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44299 0xad0b "괋" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44300 0xad0c "괌" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44301 0xad0d "괍" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44302 0xad0e "괎" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44303 0xad0f "괏" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44304 0xad10 "괐" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44305 0xad11 "광" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44306 0xad12 "괒" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44307 0xad13 "괓" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44308 0xad14 "괔" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44309 0xad15 "괕" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44310 0xad16 "괖" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44311 0xad17 "괗" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44312 0xad18 "괘" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0x12,
+/* 44313 0xad19 "괙" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44314 0xad1a "괚" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44315 0xad1b "괛" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44316 0xad1c "괜" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44317 0xad1d "괝" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44318 0xad1e "괞" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44319 0xad1f "괟" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44320 0xad20 "괠" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44321 0xad21 "괡" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44322 0xad22 "괢" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44323 0xad23 "괣" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44324 0xad24 "괤" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44325 0xad25 "괥" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44326 0xad26 "괦" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44327 0xad27 "괧" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44328 0xad28 "괨" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44329 0xad29 "괩" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44330 0xad2a "괪" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44331 0xad2b "괫" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44332 0xad2c "괬" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44333 0xad2d "괭" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44334 0xad2e "괮" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44335 0xad2f "괯" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44336 0xad30 "괰" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44337 0xad31 "괱" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44338 0xad32 "괲" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44339 0xad33 "괳" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44340 0xad34 "괴" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,
+/* 44341 0xad35 "괵" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44342 0xad36 "괶" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44343 0xad37 "괷" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44344 0xad38 "괸" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44345 0xad39 "괹" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44346 0xad3a "괺" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44347 0xad3b "괻" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44348 0xad3c "괼" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44349 0xad3d "괽" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44350 0xad3e "괾" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44351 0xad3f "괿" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44352 0xad40 "굀" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44353 0xad41 "굁" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44354 0xad42 "굂" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44355 0xad43 "굃" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44356 0xad44 "굄" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44357 0xad45 "굅" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44358 0xad46 "굆" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44359 0xad47 "굇" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44360 0xad48 "굈" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44361 0xad49 "굉" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44362 0xad4a "굊" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44363 0xad4b "굋" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44364 0xad4c "굌" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44365 0xad4d "굍" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44366 0xad4e "굎" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44367 0xad4f "굏" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44368 0xad50 "교" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x24,0x20,0x20,0xff,0x00,0x00,
+/* 44369 0xad51 "굑" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44370 0xad52 "굒" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44371 0xad53 "굓" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44372 0xad54 "굔" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 44373 0xad55 "굕" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44374 0xad56 "굖" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44375 0xad57 "굗" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44376 0xad58 "굘" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44377 0xad59 "굙" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44378 0xad5a "굚" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44379 0xad5b "굛" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44380 0xad5c "굜" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44381 0xad5d "굝" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44382 0xad5e "굞" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44383 0xad5f "굟" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44384 0xad60 "굠" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44385 0xad61 "굡" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44386 0xad62 "굢" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44387 0xad63 "굣" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44388 0xad64 "굤" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44389 0xad65 "굥" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44390 0xad66 "굦" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44391 0xad67 "굧" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44392 0xad68 "굨" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44393 0xad69 "굩" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44394 0xad6a "굪" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44395 0xad6b "굫" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x24,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44396 0xad6c "구" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 44397 0xad6d "국" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 44398 0xad6e "굮" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 44399 0xad6f "굯" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 44400 0xad70 "군" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 44401 0xad71 "굱" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 44402 0xad72 "굲" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 44403 0xad73 "굳" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 44404 0xad74 "굴" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44405 0xad75 "굵" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 44406 0xad76 "굶" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 44407 0xad77 "굷" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 44408 0xad78 "굸" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 44409 0xad79 "굹" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44410 0xad7a "굺" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 44411 0xad7b "굻" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 44412 0xad7c "굼" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 44413 0xad7d "굽" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 44414 0xad7e "굾" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 44415 0xad7f "굿" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 44416 0xad80 "궀" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 44417 0xad81 "궁" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 44418 0xad82 "궂" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 44419 0xad83 "궃" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44420 0xad84 "궄" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 44421 0xad85 "궅" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44422 0xad86 "궆" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 44423 0xad87 "궇" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44424 0xad88 "궈" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 44425 0xad89 "궉" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44426 0xad8a "궊" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44427 0xad8b "궋" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44428 0xad8c "권" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 44429 0xad8d "궍" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44430 0xad8e "궎" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44431 0xad8f "궏" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44432 0xad90 "궐" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44433 0xad91 "궑" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44434 0xad92 "궒" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44435 0xad93 "궓" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44436 0xad94 "궔" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44437 0xad95 "궕" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44438 0xad96 "궖" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44439 0xad97 "궗" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44440 0xad98 "궘" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44441 0xad99 "궙" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44442 0xad9a "궚" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44443 0xad9b "궛" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44444 0xad9c "궜" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44445 0xad9d "궝" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44446 0xad9e "궞" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44447 0xad9f "궟" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44448 0xada0 "궠" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44449 0xada1 "궡" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44450 0xada2 "궢" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44451 0xada3 "궣" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44452 0xada4 "궤" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 44453 0xada5 "궥" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44454 0xada6 "궦" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44455 0xada7 "궧" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44456 0xada8 "궨" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 44457 0xada9 "궩" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44458 0xadaa "궪" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44459 0xadab "궫" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44460 0xadac "궬" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44461 0xadad "궭" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44462 0xadae "궮" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44463 0xadaf "궯" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44464 0xadb0 "궰" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44465 0xadb1 "궱" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44466 0xadb2 "궲" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44467 0xadb3 "궳" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44468 0xadb4 "궴" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44469 0xadb5 "궵" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44470 0xadb6 "궶" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44471 0xadb7 "궷" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44472 0xadb8 "궸" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44473 0xadb9 "궹" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44474 0xadba "궺" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44475 0xadbb "궻" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44476 0xadbc "궼" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44477 0xadbd "궽" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44478 0xadbe "궾" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44479 0xadbf "궿" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44480 0xadc0 "귀" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44481 0xadc1 "귁" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44482 0xadc2 "귂" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44483 0xadc3 "귃" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44484 0xadc4 "귄" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44485 0xadc5 "귅" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44486 0xadc6 "귆" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44487 0xadc7 "귇" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44488 0xadc8 "귈" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44489 0xadc9 "귉" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44490 0xadca "귊" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44491 0xadcb "귋" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44492 0xadcc "귌" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44493 0xadcd "귍" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44494 0xadce "귎" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44495 0xadcf "귏" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44496 0xadd0 "귐" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44497 0xadd1 "귑" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44498 0xadd2 "귒" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44499 0xadd3 "귓" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44500 0xadd4 "귔" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44501 0xadd5 "귕" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44502 0xadd6 "귖" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44503 0xadd7 "귗" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44504 0xadd8 "귘" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44505 0xadd9 "귙" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44506 0xadda "귚" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44507 0xaddb "귛" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44508 0xaddc "규" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 44509 0xaddd "귝" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 44510 0xadde "귞" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 44511 0xaddf "귟" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 44512 0xade0 "균" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 44513 0xade1 "귡" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 44514 0xade2 "귢" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 44515 0xade3 "귣" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 44516 0xade4 "귤" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44517 0xade5 "귥" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 44518 0xade6 "귦" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 44519 0xade7 "귧" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 44520 0xade8 "귨" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 44521 0xade9 "귩" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44522 0xadea "귪" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 44523 0xadeb "귫" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 44524 0xadec "귬" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 44525 0xaded "귭" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 44526 0xadee "귮" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 44527 0xadef "귯" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 44528 0xadf0 "귰" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 44529 0xadf1 "귱" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 44530 0xadf2 "귲" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 44531 0xadf3 "귳" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44532 0xadf4 "귴" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 44533 0xadf5 "귵" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44534 0xadf6 "귶" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 44535 0xadf7 "귷" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44536 0xadf8 "그" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0xff,0x00,0x00,
+/* 44537 0xadf9 "극" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44538 0xadfa "귺" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44539 0xadfb "귻" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44540 0xadfc "근" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 44541 0xadfd "귽" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44542 0xadfe "귾" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44543 0xadff "귿" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44544 0xae00 "글" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44545 0xae01 "긁" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44546 0xae02 "긂" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44547 0xae03 "긃" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44548 0xae04 "긄" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44549 0xae05 "긅" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44550 0xae06 "긆" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44551 0xae07 "긇" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44552 0xae08 "금" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44553 0xae09 "급" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44554 0xae0a "긊" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44555 0xae0b "긋" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44556 0xae0c "긌" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44557 0xae0d "긍" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44558 0xae0e "긎" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44559 0xae0f "긏" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44560 0xae10 "긐" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44561 0xae11 "긑" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44562 0xae12 "긒" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44563 0xae13 "긓" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44564 0xae14 "긔" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,
+/* 44565 0xae15 "긕" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44566 0xae16 "긖" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44567 0xae17 "긗" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44568 0xae18 "긘" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44569 0xae19 "긙" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44570 0xae1a "긚" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44571 0xae1b "긛" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44572 0xae1c "긜" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44573 0xae1d "긝" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44574 0xae1e "긞" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44575 0xae1f "긟" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44576 0xae20 "긠" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44577 0xae21 "긡" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44578 0xae22 "긢" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44579 0xae23 "긣" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44580 0xae24 "긤" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44581 0xae25 "긥" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44582 0xae26 "긦" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44583 0xae27 "긧" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44584 0xae28 "긨" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44585 0xae29 "긩" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44586 0xae2a "긪" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44587 0xae2b "긫" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44588 0xae2c "긬" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44589 0xae2d "긭" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44590 0xae2e "긮" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44591 0xae2f "긯" */
+0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44592 0xae30 "기" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44593 0xae31 "긱" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44594 0xae32 "긲" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44595 0xae33 "긳" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44596 0xae34 "긴" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44597 0xae35 "긵" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44598 0xae36 "긶" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44599 0xae37 "긷" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44600 0xae38 "길" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44601 0xae39 "긹" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44602 0xae3a "긺" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44603 0xae3b "긻" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44604 0xae3c "긼" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44605 0xae3d "긽" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44606 0xae3e "긾" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44607 0xae3f "긿" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44608 0xae40 "김" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44609 0xae41 "깁" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44610 0xae42 "깂" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44611 0xae43 "깃" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44612 0xae44 "깄" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44613 0xae45 "깅" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44614 0xae46 "깆" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44615 0xae47 "깇" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44616 0xae48 "깈" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44617 0xae49 "깉" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44618 0xae4a "깊" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44619 0xae4b "깋" */
+0x00,0x00,0x3f,0x00,0x00,0x01,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44620 0xae4c "까" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44621 0xae4d "깍" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44622 0xae4e "깎" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44623 0xae4f "깏" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44624 0xae50 "깐" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44625 0xae51 "깑" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44626 0xae52 "깒" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44627 0xae53 "깓" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44628 0xae54 "깔" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44629 0xae55 "깕" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44630 0xae56 "깖" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44631 0xae57 "깗" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44632 0xae58 "깘" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44633 0xae59 "깙" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44634 0xae5a "깚" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44635 0xae5b "깛" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44636 0xae5c "깜" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44637 0xae5d "깝" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44638 0xae5e "깞" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44639 0xae5f "깟" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44640 0xae60 "깠" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44641 0xae61 "깡" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44642 0xae62 "깢" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44643 0xae63 "깣" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44644 0xae64 "깤" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44645 0xae65 "깥" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44646 0xae66 "깦" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44647 0xae67 "깧" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44648 0xae68 "깨" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44649 0xae69 "깩" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44650 0xae6a "깪" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44651 0xae6b "깫" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44652 0xae6c "깬" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44653 0xae6d "깭" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44654 0xae6e "깮" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44655 0xae6f "깯" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44656 0xae70 "깰" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44657 0xae71 "깱" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44658 0xae72 "깲" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44659 0xae73 "깳" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44660 0xae74 "깴" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44661 0xae75 "깵" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44662 0xae76 "깶" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44663 0xae77 "깷" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44664 0xae78 "깸" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44665 0xae79 "깹" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44666 0xae7a "깺" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44667 0xae7b "깻" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44668 0xae7c "깼" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44669 0xae7d "깽" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44670 0xae7e "깾" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44671 0xae7f "깿" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44672 0xae80 "꺀" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44673 0xae81 "꺁" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44674 0xae82 "꺂" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44675 0xae83 "꺃" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44676 0xae84 "꺄" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44677 0xae85 "꺅" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44678 0xae86 "꺆" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44679 0xae87 "꺇" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44680 0xae88 "꺈" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44681 0xae89 "꺉" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44682 0xae8a "꺊" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44683 0xae8b "꺋" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44684 0xae8c "꺌" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44685 0xae8d "꺍" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44686 0xae8e "꺎" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44687 0xae8f "꺏" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44688 0xae90 "꺐" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44689 0xae91 "꺑" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44690 0xae92 "꺒" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44691 0xae93 "꺓" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44692 0xae94 "꺔" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44693 0xae95 "꺕" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44694 0xae96 "꺖" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44695 0xae97 "꺗" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44696 0xae98 "꺘" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44697 0xae99 "꺙" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44698 0xae9a "꺚" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44699 0xae9b "꺛" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44700 0xae9c "꺜" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44701 0xae9d "꺝" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44702 0xae9e "꺞" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44703 0xae9f "꺟" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44704 0xaea0 "꺠" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44705 0xaea1 "꺡" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44706 0xaea2 "꺢" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44707 0xaea3 "꺣" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44708 0xaea4 "꺤" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44709 0xaea5 "꺥" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44710 0xaea6 "꺦" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44711 0xaea7 "꺧" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44712 0xaea8 "꺨" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44713 0xaea9 "꺩" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44714 0xaeaa "꺪" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44715 0xaeab "꺫" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44716 0xaeac "꺬" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44717 0xaead "꺭" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44718 0xaeae "꺮" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44719 0xaeaf "꺯" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44720 0xaeb0 "꺰" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44721 0xaeb1 "꺱" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44722 0xaeb2 "꺲" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44723 0xaeb3 "꺳" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44724 0xaeb4 "꺴" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44725 0xaeb5 "꺵" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44726 0xaeb6 "꺶" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44727 0xaeb7 "꺷" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44728 0xaeb8 "꺸" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44729 0xaeb9 "꺹" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44730 0xaeba "꺺" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44731 0xaebb "꺻" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44732 0xaebc "꺼" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0xbc,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44733 0xaebd "꺽" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44734 0xaebe "꺾" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44735 0xaebf "꺿" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44736 0xaec0 "껀" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44737 0xaec1 "껁" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44738 0xaec2 "껂" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44739 0xaec3 "껃" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44740 0xaec4 "껄" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44741 0xaec5 "껅" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44742 0xaec6 "껆" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44743 0xaec7 "껇" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44744 0xaec8 "껈" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44745 0xaec9 "껉" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44746 0xaeca "껊" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44747 0xaecb "껋" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44748 0xaecc "껌" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44749 0xaecd "껍" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44750 0xaece "껎" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44751 0xaecf "껏" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44752 0xaed0 "껐" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44753 0xaed1 "껑" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44754 0xaed2 "껒" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44755 0xaed3 "껓" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44756 0xaed4 "껔" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44757 0xaed5 "껕" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44758 0xaed6 "껖" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44759 0xaed7 "껗" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44760 0xaed8 "께" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0xf2,0x92,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44761 0xaed9 "껙" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44762 0xaeda "껚" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44763 0xaedb "껛" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44764 0xaedc "껜" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44765 0xaedd "껝" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44766 0xaede "껞" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44767 0xaedf "껟" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44768 0xaee0 "껠" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44769 0xaee1 "껡" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44770 0xaee2 "껢" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44771 0xaee3 "껣" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44772 0xaee4 "껤" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44773 0xaee5 "껥" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44774 0xaee6 "껦" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44775 0xaee7 "껧" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44776 0xaee8 "껨" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44777 0xaee9 "껩" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44778 0xaeea "껪" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44779 0xaeeb "껫" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44780 0xaeec "껬" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44781 0xaeed "껭" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44782 0xaeee "껮" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44783 0xaeef "껯" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44784 0xaef0 "껰" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44785 0xaef1 "껱" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44786 0xaef2 "껲" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44787 0xaef3 "껳" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44788 0xaef4 "껴" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 44789 0xaef5 "껵" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44790 0xaef6 "껶" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44791 0xaef7 "껷" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44792 0xaef8 "껸" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44793 0xaef9 "껹" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44794 0xaefa "껺" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44795 0xaefb "껻" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44796 0xaefc "껼" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44797 0xaefd "껽" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44798 0xaefe "껾" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44799 0xaeff "껿" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44800 0xaf00 "꼀" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44801 0xaf01 "꼁" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44802 0xaf02 "꼂" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44803 0xaf03 "꼃" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44804 0xaf04 "꼄" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44805 0xaf05 "꼅" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44806 0xaf06 "꼆" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44807 0xaf07 "꼇" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44808 0xaf08 "꼈" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44809 0xaf09 "꼉" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44810 0xaf0a "꼊" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44811 0xaf0b "꼋" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44812 0xaf0c "꼌" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44813 0xaf0d "꼍" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44814 0xaf0e "꼎" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44815 0xaf0f "꼏" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44816 0xaf10 "꼐" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 44817 0xaf11 "꼑" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44818 0xaf12 "꼒" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44819 0xaf13 "꼓" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44820 0xaf14 "꼔" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44821 0xaf15 "꼕" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44822 0xaf16 "꼖" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44823 0xaf17 "꼗" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44824 0xaf18 "꼘" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44825 0xaf19 "꼙" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44826 0xaf1a "꼚" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44827 0xaf1b "꼛" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44828 0xaf1c "꼜" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44829 0xaf1d "꼝" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44830 0xaf1e "꼞" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44831 0xaf1f "꼟" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44832 0xaf20 "꼠" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44833 0xaf21 "꼡" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44834 0xaf22 "꼢" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44835 0xaf23 "꼣" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44836 0xaf24 "꼤" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44837 0xaf25 "꼥" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44838 0xaf26 "꼦" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44839 0xaf27 "꼧" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44840 0xaf28 "꼨" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44841 0xaf29 "꼩" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44842 0xaf2a "꼪" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44843 0xaf2b "꼫" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44844 0xaf2c "꼬" */
+0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,0x02,0x04,0x08,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x88,0x80,0x80,0xff,0x00,0x00,
+/* 44845 0xaf2d "꼭" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44846 0xaf2e "꼮" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44847 0xaf2f "꼯" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44848 0xaf30 "꼰" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 44849 0xaf31 "꼱" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44850 0xaf32 "꼲" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44851 0xaf33 "꼳" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44852 0xaf34 "꼴" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44853 0xaf35 "꼵" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44854 0xaf36 "꼶" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44855 0xaf37 "꼷" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44856 0xaf38 "꼸" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44857 0xaf39 "꼹" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44858 0xaf3a "꼺" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44859 0xaf3b "꼻" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44860 0xaf3c "꼼" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44861 0xaf3d "꼽" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44862 0xaf3e "꼾" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44863 0xaf3f "꼿" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44864 0xaf40 "꽀" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44865 0xaf41 "꽁" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44866 0xaf42 "꽂" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44867 0xaf43 "꽃" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44868 0xaf44 "꽄" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44869 0xaf45 "꽅" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44870 0xaf46 "꽆" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44871 0xaf47 "꽇" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44872 0xaf48 "꽈" */
+0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x25,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x44,0x44,0x44,0x47,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 44873 0xaf49 "꽉" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44874 0xaf4a "꽊" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44875 0xaf4b "꽋" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44876 0xaf4c "꽌" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44877 0xaf4d "꽍" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44878 0xaf4e "꽎" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44879 0xaf4f "꽏" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44880 0xaf50 "꽐" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44881 0xaf51 "꽑" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44882 0xaf52 "꽒" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44883 0xaf53 "꽓" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44884 0xaf54 "꽔" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44885 0xaf55 "꽕" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44886 0xaf56 "꽖" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44887 0xaf57 "꽗" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44888 0xaf58 "꽘" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44889 0xaf59 "꽙" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44890 0xaf5a "꽚" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44891 0xaf5b "꽛" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44892 0xaf5c "꽜" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44893 0xaf5d "꽝" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44894 0xaf5e "꽞" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44895 0xaf5f "꽟" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44896 0xaf60 "꽠" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44897 0xaf61 "꽡" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44898 0xaf62 "꽢" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44899 0xaf63 "꽣" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44900 0xaf64 "꽤" */
+0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x25,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x52,0x52,0x52,0x5e,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 44901 0xaf65 "꽥" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 44902 0xaf66 "꽦" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 44903 0xaf67 "꽧" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44904 0xaf68 "꽨" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 44905 0xaf69 "꽩" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 44906 0xaf6a "꽪" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 44907 0xaf6b "꽫" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 44908 0xaf6c "꽬" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 44909 0xaf6d "꽭" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 44910 0xaf6e "꽮" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 44911 0xaf6f "꽯" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 44912 0xaf70 "꽰" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 44913 0xaf71 "꽱" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 44914 0xaf72 "꽲" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 44915 0xaf73 "꽳" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 44916 0xaf74 "꽴" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 44917 0xaf75 "꽵" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 44918 0xaf76 "꽶" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 44919 0xaf77 "꽷" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 44920 0xaf78 "꽸" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 44921 0xaf79 "꽹" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 44922 0xaf7a "꽺" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 44923 0xaf7b "꽻" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 44924 0xaf7c "꽼" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 44925 0xaf7d "꽽" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 44926 0xaf7e "꽾" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 44927 0xaf7f "꽿" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 44928 0xaf80 "꾀" */
+0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x25,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 44929 0xaf81 "꾁" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44930 0xaf82 "꾂" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44931 0xaf83 "꾃" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44932 0xaf84 "꾄" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 44933 0xaf85 "꾅" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44934 0xaf86 "꾆" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44935 0xaf87 "꾇" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44936 0xaf88 "꾈" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44937 0xaf89 "꾉" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44938 0xaf8a "꾊" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44939 0xaf8b "꾋" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44940 0xaf8c "꾌" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44941 0xaf8d "꾍" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44942 0xaf8e "꾎" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44943 0xaf8f "꾏" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44944 0xaf90 "꾐" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44945 0xaf91 "꾑" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44946 0xaf92 "꾒" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44947 0xaf93 "꾓" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44948 0xaf94 "꾔" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44949 0xaf95 "꾕" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44950 0xaf96 "꾖" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44951 0xaf97 "꾗" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44952 0xaf98 "꾘" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44953 0xaf99 "꾙" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44954 0xaf9a "꾚" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44955 0xaf9b "꾛" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44956 0xaf9c "꾜" */
+0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,0x02,0x04,0x0a,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x28,0x20,0x20,0xff,0x00,0x00,
+/* 44957 0xaf9d "꾝" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 44958 0xaf9e "꾞" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44959 0xaf9f "꾟" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44960 0xafa0 "꾠" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 44961 0xafa1 "꾡" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 44962 0xafa2 "꾢" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44963 0xafa3 "꾣" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 44964 0xafa4 "꾤" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44965 0xafa5 "꾥" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 44966 0xafa6 "꾦" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 44967 0xafa7 "꾧" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 44968 0xafa8 "꾨" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44969 0xafa9 "꾩" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44970 0xafaa "꾪" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 44971 0xafab "꾫" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 44972 0xafac "꾬" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 44973 0xafad "꾭" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 44974 0xafae "꾮" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44975 0xafaf "꾯" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 44976 0xafb0 "꾰" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 44977 0xafb1 "꾱" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 44978 0xafb2 "꾲" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 44979 0xafb3 "꾳" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 44980 0xafb4 "꾴" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 44981 0xafb5 "꾵" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 44982 0xafb6 "꾶" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 44983 0xafb7 "꾷" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 44984 0xafb8 "꾸" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 44985 0xafb9 "꾹" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 44986 0xafba "꾺" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 44987 0xafbb "꾻" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 44988 0xafbc "꾼" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 44989 0xafbd "꾽" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 44990 0xafbe "꾾" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 44991 0xafbf "꾿" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 44992 0xafc0 "꿀" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 44993 0xafc1 "꿁" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 44994 0xafc2 "꿂" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 44995 0xafc3 "꿃" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 44996 0xafc4 "꿄" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 44997 0xafc5 "꿅" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 44998 0xafc6 "꿆" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 44999 0xafc7 "꿇" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 45000 0xafc8 "꿈" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 45001 0xafc9 "꿉" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 45002 0xafca "꿊" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 45003 0xafcb "꿋" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 45004 0xafcc "꿌" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 45005 0xafcd "꿍" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 45006 0xafce "꿎" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 45007 0xafcf "꿏" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45008 0xafd0 "꿐" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 45009 0xafd1 "꿑" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45010 0xafd2 "꿒" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 45011 0xafd3 "꿓" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45012 0xafd4 "꿔" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 45013 0xafd5 "꿕" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45014 0xafd6 "꿖" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45015 0xafd7 "꿗" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45016 0xafd8 "꿘" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 45017 0xafd9 "꿙" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45018 0xafda "꿚" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45019 0xafdb "꿛" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45020 0xafdc "꿜" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45021 0xafdd "꿝" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45022 0xafde "꿞" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45023 0xafdf "꿟" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45024 0xafe0 "꿠" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45025 0xafe1 "꿡" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45026 0xafe2 "꿢" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45027 0xafe3 "꿣" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45028 0xafe4 "꿤" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45029 0xafe5 "꿥" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45030 0xafe6 "꿦" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45031 0xafe7 "꿧" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45032 0xafe8 "꿨" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45033 0xafe9 "꿩" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45034 0xafea "꿪" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45035 0xafeb "꿫" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45036 0xafec "꿬" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45037 0xafed "꿭" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45038 0xafee "꿮" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45039 0xafef "꿯" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45040 0xaff0 "꿰" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 45041 0xaff1 "꿱" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45042 0xaff2 "꿲" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45043 0xaff3 "꿳" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45044 0xaff4 "꿴" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 45045 0xaff5 "꿵" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45046 0xaff6 "꿶" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45047 0xaff7 "꿷" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45048 0xaff8 "꿸" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45049 0xaff9 "꿹" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45050 0xaffa "꿺" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45051 0xaffb "꿻" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45052 0xaffc "꿼" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45053 0xaffd "꿽" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45054 0xaffe "꿾" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45055 0xafff "꿿" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45056 0xb000 "뀀" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45057 0xb001 "뀁" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45058 0xb002 "뀂" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45059 0xb003 "뀃" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45060 0xb004 "뀄" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45061 0xb005 "뀅" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45062 0xb006 "뀆" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45063 0xb007 "뀇" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45064 0xb008 "뀈" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45065 0xb009 "뀉" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45066 0xb00a "뀊" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45067 0xb00b "뀋" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45068 0xb00c "뀌" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 45069 0xb00d "뀍" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45070 0xb00e "뀎" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45071 0xb00f "뀏" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45072 0xb010 "뀐" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45073 0xb011 "뀑" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45074 0xb012 "뀒" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45075 0xb013 "뀓" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45076 0xb014 "뀔" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45077 0xb015 "뀕" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45078 0xb016 "뀖" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45079 0xb017 "뀗" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45080 0xb018 "뀘" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45081 0xb019 "뀙" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45082 0xb01a "뀚" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45083 0xb01b "뀛" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45084 0xb01c "뀜" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45085 0xb01d "뀝" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45086 0xb01e "뀞" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45087 0xb01f "뀟" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45088 0xb020 "뀠" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45089 0xb021 "뀡" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45090 0xb022 "뀢" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45091 0xb023 "뀣" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45092 0xb024 "뀤" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45093 0xb025 "뀥" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45094 0xb026 "뀦" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45095 0xb027 "뀧" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45096 0xb028 "뀨" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 45097 0xb029 "뀩" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 45098 0xb02a "뀪" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 45099 0xb02b "뀫" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45100 0xb02c "뀬" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 45101 0xb02d "뀭" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 45102 0xb02e "뀮" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 45103 0xb02f "뀯" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 45104 0xb030 "뀰" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45105 0xb031 "뀱" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 45106 0xb032 "뀲" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 45107 0xb033 "뀳" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 45108 0xb034 "뀴" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45109 0xb035 "뀵" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45110 0xb036 "뀶" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 45111 0xb037 "뀷" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 45112 0xb038 "뀸" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 45113 0xb039 "뀹" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 45114 0xb03a "뀺" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45115 0xb03b "뀻" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 45116 0xb03c "뀼" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45117 0xb03d "뀽" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 45118 0xb03e "뀾" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 45119 0xb03f "뀿" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45120 0xb040 "끀" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 45121 0xb041 "끁" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45122 0xb042 "끂" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 45123 0xb043 "끃" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45124 0xb044 "끄" */
+0x00,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,0x02,0x04,0x08,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x08,0x00,0x00,0xff,0x00,0x00,
+/* 45125 0xb045 "끅" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45126 0xb046 "끆" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45127 0xb047 "끇" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45128 0xb048 "끈" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 45129 0xb049 "끉" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45130 0xb04a "끊" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45131 0xb04b "끋" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45132 0xb04c "끌" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45133 0xb04d "끍" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45134 0xb04e "끎" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45135 0xb04f "끏" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45136 0xb050 "끐" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45137 0xb051 "끑" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45138 0xb052 "끒" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45139 0xb053 "끓" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45140 0xb054 "끔" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45141 0xb055 "끕" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45142 0xb056 "끖" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45143 0xb057 "끗" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45144 0xb058 "끘" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45145 0xb059 "끙" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45146 0xb05a "끚" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45147 0xb05b "끛" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45148 0xb05c "끜" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45149 0xb05d "끝" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45150 0xb05e "끞" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45151 0xb05f "끟" */
+0x00,0x00,0x1f,0x01,0x01,0x02,0x04,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x04,0x04,0x04,0x08,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45152 0xb060 "끠" */
+0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x08,0x08,0x10,0x21,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x44,0x44,0x44,0x44,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 45153 0xb061 "끡" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45154 0xb062 "끢" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45155 0xb063 "끣" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45156 0xb064 "끤" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45157 0xb065 "끥" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45158 0xb066 "끦" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45159 0xb067 "끧" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45160 0xb068 "끨" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45161 0xb069 "끩" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45162 0xb06a "끪" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45163 0xb06b "끫" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45164 0xb06c "끬" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45165 0xb06d "끭" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45166 0xb06e "끮" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45167 0xb06f "끯" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45168 0xb070 "끰" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45169 0xb071 "끱" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45170 0xb072 "끲" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45171 0xb073 "끳" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45172 0xb074 "끴" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45173 0xb075 "끵" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45174 0xb076 "끶" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45175 0xb077 "끷" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45176 0xb078 "끸" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45177 0xb079 "끹" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45178 0xb07a "끺" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45179 0xb07b "끻" */
+0x00,0x00,0x7f,0x08,0x08,0x08,0x11,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45180 0xb07c "끼" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 45181 0xb07d "끽" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45182 0xb07e "끾" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45183 0xb07f "끿" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45184 0xb080 "낀" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45185 0xb081 "낁" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45186 0xb082 "낂" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45187 0xb083 "낃" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45188 0xb084 "낄" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45189 0xb085 "낅" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45190 0xb086 "낆" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45191 0xb087 "낇" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45192 0xb088 "낈" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45193 0xb089 "낉" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45194 0xb08a "낊" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45195 0xb08b "낋" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45196 0xb08c "낌" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45197 0xb08d "낍" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45198 0xb08e "낎" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45199 0xb08f "낏" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45200 0xb090 "낐" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45201 0xb091 "낑" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45202 0xb092 "낒" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45203 0xb093 "낓" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45204 0xb094 "낔" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45205 0xb095 "낕" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45206 0xb096 "낖" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45207 0xb097 "낗" */
+0x00,0x00,0x3f,0x04,0x04,0x09,0x09,0x12,0x24,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45208 0xb098 "나" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45209 0xb099 "낙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45210 0xb09a "낚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45211 0xb09b "낛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45212 0xb09c "난" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45213 0xb09d "낝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45214 0xb09e "낞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45215 0xb09f "낟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45216 0xb0a0 "날" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45217 0xb0a1 "낡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45218 0xb0a2 "낢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45219 0xb0a3 "낣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45220 0xb0a4 "낤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45221 0xb0a5 "낥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45222 0xb0a6 "낦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45223 0xb0a7 "낧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45224 0xb0a8 "남" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45225 0xb0a9 "납" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45226 0xb0aa "낪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45227 0xb0ab "낫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45228 0xb0ac "났" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45229 0xb0ad "낭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45230 0xb0ae "낮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45231 0xb0af "낯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45232 0xb0b0 "낰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45233 0xb0b1 "낱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45234 0xb0b2 "낲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45235 0xb0b3 "낳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45236 0xb0b4 "내" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45237 0xb0b5 "낵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45238 0xb0b6 "낶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45239 0xb0b7 "낷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45240 0xb0b8 "낸" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45241 0xb0b9 "낹" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45242 0xb0ba "낺" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45243 0xb0bb "낻" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45244 0xb0bc "낼" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45245 0xb0bd "낽" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45246 0xb0be "낾" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45247 0xb0bf "낿" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45248 0xb0c0 "냀" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45249 0xb0c1 "냁" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45250 0xb0c2 "냂" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45251 0xb0c3 "냃" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45252 0xb0c4 "냄" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45253 0xb0c5 "냅" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45254 0xb0c6 "냆" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45255 0xb0c7 "냇" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45256 0xb0c8 "냈" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45257 0xb0c9 "냉" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45258 0xb0ca "냊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45259 0xb0cb "냋" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45260 0xb0cc "냌" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45261 0xb0cd "냍" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45262 0xb0ce "냎" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45263 0xb0cf "냏" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45264 0xb0d0 "냐" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45265 0xb0d1 "냑" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45266 0xb0d2 "냒" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45267 0xb0d3 "냓" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45268 0xb0d4 "냔" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45269 0xb0d5 "냕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45270 0xb0d6 "냖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45271 0xb0d7 "냗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45272 0xb0d8 "냘" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45273 0xb0d9 "냙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45274 0xb0da "냚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45275 0xb0db "냛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45276 0xb0dc "냜" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45277 0xb0dd "냝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45278 0xb0de "냞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45279 0xb0df "냟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45280 0xb0e0 "냠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45281 0xb0e1 "냡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45282 0xb0e2 "냢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45283 0xb0e3 "냣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45284 0xb0e4 "냤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45285 0xb0e5 "냥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45286 0xb0e6 "냦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45287 0xb0e7 "냧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45288 0xb0e8 "냨" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45289 0xb0e9 "냩" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45290 0xb0ea "냪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45291 0xb0eb "냫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45292 0xb0ec "냬" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45293 0xb0ed "냭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45294 0xb0ee "냮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45295 0xb0ef "냯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45296 0xb0f0 "냰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45297 0xb0f1 "냱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45298 0xb0f2 "냲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45299 0xb0f3 "냳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45300 0xb0f4 "냴" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45301 0xb0f5 "냵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45302 0xb0f6 "냶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45303 0xb0f7 "냷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45304 0xb0f8 "냸" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45305 0xb0f9 "냹" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45306 0xb0fa "냺" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45307 0xb0fb "냻" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45308 0xb0fc "냼" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45309 0xb0fd "냽" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45310 0xb0fe "냾" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45311 0xb0ff "냿" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45312 0xb100 "넀" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45313 0xb101 "넁" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45314 0xb102 "넂" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45315 0xb103 "넃" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45316 0xb104 "넄" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45317 0xb105 "넅" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45318 0xb106 "넆" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45319 0xb107 "넇" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45320 0xb108 "너" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45321 0xb109 "넉" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45322 0xb10a "넊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45323 0xb10b "넋" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45324 0xb10c "넌" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45325 0xb10d "넍" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45326 0xb10e "넎" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45327 0xb10f "넏" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45328 0xb110 "널" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45329 0xb111 "넑" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45330 0xb112 "넒" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45331 0xb113 "넓" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45332 0xb114 "넔" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45333 0xb115 "넕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45334 0xb116 "넖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45335 0xb117 "넗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45336 0xb118 "넘" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45337 0xb119 "넙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45338 0xb11a "넚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45339 0xb11b "넛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45340 0xb11c "넜" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45341 0xb11d "넝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45342 0xb11e "넞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45343 0xb11f "넟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45344 0xb120 "넠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45345 0xb121 "넡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45346 0xb122 "넢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45347 0xb123 "넣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45348 0xb124 "네" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45349 0xb125 "넥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45350 0xb126 "넦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45351 0xb127 "넧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45352 0xb128 "넨" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45353 0xb129 "넩" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45354 0xb12a "넪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45355 0xb12b "넫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45356 0xb12c "넬" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45357 0xb12d "넭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45358 0xb12e "넮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45359 0xb12f "넯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45360 0xb130 "넰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45361 0xb131 "넱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45362 0xb132 "넲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45363 0xb133 "넳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45364 0xb134 "넴" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45365 0xb135 "넵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45366 0xb136 "넶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45367 0xb137 "넷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45368 0xb138 "넸" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45369 0xb139 "넹" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45370 0xb13a "넺" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45371 0xb13b "넻" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45372 0xb13c "넼" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45373 0xb13d "넽" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45374 0xb13e "넾" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45375 0xb13f "넿" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45376 0xb140 "녀" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45377 0xb141 "녁" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45378 0xb142 "녂" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45379 0xb143 "녃" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45380 0xb144 "년" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45381 0xb145 "녅" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45382 0xb146 "녆" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45383 0xb147 "녇" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45384 0xb148 "녈" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45385 0xb149 "녉" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45386 0xb14a "녊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45387 0xb14b "녋" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45388 0xb14c "녌" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45389 0xb14d "녍" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45390 0xb14e "녎" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45391 0xb14f "녏" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45392 0xb150 "념" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45393 0xb151 "녑" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45394 0xb152 "녒" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45395 0xb153 "녓" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45396 0xb154 "녔" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45397 0xb155 "녕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45398 0xb156 "녖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45399 0xb157 "녗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45400 0xb158 "녘" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45401 0xb159 "녙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45402 0xb15a "녚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45403 0xb15b "녛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45404 0xb15c "녜" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45405 0xb15d "녝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45406 0xb15e "녞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45407 0xb15f "녟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45408 0xb160 "녠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45409 0xb161 "녡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45410 0xb162 "녢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45411 0xb163 "녣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45412 0xb164 "녤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45413 0xb165 "녥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45414 0xb166 "녦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45415 0xb167 "녧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45416 0xb168 "녨" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45417 0xb169 "녩" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45418 0xb16a "녪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45419 0xb16b "녫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45420 0xb16c "녬" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45421 0xb16d "녭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45422 0xb16e "녮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45423 0xb16f "녯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45424 0xb170 "녰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45425 0xb171 "녱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45426 0xb172 "녲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45427 0xb173 "녳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45428 0xb174 "녴" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45429 0xb175 "녵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45430 0xb176 "녶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45431 0xb177 "녷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45432 0xb178 "노" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 45433 0xb179 "녹" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45434 0xb17a "녺" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45435 0xb17b "녻" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45436 0xb17c "논" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 45437 0xb17d "녽" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45438 0xb17e "녾" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45439 0xb17f "녿" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45440 0xb180 "놀" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45441 0xb181 "놁" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45442 0xb182 "놂" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45443 0xb183 "놃" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45444 0xb184 "놄" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45445 0xb185 "놅" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45446 0xb186 "놆" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45447 0xb187 "놇" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45448 0xb188 "놈" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45449 0xb189 "놉" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45450 0xb18a "놊" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45451 0xb18b "놋" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45452 0xb18c "놌" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45453 0xb18d "농" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45454 0xb18e "놎" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45455 0xb18f "놏" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45456 0xb190 "놐" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45457 0xb191 "놑" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45458 0xb192 "높" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45459 0xb193 "놓" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45460 0xb194 "놔" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 45461 0xb195 "놕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45462 0xb196 "놖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45463 0xb197 "놗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45464 0xb198 "놘" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45465 0xb199 "놙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45466 0xb19a "놚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45467 0xb19b "놛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45468 0xb19c "놜" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45469 0xb19d "놝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45470 0xb19e "놞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45471 0xb19f "놟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45472 0xb1a0 "놠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45473 0xb1a1 "놡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45474 0xb1a2 "놢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45475 0xb1a3 "놣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45476 0xb1a4 "놤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45477 0xb1a5 "놥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45478 0xb1a6 "놦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45479 0xb1a7 "놧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45480 0xb1a8 "놨" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45481 0xb1a9 "놩" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45482 0xb1aa "놪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45483 0xb1ab "놫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45484 0xb1ac "놬" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45485 0xb1ad "놭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45486 0xb1ae "놮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45487 0xb1af "놯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45488 0xb1b0 "놰" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 45489 0xb1b1 "놱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45490 0xb1b2 "놲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45491 0xb1b3 "놳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45492 0xb1b4 "놴" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45493 0xb1b5 "놵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45494 0xb1b6 "놶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45495 0xb1b7 "놷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45496 0xb1b8 "놸" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45497 0xb1b9 "놹" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45498 0xb1ba "놺" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45499 0xb1bb "놻" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45500 0xb1bc "놼" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45501 0xb1bd "놽" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45502 0xb1be "놾" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45503 0xb1bf "놿" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45504 0xb1c0 "뇀" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45505 0xb1c1 "뇁" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45506 0xb1c2 "뇂" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45507 0xb1c3 "뇃" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45508 0xb1c4 "뇄" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45509 0xb1c5 "뇅" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45510 0xb1c6 "뇆" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45511 0xb1c7 "뇇" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45512 0xb1c8 "뇈" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45513 0xb1c9 "뇉" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45514 0xb1ca "뇊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45515 0xb1cb "뇋" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45516 0xb1cc "뇌" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 45517 0xb1cd "뇍" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45518 0xb1ce "뇎" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45519 0xb1cf "뇏" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45520 0xb1d0 "뇐" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45521 0xb1d1 "뇑" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45522 0xb1d2 "뇒" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45523 0xb1d3 "뇓" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45524 0xb1d4 "뇔" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45525 0xb1d5 "뇕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45526 0xb1d6 "뇖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45527 0xb1d7 "뇗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45528 0xb1d8 "뇘" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45529 0xb1d9 "뇙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45530 0xb1da "뇚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45531 0xb1db "뇛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45532 0xb1dc "뇜" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45533 0xb1dd "뇝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45534 0xb1de "뇞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45535 0xb1df "뇟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45536 0xb1e0 "뇠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45537 0xb1e1 "뇡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45538 0xb1e2 "뇢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45539 0xb1e3 "뇣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45540 0xb1e4 "뇤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45541 0xb1e5 "뇥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45542 0xb1e6 "뇦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45543 0xb1e7 "뇧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45544 0xb1e8 "뇨" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 45545 0xb1e9 "뇩" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45546 0xb1ea "뇪" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45547 0xb1eb "뇫" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45548 0xb1ec "뇬" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 45549 0xb1ed "뇭" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45550 0xb1ee "뇮" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45551 0xb1ef "뇯" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45552 0xb1f0 "뇰" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45553 0xb1f1 "뇱" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45554 0xb1f2 "뇲" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45555 0xb1f3 "뇳" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45556 0xb1f4 "뇴" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45557 0xb1f5 "뇵" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45558 0xb1f6 "뇶" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45559 0xb1f7 "뇷" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45560 0xb1f8 "뇸" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45561 0xb1f9 "뇹" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45562 0xb1fa "뇺" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45563 0xb1fb "뇻" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45564 0xb1fc "뇼" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45565 0xb1fd "뇽" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45566 0xb1fe "뇾" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45567 0xb1ff "뇿" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45568 0xb200 "눀" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45569 0xb201 "눁" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45570 0xb202 "눂" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45571 0xb203 "눃" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45572 0xb204 "누" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 45573 0xb205 "눅" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 45574 0xb206 "눆" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 45575 0xb207 "눇" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 45576 0xb208 "눈" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 45577 0xb209 "눉" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 45578 0xb20a "눊" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 45579 0xb20b "눋" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 45580 0xb20c "눌" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45581 0xb20d "눍" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 45582 0xb20e "눎" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 45583 0xb20f "눏" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 45584 0xb210 "눐" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 45585 0xb211 "눑" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45586 0xb212 "눒" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 45587 0xb213 "눓" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 45588 0xb214 "눔" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 45589 0xb215 "눕" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 45590 0xb216 "눖" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 45591 0xb217 "눗" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 45592 0xb218 "눘" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 45593 0xb219 "눙" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 45594 0xb21a "눚" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 45595 0xb21b "눛" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45596 0xb21c "눜" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 45597 0xb21d "눝" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45598 0xb21e "눞" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 45599 0xb21f "눟" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45600 0xb220 "눠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 45601 0xb221 "눡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45602 0xb222 "눢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45603 0xb223 "눣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45604 0xb224 "눤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 45605 0xb225 "눥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45606 0xb226 "눦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45607 0xb227 "눧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45608 0xb228 "눨" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45609 0xb229 "눩" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45610 0xb22a "눪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45611 0xb22b "눫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45612 0xb22c "눬" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45613 0xb22d "눭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45614 0xb22e "눮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45615 0xb22f "눯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45616 0xb230 "눰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45617 0xb231 "눱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45618 0xb232 "눲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45619 0xb233 "눳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45620 0xb234 "눴" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45621 0xb235 "눵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45622 0xb236 "눶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45623 0xb237 "눷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45624 0xb238 "눸" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45625 0xb239 "눹" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45626 0xb23a "눺" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45627 0xb23b "눻" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45628 0xb23c "눼" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 45629 0xb23d "눽" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45630 0xb23e "눾" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45631 0xb23f "눿" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45632 0xb240 "뉀" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 45633 0xb241 "뉁" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45634 0xb242 "뉂" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45635 0xb243 "뉃" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45636 0xb244 "뉄" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45637 0xb245 "뉅" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45638 0xb246 "뉆" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45639 0xb247 "뉇" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45640 0xb248 "뉈" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45641 0xb249 "뉉" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45642 0xb24a "뉊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45643 0xb24b "뉋" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45644 0xb24c "뉌" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45645 0xb24d "뉍" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45646 0xb24e "뉎" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45647 0xb24f "뉏" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45648 0xb250 "뉐" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45649 0xb251 "뉑" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45650 0xb252 "뉒" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45651 0xb253 "뉓" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45652 0xb254 "뉔" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45653 0xb255 "뉕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45654 0xb256 "뉖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45655 0xb257 "뉗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45656 0xb258 "뉘" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 45657 0xb259 "뉙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45658 0xb25a "뉚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45659 0xb25b "뉛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45660 0xb25c "뉜" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45661 0xb25d "뉝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45662 0xb25e "뉞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45663 0xb25f "뉟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45664 0xb260 "뉠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45665 0xb261 "뉡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45666 0xb262 "뉢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45667 0xb263 "뉣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45668 0xb264 "뉤" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45669 0xb265 "뉥" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45670 0xb266 "뉦" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45671 0xb267 "뉧" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45672 0xb268 "뉨" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45673 0xb269 "뉩" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45674 0xb26a "뉪" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45675 0xb26b "뉫" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45676 0xb26c "뉬" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45677 0xb26d "뉭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45678 0xb26e "뉮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45679 0xb26f "뉯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45680 0xb270 "뉰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45681 0xb271 "뉱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45682 0xb272 "뉲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45683 0xb273 "뉳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45684 0xb274 "뉴" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 45685 0xb275 "뉵" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 45686 0xb276 "뉶" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 45687 0xb277 "뉷" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45688 0xb278 "뉸" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 45689 0xb279 "뉹" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 45690 0xb27a "뉺" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 45691 0xb27b "뉻" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 45692 0xb27c "뉼" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45693 0xb27d "뉽" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 45694 0xb27e "뉾" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 45695 0xb27f "뉿" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 45696 0xb280 "늀" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45697 0xb281 "늁" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45698 0xb282 "늂" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 45699 0xb283 "늃" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 45700 0xb284 "늄" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 45701 0xb285 "늅" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 45702 0xb286 "늆" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45703 0xb287 "늇" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 45704 0xb288 "늈" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 45705 0xb289 "늉" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 45706 0xb28a "늊" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 45707 0xb28b "늋" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45708 0xb28c "늌" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 45709 0xb28d "늍" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45710 0xb28e "늎" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 45711 0xb28f "늏" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45712 0xb290 "느" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 45713 0xb291 "늑" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45714 0xb292 "늒" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45715 0xb293 "늓" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45716 0xb294 "는" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 45717 0xb295 "늕" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45718 0xb296 "늖" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45719 0xb297 "늗" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45720 0xb298 "늘" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45721 0xb299 "늙" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45722 0xb29a "늚" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45723 0xb29b "늛" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45724 0xb29c "늜" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45725 0xb29d "늝" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45726 0xb29e "늞" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45727 0xb29f "늟" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45728 0xb2a0 "늠" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45729 0xb2a1 "늡" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45730 0xb2a2 "늢" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45731 0xb2a3 "늣" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45732 0xb2a4 "늤" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45733 0xb2a5 "능" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45734 0xb2a6 "늦" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45735 0xb2a7 "늧" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45736 0xb2a8 "늨" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45737 0xb2a9 "늩" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45738 0xb2aa "늪" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45739 0xb2ab "늫" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45740 0xb2ac "늬" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 45741 0xb2ad "늭" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45742 0xb2ae "늮" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45743 0xb2af "늯" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45744 0xb2b0 "늰" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45745 0xb2b1 "늱" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45746 0xb2b2 "늲" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45747 0xb2b3 "늳" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45748 0xb2b4 "늴" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45749 0xb2b5 "늵" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45750 0xb2b6 "늶" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45751 0xb2b7 "늷" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45752 0xb2b8 "늸" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45753 0xb2b9 "늹" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45754 0xb2ba "늺" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45755 0xb2bb "늻" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45756 0xb2bc "늼" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45757 0xb2bd "늽" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45758 0xb2be "늾" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45759 0xb2bf "늿" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45760 0xb2c0 "닀" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45761 0xb2c1 "닁" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45762 0xb2c2 "닂" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45763 0xb2c3 "닃" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45764 0xb2c4 "닄" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45765 0xb2c5 "닅" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45766 0xb2c6 "닆" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45767 0xb2c7 "닇" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45768 0xb2c8 "니" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45769 0xb2c9 "닉" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45770 0xb2ca "닊" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45771 0xb2cb "닋" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45772 0xb2cc "닌" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45773 0xb2cd "닍" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45774 0xb2ce "닎" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45775 0xb2cf "닏" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45776 0xb2d0 "닐" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45777 0xb2d1 "닑" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45778 0xb2d2 "닒" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45779 0xb2d3 "닓" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45780 0xb2d4 "닔" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45781 0xb2d5 "닕" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45782 0xb2d6 "닖" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45783 0xb2d7 "닗" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45784 0xb2d8 "님" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45785 0xb2d9 "닙" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45786 0xb2da "닚" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45787 0xb2db "닛" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45788 0xb2dc "닜" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45789 0xb2dd "닝" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45790 0xb2de "닞" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45791 0xb2df "닟" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45792 0xb2e0 "닠" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45793 0xb2e1 "닡" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45794 0xb2e2 "닢" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45795 0xb2e3 "닣" */
+0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45796 0xb2e4 "다" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45797 0xb2e5 "닥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45798 0xb2e6 "닦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45799 0xb2e7 "닧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45800 0xb2e8 "단" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45801 0xb2e9 "닩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45802 0xb2ea "닪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45803 0xb2eb "닫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45804 0xb2ec "달" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45805 0xb2ed "닭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45806 0xb2ee "닮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45807 0xb2ef "닯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45808 0xb2f0 "닰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45809 0xb2f1 "닱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45810 0xb2f2 "닲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45811 0xb2f3 "닳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45812 0xb2f4 "담" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45813 0xb2f5 "답" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45814 0xb2f6 "닶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45815 0xb2f7 "닷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45816 0xb2f8 "닸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45817 0xb2f9 "당" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45818 0xb2fa "닺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45819 0xb2fb "닻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45820 0xb2fc "닼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45821 0xb2fd "닽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45822 0xb2fe "닾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45823 0xb2ff "닿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45824 0xb300 "대" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45825 0xb301 "댁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45826 0xb302 "댂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45827 0xb303 "댃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45828 0xb304 "댄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45829 0xb305 "댅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45830 0xb306 "댆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45831 0xb307 "댇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45832 0xb308 "댈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45833 0xb309 "댉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45834 0xb30a "댊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45835 0xb30b "댋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45836 0xb30c "댌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45837 0xb30d "댍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45838 0xb30e "댎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45839 0xb30f "댏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45840 0xb310 "댐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45841 0xb311 "댑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45842 0xb312 "댒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45843 0xb313 "댓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45844 0xb314 "댔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45845 0xb315 "댕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45846 0xb316 "댖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45847 0xb317 "댗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45848 0xb318 "댘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45849 0xb319 "댙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45850 0xb31a "댚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45851 0xb31b "댛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45852 0xb31c "댜" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45853 0xb31d "댝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45854 0xb31e "댞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45855 0xb31f "댟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45856 0xb320 "댠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45857 0xb321 "댡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45858 0xb322 "댢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45859 0xb323 "댣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45860 0xb324 "댤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45861 0xb325 "댥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45862 0xb326 "댦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45863 0xb327 "댧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45864 0xb328 "댨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45865 0xb329 "댩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45866 0xb32a "댪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45867 0xb32b "댫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45868 0xb32c "댬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45869 0xb32d "댭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45870 0xb32e "댮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45871 0xb32f "댯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45872 0xb330 "댰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45873 0xb331 "댱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45874 0xb332 "댲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45875 0xb333 "댳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45876 0xb334 "댴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45877 0xb335 "댵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45878 0xb336 "댶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45879 0xb337 "댷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45880 0xb338 "댸" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45881 0xb339 "댹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45882 0xb33a "댺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45883 0xb33b "댻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45884 0xb33c "댼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45885 0xb33d "댽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45886 0xb33e "댾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45887 0xb33f "댿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45888 0xb340 "덀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45889 0xb341 "덁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45890 0xb342 "덂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45891 0xb343 "덃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45892 0xb344 "덄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45893 0xb345 "덅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45894 0xb346 "덆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45895 0xb347 "덇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45896 0xb348 "덈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45897 0xb349 "덉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45898 0xb34a "덊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45899 0xb34b "덋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45900 0xb34c "덌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45901 0xb34d "덍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45902 0xb34e "덎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45903 0xb34f "덏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45904 0xb350 "덐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45905 0xb351 "덑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45906 0xb352 "덒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45907 0xb353 "덓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45908 0xb354 "더" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45909 0xb355 "덕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45910 0xb356 "덖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45911 0xb357 "덗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45912 0xb358 "던" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45913 0xb359 "덙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45914 0xb35a "덚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45915 0xb35b "덛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45916 0xb35c "덜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45917 0xb35d "덝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45918 0xb35e "덞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45919 0xb35f "덟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45920 0xb360 "덠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45921 0xb361 "덡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45922 0xb362 "덢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45923 0xb363 "덣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45924 0xb364 "덤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45925 0xb365 "덥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45926 0xb366 "덦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45927 0xb367 "덧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45928 0xb368 "덨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45929 0xb369 "덩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45930 0xb36a "덪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45931 0xb36b "덫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45932 0xb36c "덬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45933 0xb36d "덭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45934 0xb36e "덮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45935 0xb36f "덯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45936 0xb370 "데" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45937 0xb371 "덱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45938 0xb372 "덲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45939 0xb373 "덳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45940 0xb374 "덴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45941 0xb375 "덵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45942 0xb376 "덶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45943 0xb377 "덷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 45944 0xb378 "델" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 45945 0xb379 "덹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 45946 0xb37a "덺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 45947 0xb37b "덻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 45948 0xb37c "덼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 45949 0xb37d "덽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 45950 0xb37e "덾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 45951 0xb37f "덿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 45952 0xb380 "뎀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 45953 0xb381 "뎁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 45954 0xb382 "뎂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45955 0xb383 "뎃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 45956 0xb384 "뎄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 45957 0xb385 "뎅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 45958 0xb386 "뎆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 45959 0xb387 "뎇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 45960 0xb388 "뎈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 45961 0xb389 "뎉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 45962 0xb38a "뎊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 45963 0xb38b "뎋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 45964 0xb38c "뎌" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 45965 0xb38d "뎍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 45966 0xb38e "뎎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45967 0xb38f "뎏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45968 0xb390 "뎐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 45969 0xb391 "뎑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 45970 0xb392 "뎒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45971 0xb393 "뎓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 45972 0xb394 "뎔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 45973 0xb395 "뎕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 45974 0xb396 "뎖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 45975 0xb397 "뎗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 45976 0xb398 "뎘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45977 0xb399 "뎙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 45978 0xb39a "뎚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 45979 0xb39b "뎛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 45980 0xb39c "뎜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 45981 0xb39d "뎝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 45982 0xb39e "뎞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45983 0xb39f "뎟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 45984 0xb3a0 "뎠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 45985 0xb3a1 "뎡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 45986 0xb3a2 "뎢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 45987 0xb3a3 "뎣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 45988 0xb3a4 "뎤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 45989 0xb3a5 "뎥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 45990 0xb3a6 "뎦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 45991 0xb3a7 "뎧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 45992 0xb3a8 "뎨" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 45993 0xb3a9 "뎩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 45994 0xb3aa "뎪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 45995 0xb3ab "뎫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 45996 0xb3ac "뎬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 45997 0xb3ad "뎭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 45998 0xb3ae "뎮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 45999 0xb3af "뎯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46000 0xb3b0 "뎰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46001 0xb3b1 "뎱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46002 0xb3b2 "뎲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46003 0xb3b3 "뎳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46004 0xb3b4 "뎴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46005 0xb3b5 "뎵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46006 0xb3b6 "뎶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46007 0xb3b7 "뎷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46008 0xb3b8 "뎸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46009 0xb3b9 "뎹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46010 0xb3ba "뎺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46011 0xb3bb "뎻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46012 0xb3bc "뎼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46013 0xb3bd "뎽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46014 0xb3be "뎾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46015 0xb3bf "뎿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46016 0xb3c0 "돀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46017 0xb3c1 "돁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46018 0xb3c2 "돂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46019 0xb3c3 "돃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46020 0xb3c4 "도" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 46021 0xb3c5 "독" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46022 0xb3c6 "돆" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46023 0xb3c7 "돇" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46024 0xb3c8 "돈" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 46025 0xb3c9 "돉" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46026 0xb3ca "돊" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46027 0xb3cb "돋" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46028 0xb3cc "돌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46029 0xb3cd "돍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46030 0xb3ce "돎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46031 0xb3cf "돏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46032 0xb3d0 "돐" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46033 0xb3d1 "돑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46034 0xb3d2 "돒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46035 0xb3d3 "돓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46036 0xb3d4 "돔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46037 0xb3d5 "돕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46038 0xb3d6 "돖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46039 0xb3d7 "돗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46040 0xb3d8 "돘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46041 0xb3d9 "동" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46042 0xb3da "돚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46043 0xb3db "돛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46044 0xb3dc "돜" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46045 0xb3dd "돝" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46046 0xb3de "돞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46047 0xb3df "돟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46048 0xb3e0 "돠" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 46049 0xb3e1 "돡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46050 0xb3e2 "돢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46051 0xb3e3 "돣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46052 0xb3e4 "돤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46053 0xb3e5 "돥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46054 0xb3e6 "돦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46055 0xb3e7 "돧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46056 0xb3e8 "돨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46057 0xb3e9 "돩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46058 0xb3ea "돪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46059 0xb3eb "돫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46060 0xb3ec "돬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46061 0xb3ed "돭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46062 0xb3ee "돮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46063 0xb3ef "돯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46064 0xb3f0 "돰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46065 0xb3f1 "돱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46066 0xb3f2 "돲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46067 0xb3f3 "돳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46068 0xb3f4 "돴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46069 0xb3f5 "돵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46070 0xb3f6 "돶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46071 0xb3f7 "돷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46072 0xb3f8 "돸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46073 0xb3f9 "돹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46074 0xb3fa "돺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46075 0xb3fb "돻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46076 0xb3fc "돼" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 46077 0xb3fd "돽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46078 0xb3fe "돾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46079 0xb3ff "돿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46080 0xb400 "됀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 46081 0xb401 "됁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46082 0xb402 "됂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46083 0xb403 "됃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46084 0xb404 "됄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46085 0xb405 "됅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46086 0xb406 "됆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46087 0xb407 "됇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46088 0xb408 "됈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46089 0xb409 "됉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46090 0xb40a "됊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46091 0xb40b "됋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46092 0xb40c "됌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46093 0xb40d "됍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46094 0xb40e "됎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46095 0xb40f "됏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46096 0xb410 "됐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46097 0xb411 "됑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46098 0xb412 "됒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46099 0xb413 "됓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46100 0xb414 "됔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46101 0xb415 "됕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46102 0xb416 "됖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46103 0xb417 "됗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46104 0xb418 "되" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 46105 0xb419 "됙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46106 0xb41a "됚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46107 0xb41b "됛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46108 0xb41c "된" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46109 0xb41d "됝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46110 0xb41e "됞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46111 0xb41f "됟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46112 0xb420 "될" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46113 0xb421 "됡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46114 0xb422 "됢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46115 0xb423 "됣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46116 0xb424 "됤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46117 0xb425 "됥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46118 0xb426 "됦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46119 0xb427 "됧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46120 0xb428 "됨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46121 0xb429 "됩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46122 0xb42a "됪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46123 0xb42b "됫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46124 0xb42c "됬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46125 0xb42d "됭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46126 0xb42e "됮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46127 0xb42f "됯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46128 0xb430 "됰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46129 0xb431 "됱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46130 0xb432 "됲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46131 0xb433 "됳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46132 0xb434 "됴" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 46133 0xb435 "됵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46134 0xb436 "됶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46135 0xb437 "됷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46136 0xb438 "됸" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 46137 0xb439 "됹" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46138 0xb43a "됺" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46139 0xb43b "됻" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46140 0xb43c "됼" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46141 0xb43d "됽" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46142 0xb43e "됾" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46143 0xb43f "됿" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46144 0xb440 "둀" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46145 0xb441 "둁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46146 0xb442 "둂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46147 0xb443 "둃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46148 0xb444 "둄" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46149 0xb445 "둅" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46150 0xb446 "둆" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46151 0xb447 "둇" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46152 0xb448 "둈" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46153 0xb449 "둉" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46154 0xb44a "둊" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46155 0xb44b "둋" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46156 0xb44c "둌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46157 0xb44d "둍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46158 0xb44e "둎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46159 0xb44f "둏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46160 0xb450 "두" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 46161 0xb451 "둑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 46162 0xb452 "둒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 46163 0xb453 "둓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46164 0xb454 "둔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 46165 0xb455 "둕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 46166 0xb456 "둖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 46167 0xb457 "둗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 46168 0xb458 "둘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46169 0xb459 "둙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 46170 0xb45a "둚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 46171 0xb45b "둛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 46172 0xb45c "둜" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46173 0xb45d "둝" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46174 0xb45e "둞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 46175 0xb45f "둟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 46176 0xb460 "둠" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 46177 0xb461 "둡" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 46178 0xb462 "둢" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46179 0xb463 "둣" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 46180 0xb464 "둤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46181 0xb465 "둥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 46182 0xb466 "둦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 46183 0xb467 "둧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46184 0xb468 "둨" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 46185 0xb469 "둩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46186 0xb46a "둪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 46187 0xb46b "둫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46188 0xb46c "둬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 46189 0xb46d "둭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46190 0xb46e "둮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46191 0xb46f "둯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46192 0xb470 "둰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 46193 0xb471 "둱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46194 0xb472 "둲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46195 0xb473 "둳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46196 0xb474 "둴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46197 0xb475 "둵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46198 0xb476 "둶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46199 0xb477 "둷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46200 0xb478 "둸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46201 0xb479 "둹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46202 0xb47a "둺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46203 0xb47b "둻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46204 0xb47c "둼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46205 0xb47d "둽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46206 0xb47e "둾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46207 0xb47f "둿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46208 0xb480 "뒀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46209 0xb481 "뒁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46210 0xb482 "뒂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46211 0xb483 "뒃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46212 0xb484 "뒄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46213 0xb485 "뒅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46214 0xb486 "뒆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46215 0xb487 "뒇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46216 0xb488 "뒈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 46217 0xb489 "뒉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46218 0xb48a "뒊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46219 0xb48b "뒋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46220 0xb48c "뒌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 46221 0xb48d "뒍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46222 0xb48e "뒎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46223 0xb48f "뒏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46224 0xb490 "뒐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46225 0xb491 "뒑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46226 0xb492 "뒒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46227 0xb493 "뒓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46228 0xb494 "뒔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46229 0xb495 "뒕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46230 0xb496 "뒖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46231 0xb497 "뒗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46232 0xb498 "뒘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46233 0xb499 "뒙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46234 0xb49a "뒚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46235 0xb49b "뒛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46236 0xb49c "뒜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46237 0xb49d "뒝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46238 0xb49e "뒞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46239 0xb49f "뒟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46240 0xb4a0 "뒠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46241 0xb4a1 "뒡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46242 0xb4a2 "뒢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46243 0xb4a3 "뒣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46244 0xb4a4 "뒤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 46245 0xb4a5 "뒥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46246 0xb4a6 "뒦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46247 0xb4a7 "뒧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46248 0xb4a8 "뒨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46249 0xb4a9 "뒩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46250 0xb4aa "뒪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46251 0xb4ab "뒫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46252 0xb4ac "뒬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46253 0xb4ad "뒭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46254 0xb4ae "뒮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46255 0xb4af "뒯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46256 0xb4b0 "뒰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46257 0xb4b1 "뒱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46258 0xb4b2 "뒲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46259 0xb4b3 "뒳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46260 0xb4b4 "뒴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46261 0xb4b5 "뒵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46262 0xb4b6 "뒶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46263 0xb4b7 "뒷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46264 0xb4b8 "뒸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46265 0xb4b9 "뒹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46266 0xb4ba "뒺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46267 0xb4bb "뒻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46268 0xb4bc "뒼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46269 0xb4bd "뒽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46270 0xb4be "뒾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46271 0xb4bf "뒿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46272 0xb4c0 "듀" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 46273 0xb4c1 "듁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 46274 0xb4c2 "듂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 46275 0xb4c3 "듃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46276 0xb4c4 "듄" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 46277 0xb4c5 "듅" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 46278 0xb4c6 "듆" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 46279 0xb4c7 "듇" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 46280 0xb4c8 "듈" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46281 0xb4c9 "듉" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 46282 0xb4ca "듊" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 46283 0xb4cb "듋" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 46284 0xb4cc "듌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46285 0xb4cd "듍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46286 0xb4ce "듎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 46287 0xb4cf "듏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 46288 0xb4d0 "듐" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 46289 0xb4d1 "듑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 46290 0xb4d2 "듒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46291 0xb4d3 "듓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 46292 0xb4d4 "듔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46293 0xb4d5 "듕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 46294 0xb4d6 "듖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 46295 0xb4d7 "듗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46296 0xb4d8 "듘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 46297 0xb4d9 "듙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46298 0xb4da "듚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 46299 0xb4db "듛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46300 0xb4dc "드" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 46301 0xb4dd "득" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46302 0xb4de "듞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46303 0xb4df "듟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46304 0xb4e0 "든" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 46305 0xb4e1 "듡" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46306 0xb4e2 "듢" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46307 0xb4e3 "듣" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46308 0xb4e4 "들" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46309 0xb4e5 "듥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46310 0xb4e6 "듦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46311 0xb4e7 "듧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46312 0xb4e8 "듨" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46313 0xb4e9 "듩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46314 0xb4ea "듪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46315 0xb4eb "듫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46316 0xb4ec "듬" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46317 0xb4ed "듭" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46318 0xb4ee "듮" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46319 0xb4ef "듯" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46320 0xb4f0 "듰" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46321 0xb4f1 "등" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46322 0xb4f2 "듲" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46323 0xb4f3 "듳" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46324 0xb4f4 "듴" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46325 0xb4f5 "듵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46326 0xb4f6 "듶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46327 0xb4f7 "듷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46328 0xb4f8 "듸" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 46329 0xb4f9 "듹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46330 0xb4fa "듺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46331 0xb4fb "듻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46332 0xb4fc "듼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46333 0xb4fd "듽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46334 0xb4fe "듾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46335 0xb4ff "듿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46336 0xb500 "딀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46337 0xb501 "딁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46338 0xb502 "딂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46339 0xb503 "딃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46340 0xb504 "딄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46341 0xb505 "딅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46342 0xb506 "딆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46343 0xb507 "딇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46344 0xb508 "딈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46345 0xb509 "딉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46346 0xb50a "딊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46347 0xb50b "딋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46348 0xb50c "딌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46349 0xb50d "딍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46350 0xb50e "딎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46351 0xb50f "딏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46352 0xb510 "딐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46353 0xb511 "딑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46354 0xb512 "딒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46355 0xb513 "딓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46356 0xb514 "디" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46357 0xb515 "딕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46358 0xb516 "딖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46359 0xb517 "딗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46360 0xb518 "딘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46361 0xb519 "딙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46362 0xb51a "딚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46363 0xb51b "딛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46364 0xb51c "딜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46365 0xb51d "딝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46366 0xb51e "딞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46367 0xb51f "딟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46368 0xb520 "딠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46369 0xb521 "딡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46370 0xb522 "딢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46371 0xb523 "딣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46372 0xb524 "딤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46373 0xb525 "딥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46374 0xb526 "딦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46375 0xb527 "딧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46376 0xb528 "딨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46377 0xb529 "딩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46378 0xb52a "딪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46379 0xb52b "딫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46380 0xb52c "딬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46381 0xb52d "딭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46382 0xb52e "딮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46383 0xb52f "딯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46384 0xb530 "따" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46385 0xb531 "딱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46386 0xb532 "딲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46387 0xb533 "딳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46388 0xb534 "딴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46389 0xb535 "딵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46390 0xb536 "딶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46391 0xb537 "딷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46392 0xb538 "딸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46393 0xb539 "딹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46394 0xb53a "딺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46395 0xb53b "딻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46396 0xb53c "딼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46397 0xb53d "딽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46398 0xb53e "딾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46399 0xb53f "딿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46400 0xb540 "땀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46401 0xb541 "땁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46402 0xb542 "땂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46403 0xb543 "땃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46404 0xb544 "땄" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46405 0xb545 "땅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46406 0xb546 "땆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46407 0xb547 "땇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46408 0xb548 "땈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46409 0xb549 "땉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46410 0xb54a "땊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46411 0xb54b "땋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46412 0xb54c "때" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 46413 0xb54d "땍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46414 0xb54e "땎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46415 0xb54f "땏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46416 0xb550 "땐" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 46417 0xb551 "땑" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46418 0xb552 "땒" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46419 0xb553 "땓" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46420 0xb554 "땔" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46421 0xb555 "땕" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46422 0xb556 "땖" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46423 0xb557 "땗" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46424 0xb558 "땘" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46425 0xb559 "땙" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46426 0xb55a "땚" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46427 0xb55b "땛" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46428 0xb55c "땜" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46429 0xb55d "땝" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46430 0xb55e "땞" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46431 0xb55f "땟" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46432 0xb560 "땠" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46433 0xb561 "땡" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46434 0xb562 "땢" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46435 0xb563 "땣" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46436 0xb564 "땤" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46437 0xb565 "땥" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46438 0xb566 "땦" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46439 0xb567 "땧" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46440 0xb568 "땨" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46441 0xb569 "땩" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46442 0xb56a "땪" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46443 0xb56b "땫" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46444 0xb56c "땬" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46445 0xb56d "땭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46446 0xb56e "땮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46447 0xb56f "땯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46448 0xb570 "땰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46449 0xb571 "땱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46450 0xb572 "땲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46451 0xb573 "땳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46452 0xb574 "땴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46453 0xb575 "땵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46454 0xb576 "땶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46455 0xb577 "땷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46456 0xb578 "땸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46457 0xb579 "땹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46458 0xb57a "땺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46459 0xb57b "땻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46460 0xb57c "땼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46461 0xb57d "땽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46462 0xb57e "땾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46463 0xb57f "땿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46464 0xb580 "떀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46465 0xb581 "떁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46466 0xb582 "떂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46467 0xb583 "떃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46468 0xb584 "떄" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 46469 0xb585 "떅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46470 0xb586 "떆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46471 0xb587 "떇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46472 0xb588 "떈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 46473 0xb589 "떉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46474 0xb58a "떊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46475 0xb58b "떋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46476 0xb58c "떌" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46477 0xb58d "떍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46478 0xb58e "떎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46479 0xb58f "떏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46480 0xb590 "떐" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46481 0xb591 "떑" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46482 0xb592 "떒" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46483 0xb593 "떓" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46484 0xb594 "떔" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46485 0xb595 "떕" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46486 0xb596 "떖" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46487 0xb597 "떗" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46488 0xb598 "떘" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46489 0xb599 "떙" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46490 0xb59a "떚" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46491 0xb59b "떛" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46492 0xb59c "떜" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46493 0xb59d "떝" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46494 0xb59e "떞" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46495 0xb59f "떟" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46496 0xb5a0 "떠" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46497 0xb5a1 "떡" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46498 0xb5a2 "떢" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46499 0xb5a3 "떣" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46500 0xb5a4 "떤" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46501 0xb5a5 "떥" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46502 0xb5a6 "떦" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46503 0xb5a7 "떧" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46504 0xb5a8 "떨" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46505 0xb5a9 "떩" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46506 0xb5aa "떪" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46507 0xb5ab "떫" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46508 0xb5ac "떬" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46509 0xb5ad "떭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46510 0xb5ae "떮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46511 0xb5af "떯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46512 0xb5b0 "떰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46513 0xb5b1 "떱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46514 0xb5b2 "떲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46515 0xb5b3 "떳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46516 0xb5b4 "떴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46517 0xb5b5 "떵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46518 0xb5b6 "떶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46519 0xb5b7 "떷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46520 0xb5b8 "떸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46521 0xb5b9 "떹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46522 0xb5ba "떺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46523 0xb5bb "떻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46524 0xb5bc "떼" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 46525 0xb5bd "떽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46526 0xb5be "떾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46527 0xb5bf "떿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46528 0xb5c0 "뗀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 46529 0xb5c1 "뗁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46530 0xb5c2 "뗂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46531 0xb5c3 "뗃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46532 0xb5c4 "뗄" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46533 0xb5c5 "뗅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46534 0xb5c6 "뗆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46535 0xb5c7 "뗇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46536 0xb5c8 "뗈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46537 0xb5c9 "뗉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46538 0xb5ca "뗊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46539 0xb5cb "뗋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46540 0xb5cc "뗌" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46541 0xb5cd "뗍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46542 0xb5ce "뗎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46543 0xb5cf "뗏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46544 0xb5d0 "뗐" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46545 0xb5d1 "뗑" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46546 0xb5d2 "뗒" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46547 0xb5d3 "뗓" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46548 0xb5d4 "뗔" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46549 0xb5d5 "뗕" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46550 0xb5d6 "뗖" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46551 0xb5d7 "뗗" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46552 0xb5d8 "뗘" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46553 0xb5d9 "뗙" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46554 0xb5da "뗚" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46555 0xb5db "뗛" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46556 0xb5dc "뗜" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46557 0xb5dd "뗝" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46558 0xb5de "뗞" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46559 0xb5df "뗟" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46560 0xb5e0 "뗠" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46561 0xb5e1 "뗡" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46562 0xb5e2 "뗢" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46563 0xb5e3 "뗣" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46564 0xb5e4 "뗤" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46565 0xb5e5 "뗥" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46566 0xb5e6 "뗦" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46567 0xb5e7 "뗧" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46568 0xb5e8 "뗨" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46569 0xb5e9 "뗩" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46570 0xb5ea "뗪" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46571 0xb5eb "뗫" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46572 0xb5ec "뗬" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46573 0xb5ed "뗭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46574 0xb5ee "뗮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46575 0xb5ef "뗯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46576 0xb5f0 "뗰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46577 0xb5f1 "뗱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46578 0xb5f2 "뗲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46579 0xb5f3 "뗳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46580 0xb5f4 "뗴" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 46581 0xb5f5 "뗵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46582 0xb5f6 "뗶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46583 0xb5f7 "뗷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46584 0xb5f8 "뗸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 46585 0xb5f9 "뗹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46586 0xb5fa "뗺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46587 0xb5fb "뗻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46588 0xb5fc "뗼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46589 0xb5fd "뗽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46590 0xb5fe "뗾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46591 0xb5ff "뗿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46592 0xb600 "똀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46593 0xb601 "똁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46594 0xb602 "똂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46595 0xb603 "똃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46596 0xb604 "똄" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46597 0xb605 "똅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46598 0xb606 "똆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46599 0xb607 "똇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46600 0xb608 "똈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46601 0xb609 "똉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46602 0xb60a "똊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46603 0xb60b "똋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46604 0xb60c "똌" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46605 0xb60d "똍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46606 0xb60e "똎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46607 0xb60f "똏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46608 0xb610 "또" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x3c,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 46609 0xb611 "똑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46610 0xb612 "똒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46611 0xb613 "똓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46612 0xb614 "똔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 46613 0xb615 "똕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46614 0xb616 "똖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46615 0xb617 "똗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46616 0xb618 "똘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46617 0xb619 "똙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46618 0xb61a "똚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46619 0xb61b "똛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46620 0xb61c "똜" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46621 0xb61d "똝" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46622 0xb61e "똞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46623 0xb61f "똟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46624 0xb620 "똠" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46625 0xb621 "똡" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46626 0xb622 "똢" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46627 0xb623 "똣" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46628 0xb624 "똤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46629 0xb625 "똥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46630 0xb626 "똦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46631 0xb627 "똧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46632 0xb628 "똨" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46633 0xb629 "똩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46634 0xb62a "똪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46635 0xb62b "똫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46636 0xb62c "똬" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 46637 0xb62d "똭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46638 0xb62e "똮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46639 0xb62f "똯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46640 0xb630 "똰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46641 0xb631 "똱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46642 0xb632 "똲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46643 0xb633 "똳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46644 0xb634 "똴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46645 0xb635 "똵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46646 0xb636 "똶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46647 0xb637 "똷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46648 0xb638 "똸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46649 0xb639 "똹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46650 0xb63a "똺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46651 0xb63b "똻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46652 0xb63c "똼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46653 0xb63d "똽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46654 0xb63e "똾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46655 0xb63f "똿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46656 0xb640 "뙀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46657 0xb641 "뙁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46658 0xb642 "뙂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46659 0xb643 "뙃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46660 0xb644 "뙄" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46661 0xb645 "뙅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46662 0xb646 "뙆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46663 0xb647 "뙇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46664 0xb648 "뙈" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 46665 0xb649 "뙉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46666 0xb64a "뙊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46667 0xb64b "뙋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46668 0xb64c "뙌" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 46669 0xb64d "뙍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46670 0xb64e "뙎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46671 0xb64f "뙏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46672 0xb650 "뙐" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46673 0xb651 "뙑" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46674 0xb652 "뙒" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46675 0xb653 "뙓" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46676 0xb654 "뙔" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46677 0xb655 "뙕" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46678 0xb656 "뙖" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46679 0xb657 "뙗" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46680 0xb658 "뙘" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46681 0xb659 "뙙" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46682 0xb65a "뙚" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46683 0xb65b "뙛" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46684 0xb65c "뙜" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46685 0xb65d "뙝" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46686 0xb65e "뙞" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46687 0xb65f "뙟" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46688 0xb660 "뙠" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46689 0xb661 "뙡" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46690 0xb662 "뙢" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46691 0xb663 "뙣" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46692 0xb664 "뙤" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 46693 0xb665 "뙥" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46694 0xb666 "뙦" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46695 0xb667 "뙧" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46696 0xb668 "뙨" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46697 0xb669 "뙩" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46698 0xb66a "뙪" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46699 0xb66b "뙫" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46700 0xb66c "뙬" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46701 0xb66d "뙭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46702 0xb66e "뙮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46703 0xb66f "뙯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46704 0xb670 "뙰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46705 0xb671 "뙱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46706 0xb672 "뙲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46707 0xb673 "뙳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46708 0xb674 "뙴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46709 0xb675 "뙵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46710 0xb676 "뙶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46711 0xb677 "뙷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46712 0xb678 "뙸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46713 0xb679 "뙹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46714 0xb67a "뙺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46715 0xb67b "뙻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46716 0xb67c "뙼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46717 0xb67d "뙽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46718 0xb67e "뙾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46719 0xb67f "뙿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46720 0xb680 "뚀" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x3c,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 46721 0xb681 "뚁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46722 0xb682 "뚂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46723 0xb683 "뚃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46724 0xb684 "뚄" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 46725 0xb685 "뚅" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46726 0xb686 "뚆" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46727 0xb687 "뚇" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46728 0xb688 "뚈" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46729 0xb689 "뚉" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46730 0xb68a "뚊" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46731 0xb68b "뚋" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46732 0xb68c "뚌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46733 0xb68d "뚍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46734 0xb68e "뚎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46735 0xb68f "뚏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46736 0xb690 "뚐" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46737 0xb691 "뚑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46738 0xb692 "뚒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46739 0xb693 "뚓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46740 0xb694 "뚔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46741 0xb695 "뚕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46742 0xb696 "뚖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46743 0xb697 "뚗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46744 0xb698 "뚘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46745 0xb699 "뚙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46746 0xb69a "뚚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46747 0xb69b "뚛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46748 0xb69c "뚜" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 46749 0xb69d "뚝" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 46750 0xb69e "뚞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 46751 0xb69f "뚟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46752 0xb6a0 "뚠" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 46753 0xb6a1 "뚡" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 46754 0xb6a2 "뚢" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 46755 0xb6a3 "뚣" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 46756 0xb6a4 "뚤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46757 0xb6a5 "뚥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 46758 0xb6a6 "뚦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 46759 0xb6a7 "뚧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 46760 0xb6a8 "뚨" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46761 0xb6a9 "뚩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46762 0xb6aa "뚪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 46763 0xb6ab "뚫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 46764 0xb6ac "뚬" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 46765 0xb6ad "뚭" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 46766 0xb6ae "뚮" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46767 0xb6af "뚯" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 46768 0xb6b0 "뚰" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 46769 0xb6b1 "뚱" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 46770 0xb6b2 "뚲" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 46771 0xb6b3 "뚳" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46772 0xb6b4 "뚴" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 46773 0xb6b5 "뚵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46774 0xb6b6 "뚶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 46775 0xb6b7 "뚷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46776 0xb6b8 "뚸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 46777 0xb6b9 "뚹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46778 0xb6ba "뚺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46779 0xb6bb "뚻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46780 0xb6bc "뚼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 46781 0xb6bd "뚽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46782 0xb6be "뚾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46783 0xb6bf "뚿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46784 0xb6c0 "뛀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46785 0xb6c1 "뛁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46786 0xb6c2 "뛂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46787 0xb6c3 "뛃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46788 0xb6c4 "뛄" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46789 0xb6c5 "뛅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46790 0xb6c6 "뛆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46791 0xb6c7 "뛇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46792 0xb6c8 "뛈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46793 0xb6c9 "뛉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46794 0xb6ca "뛊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46795 0xb6cb "뛋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46796 0xb6cc "뛌" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46797 0xb6cd "뛍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46798 0xb6ce "뛎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46799 0xb6cf "뛏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46800 0xb6d0 "뛐" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46801 0xb6d1 "뛑" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46802 0xb6d2 "뛒" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46803 0xb6d3 "뛓" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46804 0xb6d4 "뛔" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 46805 0xb6d5 "뛕" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 46806 0xb6d6 "뛖" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 46807 0xb6d7 "뛗" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46808 0xb6d8 "뛘" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 46809 0xb6d9 "뛙" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 46810 0xb6da "뛚" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 46811 0xb6db "뛛" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 46812 0xb6dc "뛜" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 46813 0xb6dd "뛝" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 46814 0xb6de "뛞" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 46815 0xb6df "뛟" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 46816 0xb6e0 "뛠" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 46817 0xb6e1 "뛡" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 46818 0xb6e2 "뛢" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 46819 0xb6e3 "뛣" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 46820 0xb6e4 "뛤" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 46821 0xb6e5 "뛥" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 46822 0xb6e6 "뛦" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 46823 0xb6e7 "뛧" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 46824 0xb6e8 "뛨" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 46825 0xb6e9 "뛩" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 46826 0xb6ea "뛪" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 46827 0xb6eb "뛫" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 46828 0xb6ec "뛬" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 46829 0xb6ed "뛭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 46830 0xb6ee "뛮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 46831 0xb6ef "뛯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 46832 0xb6f0 "뛰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 46833 0xb6f1 "뛱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46834 0xb6f2 "뛲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46835 0xb6f3 "뛳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46836 0xb6f4 "뛴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46837 0xb6f5 "뛵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46838 0xb6f6 "뛶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46839 0xb6f7 "뛷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46840 0xb6f8 "뛸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46841 0xb6f9 "뛹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46842 0xb6fa "뛺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46843 0xb6fb "뛻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46844 0xb6fc "뛼" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46845 0xb6fd "뛽" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46846 0xb6fe "뛾" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46847 0xb6ff "뛿" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46848 0xb700 "뜀" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46849 0xb701 "뜁" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46850 0xb702 "뜂" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46851 0xb703 "뜃" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46852 0xb704 "뜄" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46853 0xb705 "뜅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46854 0xb706 "뜆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46855 0xb707 "뜇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46856 0xb708 "뜈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46857 0xb709 "뜉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46858 0xb70a "뜊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46859 0xb70b "뜋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46860 0xb70c "뜌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 46861 0xb70d "뜍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 46862 0xb70e "뜎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 46863 0xb70f "뜏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46864 0xb710 "뜐" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 46865 0xb711 "뜑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 46866 0xb712 "뜒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 46867 0xb713 "뜓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 46868 0xb714 "뜔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46869 0xb715 "뜕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 46870 0xb716 "뜖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 46871 0xb717 "뜗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 46872 0xb718 "뜘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46873 0xb719 "뜙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46874 0xb71a "뜚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 46875 0xb71b "뜛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 46876 0xb71c "뜜" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 46877 0xb71d "뜝" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 46878 0xb71e "뜞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46879 0xb71f "뜟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 46880 0xb720 "뜠" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 46881 0xb721 "뜡" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 46882 0xb722 "뜢" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 46883 0xb723 "뜣" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46884 0xb724 "뜤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 46885 0xb725 "뜥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46886 0xb726 "뜦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 46887 0xb727 "뜧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46888 0xb728 "뜨" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x40,0x40,0x40,0x40,0x40,0x3c,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 46889 0xb729 "뜩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46890 0xb72a "뜪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46891 0xb72b "뜫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46892 0xb72c "뜬" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 46893 0xb72d "뜭" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46894 0xb72e "뜮" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46895 0xb72f "뜯" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46896 0xb730 "뜰" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46897 0xb731 "뜱" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46898 0xb732 "뜲" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46899 0xb733 "뜳" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46900 0xb734 "뜴" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46901 0xb735 "뜵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46902 0xb736 "뜶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46903 0xb737 "뜷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46904 0xb738 "뜸" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46905 0xb739 "뜹" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46906 0xb73a "뜺" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46907 0xb73b "뜻" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46908 0xb73c "뜼" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46909 0xb73d "뜽" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46910 0xb73e "뜾" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46911 0xb73f "뜿" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46912 0xb740 "띀" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46913 0xb741 "띁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46914 0xb742 "띂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46915 0xb743 "띃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x40,0x40,0x40,0x3c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46916 0xb744 "띄" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 46917 0xb745 "띅" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46918 0xb746 "띆" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46919 0xb747 "띇" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46920 0xb748 "띈" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46921 0xb749 "띉" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46922 0xb74a "띊" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46923 0xb74b "띋" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46924 0xb74c "띌" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46925 0xb74d "띍" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46926 0xb74e "띎" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46927 0xb74f "띏" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46928 0xb750 "띐" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46929 0xb751 "띑" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46930 0xb752 "띒" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46931 0xb753 "띓" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46932 0xb754 "띔" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46933 0xb755 "띕" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46934 0xb756 "띖" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46935 0xb757 "띗" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46936 0xb758 "띘" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46937 0xb759 "띙" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46938 0xb75a "띚" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46939 0xb75b "띛" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46940 0xb75c "띜" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46941 0xb75d "띝" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46942 0xb75e "띞" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46943 0xb75f "띟" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x19,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46944 0xb760 "띠" */
+0x00,0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46945 0xb761 "띡" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46946 0xb762 "띢" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46947 0xb763 "띣" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46948 0xb764 "띤" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46949 0xb765 "띥" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46950 0xb766 "띦" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46951 0xb767 "띧" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46952 0xb768 "띨" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46953 0xb769 "띩" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46954 0xb76a "띪" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46955 0xb76b "띫" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46956 0xb76c "띬" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46957 0xb76d "띭" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46958 0xb76e "띮" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46959 0xb76f "띯" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46960 0xb770 "띰" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46961 0xb771 "띱" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46962 0xb772 "띲" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46963 0xb773 "띳" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46964 0xb774 "띴" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46965 0xb775 "띵" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46966 0xb776 "띶" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46967 0xb777 "띷" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46968 0xb778 "띸" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46969 0xb779 "띹" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46970 0xb77a "띺" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46971 0xb77b "띻" */
+0x00,0x00,0x3b,0x22,0x22,0x22,0x22,0x22,0x19,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 46972 0xb77c "라" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 46973 0xb77d "락" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 46974 0xb77e "띾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46975 0xb77f "띿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46976 0xb780 "란" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 46977 0xb781 "랁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 46978 0xb782 "랂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46979 0xb783 "랃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 46980 0xb784 "랄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 46981 0xb785 "랅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 46982 0xb786 "랆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 46983 0xb787 "랇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 46984 0xb788 "랈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46985 0xb789 "랉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 46986 0xb78a "랊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 46987 0xb78b "랋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 46988 0xb78c "람" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 46989 0xb78d "랍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 46990 0xb78e "랎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46991 0xb78f "랏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 46992 0xb790 "랐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 46993 0xb791 "랑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 46994 0xb792 "랒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 46995 0xb793 "랓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 46996 0xb794 "랔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 46997 0xb795 "랕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 46998 0xb796 "랖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 46999 0xb797 "랗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47000 0xb798 "래" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 47001 0xb799 "랙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47002 0xb79a "랚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47003 0xb79b "랛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47004 0xb79c "랜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47005 0xb79d "랝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47006 0xb79e "랞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47007 0xb79f "랟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47008 0xb7a0 "랠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47009 0xb7a1 "랡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47010 0xb7a2 "랢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47011 0xb7a3 "랣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47012 0xb7a4 "랤" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47013 0xb7a5 "랥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47014 0xb7a6 "랦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47015 0xb7a7 "랧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47016 0xb7a8 "램" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47017 0xb7a9 "랩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47018 0xb7aa "랪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47019 0xb7ab "랫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47020 0xb7ac "랬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47021 0xb7ad "랭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47022 0xb7ae "랮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47023 0xb7af "랯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47024 0xb7b0 "랰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47025 0xb7b1 "랱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47026 0xb7b2 "랲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47027 0xb7b3 "랳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47028 0xb7b4 "랴" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 47029 0xb7b5 "략" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47030 0xb7b6 "랶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47031 0xb7b7 "랷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47032 0xb7b8 "랸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47033 0xb7b9 "랹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47034 0xb7ba "랺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47035 0xb7bb "랻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47036 0xb7bc "랼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47037 0xb7bd "랽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47038 0xb7be "랾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47039 0xb7bf "랿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47040 0xb7c0 "럀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47041 0xb7c1 "럁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47042 0xb7c2 "럂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47043 0xb7c3 "럃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47044 0xb7c4 "럄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47045 0xb7c5 "럅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47046 0xb7c6 "럆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47047 0xb7c7 "럇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47048 0xb7c8 "럈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47049 0xb7c9 "량" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47050 0xb7ca "럊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47051 0xb7cb "럋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47052 0xb7cc "럌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47053 0xb7cd "럍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47054 0xb7ce "럎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47055 0xb7cf "럏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47056 0xb7d0 "럐" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 47057 0xb7d1 "럑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47058 0xb7d2 "럒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47059 0xb7d3 "럓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47060 0xb7d4 "럔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47061 0xb7d5 "럕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47062 0xb7d6 "럖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47063 0xb7d7 "럗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47064 0xb7d8 "럘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47065 0xb7d9 "럙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47066 0xb7da "럚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47067 0xb7db "럛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47068 0xb7dc "럜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47069 0xb7dd "럝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47070 0xb7de "럞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47071 0xb7df "럟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47072 0xb7e0 "럠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47073 0xb7e1 "럡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47074 0xb7e2 "럢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47075 0xb7e3 "럣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47076 0xb7e4 "럤" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47077 0xb7e5 "럥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47078 0xb7e6 "럦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47079 0xb7e7 "럧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47080 0xb7e8 "럨" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47081 0xb7e9 "럩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47082 0xb7ea "럪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47083 0xb7eb "럫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47084 0xb7ec "러" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 47085 0xb7ed "럭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47086 0xb7ee "럮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47087 0xb7ef "럯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47088 0xb7f0 "런" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47089 0xb7f1 "럱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47090 0xb7f2 "럲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47091 0xb7f3 "럳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47092 0xb7f4 "럴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47093 0xb7f5 "럵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47094 0xb7f6 "럶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47095 0xb7f7 "럷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47096 0xb7f8 "럸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47097 0xb7f9 "럹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47098 0xb7fa "럺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47099 0xb7fb "럻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47100 0xb7fc "럼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47101 0xb7fd "럽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47102 0xb7fe "럾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47103 0xb7ff "럿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47104 0xb800 "렀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47105 0xb801 "렁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47106 0xb802 "렂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47107 0xb803 "렃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47108 0xb804 "렄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47109 0xb805 "렅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47110 0xb806 "렆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47111 0xb807 "렇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47112 0xb808 "레" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 47113 0xb809 "렉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47114 0xb80a "렊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47115 0xb80b "렋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47116 0xb80c "렌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47117 0xb80d "렍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47118 0xb80e "렎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47119 0xb80f "렏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47120 0xb810 "렐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47121 0xb811 "렑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47122 0xb812 "렒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47123 0xb813 "렓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47124 0xb814 "렔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47125 0xb815 "렕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47126 0xb816 "렖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47127 0xb817 "렗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47128 0xb818 "렘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47129 0xb819 "렙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47130 0xb81a "렚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47131 0xb81b "렛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47132 0xb81c "렜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47133 0xb81d "렝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47134 0xb81e "렞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47135 0xb81f "렟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47136 0xb820 "렠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47137 0xb821 "렡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47138 0xb822 "렢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47139 0xb823 "렣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47140 0xb824 "려" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 47141 0xb825 "력" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47142 0xb826 "렦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47143 0xb827 "렧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47144 0xb828 "련" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47145 0xb829 "렩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47146 0xb82a "렪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47147 0xb82b "렫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47148 0xb82c "렬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47149 0xb82d "렭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47150 0xb82e "렮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47151 0xb82f "렯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47152 0xb830 "렰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47153 0xb831 "렱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47154 0xb832 "렲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47155 0xb833 "렳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47156 0xb834 "렴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47157 0xb835 "렵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47158 0xb836 "렶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47159 0xb837 "렷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47160 0xb838 "렸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47161 0xb839 "령" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47162 0xb83a "렺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47163 0xb83b "렻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47164 0xb83c "렼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47165 0xb83d "렽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47166 0xb83e "렾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47167 0xb83f "렿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47168 0xb840 "례" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 47169 0xb841 "롁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47170 0xb842 "롂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47171 0xb843 "롃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47172 0xb844 "롄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47173 0xb845 "롅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47174 0xb846 "롆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47175 0xb847 "롇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47176 0xb848 "롈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47177 0xb849 "롉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47178 0xb84a "롊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47179 0xb84b "롋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47180 0xb84c "롌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47181 0xb84d "롍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47182 0xb84e "롎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47183 0xb84f "롏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47184 0xb850 "롐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47185 0xb851 "롑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47186 0xb852 "롒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47187 0xb853 "롓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47188 0xb854 "롔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47189 0xb855 "롕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47190 0xb856 "롖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47191 0xb857 "롗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47192 0xb858 "롘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47193 0xb859 "롙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47194 0xb85a "롚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47195 0xb85b "롛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47196 0xb85c "로" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xf8,0x00,0x00,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 47197 0xb85d "록" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47198 0xb85e "롞" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47199 0xb85f "롟" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47200 0xb860 "론" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 47201 0xb861 "롡" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47202 0xb862 "롢" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47203 0xb863 "롣" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47204 0xb864 "롤" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47205 0xb865 "롥" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47206 0xb866 "롦" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47207 0xb867 "롧" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47208 0xb868 "롨" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47209 0xb869 "롩" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47210 0xb86a "롪" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47211 0xb86b "롫" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47212 0xb86c "롬" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47213 0xb86d "롭" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47214 0xb86e "롮" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47215 0xb86f "롯" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47216 0xb870 "롰" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47217 0xb871 "롱" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47218 0xb872 "롲" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47219 0xb873 "롳" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47220 0xb874 "롴" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47221 0xb875 "롵" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47222 0xb876 "롶" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47223 0xb877 "롷" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47224 0xb878 "롸" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 47225 0xb879 "롹" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47226 0xb87a "롺" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47227 0xb87b "롻" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47228 0xb87c "롼" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47229 0xb87d "롽" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47230 0xb87e "롾" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47231 0xb87f "롿" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47232 0xb880 "뢀" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47233 0xb881 "뢁" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47234 0xb882 "뢂" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47235 0xb883 "뢃" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47236 0xb884 "뢄" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47237 0xb885 "뢅" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47238 0xb886 "뢆" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47239 0xb887 "뢇" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47240 0xb888 "뢈" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47241 0xb889 "뢉" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47242 0xb88a "뢊" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47243 0xb88b "뢋" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47244 0xb88c "뢌" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47245 0xb88d "뢍" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47246 0xb88e "뢎" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47247 0xb88f "뢏" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47248 0xb890 "뢐" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47249 0xb891 "뢑" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47250 0xb892 "뢒" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47251 0xb893 "뢓" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47252 0xb894 "뢔" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 47253 0xb895 "뢕" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47254 0xb896 "뢖" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47255 0xb897 "뢗" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47256 0xb898 "뢘" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47257 0xb899 "뢙" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47258 0xb89a "뢚" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47259 0xb89b "뢛" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47260 0xb89c "뢜" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47261 0xb89d "뢝" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47262 0xb89e "뢞" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47263 0xb89f "뢟" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47264 0xb8a0 "뢠" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47265 0xb8a1 "뢡" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47266 0xb8a2 "뢢" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47267 0xb8a3 "뢣" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47268 0xb8a4 "뢤" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47269 0xb8a5 "뢥" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47270 0xb8a6 "뢦" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47271 0xb8a7 "뢧" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47272 0xb8a8 "뢨" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47273 0xb8a9 "뢩" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47274 0xb8aa "뢪" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47275 0xb8ab "뢫" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47276 0xb8ac "뢬" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47277 0xb8ad "뢭" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47278 0xb8ae "뢮" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47279 0xb8af "뢯" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47280 0xb8b0 "뢰" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 47281 0xb8b1 "뢱" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47282 0xb8b2 "뢲" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47283 0xb8b3 "뢳" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47284 0xb8b4 "뢴" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47285 0xb8b5 "뢵" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47286 0xb8b6 "뢶" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47287 0xb8b7 "뢷" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47288 0xb8b8 "뢸" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47289 0xb8b9 "뢹" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47290 0xb8ba "뢺" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47291 0xb8bb "뢻" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47292 0xb8bc "뢼" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47293 0xb8bd "뢽" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47294 0xb8be "뢾" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47295 0xb8bf "뢿" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47296 0xb8c0 "룀" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47297 0xb8c1 "룁" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47298 0xb8c2 "룂" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47299 0xb8c3 "룃" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47300 0xb8c4 "룄" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47301 0xb8c5 "룅" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47302 0xb8c6 "룆" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47303 0xb8c7 "룇" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47304 0xb8c8 "룈" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47305 0xb8c9 "룉" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47306 0xb8ca "룊" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47307 0xb8cb "룋" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47308 0xb8cc "료" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x1f,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xf8,0x00,0x00,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 47309 0xb8cd "룍" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47310 0xb8ce "룎" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47311 0xb8cf "룏" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47312 0xb8d0 "룐" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 47313 0xb8d1 "룑" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47314 0xb8d2 "룒" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47315 0xb8d3 "룓" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47316 0xb8d4 "룔" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47317 0xb8d5 "룕" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47318 0xb8d6 "룖" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47319 0xb8d7 "룗" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47320 0xb8d8 "룘" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47321 0xb8d9 "룙" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47322 0xb8da "룚" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47323 0xb8db "룛" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47324 0xb8dc "룜" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47325 0xb8dd "룝" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47326 0xb8de "룞" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47327 0xb8df "룟" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47328 0xb8e0 "룠" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47329 0xb8e1 "룡" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47330 0xb8e2 "룢" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47331 0xb8e3 "룣" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47332 0xb8e4 "룤" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47333 0xb8e5 "룥" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47334 0xb8e6 "룦" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47335 0xb8e7 "룧" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47336 0xb8e8 "루" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 47337 0xb8e9 "룩" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 47338 0xb8ea "룪" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 47339 0xb8eb "룫" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47340 0xb8ec "룬" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 47341 0xb8ed "룭" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 47342 0xb8ee "룮" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 47343 0xb8ef "룯" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 47344 0xb8f0 "룰" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47345 0xb8f1 "룱" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 47346 0xb8f2 "룲" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 47347 0xb8f3 "룳" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 47348 0xb8f4 "룴" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47349 0xb8f5 "룵" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47350 0xb8f6 "룶" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 47351 0xb8f7 "룷" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 47352 0xb8f8 "룸" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 47353 0xb8f9 "룹" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 47354 0xb8fa "룺" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47355 0xb8fb "룻" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 47356 0xb8fc "룼" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47357 0xb8fd "룽" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 47358 0xb8fe "룾" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 47359 0xb8ff "룿" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47360 0xb900 "뤀" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 47361 0xb901 "뤁" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47362 0xb902 "뤂" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 47363 0xb903 "뤃" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47364 0xb904 "뤄" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 47365 0xb905 "뤅" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47366 0xb906 "뤆" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47367 0xb907 "뤇" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47368 0xb908 "뤈" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 47369 0xb909 "뤉" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47370 0xb90a "뤊" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47371 0xb90b "뤋" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47372 0xb90c "뤌" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47373 0xb90d "뤍" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47374 0xb90e "뤎" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47375 0xb90f "뤏" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47376 0xb910 "뤐" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47377 0xb911 "뤑" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47378 0xb912 "뤒" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47379 0xb913 "뤓" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47380 0xb914 "뤔" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47381 0xb915 "뤕" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47382 0xb916 "뤖" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47383 0xb917 "뤗" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47384 0xb918 "뤘" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47385 0xb919 "뤙" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47386 0xb91a "뤚" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47387 0xb91b "뤛" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47388 0xb91c "뤜" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47389 0xb91d "뤝" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47390 0xb91e "뤞" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47391 0xb91f "뤟" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47392 0xb920 "뤠" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 47393 0xb921 "뤡" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47394 0xb922 "뤢" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47395 0xb923 "뤣" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47396 0xb924 "뤤" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 47397 0xb925 "뤥" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47398 0xb926 "뤦" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47399 0xb927 "뤧" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47400 0xb928 "뤨" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47401 0xb929 "뤩" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47402 0xb92a "뤪" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47403 0xb92b "뤫" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47404 0xb92c "뤬" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47405 0xb92d "뤭" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47406 0xb92e "뤮" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47407 0xb92f "뤯" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47408 0xb930 "뤰" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47409 0xb931 "뤱" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47410 0xb932 "뤲" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47411 0xb933 "뤳" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47412 0xb934 "뤴" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47413 0xb935 "뤵" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47414 0xb936 "뤶" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47415 0xb937 "뤷" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47416 0xb938 "뤸" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47417 0xb939 "뤹" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47418 0xb93a "뤺" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47419 0xb93b "뤻" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47420 0xb93c "뤼" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 47421 0xb93d "뤽" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47422 0xb93e "뤾" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47423 0xb93f "뤿" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47424 0xb940 "륀" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47425 0xb941 "륁" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47426 0xb942 "륂" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47427 0xb943 "륃" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47428 0xb944 "륄" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47429 0xb945 "륅" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47430 0xb946 "륆" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47431 0xb947 "륇" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47432 0xb948 "륈" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47433 0xb949 "륉" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47434 0xb94a "륊" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47435 0xb94b "륋" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47436 0xb94c "륌" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47437 0xb94d "륍" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47438 0xb94e "륎" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47439 0xb94f "륏" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47440 0xb950 "륐" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47441 0xb951 "륑" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47442 0xb952 "륒" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47443 0xb953 "륓" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47444 0xb954 "륔" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47445 0xb955 "륕" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47446 0xb956 "륖" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47447 0xb957 "륗" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47448 0xb958 "류" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 47449 0xb959 "륙" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 47450 0xb95a "륚" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 47451 0xb95b "륛" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 47452 0xb95c "륜" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 47453 0xb95d "륝" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 47454 0xb95e "륞" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 47455 0xb95f "륟" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 47456 0xb960 "률" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47457 0xb961 "륡" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 47458 0xb962 "륢" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 47459 0xb963 "륣" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 47460 0xb964 "륤" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 47461 0xb965 "륥" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47462 0xb966 "륦" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 47463 0xb967 "륧" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 47464 0xb968 "륨" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 47465 0xb969 "륩" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 47466 0xb96a "륪" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 47467 0xb96b "륫" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 47468 0xb96c "륬" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 47469 0xb96d "륭" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 47470 0xb96e "륮" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 47471 0xb96f "륯" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47472 0xb970 "륰" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 47473 0xb971 "륱" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47474 0xb972 "륲" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 47475 0xb973 "륳" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47476 0xb974 "르" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xf8,0x00,0x00,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 47477 0xb975 "륵" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47478 0xb976 "륶" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47479 0xb977 "륷" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47480 0xb978 "른" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 47481 0xb979 "륹" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47482 0xb97a "륺" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47483 0xb97b "륻" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47484 0xb97c "를" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47485 0xb97d "륽" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47486 0xb97e "륾" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47487 0xb97f "륿" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47488 0xb980 "릀" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47489 0xb981 "릁" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47490 0xb982 "릂" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47491 0xb983 "릃" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47492 0xb984 "름" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47493 0xb985 "릅" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47494 0xb986 "릆" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47495 0xb987 "릇" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47496 0xb988 "릈" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47497 0xb989 "릉" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47498 0xb98a "릊" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47499 0xb98b "릋" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47500 0xb98c "릌" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47501 0xb98d "릍" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47502 0xb98e "릎" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47503 0xb98f "릏" */
+0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47504 0xb990 "릐" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 47505 0xb991 "릑" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47506 0xb992 "릒" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47507 0xb993 "릓" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47508 0xb994 "릔" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47509 0xb995 "릕" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47510 0xb996 "릖" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47511 0xb997 "릗" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47512 0xb998 "릘" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47513 0xb999 "릙" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47514 0xb99a "릚" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47515 0xb99b "릛" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47516 0xb99c "릜" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47517 0xb99d "릝" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47518 0xb99e "릞" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47519 0xb99f "릟" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47520 0xb9a0 "릠" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47521 0xb9a1 "릡" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47522 0xb9a2 "릢" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47523 0xb9a3 "릣" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47524 0xb9a4 "릤" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47525 0xb9a5 "릥" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47526 0xb9a6 "릦" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47527 0xb9a7 "릧" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47528 0xb9a8 "릨" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47529 0xb9a9 "릩" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47530 0xb9aa "릪" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47531 0xb9ab "릫" */
+0x00,0x00,0x3f,0x00,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47532 0xb9ac "리" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 47533 0xb9ad "릭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47534 0xb9ae "릮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47535 0xb9af "릯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47536 0xb9b0 "린" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47537 0xb9b1 "릱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47538 0xb9b2 "릲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47539 0xb9b3 "릳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47540 0xb9b4 "릴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47541 0xb9b5 "릵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47542 0xb9b6 "릶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47543 0xb9b7 "릷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47544 0xb9b8 "릸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47545 0xb9b9 "릹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47546 0xb9ba "릺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47547 0xb9bb "릻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47548 0xb9bc "림" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47549 0xb9bd "립" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47550 0xb9be "릾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47551 0xb9bf "릿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47552 0xb9c0 "맀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47553 0xb9c1 "링" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47554 0xb9c2 "맂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47555 0xb9c3 "맃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47556 0xb9c4 "맄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47557 0xb9c5 "맅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47558 0xb9c6 "맆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47559 0xb9c7 "맇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47560 0xb9c8 "마" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 47561 0xb9c9 "막" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47562 0xb9ca "맊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47563 0xb9cb "맋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47564 0xb9cc "만" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47565 0xb9cd "맍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47566 0xb9ce "많" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47567 0xb9cf "맏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47568 0xb9d0 "말" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47569 0xb9d1 "맑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47570 0xb9d2 "맒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47571 0xb9d3 "맓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47572 0xb9d4 "맔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47573 0xb9d5 "맕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47574 0xb9d6 "맖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47575 0xb9d7 "맗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47576 0xb9d8 "맘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47577 0xb9d9 "맙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47578 0xb9da "맚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47579 0xb9db "맛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47580 0xb9dc "맜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47581 0xb9dd "망" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47582 0xb9de "맞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47583 0xb9df "맟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47584 0xb9e0 "맠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47585 0xb9e1 "맡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47586 0xb9e2 "맢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47587 0xb9e3 "맣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47588 0xb9e4 "매" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 47589 0xb9e5 "맥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47590 0xb9e6 "맦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47591 0xb9e7 "맧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47592 0xb9e8 "맨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47593 0xb9e9 "맩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47594 0xb9ea "맪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47595 0xb9eb "맫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47596 0xb9ec "맬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47597 0xb9ed "맭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47598 0xb9ee "맮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47599 0xb9ef "맯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47600 0xb9f0 "맰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47601 0xb9f1 "맱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47602 0xb9f2 "맲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47603 0xb9f3 "맳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47604 0xb9f4 "맴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47605 0xb9f5 "맵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47606 0xb9f6 "맶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47607 0xb9f7 "맷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47608 0xb9f8 "맸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47609 0xb9f9 "맹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47610 0xb9fa "맺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47611 0xb9fb "맻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47612 0xb9fc "맼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47613 0xb9fd "맽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47614 0xb9fe "맾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47615 0xb9ff "맿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47616 0xba00 "먀" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 47617 0xba01 "먁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47618 0xba02 "먂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47619 0xba03 "먃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47620 0xba04 "먄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47621 0xba05 "먅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47622 0xba06 "먆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47623 0xba07 "먇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47624 0xba08 "먈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47625 0xba09 "먉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47626 0xba0a "먊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47627 0xba0b "먋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47628 0xba0c "먌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47629 0xba0d "먍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47630 0xba0e "먎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47631 0xba0f "먏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47632 0xba10 "먐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47633 0xba11 "먑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47634 0xba12 "먒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47635 0xba13 "먓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47636 0xba14 "먔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47637 0xba15 "먕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47638 0xba16 "먖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47639 0xba17 "먗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47640 0xba18 "먘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47641 0xba19 "먙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47642 0xba1a "먚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47643 0xba1b "먛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47644 0xba1c "먜" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 47645 0xba1d "먝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47646 0xba1e "먞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47647 0xba1f "먟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47648 0xba20 "먠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47649 0xba21 "먡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47650 0xba22 "먢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47651 0xba23 "먣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47652 0xba24 "먤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47653 0xba25 "먥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47654 0xba26 "먦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47655 0xba27 "먧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47656 0xba28 "먨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47657 0xba29 "먩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47658 0xba2a "먪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47659 0xba2b "먫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47660 0xba2c "먬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47661 0xba2d "먭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47662 0xba2e "먮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47663 0xba2f "먯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47664 0xba30 "먰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47665 0xba31 "먱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47666 0xba32 "먲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47667 0xba33 "먳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47668 0xba34 "먴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47669 0xba35 "먵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47670 0xba36 "먶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47671 0xba37 "먷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47672 0xba38 "머" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 47673 0xba39 "먹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47674 0xba3a "먺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47675 0xba3b "먻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47676 0xba3c "먼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47677 0xba3d "먽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47678 0xba3e "먾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47679 0xba3f "먿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47680 0xba40 "멀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47681 0xba41 "멁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47682 0xba42 "멂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47683 0xba43 "멃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47684 0xba44 "멄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47685 0xba45 "멅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47686 0xba46 "멆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47687 0xba47 "멇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47688 0xba48 "멈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47689 0xba49 "멉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47690 0xba4a "멊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47691 0xba4b "멋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47692 0xba4c "멌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47693 0xba4d "멍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47694 0xba4e "멎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47695 0xba4f "멏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47696 0xba50 "멐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47697 0xba51 "멑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47698 0xba52 "멒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47699 0xba53 "멓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47700 0xba54 "메" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 47701 0xba55 "멕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47702 0xba56 "멖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47703 0xba57 "멗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47704 0xba58 "멘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47705 0xba59 "멙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47706 0xba5a "멚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47707 0xba5b "멛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47708 0xba5c "멜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47709 0xba5d "멝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47710 0xba5e "멞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47711 0xba5f "멟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47712 0xba60 "멠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47713 0xba61 "멡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47714 0xba62 "멢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47715 0xba63 "멣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47716 0xba64 "멤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47717 0xba65 "멥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47718 0xba66 "멦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47719 0xba67 "멧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47720 0xba68 "멨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47721 0xba69 "멩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47722 0xba6a "멪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47723 0xba6b "멫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47724 0xba6c "멬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47725 0xba6d "멭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47726 0xba6e "멮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47727 0xba6f "멯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47728 0xba70 "며" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 47729 0xba71 "멱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47730 0xba72 "멲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47731 0xba73 "멳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47732 0xba74 "면" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47733 0xba75 "멵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47734 0xba76 "멶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47735 0xba77 "멷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47736 0xba78 "멸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47737 0xba79 "멹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47738 0xba7a "멺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47739 0xba7b "멻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47740 0xba7c "멼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47741 0xba7d "멽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47742 0xba7e "멾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47743 0xba7f "멿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47744 0xba80 "몀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47745 0xba81 "몁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47746 0xba82 "몂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47747 0xba83 "몃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47748 0xba84 "몄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47749 0xba85 "명" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47750 0xba86 "몆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47751 0xba87 "몇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47752 0xba88 "몈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47753 0xba89 "몉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47754 0xba8a "몊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47755 0xba8b "몋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47756 0xba8c "몌" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 47757 0xba8d "몍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47758 0xba8e "몎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47759 0xba8f "몏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47760 0xba90 "몐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47761 0xba91 "몑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47762 0xba92 "몒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47763 0xba93 "몓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47764 0xba94 "몔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47765 0xba95 "몕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47766 0xba96 "몖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47767 0xba97 "몗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47768 0xba98 "몘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47769 0xba99 "몙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47770 0xba9a "몚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47771 0xba9b "몛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47772 0xba9c "몜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47773 0xba9d "몝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47774 0xba9e "몞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47775 0xba9f "몟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47776 0xbaa0 "몠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47777 0xbaa1 "몡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47778 0xbaa2 "몢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47779 0xbaa3 "몣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47780 0xbaa4 "몤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47781 0xbaa5 "몥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47782 0xbaa6 "몦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47783 0xbaa7 "몧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47784 0xbaa8 "모" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 47785 0xbaa9 "목" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47786 0xbaaa "몪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47787 0xbaab "몫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47788 0xbaac "몬" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 47789 0xbaad "몭" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47790 0xbaae "몮" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47791 0xbaaf "몯" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47792 0xbab0 "몰" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47793 0xbab1 "몱" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47794 0xbab2 "몲" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47795 0xbab3 "몳" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47796 0xbab4 "몴" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47797 0xbab5 "몵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47798 0xbab6 "몶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47799 0xbab7 "몷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47800 0xbab8 "몸" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47801 0xbab9 "몹" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47802 0xbaba "몺" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47803 0xbabb "못" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47804 0xbabc "몼" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47805 0xbabd "몽" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47806 0xbabe "몾" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47807 0xbabf "몿" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47808 0xbac0 "뫀" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47809 0xbac1 "뫁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47810 0xbac2 "뫂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47811 0xbac3 "뫃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47812 0xbac4 "뫄" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 47813 0xbac5 "뫅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47814 0xbac6 "뫆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47815 0xbac7 "뫇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47816 0xbac8 "뫈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47817 0xbac9 "뫉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47818 0xbaca "뫊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47819 0xbacb "뫋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47820 0xbacc "뫌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47821 0xbacd "뫍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47822 0xbace "뫎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47823 0xbacf "뫏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47824 0xbad0 "뫐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47825 0xbad1 "뫑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47826 0xbad2 "뫒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47827 0xbad3 "뫓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47828 0xbad4 "뫔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47829 0xbad5 "뫕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47830 0xbad6 "뫖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47831 0xbad7 "뫗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47832 0xbad8 "뫘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47833 0xbad9 "뫙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47834 0xbada "뫚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47835 0xbadb "뫛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47836 0xbadc "뫜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47837 0xbadd "뫝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47838 0xbade "뫞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47839 0xbadf "뫟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47840 0xbae0 "뫠" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 47841 0xbae1 "뫡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47842 0xbae2 "뫢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47843 0xbae3 "뫣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47844 0xbae4 "뫤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 47845 0xbae5 "뫥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47846 0xbae6 "뫦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47847 0xbae7 "뫧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47848 0xbae8 "뫨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47849 0xbae9 "뫩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47850 0xbaea "뫪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47851 0xbaeb "뫫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47852 0xbaec "뫬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47853 0xbaed "뫭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47854 0xbaee "뫮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47855 0xbaef "뫯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47856 0xbaf0 "뫰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47857 0xbaf1 "뫱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47858 0xbaf2 "뫲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47859 0xbaf3 "뫳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 47860 0xbaf4 "뫴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 47861 0xbaf5 "뫵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 47862 0xbaf6 "뫶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 47863 0xbaf7 "뫷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 47864 0xbaf8 "뫸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 47865 0xbaf9 "뫹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 47866 0xbafa "뫺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 47867 0xbafb "뫻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 47868 0xbafc "뫼" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 47869 0xbafd "뫽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47870 0xbafe "뫾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47871 0xbaff "뫿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47872 0xbb00 "묀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 47873 0xbb01 "묁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47874 0xbb02 "묂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47875 0xbb03 "묃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47876 0xbb04 "묄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47877 0xbb05 "묅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47878 0xbb06 "묆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47879 0xbb07 "묇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47880 0xbb08 "묈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47881 0xbb09 "묉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47882 0xbb0a "묊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47883 0xbb0b "묋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47884 0xbb0c "묌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47885 0xbb0d "묍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47886 0xbb0e "묎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47887 0xbb0f "묏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47888 0xbb10 "묐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47889 0xbb11 "묑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47890 0xbb12 "묒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47891 0xbb13 "묓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47892 0xbb14 "묔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47893 0xbb15 "묕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47894 0xbb16 "묖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47895 0xbb17 "묗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47896 0xbb18 "묘" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 47897 0xbb19 "묙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47898 0xbb1a "묚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47899 0xbb1b "묛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47900 0xbb1c "묜" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 47901 0xbb1d "묝" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47902 0xbb1e "묞" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47903 0xbb1f "묟" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47904 0xbb20 "묠" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47905 0xbb21 "묡" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47906 0xbb22 "묢" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47907 0xbb23 "묣" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47908 0xbb24 "묤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47909 0xbb25 "묥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47910 0xbb26 "묦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47911 0xbb27 "묧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47912 0xbb28 "묨" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47913 0xbb29 "묩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47914 0xbb2a "묪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47915 0xbb2b "묫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47916 0xbb2c "묬" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47917 0xbb2d "묭" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47918 0xbb2e "묮" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47919 0xbb2f "묯" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47920 0xbb30 "묰" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47921 0xbb31 "묱" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47922 0xbb32 "묲" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47923 0xbb33 "묳" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47924 0xbb34 "무" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 47925 0xbb35 "묵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 47926 0xbb36 "묶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 47927 0xbb37 "묷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47928 0xbb38 "문" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 47929 0xbb39 "묹" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 47930 0xbb3a "묺" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 47931 0xbb3b "묻" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 47932 0xbb3c "물" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47933 0xbb3d "묽" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 47934 0xbb3e "묾" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 47935 0xbb3f "묿" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 47936 0xbb40 "뭀" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47937 0xbb41 "뭁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47938 0xbb42 "뭂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 47939 0xbb43 "뭃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 47940 0xbb44 "뭄" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 47941 0xbb45 "뭅" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 47942 0xbb46 "뭆" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47943 0xbb47 "뭇" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 47944 0xbb48 "뭈" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 47945 0xbb49 "뭉" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 47946 0xbb4a "뭊" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 47947 0xbb4b "뭋" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47948 0xbb4c "뭌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 47949 0xbb4d "뭍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47950 0xbb4e "뭎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 47951 0xbb4f "뭏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47952 0xbb50 "뭐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 47953 0xbb51 "뭑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 47954 0xbb52 "뭒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47955 0xbb53 "뭓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47956 0xbb54 "뭔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 47957 0xbb55 "뭕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 47958 0xbb56 "뭖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47959 0xbb57 "뭗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 47960 0xbb58 "뭘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 47961 0xbb59 "뭙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 47962 0xbb5a "뭚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 47963 0xbb5b "뭛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 47964 0xbb5c "뭜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47965 0xbb5d "뭝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 47966 0xbb5e "뭞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 47967 0xbb5f "뭟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 47968 0xbb60 "뭠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 47969 0xbb61 "뭡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 47970 0xbb62 "뭢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47971 0xbb63 "뭣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 47972 0xbb64 "뭤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 47973 0xbb65 "뭥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 47974 0xbb66 "뭦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 47975 0xbb67 "뭧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 47976 0xbb68 "뭨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 47977 0xbb69 "뭩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 47978 0xbb6a "뭪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 47979 0xbb6b "뭫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 47980 0xbb6c "뭬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 47981 0xbb6d "뭭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 47982 0xbb6e "뭮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 47983 0xbb6f "뭯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47984 0xbb70 "뭰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 47985 0xbb71 "뭱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 47986 0xbb72 "뭲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 47987 0xbb73 "뭳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 47988 0xbb74 "뭴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 47989 0xbb75 "뭵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 47990 0xbb76 "뭶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 47991 0xbb77 "뭷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 47992 0xbb78 "뭸" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 47993 0xbb79 "뭹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 47994 0xbb7a "뭺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 47995 0xbb7b "뭻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 47996 0xbb7c "뭼" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 47997 0xbb7d "뭽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 47998 0xbb7e "뭾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 47999 0xbb7f "뭿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48000 0xbb80 "뮀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48001 0xbb81 "뮁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48002 0xbb82 "뮂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48003 0xbb83 "뮃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48004 0xbb84 "뮄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48005 0xbb85 "뮅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48006 0xbb86 "뮆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48007 0xbb87 "뮇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48008 0xbb88 "뮈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 48009 0xbb89 "뮉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48010 0xbb8a "뮊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48011 0xbb8b "뮋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48012 0xbb8c "뮌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48013 0xbb8d "뮍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48014 0xbb8e "뮎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48015 0xbb8f "뮏" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48016 0xbb90 "뮐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48017 0xbb91 "뮑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48018 0xbb92 "뮒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48019 0xbb93 "뮓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48020 0xbb94 "뮔" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48021 0xbb95 "뮕" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48022 0xbb96 "뮖" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48023 0xbb97 "뮗" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48024 0xbb98 "뮘" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48025 0xbb99 "뮙" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48026 0xbb9a "뮚" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48027 0xbb9b "뮛" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48028 0xbb9c "뮜" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48029 0xbb9d "뮝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48030 0xbb9e "뮞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48031 0xbb9f "뮟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48032 0xbba0 "뮠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48033 0xbba1 "뮡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48034 0xbba2 "뮢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48035 0xbba3 "뮣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48036 0xbba4 "뮤" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 48037 0xbba5 "뮥" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 48038 0xbba6 "뮦" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 48039 0xbba7 "뮧" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48040 0xbba8 "뮨" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 48041 0xbba9 "뮩" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 48042 0xbbaa "뮪" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 48043 0xbbab "뮫" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 48044 0xbbac "뮬" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48045 0xbbad "뮭" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 48046 0xbbae "뮮" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 48047 0xbbaf "뮯" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 48048 0xbbb0 "뮰" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48049 0xbbb1 "뮱" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48050 0xbbb2 "뮲" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 48051 0xbbb3 "뮳" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 48052 0xbbb4 "뮴" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 48053 0xbbb5 "뮵" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 48054 0xbbb6 "뮶" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48055 0xbbb7 "뮷" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 48056 0xbbb8 "뮸" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48057 0xbbb9 "뮹" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 48058 0xbbba "뮺" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 48059 0xbbbb "뮻" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48060 0xbbbc "뮼" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 48061 0xbbbd "뮽" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48062 0xbbbe "뮾" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 48063 0xbbbf "뮿" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48064 0xbbc0 "므" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,0x04,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 48065 0xbbc1 "믁" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48066 0xbbc2 "믂" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48067 0xbbc3 "믃" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48068 0xbbc4 "믄" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 48069 0xbbc5 "믅" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48070 0xbbc6 "믆" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48071 0xbbc7 "믇" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48072 0xbbc8 "믈" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48073 0xbbc9 "믉" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48074 0xbbca "믊" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48075 0xbbcb "믋" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48076 0xbbcc "믌" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48077 0xbbcd "믍" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48078 0xbbce "믎" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48079 0xbbcf "믏" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48080 0xbbd0 "믐" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48081 0xbbd1 "믑" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48082 0xbbd2 "믒" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48083 0xbbd3 "믓" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48084 0xbbd4 "믔" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48085 0xbbd5 "믕" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48086 0xbbd6 "믖" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48087 0xbbd7 "믗" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48088 0xbbd8 "믘" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48089 0xbbd9 "믙" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48090 0xbbda "믚" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48091 0xbbdb "믛" */
+0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48092 0xbbdc "믜" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 48093 0xbbdd "믝" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48094 0xbbde "믞" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48095 0xbbdf "믟" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48096 0xbbe0 "믠" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48097 0xbbe1 "믡" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48098 0xbbe2 "믢" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48099 0xbbe3 "믣" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48100 0xbbe4 "믤" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48101 0xbbe5 "믥" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48102 0xbbe6 "믦" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48103 0xbbe7 "믧" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48104 0xbbe8 "믨" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48105 0xbbe9 "믩" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48106 0xbbea "믪" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48107 0xbbeb "믫" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48108 0xbbec "믬" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48109 0xbbed "믭" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48110 0xbbee "믮" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48111 0xbbef "믯" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48112 0xbbf0 "믰" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48113 0xbbf1 "믱" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48114 0xbbf2 "믲" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48115 0xbbf3 "믳" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48116 0xbbf4 "믴" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48117 0xbbf5 "믵" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48118 0xbbf6 "믶" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48119 0xbbf7 "믷" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48120 0xbbf8 "미" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48121 0xbbf9 "믹" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48122 0xbbfa "믺" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48123 0xbbfb "믻" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48124 0xbbfc "민" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48125 0xbbfd "믽" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48126 0xbbfe "믾" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48127 0xbbff "믿" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48128 0xbc00 "밀" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48129 0xbc01 "밁" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48130 0xbc02 "밂" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48131 0xbc03 "밃" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48132 0xbc04 "밄" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48133 0xbc05 "밅" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48134 0xbc06 "밆" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48135 0xbc07 "밇" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48136 0xbc08 "밈" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48137 0xbc09 "밉" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48138 0xbc0a "밊" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48139 0xbc0b "밋" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48140 0xbc0c "밌" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48141 0xbc0d "밍" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48142 0xbc0e "밎" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48143 0xbc0f "및" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48144 0xbc10 "밐" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48145 0xbc11 "밑" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48146 0xbc12 "밒" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48147 0xbc13 "밓" */
+0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48148 0xbc14 "바" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48149 0xbc15 "박" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48150 0xbc16 "밖" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48151 0xbc17 "밗" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48152 0xbc18 "반" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48153 0xbc19 "밙" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48154 0xbc1a "밚" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48155 0xbc1b "받" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48156 0xbc1c "발" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48157 0xbc1d "밝" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48158 0xbc1e "밞" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48159 0xbc1f "밟" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48160 0xbc20 "밠" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48161 0xbc21 "밡" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48162 0xbc22 "밢" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48163 0xbc23 "밣" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48164 0xbc24 "밤" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48165 0xbc25 "밥" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48166 0xbc26 "밦" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48167 0xbc27 "밧" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48168 0xbc28 "밨" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48169 0xbc29 "방" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48170 0xbc2a "밪" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48171 0xbc2b "밫" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48172 0xbc2c "밬" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48173 0xbc2d "밭" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48174 0xbc2e "밮" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48175 0xbc2f "밯" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48176 0xbc30 "배" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48177 0xbc31 "백" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48178 0xbc32 "밲" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48179 0xbc33 "밳" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48180 0xbc34 "밴" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48181 0xbc35 "밵" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48182 0xbc36 "밶" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48183 0xbc37 "밷" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48184 0xbc38 "밸" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48185 0xbc39 "밹" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48186 0xbc3a "밺" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48187 0xbc3b "밻" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48188 0xbc3c "밼" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48189 0xbc3d "밽" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48190 0xbc3e "밾" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48191 0xbc3f "밿" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48192 0xbc40 "뱀" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48193 0xbc41 "뱁" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48194 0xbc42 "뱂" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48195 0xbc43 "뱃" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48196 0xbc44 "뱄" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48197 0xbc45 "뱅" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48198 0xbc46 "뱆" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48199 0xbc47 "뱇" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48200 0xbc48 "뱈" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48201 0xbc49 "뱉" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48202 0xbc4a "뱊" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48203 0xbc4b "뱋" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48204 0xbc4c "뱌" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48205 0xbc4d "뱍" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48206 0xbc4e "뱎" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48207 0xbc4f "뱏" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48208 0xbc50 "뱐" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48209 0xbc51 "뱑" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48210 0xbc52 "뱒" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48211 0xbc53 "뱓" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48212 0xbc54 "뱔" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48213 0xbc55 "뱕" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48214 0xbc56 "뱖" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48215 0xbc57 "뱗" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48216 0xbc58 "뱘" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48217 0xbc59 "뱙" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48218 0xbc5a "뱚" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48219 0xbc5b "뱛" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48220 0xbc5c "뱜" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48221 0xbc5d "뱝" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48222 0xbc5e "뱞" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48223 0xbc5f "뱟" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48224 0xbc60 "뱠" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48225 0xbc61 "뱡" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48226 0xbc62 "뱢" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48227 0xbc63 "뱣" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48228 0xbc64 "뱤" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48229 0xbc65 "뱥" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48230 0xbc66 "뱦" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48231 0xbc67 "뱧" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48232 0xbc68 "뱨" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48233 0xbc69 "뱩" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48234 0xbc6a "뱪" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48235 0xbc6b "뱫" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48236 0xbc6c "뱬" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48237 0xbc6d "뱭" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48238 0xbc6e "뱮" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48239 0xbc6f "뱯" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48240 0xbc70 "뱰" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48241 0xbc71 "뱱" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48242 0xbc72 "뱲" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48243 0xbc73 "뱳" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48244 0xbc74 "뱴" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48245 0xbc75 "뱵" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48246 0xbc76 "뱶" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48247 0xbc77 "뱷" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48248 0xbc78 "뱸" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48249 0xbc79 "뱹" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48250 0xbc7a "뱺" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48251 0xbc7b "뱻" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48252 0xbc7c "뱼" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48253 0xbc7d "뱽" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48254 0xbc7e "뱾" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48255 0xbc7f "뱿" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48256 0xbc80 "벀" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48257 0xbc81 "벁" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48258 0xbc82 "벂" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48259 0xbc83 "벃" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48260 0xbc84 "버" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48261 0xbc85 "벅" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48262 0xbc86 "벆" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48263 0xbc87 "벇" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48264 0xbc88 "번" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48265 0xbc89 "벉" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48266 0xbc8a "벊" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48267 0xbc8b "벋" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48268 0xbc8c "벌" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48269 0xbc8d "벍" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48270 0xbc8e "벎" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48271 0xbc8f "벏" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48272 0xbc90 "벐" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48273 0xbc91 "벑" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48274 0xbc92 "벒" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48275 0xbc93 "벓" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48276 0xbc94 "범" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48277 0xbc95 "법" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48278 0xbc96 "벖" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48279 0xbc97 "벗" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48280 0xbc98 "벘" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48281 0xbc99 "벙" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48282 0xbc9a "벚" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48283 0xbc9b "벛" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48284 0xbc9c "벜" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48285 0xbc9d "벝" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48286 0xbc9e "벞" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48287 0xbc9f "벟" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48288 0xbca0 "베" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48289 0xbca1 "벡" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48290 0xbca2 "벢" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48291 0xbca3 "벣" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48292 0xbca4 "벤" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48293 0xbca5 "벥" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48294 0xbca6 "벦" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48295 0xbca7 "벧" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48296 0xbca8 "벨" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48297 0xbca9 "벩" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48298 0xbcaa "벪" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48299 0xbcab "벫" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48300 0xbcac "벬" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48301 0xbcad "벭" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48302 0xbcae "벮" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48303 0xbcaf "벯" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48304 0xbcb0 "벰" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48305 0xbcb1 "벱" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48306 0xbcb2 "벲" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48307 0xbcb3 "벳" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48308 0xbcb4 "벴" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48309 0xbcb5 "벵" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48310 0xbcb6 "벶" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48311 0xbcb7 "벷" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48312 0xbcb8 "벸" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48313 0xbcb9 "벹" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48314 0xbcba "벺" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48315 0xbcbb "벻" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48316 0xbcbc "벼" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48317 0xbcbd "벽" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48318 0xbcbe "벾" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48319 0xbcbf "벿" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48320 0xbcc0 "변" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48321 0xbcc1 "볁" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48322 0xbcc2 "볂" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48323 0xbcc3 "볃" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48324 0xbcc4 "별" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48325 0xbcc5 "볅" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48326 0xbcc6 "볆" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48327 0xbcc7 "볇" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48328 0xbcc8 "볈" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48329 0xbcc9 "볉" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48330 0xbcca "볊" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48331 0xbccb "볋" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48332 0xbccc "볌" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48333 0xbccd "볍" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48334 0xbcce "볎" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48335 0xbccf "볏" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48336 0xbcd0 "볐" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48337 0xbcd1 "병" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48338 0xbcd2 "볒" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48339 0xbcd3 "볓" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48340 0xbcd4 "볔" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48341 0xbcd5 "볕" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48342 0xbcd6 "볖" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48343 0xbcd7 "볗" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48344 0xbcd8 "볘" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48345 0xbcd9 "볙" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48346 0xbcda "볚" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48347 0xbcdb "볛" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48348 0xbcdc "볜" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48349 0xbcdd "볝" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48350 0xbcde "볞" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48351 0xbcdf "볟" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48352 0xbce0 "볠" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48353 0xbce1 "볡" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48354 0xbce2 "볢" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48355 0xbce3 "볣" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48356 0xbce4 "볤" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48357 0xbce5 "볥" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48358 0xbce6 "볦" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48359 0xbce7 "볧" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48360 0xbce8 "볨" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48361 0xbce9 "볩" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48362 0xbcea "볪" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48363 0xbceb "볫" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48364 0xbcec "볬" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48365 0xbced "볭" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48366 0xbcee "볮" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48367 0xbcef "볯" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48368 0xbcf0 "볰" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48369 0xbcf1 "볱" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48370 0xbcf2 "볲" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48371 0xbcf3 "볳" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48372 0xbcf4 "보" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x04,0x04,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 48373 0xbcf5 "복" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48374 0xbcf6 "볶" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48375 0xbcf7 "볷" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48376 0xbcf8 "본" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 48377 0xbcf9 "볹" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48378 0xbcfa "볺" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48379 0xbcfb "볻" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48380 0xbcfc "볼" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48381 0xbcfd "볽" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48382 0xbcfe "볾" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48383 0xbcff "볿" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48384 0xbd00 "봀" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48385 0xbd01 "봁" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48386 0xbd02 "봂" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48387 0xbd03 "봃" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48388 0xbd04 "봄" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48389 0xbd05 "봅" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48390 0xbd06 "봆" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48391 0xbd07 "봇" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48392 0xbd08 "봈" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48393 0xbd09 "봉" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48394 0xbd0a "봊" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48395 0xbd0b "봋" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48396 0xbd0c "봌" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48397 0xbd0d "봍" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48398 0xbd0e "봎" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48399 0xbd0f "봏" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48400 0xbd10 "봐" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 48401 0xbd11 "봑" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48402 0xbd12 "봒" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48403 0xbd13 "봓" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48404 0xbd14 "봔" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48405 0xbd15 "봕" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48406 0xbd16 "봖" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48407 0xbd17 "봗" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48408 0xbd18 "봘" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48409 0xbd19 "봙" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48410 0xbd1a "봚" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48411 0xbd1b "봛" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48412 0xbd1c "봜" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48413 0xbd1d "봝" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48414 0xbd1e "봞" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48415 0xbd1f "봟" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48416 0xbd20 "봠" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48417 0xbd21 "봡" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48418 0xbd22 "봢" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48419 0xbd23 "봣" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48420 0xbd24 "봤" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48421 0xbd25 "봥" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48422 0xbd26 "봦" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48423 0xbd27 "봧" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48424 0xbd28 "봨" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48425 0xbd29 "봩" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48426 0xbd2a "봪" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48427 0xbd2b "봫" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48428 0xbd2c "봬" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 48429 0xbd2d "봭" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48430 0xbd2e "봮" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48431 0xbd2f "봯" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48432 0xbd30 "봰" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48433 0xbd31 "봱" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48434 0xbd32 "봲" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48435 0xbd33 "봳" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48436 0xbd34 "봴" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48437 0xbd35 "봵" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48438 0xbd36 "봶" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48439 0xbd37 "봷" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48440 0xbd38 "봸" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48441 0xbd39 "봹" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48442 0xbd3a "봺" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48443 0xbd3b "봻" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48444 0xbd3c "봼" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48445 0xbd3d "봽" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48446 0xbd3e "봾" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48447 0xbd3f "봿" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48448 0xbd40 "뵀" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48449 0xbd41 "뵁" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48450 0xbd42 "뵂" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48451 0xbd43 "뵃" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48452 0xbd44 "뵄" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48453 0xbd45 "뵅" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48454 0xbd46 "뵆" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48455 0xbd47 "뵇" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48456 0xbd48 "뵈" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 48457 0xbd49 "뵉" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48458 0xbd4a "뵊" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48459 0xbd4b "뵋" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48460 0xbd4c "뵌" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48461 0xbd4d "뵍" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48462 0xbd4e "뵎" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48463 0xbd4f "뵏" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48464 0xbd50 "뵐" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48465 0xbd51 "뵑" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48466 0xbd52 "뵒" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48467 0xbd53 "뵓" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48468 0xbd54 "뵔" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48469 0xbd55 "뵕" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48470 0xbd56 "뵖" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48471 0xbd57 "뵗" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48472 0xbd58 "뵘" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48473 0xbd59 "뵙" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48474 0xbd5a "뵚" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48475 0xbd5b "뵛" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48476 0xbd5c "뵜" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48477 0xbd5d "뵝" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48478 0xbd5e "뵞" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48479 0xbd5f "뵟" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48480 0xbd60 "뵠" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48481 0xbd61 "뵡" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48482 0xbd62 "뵢" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48483 0xbd63 "뵣" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48484 0xbd64 "뵤" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x04,0x04,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 48485 0xbd65 "뵥" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48486 0xbd66 "뵦" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48487 0xbd67 "뵧" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48488 0xbd68 "뵨" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 48489 0xbd69 "뵩" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48490 0xbd6a "뵪" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48491 0xbd6b "뵫" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48492 0xbd6c "뵬" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48493 0xbd6d "뵭" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48494 0xbd6e "뵮" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48495 0xbd6f "뵯" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48496 0xbd70 "뵰" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48497 0xbd71 "뵱" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48498 0xbd72 "뵲" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48499 0xbd73 "뵳" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48500 0xbd74 "뵴" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48501 0xbd75 "뵵" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48502 0xbd76 "뵶" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48503 0xbd77 "뵷" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48504 0xbd78 "뵸" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48505 0xbd79 "뵹" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48506 0xbd7a "뵺" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48507 0xbd7b "뵻" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48508 0xbd7c "뵼" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48509 0xbd7d "뵽" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48510 0xbd7e "뵾" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48511 0xbd7f "뵿" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48512 0xbd80 "부" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 48513 0xbd81 "북" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 48514 0xbd82 "붂" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 48515 0xbd83 "붃" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 48516 0xbd84 "분" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 48517 0xbd85 "붅" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 48518 0xbd86 "붆" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 48519 0xbd87 "붇" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 48520 0xbd88 "불" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48521 0xbd89 "붉" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 48522 0xbd8a "붊" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 48523 0xbd8b "붋" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 48524 0xbd8c "붌" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 48525 0xbd8d "붍" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48526 0xbd8e "붎" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 48527 0xbd8f "붏" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 48528 0xbd90 "붐" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 48529 0xbd91 "붑" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 48530 0xbd92 "붒" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 48531 0xbd93 "붓" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 48532 0xbd94 "붔" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 48533 0xbd95 "붕" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 48534 0xbd96 "붖" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 48535 0xbd97 "붗" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48536 0xbd98 "붘" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 48537 0xbd99 "붙" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48538 0xbd9a "붚" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 48539 0xbd9b "붛" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48540 0xbd9c "붜" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 48541 0xbd9d "붝" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48542 0xbd9e "붞" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48543 0xbd9f "붟" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48544 0xbda0 "붠" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 48545 0xbda1 "붡" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48546 0xbda2 "붢" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48547 0xbda3 "붣" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48548 0xbda4 "붤" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48549 0xbda5 "붥" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48550 0xbda6 "붦" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48551 0xbda7 "붧" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48552 0xbda8 "붨" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48553 0xbda9 "붩" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48554 0xbdaa "붪" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48555 0xbdab "붫" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48556 0xbdac "붬" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48557 0xbdad "붭" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48558 0xbdae "붮" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48559 0xbdaf "붯" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48560 0xbdb0 "붰" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48561 0xbdb1 "붱" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48562 0xbdb2 "붲" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48563 0xbdb3 "붳" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48564 0xbdb4 "붴" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48565 0xbdb5 "붵" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48566 0xbdb6 "붶" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48567 0xbdb7 "붷" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48568 0xbdb8 "붸" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 48569 0xbdb9 "붹" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48570 0xbdba "붺" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48571 0xbdbb "붻" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48572 0xbdbc "붼" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 48573 0xbdbd "붽" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48574 0xbdbe "붾" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48575 0xbdbf "붿" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48576 0xbdc0 "뷀" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48577 0xbdc1 "뷁" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48578 0xbdc2 "뷂" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48579 0xbdc3 "뷃" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48580 0xbdc4 "뷄" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48581 0xbdc5 "뷅" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48582 0xbdc6 "뷆" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48583 0xbdc7 "뷇" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48584 0xbdc8 "뷈" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48585 0xbdc9 "뷉" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48586 0xbdca "뷊" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48587 0xbdcb "뷋" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48588 0xbdcc "뷌" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48589 0xbdcd "뷍" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48590 0xbdce "뷎" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48591 0xbdcf "뷏" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48592 0xbdd0 "뷐" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48593 0xbdd1 "뷑" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48594 0xbdd2 "뷒" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48595 0xbdd3 "뷓" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48596 0xbdd4 "뷔" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 48597 0xbdd5 "뷕" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48598 0xbdd6 "뷖" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48599 0xbdd7 "뷗" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48600 0xbdd8 "뷘" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48601 0xbdd9 "뷙" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48602 0xbdda "뷚" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48603 0xbddb "뷛" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48604 0xbddc "뷜" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48605 0xbddd "뷝" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48606 0xbdde "뷞" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48607 0xbddf "뷟" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48608 0xbde0 "뷠" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48609 0xbde1 "뷡" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48610 0xbde2 "뷢" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48611 0xbde3 "뷣" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48612 0xbde4 "뷤" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48613 0xbde5 "뷥" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48614 0xbde6 "뷦" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48615 0xbde7 "뷧" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48616 0xbde8 "뷨" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48617 0xbde9 "뷩" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48618 0xbdea "뷪" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48619 0xbdeb "뷫" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48620 0xbdec "뷬" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48621 0xbded "뷭" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48622 0xbdee "뷮" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48623 0xbdef "뷯" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48624 0xbdf0 "뷰" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 48625 0xbdf1 "뷱" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 48626 0xbdf2 "뷲" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 48627 0xbdf3 "뷳" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48628 0xbdf4 "뷴" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 48629 0xbdf5 "뷵" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 48630 0xbdf6 "뷶" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 48631 0xbdf7 "뷷" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 48632 0xbdf8 "뷸" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48633 0xbdf9 "뷹" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 48634 0xbdfa "뷺" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 48635 0xbdfb "뷻" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 48636 0xbdfc "뷼" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48637 0xbdfd "뷽" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48638 0xbdfe "뷾" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 48639 0xbdff "뷿" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 48640 0xbe00 "븀" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 48641 0xbe01 "븁" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 48642 0xbe02 "븂" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48643 0xbe03 "븃" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 48644 0xbe04 "븄" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 48645 0xbe05 "븅" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 48646 0xbe06 "븆" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 48647 0xbe07 "븇" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48648 0xbe08 "븈" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 48649 0xbe09 "븉" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48650 0xbe0a "븊" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 48651 0xbe0b "븋" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48652 0xbe0c "브" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0xfc,0x04,0x04,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 48653 0xbe0d "븍" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48654 0xbe0e "븎" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48655 0xbe0f "븏" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48656 0xbe10 "븐" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 48657 0xbe11 "븑" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48658 0xbe12 "븒" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48659 0xbe13 "븓" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48660 0xbe14 "블" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48661 0xbe15 "븕" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48662 0xbe16 "븖" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48663 0xbe17 "븗" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48664 0xbe18 "븘" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48665 0xbe19 "븙" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48666 0xbe1a "븚" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48667 0xbe1b "븛" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48668 0xbe1c "븜" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48669 0xbe1d "븝" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48670 0xbe1e "븞" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48671 0xbe1f "븟" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48672 0xbe20 "븠" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48673 0xbe21 "븡" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48674 0xbe22 "븢" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48675 0xbe23 "븣" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48676 0xbe24 "븤" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48677 0xbe25 "븥" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48678 0xbe26 "븦" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48679 0xbe27 "븧" */
+0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48680 0xbe28 "븨" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 48681 0xbe29 "븩" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48682 0xbe2a "븪" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48683 0xbe2b "븫" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48684 0xbe2c "븬" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48685 0xbe2d "븭" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48686 0xbe2e "븮" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48687 0xbe2f "븯" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48688 0xbe30 "븰" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48689 0xbe31 "븱" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48690 0xbe32 "븲" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48691 0xbe33 "븳" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48692 0xbe34 "븴" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48693 0xbe35 "븵" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48694 0xbe36 "븶" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48695 0xbe37 "븷" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48696 0xbe38 "븸" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48697 0xbe39 "븹" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48698 0xbe3a "븺" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48699 0xbe3b "븻" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48700 0xbe3c "븼" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48701 0xbe3d "븽" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48702 0xbe3e "븾" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48703 0xbe3f "븿" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48704 0xbe40 "빀" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48705 0xbe41 "빁" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48706 0xbe42 "빂" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48707 0xbe43 "빃" */
+0x00,0x00,0x20,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48708 0xbe44 "비" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48709 0xbe45 "빅" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48710 0xbe46 "빆" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48711 0xbe47 "빇" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48712 0xbe48 "빈" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48713 0xbe49 "빉" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48714 0xbe4a "빊" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48715 0xbe4b "빋" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48716 0xbe4c "빌" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48717 0xbe4d "빍" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48718 0xbe4e "빎" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48719 0xbe4f "빏" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48720 0xbe50 "빐" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48721 0xbe51 "빑" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48722 0xbe52 "빒" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48723 0xbe53 "빓" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48724 0xbe54 "빔" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48725 0xbe55 "빕" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48726 0xbe56 "빖" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48727 0xbe57 "빗" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48728 0xbe58 "빘" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48729 0xbe59 "빙" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48730 0xbe5a "빚" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48731 0xbe5b "빛" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48732 0xbe5c "빜" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48733 0xbe5d "빝" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48734 0xbe5e "빞" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48735 0xbe5f "빟" */
+0x00,0x00,0x20,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48736 0xbe60 "빠" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48737 0xbe61 "빡" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48738 0xbe62 "빢" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48739 0xbe63 "빣" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48740 0xbe64 "빤" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48741 0xbe65 "빥" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48742 0xbe66 "빦" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48743 0xbe67 "빧" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48744 0xbe68 "빨" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48745 0xbe69 "빩" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48746 0xbe6a "빪" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48747 0xbe6b "빫" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48748 0xbe6c "빬" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48749 0xbe6d "빭" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48750 0xbe6e "빮" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48751 0xbe6f "빯" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48752 0xbe70 "빰" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48753 0xbe71 "빱" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48754 0xbe72 "빲" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48755 0xbe73 "빳" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48756 0xbe74 "빴" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48757 0xbe75 "빵" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48758 0xbe76 "빶" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48759 0xbe77 "빷" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48760 0xbe78 "빸" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48761 0xbe79 "빹" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48762 0xbe7a "빺" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48763 0xbe7b "빻" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48764 0xbe7c "빼" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48765 0xbe7d "빽" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48766 0xbe7e "빾" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48767 0xbe7f "빿" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48768 0xbe80 "뺀" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48769 0xbe81 "뺁" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48770 0xbe82 "뺂" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48771 0xbe83 "뺃" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48772 0xbe84 "뺄" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48773 0xbe85 "뺅" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48774 0xbe86 "뺆" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48775 0xbe87 "뺇" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48776 0xbe88 "뺈" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48777 0xbe89 "뺉" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48778 0xbe8a "뺊" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48779 0xbe8b "뺋" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48780 0xbe8c "뺌" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48781 0xbe8d "뺍" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48782 0xbe8e "뺎" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48783 0xbe8f "뺏" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48784 0xbe90 "뺐" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48785 0xbe91 "뺑" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48786 0xbe92 "뺒" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48787 0xbe93 "뺓" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48788 0xbe94 "뺔" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48789 0xbe95 "뺕" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48790 0xbe96 "뺖" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48791 0xbe97 "뺗" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48792 0xbe98 "뺘" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48793 0xbe99 "뺙" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48794 0xbe9a "뺚" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48795 0xbe9b "뺛" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48796 0xbe9c "뺜" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48797 0xbe9d "뺝" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48798 0xbe9e "뺞" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48799 0xbe9f "뺟" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48800 0xbea0 "뺠" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48801 0xbea1 "뺡" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48802 0xbea2 "뺢" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48803 0xbea3 "뺣" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48804 0xbea4 "뺤" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48805 0xbea5 "뺥" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48806 0xbea6 "뺦" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48807 0xbea7 "뺧" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48808 0xbea8 "뺨" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48809 0xbea9 "뺩" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48810 0xbeaa "뺪" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48811 0xbeab "뺫" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48812 0xbeac "뺬" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48813 0xbead "뺭" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48814 0xbeae "뺮" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48815 0xbeaf "뺯" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48816 0xbeb0 "뺰" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48817 0xbeb1 "뺱" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48818 0xbeb2 "뺲" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48819 0xbeb3 "뺳" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48820 0xbeb4 "뺴" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48821 0xbeb5 "뺵" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48822 0xbeb6 "뺶" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48823 0xbeb7 "뺷" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48824 0xbeb8 "뺸" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48825 0xbeb9 "뺹" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48826 0xbeba "뺺" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48827 0xbebb "뺻" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48828 0xbebc "뺼" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48829 0xbebd "뺽" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48830 0xbebe "뺾" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48831 0xbebf "뺿" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48832 0xbec0 "뻀" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48833 0xbec1 "뻁" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48834 0xbec2 "뻂" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48835 0xbec3 "뻃" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48836 0xbec4 "뻄" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48837 0xbec5 "뻅" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48838 0xbec6 "뻆" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48839 0xbec7 "뻇" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48840 0xbec8 "뻈" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48841 0xbec9 "뻉" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48842 0xbeca "뻊" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48843 0xbecb "뻋" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48844 0xbecc "뻌" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48845 0xbecd "뻍" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48846 0xbece "뻎" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48847 0xbecf "뻏" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48848 0xbed0 "뻐" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48849 0xbed1 "뻑" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48850 0xbed2 "뻒" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48851 0xbed3 "뻓" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48852 0xbed4 "뻔" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48853 0xbed5 "뻕" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48854 0xbed6 "뻖" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48855 0xbed7 "뻗" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48856 0xbed8 "뻘" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48857 0xbed9 "뻙" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48858 0xbeda "뻚" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48859 0xbedb "뻛" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48860 0xbedc "뻜" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48861 0xbedd "뻝" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48862 0xbede "뻞" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48863 0xbedf "뻟" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48864 0xbee0 "뻠" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48865 0xbee1 "뻡" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48866 0xbee2 "뻢" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48867 0xbee3 "뻣" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48868 0xbee4 "뻤" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48869 0xbee5 "뻥" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48870 0xbee6 "뻦" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48871 0xbee7 "뻧" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48872 0xbee8 "뻨" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48873 0xbee9 "뻩" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48874 0xbeea "뻪" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48875 0xbeeb "뻫" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48876 0xbeec "뻬" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48877 0xbeed "뻭" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48878 0xbeee "뻮" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48879 0xbeef "뻯" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48880 0xbef0 "뻰" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48881 0xbef1 "뻱" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48882 0xbef2 "뻲" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48883 0xbef3 "뻳" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48884 0xbef4 "뻴" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48885 0xbef5 "뻵" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48886 0xbef6 "뻶" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48887 0xbef7 "뻷" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48888 0xbef8 "뻸" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48889 0xbef9 "뻹" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48890 0xbefa "뻺" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48891 0xbefb "뻻" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48892 0xbefc "뻼" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48893 0xbefd "뻽" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48894 0xbefe "뻾" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48895 0xbeff "뻿" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48896 0xbf00 "뼀" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48897 0xbf01 "뼁" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48898 0xbf02 "뼂" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48899 0xbf03 "뼃" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48900 0xbf04 "뼄" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48901 0xbf05 "뼅" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48902 0xbf06 "뼆" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48903 0xbf07 "뼇" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48904 0xbf08 "뼈" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 48905 0xbf09 "뼉" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48906 0xbf0a "뼊" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48907 0xbf0b "뼋" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48908 0xbf0c "뼌" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48909 0xbf0d "뼍" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48910 0xbf0e "뼎" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48911 0xbf0f "뼏" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48912 0xbf10 "뼐" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48913 0xbf11 "뼑" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48914 0xbf12 "뼒" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48915 0xbf13 "뼓" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48916 0xbf14 "뼔" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48917 0xbf15 "뼕" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48918 0xbf16 "뼖" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48919 0xbf17 "뼗" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48920 0xbf18 "뼘" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48921 0xbf19 "뼙" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48922 0xbf1a "뼚" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48923 0xbf1b "뼛" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48924 0xbf1c "뼜" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48925 0xbf1d "뼝" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48926 0xbf1e "뼞" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48927 0xbf1f "뼟" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48928 0xbf20 "뼠" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48929 0xbf21 "뼡" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48930 0xbf22 "뼢" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48931 0xbf23 "뼣" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48932 0xbf24 "뼤" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,
+/* 48933 0xbf25 "뼥" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 48934 0xbf26 "뼦" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 48935 0xbf27 "뼧" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48936 0xbf28 "뼨" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 48937 0xbf29 "뼩" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 48938 0xbf2a "뼪" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 48939 0xbf2b "뼫" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 48940 0xbf2c "뼬" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 48941 0xbf2d "뼭" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 48942 0xbf2e "뼮" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 48943 0xbf2f "뼯" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 48944 0xbf30 "뼰" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 48945 0xbf31 "뼱" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 48946 0xbf32 "뼲" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 48947 0xbf33 "뼳" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 48948 0xbf34 "뼴" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 48949 0xbf35 "뼵" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 48950 0xbf36 "뼶" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 48951 0xbf37 "뼷" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 48952 0xbf38 "뼸" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 48953 0xbf39 "뼹" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 48954 0xbf3a "뼺" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 48955 0xbf3b "뼻" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 48956 0xbf3c "뼼" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 48957 0xbf3d "뼽" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 48958 0xbf3e "뼾" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 48959 0xbf3f "뼿" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 48960 0xbf40 "뽀" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x44,0x44,0x44,0x7c,0x44,0x44,0x3c,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 48961 0xbf41 "뽁" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48962 0xbf42 "뽂" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48963 0xbf43 "뽃" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48964 0xbf44 "뽄" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 48965 0xbf45 "뽅" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48966 0xbf46 "뽆" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48967 0xbf47 "뽇" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48968 0xbf48 "뽈" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48969 0xbf49 "뽉" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48970 0xbf4a "뽊" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48971 0xbf4b "뽋" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 48972 0xbf4c "뽌" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48973 0xbf4d "뽍" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 48974 0xbf4e "뽎" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 48975 0xbf4f "뽏" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48976 0xbf50 "뽐" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 48977 0xbf51 "뽑" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 48978 0xbf52 "뽒" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48979 0xbf53 "뽓" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 48980 0xbf54 "뽔" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48981 0xbf55 "뽕" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 48982 0xbf56 "뽖" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 48983 0xbf57 "뽗" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 48984 0xbf58 "뽘" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 48985 0xbf59 "뽙" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 48986 0xbf5a "뽚" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 48987 0xbf5b "뽛" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 48988 0xbf5c "뽜" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 48989 0xbf5d "뽝" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 48990 0xbf5e "뽞" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48991 0xbf5f "뽟" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 48992 0xbf60 "뽠" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 48993 0xbf61 "뽡" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 48994 0xbf62 "뽢" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 48995 0xbf63 "뽣" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 48996 0xbf64 "뽤" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 48997 0xbf65 "뽥" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 48998 0xbf66 "뽦" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 48999 0xbf67 "뽧" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49000 0xbf68 "뽨" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49001 0xbf69 "뽩" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49002 0xbf6a "뽪" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49003 0xbf6b "뽫" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49004 0xbf6c "뽬" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49005 0xbf6d "뽭" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49006 0xbf6e "뽮" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49007 0xbf6f "뽯" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49008 0xbf70 "뽰" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49009 0xbf71 "뽱" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49010 0xbf72 "뽲" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49011 0xbf73 "뽳" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49012 0xbf74 "뽴" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49013 0xbf75 "뽵" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49014 0xbf76 "뽶" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49015 0xbf77 "뽷" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49016 0xbf78 "뽸" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 49017 0xbf79 "뽹" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49018 0xbf7a "뽺" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49019 0xbf7b "뽻" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49020 0xbf7c "뽼" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49021 0xbf7d "뽽" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49022 0xbf7e "뽾" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49023 0xbf7f "뽿" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49024 0xbf80 "뾀" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49025 0xbf81 "뾁" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49026 0xbf82 "뾂" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49027 0xbf83 "뾃" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49028 0xbf84 "뾄" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49029 0xbf85 "뾅" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49030 0xbf86 "뾆" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49031 0xbf87 "뾇" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49032 0xbf88 "뾈" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49033 0xbf89 "뾉" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49034 0xbf8a "뾊" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49035 0xbf8b "뾋" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49036 0xbf8c "뾌" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49037 0xbf8d "뾍" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49038 0xbf8e "뾎" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49039 0xbf8f "뾏" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49040 0xbf90 "뾐" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49041 0xbf91 "뾑" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49042 0xbf92 "뾒" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49043 0xbf93 "뾓" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49044 0xbf94 "뾔" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 49045 0xbf95 "뾕" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49046 0xbf96 "뾖" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49047 0xbf97 "뾗" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49048 0xbf98 "뾘" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49049 0xbf99 "뾙" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49050 0xbf9a "뾚" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49051 0xbf9b "뾛" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49052 0xbf9c "뾜" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49053 0xbf9d "뾝" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49054 0xbf9e "뾞" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49055 0xbf9f "뾟" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49056 0xbfa0 "뾠" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49057 0xbfa1 "뾡" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49058 0xbfa2 "뾢" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49059 0xbfa3 "뾣" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49060 0xbfa4 "뾤" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49061 0xbfa5 "뾥" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49062 0xbfa6 "뾦" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49063 0xbfa7 "뾧" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49064 0xbfa8 "뾨" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49065 0xbfa9 "뾩" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49066 0xbfaa "뾪" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49067 0xbfab "뾫" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49068 0xbfac "뾬" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49069 0xbfad "뾭" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49070 0xbfae "뾮" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49071 0xbfaf "뾯" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49072 0xbfb0 "뾰" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x44,0x44,0x44,0x7c,0x44,0x44,0x3c,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 49073 0xbfb1 "뾱" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49074 0xbfb2 "뾲" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49075 0xbfb3 "뾳" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49076 0xbfb4 "뾴" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 49077 0xbfb5 "뾵" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49078 0xbfb6 "뾶" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49079 0xbfb7 "뾷" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49080 0xbfb8 "뾸" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49081 0xbfb9 "뾹" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49082 0xbfba "뾺" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49083 0xbfbb "뾻" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49084 0xbfbc "뾼" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49085 0xbfbd "뾽" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49086 0xbfbe "뾾" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49087 0xbfbf "뾿" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49088 0xbfc0 "뿀" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49089 0xbfc1 "뿁" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49090 0xbfc2 "뿂" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49091 0xbfc3 "뿃" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49092 0xbfc4 "뿄" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49093 0xbfc5 "뿅" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49094 0xbfc6 "뿆" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49095 0xbfc7 "뿇" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49096 0xbfc8 "뿈" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49097 0xbfc9 "뿉" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49098 0xbfca "뿊" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49099 0xbfcb "뿋" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49100 0xbfcc "뿌" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 49101 0xbfcd "뿍" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 49102 0xbfce "뿎" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 49103 0xbfcf "뿏" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49104 0xbfd0 "뿐" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 49105 0xbfd1 "뿑" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 49106 0xbfd2 "뿒" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 49107 0xbfd3 "뿓" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 49108 0xbfd4 "뿔" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49109 0xbfd5 "뿕" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 49110 0xbfd6 "뿖" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 49111 0xbfd7 "뿗" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 49112 0xbfd8 "뿘" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49113 0xbfd9 "뿙" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49114 0xbfda "뿚" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 49115 0xbfdb "뿛" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 49116 0xbfdc "뿜" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 49117 0xbfdd "뿝" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 49118 0xbfde "뿞" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49119 0xbfdf "뿟" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 49120 0xbfe0 "뿠" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49121 0xbfe1 "뿡" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 49122 0xbfe2 "뿢" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 49123 0xbfe3 "뿣" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49124 0xbfe4 "뿤" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 49125 0xbfe5 "뿥" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49126 0xbfe6 "뿦" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 49127 0xbfe7 "뿧" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49128 0xbfe8 "뿨" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 49129 0xbfe9 "뿩" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49130 0xbfea "뿪" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49131 0xbfeb "뿫" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49132 0xbfec "뿬" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 49133 0xbfed "뿭" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49134 0xbfee "뿮" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49135 0xbfef "뿯" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49136 0xbff0 "뿰" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49137 0xbff1 "뿱" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49138 0xbff2 "뿲" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49139 0xbff3 "뿳" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49140 0xbff4 "뿴" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49141 0xbff5 "뿵" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49142 0xbff6 "뿶" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49143 0xbff7 "뿷" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49144 0xbff8 "뿸" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49145 0xbff9 "뿹" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49146 0xbffa "뿺" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49147 0xbffb "뿻" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49148 0xbffc "뿼" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49149 0xbffd "뿽" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49150 0xbffe "뿾" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49151 0xbfff "뿿" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49152 0xc000 "쀀" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49153 0xc001 "쀁" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49154 0xc002 "쀂" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49155 0xc003 "쀃" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49156 0xc004 "쀄" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 49157 0xc005 "쀅" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49158 0xc006 "쀆" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49159 0xc007 "쀇" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49160 0xc008 "쀈" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 49161 0xc009 "쀉" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49162 0xc00a "쀊" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49163 0xc00b "쀋" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49164 0xc00c "쀌" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49165 0xc00d "쀍" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49166 0xc00e "쀎" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49167 0xc00f "쀏" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49168 0xc010 "쀐" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49169 0xc011 "쀑" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49170 0xc012 "쀒" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49171 0xc013 "쀓" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49172 0xc014 "쀔" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49173 0xc015 "쀕" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49174 0xc016 "쀖" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49175 0xc017 "쀗" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49176 0xc018 "쀘" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49177 0xc019 "쀙" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49178 0xc01a "쀚" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49179 0xc01b "쀛" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49180 0xc01c "쀜" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49181 0xc01d "쀝" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49182 0xc01e "쀞" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49183 0xc01f "쀟" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49184 0xc020 "쀠" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 49185 0xc021 "쀡" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49186 0xc022 "쀢" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49187 0xc023 "쀣" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49188 0xc024 "쀤" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49189 0xc025 "쀥" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49190 0xc026 "쀦" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49191 0xc027 "쀧" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49192 0xc028 "쀨" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49193 0xc029 "쀩" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49194 0xc02a "쀪" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49195 0xc02b "쀫" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49196 0xc02c "쀬" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49197 0xc02d "쀭" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49198 0xc02e "쀮" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49199 0xc02f "쀯" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49200 0xc030 "쀰" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49201 0xc031 "쀱" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49202 0xc032 "쀲" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49203 0xc033 "쀳" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49204 0xc034 "쀴" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49205 0xc035 "쀵" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49206 0xc036 "쀶" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49207 0xc037 "쀷" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49208 0xc038 "쀸" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49209 0xc039 "쀹" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49210 0xc03a "쀺" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49211 0xc03b "쀻" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49212 0xc03c "쀼" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 49213 0xc03d "쀽" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 49214 0xc03e "쀾" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 49215 0xc03f "쀿" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49216 0xc040 "쁀" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 49217 0xc041 "쁁" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 49218 0xc042 "쁂" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 49219 0xc043 "쁃" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 49220 0xc044 "쁄" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49221 0xc045 "쁅" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 49222 0xc046 "쁆" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 49223 0xc047 "쁇" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 49224 0xc048 "쁈" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49225 0xc049 "쁉" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49226 0xc04a "쁊" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 49227 0xc04b "쁋" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 49228 0xc04c "쁌" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 49229 0xc04d "쁍" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 49230 0xc04e "쁎" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49231 0xc04f "쁏" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 49232 0xc050 "쁐" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49233 0xc051 "쁑" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 49234 0xc052 "쁒" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 49235 0xc053 "쁓" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49236 0xc054 "쁔" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 49237 0xc055 "쁕" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49238 0xc056 "쁖" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 49239 0xc057 "쁗" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49240 0xc058 "쁘" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x1f,0x11,0x11,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x44,0x44,0x44,0x7c,0x44,0x44,0x3c,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 49241 0xc059 "쁙" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49242 0xc05a "쁚" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49243 0xc05b "쁛" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49244 0xc05c "쁜" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 49245 0xc05d "쁝" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49246 0xc05e "쁞" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49247 0xc05f "쁟" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49248 0xc060 "쁠" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49249 0xc061 "쁡" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49250 0xc062 "쁢" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49251 0xc063 "쁣" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49252 0xc064 "쁤" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49253 0xc065 "쁥" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49254 0xc066 "쁦" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49255 0xc067 "쁧" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49256 0xc068 "쁨" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49257 0xc069 "쁩" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49258 0xc06a "쁪" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49259 0xc06b "쁫" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49260 0xc06c "쁬" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49261 0xc06d "쁭" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49262 0xc06e "쁮" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49263 0xc06f "쁯" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49264 0xc070 "쁰" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49265 0xc071 "쁱" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49266 0xc072 "쁲" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49267 0xc073 "쁳" */
+0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49268 0xc074 "쁴" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 49269 0xc075 "쁵" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49270 0xc076 "쁶" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49271 0xc077 "쁷" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49272 0xc078 "쁸" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49273 0xc079 "쁹" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49274 0xc07a "쁺" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49275 0xc07b "쁻" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49276 0xc07c "쁼" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49277 0xc07d "쁽" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49278 0xc07e "쁾" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49279 0xc07f "쁿" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49280 0xc080 "삀" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49281 0xc081 "삁" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49282 0xc082 "삂" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49283 0xc083 "삃" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49284 0xc084 "삄" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49285 0xc085 "삅" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49286 0xc086 "삆" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49287 0xc087 "삇" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49288 0xc088 "삈" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49289 0xc089 "삉" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49290 0xc08a "삊" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49291 0xc08b "삋" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49292 0xc08c "삌" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49293 0xc08d "삍" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49294 0xc08e "삎" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49295 0xc08f "삏" */
+0x00,0x00,0x24,0x24,0x3f,0x24,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49296 0xc090 "삐" */
+0x00,0x00,0x00,0x24,0x24,0x24,0x24,0x3f,0x24,0x24,0x24,0x24,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,
+/* 49297 0xc091 "삑" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49298 0xc092 "삒" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49299 0xc093 "삓" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49300 0xc094 "삔" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49301 0xc095 "삕" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49302 0xc096 "삖" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49303 0xc097 "삗" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49304 0xc098 "삘" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49305 0xc099 "삙" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49306 0xc09a "삚" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49307 0xc09b "삛" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49308 0xc09c "삜" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49309 0xc09d "삝" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49310 0xc09e "삞" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49311 0xc09f "삟" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49312 0xc0a0 "삠" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49313 0xc0a1 "삡" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49314 0xc0a2 "삢" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49315 0xc0a3 "삣" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49316 0xc0a4 "삤" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49317 0xc0a5 "삥" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49318 0xc0a6 "삦" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49319 0xc0a7 "삧" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49320 0xc0a8 "삨" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49321 0xc0a9 "삩" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49322 0xc0aa "삪" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49323 0xc0ab "삫" */
+0x00,0x00,0x24,0x24,0x24,0x3f,0x24,0x24,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49324 0xc0ac "사" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 49325 0xc0ad "삭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49326 0xc0ae "삮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49327 0xc0af "삯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49328 0xc0b0 "산" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49329 0xc0b1 "삱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49330 0xc0b2 "삲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49331 0xc0b3 "삳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49332 0xc0b4 "살" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49333 0xc0b5 "삵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49334 0xc0b6 "삶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49335 0xc0b7 "삷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49336 0xc0b8 "삸" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49337 0xc0b9 "삹" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49338 0xc0ba "삺" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49339 0xc0bb "삻" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49340 0xc0bc "삼" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49341 0xc0bd "삽" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49342 0xc0be "삾" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49343 0xc0bf "삿" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49344 0xc0c0 "샀" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49345 0xc0c1 "상" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49346 0xc0c2 "샂" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49347 0xc0c3 "샃" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49348 0xc0c4 "샄" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49349 0xc0c5 "샅" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49350 0xc0c6 "샆" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49351 0xc0c7 "샇" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49352 0xc0c8 "새" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 49353 0xc0c9 "색" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49354 0xc0ca "샊" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49355 0xc0cb "샋" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49356 0xc0cc "샌" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49357 0xc0cd "샍" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49358 0xc0ce "샎" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49359 0xc0cf "샏" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49360 0xc0d0 "샐" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49361 0xc0d1 "샑" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49362 0xc0d2 "샒" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49363 0xc0d3 "샓" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49364 0xc0d4 "샔" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49365 0xc0d5 "샕" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49366 0xc0d6 "샖" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49367 0xc0d7 "샗" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49368 0xc0d8 "샘" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49369 0xc0d9 "샙" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49370 0xc0da "샚" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49371 0xc0db "샛" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49372 0xc0dc "샜" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49373 0xc0dd "생" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49374 0xc0de "샞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49375 0xc0df "샟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49376 0xc0e0 "샠" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49377 0xc0e1 "샡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49378 0xc0e2 "샢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49379 0xc0e3 "샣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49380 0xc0e4 "샤" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 49381 0xc0e5 "샥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49382 0xc0e6 "샦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49383 0xc0e7 "샧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49384 0xc0e8 "샨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49385 0xc0e9 "샩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49386 0xc0ea "샪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49387 0xc0eb "샫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49388 0xc0ec "샬" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49389 0xc0ed "샭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49390 0xc0ee "샮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49391 0xc0ef "샯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49392 0xc0f0 "샰" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49393 0xc0f1 "샱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49394 0xc0f2 "샲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49395 0xc0f3 "샳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49396 0xc0f4 "샴" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49397 0xc0f5 "샵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49398 0xc0f6 "샶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49399 0xc0f7 "샷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49400 0xc0f8 "샸" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49401 0xc0f9 "샹" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49402 0xc0fa "샺" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49403 0xc0fb "샻" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49404 0xc0fc "샼" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49405 0xc0fd "샽" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49406 0xc0fe "샾" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49407 0xc0ff "샿" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49408 0xc100 "섀" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 49409 0xc101 "섁" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49410 0xc102 "섂" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49411 0xc103 "섃" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49412 0xc104 "섄" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49413 0xc105 "섅" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49414 0xc106 "섆" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49415 0xc107 "섇" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49416 0xc108 "섈" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49417 0xc109 "섉" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49418 0xc10a "섊" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49419 0xc10b "섋" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49420 0xc10c "섌" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49421 0xc10d "섍" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49422 0xc10e "섎" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49423 0xc10f "섏" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49424 0xc110 "섐" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49425 0xc111 "섑" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49426 0xc112 "섒" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49427 0xc113 "섓" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49428 0xc114 "섔" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49429 0xc115 "섕" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49430 0xc116 "섖" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49431 0xc117 "섗" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49432 0xc118 "섘" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49433 0xc119 "섙" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49434 0xc11a "섚" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49435 0xc11b "섛" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49436 0xc11c "서" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 49437 0xc11d "석" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49438 0xc11e "섞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49439 0xc11f "섟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49440 0xc120 "선" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49441 0xc121 "섡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49442 0xc122 "섢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49443 0xc123 "섣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49444 0xc124 "설" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49445 0xc125 "섥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49446 0xc126 "섦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49447 0xc127 "섧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49448 0xc128 "섨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49449 0xc129 "섩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49450 0xc12a "섪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49451 0xc12b "섫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49452 0xc12c "섬" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49453 0xc12d "섭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49454 0xc12e "섮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49455 0xc12f "섯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49456 0xc130 "섰" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49457 0xc131 "성" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49458 0xc132 "섲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49459 0xc133 "섳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49460 0xc134 "섴" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49461 0xc135 "섵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49462 0xc136 "섶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49463 0xc137 "섷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49464 0xc138 "세" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 49465 0xc139 "섹" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49466 0xc13a "섺" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49467 0xc13b "섻" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49468 0xc13c "센" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49469 0xc13d "섽" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49470 0xc13e "섾" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49471 0xc13f "섿" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49472 0xc140 "셀" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49473 0xc141 "셁" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49474 0xc142 "셂" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49475 0xc143 "셃" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49476 0xc144 "셄" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49477 0xc145 "셅" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49478 0xc146 "셆" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49479 0xc147 "셇" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49480 0xc148 "셈" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49481 0xc149 "셉" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49482 0xc14a "셊" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49483 0xc14b "셋" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49484 0xc14c "셌" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49485 0xc14d "셍" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49486 0xc14e "셎" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49487 0xc14f "셏" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49488 0xc150 "셐" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49489 0xc151 "셑" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49490 0xc152 "셒" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49491 0xc153 "셓" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49492 0xc154 "셔" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 49493 0xc155 "셕" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49494 0xc156 "셖" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49495 0xc157 "셗" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49496 0xc158 "션" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49497 0xc159 "셙" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49498 0xc15a "셚" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49499 0xc15b "셛" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49500 0xc15c "셜" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49501 0xc15d "셝" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49502 0xc15e "셞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49503 0xc15f "셟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49504 0xc160 "셠" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49505 0xc161 "셡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49506 0xc162 "셢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49507 0xc163 "셣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49508 0xc164 "셤" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49509 0xc165 "셥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49510 0xc166 "셦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49511 0xc167 "셧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49512 0xc168 "셨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49513 0xc169 "셩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49514 0xc16a "셪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49515 0xc16b "셫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49516 0xc16c "셬" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49517 0xc16d "셭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49518 0xc16e "셮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49519 0xc16f "셯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49520 0xc170 "셰" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 49521 0xc171 "셱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49522 0xc172 "셲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49523 0xc173 "셳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49524 0xc174 "셴" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49525 0xc175 "셵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49526 0xc176 "셶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49527 0xc177 "셷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49528 0xc178 "셸" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49529 0xc179 "셹" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49530 0xc17a "셺" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49531 0xc17b "셻" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49532 0xc17c "셼" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49533 0xc17d "셽" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49534 0xc17e "셾" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49535 0xc17f "셿" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49536 0xc180 "솀" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49537 0xc181 "솁" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49538 0xc182 "솂" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49539 0xc183 "솃" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49540 0xc184 "솄" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49541 0xc185 "솅" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49542 0xc186 "솆" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49543 0xc187 "솇" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49544 0xc188 "솈" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49545 0xc189 "솉" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49546 0xc18a "솊" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49547 0xc18b "솋" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49548 0xc18c "소" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x18,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x40,0x20,0x10,0x0c,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 49549 0xc18d "속" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49550 0xc18e "솎" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49551 0xc18f "솏" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49552 0xc190 "손" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 49553 0xc191 "솑" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49554 0xc192 "솒" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49555 0xc193 "솓" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49556 0xc194 "솔" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49557 0xc195 "솕" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49558 0xc196 "솖" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49559 0xc197 "솗" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49560 0xc198 "솘" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49561 0xc199 "솙" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49562 0xc19a "솚" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49563 0xc19b "솛" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49564 0xc19c "솜" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49565 0xc19d "솝" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49566 0xc19e "솞" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49567 0xc19f "솟" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49568 0xc1a0 "솠" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49569 0xc1a1 "송" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49570 0xc1a2 "솢" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49571 0xc1a3 "솣" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49572 0xc1a4 "솤" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49573 0xc1a5 "솥" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49574 0xc1a6 "솦" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49575 0xc1a7 "솧" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49576 0xc1a8 "솨" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 49577 0xc1a9 "솩" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49578 0xc1aa "솪" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49579 0xc1ab "솫" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49580 0xc1ac "솬" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49581 0xc1ad "솭" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49582 0xc1ae "솮" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49583 0xc1af "솯" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49584 0xc1b0 "솰" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49585 0xc1b1 "솱" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49586 0xc1b2 "솲" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49587 0xc1b3 "솳" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49588 0xc1b4 "솴" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49589 0xc1b5 "솵" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49590 0xc1b6 "솶" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49591 0xc1b7 "솷" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49592 0xc1b8 "솸" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49593 0xc1b9 "솹" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49594 0xc1ba "솺" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49595 0xc1bb "솻" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49596 0xc1bc "솼" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49597 0xc1bd "솽" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49598 0xc1be "솾" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49599 0xc1bf "솿" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49600 0xc1c0 "쇀" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49601 0xc1c1 "쇁" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49602 0xc1c2 "쇂" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49603 0xc1c3 "쇃" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49604 0xc1c4 "쇄" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 49605 0xc1c5 "쇅" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49606 0xc1c6 "쇆" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49607 0xc1c7 "쇇" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49608 0xc1c8 "쇈" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49609 0xc1c9 "쇉" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49610 0xc1ca "쇊" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49611 0xc1cb "쇋" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49612 0xc1cc "쇌" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49613 0xc1cd "쇍" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49614 0xc1ce "쇎" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49615 0xc1cf "쇏" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49616 0xc1d0 "쇐" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49617 0xc1d1 "쇑" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49618 0xc1d2 "쇒" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49619 0xc1d3 "쇓" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49620 0xc1d4 "쇔" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49621 0xc1d5 "쇕" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49622 0xc1d6 "쇖" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49623 0xc1d7 "쇗" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49624 0xc1d8 "쇘" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49625 0xc1d9 "쇙" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49626 0xc1da "쇚" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49627 0xc1db "쇛" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49628 0xc1dc "쇜" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49629 0xc1dd "쇝" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49630 0xc1de "쇞" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49631 0xc1df "쇟" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49632 0xc1e0 "쇠" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 49633 0xc1e1 "쇡" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49634 0xc1e2 "쇢" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49635 0xc1e3 "쇣" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49636 0xc1e4 "쇤" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49637 0xc1e5 "쇥" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49638 0xc1e6 "쇦" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49639 0xc1e7 "쇧" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49640 0xc1e8 "쇨" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49641 0xc1e9 "쇩" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49642 0xc1ea "쇪" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49643 0xc1eb "쇫" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49644 0xc1ec "쇬" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49645 0xc1ed "쇭" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49646 0xc1ee "쇮" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49647 0xc1ef "쇯" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49648 0xc1f0 "쇰" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49649 0xc1f1 "쇱" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49650 0xc1f2 "쇲" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49651 0xc1f3 "쇳" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49652 0xc1f4 "쇴" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49653 0xc1f5 "쇵" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49654 0xc1f6 "쇶" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49655 0xc1f7 "쇷" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49656 0xc1f8 "쇸" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49657 0xc1f9 "쇹" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49658 0xc1fa "쇺" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49659 0xc1fb "쇻" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49660 0xc1fc "쇼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x18,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x40,0x20,0x10,0x0c,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 49661 0xc1fd "쇽" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49662 0xc1fe "쇾" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49663 0xc1ff "쇿" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49664 0xc200 "숀" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 49665 0xc201 "숁" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49666 0xc202 "숂" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49667 0xc203 "숃" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49668 0xc204 "숄" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49669 0xc205 "숅" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49670 0xc206 "숆" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49671 0xc207 "숇" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49672 0xc208 "숈" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49673 0xc209 "숉" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49674 0xc20a "숊" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49675 0xc20b "숋" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49676 0xc20c "숌" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49677 0xc20d "숍" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49678 0xc20e "숎" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49679 0xc20f "숏" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49680 0xc210 "숐" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49681 0xc211 "숑" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49682 0xc212 "숒" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49683 0xc213 "숓" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49684 0xc214 "숔" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49685 0xc215 "숕" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49686 0xc216 "숖" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49687 0xc217 "숗" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49688 0xc218 "수" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 49689 0xc219 "숙" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 49690 0xc21a "숚" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 49691 0xc21b "숛" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49692 0xc21c "순" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 49693 0xc21d "숝" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 49694 0xc21e "숞" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 49695 0xc21f "숟" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 49696 0xc220 "술" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49697 0xc221 "숡" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 49698 0xc222 "숢" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 49699 0xc223 "숣" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 49700 0xc224 "숤" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49701 0xc225 "숥" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49702 0xc226 "숦" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 49703 0xc227 "숧" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 49704 0xc228 "숨" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 49705 0xc229 "숩" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 49706 0xc22a "숪" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49707 0xc22b "숫" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 49708 0xc22c "숬" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 49709 0xc22d "숭" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 49710 0xc22e "숮" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 49711 0xc22f "숯" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49712 0xc230 "숰" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 49713 0xc231 "숱" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49714 0xc232 "숲" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 49715 0xc233 "숳" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49716 0xc234 "숴" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 49717 0xc235 "숵" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49718 0xc236 "숶" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49719 0xc237 "숷" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49720 0xc238 "숸" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 49721 0xc239 "숹" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49722 0xc23a "숺" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49723 0xc23b "숻" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49724 0xc23c "숼" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49725 0xc23d "숽" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49726 0xc23e "숾" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49727 0xc23f "숿" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49728 0xc240 "쉀" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49729 0xc241 "쉁" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49730 0xc242 "쉂" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49731 0xc243 "쉃" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49732 0xc244 "쉄" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49733 0xc245 "쉅" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49734 0xc246 "쉆" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49735 0xc247 "쉇" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49736 0xc248 "쉈" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49737 0xc249 "쉉" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49738 0xc24a "쉊" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49739 0xc24b "쉋" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49740 0xc24c "쉌" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49741 0xc24d "쉍" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49742 0xc24e "쉎" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49743 0xc24f "쉏" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49744 0xc250 "쉐" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 49745 0xc251 "쉑" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49746 0xc252 "쉒" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49747 0xc253 "쉓" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49748 0xc254 "쉔" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 49749 0xc255 "쉕" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49750 0xc256 "쉖" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49751 0xc257 "쉗" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49752 0xc258 "쉘" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49753 0xc259 "쉙" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49754 0xc25a "쉚" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49755 0xc25b "쉛" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49756 0xc25c "쉜" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49757 0xc25d "쉝" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49758 0xc25e "쉞" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49759 0xc25f "쉟" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49760 0xc260 "쉠" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49761 0xc261 "쉡" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49762 0xc262 "쉢" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49763 0xc263 "쉣" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49764 0xc264 "쉤" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49765 0xc265 "쉥" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49766 0xc266 "쉦" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49767 0xc267 "쉧" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49768 0xc268 "쉨" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49769 0xc269 "쉩" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49770 0xc26a "쉪" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49771 0xc26b "쉫" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49772 0xc26c "쉬" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 49773 0xc26d "쉭" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49774 0xc26e "쉮" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49775 0xc26f "쉯" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49776 0xc270 "쉰" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49777 0xc271 "쉱" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49778 0xc272 "쉲" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49779 0xc273 "쉳" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49780 0xc274 "쉴" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49781 0xc275 "쉵" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49782 0xc276 "쉶" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49783 0xc277 "쉷" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49784 0xc278 "쉸" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49785 0xc279 "쉹" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49786 0xc27a "쉺" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49787 0xc27b "쉻" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49788 0xc27c "쉼" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49789 0xc27d "쉽" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49790 0xc27e "쉾" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49791 0xc27f "쉿" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49792 0xc280 "슀" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49793 0xc281 "슁" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49794 0xc282 "슂" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49795 0xc283 "슃" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49796 0xc284 "슄" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49797 0xc285 "슅" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49798 0xc286 "슆" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49799 0xc287 "슇" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49800 0xc288 "슈" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 49801 0xc289 "슉" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 49802 0xc28a "슊" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 49803 0xc28b "슋" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49804 0xc28c "슌" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 49805 0xc28d "슍" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 49806 0xc28e "슎" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 49807 0xc28f "슏" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 49808 0xc290 "슐" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49809 0xc291 "슑" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 49810 0xc292 "슒" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 49811 0xc293 "슓" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 49812 0xc294 "슔" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49813 0xc295 "슕" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49814 0xc296 "슖" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 49815 0xc297 "슗" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 49816 0xc298 "슘" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 49817 0xc299 "슙" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 49818 0xc29a "슚" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49819 0xc29b "슛" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 49820 0xc29c "슜" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 49821 0xc29d "슝" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 49822 0xc29e "슞" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 49823 0xc29f "슟" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49824 0xc2a0 "슠" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 49825 0xc2a1 "슡" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49826 0xc2a2 "슢" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 49827 0xc2a3 "슣" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49828 0xc2a4 "스" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x18,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x80,0x80,0x40,0x20,0x10,0x0c,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 49829 0xc2a5 "슥" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49830 0xc2a6 "슦" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49831 0xc2a7 "슧" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49832 0xc2a8 "슨" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 49833 0xc2a9 "슩" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49834 0xc2aa "슪" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49835 0xc2ab "슫" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49836 0xc2ac "슬" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49837 0xc2ad "슭" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49838 0xc2ae "슮" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49839 0xc2af "슯" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49840 0xc2b0 "슰" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49841 0xc2b1 "슱" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49842 0xc2b2 "슲" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49843 0xc2b3 "슳" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49844 0xc2b4 "슴" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49845 0xc2b5 "습" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49846 0xc2b6 "슶" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49847 0xc2b7 "슷" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49848 0xc2b8 "슸" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49849 0xc2b9 "승" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49850 0xc2ba "슺" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49851 0xc2bb "슻" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49852 0xc2bc "슼" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49853 0xc2bd "슽" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49854 0xc2be "슾" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49855 0xc2bf "슿" */
+0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49856 0xc2c0 "싀" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 49857 0xc2c1 "싁" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49858 0xc2c2 "싂" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49859 0xc2c3 "싃" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49860 0xc2c4 "싄" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49861 0xc2c5 "싅" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49862 0xc2c6 "싆" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49863 0xc2c7 "싇" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49864 0xc2c8 "싈" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49865 0xc2c9 "싉" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49866 0xc2ca "싊" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49867 0xc2cb "싋" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49868 0xc2cc "싌" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49869 0xc2cd "싍" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49870 0xc2ce "싎" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49871 0xc2cf "싏" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49872 0xc2d0 "싐" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49873 0xc2d1 "싑" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49874 0xc2d2 "싒" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49875 0xc2d3 "싓" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49876 0xc2d4 "싔" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49877 0xc2d5 "싕" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49878 0xc2d6 "싖" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49879 0xc2d7 "싗" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49880 0xc2d8 "싘" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49881 0xc2d9 "싙" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49882 0xc2da "싚" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49883 0xc2db "싛" */
+0x00,0x00,0x04,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49884 0xc2dc "시" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 49885 0xc2dd "식" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49886 0xc2de "싞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49887 0xc2df "싟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49888 0xc2e0 "신" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49889 0xc2e1 "싡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49890 0xc2e2 "싢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49891 0xc2e3 "싣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49892 0xc2e4 "실" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49893 0xc2e5 "싥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49894 0xc2e6 "싦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49895 0xc2e7 "싧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49896 0xc2e8 "싨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49897 0xc2e9 "싩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49898 0xc2ea "싪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49899 0xc2eb "싫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49900 0xc2ec "심" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49901 0xc2ed "십" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49902 0xc2ee "싮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49903 0xc2ef "싯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49904 0xc2f0 "싰" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49905 0xc2f1 "싱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49906 0xc2f2 "싲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49907 0xc2f3 "싳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49908 0xc2f4 "싴" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49909 0xc2f5 "싵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49910 0xc2f6 "싶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49911 0xc2f7 "싷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49912 0xc2f8 "싸" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x07,0x04,0x84,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 49913 0xc2f9 "싹" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49914 0xc2fa "싺" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49915 0xc2fb "싻" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49916 0xc2fc "싼" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49917 0xc2fd "싽" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49918 0xc2fe "싾" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49919 0xc2ff "싿" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49920 0xc300 "쌀" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49921 0xc301 "쌁" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49922 0xc302 "쌂" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49923 0xc303 "쌃" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49924 0xc304 "쌄" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49925 0xc305 "쌅" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49926 0xc306 "쌆" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49927 0xc307 "쌇" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49928 0xc308 "쌈" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49929 0xc309 "쌉" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49930 0xc30a "쌊" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49931 0xc30b "쌋" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49932 0xc30c "쌌" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49933 0xc30d "쌍" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49934 0xc30e "쌎" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49935 0xc30f "쌏" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49936 0xc310 "쌐" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49937 0xc311 "쌑" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49938 0xc312 "쌒" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49939 0xc313 "쌓" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49940 0xc314 "쌔" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0x92,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 49941 0xc315 "쌕" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49942 0xc316 "쌖" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49943 0xc317 "쌗" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49944 0xc318 "쌘" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 49945 0xc319 "쌙" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 49946 0xc31a "쌚" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 49947 0xc31b "쌛" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 49948 0xc31c "쌜" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 49949 0xc31d "쌝" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 49950 0xc31e "쌞" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 49951 0xc31f "쌟" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 49952 0xc320 "쌠" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 49953 0xc321 "쌡" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 49954 0xc322 "쌢" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 49955 0xc323 "쌣" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 49956 0xc324 "쌤" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 49957 0xc325 "쌥" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 49958 0xc326 "쌦" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 49959 0xc327 "쌧" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 49960 0xc328 "쌨" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 49961 0xc329 "쌩" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 49962 0xc32a "쌪" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 49963 0xc32b "쌫" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 49964 0xc32c "쌬" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 49965 0xc32d "쌭" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 49966 0xc32e "쌮" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 49967 0xc32f "쌯" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 49968 0xc330 "쌰" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x07,0x04,0x04,0x87,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 49969 0xc331 "쌱" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 49970 0xc332 "쌲" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49971 0xc333 "쌳" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49972 0xc334 "쌴" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 49973 0xc335 "쌵" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 49974 0xc336 "쌶" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49975 0xc337 "쌷" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 49976 0xc338 "쌸" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 49977 0xc339 "쌹" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 49978 0xc33a "쌺" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 49979 0xc33b "쌻" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 49980 0xc33c "쌼" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49981 0xc33d "쌽" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 49982 0xc33e "쌾" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 49983 0xc33f "쌿" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 49984 0xc340 "썀" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 49985 0xc341 "썁" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 49986 0xc342 "썂" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49987 0xc343 "썃" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 49988 0xc344 "썄" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 49989 0xc345 "썅" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 49990 0xc346 "썆" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 49991 0xc347 "썇" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 49992 0xc348 "썈" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 49993 0xc349 "썉" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 49994 0xc34a "썊" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 49995 0xc34b "썋" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 49996 0xc34c "썌" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x1e,0x12,0x12,0x9e,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 49997 0xc34d "썍" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 49998 0xc34e "썎" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 49999 0xc34f "썏" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50000 0xc350 "썐" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50001 0xc351 "썑" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50002 0xc352 "썒" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50003 0xc353 "썓" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50004 0xc354 "썔" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50005 0xc355 "썕" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50006 0xc356 "썖" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50007 0xc357 "썗" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50008 0xc358 "썘" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50009 0xc359 "썙" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50010 0xc35a "썚" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50011 0xc35b "썛" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50012 0xc35c "썜" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50013 0xc35d "썝" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50014 0xc35e "썞" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50015 0xc35f "썟" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50016 0xc360 "썠" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50017 0xc361 "썡" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50018 0xc362 "썢" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50019 0xc363 "썣" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50020 0xc364 "썤" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50021 0xc365 "썥" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50022 0xc366 "썦" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50023 0xc367 "썧" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50024 0xc368 "써" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x3c,0x04,0x84,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 50025 0xc369 "썩" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50026 0xc36a "썪" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50027 0xc36b "썫" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50028 0xc36c "썬" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50029 0xc36d "썭" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50030 0xc36e "썮" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50031 0xc36f "썯" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50032 0xc370 "썰" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50033 0xc371 "썱" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50034 0xc372 "썲" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50035 0xc373 "썳" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50036 0xc374 "썴" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50037 0xc375 "썵" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50038 0xc376 "썶" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50039 0xc377 "썷" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50040 0xc378 "썸" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50041 0xc379 "썹" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50042 0xc37a "썺" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50043 0xc37b "썻" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50044 0xc37c "썼" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50045 0xc37d "썽" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50046 0xc37e "썾" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50047 0xc37f "썿" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50048 0xc380 "쎀" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50049 0xc381 "쎁" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50050 0xc382 "쎂" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50051 0xc383 "쎃" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50052 0xc384 "쎄" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x72,0x12,0x92,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 50053 0xc385 "쎅" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50054 0xc386 "쎆" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50055 0xc387 "쎇" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50056 0xc388 "쎈" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50057 0xc389 "쎉" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50058 0xc38a "쎊" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50059 0xc38b "쎋" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50060 0xc38c "쎌" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50061 0xc38d "쎍" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50062 0xc38e "쎎" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50063 0xc38f "쎏" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50064 0xc390 "쎐" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50065 0xc391 "쎑" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50066 0xc392 "쎒" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50067 0xc393 "쎓" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50068 0xc394 "쎔" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50069 0xc395 "쎕" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50070 0xc396 "쎖" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50071 0xc397 "쎗" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50072 0xc398 "쎘" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50073 0xc399 "쎙" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50074 0xc39a "쎚" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50075 0xc39b "쎛" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50076 0xc39c "쎜" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50077 0xc39d "쎝" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50078 0xc39e "쎞" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50079 0xc39f "쎟" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50080 0xc3a0 "쎠" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x3c,0x04,0x04,0xbc,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 50081 0xc3a1 "쎡" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50082 0xc3a2 "쎢" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50083 0xc3a3 "쎣" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50084 0xc3a4 "쎤" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50085 0xc3a5 "쎥" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50086 0xc3a6 "쎦" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50087 0xc3a7 "쎧" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50088 0xc3a8 "쎨" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50089 0xc3a9 "쎩" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50090 0xc3aa "쎪" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50091 0xc3ab "쎫" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50092 0xc3ac "쎬" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50093 0xc3ad "쎭" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50094 0xc3ae "쎮" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50095 0xc3af "쎯" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50096 0xc3b0 "쎰" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50097 0xc3b1 "쎱" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50098 0xc3b2 "쎲" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50099 0xc3b3 "쎳" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50100 0xc3b4 "쎴" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50101 0xc3b5 "쎵" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50102 0xc3b6 "쎶" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50103 0xc3b7 "쎷" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50104 0xc3b8 "쎸" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50105 0xc3b9 "쎹" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50106 0xc3ba "쎺" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50107 0xc3bb "쎻" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50108 0xc3bc "쎼" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x72,0x12,0x12,0xf2,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 50109 0xc3bd "쎽" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50110 0xc3be "쎾" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50111 0xc3bf "쎿" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50112 0xc3c0 "쏀" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50113 0xc3c1 "쏁" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50114 0xc3c2 "쏂" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50115 0xc3c3 "쏃" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50116 0xc3c4 "쏄" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50117 0xc3c5 "쏅" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50118 0xc3c6 "쏆" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50119 0xc3c7 "쏇" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50120 0xc3c8 "쏈" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50121 0xc3c9 "쏉" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50122 0xc3ca "쏊" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50123 0xc3cb "쏋" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50124 0xc3cc "쏌" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50125 0xc3cd "쏍" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50126 0xc3ce "쏎" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50127 0xc3cf "쏏" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50128 0xc3d0 "쏐" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50129 0xc3d1 "쏑" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50130 0xc3d2 "쏒" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50131 0xc3d3 "쏓" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50132 0xc3d4 "쏔" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50133 0xc3d5 "쏕" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50134 0xc3d6 "쏖" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50135 0xc3d7 "쏗" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50136 0xc3d8 "쏘" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x11,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 50137 0xc3d9 "쏙" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50138 0xc3da "쏚" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50139 0xc3db "쏛" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50140 0xc3dc "쏜" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 50141 0xc3dd "쏝" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50142 0xc3de "쏞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50143 0xc3df "쏟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50144 0xc3e0 "쏠" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50145 0xc3e1 "쏡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50146 0xc3e2 "쏢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50147 0xc3e3 "쏣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50148 0xc3e4 "쏤" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50149 0xc3e5 "쏥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50150 0xc3e6 "쏦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50151 0xc3e7 "쏧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50152 0xc3e8 "쏨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50153 0xc3e9 "쏩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50154 0xc3ea "쏪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50155 0xc3eb "쏫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50156 0xc3ec "쏬" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50157 0xc3ed "쏭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50158 0xc3ee "쏮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50159 0xc3ef "쏯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50160 0xc3f0 "쏰" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50161 0xc3f1 "쏱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50162 0xc3f2 "쏲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50163 0xc3f3 "쏳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50164 0xc3f4 "쏴" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x87,0x84,0x44,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 50165 0xc3f5 "쏵" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50166 0xc3f6 "쏶" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50167 0xc3f7 "쏷" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50168 0xc3f8 "쏸" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50169 0xc3f9 "쏹" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50170 0xc3fa "쏺" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50171 0xc3fb "쏻" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50172 0xc3fc "쏼" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50173 0xc3fd "쏽" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50174 0xc3fe "쏾" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50175 0xc3ff "쏿" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50176 0xc400 "쐀" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50177 0xc401 "쐁" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50178 0xc402 "쐂" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50179 0xc403 "쐃" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50180 0xc404 "쐄" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50181 0xc405 "쐅" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50182 0xc406 "쐆" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50183 0xc407 "쐇" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50184 0xc408 "쐈" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50185 0xc409 "쐉" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50186 0xc40a "쐊" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50187 0xc40b "쐋" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50188 0xc40c "쐌" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50189 0xc40d "쐍" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50190 0xc40e "쐎" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50191 0xc40f "쐏" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50192 0xc410 "쐐" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x9e,0x92,0x52,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 50193 0xc411 "쐑" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50194 0xc412 "쐒" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50195 0xc413 "쐓" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50196 0xc414 "쐔" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50197 0xc415 "쐕" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50198 0xc416 "쐖" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50199 0xc417 "쐗" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50200 0xc418 "쐘" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50201 0xc419 "쐙" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50202 0xc41a "쐚" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50203 0xc41b "쐛" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50204 0xc41c "쐜" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50205 0xc41d "쐝" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50206 0xc41e "쐞" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50207 0xc41f "쐟" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50208 0xc420 "쐠" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50209 0xc421 "쐡" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50210 0xc422 "쐢" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50211 0xc423 "쐣" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50212 0xc424 "쐤" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50213 0xc425 "쐥" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50214 0xc426 "쐦" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50215 0xc427 "쐧" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50216 0xc428 "쐨" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50217 0xc429 "쐩" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50218 0xc42a "쐪" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50219 0xc42b "쐫" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50220 0xc42c "쐬" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 50221 0xc42d "쐭" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50222 0xc42e "쐮" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50223 0xc42f "쐯" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50224 0xc430 "쐰" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50225 0xc431 "쐱" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50226 0xc432 "쐲" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50227 0xc433 "쐳" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50228 0xc434 "쐴" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50229 0xc435 "쐵" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50230 0xc436 "쐶" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50231 0xc437 "쐷" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50232 0xc438 "쐸" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50233 0xc439 "쐹" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50234 0xc43a "쐺" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50235 0xc43b "쐻" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50236 0xc43c "쐼" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50237 0xc43d "쐽" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50238 0xc43e "쐾" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50239 0xc43f "쐿" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50240 0xc440 "쑀" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50241 0xc441 "쑁" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50242 0xc442 "쑂" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50243 0xc443 "쑃" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50244 0xc444 "쑄" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50245 0xc445 "쑅" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50246 0xc446 "쑆" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50247 0xc447 "쑇" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50248 0xc448 "쑈" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x11,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 50249 0xc449 "쑉" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50250 0xc44a "쑊" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50251 0xc44b "쑋" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50252 0xc44c "쑌" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 50253 0xc44d "쑍" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50254 0xc44e "쑎" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50255 0xc44f "쑏" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50256 0xc450 "쑐" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50257 0xc451 "쑑" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50258 0xc452 "쑒" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50259 0xc453 "쑓" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50260 0xc454 "쑔" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50261 0xc455 "쑕" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50262 0xc456 "쑖" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50263 0xc457 "쑗" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50264 0xc458 "쑘" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50265 0xc459 "쑙" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50266 0xc45a "쑚" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50267 0xc45b "쑛" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50268 0xc45c "쑜" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50269 0xc45d "쑝" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50270 0xc45e "쑞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50271 0xc45f "쑟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50272 0xc460 "쑠" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50273 0xc461 "쑡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50274 0xc462 "쑢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50275 0xc463 "쑣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50276 0xc464 "쑤" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 50277 0xc465 "쑥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 50278 0xc466 "쑦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 50279 0xc467 "쑧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50280 0xc468 "쑨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 50281 0xc469 "쑩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 50282 0xc46a "쑪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 50283 0xc46b "쑫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 50284 0xc46c "쑬" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50285 0xc46d "쑭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 50286 0xc46e "쑮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 50287 0xc46f "쑯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 50288 0xc470 "쑰" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50289 0xc471 "쑱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50290 0xc472 "쑲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 50291 0xc473 "쑳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 50292 0xc474 "쑴" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 50293 0xc475 "쑵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 50294 0xc476 "쑶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50295 0xc477 "쑷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 50296 0xc478 "쑸" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50297 0xc479 "쑹" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 50298 0xc47a "쑺" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 50299 0xc47b "쑻" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50300 0xc47c "쑼" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 50301 0xc47d "쑽" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50302 0xc47e "쑾" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 50303 0xc47f "쑿" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50304 0xc480 "쒀" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 50305 0xc481 "쒁" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50306 0xc482 "쒂" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50307 0xc483 "쒃" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50308 0xc484 "쒄" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 50309 0xc485 "쒅" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50310 0xc486 "쒆" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50311 0xc487 "쒇" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50312 0xc488 "쒈" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50313 0xc489 "쒉" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50314 0xc48a "쒊" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50315 0xc48b "쒋" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50316 0xc48c "쒌" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50317 0xc48d "쒍" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50318 0xc48e "쒎" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50319 0xc48f "쒏" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50320 0xc490 "쒐" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50321 0xc491 "쒑" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50322 0xc492 "쒒" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50323 0xc493 "쒓" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50324 0xc494 "쒔" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50325 0xc495 "쒕" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50326 0xc496 "쒖" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50327 0xc497 "쒗" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50328 0xc498 "쒘" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50329 0xc499 "쒙" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50330 0xc49a "쒚" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50331 0xc49b "쒛" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50332 0xc49c "쒜" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x12,0x12,0x12,0x92,0x52,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 50333 0xc49d "쒝" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50334 0xc49e "쒞" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50335 0xc49f "쒟" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50336 0xc4a0 "쒠" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0x92,0x52,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 50337 0xc4a1 "쒡" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50338 0xc4a2 "쒢" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50339 0xc4a3 "쒣" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50340 0xc4a4 "쒤" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50341 0xc4a5 "쒥" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50342 0xc4a6 "쒦" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50343 0xc4a7 "쒧" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50344 0xc4a8 "쒨" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50345 0xc4a9 "쒩" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50346 0xc4aa "쒪" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50347 0xc4ab "쒫" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50348 0xc4ac "쒬" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50349 0xc4ad "쒭" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50350 0xc4ae "쒮" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50351 0xc4af "쒯" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50352 0xc4b0 "쒰" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50353 0xc4b1 "쒱" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50354 0xc4b2 "쒲" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50355 0xc4b3 "쒳" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50356 0xc4b4 "쒴" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50357 0xc4b5 "쒵" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50358 0xc4b6 "쒶" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50359 0xc4b7 "쒷" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50360 0xc4b8 "쒸" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 50361 0xc4b9 "쒹" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50362 0xc4ba "쒺" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50363 0xc4bb "쒻" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50364 0xc4bc "쒼" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50365 0xc4bd "쒽" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50366 0xc4be "쒾" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50367 0xc4bf "쒿" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50368 0xc4c0 "쓀" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50369 0xc4c1 "쓁" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50370 0xc4c2 "쓂" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50371 0xc4c3 "쓃" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50372 0xc4c4 "쓄" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50373 0xc4c5 "쓅" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50374 0xc4c6 "쓆" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50375 0xc4c7 "쓇" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50376 0xc4c8 "쓈" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50377 0xc4c9 "쓉" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50378 0xc4ca "쓊" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50379 0xc4cb "쓋" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50380 0xc4cc "쓌" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50381 0xc4cd "쓍" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50382 0xc4ce "쓎" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50383 0xc4cf "쓏" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50384 0xc4d0 "쓐" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50385 0xc4d1 "쓑" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50386 0xc4d2 "쓒" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50387 0xc4d3 "쓓" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50388 0xc4d4 "쓔" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 50389 0xc4d5 "쓕" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 50390 0xc4d6 "쓖" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 50391 0xc4d7 "쓗" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50392 0xc4d8 "쓘" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 50393 0xc4d9 "쓙" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 50394 0xc4da "쓚" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 50395 0xc4db "쓛" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 50396 0xc4dc "쓜" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50397 0xc4dd "쓝" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 50398 0xc4de "쓞" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 50399 0xc4df "쓟" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 50400 0xc4e0 "쓠" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50401 0xc4e1 "쓡" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50402 0xc4e2 "쓢" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 50403 0xc4e3 "쓣" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 50404 0xc4e4 "쓤" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 50405 0xc4e5 "쓥" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 50406 0xc4e6 "쓦" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50407 0xc4e7 "쓧" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 50408 0xc4e8 "쓨" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50409 0xc4e9 "쓩" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 50410 0xc4ea "쓪" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 50411 0xc4eb "쓫" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50412 0xc4ec "쓬" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 50413 0xc4ed "쓭" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50414 0xc4ee "쓮" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 50415 0xc4ef "쓯" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50416 0xc4f0 "쓰" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x0a,0x0a,0x11,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x28,0x28,0x44,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 50417 0xc4f1 "쓱" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50418 0xc4f2 "쓲" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50419 0xc4f3 "쓳" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50420 0xc4f4 "쓴" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 50421 0xc4f5 "쓵" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50422 0xc4f6 "쓶" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50423 0xc4f7 "쓷" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50424 0xc4f8 "쓸" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50425 0xc4f9 "쓹" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50426 0xc4fa "쓺" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50427 0xc4fb "쓻" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50428 0xc4fc "쓼" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50429 0xc4fd "쓽" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50430 0xc4fe "쓾" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50431 0xc4ff "쓿" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50432 0xc500 "씀" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50433 0xc501 "씁" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50434 0xc502 "씂" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50435 0xc503 "씃" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50436 0xc504 "씄" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50437 0xc505 "씅" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50438 0xc506 "씆" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50439 0xc507 "씇" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50440 0xc508 "씈" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50441 0xc509 "씉" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50442 0xc50a "씊" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50443 0xc50b "씋" */
+0x00,0x00,0x04,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x10,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50444 0xc50c "씌" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 50445 0xc50d "씍" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50446 0xc50e "씎" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50447 0xc50f "씏" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50448 0xc510 "씐" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50449 0xc511 "씑" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50450 0xc512 "씒" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50451 0xc513 "씓" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50452 0xc514 "씔" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50453 0xc515 "씕" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50454 0xc516 "씖" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50455 0xc517 "씗" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50456 0xc518 "씘" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50457 0xc519 "씙" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50458 0xc51a "씚" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50459 0xc51b "씛" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50460 0xc51c "씜" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50461 0xc51d "씝" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50462 0xc51e "씞" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50463 0xc51f "씟" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50464 0xc520 "씠" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50465 0xc521 "씡" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50466 0xc522 "씢" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50467 0xc523 "씣" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50468 0xc524 "씤" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50469 0xc525 "씥" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50470 0xc526 "씦" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50471 0xc527 "씧" */
+0x00,0x00,0x11,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50472 0xc528 "씨" */
+0x00,0x00,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 50473 0xc529 "씩" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50474 0xc52a "씪" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50475 0xc52b "씫" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50476 0xc52c "씬" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50477 0xc52d "씭" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50478 0xc52e "씮" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50479 0xc52f "씯" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50480 0xc530 "씰" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50481 0xc531 "씱" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50482 0xc532 "씲" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50483 0xc533 "씳" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50484 0xc534 "씴" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50485 0xc535 "씵" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50486 0xc536 "씶" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50487 0xc537 "씷" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50488 0xc538 "씸" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50489 0xc539 "씹" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50490 0xc53a "씺" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50491 0xc53b "씻" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50492 0xc53c "씼" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50493 0xc53d "씽" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50494 0xc53e "씾" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50495 0xc53f "씿" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50496 0xc540 "앀" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50497 0xc541 "앁" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50498 0xc542 "앂" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50499 0xc543 "앃" */
+0x00,0x00,0x11,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50500 0xc544 "아" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,
+/* 50501 0xc545 "악" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50502 0xc546 "앆" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50503 0xc547 "앇" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50504 0xc548 "안" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50505 0xc549 "앉" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50506 0xc54a "않" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50507 0xc54b "앋" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50508 0xc54c "알" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50509 0xc54d "앍" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50510 0xc54e "앎" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50511 0xc54f "앏" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50512 0xc550 "앐" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50513 0xc551 "앑" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50514 0xc552 "앒" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50515 0xc553 "앓" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50516 0xc554 "암" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50517 0xc555 "압" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50518 0xc556 "앖" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50519 0xc557 "앗" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50520 0xc558 "았" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50521 0xc559 "앙" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50522 0xc55a "앚" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50523 0xc55b "앛" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50524 0xc55c "앜" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50525 0xc55d "앝" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50526 0xc55e "앞" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50527 0xc55f "앟" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x84,0x87,0x84,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50528 0xc560 "애" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0x12,0x12,0x12,
+/* 50529 0xc561 "액" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50530 0xc562 "앢" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50531 0xc563 "앣" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50532 0xc564 "앤" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50533 0xc565 "앥" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50534 0xc566 "앦" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50535 0xc567 "앧" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50536 0xc568 "앨" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50537 0xc569 "앩" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50538 0xc56a "앪" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50539 0xc56b "앫" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50540 0xc56c "앬" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50541 0xc56d "앭" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50542 0xc56e "앮" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50543 0xc56f "앯" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50544 0xc570 "앰" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50545 0xc571 "앱" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50546 0xc572 "앲" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50547 0xc573 "앳" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50548 0xc574 "앴" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50549 0xc575 "앵" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50550 0xc576 "앶" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50551 0xc577 "앷" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50552 0xc578 "앸" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50553 0xc579 "앹" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50554 0xc57a "앺" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50555 0xc57b "앻" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x92,0x9e,0x92,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50556 0xc57c "야" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x87,0x84,0x84,0x87,0x84,0x04,0x04,0x04,0x04,0x04,
+/* 50557 0xc57d "약" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50558 0xc57e "앾" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50559 0xc57f "앿" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50560 0xc580 "얀" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50561 0xc581 "얁" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50562 0xc582 "얂" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50563 0xc583 "얃" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50564 0xc584 "얄" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50565 0xc585 "얅" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50566 0xc586 "얆" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50567 0xc587 "얇" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50568 0xc588 "얈" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50569 0xc589 "얉" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50570 0xc58a "얊" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50571 0xc58b "얋" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50572 0xc58c "얌" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50573 0xc58d "얍" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50574 0xc58e "얎" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50575 0xc58f "얏" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50576 0xc590 "얐" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50577 0xc591 "양" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50578 0xc592 "얒" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50579 0xc593 "얓" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50580 0xc594 "얔" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50581 0xc595 "얕" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50582 0xc596 "얖" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50583 0xc597 "얗" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x87,0x84,0x84,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50584 0xc598 "얘" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x9e,0x92,0x92,0x9e,0x92,0x12,0x12,0x12,0x12,0x12,
+/* 50585 0xc599 "얙" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50586 0xc59a "얚" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50587 0xc59b "얛" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50588 0xc59c "얜" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50589 0xc59d "얝" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50590 0xc59e "얞" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50591 0xc59f "얟" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50592 0xc5a0 "얠" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50593 0xc5a1 "얡" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50594 0xc5a2 "얢" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50595 0xc5a3 "얣" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50596 0xc5a4 "얤" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50597 0xc5a5 "얥" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50598 0xc5a6 "얦" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50599 0xc5a7 "얧" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50600 0xc5a8 "얨" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50601 0xc5a9 "얩" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50602 0xc5aa "얪" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50603 0xc5ab "얫" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50604 0xc5ac "얬" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50605 0xc5ad "얭" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50606 0xc5ae "얮" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50607 0xc5af "얯" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50608 0xc5b0 "얰" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50609 0xc5b1 "얱" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50610 0xc5b2 "얲" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50611 0xc5b3 "얳" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x9e,0x92,0x92,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50612 0xc5b4 "어" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x84,0xbc,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,
+/* 50613 0xc5b5 "억" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50614 0xc5b6 "얶" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50615 0xc5b7 "얷" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50616 0xc5b8 "언" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50617 0xc5b9 "얹" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50618 0xc5ba "얺" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50619 0xc5bb "얻" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50620 0xc5bc "얼" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50621 0xc5bd "얽" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50622 0xc5be "얾" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50623 0xc5bf "얿" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50624 0xc5c0 "엀" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50625 0xc5c1 "엁" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50626 0xc5c2 "엂" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50627 0xc5c3 "엃" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50628 0xc5c4 "엄" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50629 0xc5c5 "업" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50630 0xc5c6 "없" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50631 0xc5c7 "엇" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50632 0xc5c8 "었" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50633 0xc5c9 "엉" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50634 0xc5ca "엊" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50635 0xc5cb "엋" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50636 0xc5cc "엌" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50637 0xc5cd "엍" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50638 0xc5ce "엎" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50639 0xc5cf "엏" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x84,0xbc,0x84,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50640 0xc5d0 "에" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x92,0xf2,0x92,0x92,0x92,0x12,0x12,0x12,0x12,0x12,
+/* 50641 0xc5d1 "엑" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50642 0xc5d2 "엒" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50643 0xc5d3 "엓" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50644 0xc5d4 "엔" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50645 0xc5d5 "엕" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50646 0xc5d6 "엖" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50647 0xc5d7 "엗" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50648 0xc5d8 "엘" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50649 0xc5d9 "엙" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50650 0xc5da "엚" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50651 0xc5db "엛" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50652 0xc5dc "엜" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50653 0xc5dd "엝" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50654 0xc5de "엞" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50655 0xc5df "엟" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50656 0xc5e0 "엠" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50657 0xc5e1 "엡" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50658 0xc5e2 "엢" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50659 0xc5e3 "엣" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50660 0xc5e4 "엤" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50661 0xc5e5 "엥" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50662 0xc5e6 "엦" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50663 0xc5e7 "엧" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50664 0xc5e8 "엨" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50665 0xc5e9 "엩" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50666 0xc5ea "엪" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50667 0xc5eb "엫" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x92,0xf2,0x92,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50668 0xc5ec "여" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0xbc,0x84,0x84,0xbc,0x84,0x04,0x04,0x04,0x04,0x04,
+/* 50669 0xc5ed "역" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50670 0xc5ee "엮" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50671 0xc5ef "엯" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50672 0xc5f0 "연" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50673 0xc5f1 "엱" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50674 0xc5f2 "엲" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50675 0xc5f3 "엳" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50676 0xc5f4 "열" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50677 0xc5f5 "엵" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50678 0xc5f6 "엶" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50679 0xc5f7 "엷" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50680 0xc5f8 "엸" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50681 0xc5f9 "엹" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50682 0xc5fa "엺" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50683 0xc5fb "엻" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50684 0xc5fc "염" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50685 0xc5fd "엽" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50686 0xc5fe "엾" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50687 0xc5ff "엿" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50688 0xc600 "였" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50689 0xc601 "영" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50690 0xc602 "옂" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50691 0xc603 "옃" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50692 0xc604 "옄" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50693 0xc605 "옅" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50694 0xc606 "옆" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50695 0xc607 "옇" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xbc,0x84,0x84,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50696 0xc608 "예" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0xf2,0x92,0x92,0xf2,0x92,0x12,0x12,0x12,0x12,0x12,
+/* 50697 0xc609 "옉" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50698 0xc60a "옊" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50699 0xc60b "옋" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50700 0xc60c "옌" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50701 0xc60d "옍" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50702 0xc60e "옎" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50703 0xc60f "옏" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50704 0xc610 "옐" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50705 0xc611 "옑" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50706 0xc612 "옒" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50707 0xc613 "옓" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50708 0xc614 "옔" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50709 0xc615 "옕" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50710 0xc616 "옖" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50711 0xc617 "옗" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50712 0xc618 "옘" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50713 0xc619 "옙" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50714 0xc61a "옚" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50715 0xc61b "옛" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50716 0xc61c "옜" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50717 0xc61d "옝" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50718 0xc61e "옞" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50719 0xc61f "옟" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50720 0xc620 "옠" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50721 0xc621 "옡" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50722 0xc622 "옢" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50723 0xc623 "옣" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0xf2,0x92,0x92,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50724 0xc624 "오" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x08,0xf0,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 50725 0xc625 "옥" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50726 0xc626 "옦" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50727 0xc627 "옧" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50728 0xc628 "온" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 50729 0xc629 "옩" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50730 0xc62a "옪" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50731 0xc62b "옫" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50732 0xc62c "올" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50733 0xc62d "옭" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50734 0xc62e "옮" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50735 0xc62f "옯" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50736 0xc630 "옰" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50737 0xc631 "옱" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50738 0xc632 "옲" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50739 0xc633 "옳" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50740 0xc634 "옴" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50741 0xc635 "옵" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50742 0xc636 "옶" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50743 0xc637 "옷" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50744 0xc638 "옸" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50745 0xc639 "옹" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50746 0xc63a "옺" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50747 0xc63b "옻" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50748 0xc63c "옼" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50749 0xc63d "옽" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50750 0xc63e "옾" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50751 0xc63f "옿" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50752 0xc640 "와" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 50753 0xc641 "왁" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50754 0xc642 "왂" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50755 0xc643 "왃" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50756 0xc644 "완" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50757 0xc645 "왅" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50758 0xc646 "왆" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50759 0xc647 "왇" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50760 0xc648 "왈" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50761 0xc649 "왉" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50762 0xc64a "왊" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50763 0xc64b "왋" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50764 0xc64c "왌" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50765 0xc64d "왍" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50766 0xc64e "왎" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50767 0xc64f "왏" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50768 0xc650 "왐" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50769 0xc651 "왑" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50770 0xc652 "왒" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50771 0xc653 "왓" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50772 0xc654 "왔" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50773 0xc655 "왕" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50774 0xc656 "왖" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50775 0xc657 "왗" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50776 0xc658 "왘" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50777 0xc659 "왙" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50778 0xc65a "왚" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50779 0xc65b "왛" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x84,0x87,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50780 0xc65c "왜" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 50781 0xc65d "왝" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50782 0xc65e "왞" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50783 0xc65f "왟" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50784 0xc660 "왠" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 50785 0xc661 "왡" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50786 0xc662 "왢" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50787 0xc663 "왣" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50788 0xc664 "왤" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50789 0xc665 "왥" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50790 0xc666 "왦" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50791 0xc667 "왧" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50792 0xc668 "왨" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50793 0xc669 "왩" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50794 0xc66a "왪" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50795 0xc66b "왫" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50796 0xc66c "왬" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50797 0xc66d "왭" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50798 0xc66e "왮" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50799 0xc66f "왯" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50800 0xc670 "왰" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50801 0xc671 "왱" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50802 0xc672 "왲" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50803 0xc673 "왳" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50804 0xc674 "왴" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50805 0xc675 "왵" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50806 0xc676 "왶" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50807 0xc677 "왷" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x92,0x92,0x9e,0x12,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50808 0xc678 "외" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 50809 0xc679 "왹" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50810 0xc67a "왺" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50811 0xc67b "왻" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50812 0xc67c "왼" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50813 0xc67d "왽" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50814 0xc67e "왾" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50815 0xc67f "왿" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50816 0xc680 "욀" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50817 0xc681 "욁" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50818 0xc682 "욂" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50819 0xc683 "욃" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50820 0xc684 "욄" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50821 0xc685 "욅" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50822 0xc686 "욆" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50823 0xc687 "욇" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50824 0xc688 "욈" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50825 0xc689 "욉" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50826 0xc68a "욊" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50827 0xc68b "욋" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50828 0xc68c "욌" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50829 0xc68d "욍" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50830 0xc68e "욎" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50831 0xc68f "욏" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50832 0xc690 "욐" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50833 0xc691 "욑" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50834 0xc692 "욒" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50835 0xc693 "욓" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50836 0xc694 "요" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x08,0xf0,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 50837 0xc695 "욕" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50838 0xc696 "욖" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50839 0xc697 "욗" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50840 0xc698 "욘" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 50841 0xc699 "욙" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50842 0xc69a "욚" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50843 0xc69b "욛" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50844 0xc69c "욜" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50845 0xc69d "욝" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50846 0xc69e "욞" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50847 0xc69f "욟" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50848 0xc6a0 "욠" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50849 0xc6a1 "욡" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50850 0xc6a2 "욢" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50851 0xc6a3 "욣" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50852 0xc6a4 "욤" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50853 0xc6a5 "욥" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50854 0xc6a6 "욦" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50855 0xc6a7 "욧" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50856 0xc6a8 "욨" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50857 0xc6a9 "용" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50858 0xc6aa "욪" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50859 0xc6ab "욫" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50860 0xc6ac "욬" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50861 0xc6ad "욭" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50862 0xc6ae "욮" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50863 0xc6af "욯" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50864 0xc6b0 "우" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 50865 0xc6b1 "욱" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 50866 0xc6b2 "욲" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 50867 0xc6b3 "욳" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50868 0xc6b4 "운" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 50869 0xc6b5 "욵" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 50870 0xc6b6 "욶" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 50871 0xc6b7 "욷" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 50872 0xc6b8 "울" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50873 0xc6b9 "욹" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 50874 0xc6ba "욺" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 50875 0xc6bb "욻" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 50876 0xc6bc "욼" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50877 0xc6bd "욽" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50878 0xc6be "욾" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 50879 0xc6bf "욿" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 50880 0xc6c0 "움" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 50881 0xc6c1 "웁" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 50882 0xc6c2 "웂" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50883 0xc6c3 "웃" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 50884 0xc6c4 "웄" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 50885 0xc6c5 "웅" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 50886 0xc6c6 "웆" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 50887 0xc6c7 "웇" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50888 0xc6c8 "웈" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 50889 0xc6c9 "웉" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50890 0xc6ca "웊" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 50891 0xc6cb "웋" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50892 0xc6cc "워" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 50893 0xc6cd "웍" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50894 0xc6ce "웎" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50895 0xc6cf "웏" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50896 0xc6d0 "원" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 50897 0xc6d1 "웑" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50898 0xc6d2 "웒" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50899 0xc6d3 "웓" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50900 0xc6d4 "월" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50901 0xc6d5 "웕" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50902 0xc6d6 "웖" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50903 0xc6d7 "웗" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50904 0xc6d8 "웘" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50905 0xc6d9 "웙" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50906 0xc6da "웚" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50907 0xc6db "웛" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50908 0xc6dc "웜" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50909 0xc6dd "웝" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50910 0xc6de "웞" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50911 0xc6df "웟" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50912 0xc6e0 "웠" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50913 0xc6e1 "웡" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50914 0xc6e2 "웢" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50915 0xc6e3 "웣" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50916 0xc6e4 "웤" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50917 0xc6e5 "웥" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50918 0xc6e6 "웦" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50919 0xc6e7 "웧" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x84,0x9c,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50920 0xc6e8 "웨" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x12,0x92,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 50921 0xc6e9 "웩" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 50922 0xc6ea "웪" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 50923 0xc6eb "웫" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50924 0xc6ec "웬" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 50925 0xc6ed "웭" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 50926 0xc6ee "웮" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 50927 0xc6ef "웯" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 50928 0xc6f0 "웰" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 50929 0xc6f1 "웱" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 50930 0xc6f2 "웲" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 50931 0xc6f3 "웳" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 50932 0xc6f4 "웴" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 50933 0xc6f5 "웵" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 50934 0xc6f6 "웶" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 50935 0xc6f7 "웷" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 50936 0xc6f8 "웸" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 50937 0xc6f9 "웹" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 50938 0xc6fa "웺" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 50939 0xc6fb "웻" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 50940 0xc6fc "웼" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 50941 0xc6fd "웽" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 50942 0xc6fe "웾" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 50943 0xc6ff "웿" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 50944 0xc700 "윀" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 50945 0xc701 "윁" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 50946 0xc702 "윂" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 50947 0xc703 "윃" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x92,0x92,0xf2,0x12,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 50948 0xc704 "위" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 50949 0xc705 "윅" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 50950 0xc706 "윆" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50951 0xc707 "윇" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50952 0xc708 "윈" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 50953 0xc709 "윉" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 50954 0xc70a "윊" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50955 0xc70b "윋" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 50956 0xc70c "윌" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50957 0xc70d "윍" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 50958 0xc70e "윎" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 50959 0xc70f "윏" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 50960 0xc710 "윐" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50961 0xc711 "윑" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50962 0xc712 "윒" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 50963 0xc713 "윓" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 50964 0xc714 "윔" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 50965 0xc715 "윕" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 50966 0xc716 "윖" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50967 0xc717 "윗" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 50968 0xc718 "윘" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 50969 0xc719 "윙" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 50970 0xc71a "윚" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 50971 0xc71b "윛" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 50972 0xc71c "윜" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 50973 0xc71d "윝" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 50974 0xc71e "윞" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 50975 0xc71f "윟" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 50976 0xc720 "유" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 50977 0xc721 "육" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 50978 0xc722 "윢" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 50979 0xc723 "윣" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50980 0xc724 "윤" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 50981 0xc725 "윥" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 50982 0xc726 "윦" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 50983 0xc727 "윧" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 50984 0xc728 "율" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 50985 0xc729 "윩" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 50986 0xc72a "윪" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 50987 0xc72b "윫" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 50988 0xc72c "윬" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50989 0xc72d "윭" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 50990 0xc72e "윮" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 50991 0xc72f "윯" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 50992 0xc730 "윰" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 50993 0xc731 "윱" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 50994 0xc732 "윲" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50995 0xc733 "윳" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 50996 0xc734 "윴" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 50997 0xc735 "융" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 50998 0xc736 "윶" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 50999 0xc737 "윷" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51000 0xc738 "윸" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 51001 0xc739 "윹" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51002 0xc73a "윺" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 51003 0xc73b "윻" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51004 0xc73c "으" */
+0x00,0x00,0x00,0x07,0x08,0x10,0x10,0x10,0x08,0x07,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x08,0x04,0x04,0x04,0x08,0xf0,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 51005 0xc73d "윽" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51006 0xc73e "윾" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51007 0xc73f "윿" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51008 0xc740 "은" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 51009 0xc741 "읁" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51010 0xc742 "읂" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51011 0xc743 "읃" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51012 0xc744 "을" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51013 0xc745 "읅" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51014 0xc746 "읆" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51015 0xc747 "읇" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51016 0xc748 "읈" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51017 0xc749 "읉" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51018 0xc74a "읊" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51019 0xc74b "읋" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51020 0xc74c "음" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51021 0xc74d "읍" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51022 0xc74e "읎" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51023 0xc74f "읏" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51024 0xc750 "읐" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51025 0xc751 "응" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51026 0xc752 "읒" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51027 0xc753 "읓" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51028 0xc754 "읔" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51029 0xc755 "읕" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51030 0xc756 "읖" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51031 0xc757 "읗" */
+0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51032 0xc758 "의" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 51033 0xc759 "읙" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51034 0xc75a "읚" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51035 0xc75b "읛" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51036 0xc75c "읜" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51037 0xc75d "읝" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51038 0xc75e "읞" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51039 0xc75f "읟" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51040 0xc760 "읠" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51041 0xc761 "읡" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51042 0xc762 "읢" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51043 0xc763 "읣" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51044 0xc764 "읤" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51045 0xc765 "읥" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51046 0xc766 "읦" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51047 0xc767 "읧" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51048 0xc768 "읨" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51049 0xc769 "읩" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51050 0xc76a "읪" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51051 0xc76b "읫" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51052 0xc76c "읬" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51053 0xc76d "읭" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51054 0xc76e "읮" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51055 0xc76f "읯" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51056 0xc770 "읰" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51057 0xc771 "읱" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51058 0xc772 "읲" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51059 0xc773 "읳" */
+0x00,0x00,0x1f,0x20,0x20,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51060 0xc774 "이" */
+0x00,0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,
+/* 51061 0xc775 "익" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51062 0xc776 "읶" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51063 0xc777 "읷" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51064 0xc778 "인" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51065 0xc779 "읹" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51066 0xc77a "읺" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51067 0xc77b "읻" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51068 0xc77c "일" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51069 0xc77d "읽" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51070 0xc77e "읾" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51071 0xc77f "읿" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51072 0xc780 "잀" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51073 0xc781 "잁" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51074 0xc782 "잂" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51075 0xc783 "잃" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51076 0xc784 "임" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51077 0xc785 "입" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51078 0xc786 "잆" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51079 0xc787 "잇" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51080 0xc788 "있" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51081 0xc789 "잉" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51082 0xc78a "잊" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51083 0xc78b "잋" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51084 0xc78c "잌" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51085 0xc78d "잍" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51086 0xc78e "잎" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51087 0xc78f "잏" */
+0x00,0x00,0x0e,0x11,0x20,0x20,0x20,0x11,0x0e,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x84,0x84,0x84,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51088 0xc790 "자" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 51089 0xc791 "작" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51090 0xc792 "잒" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51091 0xc793 "잓" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51092 0xc794 "잔" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51093 0xc795 "잕" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51094 0xc796 "잖" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51095 0xc797 "잗" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51096 0xc798 "잘" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51097 0xc799 "잙" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51098 0xc79a "잚" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51099 0xc79b "잛" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51100 0xc79c "잜" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51101 0xc79d "잝" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51102 0xc79e "잞" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51103 0xc79f "잟" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51104 0xc7a0 "잠" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51105 0xc7a1 "잡" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51106 0xc7a2 "잢" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51107 0xc7a3 "잣" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51108 0xc7a4 "잤" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51109 0xc7a5 "장" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51110 0xc7a6 "잦" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51111 0xc7a7 "잧" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51112 0xc7a8 "잨" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51113 0xc7a9 "잩" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51114 0xc7aa "잪" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51115 0xc7ab "잫" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51116 0xc7ac "재" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 51117 0xc7ad "잭" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51118 0xc7ae "잮" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51119 0xc7af "잯" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51120 0xc7b0 "잰" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51121 0xc7b1 "잱" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51122 0xc7b2 "잲" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51123 0xc7b3 "잳" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51124 0xc7b4 "잴" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51125 0xc7b5 "잵" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51126 0xc7b6 "잶" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51127 0xc7b7 "잷" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51128 0xc7b8 "잸" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51129 0xc7b9 "잹" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51130 0xc7ba "잺" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51131 0xc7bb "잻" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51132 0xc7bc "잼" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51133 0xc7bd "잽" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51134 0xc7be "잾" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51135 0xc7bf "잿" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51136 0xc7c0 "쟀" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51137 0xc7c1 "쟁" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51138 0xc7c2 "쟂" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51139 0xc7c3 "쟃" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51140 0xc7c4 "쟄" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51141 0xc7c5 "쟅" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51142 0xc7c6 "쟆" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51143 0xc7c7 "쟇" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51144 0xc7c8 "쟈" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 51145 0xc7c9 "쟉" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51146 0xc7ca "쟊" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51147 0xc7cb "쟋" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51148 0xc7cc "쟌" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51149 0xc7cd "쟍" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51150 0xc7ce "쟎" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51151 0xc7cf "쟏" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51152 0xc7d0 "쟐" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51153 0xc7d1 "쟑" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51154 0xc7d2 "쟒" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51155 0xc7d3 "쟓" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51156 0xc7d4 "쟔" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51157 0xc7d5 "쟕" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51158 0xc7d6 "쟖" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51159 0xc7d7 "쟗" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51160 0xc7d8 "쟘" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51161 0xc7d9 "쟙" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51162 0xc7da "쟚" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51163 0xc7db "쟛" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51164 0xc7dc "쟜" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51165 0xc7dd "쟝" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51166 0xc7de "쟞" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51167 0xc7df "쟟" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51168 0xc7e0 "쟠" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51169 0xc7e1 "쟡" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51170 0xc7e2 "쟢" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51171 0xc7e3 "쟣" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51172 0xc7e4 "쟤" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 51173 0xc7e5 "쟥" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51174 0xc7e6 "쟦" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51175 0xc7e7 "쟧" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51176 0xc7e8 "쟨" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51177 0xc7e9 "쟩" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51178 0xc7ea "쟪" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51179 0xc7eb "쟫" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51180 0xc7ec "쟬" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51181 0xc7ed "쟭" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51182 0xc7ee "쟮" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51183 0xc7ef "쟯" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51184 0xc7f0 "쟰" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51185 0xc7f1 "쟱" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51186 0xc7f2 "쟲" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51187 0xc7f3 "쟳" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51188 0xc7f4 "쟴" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51189 0xc7f5 "쟵" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51190 0xc7f6 "쟶" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51191 0xc7f7 "쟷" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51192 0xc7f8 "쟸" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51193 0xc7f9 "쟹" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51194 0xc7fa "쟺" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51195 0xc7fb "쟻" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51196 0xc7fc "쟼" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51197 0xc7fd "쟽" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51198 0xc7fe "쟾" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51199 0xc7ff "쟿" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51200 0xc800 "저" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 51201 0xc801 "적" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51202 0xc802 "젂" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51203 0xc803 "젃" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51204 0xc804 "전" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51205 0xc805 "젅" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51206 0xc806 "젆" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51207 0xc807 "젇" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51208 0xc808 "절" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51209 0xc809 "젉" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51210 0xc80a "젊" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51211 0xc80b "젋" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51212 0xc80c "젌" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51213 0xc80d "젍" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51214 0xc80e "젎" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51215 0xc80f "젏" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51216 0xc810 "점" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51217 0xc811 "접" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51218 0xc812 "젒" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51219 0xc813 "젓" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51220 0xc814 "젔" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51221 0xc815 "정" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51222 0xc816 "젖" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51223 0xc817 "젗" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51224 0xc818 "젘" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51225 0xc819 "젙" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51226 0xc81a "젚" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51227 0xc81b "젛" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51228 0xc81c "제" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 51229 0xc81d "젝" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51230 0xc81e "젞" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51231 0xc81f "젟" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51232 0xc820 "젠" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51233 0xc821 "젡" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51234 0xc822 "젢" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51235 0xc823 "젣" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51236 0xc824 "젤" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51237 0xc825 "젥" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51238 0xc826 "젦" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51239 0xc827 "젧" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51240 0xc828 "젨" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51241 0xc829 "젩" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51242 0xc82a "젪" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51243 0xc82b "젫" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51244 0xc82c "젬" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51245 0xc82d "젭" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51246 0xc82e "젮" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51247 0xc82f "젯" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51248 0xc830 "젰" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51249 0xc831 "젱" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51250 0xc832 "젲" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51251 0xc833 "젳" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51252 0xc834 "젴" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51253 0xc835 "젵" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51254 0xc836 "젶" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51255 0xc837 "젷" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51256 0xc838 "져" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 51257 0xc839 "젹" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51258 0xc83a "젺" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51259 0xc83b "젻" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51260 0xc83c "젼" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51261 0xc83d "젽" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51262 0xc83e "젾" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51263 0xc83f "젿" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51264 0xc840 "졀" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51265 0xc841 "졁" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51266 0xc842 "졂" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51267 0xc843 "졃" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51268 0xc844 "졄" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51269 0xc845 "졅" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51270 0xc846 "졆" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51271 0xc847 "졇" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51272 0xc848 "졈" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51273 0xc849 "졉" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51274 0xc84a "졊" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51275 0xc84b "졋" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51276 0xc84c "졌" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51277 0xc84d "졍" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51278 0xc84e "졎" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51279 0xc84f "졏" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51280 0xc850 "졐" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51281 0xc851 "졑" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51282 0xc852 "졒" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51283 0xc853 "졓" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51284 0xc854 "졔" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 51285 0xc855 "졕" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51286 0xc856 "졖" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51287 0xc857 "졗" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51288 0xc858 "졘" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51289 0xc859 "졙" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51290 0xc85a "졚" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51291 0xc85b "졛" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51292 0xc85c "졜" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51293 0xc85d "졝" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51294 0xc85e "졞" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51295 0xc85f "졟" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51296 0xc860 "졠" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51297 0xc861 "졡" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51298 0xc862 "졢" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51299 0xc863 "졣" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51300 0xc864 "졤" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51301 0xc865 "졥" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51302 0xc866 "졦" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51303 0xc867 "졧" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51304 0xc868 "졨" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51305 0xc869 "졩" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51306 0xc86a "졪" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51307 0xc86b "졫" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51308 0xc86c "졬" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51309 0xc86d "졭" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51310 0xc86e "졮" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51311 0xc86f "졯" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51312 0xc870 "조" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x01,0x02,0x04,0x18,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x40,0x20,0x10,0x0c,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 51313 0xc871 "족" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51314 0xc872 "졲" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51315 0xc873 "졳" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51316 0xc874 "존" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 51317 0xc875 "졵" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51318 0xc876 "졶" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51319 0xc877 "졷" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51320 0xc878 "졸" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51321 0xc879 "졹" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51322 0xc87a "졺" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51323 0xc87b "졻" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51324 0xc87c "졼" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51325 0xc87d "졽" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51326 0xc87e "졾" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51327 0xc87f "졿" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51328 0xc880 "좀" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51329 0xc881 "좁" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51330 0xc882 "좂" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51331 0xc883 "좃" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51332 0xc884 "좄" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51333 0xc885 "종" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51334 0xc886 "좆" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51335 0xc887 "좇" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51336 0xc888 "좈" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51337 0xc889 "좉" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51338 0xc88a "좊" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51339 0xc88b "좋" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51340 0xc88c "좌" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 51341 0xc88d "좍" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51342 0xc88e "좎" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51343 0xc88f "좏" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51344 0xc890 "좐" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51345 0xc891 "좑" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51346 0xc892 "좒" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51347 0xc893 "좓" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51348 0xc894 "좔" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51349 0xc895 "좕" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51350 0xc896 "좖" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51351 0xc897 "좗" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51352 0xc898 "좘" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51353 0xc899 "좙" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51354 0xc89a "좚" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51355 0xc89b "좛" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51356 0xc89c "좜" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51357 0xc89d "좝" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51358 0xc89e "좞" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51359 0xc89f "좟" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51360 0xc8a0 "좠" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51361 0xc8a1 "좡" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51362 0xc8a2 "좢" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51363 0xc8a3 "좣" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51364 0xc8a4 "좤" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51365 0xc8a5 "좥" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51366 0xc8a6 "좦" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51367 0xc8a7 "좧" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51368 0xc8a8 "좨" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 51369 0xc8a9 "좩" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51370 0xc8aa "좪" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51371 0xc8ab "좫" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51372 0xc8ac "좬" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51373 0xc8ad "좭" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51374 0xc8ae "좮" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51375 0xc8af "좯" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51376 0xc8b0 "좰" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51377 0xc8b1 "좱" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51378 0xc8b2 "좲" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51379 0xc8b3 "좳" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51380 0xc8b4 "좴" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51381 0xc8b5 "좵" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51382 0xc8b6 "좶" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51383 0xc8b7 "좷" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51384 0xc8b8 "좸" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51385 0xc8b9 "좹" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51386 0xc8ba "좺" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51387 0xc8bb "좻" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51388 0xc8bc "좼" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51389 0xc8bd "좽" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51390 0xc8be "좾" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51391 0xc8bf "좿" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51392 0xc8c0 "죀" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51393 0xc8c1 "죁" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51394 0xc8c2 "죂" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51395 0xc8c3 "죃" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51396 0xc8c4 "죄" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 51397 0xc8c5 "죅" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51398 0xc8c6 "죆" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51399 0xc8c7 "죇" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51400 0xc8c8 "죈" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51401 0xc8c9 "죉" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51402 0xc8ca "죊" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51403 0xc8cb "죋" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51404 0xc8cc "죌" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51405 0xc8cd "죍" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51406 0xc8ce "죎" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51407 0xc8cf "죏" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51408 0xc8d0 "죐" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51409 0xc8d1 "죑" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51410 0xc8d2 "죒" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51411 0xc8d3 "죓" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51412 0xc8d4 "죔" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51413 0xc8d5 "죕" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51414 0xc8d6 "죖" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51415 0xc8d7 "죗" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51416 0xc8d8 "죘" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51417 0xc8d9 "죙" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51418 0xc8da "죚" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51419 0xc8db "죛" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51420 0xc8dc "죜" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51421 0xc8dd "죝" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51422 0xc8de "죞" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51423 0xc8df "죟" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51424 0xc8e0 "죠" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x01,0x02,0x04,0x18,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x40,0x20,0x10,0x0c,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 51425 0xc8e1 "죡" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51426 0xc8e2 "죢" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51427 0xc8e3 "죣" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51428 0xc8e4 "죤" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 51429 0xc8e5 "죥" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51430 0xc8e6 "죦" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51431 0xc8e7 "죧" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51432 0xc8e8 "죨" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51433 0xc8e9 "죩" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51434 0xc8ea "죪" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51435 0xc8eb "죫" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51436 0xc8ec "죬" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51437 0xc8ed "죭" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51438 0xc8ee "죮" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51439 0xc8ef "죯" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51440 0xc8f0 "죰" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51441 0xc8f1 "죱" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51442 0xc8f2 "죲" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51443 0xc8f3 "죳" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51444 0xc8f4 "죴" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51445 0xc8f5 "죵" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51446 0xc8f6 "죶" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51447 0xc8f7 "죷" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51448 0xc8f8 "죸" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51449 0xc8f9 "죹" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51450 0xc8fa "죺" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51451 0xc8fb "죻" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51452 0xc8fc "주" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 51453 0xc8fd "죽" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 51454 0xc8fe "죾" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 51455 0xc8ff "죿" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 51456 0xc900 "준" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 51457 0xc901 "줁" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 51458 0xc902 "줂" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 51459 0xc903 "줃" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 51460 0xc904 "줄" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51461 0xc905 "줅" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 51462 0xc906 "줆" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 51463 0xc907 "줇" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 51464 0xc908 "줈" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 51465 0xc909 "줉" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51466 0xc90a "줊" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 51467 0xc90b "줋" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 51468 0xc90c "줌" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 51469 0xc90d "줍" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 51470 0xc90e "줎" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 51471 0xc90f "줏" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 51472 0xc910 "줐" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 51473 0xc911 "중" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 51474 0xc912 "줒" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 51475 0xc913 "줓" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51476 0xc914 "줔" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 51477 0xc915 "줕" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51478 0xc916 "줖" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 51479 0xc917 "줗" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51480 0xc918 "줘" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 51481 0xc919 "줙" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51482 0xc91a "줚" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51483 0xc91b "줛" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51484 0xc91c "줜" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 51485 0xc91d "줝" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51486 0xc91e "줞" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51487 0xc91f "줟" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51488 0xc920 "줠" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51489 0xc921 "줡" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51490 0xc922 "줢" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51491 0xc923 "줣" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51492 0xc924 "줤" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51493 0xc925 "줥" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51494 0xc926 "줦" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51495 0xc927 "줧" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51496 0xc928 "줨" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51497 0xc929 "줩" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51498 0xc92a "줪" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51499 0xc92b "줫" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51500 0xc92c "줬" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51501 0xc92d "줭" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51502 0xc92e "줮" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51503 0xc92f "줯" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51504 0xc930 "줰" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51505 0xc931 "줱" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51506 0xc932 "줲" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51507 0xc933 "줳" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51508 0xc934 "줴" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 51509 0xc935 "줵" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51510 0xc936 "줶" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51511 0xc937 "줷" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51512 0xc938 "줸" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 51513 0xc939 "줹" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51514 0xc93a "줺" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51515 0xc93b "줻" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51516 0xc93c "줼" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51517 0xc93d "줽" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51518 0xc93e "줾" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51519 0xc93f "줿" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51520 0xc940 "쥀" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51521 0xc941 "쥁" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51522 0xc942 "쥂" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51523 0xc943 "쥃" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51524 0xc944 "쥄" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51525 0xc945 "쥅" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51526 0xc946 "쥆" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51527 0xc947 "쥇" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51528 0xc948 "쥈" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51529 0xc949 "쥉" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51530 0xc94a "쥊" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51531 0xc94b "쥋" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51532 0xc94c "쥌" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51533 0xc94d "쥍" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51534 0xc94e "쥎" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51535 0xc94f "쥏" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51536 0xc950 "쥐" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 51537 0xc951 "쥑" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51538 0xc952 "쥒" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51539 0xc953 "쥓" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51540 0xc954 "쥔" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51541 0xc955 "쥕" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51542 0xc956 "쥖" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51543 0xc957 "쥗" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51544 0xc958 "쥘" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51545 0xc959 "쥙" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51546 0xc95a "쥚" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51547 0xc95b "쥛" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51548 0xc95c "쥜" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51549 0xc95d "쥝" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51550 0xc95e "쥞" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51551 0xc95f "쥟" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51552 0xc960 "쥠" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51553 0xc961 "쥡" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51554 0xc962 "쥢" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51555 0xc963 "쥣" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51556 0xc964 "쥤" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51557 0xc965 "쥥" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51558 0xc966 "쥦" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51559 0xc967 "쥧" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51560 0xc968 "쥨" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51561 0xc969 "쥩" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51562 0xc96a "쥪" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51563 0xc96b "쥫" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51564 0xc96c "쥬" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 51565 0xc96d "쥭" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 51566 0xc96e "쥮" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 51567 0xc96f "쥯" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 51568 0xc970 "쥰" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 51569 0xc971 "쥱" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 51570 0xc972 "쥲" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 51571 0xc973 "쥳" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 51572 0xc974 "쥴" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51573 0xc975 "쥵" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 51574 0xc976 "쥶" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 51575 0xc977 "쥷" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 51576 0xc978 "쥸" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 51577 0xc979 "쥹" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51578 0xc97a "쥺" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 51579 0xc97b "쥻" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 51580 0xc97c "쥼" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 51581 0xc97d "쥽" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 51582 0xc97e "쥾" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 51583 0xc97f "쥿" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 51584 0xc980 "즀" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 51585 0xc981 "즁" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 51586 0xc982 "즂" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 51587 0xc983 "즃" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51588 0xc984 "즄" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 51589 0xc985 "즅" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51590 0xc986 "즆" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 51591 0xc987 "즇" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51592 0xc988 "즈" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x01,0x02,0x04,0x18,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x80,0x80,0x40,0x20,0x10,0x0c,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 51593 0xc989 "즉" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51594 0xc98a "즊" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51595 0xc98b "즋" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51596 0xc98c "즌" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 51597 0xc98d "즍" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51598 0xc98e "즎" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51599 0xc98f "즏" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51600 0xc990 "즐" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51601 0xc991 "즑" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51602 0xc992 "즒" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51603 0xc993 "즓" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51604 0xc994 "즔" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51605 0xc995 "즕" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51606 0xc996 "즖" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51607 0xc997 "즗" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51608 0xc998 "즘" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51609 0xc999 "즙" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51610 0xc99a "즚" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51611 0xc99b "즛" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51612 0xc99c "즜" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51613 0xc99d "증" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51614 0xc99e "즞" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51615 0xc99f "즟" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51616 0xc9a0 "즠" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51617 0xc9a1 "즡" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51618 0xc9a2 "즢" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51619 0xc9a3 "즣" */
+0x00,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51620 0xc9a4 "즤" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 51621 0xc9a5 "즥" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51622 0xc9a6 "즦" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51623 0xc9a7 "즧" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51624 0xc9a8 "즨" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51625 0xc9a9 "즩" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51626 0xc9aa "즪" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51627 0xc9ab "즫" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51628 0xc9ac "즬" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51629 0xc9ad "즭" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51630 0xc9ae "즮" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51631 0xc9af "즯" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51632 0xc9b0 "즰" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51633 0xc9b1 "즱" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51634 0xc9b2 "즲" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51635 0xc9b3 "즳" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51636 0xc9b4 "즴" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51637 0xc9b5 "즵" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51638 0xc9b6 "즶" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51639 0xc9b7 "즷" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51640 0xc9b8 "즸" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51641 0xc9b9 "즹" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51642 0xc9ba "즺" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51643 0xc9bb "즻" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51644 0xc9bc "즼" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51645 0xc9bd "즽" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51646 0xc9be "즾" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51647 0xc9bf "즿" */
+0x00,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51648 0xc9c0 "지" */
+0x00,0x00,0x00,0x3f,0x04,0x04,0x04,0x0a,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 51649 0xc9c1 "직" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51650 0xc9c2 "짂" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51651 0xc9c3 "짃" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51652 0xc9c4 "진" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51653 0xc9c5 "짅" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51654 0xc9c6 "짆" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51655 0xc9c7 "짇" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51656 0xc9c8 "질" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51657 0xc9c9 "짉" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51658 0xc9ca "짊" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51659 0xc9cb "짋" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51660 0xc9cc "짌" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51661 0xc9cd "짍" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51662 0xc9ce "짎" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51663 0xc9cf "짏" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51664 0xc9d0 "짐" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51665 0xc9d1 "집" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51666 0xc9d2 "짒" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51667 0xc9d3 "짓" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51668 0xc9d4 "짔" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51669 0xc9d5 "징" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51670 0xc9d6 "짖" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51671 0xc9d7 "짗" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51672 0xc9d8 "짘" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51673 0xc9d9 "짙" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51674 0xc9da "짚" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51675 0xc9db "짛" */
+0x00,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51676 0xc9dc "짜" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x04,0x07,0x04,0x84,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 51677 0xc9dd "짝" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51678 0xc9de "짞" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51679 0xc9df "짟" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51680 0xc9e0 "짠" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51681 0xc9e1 "짡" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51682 0xc9e2 "짢" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51683 0xc9e3 "짣" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51684 0xc9e4 "짤" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51685 0xc9e5 "짥" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51686 0xc9e6 "짦" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51687 0xc9e7 "짧" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51688 0xc9e8 "짨" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51689 0xc9e9 "짩" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51690 0xc9ea "짪" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51691 0xc9eb "짫" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51692 0xc9ec "짬" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51693 0xc9ed "짭" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51694 0xc9ee "짮" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51695 0xc9ef "짯" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51696 0xc9f0 "짰" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51697 0xc9f1 "짱" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51698 0xc9f2 "짲" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51699 0xc9f3 "짳" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51700 0xc9f4 "짴" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51701 0xc9f5 "짵" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51702 0xc9f6 "짶" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51703 0xc9f7 "짷" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x07,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51704 0xc9f8 "째" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x12,0x12,0x1e,0x12,0x92,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 51705 0xc9f9 "짹" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51706 0xc9fa "짺" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51707 0xc9fb "짻" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51708 0xc9fc "짼" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51709 0xc9fd "짽" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51710 0xc9fe "짾" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51711 0xc9ff "짿" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51712 0xca00 "쨀" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51713 0xca01 "쨁" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51714 0xca02 "쨂" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51715 0xca03 "쨃" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51716 0xca04 "쨄" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51717 0xca05 "쨅" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51718 0xca06 "쨆" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51719 0xca07 "쨇" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51720 0xca08 "쨈" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51721 0xca09 "쨉" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51722 0xca0a "쨊" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51723 0xca0b "쨋" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51724 0xca0c "쨌" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51725 0xca0d "쨍" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51726 0xca0e "쨎" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51727 0xca0f "쨏" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51728 0xca10 "쨐" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51729 0xca11 "쨑" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51730 0xca12 "쨒" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51731 0xca13 "쨓" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0xd2,0x12,0x12,0x1e,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51732 0xca14 "쨔" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x07,0x04,0x04,0x87,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 51733 0xca15 "쨕" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51734 0xca16 "쨖" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51735 0xca17 "쨗" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51736 0xca18 "쨘" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51737 0xca19 "쨙" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51738 0xca1a "쨚" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51739 0xca1b "쨛" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51740 0xca1c "쨜" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51741 0xca1d "쨝" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51742 0xca1e "쨞" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51743 0xca1f "쨟" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51744 0xca20 "쨠" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51745 0xca21 "쨡" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51746 0xca22 "쨢" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51747 0xca23 "쨣" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51748 0xca24 "쨤" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51749 0xca25 "쨥" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51750 0xca26 "쨦" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51751 0xca27 "쨧" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51752 0xca28 "쨨" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51753 0xca29 "쨩" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51754 0xca2a "쨪" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51755 0xca2b "쨫" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51756 0xca2c "쨬" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51757 0xca2d "쨭" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51758 0xca2e "쨮" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51759 0xca2f "쨯" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x07,0x04,0x84,0x87,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51760 0xca30 "쨰" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x12,0x1e,0x12,0x12,0x9e,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 51761 0xca31 "쨱" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51762 0xca32 "쨲" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51763 0xca33 "쨳" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51764 0xca34 "쨴" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51765 0xca35 "쨵" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51766 0xca36 "쨶" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51767 0xca37 "쨷" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51768 0xca38 "쨸" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51769 0xca39 "쨹" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51770 0xca3a "쨺" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51771 0xca3b "쨻" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51772 0xca3c "쨼" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51773 0xca3d "쨽" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51774 0xca3e "쨾" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51775 0xca3f "쨿" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51776 0xca40 "쩀" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51777 0xca41 "쩁" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51778 0xca42 "쩂" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51779 0xca43 "쩃" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51780 0xca44 "쩄" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51781 0xca45 "쩅" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51782 0xca46 "쩆" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51783 0xca47 "쩇" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51784 0xca48 "쩈" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51785 0xca49 "쩉" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51786 0xca4a "쩊" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51787 0xca4b "쩋" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0xd2,0x12,0x1e,0x12,0x92,0x9e,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51788 0xca4c "쩌" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x04,0x3c,0x04,0x84,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 51789 0xca4d "쩍" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51790 0xca4e "쩎" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51791 0xca4f "쩏" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51792 0xca50 "쩐" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51793 0xca51 "쩑" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51794 0xca52 "쩒" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51795 0xca53 "쩓" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51796 0xca54 "쩔" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51797 0xca55 "쩕" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51798 0xca56 "쩖" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51799 0xca57 "쩗" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51800 0xca58 "쩘" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51801 0xca59 "쩙" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51802 0xca5a "쩚" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51803 0xca5b "쩛" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51804 0xca5c "쩜" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51805 0xca5d "쩝" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51806 0xca5e "쩞" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51807 0xca5f "쩟" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51808 0xca60 "쩠" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51809 0xca61 "쩡" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51810 0xca62 "쩢" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51811 0xca63 "쩣" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51812 0xca64 "쩤" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51813 0xca65 "쩥" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51814 0xca66 "쩦" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51815 0xca67 "쩧" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x3c,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51816 0xca68 "쩨" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x12,0x12,0x72,0x12,0x92,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 51817 0xca69 "쩩" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51818 0xca6a "쩪" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51819 0xca6b "쩫" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51820 0xca6c "쩬" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51821 0xca6d "쩭" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51822 0xca6e "쩮" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51823 0xca6f "쩯" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51824 0xca70 "쩰" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51825 0xca71 "쩱" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51826 0xca72 "쩲" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51827 0xca73 "쩳" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51828 0xca74 "쩴" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51829 0xca75 "쩵" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51830 0xca76 "쩶" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51831 0xca77 "쩷" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51832 0xca78 "쩸" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51833 0xca79 "쩹" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51834 0xca7a "쩺" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51835 0xca7b "쩻" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51836 0xca7c "쩼" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51837 0xca7d "쩽" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51838 0xca7e "쩾" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51839 0xca7f "쩿" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51840 0xca80 "쪀" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51841 0xca81 "쪁" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51842 0xca82 "쪂" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51843 0xca83 "쪃" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0xd2,0x12,0x12,0x72,0x92,0x92,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51844 0xca84 "쪄" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x3c,0x04,0x04,0xbc,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 51845 0xca85 "쪅" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51846 0xca86 "쪆" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51847 0xca87 "쪇" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51848 0xca88 "쪈" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51849 0xca89 "쪉" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51850 0xca8a "쪊" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51851 0xca8b "쪋" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51852 0xca8c "쪌" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51853 0xca8d "쪍" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51854 0xca8e "쪎" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51855 0xca8f "쪏" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51856 0xca90 "쪐" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51857 0xca91 "쪑" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51858 0xca92 "쪒" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51859 0xca93 "쪓" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51860 0xca94 "쪔" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51861 0xca95 "쪕" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51862 0xca96 "쪖" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51863 0xca97 "쪗" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51864 0xca98 "쪘" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51865 0xca99 "쪙" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51866 0xca9a "쪚" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51867 0xca9b "쪛" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51868 0xca9c "쪜" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51869 0xca9d "쪝" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51870 0xca9e "쪞" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51871 0xca9f "쪟" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x3c,0x04,0x84,0xbc,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51872 0xcaa0 "쪠" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x12,0x72,0x12,0x12,0xf2,0x92,0x92,0x52,0x12,0x12,0x12,
+/* 51873 0xcaa1 "쪡" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51874 0xcaa2 "쪢" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51875 0xcaa3 "쪣" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51876 0xcaa4 "쪤" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51877 0xcaa5 "쪥" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51878 0xcaa6 "쪦" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51879 0xcaa7 "쪧" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51880 0xcaa8 "쪨" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51881 0xcaa9 "쪩" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51882 0xcaaa "쪪" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51883 0xcaab "쪫" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51884 0xcaac "쪬" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51885 0xcaad "쪭" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51886 0xcaae "쪮" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51887 0xcaaf "쪯" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51888 0xcab0 "쪰" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51889 0xcab1 "쪱" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51890 0xcab2 "쪲" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51891 0xcab3 "쪳" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51892 0xcab4 "쪴" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51893 0xcab5 "쪵" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51894 0xcab6 "쪶" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51895 0xcab7 "쪷" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51896 0xcab8 "쪸" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51897 0xcab9 "쪹" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51898 0xcaba "쪺" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51899 0xcabb "쪻" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0xd2,0x12,0x72,0x12,0x92,0xf2,0x52,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51900 0xcabc "쪼" */
+0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x0a,0x0a,0x11,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x28,0x28,0x44,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 51901 0xcabd "쪽" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51902 0xcabe "쪾" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51903 0xcabf "쪿" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51904 0xcac0 "쫀" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 51905 0xcac1 "쫁" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51906 0xcac2 "쫂" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51907 0xcac3 "쫃" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51908 0xcac4 "쫄" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51909 0xcac5 "쫅" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51910 0xcac6 "쫆" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51911 0xcac7 "쫇" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51912 0xcac8 "쫈" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51913 0xcac9 "쫉" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51914 0xcaca "쫊" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51915 0xcacb "쫋" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51916 0xcacc "쫌" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51917 0xcacd "쫍" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51918 0xcace "쫎" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51919 0xcacf "쫏" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51920 0xcad0 "쫐" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51921 0xcad1 "쫑" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51922 0xcad2 "쫒" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51923 0xcad3 "쫓" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51924 0xcad4 "쫔" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51925 0xcad5 "쫕" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51926 0xcad6 "쫖" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51927 0xcad7 "쫗" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51928 0xcad8 "쫘" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x04,0x87,0x84,0x44,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 51929 0xcad9 "쫙" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51930 0xcada "쫚" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51931 0xcadb "쫛" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51932 0xcadc "쫜" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51933 0xcadd "쫝" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51934 0xcade "쫞" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51935 0xcadf "쫟" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51936 0xcae0 "쫠" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51937 0xcae1 "쫡" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51938 0xcae2 "쫢" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51939 0xcae3 "쫣" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51940 0xcae4 "쫤" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51941 0xcae5 "쫥" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51942 0xcae6 "쫦" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51943 0xcae7 "쫧" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51944 0xcae8 "쫨" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 51945 0xcae9 "쫩" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 51946 0xcaea "쫪" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51947 0xcaeb "쫫" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 51948 0xcaec "쫬" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51949 0xcaed "쫭" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 51950 0xcaee "쫮" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 51951 0xcaef "쫯" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 51952 0xcaf0 "쫰" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 51953 0xcaf1 "쫱" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 51954 0xcaf2 "쫲" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 51955 0xcaf3 "쫳" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x87,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 51956 0xcaf4 "쫴" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x12,0x12,0x9e,0x92,0x52,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 51957 0xcaf5 "쫵" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 51958 0xcaf6 "쫶" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 51959 0xcaf7 "쫷" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51960 0xcaf8 "쫸" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 51961 0xcaf9 "쫹" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 51962 0xcafa "쫺" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 51963 0xcafb "쫻" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 51964 0xcafc "쫼" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 51965 0xcafd "쫽" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 51966 0xcafe "쫾" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 51967 0xcaff "쫿" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 51968 0xcb00 "쬀" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 51969 0xcb01 "쬁" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 51970 0xcb02 "쬂" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 51971 0xcb03 "쬃" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 51972 0xcb04 "쬄" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 51973 0xcb05 "쬅" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 51974 0xcb06 "쬆" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 51975 0xcb07 "쬇" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 51976 0xcb08 "쬈" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 51977 0xcb09 "쬉" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 51978 0xcb0a "쬊" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 51979 0xcb0b "쬋" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 51980 0xcb0c "쬌" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 51981 0xcb0d "쬍" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 51982 0xcb0e "쬎" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 51983 0xcb0f "쬏" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0xd2,0x12,0x12,0x9e,0x52,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 51984 0xcb10 "쬐" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 51985 0xcb11 "쬑" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 51986 0xcb12 "쬒" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51987 0xcb13 "쬓" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51988 0xcb14 "쬔" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 51989 0xcb15 "쬕" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 51990 0xcb16 "쬖" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 51991 0xcb17 "쬗" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 51992 0xcb18 "쬘" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 51993 0xcb19 "쬙" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 51994 0xcb1a "쬚" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 51995 0xcb1b "쬛" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 51996 0xcb1c "쬜" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 51997 0xcb1d "쬝" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 51998 0xcb1e "쬞" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 51999 0xcb1f "쬟" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52000 0xcb20 "쬠" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52001 0xcb21 "쬡" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52002 0xcb22 "쬢" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52003 0xcb23 "쬣" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52004 0xcb24 "쬤" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52005 0xcb25 "쬥" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52006 0xcb26 "쬦" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52007 0xcb27 "쬧" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52008 0xcb28 "쬨" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52009 0xcb29 "쬩" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52010 0xcb2a "쬪" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52011 0xcb2b "쬫" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52012 0xcb2c "쬬" */
+0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x0a,0x0a,0x11,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x28,0x28,0x44,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 52013 0xcb2d "쬭" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52014 0xcb2e "쬮" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52015 0xcb2f "쬯" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52016 0xcb30 "쬰" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 52017 0xcb31 "쬱" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52018 0xcb32 "쬲" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52019 0xcb33 "쬳" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52020 0xcb34 "쬴" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52021 0xcb35 "쬵" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52022 0xcb36 "쬶" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52023 0xcb37 "쬷" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52024 0xcb38 "쬸" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52025 0xcb39 "쬹" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52026 0xcb3a "쬺" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52027 0xcb3b "쬻" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52028 0xcb3c "쬼" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52029 0xcb3d "쬽" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52030 0xcb3e "쬾" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52031 0xcb3f "쬿" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52032 0xcb40 "쭀" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52033 0xcb41 "쭁" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52034 0xcb42 "쭂" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52035 0xcb43 "쭃" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52036 0xcb44 "쭄" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52037 0xcb45 "쭅" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52038 0xcb46 "쭆" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52039 0xcb47 "쭇" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52040 0xcb48 "쭈" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 52041 0xcb49 "쭉" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 52042 0xcb4a "쭊" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 52043 0xcb4b "쭋" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52044 0xcb4c "쭌" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 52045 0xcb4d "쭍" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 52046 0xcb4e "쭎" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 52047 0xcb4f "쭏" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 52048 0xcb50 "쭐" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52049 0xcb51 "쭑" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 52050 0xcb52 "쭒" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 52051 0xcb53 "쭓" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 52052 0xcb54 "쭔" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52053 0xcb55 "쭕" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52054 0xcb56 "쭖" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 52055 0xcb57 "쭗" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 52056 0xcb58 "쭘" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 52057 0xcb59 "쭙" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 52058 0xcb5a "쭚" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52059 0xcb5b "쭛" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 52060 0xcb5c "쭜" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52061 0xcb5d "쭝" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 52062 0xcb5e "쭞" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 52063 0xcb5f "쭟" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52064 0xcb60 "쭠" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 52065 0xcb61 "쭡" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52066 0xcb62 "쭢" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 52067 0xcb63 "쭣" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52068 0xcb64 "쭤" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 52069 0xcb65 "쭥" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52070 0xcb66 "쭦" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52071 0xcb67 "쭧" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52072 0xcb68 "쭨" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 52073 0xcb69 "쭩" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52074 0xcb6a "쭪" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52075 0xcb6b "쭫" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52076 0xcb6c "쭬" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52077 0xcb6d "쭭" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52078 0xcb6e "쭮" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52079 0xcb6f "쭯" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52080 0xcb70 "쭰" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52081 0xcb71 "쭱" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52082 0xcb72 "쭲" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52083 0xcb73 "쭳" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52084 0xcb74 "쭴" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52085 0xcb75 "쭵" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52086 0xcb76 "쭶" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52087 0xcb77 "쭷" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52088 0xcb78 "쭸" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52089 0xcb79 "쭹" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52090 0xcb7a "쭺" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52091 0xcb7b "쭻" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52092 0xcb7c "쭼" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52093 0xcb7d "쭽" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52094 0xcb7e "쭾" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52095 0xcb7f "쭿" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x9c,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52096 0xcb80 "쮀" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xd2,0x12,0x12,0x92,0x52,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 52097 0xcb81 "쮁" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52098 0xcb82 "쮂" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52099 0xcb83 "쮃" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52100 0xcb84 "쮄" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0x92,0x52,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 52101 0xcb85 "쮅" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52102 0xcb86 "쮆" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52103 0xcb87 "쮇" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52104 0xcb88 "쮈" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52105 0xcb89 "쮉" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52106 0xcb8a "쮊" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52107 0xcb8b "쮋" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52108 0xcb8c "쮌" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52109 0xcb8d "쮍" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52110 0xcb8e "쮎" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52111 0xcb8f "쮏" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52112 0xcb90 "쮐" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52113 0xcb91 "쮑" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52114 0xcb92 "쮒" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52115 0xcb93 "쮓" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52116 0xcb94 "쮔" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52117 0xcb95 "쮕" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52118 0xcb96 "쮖" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52119 0xcb97 "쮗" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52120 0xcb98 "쮘" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52121 0xcb99 "쮙" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52122 0xcb9a "쮚" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52123 0xcb9b "쮛" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0xd2,0x12,0x12,0xf2,0x52,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52124 0xcb9c "쮜" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 52125 0xcb9d "쮝" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52126 0xcb9e "쮞" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52127 0xcb9f "쮟" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52128 0xcba0 "쮠" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52129 0xcba1 "쮡" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52130 0xcba2 "쮢" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52131 0xcba3 "쮣" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52132 0xcba4 "쮤" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52133 0xcba5 "쮥" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52134 0xcba6 "쮦" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52135 0xcba7 "쮧" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52136 0xcba8 "쮨" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52137 0xcba9 "쮩" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52138 0xcbaa "쮪" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52139 0xcbab "쮫" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52140 0xcbac "쮬" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52141 0xcbad "쮭" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52142 0xcbae "쮮" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52143 0xcbaf "쮯" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52144 0xcbb0 "쮰" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52145 0xcbb1 "쮱" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52146 0xcbb2 "쮲" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52147 0xcbb3 "쮳" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52148 0xcbb4 "쮴" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52149 0xcbb5 "쮵" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52150 0xcbb6 "쮶" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52151 0xcbb7 "쮷" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52152 0xcbb8 "쮸" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 52153 0xcbb9 "쮹" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 52154 0xcbba "쮺" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 52155 0xcbbb "쮻" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52156 0xcbbc "쮼" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 52157 0xcbbd "쮽" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 52158 0xcbbe "쮾" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 52159 0xcbbf "쮿" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 52160 0xcbc0 "쯀" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52161 0xcbc1 "쯁" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 52162 0xcbc2 "쯂" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 52163 0xcbc3 "쯃" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 52164 0xcbc4 "쯄" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52165 0xcbc5 "쯅" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52166 0xcbc6 "쯆" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 52167 0xcbc7 "쯇" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 52168 0xcbc8 "쯈" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 52169 0xcbc9 "쯉" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 52170 0xcbca "쯊" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52171 0xcbcb "쯋" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 52172 0xcbcc "쯌" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52173 0xcbcd "쯍" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 52174 0xcbce "쯎" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 52175 0xcbcf "쯏" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52176 0xcbd0 "쯐" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 52177 0xcbd1 "쯑" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52178 0xcbd2 "쯒" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 52179 0xcbd3 "쯓" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52180 0xcbd4 "쯔" */
+0x00,0x00,0x00,0x1f,0x04,0x04,0x04,0x0a,0x0a,0x11,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x28,0x28,0x44,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 52181 0xcbd5 "쯕" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52182 0xcbd6 "쯖" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52183 0xcbd7 "쯗" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52184 0xcbd8 "쯘" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 52185 0xcbd9 "쯙" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52186 0xcbda "쯚" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52187 0xcbdb "쯛" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52188 0xcbdc "쯜" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52189 0xcbdd "쯝" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52190 0xcbde "쯞" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52191 0xcbdf "쯟" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52192 0xcbe0 "쯠" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52193 0xcbe1 "쯡" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52194 0xcbe2 "쯢" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52195 0xcbe3 "쯣" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52196 0xcbe4 "쯤" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52197 0xcbe5 "쯥" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52198 0xcbe6 "쯦" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52199 0xcbe7 "쯧" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52200 0xcbe8 "쯨" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52201 0xcbe9 "쯩" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52202 0xcbea "쯪" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52203 0xcbeb "쯫" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52204 0xcbec "쯬" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52205 0xcbed "쯭" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52206 0xcbee "쯮" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52207 0xcbef "쯯" */
+0x00,0x00,0x1f,0x04,0x04,0x0a,0x31,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52208 0xcbf0 "쯰" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 52209 0xcbf1 "쯱" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52210 0xcbf2 "쯲" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52211 0xcbf3 "쯳" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52212 0xcbf4 "쯴" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52213 0xcbf5 "쯵" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52214 0xcbf6 "쯶" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52215 0xcbf7 "쯷" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52216 0xcbf8 "쯸" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52217 0xcbf9 "쯹" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52218 0xcbfa "쯺" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52219 0xcbfb "쯻" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52220 0xcbfc "쯼" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52221 0xcbfd "쯽" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52222 0xcbfe "쯾" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52223 0xcbff "쯿" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52224 0xcc00 "찀" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52225 0xcc01 "찁" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52226 0xcc02 "찂" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52227 0xcc03 "찃" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52228 0xcc04 "찄" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52229 0xcc05 "찅" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52230 0xcc06 "찆" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52231 0xcc07 "찇" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52232 0xcc08 "찈" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52233 0xcc09 "찉" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52234 0xcc0a "찊" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52235 0xcc0b "찋" */
+0x00,0x00,0x7f,0x11,0x11,0x2a,0x44,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x84,0x44,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52236 0xcc0c "찌" */
+0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x11,0x11,0x2a,0x2a,0x2a,0x44,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x04,0x04,0x04,0x84,0x84,0x84,0x44,0x04,0x04,0x04,
+/* 52237 0xcc0d "찍" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52238 0xcc0e "찎" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52239 0xcc0f "찏" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52240 0xcc10 "찐" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52241 0xcc11 "찑" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52242 0xcc12 "찒" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52243 0xcc13 "찓" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52244 0xcc14 "찔" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52245 0xcc15 "찕" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52246 0xcc16 "찖" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52247 0xcc17 "찗" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52248 0xcc18 "찘" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52249 0xcc19 "찙" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52250 0xcc1a "찚" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52251 0xcc1b "찛" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52252 0xcc1c "찜" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52253 0xcc1d "찝" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52254 0xcc1e "찞" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52255 0xcc1f "찟" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52256 0xcc20 "찠" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52257 0xcc21 "찡" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52258 0xcc22 "찢" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52259 0xcc23 "찣" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52260 0xcc24 "찤" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52261 0xcc25 "찥" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52262 0xcc26 "찦" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52263 0xcc27 "찧" */
+0x00,0x00,0x7f,0x11,0x11,0x11,0x2a,0x2a,0x44,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xc4,0x04,0x04,0x04,0x84,0x84,0x44,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52264 0xcc28 "차" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 52265 0xcc29 "착" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52266 0xcc2a "찪" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52267 0xcc2b "찫" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52268 0xcc2c "찬" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52269 0xcc2d "찭" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52270 0xcc2e "찮" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52271 0xcc2f "찯" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52272 0xcc30 "찰" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52273 0xcc31 "찱" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52274 0xcc32 "찲" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52275 0xcc33 "찳" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52276 0xcc34 "찴" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52277 0xcc35 "찵" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52278 0xcc36 "찶" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52279 0xcc37 "찷" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52280 0xcc38 "참" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52281 0xcc39 "찹" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52282 0xcc3a "찺" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52283 0xcc3b "찻" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52284 0xcc3c "찼" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52285 0xcc3d "창" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52286 0xcc3e "찾" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52287 0xcc3f "찿" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52288 0xcc40 "챀" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52289 0xcc41 "챁" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52290 0xcc42 "챂" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52291 0xcc43 "챃" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x84,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52292 0xcc44 "채" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 52293 0xcc45 "책" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52294 0xcc46 "챆" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52295 0xcc47 "챇" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52296 0xcc48 "챈" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52297 0xcc49 "챉" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52298 0xcc4a "챊" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52299 0xcc4b "챋" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52300 0xcc4c "챌" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52301 0xcc4d "챍" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52302 0xcc4e "챎" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52303 0xcc4f "챏" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52304 0xcc50 "챐" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52305 0xcc51 "챑" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52306 0xcc52 "챒" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52307 0xcc53 "챓" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52308 0xcc54 "챔" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52309 0xcc55 "챕" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52310 0xcc56 "챖" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52311 0xcc57 "챗" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52312 0xcc58 "챘" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52313 0xcc59 "챙" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52314 0xcc5a "챚" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52315 0xcc5b "챛" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52316 0xcc5c "챜" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52317 0xcc5d "챝" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52318 0xcc5e "챞" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52319 0xcc5f "챟" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x92,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52320 0xcc60 "챠" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 52321 0xcc61 "챡" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52322 0xcc62 "챢" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52323 0xcc63 "챣" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52324 0xcc64 "챤" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52325 0xcc65 "챥" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52326 0xcc66 "챦" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52327 0xcc67 "챧" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52328 0xcc68 "챨" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52329 0xcc69 "챩" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52330 0xcc6a "챪" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52331 0xcc6b "챫" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52332 0xcc6c "챬" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52333 0xcc6d "챭" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52334 0xcc6e "챮" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52335 0xcc6f "챯" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52336 0xcc70 "챰" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52337 0xcc71 "챱" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52338 0xcc72 "챲" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52339 0xcc73 "챳" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52340 0xcc74 "챴" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52341 0xcc75 "챵" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52342 0xcc76 "챶" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52343 0xcc77 "챷" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52344 0xcc78 "챸" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52345 0xcc79 "챹" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52346 0xcc7a "챺" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52347 0xcc7b "챻" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x87,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52348 0xcc7c "챼" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 52349 0xcc7d "챽" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52350 0xcc7e "챾" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52351 0xcc7f "챿" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52352 0xcc80 "첀" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52353 0xcc81 "첁" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52354 0xcc82 "첂" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52355 0xcc83 "첃" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52356 0xcc84 "첄" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52357 0xcc85 "첅" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52358 0xcc86 "첆" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52359 0xcc87 "첇" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52360 0xcc88 "첈" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52361 0xcc89 "첉" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52362 0xcc8a "첊" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52363 0xcc8b "첋" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52364 0xcc8c "첌" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52365 0xcc8d "첍" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52366 0xcc8e "첎" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52367 0xcc8f "첏" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52368 0xcc90 "첐" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52369 0xcc91 "첑" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52370 0xcc92 "첒" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52371 0xcc93 "첓" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52372 0xcc94 "첔" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52373 0xcc95 "첕" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52374 0xcc96 "첖" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52375 0xcc97 "첗" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x9e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52376 0xcc98 "처" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 52377 0xcc99 "척" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52378 0xcc9a "첚" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52379 0xcc9b "첛" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52380 0xcc9c "천" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52381 0xcc9d "첝" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52382 0xcc9e "첞" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52383 0xcc9f "첟" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52384 0xcca0 "철" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52385 0xcca1 "첡" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52386 0xcca2 "첢" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52387 0xcca3 "첣" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52388 0xcca4 "첤" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52389 0xcca5 "첥" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52390 0xcca6 "첦" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52391 0xcca7 "첧" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52392 0xcca8 "첨" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52393 0xcca9 "첩" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52394 0xccaa "첪" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52395 0xccab "첫" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52396 0xccac "첬" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52397 0xccad "청" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52398 0xccae "첮" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52399 0xccaf "첯" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52400 0xccb0 "첰" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52401 0xccb1 "첱" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52402 0xccb2 "첲" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52403 0xccb3 "첳" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x84,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52404 0xccb4 "체" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 52405 0xccb5 "첵" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52406 0xccb6 "첶" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52407 0xccb7 "첷" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52408 0xccb8 "첸" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52409 0xccb9 "첹" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52410 0xccba "첺" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52411 0xccbb "첻" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52412 0xccbc "첼" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52413 0xccbd "첽" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52414 0xccbe "첾" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52415 0xccbf "첿" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52416 0xccc0 "쳀" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52417 0xccc1 "쳁" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52418 0xccc2 "쳂" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52419 0xccc3 "쳃" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52420 0xccc4 "쳄" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52421 0xccc5 "쳅" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52422 0xccc6 "쳆" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52423 0xccc7 "쳇" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52424 0xccc8 "쳈" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52425 0xccc9 "쳉" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52426 0xccca "쳊" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52427 0xcccb "쳋" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52428 0xcccc "쳌" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52429 0xcccd "쳍" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52430 0xccce "쳎" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52431 0xcccf "쳏" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0x92,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52432 0xccd0 "쳐" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 52433 0xccd1 "쳑" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52434 0xccd2 "쳒" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52435 0xccd3 "쳓" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52436 0xccd4 "쳔" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52437 0xccd5 "쳕" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52438 0xccd6 "쳖" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52439 0xccd7 "쳗" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52440 0xccd8 "쳘" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52441 0xccd9 "쳙" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52442 0xccda "쳚" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52443 0xccdb "쳛" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52444 0xccdc "쳜" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52445 0xccdd "쳝" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52446 0xccde "쳞" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52447 0xccdf "쳟" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52448 0xcce0 "쳠" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52449 0xcce1 "쳡" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52450 0xcce2 "쳢" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52451 0xcce3 "쳣" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52452 0xcce4 "쳤" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52453 0xcce5 "쳥" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52454 0xcce6 "쳦" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52455 0xcce7 "쳧" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52456 0xcce8 "쳨" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52457 0xcce9 "쳩" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52458 0xccea "쳪" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52459 0xcceb "쳫" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0xbc,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52460 0xccec "쳬" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 52461 0xcced "쳭" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52462 0xccee "쳮" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52463 0xccef "쳯" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52464 0xccf0 "쳰" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52465 0xccf1 "쳱" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52466 0xccf2 "쳲" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52467 0xccf3 "쳳" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52468 0xccf4 "쳴" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52469 0xccf5 "쳵" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52470 0xccf6 "쳶" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52471 0xccf7 "쳷" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52472 0xccf8 "쳸" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52473 0xccf9 "쳹" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52474 0xccfa "쳺" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52475 0xccfb "쳻" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52476 0xccfc "쳼" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52477 0xccfd "쳽" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52478 0xccfe "쳾" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52479 0xccff "쳿" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52480 0xcd00 "촀" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52481 0xcd01 "촁" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52482 0xcd02 "촂" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52483 0xcd03 "촃" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52484 0xcd04 "촄" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52485 0xcd05 "촅" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52486 0xcd06 "촆" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52487 0xcd07 "촇" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x12,0xf2,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52488 0xcd08 "초" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xfc,0x80,0x40,0x30,0x0c,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 52489 0xcd09 "촉" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52490 0xcd0a "촊" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52491 0xcd0b "촋" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52492 0xcd0c "촌" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 52493 0xcd0d "촍" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52494 0xcd0e "촎" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52495 0xcd0f "촏" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52496 0xcd10 "촐" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52497 0xcd11 "촑" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52498 0xcd12 "촒" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52499 0xcd13 "촓" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52500 0xcd14 "촔" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52501 0xcd15 "촕" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52502 0xcd16 "촖" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52503 0xcd17 "촗" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52504 0xcd18 "촘" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52505 0xcd19 "촙" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52506 0xcd1a "촚" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52507 0xcd1b "촛" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52508 0xcd1c "촜" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52509 0xcd1d "총" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52510 0xcd1e "촞" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52511 0xcd1f "촟" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52512 0xcd20 "촠" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52513 0xcd21 "촡" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52514 0xcd22 "촢" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52515 0xcd23 "촣" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52516 0xcd24 "촤" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 52517 0xcd25 "촥" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52518 0xcd26 "촦" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52519 0xcd27 "촧" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52520 0xcd28 "촨" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52521 0xcd29 "촩" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52522 0xcd2a "촪" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52523 0xcd2b "촫" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52524 0xcd2c "촬" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52525 0xcd2d "촭" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52526 0xcd2e "촮" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52527 0xcd2f "촯" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52528 0xcd30 "촰" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52529 0xcd31 "촱" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52530 0xcd32 "촲" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52531 0xcd33 "촳" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52532 0xcd34 "촴" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52533 0xcd35 "촵" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52534 0xcd36 "촶" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52535 0xcd37 "촷" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52536 0xcd38 "촸" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52537 0xcd39 "촹" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52538 0xcd3a "촺" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52539 0xcd3b "촻" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52540 0xcd3c "촼" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52541 0xcd3d "촽" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52542 0xcd3e "촾" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52543 0xcd3f "촿" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52544 0xcd40 "쵀" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0x92,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 52545 0xcd41 "쵁" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52546 0xcd42 "쵂" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52547 0xcd43 "쵃" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52548 0xcd44 "쵄" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52549 0xcd45 "쵅" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52550 0xcd46 "쵆" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52551 0xcd47 "쵇" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52552 0xcd48 "쵈" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52553 0xcd49 "쵉" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52554 0xcd4a "쵊" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52555 0xcd4b "쵋" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52556 0xcd4c "쵌" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52557 0xcd4d "쵍" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52558 0xcd4e "쵎" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52559 0xcd4f "쵏" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52560 0xcd50 "쵐" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52561 0xcd51 "쵑" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52562 0xcd52 "쵒" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52563 0xcd53 "쵓" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52564 0xcd54 "쵔" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52565 0xcd55 "쵕" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52566 0xcd56 "쵖" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52567 0xcd57 "쵗" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52568 0xcd58 "쵘" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52569 0xcd59 "쵙" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52570 0xcd5a "쵚" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52571 0xcd5b "쵛" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x92,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52572 0xcd5c "최" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 52573 0xcd5d "쵝" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52574 0xcd5e "쵞" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52575 0xcd5f "쵟" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52576 0xcd60 "쵠" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52577 0xcd61 "쵡" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52578 0xcd62 "쵢" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52579 0xcd63 "쵣" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52580 0xcd64 "쵤" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52581 0xcd65 "쵥" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52582 0xcd66 "쵦" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52583 0xcd67 "쵧" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52584 0xcd68 "쵨" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52585 0xcd69 "쵩" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52586 0xcd6a "쵪" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52587 0xcd6b "쵫" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52588 0xcd6c "쵬" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52589 0xcd6d "쵭" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52590 0xcd6e "쵮" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52591 0xcd6f "쵯" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52592 0xcd70 "쵰" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52593 0xcd71 "쵱" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52594 0xcd72 "쵲" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52595 0xcd73 "쵳" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52596 0xcd74 "쵴" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52597 0xcd75 "쵵" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52598 0xcd76 "쵶" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52599 0xcd77 "쵷" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52600 0xcd78 "쵸" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x00,0x01,0x06,0x18,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xfc,0x80,0x40,0x30,0x0c,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 52601 0xcd79 "쵹" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52602 0xcd7a "쵺" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52603 0xcd7b "쵻" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52604 0xcd7c "쵼" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 52605 0xcd7d "쵽" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52606 0xcd7e "쵾" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52607 0xcd7f "쵿" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52608 0xcd80 "춀" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52609 0xcd81 "춁" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52610 0xcd82 "춂" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52611 0xcd83 "춃" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52612 0xcd84 "춄" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52613 0xcd85 "춅" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52614 0xcd86 "춆" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52615 0xcd87 "춇" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52616 0xcd88 "춈" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52617 0xcd89 "춉" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52618 0xcd8a "춊" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52619 0xcd8b "춋" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52620 0xcd8c "춌" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52621 0xcd8d "춍" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52622 0xcd8e "춎" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52623 0xcd8f "춏" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52624 0xcd90 "춐" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52625 0xcd91 "춑" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52626 0xcd92 "춒" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52627 0xcd93 "춓" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52628 0xcd94 "추" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 52629 0xcd95 "축" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 52630 0xcd96 "춖" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 52631 0xcd97 "춗" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52632 0xcd98 "춘" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 52633 0xcd99 "춙" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 52634 0xcd9a "춚" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 52635 0xcd9b "춛" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 52636 0xcd9c "출" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52637 0xcd9d "춝" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 52638 0xcd9e "춞" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 52639 0xcd9f "춟" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 52640 0xcda0 "춠" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52641 0xcda1 "춡" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52642 0xcda2 "춢" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 52643 0xcda3 "춣" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 52644 0xcda4 "춤" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 52645 0xcda5 "춥" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 52646 0xcda6 "춦" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52647 0xcda7 "춧" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 52648 0xcda8 "춨" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 52649 0xcda9 "충" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 52650 0xcdaa "춪" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 52651 0xcdab "춫" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52652 0xcdac "춬" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 52653 0xcdad "춭" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52654 0xcdae "춮" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 52655 0xcdaf "춯" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52656 0xcdb0 "춰" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 52657 0xcdb1 "춱" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52658 0xcdb2 "춲" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52659 0xcdb3 "춳" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52660 0xcdb4 "춴" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 52661 0xcdb5 "춵" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52662 0xcdb6 "춶" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52663 0xcdb7 "춷" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52664 0xcdb8 "춸" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52665 0xcdb9 "춹" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52666 0xcdba "춺" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52667 0xcdbb "춻" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52668 0xcdbc "춼" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52669 0xcdbd "춽" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52670 0xcdbe "춾" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52671 0xcdbf "춿" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52672 0xcdc0 "췀" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52673 0xcdc1 "췁" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52674 0xcdc2 "췂" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52675 0xcdc3 "췃" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52676 0xcdc4 "췄" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52677 0xcdc5 "췅" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52678 0xcdc6 "췆" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52679 0xcdc7 "췇" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52680 0xcdc8 "췈" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52681 0xcdc9 "췉" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52682 0xcdca "췊" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52683 0xcdcb "췋" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52684 0xcdcc "췌" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x12,0x92,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 52685 0xcdcd "췍" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52686 0xcdce "췎" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52687 0xcdcf "췏" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52688 0xcdd0 "췐" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 52689 0xcdd1 "췑" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52690 0xcdd2 "췒" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52691 0xcdd3 "췓" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52692 0xcdd4 "췔" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52693 0xcdd5 "췕" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52694 0xcdd6 "췖" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52695 0xcdd7 "췗" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52696 0xcdd8 "췘" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52697 0xcdd9 "췙" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52698 0xcdda "췚" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52699 0xcddb "췛" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52700 0xcddc "췜" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52701 0xcddd "췝" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52702 0xcdde "췞" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52703 0xcddf "췟" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52704 0xcde0 "췠" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52705 0xcde1 "췡" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52706 0xcde2 "췢" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52707 0xcde3 "췣" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52708 0xcde4 "췤" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52709 0xcde5 "췥" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52710 0xcde6 "췦" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52711 0xcde7 "췧" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0x92,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52712 0xcde8 "취" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 52713 0xcde9 "췩" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52714 0xcdea "췪" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52715 0xcdeb "췫" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52716 0xcdec "췬" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52717 0xcded "췭" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52718 0xcdee "췮" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52719 0xcdef "췯" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52720 0xcdf0 "췰" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52721 0xcdf1 "췱" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52722 0xcdf2 "췲" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52723 0xcdf3 "췳" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52724 0xcdf4 "췴" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52725 0xcdf5 "췵" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52726 0xcdf6 "췶" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52727 0xcdf7 "췷" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52728 0xcdf8 "췸" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52729 0xcdf9 "췹" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52730 0xcdfa "췺" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52731 0xcdfb "췻" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52732 0xcdfc "췼" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52733 0xcdfd "췽" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52734 0xcdfe "췾" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52735 0xcdff "췿" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52736 0xce00 "츀" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52737 0xce01 "츁" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52738 0xce02 "츂" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52739 0xce03 "츃" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52740 0xce04 "츄" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 52741 0xce05 "츅" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 52742 0xce06 "츆" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 52743 0xce07 "츇" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52744 0xce08 "츈" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 52745 0xce09 "츉" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 52746 0xce0a "츊" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 52747 0xce0b "츋" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 52748 0xce0c "츌" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52749 0xce0d "츍" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 52750 0xce0e "츎" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 52751 0xce0f "츏" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 52752 0xce10 "츐" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52753 0xce11 "츑" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52754 0xce12 "츒" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 52755 0xce13 "츓" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 52756 0xce14 "츔" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 52757 0xce15 "츕" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 52758 0xce16 "츖" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52759 0xce17 "츗" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 52760 0xce18 "츘" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 52761 0xce19 "츙" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 52762 0xce1a "츚" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 52763 0xce1b "츛" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52764 0xce1c "츜" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 52765 0xce1d "츝" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52766 0xce1e "츞" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 52767 0xce1f "츟" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52768 0xce20 "츠" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xfc,0x80,0x40,0x30,0x0c,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 52769 0xce21 "측" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52770 0xce22 "츢" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52771 0xce23 "츣" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52772 0xce24 "츤" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 52773 0xce25 "츥" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52774 0xce26 "츦" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52775 0xce27 "츧" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52776 0xce28 "츨" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52777 0xce29 "츩" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52778 0xce2a "츪" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52779 0xce2b "츫" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52780 0xce2c "츬" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52781 0xce2d "츭" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52782 0xce2e "츮" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52783 0xce2f "츯" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52784 0xce30 "츰" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52785 0xce31 "츱" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52786 0xce32 "츲" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52787 0xce33 "츳" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52788 0xce34 "츴" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52789 0xce35 "층" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52790 0xce36 "츶" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52791 0xce37 "츷" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52792 0xce38 "츸" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52793 0xce39 "츹" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52794 0xce3a "츺" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52795 0xce3b "츻" */
+0x00,0x00,0x00,0x1f,0x01,0x06,0x18,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x40,0x30,0x0c,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52796 0xce3c "츼" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 52797 0xce3d "츽" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52798 0xce3e "츾" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52799 0xce3f "츿" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52800 0xce40 "칀" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52801 0xce41 "칁" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52802 0xce42 "칂" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52803 0xce43 "칃" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52804 0xce44 "칄" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52805 0xce45 "칅" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52806 0xce46 "칆" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52807 0xce47 "칇" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52808 0xce48 "칈" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52809 0xce49 "칉" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52810 0xce4a "칊" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52811 0xce4b "칋" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52812 0xce4c "칌" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52813 0xce4d "칍" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52814 0xce4e "칎" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52815 0xce4f "칏" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52816 0xce50 "칐" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52817 0xce51 "칑" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52818 0xce52 "칒" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52819 0xce53 "칓" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52820 0xce54 "칔" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52821 0xce55 "칕" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52822 0xce56 "칖" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52823 0xce57 "칗" */
+0x00,0x00,0x04,0x3f,0x0a,0x11,0x20,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x84,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52824 0xce58 "치" */
+0x00,0x00,0x00,0x1f,0x00,0x3f,0x04,0x04,0x0a,0x0a,0x11,0x11,0x20,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 52825 0xce59 "칙" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52826 0xce5a "칚" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52827 0xce5b "칛" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52828 0xce5c "친" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52829 0xce5d "칝" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52830 0xce5e "칞" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52831 0xce5f "칟" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52832 0xce60 "칠" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52833 0xce61 "칡" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52834 0xce62 "칢" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52835 0xce63 "칣" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52836 0xce64 "칤" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52837 0xce65 "칥" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52838 0xce66 "칦" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52839 0xce67 "칧" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52840 0xce68 "침" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52841 0xce69 "칩" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52842 0xce6a "칪" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52843 0xce6b "칫" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52844 0xce6c "칬" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52845 0xce6d "칭" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52846 0xce6e "칮" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52847 0xce6f "칯" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52848 0xce70 "칰" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52849 0xce71 "칱" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52850 0xce72 "칲" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52851 0xce73 "칳" */
+0x00,0x00,0x1f,0x00,0x3f,0x04,0x0a,0x11,0x20,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0x04,0x84,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52852 0xce74 "카" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 52853 0xce75 "칵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52854 0xce76 "칶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52855 0xce77 "칷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52856 0xce78 "칸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52857 0xce79 "칹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52858 0xce7a "칺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52859 0xce7b "칻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52860 0xce7c "칼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52861 0xce7d "칽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52862 0xce7e "칾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52863 0xce7f "칿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52864 0xce80 "캀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52865 0xce81 "캁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52866 0xce82 "캂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52867 0xce83 "캃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52868 0xce84 "캄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52869 0xce85 "캅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52870 0xce86 "캆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52871 0xce87 "캇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52872 0xce88 "캈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52873 0xce89 "캉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52874 0xce8a "캊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52875 0xce8b "캋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52876 0xce8c "캌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52877 0xce8d "캍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52878 0xce8e "캎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52879 0xce8f "캏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x07,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52880 0xce90 "캐" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 52881 0xce91 "캑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52882 0xce92 "캒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52883 0xce93 "캓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52884 0xce94 "캔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52885 0xce95 "캕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52886 0xce96 "캖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52887 0xce97 "캗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52888 0xce98 "캘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52889 0xce99 "캙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52890 0xce9a "캚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52891 0xce9b "캛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52892 0xce9c "캜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52893 0xce9d "캝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52894 0xce9e "캞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52895 0xce9f "캟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52896 0xcea0 "캠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52897 0xcea1 "캡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52898 0xcea2 "캢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52899 0xcea3 "캣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52900 0xcea4 "캤" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52901 0xcea5 "캥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52902 0xcea6 "캦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52903 0xcea7 "캧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52904 0xcea8 "캨" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52905 0xcea9 "캩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52906 0xceaa "캪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52907 0xceab "캫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x1e,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52908 0xceac "캬" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x87,0x84,0x04,0x07,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 52909 0xcead "캭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52910 0xceae "캮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52911 0xceaf "캯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52912 0xceb0 "캰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52913 0xceb1 "캱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52914 0xceb2 "캲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52915 0xceb3 "캳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52916 0xceb4 "캴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52917 0xceb5 "캵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52918 0xceb6 "캶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52919 0xceb7 "캷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52920 0xceb8 "캸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52921 0xceb9 "캹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52922 0xceba "캺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52923 0xcebb "캻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52924 0xcebc "캼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52925 0xcebd "캽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52926 0xcebe "캾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52927 0xcebf "캿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52928 0xcec0 "컀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52929 0xcec1 "컁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52930 0xcec2 "컂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52931 0xcec3 "컃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52932 0xcec4 "컄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52933 0xcec5 "컅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52934 0xcec6 "컆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52935 0xcec7 "컇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x87,0x04,0x04,0x07,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52936 0xcec8 "컈" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x9e,0x92,0x12,0x1e,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 52937 0xcec9 "컉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52938 0xceca "컊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52939 0xcecb "컋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52940 0xcecc "컌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52941 0xcecd "컍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52942 0xcece "컎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52943 0xcecf "컏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 52944 0xced0 "컐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 52945 0xced1 "컑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 52946 0xced2 "컒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 52947 0xced3 "컓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 52948 0xced4 "컔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 52949 0xced5 "컕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 52950 0xced6 "컖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 52951 0xced7 "컗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 52952 0xced8 "컘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 52953 0xced9 "컙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 52954 0xceda "컚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52955 0xcedb "컛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 52956 0xcedc "컜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 52957 0xcedd "컝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 52958 0xcede "컞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 52959 0xcedf "컟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 52960 0xcee0 "컠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 52961 0xcee1 "컡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 52962 0xcee2 "컢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 52963 0xcee3 "컣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x9e,0x12,0x12,0x1e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 52964 0xcee4 "커" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0xbc,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 52965 0xcee5 "컥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 52966 0xcee6 "컦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52967 0xcee7 "컧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52968 0xcee8 "컨" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 52969 0xcee9 "컩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 52970 0xceea "컪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52971 0xceeb "컫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 52972 0xceec "컬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 52973 0xceed "컭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 52974 0xceee "컮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 52975 0xceef "컯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 52976 0xcef0 "컰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52977 0xcef1 "컱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 52978 0xcef2 "컲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 52979 0xcef3 "컳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 52980 0xcef4 "컴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 52981 0xcef5 "컵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 52982 0xcef6 "컶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52983 0xcef7 "컷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 52984 0xcef8 "컸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 52985 0xcef9 "컹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 52986 0xcefa "컺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 52987 0xcefb "컻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 52988 0xcefc "컼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 52989 0xcefd "컽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 52990 0xcefe "컾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 52991 0xceff "컿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x3c,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 52992 0xcf00 "케" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0xf2,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 52993 0xcf01 "켁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 52994 0xcf02 "켂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 52995 0xcf03 "켃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 52996 0xcf04 "켄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 52997 0xcf05 "켅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 52998 0xcf06 "켆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 52999 0xcf07 "켇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53000 0xcf08 "켈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53001 0xcf09 "켉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53002 0xcf0a "켊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53003 0xcf0b "켋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53004 0xcf0c "켌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53005 0xcf0d "켍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53006 0xcf0e "켎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53007 0xcf0f "켏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53008 0xcf10 "켐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53009 0xcf11 "켑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53010 0xcf12 "켒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53011 0xcf13 "켓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53012 0xcf14 "켔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53013 0xcf15 "켕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53014 0xcf16 "켖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53015 0xcf17 "켗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53016 0xcf18 "켘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53017 0xcf19 "켙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53018 0xcf1a "켚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53019 0xcf1b "켛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x72,0x12,0x12,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53020 0xcf1c "켜" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0xbc,0x84,0x04,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 53021 0xcf1d "켝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53022 0xcf1e "켞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53023 0xcf1f "켟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53024 0xcf20 "켠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53025 0xcf21 "켡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53026 0xcf22 "켢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53027 0xcf23 "켣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53028 0xcf24 "켤" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53029 0xcf25 "켥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53030 0xcf26 "켦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53031 0xcf27 "켧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53032 0xcf28 "켨" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53033 0xcf29 "켩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53034 0xcf2a "켪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53035 0xcf2b "켫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53036 0xcf2c "켬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53037 0xcf2d "켭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53038 0xcf2e "켮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53039 0xcf2f "켯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53040 0xcf30 "켰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53041 0xcf31 "켱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53042 0xcf32 "켲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53043 0xcf33 "켳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53044 0xcf34 "켴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53045 0xcf35 "켵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53046 0xcf36 "켶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53047 0xcf37 "켷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0xbc,0x04,0x04,0x3c,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53048 0xcf38 "켸" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0xf2,0x92,0x12,0x72,0x12,0x12,0x12,0x12,0x12,0x12,
+/* 53049 0xcf39 "켹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53050 0xcf3a "켺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53051 0xcf3b "켻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53052 0xcf3c "켼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53053 0xcf3d "켽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53054 0xcf3e "켾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53055 0xcf3f "켿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53056 0xcf40 "콀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53057 0xcf41 "콁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53058 0xcf42 "콂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53059 0xcf43 "콃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53060 0xcf44 "콄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53061 0xcf45 "콅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53062 0xcf46 "콆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53063 0xcf47 "콇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53064 0xcf48 "콈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53065 0xcf49 "콉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53066 0xcf4a "콊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53067 0xcf4b "콋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53068 0xcf4c "콌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53069 0xcf4d "콍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53070 0xcf4e "콎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53071 0xcf4f "콏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53072 0xcf50 "콐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53073 0xcf51 "콑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53074 0xcf52 "콒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53075 0xcf53 "콓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0xf2,0x12,0x12,0x72,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53076 0xcf54 "코" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0x84,0x80,0x80,0xff,0x00,0x00,
+/* 53077 0xcf55 "콕" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53078 0xcf56 "콖" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53079 0xcf57 "콗" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53080 0xcf58 "콘" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 53081 0xcf59 "콙" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53082 0xcf5a "콚" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53083 0xcf5b "콛" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53084 0xcf5c "콜" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53085 0xcf5d "콝" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53086 0xcf5e "콞" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53087 0xcf5f "콟" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53088 0xcf60 "콠" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53089 0xcf61 "콡" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53090 0xcf62 "콢" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53091 0xcf63 "콣" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53092 0xcf64 "콤" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53093 0xcf65 "콥" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53094 0xcf66 "콦" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53095 0xcf67 "콧" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53096 0xcf68 "콨" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53097 0xcf69 "콩" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53098 0xcf6a "콪" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53099 0xcf6b "콫" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53100 0xcf6c "콬" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53101 0xcf6d "콭" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53102 0xcf6e "콮" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53103 0xcf6f "콯" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x84,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53104 0xcf70 "콰" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x87,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,
+/* 53105 0xcf71 "콱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53106 0xcf72 "콲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53107 0xcf73 "콳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53108 0xcf74 "콴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53109 0xcf75 "콵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53110 0xcf76 "콶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53111 0xcf77 "콷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53112 0xcf78 "콸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53113 0xcf79 "콹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53114 0xcf7a "콺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53115 0xcf7b "콻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53116 0xcf7c "콼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53117 0xcf7d "콽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53118 0xcf7e "콾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53119 0xcf7f "콿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53120 0xcf80 "쾀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53121 0xcf81 "쾁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53122 0xcf82 "쾂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53123 0xcf83 "쾃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53124 0xcf84 "쾄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53125 0xcf85 "쾅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53126 0xcf86 "쾆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53127 0xcf87 "쾇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53128 0xcf88 "쾈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53129 0xcf89 "쾉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53130 0xcf8a "쾊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53131 0xcf8b "쾋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x87,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53132 0xcf8c "쾌" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x92,0x92,0x92,0x9e,0x92,0x92,0x92,0x12,0x12,0xd2,0x12,0x12,
+/* 53133 0xcf8d "쾍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53134 0xcf8e "쾎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53135 0xcf8f "쾏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53136 0xcf90 "쾐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53137 0xcf91 "쾑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53138 0xcf92 "쾒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53139 0xcf93 "쾓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53140 0xcf94 "쾔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53141 0xcf95 "쾕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53142 0xcf96 "쾖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53143 0xcf97 "쾗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53144 0xcf98 "쾘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53145 0xcf99 "쾙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53146 0xcf9a "쾚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53147 0xcf9b "쾛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53148 0xcf9c "쾜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53149 0xcf9d "쾝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53150 0xcf9e "쾞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53151 0xcf9f "쾟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53152 0xcfa0 "쾠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53153 0xcfa1 "쾡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53154 0xcfa2 "쾢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53155 0xcfa3 "쾣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53156 0xcfa4 "쾤" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53157 0xcfa5 "쾥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53158 0xcfa6 "쾦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53159 0xcfa7 "쾧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0x9e,0x92,0x92,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53160 0xcfa8 "쾨" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,
+/* 53161 0xcfa9 "쾩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53162 0xcfaa "쾪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53163 0xcfab "쾫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53164 0xcfac "쾬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53165 0xcfad "쾭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53166 0xcfae "쾮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53167 0xcfaf "쾯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53168 0xcfb0 "쾰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53169 0xcfb1 "쾱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53170 0xcfb2 "쾲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53171 0xcfb3 "쾳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53172 0xcfb4 "쾴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53173 0xcfb5 "쾵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53174 0xcfb6 "쾶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53175 0xcfb7 "쾷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53176 0xcfb8 "쾸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53177 0xcfb9 "쾹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53178 0xcfba "쾺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53179 0xcfbb "쾻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53180 0xcfbc "쾼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53181 0xcfbd "쾽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53182 0xcfbe "쾾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53183 0xcfbf "쾿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53184 0xcfc0 "쿀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53185 0xcfc1 "쿁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53186 0xcfc2 "쿂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53187 0xcfc3 "쿃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53188 0xcfc4 "쿄" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0x24,0x20,0x20,0xff,0x00,0x00,
+/* 53189 0xcfc5 "쿅" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53190 0xcfc6 "쿆" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53191 0xcfc7 "쿇" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53192 0xcfc8 "쿈" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 53193 0xcfc9 "쿉" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53194 0xcfca "쿊" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53195 0xcfcb "쿋" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53196 0xcfcc "쿌" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53197 0xcfcd "쿍" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53198 0xcfce "쿎" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53199 0xcfcf "쿏" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53200 0xcfd0 "쿐" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53201 0xcfd1 "쿑" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53202 0xcfd2 "쿒" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53203 0xcfd3 "쿓" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53204 0xcfd4 "쿔" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53205 0xcfd5 "쿕" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53206 0xcfd6 "쿖" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53207 0xcfd7 "쿗" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53208 0xcfd8 "쿘" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53209 0xcfd9 "쿙" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53210 0xcfda "쿚" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53211 0xcfdb "쿛" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53212 0xcfdc "쿜" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53213 0xcfdd "쿝" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53214 0xcfde "쿞" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53215 0xcfdf "쿟" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x24,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53216 0xcfe0 "쿠" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 53217 0xcfe1 "쿡" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 53218 0xcfe2 "쿢" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 53219 0xcfe3 "쿣" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53220 0xcfe4 "쿤" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 53221 0xcfe5 "쿥" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 53222 0xcfe6 "쿦" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 53223 0xcfe7 "쿧" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 53224 0xcfe8 "쿨" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53225 0xcfe9 "쿩" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 53226 0xcfea "쿪" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 53227 0xcfeb "쿫" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 53228 0xcfec "쿬" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53229 0xcfed "쿭" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53230 0xcfee "쿮" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 53231 0xcfef "쿯" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 53232 0xcff0 "쿰" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 53233 0xcff1 "쿱" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 53234 0xcff2 "쿲" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53235 0xcff3 "쿳" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 53236 0xcff4 "쿴" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53237 0xcff5 "쿵" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 53238 0xcff6 "쿶" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 53239 0xcff7 "쿷" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53240 0xcff8 "쿸" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 53241 0xcff9 "쿹" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53242 0xcffa "쿺" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 53243 0xcffb "쿻" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53244 0xcffc "쿼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 53245 0xcffd "쿽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53246 0xcffe "쿾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53247 0xcfff "쿿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53248 0xd000 "퀀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 53249 0xd001 "퀁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53250 0xd002 "퀂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53251 0xd003 "퀃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53252 0xd004 "퀄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53253 0xd005 "퀅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53254 0xd006 "퀆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53255 0xd007 "퀇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53256 0xd008 "퀈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53257 0xd009 "퀉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53258 0xd00a "퀊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53259 0xd00b "퀋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53260 0xd00c "퀌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53261 0xd00d "퀍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53262 0xd00e "퀎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53263 0xd00f "퀏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53264 0xd010 "퀐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53265 0xd011 "퀑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53266 0xd012 "퀒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53267 0xd013 "퀓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53268 0xd014 "퀔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53269 0xd015 "퀕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53270 0xd016 "퀖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53271 0xd017 "퀗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x9c,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53272 0xd018 "퀘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 53273 0xd019 "퀙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53274 0xd01a "퀚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53275 0xd01b "퀛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53276 0xd01c "퀜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0x92,0x92,0x92,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 53277 0xd01d "퀝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53278 0xd01e "퀞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53279 0xd01f "퀟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53280 0xd020 "퀠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53281 0xd021 "퀡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53282 0xd022 "퀢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53283 0xd023 "퀣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53284 0xd024 "퀤" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53285 0xd025 "퀥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53286 0xd026 "퀦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53287 0xd027 "퀧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53288 0xd028 "퀨" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53289 0xd029 "퀩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53290 0xd02a "퀪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53291 0xd02b "퀫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53292 0xd02c "퀬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53293 0xd02d "퀭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53294 0xd02e "퀮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53295 0xd02f "퀯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53296 0xd030 "퀰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53297 0xd031 "퀱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53298 0xd032 "퀲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53299 0xd033 "퀳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x92,0x92,0xf2,0x92,0x92,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53300 0xd034 "퀴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 53301 0xd035 "퀵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53302 0xd036 "퀶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53303 0xd037 "퀷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53304 0xd038 "퀸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53305 0xd039 "퀹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53306 0xd03a "퀺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53307 0xd03b "퀻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53308 0xd03c "퀼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53309 0xd03d "퀽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53310 0xd03e "퀾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53311 0xd03f "퀿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53312 0xd040 "큀" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53313 0xd041 "큁" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53314 0xd042 "큂" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53315 0xd043 "큃" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53316 0xd044 "큄" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53317 0xd045 "큅" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53318 0xd046 "큆" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53319 0xd047 "큇" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53320 0xd048 "큈" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53321 0xd049 "큉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53322 0xd04a "큊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53323 0xd04b "큋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53324 0xd04c "큌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53325 0xd04d "큍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53326 0xd04e "큎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53327 0xd04f "큏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53328 0xd050 "큐" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 53329 0xd051 "큑" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 53330 0xd052 "큒" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 53331 0xd053 "큓" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53332 0xd054 "큔" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 53333 0xd055 "큕" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 53334 0xd056 "큖" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 53335 0xd057 "큗" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 53336 0xd058 "큘" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53337 0xd059 "큙" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 53338 0xd05a "큚" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 53339 0xd05b "큛" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 53340 0xd05c "큜" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53341 0xd05d "큝" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53342 0xd05e "큞" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 53343 0xd05f "큟" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 53344 0xd060 "큠" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 53345 0xd061 "큡" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 53346 0xd062 "큢" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53347 0xd063 "큣" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 53348 0xd064 "큤" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53349 0xd065 "큥" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 53350 0xd066 "큦" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 53351 0xd067 "큧" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53352 0xd068 "큨" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 53353 0xd069 "큩" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53354 0xd06a "큪" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 53355 0xd06b "큫" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53356 0xd06c "크" */
+0x00,0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x04,0x04,0x00,0x00,0xff,0x00,0x00,
+/* 53357 0xd06d "큭" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53358 0xd06e "큮" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53359 0xd06f "큯" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53360 0xd070 "큰" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 53361 0xd071 "큱" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53362 0xd072 "큲" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53363 0xd073 "큳" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53364 0xd074 "클" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53365 0xd075 "큵" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53366 0xd076 "큶" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53367 0xd077 "큷" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53368 0xd078 "큸" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53369 0xd079 "큹" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53370 0xd07a "큺" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53371 0xd07b "큻" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53372 0xd07c "큼" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53373 0xd07d "큽" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53374 0xd07e "큾" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53375 0xd07f "큿" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53376 0xd080 "킀" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53377 0xd081 "킁" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53378 0xd082 "킂" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53379 0xd083 "킃" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53380 0xd084 "킄" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53381 0xd085 "킅" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53382 0xd086 "킆" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53383 0xd087 "킇" */
+0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53384 0xd088 "킈" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0xf4,0x04,0x04,
+/* 53385 0xd089 "킉" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53386 0xd08a "킊" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53387 0xd08b "킋" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53388 0xd08c "킌" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53389 0xd08d "킍" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53390 0xd08e "킎" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53391 0xd08f "킏" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53392 0xd090 "킐" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53393 0xd091 "킑" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53394 0xd092 "킒" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53395 0xd093 "킓" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53396 0xd094 "킔" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53397 0xd095 "킕" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53398 0xd096 "킖" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53399 0xd097 "킗" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53400 0xd098 "킘" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53401 0xd099 "킙" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53402 0xd09a "킚" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53403 0xd09b "킛" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53404 0xd09c "킜" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53405 0xd09d "킝" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53406 0xd09e "킞" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53407 0xd09f "킟" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53408 0xd0a0 "킠" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53409 0xd0a1 "킡" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53410 0xd0a2 "킢" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53411 0xd0a3 "킣" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x84,0x84,0x84,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53412 0xd0a4 "키" */
+0x00,0x00,0x00,0x3f,0x00,0x00,0x03,0x3c,0x01,0x01,0x02,0x0c,0x30,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 53413 0xd0a5 "킥" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53414 0xd0a6 "킦" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53415 0xd0a7 "킧" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53416 0xd0a8 "킨" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53417 0xd0a9 "킩" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53418 0xd0aa "킪" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53419 0xd0ab "킫" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53420 0xd0ac "킬" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53421 0xd0ad "킭" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53422 0xd0ae "킮" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53423 0xd0af "킯" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53424 0xd0b0 "킰" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53425 0xd0b1 "킱" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53426 0xd0b2 "킲" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53427 0xd0b3 "킳" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53428 0xd0b4 "킴" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53429 0xd0b5 "킵" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53430 0xd0b6 "킶" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53431 0xd0b7 "킷" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53432 0xd0b8 "킸" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53433 0xd0b9 "킹" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53434 0xd0ba "킺" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53435 0xd0bb "킻" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53436 0xd0bc "킼" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53437 0xd0bd "킽" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53438 0xd0be "킾" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53439 0xd0bf "킿" */
+0x00,0x00,0x3f,0x00,0x00,0x3f,0x01,0x06,0x38,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x84,0x84,0x04,0x04,0x04,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53440 0xd0c0 "타" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 53441 0xd0c1 "탁" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53442 0xd0c2 "탂" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53443 0xd0c3 "탃" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53444 0xd0c4 "탄" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53445 0xd0c5 "탅" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53446 0xd0c6 "탆" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53447 0xd0c7 "탇" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53448 0xd0c8 "탈" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53449 0xd0c9 "탉" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53450 0xd0ca "탊" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53451 0xd0cb "탋" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53452 0xd0cc "탌" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53453 0xd0cd "탍" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53454 0xd0ce "탎" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53455 0xd0cf "탏" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53456 0xd0d0 "탐" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53457 0xd0d1 "탑" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53458 0xd0d2 "탒" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53459 0xd0d3 "탓" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53460 0xd0d4 "탔" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53461 0xd0d5 "탕" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53462 0xd0d6 "탖" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53463 0xd0d7 "탗" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53464 0xd0d8 "탘" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53465 0xd0d9 "탙" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53466 0xd0da "탚" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53467 0xd0db "탛" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53468 0xd0dc "태" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 53469 0xd0dd "택" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53470 0xd0de "탞" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53471 0xd0df "탟" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53472 0xd0e0 "탠" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53473 0xd0e1 "탡" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53474 0xd0e2 "탢" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53475 0xd0e3 "탣" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53476 0xd0e4 "탤" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53477 0xd0e5 "탥" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53478 0xd0e6 "탦" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53479 0xd0e7 "탧" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53480 0xd0e8 "탨" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53481 0xd0e9 "탩" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53482 0xd0ea "탪" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53483 0xd0eb "탫" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53484 0xd0ec "탬" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53485 0xd0ed "탭" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53486 0xd0ee "탮" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53487 0xd0ef "탯" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53488 0xd0f0 "탰" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53489 0xd0f1 "탱" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53490 0xd0f2 "탲" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53491 0xd0f3 "탳" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53492 0xd0f4 "탴" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53493 0xd0f5 "탵" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53494 0xd0f6 "탶" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53495 0xd0f7 "탷" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53496 0xd0f8 "탸" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 53497 0xd0f9 "탹" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53498 0xd0fa "탺" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53499 0xd0fb "탻" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53500 0xd0fc "탼" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53501 0xd0fd "탽" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53502 0xd0fe "탾" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53503 0xd0ff "탿" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53504 0xd100 "턀" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53505 0xd101 "턁" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53506 0xd102 "턂" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53507 0xd103 "턃" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53508 0xd104 "턄" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53509 0xd105 "턅" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53510 0xd106 "턆" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53511 0xd107 "턇" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53512 0xd108 "턈" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53513 0xd109 "턉" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53514 0xd10a "턊" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53515 0xd10b "턋" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53516 0xd10c "턌" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53517 0xd10d "턍" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53518 0xd10e "턎" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53519 0xd10f "턏" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53520 0xd110 "턐" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53521 0xd111 "턑" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53522 0xd112 "턒" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53523 0xd113 "턓" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53524 0xd114 "턔" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 53525 0xd115 "턕" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53526 0xd116 "턖" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53527 0xd117 "턗" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53528 0xd118 "턘" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53529 0xd119 "턙" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53530 0xd11a "턚" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53531 0xd11b "턛" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53532 0xd11c "턜" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53533 0xd11d "턝" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53534 0xd11e "턞" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53535 0xd11f "턟" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53536 0xd120 "턠" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53537 0xd121 "턡" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53538 0xd122 "턢" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53539 0xd123 "턣" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53540 0xd124 "턤" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53541 0xd125 "턥" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53542 0xd126 "턦" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53543 0xd127 "턧" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53544 0xd128 "턨" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53545 0xd129 "턩" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53546 0xd12a "턪" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53547 0xd12b "턫" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53548 0xd12c "턬" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53549 0xd12d "턭" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53550 0xd12e "턮" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53551 0xd12f "턯" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53552 0xd130 "터" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 53553 0xd131 "턱" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53554 0xd132 "턲" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53555 0xd133 "턳" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53556 0xd134 "턴" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53557 0xd135 "턵" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53558 0xd136 "턶" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53559 0xd137 "턷" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53560 0xd138 "털" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53561 0xd139 "턹" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53562 0xd13a "턺" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53563 0xd13b "턻" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53564 0xd13c "턼" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53565 0xd13d "턽" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53566 0xd13e "턾" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53567 0xd13f "턿" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53568 0xd140 "텀" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53569 0xd141 "텁" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53570 0xd142 "텂" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53571 0xd143 "텃" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53572 0xd144 "텄" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53573 0xd145 "텅" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53574 0xd146 "텆" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53575 0xd147 "텇" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53576 0xd148 "텈" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53577 0xd149 "텉" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53578 0xd14a "텊" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53579 0xd14b "텋" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53580 0xd14c "테" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 53581 0xd14d "텍" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53582 0xd14e "텎" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53583 0xd14f "텏" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53584 0xd150 "텐" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53585 0xd151 "텑" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53586 0xd152 "텒" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53587 0xd153 "텓" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53588 0xd154 "텔" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53589 0xd155 "텕" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53590 0xd156 "텖" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53591 0xd157 "텗" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53592 0xd158 "텘" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53593 0xd159 "텙" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53594 0xd15a "텚" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53595 0xd15b "텛" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53596 0xd15c "템" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53597 0xd15d "텝" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53598 0xd15e "텞" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53599 0xd15f "텟" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53600 0xd160 "텠" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53601 0xd161 "텡" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53602 0xd162 "텢" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53603 0xd163 "텣" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53604 0xd164 "텤" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53605 0xd165 "텥" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53606 0xd166 "텦" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53607 0xd167 "텧" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53608 0xd168 "텨" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 53609 0xd169 "텩" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53610 0xd16a "텪" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53611 0xd16b "텫" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53612 0xd16c "텬" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53613 0xd16d "텭" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53614 0xd16e "텮" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53615 0xd16f "텯" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53616 0xd170 "텰" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53617 0xd171 "텱" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53618 0xd172 "텲" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53619 0xd173 "텳" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53620 0xd174 "텴" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53621 0xd175 "텵" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53622 0xd176 "텶" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53623 0xd177 "텷" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53624 0xd178 "텸" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53625 0xd179 "텹" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53626 0xd17a "텺" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53627 0xd17b "텻" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53628 0xd17c "텼" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53629 0xd17d "텽" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53630 0xd17e "텾" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53631 0xd17f "텿" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53632 0xd180 "톀" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53633 0xd181 "톁" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53634 0xd182 "톂" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53635 0xd183 "톃" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53636 0xd184 "톄" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 53637 0xd185 "톅" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53638 0xd186 "톆" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53639 0xd187 "톇" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53640 0xd188 "톈" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53641 0xd189 "톉" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53642 0xd18a "톊" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53643 0xd18b "톋" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53644 0xd18c "톌" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53645 0xd18d "톍" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53646 0xd18e "톎" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53647 0xd18f "톏" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53648 0xd190 "톐" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53649 0xd191 "톑" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53650 0xd192 "톒" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53651 0xd193 "톓" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53652 0xd194 "톔" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53653 0xd195 "톕" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53654 0xd196 "톖" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53655 0xd197 "톗" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53656 0xd198 "톘" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53657 0xd199 "톙" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53658 0xd19a "톚" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53659 0xd19b "톛" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53660 0xd19c "톜" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53661 0xd19d "톝" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53662 0xd19e "톞" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53663 0xd19f "톟" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53664 0xd1a0 "토" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 53665 0xd1a1 "톡" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53666 0xd1a2 "톢" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53667 0xd1a3 "톣" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53668 0xd1a4 "톤" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 53669 0xd1a5 "톥" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53670 0xd1a6 "톦" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53671 0xd1a7 "톧" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53672 0xd1a8 "톨" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53673 0xd1a9 "톩" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53674 0xd1aa "톪" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53675 0xd1ab "톫" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53676 0xd1ac "톬" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53677 0xd1ad "톭" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53678 0xd1ae "톮" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53679 0xd1af "톯" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53680 0xd1b0 "톰" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53681 0xd1b1 "톱" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53682 0xd1b2 "톲" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53683 0xd1b3 "톳" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53684 0xd1b4 "톴" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53685 0xd1b5 "통" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53686 0xd1b6 "톶" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53687 0xd1b7 "톷" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53688 0xd1b8 "톸" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53689 0xd1b9 "톹" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53690 0xd1ba "톺" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53691 0xd1bb "톻" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53692 0xd1bc "톼" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 53693 0xd1bd "톽" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53694 0xd1be "톾" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53695 0xd1bf "톿" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53696 0xd1c0 "퇀" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53697 0xd1c1 "퇁" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53698 0xd1c2 "퇂" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53699 0xd1c3 "퇃" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53700 0xd1c4 "퇄" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53701 0xd1c5 "퇅" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53702 0xd1c6 "퇆" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53703 0xd1c7 "퇇" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53704 0xd1c8 "퇈" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53705 0xd1c9 "퇉" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53706 0xd1ca "퇊" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53707 0xd1cb "퇋" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53708 0xd1cc "퇌" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53709 0xd1cd "퇍" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53710 0xd1ce "퇎" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53711 0xd1cf "퇏" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53712 0xd1d0 "퇐" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53713 0xd1d1 "퇑" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53714 0xd1d2 "퇒" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53715 0xd1d3 "퇓" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53716 0xd1d4 "퇔" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53717 0xd1d5 "퇕" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53718 0xd1d6 "퇖" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53719 0xd1d7 "퇗" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53720 0xd1d8 "퇘" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 53721 0xd1d9 "퇙" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53722 0xd1da "퇚" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53723 0xd1db "퇛" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53724 0xd1dc "퇜" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 53725 0xd1dd "퇝" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53726 0xd1de "퇞" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53727 0xd1df "퇟" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53728 0xd1e0 "퇠" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53729 0xd1e1 "퇡" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53730 0xd1e2 "퇢" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53731 0xd1e3 "퇣" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53732 0xd1e4 "퇤" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53733 0xd1e5 "퇥" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53734 0xd1e6 "퇦" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53735 0xd1e7 "퇧" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53736 0xd1e8 "퇨" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53737 0xd1e9 "퇩" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53738 0xd1ea "퇪" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53739 0xd1eb "퇫" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53740 0xd1ec "퇬" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53741 0xd1ed "퇭" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53742 0xd1ee "퇮" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53743 0xd1ef "퇯" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53744 0xd1f0 "퇰" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53745 0xd1f1 "퇱" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53746 0xd1f2 "퇲" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53747 0xd1f3 "퇳" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53748 0xd1f4 "퇴" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 53749 0xd1f5 "퇵" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53750 0xd1f6 "퇶" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53751 0xd1f7 "퇷" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53752 0xd1f8 "퇸" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53753 0xd1f9 "퇹" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53754 0xd1fa "퇺" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53755 0xd1fb "퇻" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53756 0xd1fc "퇼" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53757 0xd1fd "퇽" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53758 0xd1fe "퇾" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53759 0xd1ff "퇿" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53760 0xd200 "툀" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53761 0xd201 "툁" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53762 0xd202 "툂" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53763 0xd203 "툃" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53764 0xd204 "툄" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53765 0xd205 "툅" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53766 0xd206 "툆" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53767 0xd207 "툇" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53768 0xd208 "툈" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53769 0xd209 "툉" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53770 0xd20a "툊" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53771 0xd20b "툋" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53772 0xd20c "툌" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53773 0xd20d "툍" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53774 0xd20e "툎" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53775 0xd20f "툏" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53776 0xd210 "툐" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x0f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 53777 0xd211 "툑" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53778 0xd212 "툒" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53779 0xd213 "툓" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53780 0xd214 "툔" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 53781 0xd215 "툕" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53782 0xd216 "툖" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53783 0xd217 "툗" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53784 0xd218 "툘" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53785 0xd219 "툙" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53786 0xd21a "툚" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53787 0xd21b "툛" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53788 0xd21c "툜" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53789 0xd21d "툝" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53790 0xd21e "툞" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53791 0xd21f "툟" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53792 0xd220 "툠" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53793 0xd221 "툡" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53794 0xd222 "툢" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53795 0xd223 "툣" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53796 0xd224 "툤" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53797 0xd225 "툥" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53798 0xd226 "툦" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53799 0xd227 "툧" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53800 0xd228 "툨" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53801 0xd229 "툩" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53802 0xd22a "툪" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53803 0xd22b "툫" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53804 0xd22c "투" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 53805 0xd22d "툭" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 53806 0xd22e "툮" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 53807 0xd22f "툯" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53808 0xd230 "툰" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 53809 0xd231 "툱" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 53810 0xd232 "툲" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 53811 0xd233 "툳" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 53812 0xd234 "툴" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53813 0xd235 "툵" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 53814 0xd236 "툶" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 53815 0xd237 "툷" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 53816 0xd238 "툸" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53817 0xd239 "툹" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53818 0xd23a "툺" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 53819 0xd23b "툻" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 53820 0xd23c "툼" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 53821 0xd23d "툽" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 53822 0xd23e "툾" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53823 0xd23f "툿" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 53824 0xd240 "퉀" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 53825 0xd241 "퉁" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 53826 0xd242 "퉂" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 53827 0xd243 "퉃" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53828 0xd244 "퉄" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 53829 0xd245 "퉅" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53830 0xd246 "퉆" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 53831 0xd247 "퉇" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53832 0xd248 "퉈" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 53833 0xd249 "퉉" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53834 0xd24a "퉊" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53835 0xd24b "퉋" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53836 0xd24c "퉌" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 53837 0xd24d "퉍" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53838 0xd24e "퉎" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53839 0xd24f "퉏" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53840 0xd250 "퉐" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53841 0xd251 "퉑" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53842 0xd252 "퉒" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53843 0xd253 "퉓" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53844 0xd254 "퉔" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53845 0xd255 "퉕" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53846 0xd256 "퉖" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53847 0xd257 "퉗" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53848 0xd258 "퉘" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53849 0xd259 "퉙" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53850 0xd25a "퉚" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53851 0xd25b "퉛" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53852 0xd25c "퉜" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53853 0xd25d "퉝" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53854 0xd25e "퉞" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53855 0xd25f "퉟" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53856 0xd260 "퉠" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53857 0xd261 "퉡" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53858 0xd262 "퉢" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53859 0xd263 "퉣" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53860 0xd264 "퉤" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 53861 0xd265 "퉥" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 53862 0xd266 "퉦" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 53863 0xd267 "퉧" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53864 0xd268 "퉨" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 53865 0xd269 "퉩" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 53866 0xd26a "퉪" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 53867 0xd26b "퉫" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 53868 0xd26c "퉬" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 53869 0xd26d "퉭" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 53870 0xd26e "퉮" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 53871 0xd26f "퉯" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 53872 0xd270 "퉰" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 53873 0xd271 "퉱" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 53874 0xd272 "퉲" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 53875 0xd273 "퉳" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 53876 0xd274 "퉴" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 53877 0xd275 "퉵" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 53878 0xd276 "퉶" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 53879 0xd277 "퉷" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 53880 0xd278 "퉸" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 53881 0xd279 "퉹" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 53882 0xd27a "퉺" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 53883 0xd27b "퉻" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 53884 0xd27c "퉼" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 53885 0xd27d "퉽" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 53886 0xd27e "퉾" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 53887 0xd27f "퉿" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 53888 0xd280 "튀" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 53889 0xd281 "튁" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53890 0xd282 "튂" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53891 0xd283 "튃" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53892 0xd284 "튄" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53893 0xd285 "튅" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53894 0xd286 "튆" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53895 0xd287 "튇" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53896 0xd288 "튈" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53897 0xd289 "튉" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53898 0xd28a "튊" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53899 0xd28b "튋" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53900 0xd28c "튌" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53901 0xd28d "튍" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53902 0xd28e "튎" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53903 0xd28f "튏" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53904 0xd290 "튐" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53905 0xd291 "튑" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53906 0xd292 "튒" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53907 0xd293 "튓" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53908 0xd294 "튔" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53909 0xd295 "튕" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53910 0xd296 "튖" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53911 0xd297 "튗" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53912 0xd298 "튘" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53913 0xd299 "튙" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53914 0xd29a "튚" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53915 0xd29b "튛" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53916 0xd29c "튜" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 53917 0xd29d "튝" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 53918 0xd29e "튞" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 53919 0xd29f "튟" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53920 0xd2a0 "튠" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 53921 0xd2a1 "튡" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 53922 0xd2a2 "튢" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 53923 0xd2a3 "튣" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 53924 0xd2a4 "튤" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53925 0xd2a5 "튥" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 53926 0xd2a6 "튦" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 53927 0xd2a7 "튧" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 53928 0xd2a8 "튨" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53929 0xd2a9 "튩" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53930 0xd2aa "튪" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 53931 0xd2ab "튫" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 53932 0xd2ac "튬" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 53933 0xd2ad "튭" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 53934 0xd2ae "튮" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53935 0xd2af "튯" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 53936 0xd2b0 "튰" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 53937 0xd2b1 "튱" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 53938 0xd2b2 "튲" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 53939 0xd2b3 "튳" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53940 0xd2b4 "튴" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 53941 0xd2b5 "튵" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53942 0xd2b6 "튶" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 53943 0xd2b7 "튷" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53944 0xd2b8 "트" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x0f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 53945 0xd2b9 "특" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53946 0xd2ba "튺" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53947 0xd2bb "튻" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53948 0xd2bc "튼" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 53949 0xd2bd "튽" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53950 0xd2be "튾" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53951 0xd2bf "튿" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53952 0xd2c0 "틀" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53953 0xd2c1 "틁" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53954 0xd2c2 "틂" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53955 0xd2c3 "틃" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53956 0xd2c4 "틄" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53957 0xd2c5 "틅" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53958 0xd2c6 "틆" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53959 0xd2c7 "틇" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53960 0xd2c8 "틈" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53961 0xd2c9 "틉" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53962 0xd2ca "틊" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53963 0xd2cb "틋" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53964 0xd2cc "틌" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53965 0xd2cd "틍" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53966 0xd2ce "틎" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53967 0xd2cf "틏" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53968 0xd2d0 "틐" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53969 0xd2d1 "틑" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53970 0xd2d2 "틒" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53971 0xd2d3 "틓" */
+0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 53972 0xd2d4 "틔" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 53973 0xd2d5 "틕" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 53974 0xd2d6 "틖" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53975 0xd2d7 "틗" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53976 0xd2d8 "틘" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 53977 0xd2d9 "틙" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 53978 0xd2da "틚" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53979 0xd2db "틛" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 53980 0xd2dc "틜" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 53981 0xd2dd "틝" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 53982 0xd2de "틞" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 53983 0xd2df "틟" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 53984 0xd2e0 "틠" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53985 0xd2e1 "틡" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 53986 0xd2e2 "틢" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 53987 0xd2e3 "틣" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 53988 0xd2e4 "틤" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 53989 0xd2e5 "틥" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 53990 0xd2e6 "틦" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53991 0xd2e7 "틧" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 53992 0xd2e8 "틨" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 53993 0xd2e9 "틩" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 53994 0xd2ea "틪" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 53995 0xd2eb "틫" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 53996 0xd2ec "틬" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 53997 0xd2ed "틭" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 53998 0xd2ee "틮" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 53999 0xd2ef "틯" */
+0x00,0x00,0x3f,0x20,0x3f,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54000 0xd2f0 "티" */
+0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x3f,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 54001 0xd2f1 "틱" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54002 0xd2f2 "틲" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54003 0xd2f3 "틳" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54004 0xd2f4 "틴" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54005 0xd2f5 "틵" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54006 0xd2f6 "틶" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54007 0xd2f7 "틷" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54008 0xd2f8 "틸" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54009 0xd2f9 "틹" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54010 0xd2fa "틺" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54011 0xd2fb "틻" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54012 0xd2fc "틼" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54013 0xd2fd "틽" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54014 0xd2fe "틾" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54015 0xd2ff "틿" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54016 0xd300 "팀" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54017 0xd301 "팁" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54018 0xd302 "팂" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54019 0xd303 "팃" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54020 0xd304 "팄" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54021 0xd305 "팅" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54022 0xd306 "팆" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54023 0xd307 "팇" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54024 0xd308 "팈" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54025 0xd309 "팉" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54026 0xd30a "팊" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54027 0xd30b "팋" */
+0x00,0x00,0x3f,0x20,0x20,0x3f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54028 0xd30c "파" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 54029 0xd30d "팍" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54030 0xd30e "팎" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54031 0xd30f "팏" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54032 0xd310 "판" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54033 0xd311 "팑" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54034 0xd312 "팒" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54035 0xd313 "팓" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54036 0xd314 "팔" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54037 0xd315 "팕" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54038 0xd316 "팖" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54039 0xd317 "팗" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54040 0xd318 "팘" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54041 0xd319 "팙" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54042 0xd31a "팚" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54043 0xd31b "팛" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54044 0xd31c "팜" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54045 0xd31d "팝" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54046 0xd31e "팞" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54047 0xd31f "팟" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54048 0xd320 "팠" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54049 0xd321 "팡" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54050 0xd322 "팢" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54051 0xd323 "팣" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54052 0xd324 "팤" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54053 0xd325 "팥" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54054 0xd326 "팦" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54055 0xd327 "팧" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54056 0xd328 "패" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 54057 0xd329 "팩" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54058 0xd32a "팪" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54059 0xd32b "팫" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54060 0xd32c "팬" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54061 0xd32d "팭" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54062 0xd32e "팮" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54063 0xd32f "팯" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54064 0xd330 "팰" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54065 0xd331 "팱" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54066 0xd332 "팲" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54067 0xd333 "팳" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54068 0xd334 "팴" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54069 0xd335 "팵" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54070 0xd336 "팶" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54071 0xd337 "팷" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54072 0xd338 "팸" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54073 0xd339 "팹" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54074 0xd33a "팺" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54075 0xd33b "팻" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54076 0xd33c "팼" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54077 0xd33d "팽" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54078 0xd33e "팾" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54079 0xd33f "팿" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54080 0xd340 "퍀" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54081 0xd341 "퍁" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54082 0xd342 "퍂" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54083 0xd343 "퍃" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54084 0xd344 "퍄" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x07,0x04,0x04,0x07,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 54085 0xd345 "퍅" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54086 0xd346 "퍆" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54087 0xd347 "퍇" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54088 0xd348 "퍈" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54089 0xd349 "퍉" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54090 0xd34a "퍊" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54091 0xd34b "퍋" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54092 0xd34c "퍌" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54093 0xd34d "퍍" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54094 0xd34e "퍎" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54095 0xd34f "퍏" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54096 0xd350 "퍐" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54097 0xd351 "퍑" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54098 0xd352 "퍒" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54099 0xd353 "퍓" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54100 0xd354 "퍔" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54101 0xd355 "퍕" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54102 0xd356 "퍖" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54103 0xd357 "퍗" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54104 0xd358 "퍘" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54105 0xd359 "퍙" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54106 0xd35a "퍚" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54107 0xd35b "퍛" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54108 0xd35c "퍜" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54109 0xd35d "퍝" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54110 0xd35e "퍞" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54111 0xd35f "퍟" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x07,0x04,0x04,0x07,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54112 0xd360 "퍠" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x1e,0x12,0x12,0x1e,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 54113 0xd361 "퍡" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54114 0xd362 "퍢" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54115 0xd363 "퍣" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54116 0xd364 "퍤" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54117 0xd365 "퍥" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54118 0xd366 "퍦" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54119 0xd367 "퍧" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54120 0xd368 "퍨" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54121 0xd369 "퍩" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54122 0xd36a "퍪" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54123 0xd36b "퍫" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54124 0xd36c "퍬" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54125 0xd36d "퍭" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54126 0xd36e "퍮" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54127 0xd36f "퍯" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54128 0xd370 "퍰" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54129 0xd371 "퍱" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54130 0xd372 "퍲" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54131 0xd373 "퍳" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54132 0xd374 "퍴" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54133 0xd375 "퍵" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54134 0xd376 "퍶" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54135 0xd377 "퍷" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54136 0xd378 "퍸" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54137 0xd379 "퍹" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54138 0xd37a "퍺" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54139 0xd37b "퍻" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x1e,0x12,0x12,0x1e,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54140 0xd37c "퍼" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x3c,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 54141 0xd37d "퍽" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54142 0xd37e "퍾" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54143 0xd37f "퍿" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54144 0xd380 "펀" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54145 0xd381 "펁" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54146 0xd382 "펂" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54147 0xd383 "펃" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54148 0xd384 "펄" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54149 0xd385 "펅" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54150 0xd386 "펆" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54151 0xd387 "펇" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54152 0xd388 "펈" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54153 0xd389 "펉" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54154 0xd38a "펊" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54155 0xd38b "펋" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54156 0xd38c "펌" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54157 0xd38d "펍" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54158 0xd38e "펎" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54159 0xd38f "펏" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54160 0xd390 "펐" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54161 0xd391 "펑" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54162 0xd392 "펒" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54163 0xd393 "펓" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54164 0xd394 "펔" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54165 0xd395 "펕" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54166 0xd396 "펖" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54167 0xd397 "펗" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54168 0xd398 "페" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 54169 0xd399 "펙" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54170 0xd39a "펚" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54171 0xd39b "펛" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54172 0xd39c "펜" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54173 0xd39d "펝" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54174 0xd39e "펞" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54175 0xd39f "펟" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54176 0xd3a0 "펠" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54177 0xd3a1 "펡" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54178 0xd3a2 "펢" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54179 0xd3a3 "펣" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54180 0xd3a4 "펤" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54181 0xd3a5 "펥" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54182 0xd3a6 "펦" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54183 0xd3a7 "펧" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54184 0xd3a8 "펨" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54185 0xd3a9 "펩" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54186 0xd3aa "펪" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54187 0xd3ab "펫" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54188 0xd3ac "펬" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54189 0xd3ad "펭" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54190 0xd3ae "펮" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54191 0xd3af "펯" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54192 0xd3b0 "펰" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54193 0xd3b1 "펱" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54194 0xd3b2 "펲" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54195 0xd3b3 "펳" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54196 0xd3b4 "펴" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x3c,0x04,0x04,0x3c,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 54197 0xd3b5 "펵" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54198 0xd3b6 "펶" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54199 0xd3b7 "펷" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54200 0xd3b8 "편" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54201 0xd3b9 "펹" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54202 0xd3ba "펺" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54203 0xd3bb "펻" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54204 0xd3bc "펼" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54205 0xd3bd "펽" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54206 0xd3be "펾" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54207 0xd3bf "펿" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54208 0xd3c0 "폀" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54209 0xd3c1 "폁" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54210 0xd3c2 "폂" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54211 0xd3c3 "폃" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54212 0xd3c4 "폄" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54213 0xd3c5 "폅" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54214 0xd3c6 "폆" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54215 0xd3c7 "폇" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54216 0xd3c8 "폈" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54217 0xd3c9 "평" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54218 0xd3ca "폊" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54219 0xd3cb "폋" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54220 0xd3cc "폌" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54221 0xd3cd "폍" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54222 0xd3ce "폎" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54223 0xd3cf "폏" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x3c,0x04,0x04,0x3c,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54224 0xd3d0 "폐" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x72,0x12,0x12,0x72,0x12,0x12,0x92,0x12,0x12,0x12,
+/* 54225 0xd3d1 "폑" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54226 0xd3d2 "폒" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54227 0xd3d3 "폓" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54228 0xd3d4 "폔" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54229 0xd3d5 "폕" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54230 0xd3d6 "폖" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54231 0xd3d7 "폗" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54232 0xd3d8 "폘" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54233 0xd3d9 "폙" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54234 0xd3da "폚" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54235 0xd3db "폛" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54236 0xd3dc "폜" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54237 0xd3dd "폝" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54238 0xd3de "폞" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54239 0xd3df "폟" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54240 0xd3e0 "폠" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54241 0xd3e1 "폡" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54242 0xd3e2 "폢" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54243 0xd3e3 "폣" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54244 0xd3e4 "폤" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54245 0xd3e5 "폥" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54246 0xd3e6 "폦" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54247 0xd3e7 "폧" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54248 0xd3e8 "폨" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54249 0xd3e9 "폩" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54250 0xd3ea "폪" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54251 0xd3eb "폫" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x72,0x12,0x12,0x72,0x92,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54252 0xd3ec "포" */
+0x00,0x00,0x00,0x1f,0x00,0x04,0x04,0x04,0x04,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x10,0x10,0xfc,0x80,0x80,0x80,0xff,0x00,0x00,
+/* 54253 0xd3ed "폭" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54254 0xd3ee "폮" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54255 0xd3ef "폯" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54256 0xd3f0 "폰" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 54257 0xd3f1 "폱" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54258 0xd3f2 "폲" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54259 0xd3f3 "폳" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54260 0xd3f4 "폴" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54261 0xd3f5 "폵" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54262 0xd3f6 "폶" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54263 0xd3f7 "폷" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54264 0xd3f8 "폸" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54265 0xd3f9 "폹" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54266 0xd3fa "폺" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54267 0xd3fb "폻" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54268 0xd3fc "폼" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54269 0xd3fd "폽" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54270 0xd3fe "폾" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54271 0xd3ff "폿" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54272 0xd400 "퐀" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54273 0xd401 "퐁" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54274 0xd402 "퐂" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54275 0xd403 "퐃" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54276 0xd404 "퐄" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54277 0xd405 "퐅" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54278 0xd406 "퐆" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54279 0xd407 "퐇" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54280 0xd408 "퐈" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x07,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 54281 0xd409 "퐉" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54282 0xd40a "퐊" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54283 0xd40b "퐋" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54284 0xd40c "퐌" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54285 0xd40d "퐍" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54286 0xd40e "퐎" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54287 0xd40f "퐏" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54288 0xd410 "퐐" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54289 0xd411 "퐑" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54290 0xd412 "퐒" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54291 0xd413 "퐓" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54292 0xd414 "퐔" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54293 0xd415 "퐕" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54294 0xd416 "퐖" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54295 0xd417 "퐗" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54296 0xd418 "퐘" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54297 0xd419 "퐙" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54298 0xd41a "퐚" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54299 0xd41b "퐛" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54300 0xd41c "퐜" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54301 0xd41d "퐝" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54302 0xd41e "퐞" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54303 0xd41f "퐟" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54304 0xd420 "퐠" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54305 0xd421 "퐡" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54306 0xd422 "퐢" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54307 0xd423 "퐣" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x07,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54308 0xd424 "퐤" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x92,0x12,0x12,0x12,0x1e,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 54309 0xd425 "퐥" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54310 0xd426 "퐦" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54311 0xd427 "퐧" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54312 0xd428 "퐨" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54313 0xd429 "퐩" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54314 0xd42a "퐪" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54315 0xd42b "퐫" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54316 0xd42c "퐬" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54317 0xd42d "퐭" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54318 0xd42e "퐮" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54319 0xd42f "퐯" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54320 0xd430 "퐰" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54321 0xd431 "퐱" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54322 0xd432 "퐲" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54323 0xd433 "퐳" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54324 0xd434 "퐴" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54325 0xd435 "퐵" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54326 0xd436 "퐶" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54327 0xd437 "퐷" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54328 0xd438 "퐸" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54329 0xd439 "퐹" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54330 0xd43a "퐺" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54331 0xd43b "퐻" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54332 0xd43c "퐼" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54333 0xd43d "퐽" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54334 0xd43e "퐾" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54335 0xd43f "퐿" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x1e,0x92,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54336 0xd440 "푀" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 54337 0xd441 "푁" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54338 0xd442 "푂" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54339 0xd443 "푃" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54340 0xd444 "푄" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54341 0xd445 "푅" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54342 0xd446 "푆" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54343 0xd447 "푇" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54344 0xd448 "푈" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54345 0xd449 "푉" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54346 0xd44a "푊" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54347 0xd44b "푋" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54348 0xd44c "푌" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54349 0xd44d "푍" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54350 0xd44e "푎" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54351 0xd44f "푏" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54352 0xd450 "푐" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54353 0xd451 "푑" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54354 0xd452 "푒" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54355 0xd453 "푓" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54356 0xd454 "푔" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54357 0xd455 "푕" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54358 0xd456 "푖" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54359 0xd457 "푗" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54360 0xd458 "푘" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54361 0xd459 "푙" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54362 0xd45a "푚" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54363 0xd45b "푛" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54364 0xd45c "표" */
+0x00,0x00,0x00,0x1f,0x00,0x04,0x04,0x04,0x04,0x1f,0x02,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x10,0x10,0xfc,0x20,0x20,0x20,0xff,0x00,0x00,
+/* 54365 0xd45d "푝" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54366 0xd45e "푞" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54367 0xd45f "푟" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54368 0xd460 "푠" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 54369 0xd461 "푡" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54370 0xd462 "푢" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54371 0xd463 "푣" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54372 0xd464 "푤" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54373 0xd465 "푥" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54374 0xd466 "푦" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54375 0xd467 "푧" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54376 0xd468 "푨" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54377 0xd469 "푩" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54378 0xd46a "푪" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54379 0xd46b "푫" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54380 0xd46c "푬" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54381 0xd46d "푭" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54382 0xd46e "푮" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54383 0xd46f "푯" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54384 0xd470 "푰" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54385 0xd471 "푱" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54386 0xd472 "푲" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54387 0xd473 "푳" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54388 0xd474 "푴" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54389 0xd475 "푵" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54390 0xd476 "푶" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54391 0xd477 "푷" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54392 0xd478 "푸" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 54393 0xd479 "푹" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 54394 0xd47a "푺" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 54395 0xd47b "푻" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54396 0xd47c "푼" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 54397 0xd47d "푽" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 54398 0xd47e "푾" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 54399 0xd47f "푿" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 54400 0xd480 "풀" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54401 0xd481 "풁" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 54402 0xd482 "풂" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 54403 0xd483 "풃" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 54404 0xd484 "풄" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54405 0xd485 "풅" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54406 0xd486 "풆" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 54407 0xd487 "풇" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 54408 0xd488 "품" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 54409 0xd489 "풉" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 54410 0xd48a "풊" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54411 0xd48b "풋" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 54412 0xd48c "풌" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54413 0xd48d "풍" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 54414 0xd48e "풎" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 54415 0xd48f "풏" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54416 0xd490 "풐" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 54417 0xd491 "풑" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54418 0xd492 "풒" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 54419 0xd493 "풓" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54420 0xd494 "풔" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 54421 0xd495 "풕" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54422 0xd496 "풖" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54423 0xd497 "풗" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54424 0xd498 "풘" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 54425 0xd499 "풙" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54426 0xd49a "풚" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54427 0xd49b "풛" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54428 0xd49c "풜" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54429 0xd49d "풝" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54430 0xd49e "풞" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54431 0xd49f "풟" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54432 0xd4a0 "풠" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54433 0xd4a1 "풡" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54434 0xd4a2 "풢" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54435 0xd4a3 "풣" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54436 0xd4a4 "풤" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54437 0xd4a5 "풥" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54438 0xd4a6 "풦" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54439 0xd4a7 "풧" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54440 0xd4a8 "풨" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54441 0xd4a9 "풩" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54442 0xd4aa "풪" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54443 0xd4ab "풫" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54444 0xd4ac "풬" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54445 0xd4ad "풭" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54446 0xd4ae "풮" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54447 0xd4af "풯" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x1c,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54448 0xd4b0 "풰" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 54449 0xd4b1 "풱" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54450 0xd4b2 "풲" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54451 0xd4b3 "풳" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54452 0xd4b4 "풴" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x12,0x92,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 54453 0xd4b5 "풵" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54454 0xd4b6 "풶" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54455 0xd4b7 "풷" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54456 0xd4b8 "풸" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54457 0xd4b9 "풹" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54458 0xd4ba "풺" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54459 0xd4bb "풻" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54460 0xd4bc "풼" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54461 0xd4bd "풽" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54462 0xd4be "풾" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54463 0xd4bf "풿" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54464 0xd4c0 "퓀" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54465 0xd4c1 "퓁" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54466 0xd4c2 "퓂" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54467 0xd4c3 "퓃" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54468 0xd4c4 "퓄" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54469 0xd4c5 "퓅" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54470 0xd4c6 "퓆" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54471 0xd4c7 "퓇" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54472 0xd4c8 "퓈" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54473 0xd4c9 "퓉" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54474 0xd4ca "퓊" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54475 0xd4cb "퓋" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x92,0x12,0x12,0x72,0x92,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54476 0xd4cc "퓌" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 54477 0xd4cd "퓍" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54478 0xd4ce "퓎" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54479 0xd4cf "퓏" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54480 0xd4d0 "퓐" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54481 0xd4d1 "퓑" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54482 0xd4d2 "퓒" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54483 0xd4d3 "퓓" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54484 0xd4d4 "퓔" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54485 0xd4d5 "퓕" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54486 0xd4d6 "퓖" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54487 0xd4d7 "퓗" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54488 0xd4d8 "퓘" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54489 0xd4d9 "퓙" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54490 0xd4da "퓚" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54491 0xd4db "퓛" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54492 0xd4dc "퓜" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54493 0xd4dd "퓝" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54494 0xd4de "퓞" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54495 0xd4df "퓟" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54496 0xd4e0 "퓠" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54497 0xd4e1 "퓡" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54498 0xd4e2 "퓢" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54499 0xd4e3 "퓣" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54500 0xd4e4 "퓤" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54501 0xd4e5 "퓥" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54502 0xd4e6 "퓦" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54503 0xd4e7 "퓧" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54504 0xd4e8 "퓨" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 54505 0xd4e9 "퓩" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 54506 0xd4ea "퓪" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 54507 0xd4eb "퓫" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 54508 0xd4ec "퓬" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 54509 0xd4ed "퓭" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 54510 0xd4ee "퓮" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 54511 0xd4ef "퓯" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 54512 0xd4f0 "퓰" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54513 0xd4f1 "퓱" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 54514 0xd4f2 "퓲" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 54515 0xd4f3 "퓳" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 54516 0xd4f4 "퓴" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 54517 0xd4f5 "퓵" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54518 0xd4f6 "퓶" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 54519 0xd4f7 "퓷" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 54520 0xd4f8 "퓸" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 54521 0xd4f9 "퓹" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 54522 0xd4fa "퓺" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 54523 0xd4fb "퓻" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 54524 0xd4fc "퓼" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 54525 0xd4fd "퓽" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 54526 0xd4fe "퓾" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 54527 0xd4ff "퓿" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54528 0xd500 "픀" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 54529 0xd501 "픁" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54530 0xd502 "픂" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 54531 0xd503 "픃" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54532 0xd504 "프" */
+0x00,0x00,0x00,0x1f,0x00,0x04,0x04,0x04,0x04,0x1f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xfc,0x00,0x10,0x10,0x10,0x10,0xfc,0x00,0x00,0x00,0xff,0x00,0x00,
+/* 54533 0xd505 "픅" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54534 0xd506 "픆" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54535 0xd507 "픇" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54536 0xd508 "픈" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 54537 0xd509 "픉" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54538 0xd50a "픊" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54539 0xd50b "픋" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54540 0xd50c "플" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54541 0xd50d "픍" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54542 0xd50e "픎" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54543 0xd50f "픏" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54544 0xd510 "픐" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54545 0xd511 "픑" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54546 0xd512 "픒" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54547 0xd513 "픓" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54548 0xd514 "픔" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54549 0xd515 "픕" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54550 0xd516 "픖" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54551 0xd517 "픗" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54552 0xd518 "픘" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54553 0xd519 "픙" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54554 0xd51a "픚" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54555 0xd51b "픛" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54556 0xd51c "픜" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54557 0xd51d "픝" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54558 0xd51e "픞" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54559 0xd51f "픟" */
+0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54560 0xd520 "픠" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 54561 0xd521 "픡" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54562 0xd522 "픢" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54563 0xd523 "픣" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54564 0xd524 "픤" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54565 0xd525 "픥" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54566 0xd526 "픦" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54567 0xd527 "픧" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54568 0xd528 "픨" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54569 0xd529 "픩" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54570 0xd52a "픪" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54571 0xd52b "픫" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54572 0xd52c "픬" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54573 0xd52d "픭" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54574 0xd52e "픮" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54575 0xd52f "픯" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54576 0xd530 "픰" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54577 0xd531 "픱" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54578 0xd532 "픲" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54579 0xd533 "픳" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54580 0xd534 "픴" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54581 0xd535 "픵" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54582 0xd536 "픶" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54583 0xd537 "픷" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54584 0xd538 "픸" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54585 0xd539 "픹" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54586 0xd53a "픺" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54587 0xd53b "픻" */
+0x00,0x00,0x3f,0x11,0x11,0x11,0x3f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x84,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54588 0xd53c "피" */
+0x00,0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x84,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,
+/* 54589 0xd53d "픽" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54590 0xd53e "픾" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54591 0xd53f "픿" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54592 0xd540 "핀" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54593 0xd541 "핁" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54594 0xd542 "핂" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54595 0xd543 "핃" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54596 0xd544 "필" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54597 0xd545 "핅" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54598 0xd546 "핆" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54599 0xd547 "핇" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54600 0xd548 "핈" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54601 0xd549 "핉" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54602 0xd54a "핊" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54603 0xd54b "핋" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54604 0xd54c "핌" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54605 0xd54d "핍" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54606 0xd54e "핎" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54607 0xd54f "핏" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54608 0xd550 "핐" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54609 0xd551 "핑" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54610 0xd552 "핒" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54611 0xd553 "핓" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54612 0xd554 "핔" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54613 0xd555 "핕" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54614 0xd556 "핖" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54615 0xd557 "핗" */
+0x00,0x00,0x3f,0x00,0x11,0x11,0x11,0x11,0x3f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x84,0x04,0x04,0x04,0x04,0x04,0x84,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54616 0xd558 "하" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x04,0x07,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,
+/* 54617 0xd559 "학" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54618 0xd55a "핚" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54619 0xd55b "핛" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54620 0xd55c "한" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54621 0xd55d "핝" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54622 0xd55e "핞" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54623 0xd55f "핟" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54624 0xd560 "할" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54625 0xd561 "핡" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54626 0xd562 "핢" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54627 0xd563 "핣" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54628 0xd564 "핤" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54629 0xd565 "핥" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54630 0xd566 "핦" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54631 0xd567 "핧" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54632 0xd568 "함" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54633 0xd569 "합" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54634 0xd56a "핪" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54635 0xd56b "핫" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54636 0xd56c "핬" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54637 0xd56d "항" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54638 0xd56e "핮" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54639 0xd56f "핯" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54640 0xd570 "핰" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54641 0xd571 "핱" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54642 0xd572 "핲" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54643 0xd573 "핳" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54644 0xd574 "해" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xd2,0x12,0x1e,0x92,0x92,0x92,0x92,0x12,0x12,0x12,0x12,
+/* 54645 0xd575 "핵" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54646 0xd576 "핶" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54647 0xd577 "핷" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54648 0xd578 "핸" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54649 0xd579 "핹" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54650 0xd57a "핺" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54651 0xd57b "핻" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54652 0xd57c "핼" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54653 0xd57d "핽" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54654 0xd57e "핾" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54655 0xd57f "핿" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54656 0xd580 "햀" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54657 0xd581 "햁" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54658 0xd582 "햂" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54659 0xd583 "햃" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54660 0xd584 "햄" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54661 0xd585 "햅" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54662 0xd586 "햆" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54663 0xd587 "햇" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54664 0xd588 "했" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54665 0xd589 "행" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54666 0xd58a "햊" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54667 0xd58b "햋" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54668 0xd58c "햌" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54669 0xd58d "햍" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54670 0xd58e "햎" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54671 0xd58f "햏" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54672 0xd590 "햐" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x07,0x04,0x84,0x87,0x84,0x84,0x04,0x04,0x04,0x04,
+/* 54673 0xd591 "햑" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54674 0xd592 "햒" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54675 0xd593 "햓" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54676 0xd594 "햔" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54677 0xd595 "햕" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54678 0xd596 "햖" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54679 0xd597 "햗" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54680 0xd598 "햘" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54681 0xd599 "햙" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54682 0xd59a "햚" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54683 0xd59b "햛" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54684 0xd59c "햜" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54685 0xd59d "햝" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54686 0xd59e "햞" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54687 0xd59f "햟" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54688 0xd5a0 "햠" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54689 0xd5a1 "햡" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54690 0xd5a2 "햢" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54691 0xd5a3 "햣" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54692 0xd5a4 "햤" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54693 0xd5a5 "향" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54694 0xd5a6 "햦" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54695 0xd5a7 "햧" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54696 0xd5a8 "햨" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54697 0xd5a9 "햩" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54698 0xd5aa "햪" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54699 0xd5ab "햫" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x07,0x04,0x84,0x87,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54700 0xd5ac "햬" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x92,0x92,0x12,0x12,0x12,0x12,
+/* 54701 0xd5ad "햭" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54702 0xd5ae "햮" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54703 0xd5af "햯" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54704 0xd5b0 "햰" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54705 0xd5b1 "햱" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54706 0xd5b2 "햲" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54707 0xd5b3 "햳" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54708 0xd5b4 "햴" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54709 0xd5b5 "햵" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54710 0xd5b6 "햶" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54711 0xd5b7 "햷" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54712 0xd5b8 "햸" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54713 0xd5b9 "햹" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54714 0xd5ba "햺" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54715 0xd5bb "햻" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54716 0xd5bc "햼" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54717 0xd5bd "햽" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54718 0xd5be "햾" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54719 0xd5bf "햿" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54720 0xd5c0 "헀" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54721 0xd5c1 "헁" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54722 0xd5c2 "헂" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54723 0xd5c3 "헃" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54724 0xd5c4 "헄" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54725 0xd5c5 "헅" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54726 0xd5c6 "헆" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54727 0xd5c7 "헇" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0xd2,0x1e,0x12,0x92,0x9e,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54728 0xd5c8 "허" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x04,0x3c,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,
+/* 54729 0xd5c9 "헉" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54730 0xd5ca "헊" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54731 0xd5cb "헋" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54732 0xd5cc "헌" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54733 0xd5cd "헍" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54734 0xd5ce "헎" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54735 0xd5cf "헏" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54736 0xd5d0 "헐" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54737 0xd5d1 "헑" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54738 0xd5d2 "헒" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54739 0xd5d3 "헓" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54740 0xd5d4 "헔" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54741 0xd5d5 "헕" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54742 0xd5d6 "헖" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54743 0xd5d7 "헗" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54744 0xd5d8 "험" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54745 0xd5d9 "헙" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54746 0xd5da "헚" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54747 0xd5db "헛" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54748 0xd5dc "헜" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54749 0xd5dd "헝" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54750 0xd5de "헞" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54751 0xd5df "헟" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54752 0xd5e0 "헠" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54753 0xd5e1 "헡" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54754 0xd5e2 "헢" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54755 0xd5e3 "헣" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x3c,0x84,0x84,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54756 0xd5e4 "헤" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xd2,0x12,0x72,0x92,0x92,0x92,0x92,0x12,0x12,0x12,0x12,
+/* 54757 0xd5e5 "헥" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54758 0xd5e6 "헦" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54759 0xd5e7 "헧" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54760 0xd5e8 "헨" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54761 0xd5e9 "헩" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54762 0xd5ea "헪" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54763 0xd5eb "헫" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54764 0xd5ec "헬" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54765 0xd5ed "헭" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54766 0xd5ee "헮" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54767 0xd5ef "헯" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54768 0xd5f0 "헰" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54769 0xd5f1 "헱" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54770 0xd5f2 "헲" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54771 0xd5f3 "헳" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54772 0xd5f4 "헴" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54773 0xd5f5 "헵" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54774 0xd5f6 "헶" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54775 0xd5f7 "헷" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54776 0xd5f8 "헸" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54777 0xd5f9 "헹" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54778 0xd5fa "헺" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54779 0xd5fb "헻" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54780 0xd5fc "헼" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54781 0xd5fd "헽" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54782 0xd5fe "헾" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54783 0xd5ff "헿" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0xd2,0x12,0x72,0x92,0x92,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54784 0xd600 "혀" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x84,0x84,0x04,0x04,0x04,0x04,
+/* 54785 0xd601 "혁" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54786 0xd602 "혂" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54787 0xd603 "혃" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54788 0xd604 "현" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54789 0xd605 "혅" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54790 0xd606 "혆" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54791 0xd607 "혇" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54792 0xd608 "혈" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54793 0xd609 "혉" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54794 0xd60a "혊" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54795 0xd60b "혋" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54796 0xd60c "혌" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54797 0xd60d "혍" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54798 0xd60e "혎" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54799 0xd60f "혏" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54800 0xd610 "혐" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54801 0xd611 "협" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54802 0xd612 "혒" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54803 0xd613 "혓" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54804 0xd614 "혔" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54805 0xd615 "형" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54806 0xd616 "혖" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54807 0xd617 "혗" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54808 0xd618 "혘" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54809 0xd619 "혙" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54810 0xd61a "혚" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54811 0xd61b "혛" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x3c,0x04,0x84,0xbc,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54812 0xd61c "혜" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xd2,0x72,0x12,0x92,0xf2,0x92,0x92,0x12,0x12,0x12,0x12,
+/* 54813 0xd61d "혝" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54814 0xd61e "혞" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54815 0xd61f "혟" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54816 0xd620 "혠" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54817 0xd621 "혡" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54818 0xd622 "혢" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54819 0xd623 "혣" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54820 0xd624 "혤" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54821 0xd625 "혥" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54822 0xd626 "혦" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54823 0xd627 "혧" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54824 0xd628 "혨" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54825 0xd629 "혩" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54826 0xd62a "혪" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54827 0xd62b "혫" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54828 0xd62c "혬" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54829 0xd62d "혭" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54830 0xd62e "혮" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54831 0xd62f "혯" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54832 0xd630 "혰" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54833 0xd631 "혱" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54834 0xd632 "혲" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54835 0xd633 "혳" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54836 0xd634 "혴" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54837 0xd635 "혵" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54838 0xd636 "혶" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54839 0xd637 "혷" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0xd2,0x72,0x12,0x92,0xf2,0x12,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54840 0xd638 "호" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xfc,0x00,0xf0,0x08,0x08,0xf0,0x80,0x80,0xff,0x00,0x00,
+/* 54841 0xd639 "혹" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54842 0xd63a "혺" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54843 0xd63b "혻" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54844 0xd63c "혼" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 54845 0xd63d "혽" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54846 0xd63e "혾" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54847 0xd63f "혿" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54848 0xd640 "홀" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54849 0xd641 "홁" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54850 0xd642 "홂" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54851 0xd643 "홃" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54852 0xd644 "홄" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54853 0xd645 "홅" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54854 0xd646 "홆" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54855 0xd647 "홇" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54856 0xd648 "홈" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54857 0xd649 "홉" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54858 0xd64a "홊" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54859 0xd64b "홋" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54860 0xd64c "홌" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54861 0xd64d "홍" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54862 0xd64e "홎" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54863 0xd64f "홏" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54864 0xd650 "홐" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54865 0xd651 "홑" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54866 0xd652 "홒" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54867 0xd653 "홓" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x80,0x80,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54868 0xd654 "화" */
+0x00,0x00,0x00,0x1f,0x00,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x04,0x07,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 54869 0xd655 "확" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54870 0xd656 "홖" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54871 0xd657 "홗" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54872 0xd658 "환" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54873 0xd659 "홙" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54874 0xd65a "홚" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54875 0xd65b "홛" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54876 0xd65c "활" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54877 0xd65d "홝" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54878 0xd65e "홞" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54879 0xd65f "홟" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54880 0xd660 "홠" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54881 0xd661 "홡" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54882 0xd662 "홢" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54883 0xd663 "홣" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54884 0xd664 "홤" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54885 0xd665 "홥" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54886 0xd666 "홦" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54887 0xd667 "홧" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54888 0xd668 "홨" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54889 0xd669 "황" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54890 0xd66a "홪" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54891 0xd66b "홫" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54892 0xd66c "홬" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54893 0xd66d "홭" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54894 0xd66e "홮" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54895 0xd66f "홯" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x87,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54896 0xd670 "홰" */
+0x00,0x00,0x00,0x1f,0x00,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x12,0x12,0x12,0xd2,0x12,0x1e,0x92,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,
+/* 54897 0xd671 "홱" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 54898 0xd672 "홲" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 54899 0xd673 "홳" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54900 0xd674 "홴" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x12,0x12,0x00,0x00,0x00,0xfe,
+/* 54901 0xd675 "홵" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 54902 0xd676 "홶" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 54903 0xd677 "홷" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 54904 0xd678 "홸" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 54905 0xd679 "홹" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 54906 0xd67a "홺" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 54907 0xd67b "홻" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 54908 0xd67c "홼" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 54909 0xd67d "홽" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 54910 0xd67e "홾" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 54911 0xd67f "홿" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 54912 0xd680 "횀" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 54913 0xd681 "횁" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 54914 0xd682 "횂" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 54915 0xd683 "횃" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 54916 0xd684 "횄" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 54917 0xd685 "횅" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 54918 0xd686 "횆" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 54919 0xd687 "횇" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 54920 0xd688 "횈" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 54921 0xd689 "횉" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 54922 0xd68a "횊" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 54923 0xd68b "횋" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0xd2,0x12,0x9e,0x12,0x12,0x12,0xd2,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 54924 0xd68c "회" */
+0x00,0x00,0x00,0x1f,0x00,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 54925 0xd68d "획" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54926 0xd68e "횎" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54927 0xd68f "횏" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54928 0xd690 "횐" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 54929 0xd691 "횑" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54930 0xd692 "횒" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54931 0xd693 "횓" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54932 0xd694 "횔" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54933 0xd695 "횕" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54934 0xd696 "횖" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54935 0xd697 "횗" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54936 0xd698 "횘" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54937 0xd699 "횙" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54938 0xd69a "횚" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54939 0xd69b "횛" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54940 0xd69c "횜" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54941 0xd69d "횝" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54942 0xd69e "횞" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54943 0xd69f "횟" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54944 0xd6a0 "횠" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54945 0xd6a1 "횡" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54946 0xd6a2 "횢" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54947 0xd6a3 "횣" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54948 0xd6a4 "횤" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54949 0xd6a5 "횥" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54950 0xd6a6 "횦" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54951 0xd6a7 "횧" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x04,0x04,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54952 0xd6a8 "효" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x00,0x07,0x08,0x08,0x07,0x02,0x02,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xfc,0x00,0xf0,0x08,0x08,0xf0,0x20,0x20,0xff,0x00,0x00,
+/* 54953 0xd6a9 "횩" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 54954 0xd6aa "횪" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54955 0xd6ab "횫" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54956 0xd6ac "횬" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 54957 0xd6ad "횭" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 54958 0xd6ae "횮" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54959 0xd6af "횯" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 54960 0xd6b0 "횰" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54961 0xd6b1 "횱" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 54962 0xd6b2 "횲" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 54963 0xd6b3 "횳" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 54964 0xd6b4 "횴" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54965 0xd6b5 "횵" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54966 0xd6b6 "횶" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 54967 0xd6b7 "횷" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 54968 0xd6b8 "횸" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 54969 0xd6b9 "횹" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 54970 0xd6ba "횺" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54971 0xd6bb "횻" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 54972 0xd6bc "횼" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 54973 0xd6bd "횽" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 54974 0xd6be "횾" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 54975 0xd6bf "횿" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 54976 0xd6c0 "훀" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 54977 0xd6c1 "훁" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 54978 0xd6c2 "훂" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 54979 0xd6c3 "훃" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x02,0x02,0x7f,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x20,0x20,0xff,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 54980 0xd6c4 "후" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0x00,0xff,0x80,0x80,0x80,0x80,0x80,0x80,
+/* 54981 0xd6c5 "훅" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0x04,
+/* 54982 0xd6c6 "훆" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 54983 0xd6c7 "훇" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54984 0xd6c8 "훈" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0x00,0xff,0x80,0x80,0x80,0x00,0x00,0xfc,
+/* 54985 0xd6c9 "훉" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x7c,0x10,0x10,0x28,0xc6,
+/* 54986 0xd6ca "훊" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 54987 0xd6cb "훋" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x00,0x00,0x00,0xfc,
+/* 54988 0xd6cc "훌" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x04,0xf8,0x00,0xfc,
+/* 54989 0xd6cd "훍" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x7c,0x04,0x04,0x04,0x04,
+/* 54990 0xd6ce "훎" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x7c,0x44,0x44,0x44,0x3c,
+/* 54991 0xd6cf "훏" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x44,0x44,0x7c,0x44,0x3c,
+/* 54992 0xd6d0 "훐" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54993 0xd6d1 "훑" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x7c,0x40,0x7c,0x40,0x3c,
+/* 54994 0xd6d2 "훒" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x7e,0x24,0x24,0x24,0x7e,
+/* 54995 0xd6d3 "훓" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x38,0x00,0xfe,0x44,0x38,
+/* 54996 0xd6d4 "훔" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x04,0x04,0x04,0xfc,
+/* 54997 0xd6d5 "훕" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x04,0x04,0xfc,0x04,0xfc,
+/* 54998 0xd6d6 "훖" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 54999 0xd6d7 "훗" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x80,0x80,0x40,0x30,0x0c,
+/* 55000 0xd6d8 "훘" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0x10,0x10,0x10,0x28,0xc6,
+/* 55001 0xd6d9 "훙" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xf8,0x04,0x04,0x04,0xf8,
+/* 55002 0xd6da "훚" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x80,0x40,0x30,0x0c,
+/* 55003 0xd6db "훛" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55004 0xd6dc "훜" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x04,0xfc,0x04,0x04,
+/* 55005 0xd6dd "훝" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55006 0xd6de "훞" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xfc,0x10,0x10,0x10,0xfc,
+/* 55007 0xd6df "훟" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x80,0x80,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55008 0xd6e0 "훠" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x3c,0x04,0x04,0x04,
+/* 55009 0xd6e1 "훡" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 55010 0xd6e2 "훢" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55011 0xd6e3 "훣" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55012 0xd6e4 "훤" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x3c,0x04,0x00,0x00,0x00,0xfc,
+/* 55013 0xd6e5 "훥" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 55014 0xd6e6 "훦" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55015 0xd6e7 "훧" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 55016 0xd6e8 "훨" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 55017 0xd6e9 "훩" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55018 0xd6ea "훪" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 55019 0xd6eb "훫" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 55020 0xd6ec "훬" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55021 0xd6ed "훭" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 55022 0xd6ee "훮" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 55023 0xd6ef "훯" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55024 0xd6f0 "훰" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 55025 0xd6f1 "훱" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 55026 0xd6f2 "훲" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55027 0xd6f3 "훳" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 55028 0xd6f4 "훴" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55029 0xd6f5 "훵" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 55030 0xd6f6 "훶" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 55031 0xd6f7 "훷" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55032 0xd6f8 "훸" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 55033 0xd6f9 "훹" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55034 0xd6fa "훺" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 55035 0xd6fb "훻" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x9c,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55036 0xd6fc "훼" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x12,0xd2,0x12,0x92,0x12,0x12,0x12,0xd2,0x12,0x12,0xf2,0x12,0x12,0x12,
+/* 55037 0xd6fd "훽" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0x02,
+/* 55038 0xd6fe "훾" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0x82,0x82,0x82,0x82,
+/* 55039 0xd6ff "훿" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 55040 0xd700 "휀" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x02,0x02,0x0a,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0x92,0x12,0x12,0xd2,0x12,0xf2,0x12,0x00,0x00,0x00,0xfe,
+/* 55041 0xd701 "휁" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x3e,0x08,0x08,0x14,0xe3,
+/* 55042 0xd702 "휂" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x1c,0x00,0x7f,0x22,0x9c,
+/* 55043 0xd703 "휃" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x00,0x00,0x00,0xfe,
+/* 55044 0xd704 "휄" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfc,0x00,0xfe,
+/* 55045 0xd705 "휅" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0x82,0x02,0x02,0x82,
+/* 55046 0xd706 "휆" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0xa2,0x22,0x22,0x9e,
+/* 55047 0xd707 "휇" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xa2,0xa2,0x3e,0x22,0x9e,
+/* 55048 0xd708 "휈" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x08,0x14,0xe3,
+/* 55049 0xd709 "휉" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbe,0xa0,0x3e,0x20,0x9e,
+/* 55050 0xd70a "휊" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xbf,0x92,0x12,0x12,0xbf,
+/* 55051 0xd70b "휋" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x9c,0x80,0x7f,0x22,0x9c,
+/* 55052 0xd70c "휌" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0x02,0x02,0xfe,
+/* 55053 0xd70d "휍" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x02,0x02,0xfe,0x02,0xfe,
+/* 55054 0xd70e "휎" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x08,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x88,0x88,0x88,0x94,0xe3,
+/* 55055 0xd70f "휏" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x40,0x40,0xa0,0x18,0x06,
+/* 55056 0xd710 "휐" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x02,0x02,0x02,0x05,0x18,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0x08,0x08,0x08,0x14,0xe3,
+/* 55057 0xd711 "휑" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x07,0x08,0x08,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfc,0x02,0x02,0x02,0xfc,
+/* 55058 0xd712 "휒" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x00,0x03,0x0c,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x40,0xa0,0x18,0x06,
+/* 55059 0xd713 "휓" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x01,0x0e,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x10,0x0e,
+/* 55060 0xd714 "휔" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x00,0x0f,0x00,0x00,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x02,0xfe,0x02,0x02,
+/* 55061 0xd715 "휕" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x08,0x0f,0x08,0x07,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x00,0xfc,0x00,0xfe,
+/* 55062 0xd716 "휖" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x02,0x02,0x02,0x0f,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xfe,0x08,0x08,0x08,0xfe,
+/* 55063 0xd717 "휗" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x01,0x00,0x0f,0x04,0x03,
+0x00,0x00,0x12,0xd2,0x12,0xf2,0x12,0x12,0xd2,0x12,0x00,0xf0,0x00,0xfe,0x04,0xf8,
+/* 55064 0xd718 "휘" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x04,0x04,0x04,0x04,
+/* 55065 0xd719 "휙" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 55066 0xd71a "휚" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55067 0xd71b "휛" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55068 0xd71c "휜" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x14,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 55069 0xd71d "휝" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 55070 0xd71e "휞" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55071 0xd71f "휟" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 55072 0xd720 "휠" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 55073 0xd721 "휡" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55074 0xd722 "휢" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 55075 0xd723 "휣" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 55076 0xd724 "휤" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55077 0xd725 "휥" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 55078 0xd726 "휦" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 55079 0xd727 "휧" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55080 0xd728 "휨" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 55081 0xd729 "휩" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 55082 0xd72a "휪" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55083 0xd72b "휫" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 55084 0xd72c "휬" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55085 0xd72d "휭" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 55086 0xd72e "휮" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 55087 0xd72f "휯" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55088 0xd730 "휰" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 55089 0xd731 "휱" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55090 0xd732 "휲" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 55091 0xd733 "휳" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x04,0x04,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55092 0xd734 "휴" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x04,0x04,0x04,0x04,0x04,0x04,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0x00,0xff,0x10,0x10,0x10,0x10,0x10,0x10,
+/* 55093 0xd735 "휵" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0x04,
+/* 55094 0xd736 "휶" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 55095 0xd737 "휷" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 55096 0xd738 "휸" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x02,0x12,0x12,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0x00,0xff,0x20,0x20,0x20,0x00,0x00,0xfc,
+/* 55097 0xd739 "휹" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x7c,0x10,0x10,0x28,0xc6,
+/* 55098 0xd73a "휺" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 55099 0xd73b "휻" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x00,0x00,0x00,0xfc,
+/* 55100 0xd73c "휼" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x04,0xf8,0x00,0xfc,
+/* 55101 0xd73d "휽" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x7c,0x04,0x04,0x04,0x04,
+/* 55102 0xd73e "휾" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x7c,0x44,0x44,0x44,0x3c,
+/* 55103 0xd73f "휿" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x44,0x44,0x7c,0x44,0x3c,
+/* 55104 0xd740 "흀" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 55105 0xd741 "흁" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x7c,0x40,0x7c,0x40,0x3c,
+/* 55106 0xd742 "흂" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x7e,0x24,0x24,0x24,0x7e,
+/* 55107 0xd743 "흃" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x38,0x00,0xfe,0x44,0x38,
+/* 55108 0xd744 "흄" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x04,0x04,0x04,0xfc,
+/* 55109 0xd745 "흅" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x04,0x04,0xfc,0x04,0xfc,
+/* 55110 0xd746 "흆" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 55111 0xd747 "흇" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x80,0x80,0x40,0x30,0x0c,
+/* 55112 0xd748 "흈" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0x10,0x10,0x10,0x28,0xc6,
+/* 55113 0xd749 "흉" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xf8,0x04,0x04,0x04,0xf8,
+/* 55114 0xd74a "흊" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x80,0x40,0x30,0x0c,
+/* 55115 0xd74b "흋" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55116 0xd74c "흌" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x04,0xfc,0x04,0x04,
+/* 55117 0xd74d "흍" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55118 0xd74e "흎" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xfc,0x10,0x10,0x10,0xfc,
+/* 55119 0xd74f "흏" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x02,0x02,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x20,0x20,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55120 0xd750 "흐" */
+0x00,0x00,0x00,0x03,0x00,0x1f,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x00,0xfc,0x00,0xf0,0x08,0x08,0xf0,0x00,0x00,0xff,0x00,0x00,
+/* 55121 0xd751 "흑" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 55122 0xd752 "흒" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55123 0xd753 "흓" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55124 0xd754 "흔" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xfc,
+/* 55125 0xd755 "흕" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 55126 0xd756 "흖" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55127 0xd757 "흗" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 55128 0xd758 "흘" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 55129 0xd759 "흙" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55130 0xd75a "흚" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 55131 0xd75b "흛" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 55132 0xd75c "흜" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55133 0xd75d "흝" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 55134 0xd75e "흞" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 55135 0xd75f "흟" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55136 0xd760 "흠" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 55137 0xd761 "흡" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 55138 0xd762 "흢" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55139 0xd763 "흣" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 55140 0xd764 "흤" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55141 0xd765 "흥" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 55142 0xd766 "흦" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 55143 0xd767 "흧" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55144 0xd768 "흨" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 55145 0xd769 "흩" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55146 0xd76a "흪" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 55147 0xd76b "흫" */
+0x00,0x00,0x00,0x1f,0x04,0x08,0x07,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x80,0xfc,0x10,0x08,0xf0,0x00,0xff,0x00,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55148 0xd76c "희" */
+0x00,0x00,0x00,0x1f,0x00,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,
+/* 55149 0xd76d "흭" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 55150 0xd76e "흮" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55151 0xd76f "흯" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55152 0xd770 "흰" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x00,0x7f,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0x04,0xf4,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 55153 0xd771 "흱" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 55154 0xd772 "흲" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55155 0xd773 "흳" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 55156 0xd774 "흴" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 55157 0xd775 "흵" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55158 0xd776 "흶" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 55159 0xd777 "흷" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 55160 0xd778 "흸" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55161 0xd779 "흹" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 55162 0xd77a "흺" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 55163 0xd77b "흻" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55164 0xd77c "흼" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 55165 0xd77d "흽" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 55166 0xd77e "흾" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55167 0xd77f "흿" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 55168 0xd780 "힀" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55169 0xd781 "힁" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 55170 0xd782 "힂" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 55171 0xd783 "힃" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55172 0xd784 "힄" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 55173 0xd785 "힅" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55174 0xd786 "힆" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 55175 0xd787 "힇" */
+0x00,0x00,0x04,0x7f,0x11,0x20,0x1f,0x00,0x7f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x84,0x04,0x04,0xf4,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55176 0xd788 "히" */
+0x00,0x00,0x00,0x0f,0x00,0x3f,0x00,0x0f,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0xc4,0x04,0x04,0x84,0x84,0x84,0x84,0x04,0x04,0x04,0x04,
+/* 55177 0xd789 "힉" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0x04,
+/* 55178 0xd78a "힊" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55179 0xd78b "힋" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x01,0x01,0x01,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55180 0xd78c "힌" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x04,0x04,0x00,0x00,0x00,0xfc,
+/* 55181 0xd78d "힍" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x7c,0x10,0x10,0x28,0xc6,
+/* 55182 0xd78e "힎" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55183 0xd78f "힏" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x00,0x00,0x00,0xfc,
+/* 55184 0xd790 "힐" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0xf8,0x00,0xfc,
+/* 55185 0xd791 "힑" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x7c,0x04,0x04,0x04,0x04,
+/* 55186 0xd792 "힒" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x7c,0x44,0x44,0x44,0x3c,
+/* 55187 0xd793 "힓" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x44,0x44,0x7c,0x44,0x3c,
+/* 55188 0xd794 "힔" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55189 0xd795 "힕" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x7c,0x40,0x7c,0x40,0x3c,
+/* 55190 0xd796 "힖" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x7e,0x24,0x24,0x24,0x7e,
+/* 55191 0xd797 "힗" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x01,0x1e,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x38,0x00,0xfe,0x44,0x38,
+/* 55192 0xd798 "힘" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0x04,0x04,0xfc,
+/* 55193 0xd799 "힙" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x10,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x04,0x04,0xfc,0x04,0xfc,
+/* 55194 0xd79a "힚" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x11,0x11,0x1f,0x11,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55195 0xd79b "힛" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x80,0x80,0x40,0x30,0x0c,
+/* 55196 0xd79c "힜" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x04,0x04,0x04,0x0a,0x31,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0x10,0x10,0x10,0x28,0xc6,
+/* 55197 0xd79d "힝" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x0f,0x10,0x10,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xf8,0x04,0x04,0x04,0xf8,
+/* 55198 0xd79e "힞" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x01,0x06,0x18,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x80,0x40,0x30,0x0c,
+/* 55199 0xd79f "힟" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x02,0x1c,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xe0,0x00,0xfc,0x20,0x1c,
+/* 55200 0xd7a0 "힠" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x00,0x1f,0x00,0x00,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x04,0xfc,0x04,0x04,
+/* 55201 0xd7a1 "힡" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x10,0x1f,0x10,0x0f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x00,0xf8,0x00,0xfc,
+/* 55202 0xd7a2 "힢" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x1f,0x04,0x04,0x04,0x1f,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xfc,0x10,0x10,0x10,0xfc,
+/* 55203 0xd7a3 "힣" */
+0x00,0x00,0x04,0x7f,0x00,0x1f,0x20,0x20,0x1f,0x00,0x00,0x03,0x00,0x1f,0x08,0x07,
+0x00,0x00,0x04,0xc4,0x04,0x04,0x84,0x84,0x04,0x04,0x00,0xe0,0x00,0xfc,0x08,0xf0,
+/* 55204 0xd7a4 "힤" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 55205 0xd7a5 "힥" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 55206 0xd7a6 "힦" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 55207 0xd7a7 "힧" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 55208 0xd7a8 "힨" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 55209 0xd7a9 "힩" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 55210 0xd7aa "힪" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 55211 0xd7ab "힫" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 55212 0xd7ac "힬" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 55213 0xd7ad "힭" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 55214 0xd7ae "힮" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 55215 0xd7af "힯" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6d,0x61,0x6d,0x6d,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 55216 0xd7b0 "ힰ" */
+0x00,0x00,0x00,0x00,0x00,0x03,0x01,0x00,0x03,0x01,0x00,0x0c,0x04,0x07,0x78,0x00,
+0x40,0x30,0x10,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,0x10,0x10,0xd0,0x10,0x10,0x00,
+/* 55217 0xd7b1 "ힱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x01,0x1f,0x01,0x3f,0x00,0x03,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0xf8,0x00,0x00,0x00,
+/* 55218 0xd7b2 "ힲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x0c,0x04,0x07,0x78,0x00,
+0x40,0x30,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x9c,0xf0,0x10,0x10,0x00,
+/* 55219 0xd7b3 "ힳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x19,0x09,0x0f,0x78,0x00,
+0x48,0x36,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0xf2,0x12,0x02,0x00,
+/* 55220 0xd7b4 "ힴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x19,0x09,0x0f,0x78,0x00,
+0x08,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x1e,0x02,0x02,0x32,0xc2,0x02,0x02,0x00,
+/* 55221 0xd7b5 "ힵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x02,0x02,0x02,0x02,0x00,0x00,
+0x08,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xf2,0x02,0x1e,0x02,0x1e,0x02,0x00,
+/* 55222 0xd7b6 "ힶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x04,0x04,0x04,0x00,0x00,
+0x10,0x8c,0x64,0x24,0x24,0x24,0x24,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x04,0x00,
+/* 55223 0xd7b7 "ힷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x11,0x11,0x11,0x00,0x00,
+0x48,0x36,0x12,0x12,0x12,0x12,0x12,0x12,0x1e,0x12,0xf2,0x12,0x12,0x12,0x02,0x00,
+/* 55224 0xd7b8 "ힸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x08,0x0b,0x00,0x3f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x20,0xa0,0x80,0xfc,0x00,
+/* 55225 0xd7b9 "ힹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x78,0x00,
+0x80,0x60,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0xe0,0x20,0x20,0x00,
+/* 55226 0xd7ba "ힺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x78,0x00,
+0x08,0x06,0x02,0x02,0x02,0x02,0x02,0x02,0x1e,0x02,0x02,0x02,0xe2,0x02,0x02,0x00,
+/* 55227 0xd7bb "ힻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x78,0x00,
+0x48,0x36,0x12,0x12,0x12,0x12,0x12,0x12,0x72,0x12,0x12,0x12,0xd2,0x12,0x02,0x00,
+/* 55228 0xd7bc "ힼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x03,0x00,0x3f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x80,0x80,0xfc,0x00,
+/* 55229 0xd7bd "ힽ" */
+0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x02,0x3f,0x00,
+0x00,0x40,0x30,0xd0,0x50,0x50,0x5c,0x50,0x50,0x5c,0x50,0x50,0x10,0x00,0xfc,0x00,
+/* 55230 0xd7be "ힾ" */
+0x00,0x04,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,
+0x90,0x6c,0x24,0x24,0x3c,0x24,0x24,0x3c,0x24,0x24,0x24,0x24,0x24,0x04,0x00,0x00,
+/* 55231 0xd7bf "ힿ" */
+0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0xcc,0x44,0x44,0x5c,0x44,0x44,0x5c,0x44,0x44,0x44,0x44,0x44,0x04,0x00,0x00,
+/* 55232 0xd7c0 "ퟀ" */
+0x04,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x10,0x4c,0x34,0x14,0x14,0x74,0x14,0x14,0x74,0x14,0x14,0x14,0x14,0x14,0x04,0x00,
+/* 55233 0xd7c1 "ퟁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x01,0x3f,0x00,0x07,0x01,0x01,
+0x00,0x20,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0xf8,0x00,0x00,0x00,0x00,
+/* 55234 0xd7c2 "ퟂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0x08,0x3f,0x00,0x00,0x00,0x00,
+0x00,0x20,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0xc8,0x40,0xf8,0x00,0x00,0x00,0x00,
+/* 55235 0xd7c3 "ퟃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x08,0x08,0x00,0x00,
+0x00,0x20,0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0xf8,0x40,0x40,0x00,0x00,
+/* 55236 0xd7c4 "ퟄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x48,0x36,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x02,0x00,
+/* 55237 0xd7c5 "ퟅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x38,0x08,0x00,0x00,0x00,
+0x80,0x60,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+/* 55238 0xd7c6 "ퟆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x30,0x38,0x08,0x00,0x00,0x00,
+0x10,0x8c,0x64,0x24,0x24,0x24,0x24,0x24,0xe4,0x24,0x24,0x24,0x24,0x24,0x04,0x00,
+/* 55239 0xd7c7 "퟇" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 55240 0xd7c8 "퟈" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 55241 0xd7c9 "퟉" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 55242 0xd7ca "퟊" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 55243 0xd7cb "ퟋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x20,0x20,0x20,0x26,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0xfe,0x80,0x80,0xfe,0x00,
+/* 55244 0xd7cc "ퟌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x43,0x40,0x40,0x4c,0x71,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x78,0x00,0xfe,0x20,0x30,0x48,0x84,0x00,0x00,0x00,0x00,
+/* 55245 0xd7cd "ퟍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfd,0x20,0x20,0x20,0x26,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x80,0x80,0x80,0x80,0x78,0x00,
+/* 55246 0xd7ce "ퟎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x22,0x22,0x22,0x22,0x26,0x19,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0x12,0x1e,0x12,0x12,0x5e,0x92,0x00,
+/* 55247 0xd7cf "ퟏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfd,0x20,0x20,0x20,0x20,0x26,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x98,0x88,0xf8,0x88,0x88,0xf8,0x88,0x00,
+/* 55248 0xd7d0 "ퟐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x20,0x20,0x20,0x26,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x18,0x24,0xc2,0x00,
+/* 55249 0xd7d1 "ퟑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x20,0x20,0x20,0x24,0x39,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0x22,0x22,0x62,0x92,0x0a,0x00,
+/* 55250 0xd7d2 "ퟒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x20,0x20,0x20,0x26,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x08,0x08,0x18,0x24,0xc2,0x00,
+/* 55251 0xd7d3 "ퟓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x20,0x20,0x20,0x26,0x38,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x00,0x7e,0x08,0x18,0x24,0xc2,0x00,
+/* 55252 0xd7d4 "ퟔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x10,0x13,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x40,0x7c,0x40,0x3c,0x00,
+/* 55253 0xd7d5 "ퟕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3d,0x04,0x3c,0x20,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdc,0x44,0x44,0x44,0x44,0x00,
+/* 55254 0xd7d6 "ퟖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3d,0x04,0x04,0x3c,0x20,0x20,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0xc0,0x7e,0x48,0x5c,0x62,0x62,0x5c,0x00,
+/* 55255 0xd7d7 "ퟗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x08,0x7b,0x42,0x7b,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdc,0x44,0xdc,0x04,0xc4,0x00,
+/* 55256 0xd7d8 "ퟘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x0a,0x0a,0x7a,0x42,0x43,0x7a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0xc0,0x7e,0x48,0x5c,0x62,0xe2,0x1c,0x00,
+/* 55257 0xd7d9 "ퟙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x7a,0x0a,0x0b,0x7a,0x42,0x43,0x7a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x5e,0x48,0xc8,0x48,0x48,0xc8,0x4e,0x00,
+/* 55258 0xd7da "ퟚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x7a,0x0a,0x0b,0x7a,0x42,0x43,0x7a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9e,0x44,0x42,0xd2,0x4a,0x42,0xc4,0x5e,0x00,
+/* 55259 0xd7db "ퟛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x3c,0x20,0x20,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x1c,0x22,0x22,0x22,0x22,0x1c,0x00,
+/* 55260 0xd7dc "ퟜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf7,0x10,0x13,0xf4,0x84,0x84,0xf3,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x80,0x1f,0x04,0x8e,0x91,0x91,0x0e,0x00,
+/* 55261 0xd7dd "ퟝ" */
+0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x1f,0x10,0x1f,0x00,0x03,0x04,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0xf8,0x00,0xf8,0x00,0xe0,0x10,0x10,0xe0,0x00,
+/* 55262 0xd7de "ퟞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0x44,0x44,0x44,0x44,0x7c,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x40,0x40,0x40,0x40,0x3e,0x00,
+/* 55263 0xd7df "ퟟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0x49,0x49,0x49,0x49,0x78,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0xcc,0x00,
+/* 55264 0xd7e0 "ퟠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x40,
+/* 55265 0xd7e1 "ퟡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xf4,0x97,0x94,0x94,0xf7,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x88,0x84,0x8c,0x92,0xa1,0x00,
+/* 55266 0xd7e2 "ퟢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x3e,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x30,0x48,0x84,0x00,
+/* 55267 0xd7e3 "ퟣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x22,0x22,0x3e,0x22,0x22,0x3e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x20,0x20,0x20,0x20,0x3c,0x00,
+/* 55268 0xd7e4 "ퟤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x24,0x24,0x3d,0x25,0x25,0x3d,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xde,0x44,0x52,0xca,0x02,0x04,0xde,0x00,
+/* 55269 0xd7e5 "ퟥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x22,0x22,0x3e,0x22,0x22,0x3e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x40,
+/* 55270 0xd7e6 "ퟦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x22,0x22,0x3e,0x22,0x22,0x3e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0x44,0x44,0x7c,0x44,0x44,0x7c,0x00,
+/* 55271 0xd7e7 "ퟧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x48,0x48,0x78,0x49,0x4a,0x7a,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5e,0x48,0x88,0x48,0x28,0x2e,0x00,
+/* 55272 0xd7e8 "ퟨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x22,0x22,0x3e,0x22,0x22,0x3e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x30,0x48,0x84,0x00,
+/* 55273 0xd7e9 "ퟩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x22,0x22,0x3e,0x22,0x22,0x3e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0xfc,0x20,0x30,0x48,0x84,0x00,
+/* 55274 0xd7ea "ퟪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x0c,0x12,0x61,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x40,
+/* 55275 0xd7eb "ퟫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0x0c,0x12,0x61,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x7c,0x44,0x7c,0x00,0x38,0x44,0x38,0x00,
+/* 55276 0xd7ec "ퟬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x09,0x09,0x19,0x26,0xcc,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x04,0x84,0x44,0x00,
+/* 55277 0xd7ed "ퟭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x09,0x09,0x19,0x26,0xcc,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x10,0x10,0x10,0x90,0x5e,0x00,
+/* 55278 0xd7ee "ퟮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x18,0x24,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x10,0x28,0x44,0x82,0xfe,0x00,
+/* 55279 0xd7ef "ퟯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x18,0x24,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x30,0x48,0x84,0x00,
+/* 55280 0xd7f0 "ퟰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x18,0x24,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0xfc,0x20,0x30,0x48,0x84,0x00,
+/* 55281 0xd7f1 "ퟱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x18,0x24,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x40,0x7c,0x40,0x3c,0x00,
+/* 55282 0xd7f2 "ퟲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x08,0x18,0x24,0xc2,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x7c,0x10,0x38,0x44,0x44,0x38,0x00,
+/* 55283 0xd7f3 "ퟳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x20,0x10,0x28,0x44,0x82,0xfe,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,
+/* 55284 0xd7f4 "ퟴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x21,0x11,0x28,0x44,0x82,0xfe,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x08,0xf8,0x08,0xf8,0x70,0x88,0x70,0x00,0x00,
+/* 55285 0xd7f5 "ퟵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x1c,0x22,0x22,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x44,0x7c,0x40,
+/* 55286 0xd7f6 "ퟶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x1c,0x22,0x22,0x22,0x1c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x7c,0x10,0x38,0x44,0x44,0x38,0x00,
+/* 55287 0xd7f7 "ퟷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x04,0x0c,0x12,0x21,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,0x7c,0x44,0x7c,0x40,
+/* 55288 0xd7f8 "ퟸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x7d,0x11,0x29,0x45,0x01,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x29,0x29,0xef,0x29,0xef,0x08,
+/* 55289 0xd7f9 "ퟹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x08,0x18,0x24,0x42,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x20,0x30,0x48,0x84,0x00,
+/* 55290 0xd7fa "ퟺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x10,0x48,0x28,0x08,0x10,0x7b,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x20,0x20,0x60,0x90,0x08,0x00,
+/* 55291 0xd7fb "ퟻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x10,0x48,0x28,0x08,0x10,0x78,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x40,0x40,0x7c,0x40,0x40,0x3c,0x00,
+/* 55292 0xd7fc "퟼" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 55293 0xd7fd "퟽" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 55294 0xd7fe "퟾" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 55295 0xd7ff "퟿" */
+0x00,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 55296 0xd800 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55297 0xd801 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55298 0xd802 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55299 0xd803 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55300 0xd804 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55301 0xd805 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55302 0xd806 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55303 0xd807 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55304 0xd808 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55305 0xd809 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55306 0xd80a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55307 0xd80b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55308 0xd80c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55309 0xd80d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55310 0xd80e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55311 0xd80f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55312 0xd810 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55313 0xd811 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55314 0xd812 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55315 0xd813 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55316 0xd814 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55317 0xd815 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55318 0xd816 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55319 0xd817 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55320 0xd818 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55321 0xd819 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55322 0xd81a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55323 0xd81b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55324 0xd81c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55325 0xd81d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55326 0xd81e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55327 0xd81f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55328 0xd820 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55329 0xd821 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55330 0xd822 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55331 0xd823 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55332 0xd824 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55333 0xd825 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55334 0xd826 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55335 0xd827 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55336 0xd828 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55337 0xd829 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55338 0xd82a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55339 0xd82b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55340 0xd82c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55341 0xd82d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55342 0xd82e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55343 0xd82f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55344 0xd830 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55345 0xd831 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55346 0xd832 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55347 0xd833 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55348 0xd834 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55349 0xd835 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55350 0xd836 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55351 0xd837 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55352 0xd838 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55353 0xd839 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55354 0xd83a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55355 0xd83b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55356 0xd83c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55357 0xd83d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55358 0xd83e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55359 0xd83f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55360 0xd840 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55361 0xd841 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55362 0xd842 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55363 0xd843 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55364 0xd844 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55365 0xd845 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55366 0xd846 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55367 0xd847 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55368 0xd848 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55369 0xd849 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55370 0xd84a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55371 0xd84b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55372 0xd84c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55373 0xd84d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55374 0xd84e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55375 0xd84f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55376 0xd850 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55377 0xd851 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55378 0xd852 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55379 0xd853 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55380 0xd854 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55381 0xd855 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55382 0xd856 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55383 0xd857 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55384 0xd858 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55385 0xd859 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55386 0xd85a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55387 0xd85b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55388 0xd85c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55389 0xd85d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55390 0xd85e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55391 0xd85f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55392 0xd860 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55393 0xd861 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55394 0xd862 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55395 0xd863 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55396 0xd864 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55397 0xd865 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55398 0xd866 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55399 0xd867 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55400 0xd868 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55401 0xd869 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55402 0xd86a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55403 0xd86b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55404 0xd86c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55405 0xd86d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55406 0xd86e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55407 0xd86f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55408 0xd870 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55409 0xd871 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55410 0xd872 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55411 0xd873 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55412 0xd874 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55413 0xd875 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55414 0xd876 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55415 0xd877 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55416 0xd878 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55417 0xd879 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55418 0xd87a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55419 0xd87b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55420 0xd87c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55421 0xd87d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55422 0xd87e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55423 0xd87f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55424 0xd880 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55425 0xd881 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55426 0xd882 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55427 0xd883 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55428 0xd884 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55429 0xd885 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55430 0xd886 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55431 0xd887 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55432 0xd888 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55433 0xd889 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55434 0xd88a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55435 0xd88b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55436 0xd88c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55437 0xd88d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55438 0xd88e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55439 0xd88f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55440 0xd890 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55441 0xd891 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55442 0xd892 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55443 0xd893 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55444 0xd894 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55445 0xd895 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55446 0xd896 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55447 0xd897 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55448 0xd898 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55449 0xd899 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55450 0xd89a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55451 0xd89b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55452 0xd89c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55453 0xd89d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55454 0xd89e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55455 0xd89f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55456 0xd8a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55457 0xd8a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55458 0xd8a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55459 0xd8a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55460 0xd8a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55461 0xd8a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55462 0xd8a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55463 0xd8a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55464 0xd8a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55465 0xd8a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55466 0xd8aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55467 0xd8ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55468 0xd8ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55469 0xd8ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55470 0xd8ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55471 0xd8af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55472 0xd8b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55473 0xd8b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55474 0xd8b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55475 0xd8b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55476 0xd8b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55477 0xd8b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55478 0xd8b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55479 0xd8b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55480 0xd8b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55481 0xd8b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55482 0xd8ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55483 0xd8bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55484 0xd8bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55485 0xd8bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55486 0xd8be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55487 0xd8bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55488 0xd8c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55489 0xd8c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55490 0xd8c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55491 0xd8c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55492 0xd8c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55493 0xd8c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55494 0xd8c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55495 0xd8c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55496 0xd8c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55497 0xd8c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55498 0xd8ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55499 0xd8cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55500 0xd8cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55501 0xd8cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55502 0xd8ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55503 0xd8cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55504 0xd8d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55505 0xd8d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55506 0xd8d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55507 0xd8d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55508 0xd8d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55509 0xd8d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55510 0xd8d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55511 0xd8d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55512 0xd8d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55513 0xd8d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55514 0xd8da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55515 0xd8db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55516 0xd8dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55517 0xd8dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55518 0xd8de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55519 0xd8df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55520 0xd8e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55521 0xd8e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55522 0xd8e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55523 0xd8e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55524 0xd8e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55525 0xd8e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55526 0xd8e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55527 0xd8e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55528 0xd8e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55529 0xd8e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55530 0xd8ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55531 0xd8eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55532 0xd8ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55533 0xd8ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55534 0xd8ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55535 0xd8ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55536 0xd8f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55537 0xd8f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55538 0xd8f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55539 0xd8f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55540 0xd8f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55541 0xd8f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55542 0xd8f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55543 0xd8f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55544 0xd8f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55545 0xd8f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55546 0xd8fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55547 0xd8fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55548 0xd8fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55549 0xd8fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55550 0xd8fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55551 0xd8ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55552 0xd900 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55553 0xd901 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55554 0xd902 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55555 0xd903 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55556 0xd904 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55557 0xd905 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55558 0xd906 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55559 0xd907 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55560 0xd908 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55561 0xd909 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55562 0xd90a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55563 0xd90b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55564 0xd90c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55565 0xd90d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55566 0xd90e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55567 0xd90f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55568 0xd910 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55569 0xd911 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55570 0xd912 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55571 0xd913 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55572 0xd914 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55573 0xd915 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55574 0xd916 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55575 0xd917 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55576 0xd918 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55577 0xd919 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55578 0xd91a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55579 0xd91b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55580 0xd91c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55581 0xd91d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55582 0xd91e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55583 0xd91f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55584 0xd920 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55585 0xd921 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55586 0xd922 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55587 0xd923 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55588 0xd924 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55589 0xd925 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55590 0xd926 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55591 0xd927 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55592 0xd928 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55593 0xd929 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55594 0xd92a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55595 0xd92b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55596 0xd92c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55597 0xd92d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55598 0xd92e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55599 0xd92f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55600 0xd930 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55601 0xd931 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55602 0xd932 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55603 0xd933 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55604 0xd934 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55605 0xd935 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55606 0xd936 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55607 0xd937 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55608 0xd938 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55609 0xd939 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55610 0xd93a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55611 0xd93b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55612 0xd93c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55613 0xd93d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55614 0xd93e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55615 0xd93f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55616 0xd940 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55617 0xd941 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55618 0xd942 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55619 0xd943 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55620 0xd944 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55621 0xd945 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55622 0xd946 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55623 0xd947 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55624 0xd948 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55625 0xd949 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55626 0xd94a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55627 0xd94b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55628 0xd94c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55629 0xd94d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55630 0xd94e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55631 0xd94f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55632 0xd950 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55633 0xd951 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55634 0xd952 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55635 0xd953 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55636 0xd954 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55637 0xd955 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55638 0xd956 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55639 0xd957 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55640 0xd958 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55641 0xd959 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55642 0xd95a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55643 0xd95b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55644 0xd95c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55645 0xd95d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55646 0xd95e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55647 0xd95f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55648 0xd960 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55649 0xd961 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55650 0xd962 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55651 0xd963 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55652 0xd964 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55653 0xd965 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55654 0xd966 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55655 0xd967 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55656 0xd968 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55657 0xd969 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55658 0xd96a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55659 0xd96b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55660 0xd96c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55661 0xd96d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55662 0xd96e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55663 0xd96f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55664 0xd970 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55665 0xd971 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55666 0xd972 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55667 0xd973 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55668 0xd974 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55669 0xd975 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55670 0xd976 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55671 0xd977 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55672 0xd978 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55673 0xd979 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55674 0xd97a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55675 0xd97b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55676 0xd97c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55677 0xd97d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55678 0xd97e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55679 0xd97f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55680 0xd980 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55681 0xd981 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55682 0xd982 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55683 0xd983 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55684 0xd984 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55685 0xd985 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55686 0xd986 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55687 0xd987 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55688 0xd988 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55689 0xd989 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55690 0xd98a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55691 0xd98b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55692 0xd98c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55693 0xd98d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55694 0xd98e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55695 0xd98f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55696 0xd990 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55697 0xd991 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55698 0xd992 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55699 0xd993 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55700 0xd994 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55701 0xd995 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55702 0xd996 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55703 0xd997 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55704 0xd998 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55705 0xd999 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55706 0xd99a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55707 0xd99b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55708 0xd99c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55709 0xd99d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55710 0xd99e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55711 0xd99f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55712 0xd9a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55713 0xd9a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55714 0xd9a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55715 0xd9a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55716 0xd9a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55717 0xd9a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55718 0xd9a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55719 0xd9a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55720 0xd9a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55721 0xd9a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55722 0xd9aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55723 0xd9ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55724 0xd9ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55725 0xd9ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55726 0xd9ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55727 0xd9af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55728 0xd9b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55729 0xd9b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55730 0xd9b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55731 0xd9b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55732 0xd9b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55733 0xd9b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55734 0xd9b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55735 0xd9b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55736 0xd9b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55737 0xd9b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55738 0xd9ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55739 0xd9bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55740 0xd9bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55741 0xd9bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55742 0xd9be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55743 0xd9bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55744 0xd9c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55745 0xd9c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55746 0xd9c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55747 0xd9c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55748 0xd9c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55749 0xd9c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55750 0xd9c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55751 0xd9c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55752 0xd9c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55753 0xd9c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55754 0xd9ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55755 0xd9cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55756 0xd9cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55757 0xd9cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55758 0xd9ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55759 0xd9cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55760 0xd9d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55761 0xd9d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55762 0xd9d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55763 0xd9d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55764 0xd9d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55765 0xd9d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55766 0xd9d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55767 0xd9d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55768 0xd9d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55769 0xd9d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55770 0xd9da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55771 0xd9db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55772 0xd9dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55773 0xd9dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55774 0xd9de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55775 0xd9df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55776 0xd9e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55777 0xd9e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55778 0xd9e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55779 0xd9e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55780 0xd9e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55781 0xd9e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55782 0xd9e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55783 0xd9e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55784 0xd9e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55785 0xd9e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55786 0xd9ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55787 0xd9eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55788 0xd9ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55789 0xd9ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55790 0xd9ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55791 0xd9ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55792 0xd9f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55793 0xd9f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55794 0xd9f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55795 0xd9f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55796 0xd9f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55797 0xd9f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55798 0xd9f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55799 0xd9f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55800 0xd9f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55801 0xd9f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55802 0xd9fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55803 0xd9fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55804 0xd9fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55805 0xd9fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55806 0xd9fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55807 0xd9ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55808 0xda00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55809 0xda01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55810 0xda02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55811 0xda03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55812 0xda04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55813 0xda05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55814 0xda06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55815 0xda07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55816 0xda08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55817 0xda09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55818 0xda0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55819 0xda0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55820 0xda0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55821 0xda0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55822 0xda0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55823 0xda0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55824 0xda10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55825 0xda11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55826 0xda12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55827 0xda13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55828 0xda14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55829 0xda15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55830 0xda16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55831 0xda17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55832 0xda18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55833 0xda19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55834 0xda1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55835 0xda1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55836 0xda1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55837 0xda1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55838 0xda1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55839 0xda1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55840 0xda20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55841 0xda21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55842 0xda22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55843 0xda23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55844 0xda24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55845 0xda25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55846 0xda26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55847 0xda27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55848 0xda28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55849 0xda29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55850 0xda2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55851 0xda2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55852 0xda2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55853 0xda2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55854 0xda2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55855 0xda2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55856 0xda30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55857 0xda31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55858 0xda32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55859 0xda33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55860 0xda34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55861 0xda35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55862 0xda36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55863 0xda37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55864 0xda38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55865 0xda39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55866 0xda3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55867 0xda3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55868 0xda3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55869 0xda3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55870 0xda3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55871 0xda3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55872 0xda40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55873 0xda41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55874 0xda42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55875 0xda43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55876 0xda44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55877 0xda45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55878 0xda46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55879 0xda47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55880 0xda48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55881 0xda49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55882 0xda4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55883 0xda4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55884 0xda4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55885 0xda4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55886 0xda4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55887 0xda4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55888 0xda50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55889 0xda51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55890 0xda52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55891 0xda53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55892 0xda54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55893 0xda55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55894 0xda56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55895 0xda57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55896 0xda58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55897 0xda59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55898 0xda5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55899 0xda5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55900 0xda5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55901 0xda5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55902 0xda5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55903 0xda5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55904 0xda60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55905 0xda61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55906 0xda62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55907 0xda63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55908 0xda64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55909 0xda65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55910 0xda66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55911 0xda67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55912 0xda68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55913 0xda69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55914 0xda6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55915 0xda6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55916 0xda6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55917 0xda6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55918 0xda6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55919 0xda6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55920 0xda70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55921 0xda71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55922 0xda72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55923 0xda73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55924 0xda74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55925 0xda75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55926 0xda76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55927 0xda77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55928 0xda78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55929 0xda79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55930 0xda7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55931 0xda7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55932 0xda7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55933 0xda7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55934 0xda7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55935 0xda7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55936 0xda80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55937 0xda81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55938 0xda82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55939 0xda83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55940 0xda84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55941 0xda85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55942 0xda86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55943 0xda87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55944 0xda88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55945 0xda89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55946 0xda8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55947 0xda8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55948 0xda8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55949 0xda8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55950 0xda8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55951 0xda8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55952 0xda90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55953 0xda91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55954 0xda92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55955 0xda93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55956 0xda94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55957 0xda95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55958 0xda96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55959 0xda97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55960 0xda98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55961 0xda99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55962 0xda9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55963 0xda9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55964 0xda9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55965 0xda9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55966 0xda9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55967 0xda9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55968 0xdaa0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55969 0xdaa1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55970 0xdaa2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55971 0xdaa3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55972 0xdaa4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55973 0xdaa5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55974 0xdaa6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55975 0xdaa7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55976 0xdaa8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55977 0xdaa9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55978 0xdaaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55979 0xdaab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55980 0xdaac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55981 0xdaad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55982 0xdaae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55983 0xdaaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55984 0xdab0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55985 0xdab1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55986 0xdab2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55987 0xdab3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55988 0xdab4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55989 0xdab5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55990 0xdab6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55991 0xdab7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55992 0xdab8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55993 0xdab9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55994 0xdaba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55995 0xdabb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55996 0xdabc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55997 0xdabd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55998 0xdabe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 55999 0xdabf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56000 0xdac0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56001 0xdac1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56002 0xdac2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56003 0xdac3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56004 0xdac4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56005 0xdac5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56006 0xdac6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56007 0xdac7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56008 0xdac8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56009 0xdac9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56010 0xdaca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56011 0xdacb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56012 0xdacc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56013 0xdacd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56014 0xdace */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56015 0xdacf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56016 0xdad0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56017 0xdad1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56018 0xdad2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56019 0xdad3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56020 0xdad4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56021 0xdad5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56022 0xdad6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56023 0xdad7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56024 0xdad8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56025 0xdad9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56026 0xdada */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56027 0xdadb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56028 0xdadc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56029 0xdadd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56030 0xdade */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56031 0xdadf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56032 0xdae0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56033 0xdae1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56034 0xdae2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56035 0xdae3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56036 0xdae4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56037 0xdae5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56038 0xdae6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56039 0xdae7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56040 0xdae8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56041 0xdae9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56042 0xdaea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56043 0xdaeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56044 0xdaec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56045 0xdaed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56046 0xdaee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56047 0xdaef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56048 0xdaf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56049 0xdaf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56050 0xdaf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56051 0xdaf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56052 0xdaf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56053 0xdaf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56054 0xdaf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56055 0xdaf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56056 0xdaf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56057 0xdaf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56058 0xdafa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56059 0xdafb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56060 0xdafc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56061 0xdafd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56062 0xdafe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56063 0xdaff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56064 0xdb00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56065 0xdb01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56066 0xdb02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56067 0xdb03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56068 0xdb04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56069 0xdb05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56070 0xdb06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56071 0xdb07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56072 0xdb08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56073 0xdb09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56074 0xdb0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56075 0xdb0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56076 0xdb0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56077 0xdb0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56078 0xdb0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56079 0xdb0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56080 0xdb10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56081 0xdb11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56082 0xdb12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56083 0xdb13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56084 0xdb14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56085 0xdb15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56086 0xdb16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56087 0xdb17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56088 0xdb18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56089 0xdb19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56090 0xdb1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56091 0xdb1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56092 0xdb1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56093 0xdb1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56094 0xdb1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56095 0xdb1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56096 0xdb20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56097 0xdb21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56098 0xdb22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56099 0xdb23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56100 0xdb24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56101 0xdb25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56102 0xdb26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56103 0xdb27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56104 0xdb28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56105 0xdb29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56106 0xdb2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56107 0xdb2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56108 0xdb2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56109 0xdb2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56110 0xdb2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56111 0xdb2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56112 0xdb30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56113 0xdb31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56114 0xdb32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56115 0xdb33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56116 0xdb34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56117 0xdb35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56118 0xdb36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56119 0xdb37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56120 0xdb38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56121 0xdb39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56122 0xdb3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56123 0xdb3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56124 0xdb3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56125 0xdb3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56126 0xdb3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56127 0xdb3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56128 0xdb40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56129 0xdb41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56130 0xdb42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56131 0xdb43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56132 0xdb44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56133 0xdb45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56134 0xdb46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56135 0xdb47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56136 0xdb48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56137 0xdb49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56138 0xdb4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56139 0xdb4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56140 0xdb4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56141 0xdb4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56142 0xdb4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56143 0xdb4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56144 0xdb50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56145 0xdb51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56146 0xdb52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56147 0xdb53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56148 0xdb54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56149 0xdb55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56150 0xdb56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56151 0xdb57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56152 0xdb58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56153 0xdb59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56154 0xdb5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56155 0xdb5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56156 0xdb5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56157 0xdb5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56158 0xdb5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56159 0xdb5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56160 0xdb60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56161 0xdb61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56162 0xdb62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56163 0xdb63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56164 0xdb64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56165 0xdb65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56166 0xdb66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56167 0xdb67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56168 0xdb68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56169 0xdb69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56170 0xdb6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56171 0xdb6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56172 0xdb6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56173 0xdb6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56174 0xdb6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56175 0xdb6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56176 0xdb70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56177 0xdb71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56178 0xdb72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56179 0xdb73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56180 0xdb74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56181 0xdb75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56182 0xdb76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56183 0xdb77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56184 0xdb78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56185 0xdb79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56186 0xdb7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56187 0xdb7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56188 0xdb7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56189 0xdb7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56190 0xdb7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56191 0xdb7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56192 0xdb80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56193 0xdb81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56194 0xdb82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56195 0xdb83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56196 0xdb84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56197 0xdb85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56198 0xdb86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56199 0xdb87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56200 0xdb88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56201 0xdb89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56202 0xdb8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56203 0xdb8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56204 0xdb8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56205 0xdb8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56206 0xdb8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56207 0xdb8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56208 0xdb90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56209 0xdb91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56210 0xdb92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56211 0xdb93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56212 0xdb94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56213 0xdb95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56214 0xdb96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56215 0xdb97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56216 0xdb98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56217 0xdb99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56218 0xdb9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56219 0xdb9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56220 0xdb9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56221 0xdb9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56222 0xdb9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56223 0xdb9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56224 0xdba0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56225 0xdba1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56226 0xdba2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56227 0xdba3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56228 0xdba4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56229 0xdba5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56230 0xdba6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56231 0xdba7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56232 0xdba8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56233 0xdba9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56234 0xdbaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56235 0xdbab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56236 0xdbac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56237 0xdbad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56238 0xdbae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56239 0xdbaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56240 0xdbb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56241 0xdbb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56242 0xdbb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56243 0xdbb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56244 0xdbb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56245 0xdbb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56246 0xdbb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56247 0xdbb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56248 0xdbb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56249 0xdbb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56250 0xdbba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56251 0xdbbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56252 0xdbbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56253 0xdbbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56254 0xdbbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56255 0xdbbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56256 0xdbc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56257 0xdbc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56258 0xdbc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56259 0xdbc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56260 0xdbc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56261 0xdbc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56262 0xdbc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56263 0xdbc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56264 0xdbc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56265 0xdbc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56266 0xdbca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56267 0xdbcb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56268 0xdbcc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56269 0xdbcd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56270 0xdbce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56271 0xdbcf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56272 0xdbd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56273 0xdbd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56274 0xdbd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56275 0xdbd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56276 0xdbd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56277 0xdbd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56278 0xdbd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56279 0xdbd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56280 0xdbd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56281 0xdbd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56282 0xdbda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56283 0xdbdb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56284 0xdbdc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56285 0xdbdd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56286 0xdbde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56287 0xdbdf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56288 0xdbe0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56289 0xdbe1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56290 0xdbe2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56291 0xdbe3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56292 0xdbe4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56293 0xdbe5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56294 0xdbe6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56295 0xdbe7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56296 0xdbe8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56297 0xdbe9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56298 0xdbea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56299 0xdbeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56300 0xdbec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56301 0xdbed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56302 0xdbee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56303 0xdbef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56304 0xdbf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56305 0xdbf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56306 0xdbf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56307 0xdbf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56308 0xdbf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56309 0xdbf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56310 0xdbf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56311 0xdbf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56312 0xdbf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56313 0xdbf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56314 0xdbfa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56315 0xdbfb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56316 0xdbfc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56317 0xdbfd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56318 0xdbfe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56319 0xdbff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56320 0xdc00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56321 0xdc01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56322 0xdc02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56323 0xdc03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56324 0xdc04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56325 0xdc05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56326 0xdc06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56327 0xdc07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56328 0xdc08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56329 0xdc09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56330 0xdc0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56331 0xdc0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56332 0xdc0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56333 0xdc0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56334 0xdc0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56335 0xdc0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56336 0xdc10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56337 0xdc11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56338 0xdc12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56339 0xdc13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56340 0xdc14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56341 0xdc15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56342 0xdc16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56343 0xdc17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56344 0xdc18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56345 0xdc19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56346 0xdc1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56347 0xdc1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56348 0xdc1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56349 0xdc1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56350 0xdc1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56351 0xdc1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56352 0xdc20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56353 0xdc21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56354 0xdc22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56355 0xdc23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56356 0xdc24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56357 0xdc25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56358 0xdc26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56359 0xdc27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56360 0xdc28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56361 0xdc29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56362 0xdc2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56363 0xdc2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56364 0xdc2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56365 0xdc2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56366 0xdc2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56367 0xdc2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56368 0xdc30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56369 0xdc31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56370 0xdc32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56371 0xdc33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56372 0xdc34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56373 0xdc35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56374 0xdc36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56375 0xdc37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56376 0xdc38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56377 0xdc39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56378 0xdc3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56379 0xdc3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56380 0xdc3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56381 0xdc3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56382 0xdc3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56383 0xdc3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56384 0xdc40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56385 0xdc41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56386 0xdc42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56387 0xdc43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56388 0xdc44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56389 0xdc45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56390 0xdc46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56391 0xdc47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56392 0xdc48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56393 0xdc49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56394 0xdc4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56395 0xdc4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56396 0xdc4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56397 0xdc4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56398 0xdc4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56399 0xdc4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56400 0xdc50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56401 0xdc51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56402 0xdc52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56403 0xdc53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56404 0xdc54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56405 0xdc55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56406 0xdc56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56407 0xdc57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56408 0xdc58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56409 0xdc59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56410 0xdc5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56411 0xdc5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56412 0xdc5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56413 0xdc5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56414 0xdc5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56415 0xdc5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56416 0xdc60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56417 0xdc61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56418 0xdc62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56419 0xdc63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56420 0xdc64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56421 0xdc65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56422 0xdc66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56423 0xdc67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56424 0xdc68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56425 0xdc69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56426 0xdc6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56427 0xdc6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56428 0xdc6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56429 0xdc6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56430 0xdc6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56431 0xdc6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56432 0xdc70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56433 0xdc71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56434 0xdc72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56435 0xdc73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56436 0xdc74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56437 0xdc75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56438 0xdc76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56439 0xdc77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56440 0xdc78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56441 0xdc79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56442 0xdc7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56443 0xdc7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56444 0xdc7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56445 0xdc7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56446 0xdc7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56447 0xdc7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56448 0xdc80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56449 0xdc81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56450 0xdc82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56451 0xdc83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56452 0xdc84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56453 0xdc85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56454 0xdc86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56455 0xdc87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56456 0xdc88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56457 0xdc89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56458 0xdc8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56459 0xdc8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56460 0xdc8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56461 0xdc8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56462 0xdc8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56463 0xdc8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56464 0xdc90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56465 0xdc91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56466 0xdc92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56467 0xdc93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56468 0xdc94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56469 0xdc95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56470 0xdc96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56471 0xdc97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56472 0xdc98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56473 0xdc99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56474 0xdc9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56475 0xdc9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56476 0xdc9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56477 0xdc9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56478 0xdc9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56479 0xdc9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56480 0xdca0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56481 0xdca1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56482 0xdca2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56483 0xdca3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56484 0xdca4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56485 0xdca5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56486 0xdca6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56487 0xdca7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56488 0xdca8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56489 0xdca9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56490 0xdcaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56491 0xdcab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56492 0xdcac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56493 0xdcad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56494 0xdcae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56495 0xdcaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56496 0xdcb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56497 0xdcb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56498 0xdcb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56499 0xdcb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56500 0xdcb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56501 0xdcb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56502 0xdcb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56503 0xdcb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56504 0xdcb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56505 0xdcb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56506 0xdcba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56507 0xdcbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56508 0xdcbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56509 0xdcbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56510 0xdcbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56511 0xdcbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56512 0xdcc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56513 0xdcc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56514 0xdcc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56515 0xdcc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56516 0xdcc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56517 0xdcc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56518 0xdcc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56519 0xdcc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56520 0xdcc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56521 0xdcc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56522 0xdcca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56523 0xdccb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56524 0xdccc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56525 0xdccd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56526 0xdcce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56527 0xdccf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56528 0xdcd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56529 0xdcd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56530 0xdcd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56531 0xdcd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56532 0xdcd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56533 0xdcd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56534 0xdcd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56535 0xdcd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56536 0xdcd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56537 0xdcd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56538 0xdcda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56539 0xdcdb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56540 0xdcdc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56541 0xdcdd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56542 0xdcde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56543 0xdcdf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56544 0xdce0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56545 0xdce1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56546 0xdce2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56547 0xdce3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56548 0xdce4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56549 0xdce5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56550 0xdce6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56551 0xdce7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56552 0xdce8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56553 0xdce9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56554 0xdcea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56555 0xdceb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56556 0xdcec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56557 0xdced */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56558 0xdcee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56559 0xdcef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56560 0xdcf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56561 0xdcf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56562 0xdcf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56563 0xdcf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56564 0xdcf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56565 0xdcf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56566 0xdcf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56567 0xdcf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56568 0xdcf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56569 0xdcf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56570 0xdcfa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56571 0xdcfb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56572 0xdcfc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56573 0xdcfd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56574 0xdcfe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56575 0xdcff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56576 0xdd00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56577 0xdd01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56578 0xdd02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56579 0xdd03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56580 0xdd04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56581 0xdd05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56582 0xdd06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56583 0xdd07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56584 0xdd08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56585 0xdd09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56586 0xdd0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56587 0xdd0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56588 0xdd0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56589 0xdd0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56590 0xdd0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56591 0xdd0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56592 0xdd10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56593 0xdd11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56594 0xdd12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56595 0xdd13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56596 0xdd14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56597 0xdd15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56598 0xdd16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56599 0xdd17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56600 0xdd18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56601 0xdd19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56602 0xdd1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56603 0xdd1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56604 0xdd1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56605 0xdd1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56606 0xdd1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56607 0xdd1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56608 0xdd20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56609 0xdd21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56610 0xdd22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56611 0xdd23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56612 0xdd24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56613 0xdd25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56614 0xdd26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56615 0xdd27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56616 0xdd28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56617 0xdd29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56618 0xdd2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56619 0xdd2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56620 0xdd2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56621 0xdd2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56622 0xdd2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56623 0xdd2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56624 0xdd30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56625 0xdd31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56626 0xdd32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56627 0xdd33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56628 0xdd34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56629 0xdd35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56630 0xdd36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56631 0xdd37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56632 0xdd38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56633 0xdd39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56634 0xdd3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56635 0xdd3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56636 0xdd3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56637 0xdd3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56638 0xdd3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56639 0xdd3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56640 0xdd40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56641 0xdd41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56642 0xdd42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56643 0xdd43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56644 0xdd44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56645 0xdd45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56646 0xdd46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56647 0xdd47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56648 0xdd48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56649 0xdd49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56650 0xdd4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56651 0xdd4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56652 0xdd4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56653 0xdd4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56654 0xdd4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56655 0xdd4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56656 0xdd50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56657 0xdd51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56658 0xdd52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56659 0xdd53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56660 0xdd54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56661 0xdd55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56662 0xdd56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56663 0xdd57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56664 0xdd58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56665 0xdd59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56666 0xdd5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56667 0xdd5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56668 0xdd5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56669 0xdd5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56670 0xdd5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56671 0xdd5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56672 0xdd60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56673 0xdd61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56674 0xdd62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56675 0xdd63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56676 0xdd64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56677 0xdd65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56678 0xdd66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56679 0xdd67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56680 0xdd68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56681 0xdd69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56682 0xdd6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56683 0xdd6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56684 0xdd6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56685 0xdd6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56686 0xdd6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56687 0xdd6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56688 0xdd70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56689 0xdd71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56690 0xdd72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56691 0xdd73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56692 0xdd74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56693 0xdd75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56694 0xdd76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56695 0xdd77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56696 0xdd78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56697 0xdd79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56698 0xdd7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56699 0xdd7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56700 0xdd7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56701 0xdd7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56702 0xdd7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56703 0xdd7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56704 0xdd80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56705 0xdd81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56706 0xdd82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56707 0xdd83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56708 0xdd84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56709 0xdd85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56710 0xdd86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56711 0xdd87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56712 0xdd88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56713 0xdd89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56714 0xdd8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56715 0xdd8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56716 0xdd8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56717 0xdd8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56718 0xdd8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56719 0xdd8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56720 0xdd90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56721 0xdd91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56722 0xdd92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56723 0xdd93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56724 0xdd94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56725 0xdd95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56726 0xdd96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56727 0xdd97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56728 0xdd98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56729 0xdd99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56730 0xdd9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56731 0xdd9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56732 0xdd9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56733 0xdd9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56734 0xdd9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56735 0xdd9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56736 0xdda0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56737 0xdda1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56738 0xdda2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56739 0xdda3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56740 0xdda4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56741 0xdda5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56742 0xdda6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56743 0xdda7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56744 0xdda8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56745 0xdda9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56746 0xddaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56747 0xddab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56748 0xddac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56749 0xddad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56750 0xddae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56751 0xddaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56752 0xddb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56753 0xddb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56754 0xddb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56755 0xddb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56756 0xddb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56757 0xddb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56758 0xddb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56759 0xddb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56760 0xddb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56761 0xddb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56762 0xddba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56763 0xddbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56764 0xddbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56765 0xddbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56766 0xddbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56767 0xddbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56768 0xddc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56769 0xddc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56770 0xddc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56771 0xddc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56772 0xddc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56773 0xddc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56774 0xddc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56775 0xddc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56776 0xddc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56777 0xddc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56778 0xddca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56779 0xddcb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56780 0xddcc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56781 0xddcd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56782 0xddce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56783 0xddcf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56784 0xddd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56785 0xddd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56786 0xddd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56787 0xddd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56788 0xddd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56789 0xddd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56790 0xddd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56791 0xddd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56792 0xddd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56793 0xddd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56794 0xddda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56795 0xdddb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56796 0xdddc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56797 0xdddd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56798 0xddde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56799 0xdddf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56800 0xdde0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56801 0xdde1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56802 0xdde2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56803 0xdde3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56804 0xdde4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56805 0xdde5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56806 0xdde6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56807 0xdde7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56808 0xdde8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56809 0xdde9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56810 0xddea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56811 0xddeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56812 0xddec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56813 0xdded */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56814 0xddee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56815 0xddef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56816 0xddf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56817 0xddf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56818 0xddf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56819 0xddf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56820 0xddf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56821 0xddf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56822 0xddf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56823 0xddf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56824 0xddf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56825 0xddf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56826 0xddfa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56827 0xddfb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56828 0xddfc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56829 0xddfd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56830 0xddfe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56831 0xddff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56832 0xde00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56833 0xde01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56834 0xde02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56835 0xde03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56836 0xde04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56837 0xde05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56838 0xde06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56839 0xde07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56840 0xde08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56841 0xde09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56842 0xde0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56843 0xde0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56844 0xde0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56845 0xde0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56846 0xde0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56847 0xde0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56848 0xde10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56849 0xde11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56850 0xde12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56851 0xde13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56852 0xde14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56853 0xde15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56854 0xde16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56855 0xde17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56856 0xde18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56857 0xde19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56858 0xde1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56859 0xde1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56860 0xde1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56861 0xde1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56862 0xde1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56863 0xde1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56864 0xde20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56865 0xde21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56866 0xde22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56867 0xde23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56868 0xde24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56869 0xde25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56870 0xde26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56871 0xde27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56872 0xde28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56873 0xde29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56874 0xde2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56875 0xde2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56876 0xde2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56877 0xde2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56878 0xde2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56879 0xde2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56880 0xde30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56881 0xde31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56882 0xde32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56883 0xde33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56884 0xde34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56885 0xde35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56886 0xde36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56887 0xde37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56888 0xde38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56889 0xde39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56890 0xde3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56891 0xde3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56892 0xde3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56893 0xde3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56894 0xde3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56895 0xde3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56896 0xde40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56897 0xde41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56898 0xde42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56899 0xde43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56900 0xde44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56901 0xde45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56902 0xde46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56903 0xde47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56904 0xde48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56905 0xde49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56906 0xde4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56907 0xde4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56908 0xde4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56909 0xde4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56910 0xde4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56911 0xde4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56912 0xde50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56913 0xde51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56914 0xde52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56915 0xde53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56916 0xde54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56917 0xde55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56918 0xde56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56919 0xde57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56920 0xde58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56921 0xde59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56922 0xde5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56923 0xde5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56924 0xde5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56925 0xde5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56926 0xde5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56927 0xde5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56928 0xde60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56929 0xde61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56930 0xde62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56931 0xde63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56932 0xde64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56933 0xde65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56934 0xde66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56935 0xde67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56936 0xde68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56937 0xde69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56938 0xde6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56939 0xde6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56940 0xde6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56941 0xde6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56942 0xde6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56943 0xde6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56944 0xde70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56945 0xde71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56946 0xde72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56947 0xde73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56948 0xde74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56949 0xde75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56950 0xde76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56951 0xde77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56952 0xde78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56953 0xde79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56954 0xde7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56955 0xde7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56956 0xde7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56957 0xde7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56958 0xde7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56959 0xde7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56960 0xde80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56961 0xde81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56962 0xde82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56963 0xde83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56964 0xde84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56965 0xde85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56966 0xde86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56967 0xde87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56968 0xde88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56969 0xde89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56970 0xde8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56971 0xde8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56972 0xde8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56973 0xde8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56974 0xde8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56975 0xde8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56976 0xde90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56977 0xde91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56978 0xde92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56979 0xde93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56980 0xde94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56981 0xde95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56982 0xde96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56983 0xde97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56984 0xde98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56985 0xde99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56986 0xde9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56987 0xde9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56988 0xde9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56989 0xde9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56990 0xde9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56991 0xde9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56992 0xdea0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56993 0xdea1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56994 0xdea2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56995 0xdea3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56996 0xdea4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56997 0xdea5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56998 0xdea6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 56999 0xdea7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57000 0xdea8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57001 0xdea9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57002 0xdeaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57003 0xdeab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57004 0xdeac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57005 0xdead */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57006 0xdeae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57007 0xdeaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57008 0xdeb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57009 0xdeb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57010 0xdeb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57011 0xdeb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57012 0xdeb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57013 0xdeb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57014 0xdeb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57015 0xdeb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57016 0xdeb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57017 0xdeb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57018 0xdeba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57019 0xdebb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57020 0xdebc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57021 0xdebd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57022 0xdebe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57023 0xdebf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57024 0xdec0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57025 0xdec1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57026 0xdec2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57027 0xdec3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57028 0xdec4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57029 0xdec5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57030 0xdec6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57031 0xdec7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57032 0xdec8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57033 0xdec9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57034 0xdeca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57035 0xdecb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57036 0xdecc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57037 0xdecd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57038 0xdece */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57039 0xdecf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57040 0xded0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57041 0xded1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57042 0xded2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57043 0xded3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57044 0xded4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57045 0xded5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57046 0xded6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57047 0xded7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57048 0xded8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57049 0xded9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57050 0xdeda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57051 0xdedb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57052 0xdedc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57053 0xdedd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57054 0xdede */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57055 0xdedf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57056 0xdee0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57057 0xdee1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57058 0xdee2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57059 0xdee3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57060 0xdee4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57061 0xdee5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57062 0xdee6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57063 0xdee7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57064 0xdee8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57065 0xdee9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57066 0xdeea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57067 0xdeeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57068 0xdeec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57069 0xdeed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57070 0xdeee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57071 0xdeef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57072 0xdef0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57073 0xdef1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57074 0xdef2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57075 0xdef3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57076 0xdef4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57077 0xdef5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57078 0xdef6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57079 0xdef7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57080 0xdef8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57081 0xdef9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57082 0xdefa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57083 0xdefb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57084 0xdefc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57085 0xdefd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57086 0xdefe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57087 0xdeff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57088 0xdf00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57089 0xdf01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57090 0xdf02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57091 0xdf03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57092 0xdf04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57093 0xdf05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57094 0xdf06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57095 0xdf07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57096 0xdf08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57097 0xdf09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57098 0xdf0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57099 0xdf0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57100 0xdf0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57101 0xdf0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57102 0xdf0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57103 0xdf0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57104 0xdf10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57105 0xdf11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57106 0xdf12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57107 0xdf13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57108 0xdf14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57109 0xdf15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57110 0xdf16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57111 0xdf17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57112 0xdf18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57113 0xdf19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57114 0xdf1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57115 0xdf1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57116 0xdf1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57117 0xdf1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57118 0xdf1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57119 0xdf1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57120 0xdf20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57121 0xdf21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57122 0xdf22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57123 0xdf23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57124 0xdf24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57125 0xdf25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57126 0xdf26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57127 0xdf27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57128 0xdf28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57129 0xdf29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57130 0xdf2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57131 0xdf2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57132 0xdf2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57133 0xdf2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57134 0xdf2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57135 0xdf2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57136 0xdf30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57137 0xdf31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57138 0xdf32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57139 0xdf33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57140 0xdf34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57141 0xdf35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57142 0xdf36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57143 0xdf37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57144 0xdf38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57145 0xdf39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57146 0xdf3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57147 0xdf3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57148 0xdf3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57149 0xdf3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57150 0xdf3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57151 0xdf3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57152 0xdf40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57153 0xdf41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57154 0xdf42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57155 0xdf43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57156 0xdf44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57157 0xdf45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57158 0xdf46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57159 0xdf47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57160 0xdf48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57161 0xdf49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57162 0xdf4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57163 0xdf4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57164 0xdf4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57165 0xdf4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57166 0xdf4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57167 0xdf4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57168 0xdf50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57169 0xdf51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57170 0xdf52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57171 0xdf53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57172 0xdf54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57173 0xdf55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57174 0xdf56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57175 0xdf57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57176 0xdf58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57177 0xdf59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57178 0xdf5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57179 0xdf5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57180 0xdf5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57181 0xdf5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57182 0xdf5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57183 0xdf5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57184 0xdf60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57185 0xdf61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57186 0xdf62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57187 0xdf63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57188 0xdf64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57189 0xdf65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57190 0xdf66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57191 0xdf67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57192 0xdf68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57193 0xdf69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57194 0xdf6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57195 0xdf6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57196 0xdf6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57197 0xdf6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57198 0xdf6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57199 0xdf6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57200 0xdf70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57201 0xdf71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57202 0xdf72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57203 0xdf73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57204 0xdf74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57205 0xdf75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57206 0xdf76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57207 0xdf77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57208 0xdf78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57209 0xdf79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57210 0xdf7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57211 0xdf7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57212 0xdf7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57213 0xdf7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57214 0xdf7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57215 0xdf7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57216 0xdf80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57217 0xdf81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57218 0xdf82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57219 0xdf83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57220 0xdf84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57221 0xdf85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57222 0xdf86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57223 0xdf87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57224 0xdf88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57225 0xdf89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57226 0xdf8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57227 0xdf8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57228 0xdf8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57229 0xdf8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57230 0xdf8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57231 0xdf8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57232 0xdf90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57233 0xdf91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57234 0xdf92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57235 0xdf93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57236 0xdf94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57237 0xdf95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57238 0xdf96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57239 0xdf97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57240 0xdf98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57241 0xdf99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57242 0xdf9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57243 0xdf9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57244 0xdf9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57245 0xdf9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57246 0xdf9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57247 0xdf9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57248 0xdfa0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57249 0xdfa1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57250 0xdfa2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57251 0xdfa3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57252 0xdfa4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57253 0xdfa5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57254 0xdfa6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57255 0xdfa7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57256 0xdfa8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57257 0xdfa9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57258 0xdfaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57259 0xdfab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57260 0xdfac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57261 0xdfad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57262 0xdfae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57263 0xdfaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57264 0xdfb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57265 0xdfb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57266 0xdfb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57267 0xdfb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57268 0xdfb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57269 0xdfb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57270 0xdfb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57271 0xdfb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57272 0xdfb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57273 0xdfb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57274 0xdfba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57275 0xdfbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57276 0xdfbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57277 0xdfbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57278 0xdfbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57279 0xdfbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57280 0xdfc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57281 0xdfc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57282 0xdfc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57283 0xdfc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57284 0xdfc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57285 0xdfc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57286 0xdfc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57287 0xdfc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57288 0xdfc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57289 0xdfc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57290 0xdfca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57291 0xdfcb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57292 0xdfcc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57293 0xdfcd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57294 0xdfce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57295 0xdfcf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57296 0xdfd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57297 0xdfd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57298 0xdfd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57299 0xdfd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57300 0xdfd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57301 0xdfd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57302 0xdfd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57303 0xdfd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57304 0xdfd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57305 0xdfd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57306 0xdfda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57307 0xdfdb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57308 0xdfdc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57309 0xdfdd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57310 0xdfde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57311 0xdfdf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57312 0xdfe0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57313 0xdfe1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57314 0xdfe2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57315 0xdfe3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57316 0xdfe4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57317 0xdfe5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57318 0xdfe6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57319 0xdfe7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57320 0xdfe8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57321 0xdfe9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57322 0xdfea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57323 0xdfeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57324 0xdfec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57325 0xdfed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57326 0xdfee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57327 0xdfef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57328 0xdff0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57329 0xdff1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57330 0xdff2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57331 0xdff3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57332 0xdff4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57333 0xdff5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57334 0xdff6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57335 0xdff7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57336 0xdff8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57337 0xdff9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57338 0xdffa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57339 0xdffb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57340 0xdffc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57341 0xdffd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57342 0xdffe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57343 0xdfff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57344 0xe000 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57345 0xe001 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57346 0xe002 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57347 0xe003 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57348 0xe004 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57349 0xe005 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57350 0xe006 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57351 0xe007 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57352 0xe008 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57353 0xe009 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57354 0xe00a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57355 0xe00b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57356 0xe00c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57357 0xe00d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57358 0xe00e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57359 0xe00f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57360 0xe010 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57361 0xe011 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57362 0xe012 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57363 0xe013 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57364 0xe014 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57365 0xe015 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57366 0xe016 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57367 0xe017 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57368 0xe018 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57369 0xe019 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57370 0xe01a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57371 0xe01b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57372 0xe01c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57373 0xe01d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57374 0xe01e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57375 0xe01f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57376 0xe020 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57377 0xe021 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57378 0xe022 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57379 0xe023 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57380 0xe024 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57381 0xe025 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57382 0xe026 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57383 0xe027 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57384 0xe028 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57385 0xe029 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57386 0xe02a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57387 0xe02b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57388 0xe02c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57389 0xe02d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57390 0xe02e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57391 0xe02f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57392 0xe030 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57393 0xe031 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57394 0xe032 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57395 0xe033 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57396 0xe034 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57397 0xe035 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57398 0xe036 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57399 0xe037 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57400 0xe038 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57401 0xe039 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57402 0xe03a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57403 0xe03b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57404 0xe03c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57405 0xe03d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57406 0xe03e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57407 0xe03f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57408 0xe040 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57409 0xe041 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57410 0xe042 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57411 0xe043 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57412 0xe044 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57413 0xe045 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57414 0xe046 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57415 0xe047 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57416 0xe048 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57417 0xe049 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57418 0xe04a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57419 0xe04b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57420 0xe04c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57421 0xe04d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57422 0xe04e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57423 0xe04f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57424 0xe050 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57425 0xe051 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57426 0xe052 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57427 0xe053 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57428 0xe054 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57429 0xe055 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57430 0xe056 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57431 0xe057 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57432 0xe058 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57433 0xe059 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57434 0xe05a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57435 0xe05b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57436 0xe05c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57437 0xe05d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57438 0xe05e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57439 0xe05f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57440 0xe060 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57441 0xe061 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57442 0xe062 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57443 0xe063 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57444 0xe064 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57445 0xe065 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57446 0xe066 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57447 0xe067 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57448 0xe068 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57449 0xe069 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57450 0xe06a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57451 0xe06b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57452 0xe06c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57453 0xe06d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57454 0xe06e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57455 0xe06f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57456 0xe070 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57457 0xe071 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57458 0xe072 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57459 0xe073 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57460 0xe074 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57461 0xe075 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57462 0xe076 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57463 0xe077 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57464 0xe078 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57465 0xe079 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57466 0xe07a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57467 0xe07b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57468 0xe07c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57469 0xe07d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57470 0xe07e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57471 0xe07f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57472 0xe080 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57473 0xe081 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57474 0xe082 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57475 0xe083 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57476 0xe084 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57477 0xe085 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57478 0xe086 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57479 0xe087 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57480 0xe088 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57481 0xe089 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57482 0xe08a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57483 0xe08b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57484 0xe08c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57485 0xe08d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57486 0xe08e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57487 0xe08f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57488 0xe090 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57489 0xe091 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57490 0xe092 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57491 0xe093 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57492 0xe094 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57493 0xe095 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57494 0xe096 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57495 0xe097 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57496 0xe098 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57497 0xe099 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57498 0xe09a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57499 0xe09b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57500 0xe09c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57501 0xe09d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57502 0xe09e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57503 0xe09f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57504 0xe0a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57505 0xe0a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57506 0xe0a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57507 0xe0a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57508 0xe0a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57509 0xe0a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57510 0xe0a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57511 0xe0a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57512 0xe0a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57513 0xe0a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57514 0xe0aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57515 0xe0ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57516 0xe0ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57517 0xe0ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57518 0xe0ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57519 0xe0af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57520 0xe0b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57521 0xe0b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57522 0xe0b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57523 0xe0b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57524 0xe0b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57525 0xe0b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57526 0xe0b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57527 0xe0b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57528 0xe0b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57529 0xe0b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57530 0xe0ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57531 0xe0bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57532 0xe0bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57533 0xe0bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57534 0xe0be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57535 0xe0bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57536 0xe0c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57537 0xe0c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57538 0xe0c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57539 0xe0c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57540 0xe0c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57541 0xe0c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57542 0xe0c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57543 0xe0c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57544 0xe0c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57545 0xe0c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57546 0xe0ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57547 0xe0cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57548 0xe0cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57549 0xe0cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57550 0xe0ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57551 0xe0cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57552 0xe0d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57553 0xe0d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57554 0xe0d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57555 0xe0d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57556 0xe0d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57557 0xe0d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57558 0xe0d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57559 0xe0d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57560 0xe0d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57561 0xe0d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57562 0xe0da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57563 0xe0db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57564 0xe0dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57565 0xe0dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57566 0xe0de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57567 0xe0df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57568 0xe0e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57569 0xe0e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57570 0xe0e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57571 0xe0e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57572 0xe0e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57573 0xe0e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57574 0xe0e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57575 0xe0e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57576 0xe0e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57577 0xe0e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57578 0xe0ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57579 0xe0eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57580 0xe0ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57581 0xe0ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57582 0xe0ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57583 0xe0ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57584 0xe0f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57585 0xe0f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57586 0xe0f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57587 0xe0f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57588 0xe0f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57589 0xe0f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57590 0xe0f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57591 0xe0f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57592 0xe0f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57593 0xe0f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57594 0xe0fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57595 0xe0fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57596 0xe0fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57597 0xe0fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57598 0xe0fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57599 0xe0ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57600 0xe100 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57601 0xe101 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57602 0xe102 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57603 0xe103 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57604 0xe104 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57605 0xe105 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57606 0xe106 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57607 0xe107 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57608 0xe108 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57609 0xe109 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57610 0xe10a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57611 0xe10b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57612 0xe10c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57613 0xe10d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57614 0xe10e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57615 0xe10f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57616 0xe110 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57617 0xe111 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57618 0xe112 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57619 0xe113 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57620 0xe114 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57621 0xe115 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57622 0xe116 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57623 0xe117 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57624 0xe118 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57625 0xe119 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57626 0xe11a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57627 0xe11b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57628 0xe11c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57629 0xe11d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57630 0xe11e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57631 0xe11f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57632 0xe120 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57633 0xe121 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57634 0xe122 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57635 0xe123 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57636 0xe124 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57637 0xe125 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57638 0xe126 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57639 0xe127 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57640 0xe128 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57641 0xe129 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57642 0xe12a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57643 0xe12b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57644 0xe12c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57645 0xe12d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57646 0xe12e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57647 0xe12f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57648 0xe130 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57649 0xe131 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57650 0xe132 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57651 0xe133 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57652 0xe134 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57653 0xe135 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57654 0xe136 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57655 0xe137 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57656 0xe138 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57657 0xe139 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57658 0xe13a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57659 0xe13b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57660 0xe13c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57661 0xe13d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57662 0xe13e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57663 0xe13f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57664 0xe140 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57665 0xe141 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57666 0xe142 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57667 0xe143 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57668 0xe144 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57669 0xe145 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57670 0xe146 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57671 0xe147 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57672 0xe148 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57673 0xe149 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57674 0xe14a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57675 0xe14b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57676 0xe14c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57677 0xe14d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57678 0xe14e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57679 0xe14f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57680 0xe150 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57681 0xe151 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57682 0xe152 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57683 0xe153 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57684 0xe154 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57685 0xe155 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57686 0xe156 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57687 0xe157 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57688 0xe158 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57689 0xe159 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57690 0xe15a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57691 0xe15b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57692 0xe15c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57693 0xe15d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57694 0xe15e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57695 0xe15f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57696 0xe160 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57697 0xe161 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57698 0xe162 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57699 0xe163 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57700 0xe164 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57701 0xe165 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57702 0xe166 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57703 0xe167 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57704 0xe168 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57705 0xe169 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57706 0xe16a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57707 0xe16b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57708 0xe16c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57709 0xe16d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57710 0xe16e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57711 0xe16f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57712 0xe170 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57713 0xe171 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57714 0xe172 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57715 0xe173 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57716 0xe174 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57717 0xe175 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57718 0xe176 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57719 0xe177 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57720 0xe178 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57721 0xe179 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57722 0xe17a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57723 0xe17b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57724 0xe17c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57725 0xe17d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57726 0xe17e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57727 0xe17f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57728 0xe180 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57729 0xe181 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57730 0xe182 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57731 0xe183 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57732 0xe184 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57733 0xe185 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57734 0xe186 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57735 0xe187 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57736 0xe188 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57737 0xe189 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57738 0xe18a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57739 0xe18b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57740 0xe18c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57741 0xe18d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57742 0xe18e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57743 0xe18f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57744 0xe190 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57745 0xe191 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57746 0xe192 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57747 0xe193 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57748 0xe194 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57749 0xe195 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57750 0xe196 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57751 0xe197 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57752 0xe198 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57753 0xe199 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57754 0xe19a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57755 0xe19b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57756 0xe19c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57757 0xe19d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57758 0xe19e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57759 0xe19f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57760 0xe1a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57761 0xe1a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57762 0xe1a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57763 0xe1a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57764 0xe1a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57765 0xe1a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57766 0xe1a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57767 0xe1a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57768 0xe1a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57769 0xe1a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57770 0xe1aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57771 0xe1ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57772 0xe1ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57773 0xe1ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57774 0xe1ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57775 0xe1af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57776 0xe1b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57777 0xe1b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57778 0xe1b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57779 0xe1b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57780 0xe1b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57781 0xe1b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57782 0xe1b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57783 0xe1b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57784 0xe1b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57785 0xe1b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57786 0xe1ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57787 0xe1bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57788 0xe1bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57789 0xe1bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57790 0xe1be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57791 0xe1bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57792 0xe1c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57793 0xe1c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57794 0xe1c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57795 0xe1c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57796 0xe1c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57797 0xe1c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57798 0xe1c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57799 0xe1c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57800 0xe1c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57801 0xe1c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57802 0xe1ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57803 0xe1cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57804 0xe1cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57805 0xe1cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57806 0xe1ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57807 0xe1cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57808 0xe1d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57809 0xe1d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57810 0xe1d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57811 0xe1d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57812 0xe1d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57813 0xe1d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57814 0xe1d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57815 0xe1d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57816 0xe1d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57817 0xe1d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57818 0xe1da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57819 0xe1db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57820 0xe1dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57821 0xe1dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57822 0xe1de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57823 0xe1df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57824 0xe1e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57825 0xe1e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57826 0xe1e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57827 0xe1e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57828 0xe1e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57829 0xe1e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57830 0xe1e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57831 0xe1e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57832 0xe1e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57833 0xe1e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57834 0xe1ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57835 0xe1eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57836 0xe1ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57837 0xe1ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57838 0xe1ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57839 0xe1ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57840 0xe1f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57841 0xe1f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57842 0xe1f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57843 0xe1f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57844 0xe1f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57845 0xe1f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57846 0xe1f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57847 0xe1f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57848 0xe1f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57849 0xe1f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57850 0xe1fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57851 0xe1fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57852 0xe1fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57853 0xe1fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57854 0xe1fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57855 0xe1ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57856 0xe200 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57857 0xe201 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57858 0xe202 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57859 0xe203 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57860 0xe204 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57861 0xe205 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57862 0xe206 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57863 0xe207 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57864 0xe208 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57865 0xe209 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57866 0xe20a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57867 0xe20b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57868 0xe20c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57869 0xe20d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57870 0xe20e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57871 0xe20f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57872 0xe210 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57873 0xe211 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57874 0xe212 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57875 0xe213 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57876 0xe214 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57877 0xe215 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57878 0xe216 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57879 0xe217 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57880 0xe218 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57881 0xe219 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57882 0xe21a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57883 0xe21b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57884 0xe21c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57885 0xe21d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57886 0xe21e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57887 0xe21f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57888 0xe220 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57889 0xe221 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57890 0xe222 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57891 0xe223 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57892 0xe224 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57893 0xe225 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57894 0xe226 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57895 0xe227 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57896 0xe228 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57897 0xe229 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57898 0xe22a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57899 0xe22b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57900 0xe22c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57901 0xe22d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57902 0xe22e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57903 0xe22f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57904 0xe230 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57905 0xe231 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57906 0xe232 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57907 0xe233 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57908 0xe234 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57909 0xe235 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57910 0xe236 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57911 0xe237 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57912 0xe238 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57913 0xe239 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57914 0xe23a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57915 0xe23b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57916 0xe23c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57917 0xe23d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57918 0xe23e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57919 0xe23f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57920 0xe240 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57921 0xe241 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57922 0xe242 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57923 0xe243 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57924 0xe244 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57925 0xe245 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57926 0xe246 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57927 0xe247 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57928 0xe248 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57929 0xe249 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57930 0xe24a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57931 0xe24b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57932 0xe24c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57933 0xe24d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57934 0xe24e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57935 0xe24f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57936 0xe250 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57937 0xe251 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57938 0xe252 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57939 0xe253 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57940 0xe254 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57941 0xe255 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57942 0xe256 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57943 0xe257 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57944 0xe258 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57945 0xe259 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57946 0xe25a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57947 0xe25b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57948 0xe25c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57949 0xe25d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57950 0xe25e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57951 0xe25f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57952 0xe260 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57953 0xe261 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57954 0xe262 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57955 0xe263 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57956 0xe264 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57957 0xe265 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57958 0xe266 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57959 0xe267 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57960 0xe268 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57961 0xe269 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57962 0xe26a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57963 0xe26b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57964 0xe26c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57965 0xe26d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57966 0xe26e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57967 0xe26f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57968 0xe270 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57969 0xe271 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57970 0xe272 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57971 0xe273 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57972 0xe274 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57973 0xe275 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57974 0xe276 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57975 0xe277 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57976 0xe278 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57977 0xe279 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57978 0xe27a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57979 0xe27b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57980 0xe27c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57981 0xe27d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57982 0xe27e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57983 0xe27f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57984 0xe280 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57985 0xe281 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57986 0xe282 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57987 0xe283 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57988 0xe284 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57989 0xe285 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57990 0xe286 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57991 0xe287 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57992 0xe288 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57993 0xe289 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57994 0xe28a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57995 0xe28b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57996 0xe28c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57997 0xe28d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57998 0xe28e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 57999 0xe28f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58000 0xe290 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58001 0xe291 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58002 0xe292 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58003 0xe293 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58004 0xe294 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58005 0xe295 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58006 0xe296 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58007 0xe297 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58008 0xe298 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58009 0xe299 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58010 0xe29a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58011 0xe29b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58012 0xe29c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58013 0xe29d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58014 0xe29e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58015 0xe29f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58016 0xe2a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58017 0xe2a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58018 0xe2a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58019 0xe2a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58020 0xe2a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58021 0xe2a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58022 0xe2a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58023 0xe2a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58024 0xe2a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58025 0xe2a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58026 0xe2aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58027 0xe2ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58028 0xe2ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58029 0xe2ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58030 0xe2ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58031 0xe2af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58032 0xe2b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58033 0xe2b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58034 0xe2b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58035 0xe2b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58036 0xe2b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58037 0xe2b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58038 0xe2b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58039 0xe2b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58040 0xe2b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58041 0xe2b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58042 0xe2ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58043 0xe2bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58044 0xe2bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58045 0xe2bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58046 0xe2be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58047 0xe2bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58048 0xe2c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58049 0xe2c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58050 0xe2c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58051 0xe2c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58052 0xe2c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58053 0xe2c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58054 0xe2c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58055 0xe2c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58056 0xe2c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58057 0xe2c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58058 0xe2ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58059 0xe2cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58060 0xe2cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58061 0xe2cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58062 0xe2ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58063 0xe2cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58064 0xe2d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58065 0xe2d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58066 0xe2d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58067 0xe2d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58068 0xe2d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58069 0xe2d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58070 0xe2d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58071 0xe2d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58072 0xe2d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58073 0xe2d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58074 0xe2da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58075 0xe2db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58076 0xe2dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58077 0xe2dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58078 0xe2de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58079 0xe2df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58080 0xe2e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58081 0xe2e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58082 0xe2e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58083 0xe2e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58084 0xe2e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58085 0xe2e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58086 0xe2e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58087 0xe2e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58088 0xe2e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58089 0xe2e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58090 0xe2ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58091 0xe2eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58092 0xe2ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58093 0xe2ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58094 0xe2ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58095 0xe2ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58096 0xe2f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58097 0xe2f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58098 0xe2f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58099 0xe2f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58100 0xe2f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58101 0xe2f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58102 0xe2f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58103 0xe2f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58104 0xe2f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58105 0xe2f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58106 0xe2fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58107 0xe2fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58108 0xe2fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58109 0xe2fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58110 0xe2fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58111 0xe2ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58112 0xe300 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58113 0xe301 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58114 0xe302 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58115 0xe303 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58116 0xe304 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58117 0xe305 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58118 0xe306 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58119 0xe307 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58120 0xe308 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58121 0xe309 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58122 0xe30a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58123 0xe30b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58124 0xe30c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58125 0xe30d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58126 0xe30e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58127 0xe30f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58128 0xe310 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58129 0xe311 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58130 0xe312 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58131 0xe313 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58132 0xe314 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58133 0xe315 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58134 0xe316 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58135 0xe317 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58136 0xe318 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58137 0xe319 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58138 0xe31a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58139 0xe31b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58140 0xe31c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58141 0xe31d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58142 0xe31e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58143 0xe31f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58144 0xe320 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58145 0xe321 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58146 0xe322 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58147 0xe323 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58148 0xe324 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58149 0xe325 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58150 0xe326 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58151 0xe327 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58152 0xe328 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58153 0xe329 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58154 0xe32a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58155 0xe32b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58156 0xe32c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58157 0xe32d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58158 0xe32e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58159 0xe32f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58160 0xe330 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58161 0xe331 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58162 0xe332 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58163 0xe333 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58164 0xe334 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58165 0xe335 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58166 0xe336 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58167 0xe337 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58168 0xe338 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58169 0xe339 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58170 0xe33a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58171 0xe33b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58172 0xe33c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58173 0xe33d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58174 0xe33e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58175 0xe33f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58176 0xe340 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58177 0xe341 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58178 0xe342 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58179 0xe343 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58180 0xe344 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58181 0xe345 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58182 0xe346 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58183 0xe347 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58184 0xe348 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58185 0xe349 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58186 0xe34a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58187 0xe34b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58188 0xe34c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58189 0xe34d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58190 0xe34e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58191 0xe34f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58192 0xe350 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58193 0xe351 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58194 0xe352 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58195 0xe353 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58196 0xe354 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58197 0xe355 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58198 0xe356 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58199 0xe357 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58200 0xe358 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58201 0xe359 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58202 0xe35a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58203 0xe35b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58204 0xe35c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58205 0xe35d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58206 0xe35e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58207 0xe35f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58208 0xe360 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58209 0xe361 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58210 0xe362 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58211 0xe363 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58212 0xe364 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58213 0xe365 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58214 0xe366 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58215 0xe367 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58216 0xe368 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58217 0xe369 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58218 0xe36a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58219 0xe36b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58220 0xe36c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58221 0xe36d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58222 0xe36e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58223 0xe36f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58224 0xe370 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58225 0xe371 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58226 0xe372 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58227 0xe373 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58228 0xe374 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58229 0xe375 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58230 0xe376 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58231 0xe377 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58232 0xe378 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58233 0xe379 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58234 0xe37a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58235 0xe37b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58236 0xe37c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58237 0xe37d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58238 0xe37e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58239 0xe37f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58240 0xe380 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58241 0xe381 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58242 0xe382 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58243 0xe383 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58244 0xe384 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58245 0xe385 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58246 0xe386 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58247 0xe387 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58248 0xe388 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58249 0xe389 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58250 0xe38a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58251 0xe38b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58252 0xe38c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58253 0xe38d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58254 0xe38e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58255 0xe38f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58256 0xe390 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58257 0xe391 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58258 0xe392 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58259 0xe393 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58260 0xe394 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58261 0xe395 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58262 0xe396 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58263 0xe397 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58264 0xe398 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58265 0xe399 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58266 0xe39a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58267 0xe39b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58268 0xe39c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58269 0xe39d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58270 0xe39e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58271 0xe39f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58272 0xe3a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58273 0xe3a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58274 0xe3a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58275 0xe3a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58276 0xe3a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58277 0xe3a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58278 0xe3a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58279 0xe3a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58280 0xe3a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58281 0xe3a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58282 0xe3aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58283 0xe3ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58284 0xe3ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58285 0xe3ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58286 0xe3ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58287 0xe3af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58288 0xe3b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58289 0xe3b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58290 0xe3b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58291 0xe3b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58292 0xe3b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58293 0xe3b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58294 0xe3b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58295 0xe3b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58296 0xe3b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58297 0xe3b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58298 0xe3ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58299 0xe3bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58300 0xe3bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58301 0xe3bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58302 0xe3be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58303 0xe3bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58304 0xe3c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58305 0xe3c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58306 0xe3c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58307 0xe3c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58308 0xe3c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58309 0xe3c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58310 0xe3c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58311 0xe3c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58312 0xe3c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58313 0xe3c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58314 0xe3ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58315 0xe3cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58316 0xe3cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58317 0xe3cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58318 0xe3ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58319 0xe3cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58320 0xe3d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58321 0xe3d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58322 0xe3d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58323 0xe3d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58324 0xe3d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58325 0xe3d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58326 0xe3d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58327 0xe3d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58328 0xe3d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58329 0xe3d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58330 0xe3da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58331 0xe3db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58332 0xe3dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58333 0xe3dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58334 0xe3de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58335 0xe3df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58336 0xe3e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58337 0xe3e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58338 0xe3e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58339 0xe3e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58340 0xe3e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58341 0xe3e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58342 0xe3e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58343 0xe3e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58344 0xe3e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58345 0xe3e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58346 0xe3ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58347 0xe3eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58348 0xe3ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58349 0xe3ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58350 0xe3ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58351 0xe3ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58352 0xe3f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58353 0xe3f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58354 0xe3f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58355 0xe3f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58356 0xe3f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58357 0xe3f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58358 0xe3f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58359 0xe3f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58360 0xe3f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58361 0xe3f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58362 0xe3fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58363 0xe3fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58364 0xe3fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58365 0xe3fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58366 0xe3fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58367 0xe3ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58368 0xe400 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58369 0xe401 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58370 0xe402 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58371 0xe403 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58372 0xe404 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58373 0xe405 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58374 0xe406 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58375 0xe407 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58376 0xe408 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58377 0xe409 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58378 0xe40a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58379 0xe40b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58380 0xe40c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58381 0xe40d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58382 0xe40e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58383 0xe40f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58384 0xe410 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58385 0xe411 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58386 0xe412 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58387 0xe413 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58388 0xe414 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58389 0xe415 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58390 0xe416 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58391 0xe417 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58392 0xe418 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58393 0xe419 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58394 0xe41a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58395 0xe41b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58396 0xe41c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58397 0xe41d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58398 0xe41e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58399 0xe41f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58400 0xe420 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58401 0xe421 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58402 0xe422 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58403 0xe423 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58404 0xe424 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58405 0xe425 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58406 0xe426 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58407 0xe427 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58408 0xe428 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58409 0xe429 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58410 0xe42a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58411 0xe42b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58412 0xe42c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58413 0xe42d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58414 0xe42e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58415 0xe42f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58416 0xe430 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58417 0xe431 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58418 0xe432 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58419 0xe433 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58420 0xe434 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58421 0xe435 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58422 0xe436 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58423 0xe437 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58424 0xe438 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58425 0xe439 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58426 0xe43a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58427 0xe43b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58428 0xe43c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58429 0xe43d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58430 0xe43e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58431 0xe43f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58432 0xe440 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58433 0xe441 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58434 0xe442 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58435 0xe443 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58436 0xe444 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58437 0xe445 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58438 0xe446 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58439 0xe447 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58440 0xe448 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58441 0xe449 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58442 0xe44a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58443 0xe44b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58444 0xe44c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58445 0xe44d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58446 0xe44e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58447 0xe44f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58448 0xe450 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58449 0xe451 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58450 0xe452 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58451 0xe453 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58452 0xe454 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58453 0xe455 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58454 0xe456 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58455 0xe457 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58456 0xe458 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58457 0xe459 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58458 0xe45a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58459 0xe45b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58460 0xe45c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58461 0xe45d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58462 0xe45e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58463 0xe45f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58464 0xe460 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58465 0xe461 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58466 0xe462 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58467 0xe463 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58468 0xe464 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58469 0xe465 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58470 0xe466 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58471 0xe467 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58472 0xe468 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58473 0xe469 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58474 0xe46a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58475 0xe46b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58476 0xe46c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58477 0xe46d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58478 0xe46e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58479 0xe46f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58480 0xe470 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58481 0xe471 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58482 0xe472 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58483 0xe473 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58484 0xe474 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58485 0xe475 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58486 0xe476 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58487 0xe477 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58488 0xe478 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58489 0xe479 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58490 0xe47a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58491 0xe47b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58492 0xe47c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58493 0xe47d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58494 0xe47e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58495 0xe47f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58496 0xe480 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58497 0xe481 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58498 0xe482 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58499 0xe483 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58500 0xe484 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58501 0xe485 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58502 0xe486 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58503 0xe487 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58504 0xe488 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58505 0xe489 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58506 0xe48a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58507 0xe48b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58508 0xe48c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58509 0xe48d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58510 0xe48e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58511 0xe48f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58512 0xe490 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58513 0xe491 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58514 0xe492 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58515 0xe493 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58516 0xe494 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58517 0xe495 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58518 0xe496 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58519 0xe497 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58520 0xe498 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58521 0xe499 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58522 0xe49a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58523 0xe49b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58524 0xe49c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58525 0xe49d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58526 0xe49e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58527 0xe49f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58528 0xe4a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58529 0xe4a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58530 0xe4a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58531 0xe4a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58532 0xe4a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58533 0xe4a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58534 0xe4a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58535 0xe4a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58536 0xe4a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58537 0xe4a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58538 0xe4aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58539 0xe4ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58540 0xe4ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58541 0xe4ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58542 0xe4ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58543 0xe4af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58544 0xe4b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58545 0xe4b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58546 0xe4b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58547 0xe4b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58548 0xe4b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58549 0xe4b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58550 0xe4b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58551 0xe4b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58552 0xe4b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58553 0xe4b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58554 0xe4ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58555 0xe4bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58556 0xe4bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58557 0xe4bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58558 0xe4be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58559 0xe4bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58560 0xe4c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58561 0xe4c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58562 0xe4c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58563 0xe4c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58564 0xe4c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58565 0xe4c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58566 0xe4c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58567 0xe4c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58568 0xe4c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58569 0xe4c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58570 0xe4ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58571 0xe4cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58572 0xe4cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58573 0xe4cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58574 0xe4ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58575 0xe4cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58576 0xe4d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58577 0xe4d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58578 0xe4d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58579 0xe4d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58580 0xe4d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58581 0xe4d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58582 0xe4d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58583 0xe4d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58584 0xe4d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58585 0xe4d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58586 0xe4da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58587 0xe4db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58588 0xe4dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58589 0xe4dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58590 0xe4de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58591 0xe4df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58592 0xe4e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58593 0xe4e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58594 0xe4e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58595 0xe4e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58596 0xe4e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58597 0xe4e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58598 0xe4e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58599 0xe4e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58600 0xe4e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58601 0xe4e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58602 0xe4ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58603 0xe4eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58604 0xe4ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58605 0xe4ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58606 0xe4ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58607 0xe4ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58608 0xe4f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58609 0xe4f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58610 0xe4f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58611 0xe4f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58612 0xe4f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58613 0xe4f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58614 0xe4f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58615 0xe4f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58616 0xe4f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58617 0xe4f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58618 0xe4fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58619 0xe4fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58620 0xe4fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58621 0xe4fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58622 0xe4fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58623 0xe4ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58624 0xe500 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58625 0xe501 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58626 0xe502 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58627 0xe503 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58628 0xe504 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58629 0xe505 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58630 0xe506 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58631 0xe507 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58632 0xe508 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58633 0xe509 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58634 0xe50a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58635 0xe50b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58636 0xe50c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58637 0xe50d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58638 0xe50e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58639 0xe50f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58640 0xe510 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58641 0xe511 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58642 0xe512 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58643 0xe513 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58644 0xe514 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58645 0xe515 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58646 0xe516 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58647 0xe517 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58648 0xe518 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58649 0xe519 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58650 0xe51a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58651 0xe51b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58652 0xe51c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58653 0xe51d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58654 0xe51e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58655 0xe51f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58656 0xe520 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58657 0xe521 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58658 0xe522 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58659 0xe523 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58660 0xe524 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58661 0xe525 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58662 0xe526 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58663 0xe527 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58664 0xe528 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58665 0xe529 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58666 0xe52a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58667 0xe52b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58668 0xe52c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58669 0xe52d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58670 0xe52e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58671 0xe52f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58672 0xe530 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58673 0xe531 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58674 0xe532 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58675 0xe533 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58676 0xe534 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58677 0xe535 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58678 0xe536 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58679 0xe537 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58680 0xe538 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58681 0xe539 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58682 0xe53a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58683 0xe53b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58684 0xe53c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58685 0xe53d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58686 0xe53e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58687 0xe53f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58688 0xe540 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58689 0xe541 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58690 0xe542 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58691 0xe543 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58692 0xe544 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58693 0xe545 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58694 0xe546 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58695 0xe547 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58696 0xe548 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58697 0xe549 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58698 0xe54a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58699 0xe54b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58700 0xe54c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58701 0xe54d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58702 0xe54e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58703 0xe54f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58704 0xe550 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58705 0xe551 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58706 0xe552 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58707 0xe553 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58708 0xe554 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58709 0xe555 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58710 0xe556 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58711 0xe557 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58712 0xe558 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58713 0xe559 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58714 0xe55a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58715 0xe55b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58716 0xe55c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58717 0xe55d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58718 0xe55e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58719 0xe55f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58720 0xe560 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58721 0xe561 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58722 0xe562 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58723 0xe563 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58724 0xe564 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58725 0xe565 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58726 0xe566 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58727 0xe567 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58728 0xe568 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58729 0xe569 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58730 0xe56a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58731 0xe56b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58732 0xe56c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58733 0xe56d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58734 0xe56e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58735 0xe56f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58736 0xe570 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58737 0xe571 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58738 0xe572 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58739 0xe573 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58740 0xe574 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58741 0xe575 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58742 0xe576 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58743 0xe577 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58744 0xe578 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58745 0xe579 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58746 0xe57a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58747 0xe57b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58748 0xe57c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58749 0xe57d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58750 0xe57e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58751 0xe57f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58752 0xe580 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58753 0xe581 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58754 0xe582 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58755 0xe583 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58756 0xe584 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58757 0xe585 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58758 0xe586 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58759 0xe587 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58760 0xe588 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58761 0xe589 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58762 0xe58a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58763 0xe58b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58764 0xe58c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58765 0xe58d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58766 0xe58e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58767 0xe58f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58768 0xe590 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58769 0xe591 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58770 0xe592 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58771 0xe593 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58772 0xe594 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58773 0xe595 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58774 0xe596 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58775 0xe597 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58776 0xe598 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58777 0xe599 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58778 0xe59a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58779 0xe59b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58780 0xe59c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58781 0xe59d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58782 0xe59e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58783 0xe59f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58784 0xe5a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58785 0xe5a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58786 0xe5a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58787 0xe5a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58788 0xe5a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58789 0xe5a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58790 0xe5a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58791 0xe5a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58792 0xe5a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58793 0xe5a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58794 0xe5aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58795 0xe5ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58796 0xe5ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58797 0xe5ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58798 0xe5ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58799 0xe5af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58800 0xe5b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58801 0xe5b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58802 0xe5b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58803 0xe5b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58804 0xe5b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58805 0xe5b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58806 0xe5b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58807 0xe5b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58808 0xe5b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58809 0xe5b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58810 0xe5ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58811 0xe5bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58812 0xe5bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58813 0xe5bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58814 0xe5be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58815 0xe5bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58816 0xe5c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58817 0xe5c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58818 0xe5c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58819 0xe5c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58820 0xe5c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58821 0xe5c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58822 0xe5c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58823 0xe5c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58824 0xe5c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58825 0xe5c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58826 0xe5ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58827 0xe5cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58828 0xe5cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58829 0xe5cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58830 0xe5ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58831 0xe5cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58832 0xe5d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58833 0xe5d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58834 0xe5d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58835 0xe5d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58836 0xe5d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58837 0xe5d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58838 0xe5d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58839 0xe5d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58840 0xe5d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58841 0xe5d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58842 0xe5da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58843 0xe5db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58844 0xe5dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58845 0xe5dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58846 0xe5de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58847 0xe5df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58848 0xe5e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58849 0xe5e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58850 0xe5e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58851 0xe5e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58852 0xe5e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58853 0xe5e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58854 0xe5e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58855 0xe5e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58856 0xe5e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58857 0xe5e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58858 0xe5ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58859 0xe5eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58860 0xe5ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58861 0xe5ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58862 0xe5ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58863 0xe5ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58864 0xe5f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58865 0xe5f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58866 0xe5f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58867 0xe5f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58868 0xe5f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58869 0xe5f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58870 0xe5f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58871 0xe5f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58872 0xe5f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58873 0xe5f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58874 0xe5fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58875 0xe5fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58876 0xe5fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58877 0xe5fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58878 0xe5fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58879 0xe5ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58880 0xe600 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58881 0xe601 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58882 0xe602 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58883 0xe603 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58884 0xe604 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58885 0xe605 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58886 0xe606 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58887 0xe607 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58888 0xe608 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58889 0xe609 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58890 0xe60a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58891 0xe60b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58892 0xe60c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58893 0xe60d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58894 0xe60e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58895 0xe60f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58896 0xe610 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58897 0xe611 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58898 0xe612 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58899 0xe613 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58900 0xe614 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58901 0xe615 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58902 0xe616 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58903 0xe617 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58904 0xe618 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58905 0xe619 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58906 0xe61a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58907 0xe61b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58908 0xe61c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58909 0xe61d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58910 0xe61e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58911 0xe61f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58912 0xe620 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58913 0xe621 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58914 0xe622 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58915 0xe623 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58916 0xe624 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58917 0xe625 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58918 0xe626 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58919 0xe627 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58920 0xe628 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58921 0xe629 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58922 0xe62a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58923 0xe62b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58924 0xe62c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58925 0xe62d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58926 0xe62e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58927 0xe62f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58928 0xe630 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58929 0xe631 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58930 0xe632 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58931 0xe633 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58932 0xe634 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58933 0xe635 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58934 0xe636 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58935 0xe637 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58936 0xe638 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58937 0xe639 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58938 0xe63a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58939 0xe63b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58940 0xe63c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58941 0xe63d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58942 0xe63e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58943 0xe63f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58944 0xe640 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58945 0xe641 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58946 0xe642 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58947 0xe643 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58948 0xe644 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58949 0xe645 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58950 0xe646 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58951 0xe647 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58952 0xe648 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58953 0xe649 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58954 0xe64a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58955 0xe64b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58956 0xe64c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58957 0xe64d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58958 0xe64e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58959 0xe64f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58960 0xe650 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58961 0xe651 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58962 0xe652 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58963 0xe653 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58964 0xe654 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58965 0xe655 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58966 0xe656 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58967 0xe657 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58968 0xe658 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58969 0xe659 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58970 0xe65a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58971 0xe65b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58972 0xe65c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58973 0xe65d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58974 0xe65e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58975 0xe65f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58976 0xe660 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58977 0xe661 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58978 0xe662 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58979 0xe663 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58980 0xe664 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58981 0xe665 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58982 0xe666 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58983 0xe667 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58984 0xe668 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58985 0xe669 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58986 0xe66a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58987 0xe66b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58988 0xe66c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58989 0xe66d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58990 0xe66e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58991 0xe66f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58992 0xe670 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58993 0xe671 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58994 0xe672 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58995 0xe673 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58996 0xe674 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58997 0xe675 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58998 0xe676 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 58999 0xe677 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59000 0xe678 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59001 0xe679 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59002 0xe67a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59003 0xe67b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59004 0xe67c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59005 0xe67d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59006 0xe67e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59007 0xe67f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59008 0xe680 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59009 0xe681 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59010 0xe682 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59011 0xe683 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59012 0xe684 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59013 0xe685 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59014 0xe686 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59015 0xe687 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59016 0xe688 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59017 0xe689 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59018 0xe68a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59019 0xe68b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59020 0xe68c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59021 0xe68d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59022 0xe68e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59023 0xe68f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59024 0xe690 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59025 0xe691 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59026 0xe692 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59027 0xe693 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59028 0xe694 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59029 0xe695 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59030 0xe696 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59031 0xe697 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59032 0xe698 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59033 0xe699 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59034 0xe69a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59035 0xe69b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59036 0xe69c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59037 0xe69d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59038 0xe69e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59039 0xe69f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59040 0xe6a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59041 0xe6a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59042 0xe6a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59043 0xe6a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59044 0xe6a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59045 0xe6a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59046 0xe6a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59047 0xe6a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59048 0xe6a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59049 0xe6a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59050 0xe6aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59051 0xe6ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59052 0xe6ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59053 0xe6ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59054 0xe6ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59055 0xe6af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59056 0xe6b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59057 0xe6b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59058 0xe6b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59059 0xe6b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59060 0xe6b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59061 0xe6b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59062 0xe6b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59063 0xe6b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59064 0xe6b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59065 0xe6b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59066 0xe6ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59067 0xe6bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59068 0xe6bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59069 0xe6bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59070 0xe6be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59071 0xe6bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59072 0xe6c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59073 0xe6c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59074 0xe6c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59075 0xe6c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59076 0xe6c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59077 0xe6c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59078 0xe6c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59079 0xe6c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59080 0xe6c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59081 0xe6c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59082 0xe6ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59083 0xe6cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59084 0xe6cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59085 0xe6cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59086 0xe6ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59087 0xe6cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59088 0xe6d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59089 0xe6d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59090 0xe6d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59091 0xe6d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59092 0xe6d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59093 0xe6d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59094 0xe6d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59095 0xe6d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59096 0xe6d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59097 0xe6d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59098 0xe6da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59099 0xe6db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59100 0xe6dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59101 0xe6dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59102 0xe6de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59103 0xe6df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59104 0xe6e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59105 0xe6e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59106 0xe6e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59107 0xe6e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59108 0xe6e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59109 0xe6e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59110 0xe6e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59111 0xe6e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59112 0xe6e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59113 0xe6e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59114 0xe6ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59115 0xe6eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59116 0xe6ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59117 0xe6ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59118 0xe6ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59119 0xe6ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59120 0xe6f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59121 0xe6f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59122 0xe6f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59123 0xe6f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59124 0xe6f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59125 0xe6f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59126 0xe6f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59127 0xe6f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59128 0xe6f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59129 0xe6f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59130 0xe6fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59131 0xe6fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59132 0xe6fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59133 0xe6fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59134 0xe6fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59135 0xe6ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59136 0xe700 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59137 0xe701 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59138 0xe702 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59139 0xe703 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59140 0xe704 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59141 0xe705 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59142 0xe706 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59143 0xe707 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59144 0xe708 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59145 0xe709 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59146 0xe70a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59147 0xe70b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59148 0xe70c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59149 0xe70d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59150 0xe70e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59151 0xe70f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59152 0xe710 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59153 0xe711 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59154 0xe712 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59155 0xe713 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59156 0xe714 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59157 0xe715 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59158 0xe716 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59159 0xe717 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59160 0xe718 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59161 0xe719 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59162 0xe71a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59163 0xe71b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59164 0xe71c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59165 0xe71d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59166 0xe71e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59167 0xe71f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59168 0xe720 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59169 0xe721 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59170 0xe722 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59171 0xe723 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59172 0xe724 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59173 0xe725 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59174 0xe726 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59175 0xe727 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59176 0xe728 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59177 0xe729 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59178 0xe72a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59179 0xe72b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59180 0xe72c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59181 0xe72d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59182 0xe72e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59183 0xe72f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59184 0xe730 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59185 0xe731 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59186 0xe732 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59187 0xe733 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59188 0xe734 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59189 0xe735 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59190 0xe736 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59191 0xe737 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59192 0xe738 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59193 0xe739 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59194 0xe73a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59195 0xe73b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59196 0xe73c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59197 0xe73d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59198 0xe73e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59199 0xe73f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59200 0xe740 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59201 0xe741 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59202 0xe742 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59203 0xe743 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59204 0xe744 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59205 0xe745 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59206 0xe746 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59207 0xe747 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59208 0xe748 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59209 0xe749 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59210 0xe74a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59211 0xe74b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59212 0xe74c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59213 0xe74d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59214 0xe74e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59215 0xe74f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59216 0xe750 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59217 0xe751 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59218 0xe752 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59219 0xe753 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59220 0xe754 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59221 0xe755 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59222 0xe756 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59223 0xe757 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59224 0xe758 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59225 0xe759 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59226 0xe75a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59227 0xe75b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59228 0xe75c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59229 0xe75d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59230 0xe75e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59231 0xe75f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59232 0xe760 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59233 0xe761 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59234 0xe762 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59235 0xe763 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59236 0xe764 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59237 0xe765 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59238 0xe766 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59239 0xe767 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59240 0xe768 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59241 0xe769 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59242 0xe76a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59243 0xe76b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59244 0xe76c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59245 0xe76d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59246 0xe76e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59247 0xe76f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59248 0xe770 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59249 0xe771 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59250 0xe772 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59251 0xe773 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59252 0xe774 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59253 0xe775 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59254 0xe776 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59255 0xe777 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59256 0xe778 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59257 0xe779 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59258 0xe77a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59259 0xe77b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59260 0xe77c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59261 0xe77d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59262 0xe77e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59263 0xe77f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59264 0xe780 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59265 0xe781 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59266 0xe782 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59267 0xe783 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59268 0xe784 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59269 0xe785 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59270 0xe786 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59271 0xe787 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59272 0xe788 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59273 0xe789 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59274 0xe78a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59275 0xe78b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59276 0xe78c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59277 0xe78d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59278 0xe78e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59279 0xe78f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59280 0xe790 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59281 0xe791 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59282 0xe792 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59283 0xe793 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59284 0xe794 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59285 0xe795 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59286 0xe796 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59287 0xe797 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59288 0xe798 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59289 0xe799 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59290 0xe79a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59291 0xe79b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59292 0xe79c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59293 0xe79d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59294 0xe79e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59295 0xe79f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59296 0xe7a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59297 0xe7a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59298 0xe7a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59299 0xe7a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59300 0xe7a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59301 0xe7a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59302 0xe7a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59303 0xe7a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59304 0xe7a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59305 0xe7a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59306 0xe7aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59307 0xe7ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59308 0xe7ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59309 0xe7ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59310 0xe7ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59311 0xe7af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59312 0xe7b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59313 0xe7b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59314 0xe7b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59315 0xe7b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59316 0xe7b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59317 0xe7b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59318 0xe7b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59319 0xe7b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59320 0xe7b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59321 0xe7b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59322 0xe7ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59323 0xe7bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59324 0xe7bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59325 0xe7bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59326 0xe7be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59327 0xe7bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59328 0xe7c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59329 0xe7c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59330 0xe7c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59331 0xe7c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59332 0xe7c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59333 0xe7c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59334 0xe7c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59335 0xe7c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59336 0xe7c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59337 0xe7c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59338 0xe7ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59339 0xe7cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59340 0xe7cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59341 0xe7cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59342 0xe7ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59343 0xe7cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59344 0xe7d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59345 0xe7d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59346 0xe7d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59347 0xe7d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59348 0xe7d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59349 0xe7d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59350 0xe7d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59351 0xe7d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59352 0xe7d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59353 0xe7d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59354 0xe7da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59355 0xe7db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59356 0xe7dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59357 0xe7dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59358 0xe7de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59359 0xe7df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59360 0xe7e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59361 0xe7e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59362 0xe7e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59363 0xe7e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59364 0xe7e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59365 0xe7e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59366 0xe7e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59367 0xe7e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59368 0xe7e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59369 0xe7e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59370 0xe7ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59371 0xe7eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59372 0xe7ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59373 0xe7ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59374 0xe7ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59375 0xe7ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59376 0xe7f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59377 0xe7f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59378 0xe7f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59379 0xe7f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59380 0xe7f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59381 0xe7f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59382 0xe7f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59383 0xe7f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59384 0xe7f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59385 0xe7f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59386 0xe7fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59387 0xe7fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59388 0xe7fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59389 0xe7fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59390 0xe7fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59391 0xe7ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59392 0xe800 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59393 0xe801 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59394 0xe802 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59395 0xe803 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59396 0xe804 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59397 0xe805 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59398 0xe806 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59399 0xe807 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59400 0xe808 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59401 0xe809 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59402 0xe80a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59403 0xe80b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59404 0xe80c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59405 0xe80d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59406 0xe80e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59407 0xe80f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59408 0xe810 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59409 0xe811 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59410 0xe812 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59411 0xe813 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59412 0xe814 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59413 0xe815 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59414 0xe816 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59415 0xe817 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59416 0xe818 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59417 0xe819 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59418 0xe81a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59419 0xe81b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59420 0xe81c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59421 0xe81d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59422 0xe81e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59423 0xe81f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59424 0xe820 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59425 0xe821 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59426 0xe822 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59427 0xe823 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59428 0xe824 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59429 0xe825 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59430 0xe826 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59431 0xe827 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59432 0xe828 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59433 0xe829 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59434 0xe82a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59435 0xe82b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59436 0xe82c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59437 0xe82d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59438 0xe82e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59439 0xe82f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59440 0xe830 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59441 0xe831 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59442 0xe832 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59443 0xe833 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59444 0xe834 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59445 0xe835 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59446 0xe836 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59447 0xe837 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59448 0xe838 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59449 0xe839 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59450 0xe83a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59451 0xe83b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59452 0xe83c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59453 0xe83d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59454 0xe83e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59455 0xe83f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59456 0xe840 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59457 0xe841 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59458 0xe842 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59459 0xe843 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59460 0xe844 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59461 0xe845 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59462 0xe846 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59463 0xe847 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59464 0xe848 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59465 0xe849 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59466 0xe84a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59467 0xe84b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59468 0xe84c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59469 0xe84d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59470 0xe84e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59471 0xe84f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59472 0xe850 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59473 0xe851 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59474 0xe852 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59475 0xe853 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59476 0xe854 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59477 0xe855 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59478 0xe856 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59479 0xe857 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59480 0xe858 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59481 0xe859 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59482 0xe85a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59483 0xe85b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59484 0xe85c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59485 0xe85d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59486 0xe85e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59487 0xe85f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59488 0xe860 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59489 0xe861 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59490 0xe862 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59491 0xe863 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59492 0xe864 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59493 0xe865 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59494 0xe866 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59495 0xe867 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59496 0xe868 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59497 0xe869 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59498 0xe86a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59499 0xe86b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59500 0xe86c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59501 0xe86d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59502 0xe86e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59503 0xe86f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59504 0xe870 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59505 0xe871 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59506 0xe872 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59507 0xe873 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59508 0xe874 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59509 0xe875 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59510 0xe876 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59511 0xe877 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59512 0xe878 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59513 0xe879 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59514 0xe87a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59515 0xe87b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59516 0xe87c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59517 0xe87d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59518 0xe87e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59519 0xe87f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59520 0xe880 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59521 0xe881 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59522 0xe882 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59523 0xe883 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59524 0xe884 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59525 0xe885 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59526 0xe886 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59527 0xe887 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59528 0xe888 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59529 0xe889 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59530 0xe88a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59531 0xe88b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59532 0xe88c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59533 0xe88d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59534 0xe88e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59535 0xe88f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59536 0xe890 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59537 0xe891 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59538 0xe892 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59539 0xe893 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59540 0xe894 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59541 0xe895 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59542 0xe896 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59543 0xe897 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59544 0xe898 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59545 0xe899 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59546 0xe89a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59547 0xe89b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59548 0xe89c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59549 0xe89d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59550 0xe89e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59551 0xe89f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59552 0xe8a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59553 0xe8a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59554 0xe8a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59555 0xe8a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59556 0xe8a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59557 0xe8a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59558 0xe8a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59559 0xe8a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59560 0xe8a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59561 0xe8a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59562 0xe8aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59563 0xe8ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59564 0xe8ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59565 0xe8ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59566 0xe8ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59567 0xe8af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59568 0xe8b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59569 0xe8b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59570 0xe8b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59571 0xe8b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59572 0xe8b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59573 0xe8b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59574 0xe8b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59575 0xe8b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59576 0xe8b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59577 0xe8b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59578 0xe8ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59579 0xe8bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59580 0xe8bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59581 0xe8bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59582 0xe8be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59583 0xe8bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59584 0xe8c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59585 0xe8c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59586 0xe8c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59587 0xe8c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59588 0xe8c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59589 0xe8c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59590 0xe8c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59591 0xe8c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59592 0xe8c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59593 0xe8c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59594 0xe8ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59595 0xe8cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59596 0xe8cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59597 0xe8cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59598 0xe8ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59599 0xe8cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59600 0xe8d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59601 0xe8d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59602 0xe8d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59603 0xe8d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59604 0xe8d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59605 0xe8d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59606 0xe8d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59607 0xe8d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59608 0xe8d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59609 0xe8d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59610 0xe8da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59611 0xe8db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59612 0xe8dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59613 0xe8dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59614 0xe8de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59615 0xe8df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59616 0xe8e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59617 0xe8e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59618 0xe8e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59619 0xe8e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59620 0xe8e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59621 0xe8e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59622 0xe8e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59623 0xe8e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59624 0xe8e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59625 0xe8e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59626 0xe8ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59627 0xe8eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59628 0xe8ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59629 0xe8ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59630 0xe8ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59631 0xe8ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59632 0xe8f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59633 0xe8f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59634 0xe8f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59635 0xe8f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59636 0xe8f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59637 0xe8f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59638 0xe8f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59639 0xe8f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59640 0xe8f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59641 0xe8f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59642 0xe8fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59643 0xe8fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59644 0xe8fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59645 0xe8fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59646 0xe8fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59647 0xe8ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59648 0xe900 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59649 0xe901 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59650 0xe902 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59651 0xe903 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59652 0xe904 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59653 0xe905 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59654 0xe906 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59655 0xe907 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59656 0xe908 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59657 0xe909 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59658 0xe90a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59659 0xe90b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59660 0xe90c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59661 0xe90d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59662 0xe90e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59663 0xe90f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59664 0xe910 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59665 0xe911 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59666 0xe912 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59667 0xe913 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59668 0xe914 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59669 0xe915 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59670 0xe916 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59671 0xe917 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59672 0xe918 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59673 0xe919 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59674 0xe91a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59675 0xe91b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59676 0xe91c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59677 0xe91d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59678 0xe91e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59679 0xe91f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59680 0xe920 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59681 0xe921 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59682 0xe922 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59683 0xe923 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59684 0xe924 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59685 0xe925 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59686 0xe926 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59687 0xe927 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59688 0xe928 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59689 0xe929 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59690 0xe92a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59691 0xe92b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59692 0xe92c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59693 0xe92d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59694 0xe92e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59695 0xe92f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59696 0xe930 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59697 0xe931 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59698 0xe932 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59699 0xe933 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59700 0xe934 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59701 0xe935 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59702 0xe936 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59703 0xe937 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59704 0xe938 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59705 0xe939 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59706 0xe93a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59707 0xe93b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59708 0xe93c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59709 0xe93d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59710 0xe93e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59711 0xe93f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59712 0xe940 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59713 0xe941 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59714 0xe942 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59715 0xe943 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59716 0xe944 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59717 0xe945 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59718 0xe946 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59719 0xe947 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59720 0xe948 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59721 0xe949 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59722 0xe94a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59723 0xe94b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59724 0xe94c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59725 0xe94d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59726 0xe94e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59727 0xe94f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59728 0xe950 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59729 0xe951 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59730 0xe952 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59731 0xe953 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59732 0xe954 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59733 0xe955 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59734 0xe956 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59735 0xe957 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59736 0xe958 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59737 0xe959 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59738 0xe95a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59739 0xe95b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59740 0xe95c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59741 0xe95d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59742 0xe95e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59743 0xe95f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59744 0xe960 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59745 0xe961 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59746 0xe962 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59747 0xe963 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59748 0xe964 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59749 0xe965 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59750 0xe966 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59751 0xe967 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59752 0xe968 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59753 0xe969 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59754 0xe96a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59755 0xe96b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59756 0xe96c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59757 0xe96d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59758 0xe96e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59759 0xe96f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59760 0xe970 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59761 0xe971 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59762 0xe972 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59763 0xe973 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59764 0xe974 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59765 0xe975 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59766 0xe976 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59767 0xe977 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59768 0xe978 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59769 0xe979 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59770 0xe97a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59771 0xe97b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59772 0xe97c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59773 0xe97d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59774 0xe97e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59775 0xe97f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59776 0xe980 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59777 0xe981 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59778 0xe982 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59779 0xe983 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59780 0xe984 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59781 0xe985 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59782 0xe986 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59783 0xe987 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59784 0xe988 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59785 0xe989 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59786 0xe98a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59787 0xe98b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59788 0xe98c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59789 0xe98d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59790 0xe98e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59791 0xe98f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59792 0xe990 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59793 0xe991 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59794 0xe992 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59795 0xe993 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59796 0xe994 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59797 0xe995 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59798 0xe996 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59799 0xe997 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59800 0xe998 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59801 0xe999 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59802 0xe99a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59803 0xe99b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59804 0xe99c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59805 0xe99d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59806 0xe99e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59807 0xe99f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59808 0xe9a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59809 0xe9a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59810 0xe9a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59811 0xe9a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59812 0xe9a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59813 0xe9a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59814 0xe9a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59815 0xe9a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59816 0xe9a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59817 0xe9a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59818 0xe9aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59819 0xe9ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59820 0xe9ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59821 0xe9ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59822 0xe9ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59823 0xe9af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59824 0xe9b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59825 0xe9b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59826 0xe9b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59827 0xe9b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59828 0xe9b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59829 0xe9b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59830 0xe9b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59831 0xe9b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59832 0xe9b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59833 0xe9b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59834 0xe9ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59835 0xe9bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59836 0xe9bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59837 0xe9bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59838 0xe9be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59839 0xe9bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59840 0xe9c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59841 0xe9c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59842 0xe9c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59843 0xe9c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59844 0xe9c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59845 0xe9c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59846 0xe9c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59847 0xe9c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59848 0xe9c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59849 0xe9c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59850 0xe9ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59851 0xe9cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59852 0xe9cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59853 0xe9cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59854 0xe9ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59855 0xe9cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59856 0xe9d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59857 0xe9d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59858 0xe9d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59859 0xe9d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59860 0xe9d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59861 0xe9d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59862 0xe9d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59863 0xe9d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59864 0xe9d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59865 0xe9d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59866 0xe9da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59867 0xe9db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59868 0xe9dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59869 0xe9dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59870 0xe9de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59871 0xe9df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59872 0xe9e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59873 0xe9e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59874 0xe9e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59875 0xe9e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59876 0xe9e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59877 0xe9e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59878 0xe9e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59879 0xe9e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59880 0xe9e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59881 0xe9e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59882 0xe9ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59883 0xe9eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59884 0xe9ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59885 0xe9ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59886 0xe9ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59887 0xe9ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59888 0xe9f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59889 0xe9f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59890 0xe9f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59891 0xe9f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59892 0xe9f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59893 0xe9f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59894 0xe9f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59895 0xe9f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59896 0xe9f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59897 0xe9f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59898 0xe9fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59899 0xe9fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59900 0xe9fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59901 0xe9fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59902 0xe9fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59903 0xe9ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59904 0xea00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59905 0xea01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59906 0xea02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59907 0xea03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59908 0xea04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59909 0xea05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59910 0xea06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59911 0xea07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59912 0xea08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59913 0xea09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59914 0xea0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59915 0xea0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59916 0xea0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59917 0xea0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59918 0xea0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59919 0xea0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59920 0xea10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59921 0xea11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59922 0xea12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59923 0xea13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59924 0xea14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59925 0xea15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59926 0xea16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59927 0xea17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59928 0xea18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59929 0xea19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59930 0xea1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59931 0xea1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59932 0xea1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59933 0xea1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59934 0xea1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59935 0xea1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59936 0xea20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59937 0xea21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59938 0xea22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59939 0xea23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59940 0xea24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59941 0xea25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59942 0xea26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59943 0xea27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59944 0xea28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59945 0xea29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59946 0xea2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59947 0xea2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59948 0xea2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59949 0xea2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59950 0xea2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59951 0xea2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59952 0xea30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59953 0xea31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59954 0xea32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59955 0xea33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59956 0xea34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59957 0xea35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59958 0xea36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59959 0xea37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59960 0xea38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59961 0xea39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59962 0xea3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59963 0xea3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59964 0xea3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59965 0xea3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59966 0xea3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59967 0xea3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59968 0xea40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59969 0xea41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59970 0xea42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59971 0xea43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59972 0xea44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59973 0xea45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59974 0xea46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59975 0xea47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59976 0xea48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59977 0xea49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59978 0xea4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59979 0xea4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59980 0xea4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59981 0xea4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59982 0xea4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59983 0xea4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59984 0xea50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59985 0xea51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59986 0xea52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59987 0xea53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59988 0xea54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59989 0xea55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59990 0xea56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59991 0xea57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59992 0xea58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59993 0xea59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59994 0xea5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59995 0xea5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59996 0xea5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59997 0xea5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59998 0xea5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 59999 0xea5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60000 0xea60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60001 0xea61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60002 0xea62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60003 0xea63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60004 0xea64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60005 0xea65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60006 0xea66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60007 0xea67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60008 0xea68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60009 0xea69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60010 0xea6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60011 0xea6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60012 0xea6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60013 0xea6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60014 0xea6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60015 0xea6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60016 0xea70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60017 0xea71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60018 0xea72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60019 0xea73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60020 0xea74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60021 0xea75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60022 0xea76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60023 0xea77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60024 0xea78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60025 0xea79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60026 0xea7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60027 0xea7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60028 0xea7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60029 0xea7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60030 0xea7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60031 0xea7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60032 0xea80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60033 0xea81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60034 0xea82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60035 0xea83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60036 0xea84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60037 0xea85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60038 0xea86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60039 0xea87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60040 0xea88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60041 0xea89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60042 0xea8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60043 0xea8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60044 0xea8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60045 0xea8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60046 0xea8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60047 0xea8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60048 0xea90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60049 0xea91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60050 0xea92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60051 0xea93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60052 0xea94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60053 0xea95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60054 0xea96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60055 0xea97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60056 0xea98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60057 0xea99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60058 0xea9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60059 0xea9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60060 0xea9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60061 0xea9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60062 0xea9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60063 0xea9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60064 0xeaa0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60065 0xeaa1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60066 0xeaa2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60067 0xeaa3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60068 0xeaa4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60069 0xeaa5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60070 0xeaa6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60071 0xeaa7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60072 0xeaa8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60073 0xeaa9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60074 0xeaaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60075 0xeaab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60076 0xeaac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60077 0xeaad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60078 0xeaae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60079 0xeaaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60080 0xeab0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60081 0xeab1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60082 0xeab2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60083 0xeab3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60084 0xeab4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60085 0xeab5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60086 0xeab6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60087 0xeab7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60088 0xeab8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60089 0xeab9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60090 0xeaba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60091 0xeabb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60092 0xeabc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60093 0xeabd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60094 0xeabe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60095 0xeabf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60096 0xeac0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60097 0xeac1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60098 0xeac2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60099 0xeac3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60100 0xeac4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60101 0xeac5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60102 0xeac6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60103 0xeac7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60104 0xeac8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60105 0xeac9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60106 0xeaca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60107 0xeacb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60108 0xeacc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60109 0xeacd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60110 0xeace */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60111 0xeacf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60112 0xead0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60113 0xead1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60114 0xead2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60115 0xead3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60116 0xead4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60117 0xead5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60118 0xead6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60119 0xead7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60120 0xead8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60121 0xead9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60122 0xeada */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60123 0xeadb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60124 0xeadc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60125 0xeadd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60126 0xeade */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60127 0xeadf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60128 0xeae0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60129 0xeae1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60130 0xeae2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60131 0xeae3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60132 0xeae4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60133 0xeae5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60134 0xeae6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60135 0xeae7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60136 0xeae8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60137 0xeae9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60138 0xeaea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60139 0xeaeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60140 0xeaec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60141 0xeaed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60142 0xeaee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60143 0xeaef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60144 0xeaf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60145 0xeaf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60146 0xeaf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60147 0xeaf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60148 0xeaf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60149 0xeaf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60150 0xeaf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60151 0xeaf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60152 0xeaf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60153 0xeaf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60154 0xeafa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60155 0xeafb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60156 0xeafc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60157 0xeafd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60158 0xeafe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60159 0xeaff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60160 0xeb00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60161 0xeb01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60162 0xeb02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60163 0xeb03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60164 0xeb04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60165 0xeb05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60166 0xeb06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60167 0xeb07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60168 0xeb08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60169 0xeb09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60170 0xeb0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60171 0xeb0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60172 0xeb0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60173 0xeb0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60174 0xeb0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60175 0xeb0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60176 0xeb10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60177 0xeb11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60178 0xeb12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60179 0xeb13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60180 0xeb14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60181 0xeb15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60182 0xeb16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60183 0xeb17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60184 0xeb18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60185 0xeb19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60186 0xeb1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60187 0xeb1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60188 0xeb1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60189 0xeb1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60190 0xeb1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60191 0xeb1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60192 0xeb20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60193 0xeb21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60194 0xeb22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60195 0xeb23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60196 0xeb24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60197 0xeb25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60198 0xeb26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60199 0xeb27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60200 0xeb28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60201 0xeb29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60202 0xeb2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60203 0xeb2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60204 0xeb2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60205 0xeb2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60206 0xeb2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60207 0xeb2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60208 0xeb30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60209 0xeb31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60210 0xeb32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60211 0xeb33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60212 0xeb34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60213 0xeb35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60214 0xeb36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60215 0xeb37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60216 0xeb38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60217 0xeb39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60218 0xeb3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60219 0xeb3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60220 0xeb3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60221 0xeb3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60222 0xeb3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60223 0xeb3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60224 0xeb40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60225 0xeb41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60226 0xeb42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60227 0xeb43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60228 0xeb44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60229 0xeb45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60230 0xeb46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60231 0xeb47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60232 0xeb48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60233 0xeb49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60234 0xeb4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60235 0xeb4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60236 0xeb4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60237 0xeb4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60238 0xeb4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60239 0xeb4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60240 0xeb50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60241 0xeb51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60242 0xeb52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60243 0xeb53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60244 0xeb54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60245 0xeb55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60246 0xeb56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60247 0xeb57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60248 0xeb58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60249 0xeb59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60250 0xeb5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60251 0xeb5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60252 0xeb5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60253 0xeb5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60254 0xeb5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60255 0xeb5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60256 0xeb60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60257 0xeb61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60258 0xeb62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60259 0xeb63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60260 0xeb64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60261 0xeb65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60262 0xeb66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60263 0xeb67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60264 0xeb68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60265 0xeb69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60266 0xeb6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60267 0xeb6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60268 0xeb6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60269 0xeb6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60270 0xeb6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60271 0xeb6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60272 0xeb70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60273 0xeb71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60274 0xeb72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60275 0xeb73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60276 0xeb74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60277 0xeb75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60278 0xeb76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60279 0xeb77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60280 0xeb78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60281 0xeb79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60282 0xeb7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60283 0xeb7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60284 0xeb7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60285 0xeb7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60286 0xeb7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60287 0xeb7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60288 0xeb80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60289 0xeb81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60290 0xeb82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60291 0xeb83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60292 0xeb84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60293 0xeb85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60294 0xeb86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60295 0xeb87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60296 0xeb88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60297 0xeb89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60298 0xeb8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60299 0xeb8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60300 0xeb8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60301 0xeb8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60302 0xeb8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60303 0xeb8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60304 0xeb90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60305 0xeb91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60306 0xeb92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60307 0xeb93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60308 0xeb94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60309 0xeb95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60310 0xeb96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60311 0xeb97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60312 0xeb98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60313 0xeb99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60314 0xeb9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60315 0xeb9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60316 0xeb9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60317 0xeb9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60318 0xeb9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60319 0xeb9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60320 0xeba0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60321 0xeba1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60322 0xeba2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60323 0xeba3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60324 0xeba4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60325 0xeba5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60326 0xeba6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60327 0xeba7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60328 0xeba8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60329 0xeba9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60330 0xebaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60331 0xebab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60332 0xebac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60333 0xebad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60334 0xebae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60335 0xebaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60336 0xebb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60337 0xebb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60338 0xebb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60339 0xebb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60340 0xebb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60341 0xebb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60342 0xebb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60343 0xebb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60344 0xebb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60345 0xebb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60346 0xebba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60347 0xebbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60348 0xebbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60349 0xebbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60350 0xebbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60351 0xebbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60352 0xebc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60353 0xebc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60354 0xebc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60355 0xebc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60356 0xebc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60357 0xebc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60358 0xebc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60359 0xebc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60360 0xebc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60361 0xebc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60362 0xebca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60363 0xebcb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60364 0xebcc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60365 0xebcd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60366 0xebce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60367 0xebcf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60368 0xebd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60369 0xebd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60370 0xebd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60371 0xebd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60372 0xebd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60373 0xebd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60374 0xebd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60375 0xebd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60376 0xebd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60377 0xebd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60378 0xebda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60379 0xebdb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60380 0xebdc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60381 0xebdd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60382 0xebde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60383 0xebdf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60384 0xebe0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60385 0xebe1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60386 0xebe2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60387 0xebe3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60388 0xebe4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60389 0xebe5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60390 0xebe6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60391 0xebe7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60392 0xebe8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60393 0xebe9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60394 0xebea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60395 0xebeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60396 0xebec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60397 0xebed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60398 0xebee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60399 0xebef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60400 0xebf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60401 0xebf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60402 0xebf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60403 0xebf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60404 0xebf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60405 0xebf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60406 0xebf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60407 0xebf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60408 0xebf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60409 0xebf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60410 0xebfa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60411 0xebfb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60412 0xebfc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60413 0xebfd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60414 0xebfe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60415 0xebff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60416 0xec00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60417 0xec01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60418 0xec02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60419 0xec03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60420 0xec04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60421 0xec05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60422 0xec06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60423 0xec07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60424 0xec08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60425 0xec09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60426 0xec0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60427 0xec0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60428 0xec0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60429 0xec0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60430 0xec0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60431 0xec0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60432 0xec10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60433 0xec11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60434 0xec12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60435 0xec13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60436 0xec14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60437 0xec15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60438 0xec16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60439 0xec17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60440 0xec18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60441 0xec19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60442 0xec1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60443 0xec1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60444 0xec1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60445 0xec1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60446 0xec1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60447 0xec1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60448 0xec20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60449 0xec21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60450 0xec22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60451 0xec23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60452 0xec24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60453 0xec25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60454 0xec26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60455 0xec27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60456 0xec28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60457 0xec29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60458 0xec2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60459 0xec2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60460 0xec2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60461 0xec2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60462 0xec2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60463 0xec2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60464 0xec30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60465 0xec31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60466 0xec32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60467 0xec33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60468 0xec34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60469 0xec35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60470 0xec36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60471 0xec37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60472 0xec38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60473 0xec39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60474 0xec3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60475 0xec3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60476 0xec3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60477 0xec3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60478 0xec3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60479 0xec3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60480 0xec40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60481 0xec41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60482 0xec42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60483 0xec43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60484 0xec44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60485 0xec45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60486 0xec46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60487 0xec47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60488 0xec48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60489 0xec49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60490 0xec4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60491 0xec4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60492 0xec4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60493 0xec4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60494 0xec4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60495 0xec4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60496 0xec50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60497 0xec51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60498 0xec52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60499 0xec53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60500 0xec54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60501 0xec55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60502 0xec56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60503 0xec57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60504 0xec58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60505 0xec59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60506 0xec5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60507 0xec5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60508 0xec5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60509 0xec5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60510 0xec5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60511 0xec5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60512 0xec60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60513 0xec61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60514 0xec62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60515 0xec63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60516 0xec64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60517 0xec65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60518 0xec66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60519 0xec67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60520 0xec68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60521 0xec69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60522 0xec6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60523 0xec6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60524 0xec6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60525 0xec6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60526 0xec6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60527 0xec6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60528 0xec70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60529 0xec71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60530 0xec72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60531 0xec73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60532 0xec74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60533 0xec75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60534 0xec76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60535 0xec77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60536 0xec78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60537 0xec79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60538 0xec7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60539 0xec7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60540 0xec7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60541 0xec7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60542 0xec7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60543 0xec7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60544 0xec80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60545 0xec81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60546 0xec82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60547 0xec83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60548 0xec84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60549 0xec85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60550 0xec86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60551 0xec87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60552 0xec88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60553 0xec89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60554 0xec8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60555 0xec8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60556 0xec8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60557 0xec8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60558 0xec8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60559 0xec8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60560 0xec90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60561 0xec91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60562 0xec92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60563 0xec93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60564 0xec94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60565 0xec95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60566 0xec96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60567 0xec97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60568 0xec98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60569 0xec99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60570 0xec9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60571 0xec9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60572 0xec9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60573 0xec9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60574 0xec9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60575 0xec9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60576 0xeca0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60577 0xeca1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60578 0xeca2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60579 0xeca3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60580 0xeca4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60581 0xeca5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60582 0xeca6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60583 0xeca7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60584 0xeca8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60585 0xeca9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60586 0xecaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60587 0xecab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60588 0xecac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60589 0xecad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60590 0xecae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60591 0xecaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60592 0xecb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60593 0xecb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60594 0xecb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60595 0xecb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60596 0xecb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60597 0xecb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60598 0xecb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60599 0xecb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60600 0xecb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60601 0xecb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60602 0xecba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60603 0xecbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60604 0xecbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60605 0xecbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60606 0xecbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60607 0xecbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60608 0xecc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60609 0xecc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60610 0xecc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60611 0xecc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60612 0xecc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60613 0xecc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60614 0xecc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60615 0xecc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60616 0xecc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60617 0xecc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60618 0xecca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60619 0xeccb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60620 0xeccc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60621 0xeccd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60622 0xecce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60623 0xeccf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60624 0xecd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60625 0xecd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60626 0xecd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60627 0xecd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60628 0xecd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60629 0xecd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60630 0xecd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60631 0xecd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60632 0xecd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60633 0xecd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60634 0xecda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60635 0xecdb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60636 0xecdc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60637 0xecdd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60638 0xecde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60639 0xecdf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60640 0xece0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60641 0xece1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60642 0xece2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60643 0xece3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60644 0xece4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60645 0xece5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60646 0xece6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60647 0xece7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60648 0xece8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60649 0xece9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60650 0xecea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60651 0xeceb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60652 0xecec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60653 0xeced */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60654 0xecee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60655 0xecef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60656 0xecf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60657 0xecf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60658 0xecf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60659 0xecf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60660 0xecf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60661 0xecf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60662 0xecf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60663 0xecf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60664 0xecf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60665 0xecf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60666 0xecfa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60667 0xecfb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60668 0xecfc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60669 0xecfd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60670 0xecfe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60671 0xecff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60672 0xed00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60673 0xed01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60674 0xed02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60675 0xed03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60676 0xed04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60677 0xed05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60678 0xed06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60679 0xed07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60680 0xed08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60681 0xed09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60682 0xed0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60683 0xed0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60684 0xed0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60685 0xed0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60686 0xed0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60687 0xed0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60688 0xed10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60689 0xed11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60690 0xed12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60691 0xed13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60692 0xed14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60693 0xed15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60694 0xed16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60695 0xed17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60696 0xed18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60697 0xed19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60698 0xed1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60699 0xed1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60700 0xed1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60701 0xed1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60702 0xed1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60703 0xed1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60704 0xed20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60705 0xed21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60706 0xed22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60707 0xed23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60708 0xed24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60709 0xed25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60710 0xed26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60711 0xed27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60712 0xed28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60713 0xed29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60714 0xed2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60715 0xed2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60716 0xed2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60717 0xed2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60718 0xed2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60719 0xed2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60720 0xed30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60721 0xed31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60722 0xed32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60723 0xed33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60724 0xed34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60725 0xed35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60726 0xed36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60727 0xed37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60728 0xed38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60729 0xed39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60730 0xed3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60731 0xed3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60732 0xed3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60733 0xed3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60734 0xed3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60735 0xed3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60736 0xed40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60737 0xed41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60738 0xed42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60739 0xed43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60740 0xed44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60741 0xed45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60742 0xed46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60743 0xed47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60744 0xed48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60745 0xed49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60746 0xed4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60747 0xed4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60748 0xed4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60749 0xed4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60750 0xed4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60751 0xed4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60752 0xed50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60753 0xed51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60754 0xed52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60755 0xed53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60756 0xed54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60757 0xed55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60758 0xed56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60759 0xed57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60760 0xed58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60761 0xed59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60762 0xed5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60763 0xed5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60764 0xed5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60765 0xed5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60766 0xed5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60767 0xed5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60768 0xed60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60769 0xed61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60770 0xed62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60771 0xed63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60772 0xed64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60773 0xed65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60774 0xed66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60775 0xed67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60776 0xed68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60777 0xed69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60778 0xed6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60779 0xed6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60780 0xed6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60781 0xed6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60782 0xed6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60783 0xed6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60784 0xed70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60785 0xed71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60786 0xed72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60787 0xed73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60788 0xed74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60789 0xed75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60790 0xed76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60791 0xed77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60792 0xed78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60793 0xed79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60794 0xed7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60795 0xed7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60796 0xed7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60797 0xed7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60798 0xed7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60799 0xed7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60800 0xed80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60801 0xed81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60802 0xed82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60803 0xed83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60804 0xed84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60805 0xed85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60806 0xed86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60807 0xed87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60808 0xed88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60809 0xed89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60810 0xed8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60811 0xed8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60812 0xed8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60813 0xed8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60814 0xed8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60815 0xed8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60816 0xed90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60817 0xed91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60818 0xed92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60819 0xed93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60820 0xed94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60821 0xed95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60822 0xed96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60823 0xed97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60824 0xed98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60825 0xed99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60826 0xed9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60827 0xed9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60828 0xed9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60829 0xed9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60830 0xed9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60831 0xed9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60832 0xeda0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60833 0xeda1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60834 0xeda2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60835 0xeda3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60836 0xeda4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60837 0xeda5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60838 0xeda6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60839 0xeda7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60840 0xeda8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60841 0xeda9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60842 0xedaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60843 0xedab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60844 0xedac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60845 0xedad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60846 0xedae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60847 0xedaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60848 0xedb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60849 0xedb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60850 0xedb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60851 0xedb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60852 0xedb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60853 0xedb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60854 0xedb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60855 0xedb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60856 0xedb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60857 0xedb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60858 0xedba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60859 0xedbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60860 0xedbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60861 0xedbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60862 0xedbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60863 0xedbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60864 0xedc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60865 0xedc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60866 0xedc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60867 0xedc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60868 0xedc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60869 0xedc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60870 0xedc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60871 0xedc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60872 0xedc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60873 0xedc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60874 0xedca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60875 0xedcb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60876 0xedcc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60877 0xedcd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60878 0xedce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60879 0xedcf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60880 0xedd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60881 0xedd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60882 0xedd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60883 0xedd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60884 0xedd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60885 0xedd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60886 0xedd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60887 0xedd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60888 0xedd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60889 0xedd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60890 0xedda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60891 0xeddb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60892 0xeddc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60893 0xeddd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60894 0xedde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60895 0xeddf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60896 0xede0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60897 0xede1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60898 0xede2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60899 0xede3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60900 0xede4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60901 0xede5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60902 0xede6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60903 0xede7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60904 0xede8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60905 0xede9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60906 0xedea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60907 0xedeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60908 0xedec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60909 0xeded */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60910 0xedee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60911 0xedef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60912 0xedf0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60913 0xedf1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60914 0xedf2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60915 0xedf3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60916 0xedf4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60917 0xedf5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60918 0xedf6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60919 0xedf7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60920 0xedf8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60921 0xedf9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60922 0xedfa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60923 0xedfb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60924 0xedfc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60925 0xedfd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60926 0xedfe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60927 0xedff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60928 0xee00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60929 0xee01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60930 0xee02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60931 0xee03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60932 0xee04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60933 0xee05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60934 0xee06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60935 0xee07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60936 0xee08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60937 0xee09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60938 0xee0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60939 0xee0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60940 0xee0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60941 0xee0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60942 0xee0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60943 0xee0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60944 0xee10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60945 0xee11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60946 0xee12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60947 0xee13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60948 0xee14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60949 0xee15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60950 0xee16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60951 0xee17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60952 0xee18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60953 0xee19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60954 0xee1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60955 0xee1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60956 0xee1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60957 0xee1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60958 0xee1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60959 0xee1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60960 0xee20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60961 0xee21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60962 0xee22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60963 0xee23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60964 0xee24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60965 0xee25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60966 0xee26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60967 0xee27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60968 0xee28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60969 0xee29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60970 0xee2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60971 0xee2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60972 0xee2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60973 0xee2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60974 0xee2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60975 0xee2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60976 0xee30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60977 0xee31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60978 0xee32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60979 0xee33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60980 0xee34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60981 0xee35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60982 0xee36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60983 0xee37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60984 0xee38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60985 0xee39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60986 0xee3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60987 0xee3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60988 0xee3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60989 0xee3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60990 0xee3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60991 0xee3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60992 0xee40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60993 0xee41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60994 0xee42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60995 0xee43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60996 0xee44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60997 0xee45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60998 0xee46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 60999 0xee47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61000 0xee48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61001 0xee49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61002 0xee4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61003 0xee4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61004 0xee4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61005 0xee4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61006 0xee4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61007 0xee4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61008 0xee50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61009 0xee51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61010 0xee52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61011 0xee53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61012 0xee54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61013 0xee55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61014 0xee56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61015 0xee57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61016 0xee58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61017 0xee59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61018 0xee5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61019 0xee5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61020 0xee5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61021 0xee5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61022 0xee5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61023 0xee5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61024 0xee60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61025 0xee61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61026 0xee62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61027 0xee63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61028 0xee64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61029 0xee65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61030 0xee66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61031 0xee67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61032 0xee68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61033 0xee69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61034 0xee6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61035 0xee6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61036 0xee6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61037 0xee6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61038 0xee6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61039 0xee6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61040 0xee70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61041 0xee71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61042 0xee72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61043 0xee73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61044 0xee74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61045 0xee75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61046 0xee76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61047 0xee77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61048 0xee78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61049 0xee79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61050 0xee7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61051 0xee7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61052 0xee7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61053 0xee7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61054 0xee7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61055 0xee7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61056 0xee80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61057 0xee81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61058 0xee82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61059 0xee83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61060 0xee84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61061 0xee85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61062 0xee86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61063 0xee87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61064 0xee88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61065 0xee89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61066 0xee8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61067 0xee8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61068 0xee8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61069 0xee8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61070 0xee8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61071 0xee8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61072 0xee90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61073 0xee91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61074 0xee92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61075 0xee93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61076 0xee94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61077 0xee95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61078 0xee96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61079 0xee97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61080 0xee98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61081 0xee99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61082 0xee9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61083 0xee9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61084 0xee9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61085 0xee9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61086 0xee9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61087 0xee9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61088 0xeea0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61089 0xeea1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61090 0xeea2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61091 0xeea3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61092 0xeea4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61093 0xeea5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61094 0xeea6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61095 0xeea7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61096 0xeea8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61097 0xeea9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61098 0xeeaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61099 0xeeab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61100 0xeeac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61101 0xeead */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61102 0xeeae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61103 0xeeaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61104 0xeeb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61105 0xeeb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61106 0xeeb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61107 0xeeb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61108 0xeeb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61109 0xeeb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61110 0xeeb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61111 0xeeb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61112 0xeeb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61113 0xeeb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61114 0xeeba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61115 0xeebb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61116 0xeebc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61117 0xeebd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61118 0xeebe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61119 0xeebf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61120 0xeec0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61121 0xeec1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61122 0xeec2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61123 0xeec3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61124 0xeec4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61125 0xeec5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61126 0xeec6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61127 0xeec7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61128 0xeec8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61129 0xeec9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61130 0xeeca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61131 0xeecb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61132 0xeecc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61133 0xeecd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61134 0xeece */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61135 0xeecf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61136 0xeed0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61137 0xeed1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61138 0xeed2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61139 0xeed3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61140 0xeed4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61141 0xeed5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61142 0xeed6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61143 0xeed7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61144 0xeed8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61145 0xeed9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61146 0xeeda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61147 0xeedb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61148 0xeedc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61149 0xeedd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61150 0xeede */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61151 0xeedf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61152 0xeee0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61153 0xeee1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61154 0xeee2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61155 0xeee3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61156 0xeee4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61157 0xeee5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61158 0xeee6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61159 0xeee7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61160 0xeee8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61161 0xeee9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61162 0xeeea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61163 0xeeeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61164 0xeeec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61165 0xeeed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61166 0xeeee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61167 0xeeef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61168 0xeef0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61169 0xeef1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61170 0xeef2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61171 0xeef3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61172 0xeef4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61173 0xeef5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61174 0xeef6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61175 0xeef7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61176 0xeef8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61177 0xeef9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61178 0xeefa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61179 0xeefb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61180 0xeefc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61181 0xeefd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61182 0xeefe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61183 0xeeff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61184 0xef00 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61185 0xef01 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61186 0xef02 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61187 0xef03 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61188 0xef04 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61189 0xef05 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61190 0xef06 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61191 0xef07 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61192 0xef08 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61193 0xef09 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61194 0xef0a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61195 0xef0b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61196 0xef0c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61197 0xef0d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61198 0xef0e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61199 0xef0f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61200 0xef10 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61201 0xef11 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61202 0xef12 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61203 0xef13 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61204 0xef14 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61205 0xef15 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61206 0xef16 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61207 0xef17 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61208 0xef18 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61209 0xef19 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61210 0xef1a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61211 0xef1b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61212 0xef1c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61213 0xef1d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61214 0xef1e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61215 0xef1f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61216 0xef20 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61217 0xef21 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61218 0xef22 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61219 0xef23 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61220 0xef24 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61221 0xef25 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61222 0xef26 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61223 0xef27 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61224 0xef28 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61225 0xef29 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61226 0xef2a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61227 0xef2b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61228 0xef2c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61229 0xef2d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61230 0xef2e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61231 0xef2f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61232 0xef30 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61233 0xef31 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61234 0xef32 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61235 0xef33 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61236 0xef34 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61237 0xef35 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61238 0xef36 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61239 0xef37 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61240 0xef38 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61241 0xef39 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61242 0xef3a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61243 0xef3b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61244 0xef3c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61245 0xef3d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61246 0xef3e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61247 0xef3f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61248 0xef40 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61249 0xef41 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61250 0xef42 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61251 0xef43 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61252 0xef44 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61253 0xef45 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61254 0xef46 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61255 0xef47 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61256 0xef48 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61257 0xef49 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61258 0xef4a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61259 0xef4b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61260 0xef4c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61261 0xef4d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61262 0xef4e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61263 0xef4f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61264 0xef50 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61265 0xef51 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61266 0xef52 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61267 0xef53 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61268 0xef54 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61269 0xef55 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61270 0xef56 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61271 0xef57 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61272 0xef58 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61273 0xef59 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61274 0xef5a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61275 0xef5b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61276 0xef5c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61277 0xef5d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61278 0xef5e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61279 0xef5f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61280 0xef60 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61281 0xef61 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61282 0xef62 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61283 0xef63 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61284 0xef64 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61285 0xef65 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61286 0xef66 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61287 0xef67 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61288 0xef68 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61289 0xef69 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61290 0xef6a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61291 0xef6b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61292 0xef6c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61293 0xef6d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61294 0xef6e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61295 0xef6f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61296 0xef70 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61297 0xef71 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61298 0xef72 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61299 0xef73 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61300 0xef74 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61301 0xef75 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61302 0xef76 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61303 0xef77 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61304 0xef78 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61305 0xef79 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61306 0xef7a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61307 0xef7b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61308 0xef7c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61309 0xef7d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61310 0xef7e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61311 0xef7f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61312 0xef80 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61313 0xef81 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61314 0xef82 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61315 0xef83 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61316 0xef84 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61317 0xef85 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61318 0xef86 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61319 0xef87 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61320 0xef88 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61321 0xef89 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61322 0xef8a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61323 0xef8b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61324 0xef8c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61325 0xef8d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61326 0xef8e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61327 0xef8f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61328 0xef90 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61329 0xef91 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61330 0xef92 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61331 0xef93 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61332 0xef94 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61333 0xef95 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61334 0xef96 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61335 0xef97 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61336 0xef98 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61337 0xef99 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61338 0xef9a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61339 0xef9b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61340 0xef9c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61341 0xef9d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61342 0xef9e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61343 0xef9f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61344 0xefa0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61345 0xefa1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61346 0xefa2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61347 0xefa3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61348 0xefa4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61349 0xefa5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61350 0xefa6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61351 0xefa7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61352 0xefa8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61353 0xefa9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61354 0xefaa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61355 0xefab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61356 0xefac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61357 0xefad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61358 0xefae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61359 0xefaf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61360 0xefb0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61361 0xefb1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61362 0xefb2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61363 0xefb3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61364 0xefb4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61365 0xefb5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61366 0xefb6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61367 0xefb7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61368 0xefb8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61369 0xefb9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61370 0xefba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61371 0xefbb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61372 0xefbc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61373 0xefbd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61374 0xefbe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61375 0xefbf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61376 0xefc0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61377 0xefc1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61378 0xefc2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61379 0xefc3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61380 0xefc4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61381 0xefc5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61382 0xefc6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61383 0xefc7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61384 0xefc8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61385 0xefc9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61386 0xefca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61387 0xefcb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61388 0xefcc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61389 0xefcd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61390 0xefce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61391 0xefcf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61392 0xefd0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61393 0xefd1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61394 0xefd2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61395 0xefd3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61396 0xefd4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61397 0xefd5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61398 0xefd6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61399 0xefd7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61400 0xefd8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61401 0xefd9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61402 0xefda */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61403 0xefdb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61404 0xefdc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61405 0xefdd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61406 0xefde */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61407 0xefdf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61408 0xefe0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61409 0xefe1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61410 0xefe2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61411 0xefe3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61412 0xefe4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61413 0xefe5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61414 0xefe6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61415 0xefe7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61416 0xefe8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61417 0xefe9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61418 0xefea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61419 0xefeb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61420 0xefec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61421 0xefed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61422 0xefee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61423 0xefef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61424 0xeff0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61425 0xeff1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61426 0xeff2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61427 0xeff3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61428 0xeff4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61429 0xeff5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61430 0xeff6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61431 0xeff7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61432 0xeff8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61433 0xeff9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61434 0xeffa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61435 0xeffb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61436 0xeffc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61437 0xeffd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61438 0xeffe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61439 0xefff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61440 0xf000 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61441 0xf001 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61442 0xf002 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61443 0xf003 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61444 0xf004 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61445 0xf005 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61446 0xf006 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61447 0xf007 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61448 0xf008 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61449 0xf009 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61450 0xf00a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61451 0xf00b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61452 0xf00c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61453 0xf00d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61454 0xf00e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61455 0xf00f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61456 0xf010 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61457 0xf011 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61458 0xf012 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61459 0xf013 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61460 0xf014 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61461 0xf015 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61462 0xf016 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61463 0xf017 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61464 0xf018 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61465 0xf019 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61466 0xf01a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61467 0xf01b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61468 0xf01c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61469 0xf01d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61470 0xf01e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61471 0xf01f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61472 0xf020 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61473 0xf021 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61474 0xf022 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61475 0xf023 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61476 0xf024 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61477 0xf025 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61478 0xf026 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61479 0xf027 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61480 0xf028 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61481 0xf029 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61482 0xf02a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61483 0xf02b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61484 0xf02c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61485 0xf02d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61486 0xf02e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61487 0xf02f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61488 0xf030 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61489 0xf031 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61490 0xf032 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61491 0xf033 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61492 0xf034 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61493 0xf035 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61494 0xf036 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61495 0xf037 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61496 0xf038 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61497 0xf039 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61498 0xf03a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61499 0xf03b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61500 0xf03c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61501 0xf03d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61502 0xf03e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61503 0xf03f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61504 0xf040 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61505 0xf041 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61506 0xf042 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61507 0xf043 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61508 0xf044 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61509 0xf045 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61510 0xf046 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61511 0xf047 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61512 0xf048 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61513 0xf049 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61514 0xf04a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61515 0xf04b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61516 0xf04c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61517 0xf04d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61518 0xf04e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61519 0xf04f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61520 0xf050 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61521 0xf051 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61522 0xf052 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61523 0xf053 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61524 0xf054 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61525 0xf055 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61526 0xf056 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61527 0xf057 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61528 0xf058 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61529 0xf059 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61530 0xf05a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61531 0xf05b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61532 0xf05c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61533 0xf05d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61534 0xf05e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61535 0xf05f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61536 0xf060 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61537 0xf061 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61538 0xf062 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61539 0xf063 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61540 0xf064 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61541 0xf065 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61542 0xf066 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61543 0xf067 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61544 0xf068 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61545 0xf069 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61546 0xf06a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61547 0xf06b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61548 0xf06c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61549 0xf06d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61550 0xf06e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61551 0xf06f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61552 0xf070 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61553 0xf071 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61554 0xf072 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61555 0xf073 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61556 0xf074 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61557 0xf075 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61558 0xf076 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61559 0xf077 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61560 0xf078 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61561 0xf079 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61562 0xf07a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61563 0xf07b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61564 0xf07c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61565 0xf07d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61566 0xf07e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61567 0xf07f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61568 0xf080 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61569 0xf081 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61570 0xf082 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61571 0xf083 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61572 0xf084 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61573 0xf085 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61574 0xf086 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61575 0xf087 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61576 0xf088 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61577 0xf089 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61578 0xf08a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61579 0xf08b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61580 0xf08c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61581 0xf08d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61582 0xf08e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61583 0xf08f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61584 0xf090 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61585 0xf091 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61586 0xf092 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61587 0xf093 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61588 0xf094 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61589 0xf095 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61590 0xf096 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61591 0xf097 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61592 0xf098 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61593 0xf099 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61594 0xf09a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61595 0xf09b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61596 0xf09c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61597 0xf09d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61598 0xf09e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61599 0xf09f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61600 0xf0a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61601 0xf0a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61602 0xf0a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61603 0xf0a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61604 0xf0a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61605 0xf0a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61606 0xf0a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61607 0xf0a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61608 0xf0a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61609 0xf0a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61610 0xf0aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61611 0xf0ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61612 0xf0ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61613 0xf0ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61614 0xf0ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61615 0xf0af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61616 0xf0b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61617 0xf0b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61618 0xf0b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61619 0xf0b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61620 0xf0b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61621 0xf0b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61622 0xf0b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61623 0xf0b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61624 0xf0b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61625 0xf0b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61626 0xf0ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61627 0xf0bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61628 0xf0bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61629 0xf0bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61630 0xf0be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61631 0xf0bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61632 0xf0c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61633 0xf0c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61634 0xf0c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61635 0xf0c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61636 0xf0c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61637 0xf0c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61638 0xf0c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61639 0xf0c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61640 0xf0c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61641 0xf0c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61642 0xf0ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61643 0xf0cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61644 0xf0cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61645 0xf0cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61646 0xf0ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61647 0xf0cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61648 0xf0d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61649 0xf0d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61650 0xf0d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61651 0xf0d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61652 0xf0d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61653 0xf0d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61654 0xf0d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61655 0xf0d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61656 0xf0d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61657 0xf0d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61658 0xf0da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61659 0xf0db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61660 0xf0dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61661 0xf0dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61662 0xf0de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61663 0xf0df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61664 0xf0e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61665 0xf0e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61666 0xf0e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61667 0xf0e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61668 0xf0e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61669 0xf0e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61670 0xf0e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61671 0xf0e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61672 0xf0e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61673 0xf0e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61674 0xf0ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61675 0xf0eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61676 0xf0ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61677 0xf0ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61678 0xf0ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61679 0xf0ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61680 0xf0f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61681 0xf0f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61682 0xf0f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61683 0xf0f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61684 0xf0f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61685 0xf0f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61686 0xf0f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61687 0xf0f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61688 0xf0f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61689 0xf0f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61690 0xf0fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61691 0xf0fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61692 0xf0fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61693 0xf0fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61694 0xf0fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61695 0xf0ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61696 0xf100 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61697 0xf101 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61698 0xf102 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61699 0xf103 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61700 0xf104 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61701 0xf105 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61702 0xf106 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61703 0xf107 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61704 0xf108 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61705 0xf109 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61706 0xf10a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61707 0xf10b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61708 0xf10c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61709 0xf10d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61710 0xf10e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61711 0xf10f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61712 0xf110 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61713 0xf111 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61714 0xf112 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61715 0xf113 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61716 0xf114 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61717 0xf115 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61718 0xf116 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61719 0xf117 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61720 0xf118 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61721 0xf119 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61722 0xf11a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61723 0xf11b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61724 0xf11c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61725 0xf11d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61726 0xf11e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61727 0xf11f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61728 0xf120 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61729 0xf121 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61730 0xf122 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61731 0xf123 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61732 0xf124 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61733 0xf125 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61734 0xf126 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61735 0xf127 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61736 0xf128 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61737 0xf129 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61738 0xf12a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61739 0xf12b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61740 0xf12c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61741 0xf12d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61742 0xf12e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61743 0xf12f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61744 0xf130 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61745 0xf131 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61746 0xf132 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61747 0xf133 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61748 0xf134 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61749 0xf135 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61750 0xf136 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61751 0xf137 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61752 0xf138 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61753 0xf139 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61754 0xf13a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61755 0xf13b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61756 0xf13c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61757 0xf13d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61758 0xf13e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61759 0xf13f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61760 0xf140 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61761 0xf141 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61762 0xf142 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61763 0xf143 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61764 0xf144 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61765 0xf145 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61766 0xf146 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61767 0xf147 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61768 0xf148 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61769 0xf149 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61770 0xf14a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61771 0xf14b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61772 0xf14c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61773 0xf14d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61774 0xf14e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61775 0xf14f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61776 0xf150 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61777 0xf151 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61778 0xf152 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61779 0xf153 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61780 0xf154 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61781 0xf155 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61782 0xf156 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61783 0xf157 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61784 0xf158 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61785 0xf159 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61786 0xf15a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61787 0xf15b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61788 0xf15c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61789 0xf15d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61790 0xf15e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61791 0xf15f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61792 0xf160 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61793 0xf161 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61794 0xf162 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61795 0xf163 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61796 0xf164 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61797 0xf165 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61798 0xf166 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61799 0xf167 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61800 0xf168 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61801 0xf169 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61802 0xf16a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61803 0xf16b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61804 0xf16c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61805 0xf16d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61806 0xf16e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61807 0xf16f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61808 0xf170 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61809 0xf171 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61810 0xf172 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61811 0xf173 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61812 0xf174 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61813 0xf175 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61814 0xf176 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61815 0xf177 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61816 0xf178 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61817 0xf179 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61818 0xf17a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61819 0xf17b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61820 0xf17c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61821 0xf17d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61822 0xf17e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61823 0xf17f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61824 0xf180 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61825 0xf181 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61826 0xf182 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61827 0xf183 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61828 0xf184 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61829 0xf185 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61830 0xf186 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61831 0xf187 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61832 0xf188 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61833 0xf189 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61834 0xf18a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61835 0xf18b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61836 0xf18c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61837 0xf18d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61838 0xf18e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61839 0xf18f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61840 0xf190 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61841 0xf191 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61842 0xf192 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61843 0xf193 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61844 0xf194 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61845 0xf195 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61846 0xf196 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61847 0xf197 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61848 0xf198 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61849 0xf199 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61850 0xf19a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61851 0xf19b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61852 0xf19c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61853 0xf19d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61854 0xf19e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61855 0xf19f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61856 0xf1a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61857 0xf1a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61858 0xf1a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61859 0xf1a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61860 0xf1a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61861 0xf1a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61862 0xf1a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61863 0xf1a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61864 0xf1a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61865 0xf1a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61866 0xf1aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61867 0xf1ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61868 0xf1ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61869 0xf1ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61870 0xf1ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61871 0xf1af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61872 0xf1b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61873 0xf1b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61874 0xf1b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61875 0xf1b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61876 0xf1b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61877 0xf1b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61878 0xf1b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61879 0xf1b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61880 0xf1b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61881 0xf1b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61882 0xf1ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61883 0xf1bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61884 0xf1bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61885 0xf1bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61886 0xf1be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61887 0xf1bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61888 0xf1c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61889 0xf1c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61890 0xf1c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61891 0xf1c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61892 0xf1c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61893 0xf1c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61894 0xf1c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61895 0xf1c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61896 0xf1c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61897 0xf1c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61898 0xf1ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61899 0xf1cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61900 0xf1cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61901 0xf1cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61902 0xf1ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61903 0xf1cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61904 0xf1d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61905 0xf1d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61906 0xf1d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61907 0xf1d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61908 0xf1d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61909 0xf1d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61910 0xf1d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61911 0xf1d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61912 0xf1d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61913 0xf1d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61914 0xf1da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61915 0xf1db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61916 0xf1dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61917 0xf1dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61918 0xf1de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61919 0xf1df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61920 0xf1e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61921 0xf1e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61922 0xf1e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61923 0xf1e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61924 0xf1e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61925 0xf1e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61926 0xf1e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61927 0xf1e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61928 0xf1e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61929 0xf1e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61930 0xf1ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61931 0xf1eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61932 0xf1ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61933 0xf1ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61934 0xf1ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61935 0xf1ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61936 0xf1f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61937 0xf1f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61938 0xf1f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61939 0xf1f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61940 0xf1f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61941 0xf1f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61942 0xf1f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61943 0xf1f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61944 0xf1f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61945 0xf1f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61946 0xf1fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61947 0xf1fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61948 0xf1fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61949 0xf1fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61950 0xf1fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61951 0xf1ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61952 0xf200 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61953 0xf201 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61954 0xf202 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61955 0xf203 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61956 0xf204 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61957 0xf205 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61958 0xf206 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61959 0xf207 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61960 0xf208 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61961 0xf209 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61962 0xf20a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61963 0xf20b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61964 0xf20c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61965 0xf20d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61966 0xf20e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61967 0xf20f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61968 0xf210 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61969 0xf211 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61970 0xf212 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61971 0xf213 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61972 0xf214 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61973 0xf215 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61974 0xf216 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61975 0xf217 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61976 0xf218 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61977 0xf219 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61978 0xf21a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61979 0xf21b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61980 0xf21c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61981 0xf21d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61982 0xf21e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61983 0xf21f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61984 0xf220 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61985 0xf221 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61986 0xf222 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61987 0xf223 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61988 0xf224 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61989 0xf225 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61990 0xf226 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61991 0xf227 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61992 0xf228 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61993 0xf229 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61994 0xf22a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61995 0xf22b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61996 0xf22c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61997 0xf22d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61998 0xf22e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 61999 0xf22f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62000 0xf230 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62001 0xf231 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62002 0xf232 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62003 0xf233 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62004 0xf234 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62005 0xf235 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62006 0xf236 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62007 0xf237 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62008 0xf238 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62009 0xf239 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62010 0xf23a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62011 0xf23b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62012 0xf23c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62013 0xf23d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62014 0xf23e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62015 0xf23f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62016 0xf240 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62017 0xf241 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62018 0xf242 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62019 0xf243 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62020 0xf244 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62021 0xf245 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62022 0xf246 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62023 0xf247 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62024 0xf248 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62025 0xf249 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62026 0xf24a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62027 0xf24b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62028 0xf24c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62029 0xf24d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62030 0xf24e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62031 0xf24f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62032 0xf250 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62033 0xf251 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62034 0xf252 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62035 0xf253 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62036 0xf254 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62037 0xf255 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62038 0xf256 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62039 0xf257 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62040 0xf258 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62041 0xf259 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62042 0xf25a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62043 0xf25b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62044 0xf25c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62045 0xf25d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62046 0xf25e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62047 0xf25f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62048 0xf260 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62049 0xf261 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62050 0xf262 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62051 0xf263 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62052 0xf264 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62053 0xf265 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62054 0xf266 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62055 0xf267 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62056 0xf268 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62057 0xf269 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62058 0xf26a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62059 0xf26b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62060 0xf26c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62061 0xf26d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62062 0xf26e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62063 0xf26f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62064 0xf270 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62065 0xf271 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62066 0xf272 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62067 0xf273 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62068 0xf274 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62069 0xf275 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62070 0xf276 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62071 0xf277 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62072 0xf278 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62073 0xf279 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62074 0xf27a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62075 0xf27b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62076 0xf27c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62077 0xf27d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62078 0xf27e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62079 0xf27f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62080 0xf280 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62081 0xf281 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62082 0xf282 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62083 0xf283 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62084 0xf284 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62085 0xf285 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62086 0xf286 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62087 0xf287 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62088 0xf288 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62089 0xf289 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62090 0xf28a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62091 0xf28b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62092 0xf28c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62093 0xf28d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62094 0xf28e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62095 0xf28f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62096 0xf290 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62097 0xf291 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62098 0xf292 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62099 0xf293 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62100 0xf294 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62101 0xf295 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62102 0xf296 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62103 0xf297 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62104 0xf298 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62105 0xf299 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62106 0xf29a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62107 0xf29b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62108 0xf29c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62109 0xf29d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62110 0xf29e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62111 0xf29f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62112 0xf2a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62113 0xf2a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62114 0xf2a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62115 0xf2a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62116 0xf2a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62117 0xf2a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62118 0xf2a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62119 0xf2a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62120 0xf2a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62121 0xf2a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62122 0xf2aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62123 0xf2ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62124 0xf2ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62125 0xf2ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62126 0xf2ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62127 0xf2af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62128 0xf2b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62129 0xf2b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62130 0xf2b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62131 0xf2b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62132 0xf2b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62133 0xf2b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62134 0xf2b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62135 0xf2b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62136 0xf2b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62137 0xf2b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62138 0xf2ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62139 0xf2bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62140 0xf2bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62141 0xf2bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62142 0xf2be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62143 0xf2bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62144 0xf2c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62145 0xf2c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62146 0xf2c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62147 0xf2c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62148 0xf2c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62149 0xf2c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62150 0xf2c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62151 0xf2c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62152 0xf2c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62153 0xf2c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62154 0xf2ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62155 0xf2cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62156 0xf2cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62157 0xf2cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62158 0xf2ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62159 0xf2cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62160 0xf2d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62161 0xf2d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62162 0xf2d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62163 0xf2d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62164 0xf2d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62165 0xf2d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62166 0xf2d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62167 0xf2d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62168 0xf2d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62169 0xf2d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62170 0xf2da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62171 0xf2db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62172 0xf2dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62173 0xf2dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62174 0xf2de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62175 0xf2df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62176 0xf2e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62177 0xf2e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62178 0xf2e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62179 0xf2e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62180 0xf2e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62181 0xf2e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62182 0xf2e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62183 0xf2e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62184 0xf2e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62185 0xf2e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62186 0xf2ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62187 0xf2eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62188 0xf2ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62189 0xf2ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62190 0xf2ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62191 0xf2ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62192 0xf2f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62193 0xf2f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62194 0xf2f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62195 0xf2f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62196 0xf2f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62197 0xf2f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62198 0xf2f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62199 0xf2f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62200 0xf2f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62201 0xf2f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62202 0xf2fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62203 0xf2fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62204 0xf2fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62205 0xf2fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62206 0xf2fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62207 0xf2ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62208 0xf300 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62209 0xf301 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62210 0xf302 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62211 0xf303 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62212 0xf304 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62213 0xf305 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62214 0xf306 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62215 0xf307 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62216 0xf308 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62217 0xf309 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62218 0xf30a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62219 0xf30b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62220 0xf30c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62221 0xf30d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62222 0xf30e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62223 0xf30f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62224 0xf310 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62225 0xf311 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62226 0xf312 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62227 0xf313 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62228 0xf314 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62229 0xf315 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62230 0xf316 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62231 0xf317 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62232 0xf318 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62233 0xf319 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62234 0xf31a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62235 0xf31b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62236 0xf31c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62237 0xf31d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62238 0xf31e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62239 0xf31f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62240 0xf320 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62241 0xf321 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62242 0xf322 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62243 0xf323 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62244 0xf324 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62245 0xf325 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62246 0xf326 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62247 0xf327 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62248 0xf328 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62249 0xf329 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62250 0xf32a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62251 0xf32b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62252 0xf32c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62253 0xf32d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62254 0xf32e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62255 0xf32f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62256 0xf330 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62257 0xf331 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62258 0xf332 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62259 0xf333 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62260 0xf334 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62261 0xf335 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62262 0xf336 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62263 0xf337 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62264 0xf338 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62265 0xf339 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62266 0xf33a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62267 0xf33b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62268 0xf33c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62269 0xf33d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62270 0xf33e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62271 0xf33f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62272 0xf340 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62273 0xf341 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62274 0xf342 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62275 0xf343 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62276 0xf344 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62277 0xf345 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62278 0xf346 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62279 0xf347 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62280 0xf348 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62281 0xf349 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62282 0xf34a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62283 0xf34b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62284 0xf34c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62285 0xf34d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62286 0xf34e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62287 0xf34f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62288 0xf350 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62289 0xf351 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62290 0xf352 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62291 0xf353 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62292 0xf354 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62293 0xf355 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62294 0xf356 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62295 0xf357 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62296 0xf358 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62297 0xf359 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62298 0xf35a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62299 0xf35b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62300 0xf35c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62301 0xf35d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62302 0xf35e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62303 0xf35f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62304 0xf360 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62305 0xf361 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62306 0xf362 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62307 0xf363 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62308 0xf364 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62309 0xf365 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62310 0xf366 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62311 0xf367 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62312 0xf368 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62313 0xf369 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62314 0xf36a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62315 0xf36b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62316 0xf36c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62317 0xf36d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62318 0xf36e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62319 0xf36f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62320 0xf370 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62321 0xf371 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62322 0xf372 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62323 0xf373 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62324 0xf374 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62325 0xf375 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62326 0xf376 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62327 0xf377 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62328 0xf378 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62329 0xf379 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62330 0xf37a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62331 0xf37b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62332 0xf37c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62333 0xf37d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62334 0xf37e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62335 0xf37f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62336 0xf380 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62337 0xf381 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62338 0xf382 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62339 0xf383 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62340 0xf384 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62341 0xf385 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62342 0xf386 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62343 0xf387 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62344 0xf388 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62345 0xf389 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62346 0xf38a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62347 0xf38b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62348 0xf38c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62349 0xf38d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62350 0xf38e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62351 0xf38f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62352 0xf390 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62353 0xf391 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62354 0xf392 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62355 0xf393 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62356 0xf394 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62357 0xf395 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62358 0xf396 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62359 0xf397 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62360 0xf398 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62361 0xf399 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62362 0xf39a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62363 0xf39b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62364 0xf39c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62365 0xf39d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62366 0xf39e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62367 0xf39f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62368 0xf3a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62369 0xf3a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62370 0xf3a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62371 0xf3a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62372 0xf3a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62373 0xf3a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62374 0xf3a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62375 0xf3a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62376 0xf3a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62377 0xf3a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62378 0xf3aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62379 0xf3ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62380 0xf3ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62381 0xf3ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62382 0xf3ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62383 0xf3af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62384 0xf3b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62385 0xf3b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62386 0xf3b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62387 0xf3b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62388 0xf3b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62389 0xf3b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62390 0xf3b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62391 0xf3b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62392 0xf3b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62393 0xf3b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62394 0xf3ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62395 0xf3bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62396 0xf3bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62397 0xf3bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62398 0xf3be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62399 0xf3bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62400 0xf3c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62401 0xf3c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62402 0xf3c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62403 0xf3c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62404 0xf3c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62405 0xf3c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62406 0xf3c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62407 0xf3c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62408 0xf3c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62409 0xf3c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62410 0xf3ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62411 0xf3cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62412 0xf3cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62413 0xf3cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62414 0xf3ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62415 0xf3cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62416 0xf3d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62417 0xf3d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62418 0xf3d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62419 0xf3d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62420 0xf3d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62421 0xf3d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62422 0xf3d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62423 0xf3d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62424 0xf3d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62425 0xf3d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62426 0xf3da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62427 0xf3db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62428 0xf3dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62429 0xf3dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62430 0xf3de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62431 0xf3df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62432 0xf3e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62433 0xf3e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62434 0xf3e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62435 0xf3e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62436 0xf3e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62437 0xf3e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62438 0xf3e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62439 0xf3e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62440 0xf3e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62441 0xf3e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62442 0xf3ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62443 0xf3eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62444 0xf3ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62445 0xf3ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62446 0xf3ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62447 0xf3ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62448 0xf3f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62449 0xf3f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62450 0xf3f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62451 0xf3f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62452 0xf3f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62453 0xf3f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62454 0xf3f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62455 0xf3f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62456 0xf3f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62457 0xf3f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62458 0xf3fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62459 0xf3fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62460 0xf3fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62461 0xf3fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62462 0xf3fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62463 0xf3ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62464 0xf400 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62465 0xf401 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62466 0xf402 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62467 0xf403 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62468 0xf404 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62469 0xf405 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62470 0xf406 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62471 0xf407 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62472 0xf408 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62473 0xf409 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62474 0xf40a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62475 0xf40b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62476 0xf40c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62477 0xf40d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62478 0xf40e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62479 0xf40f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62480 0xf410 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62481 0xf411 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62482 0xf412 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62483 0xf413 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62484 0xf414 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62485 0xf415 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62486 0xf416 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62487 0xf417 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62488 0xf418 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62489 0xf419 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62490 0xf41a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62491 0xf41b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62492 0xf41c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62493 0xf41d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62494 0xf41e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62495 0xf41f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62496 0xf420 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62497 0xf421 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62498 0xf422 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62499 0xf423 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62500 0xf424 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62501 0xf425 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62502 0xf426 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62503 0xf427 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62504 0xf428 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62505 0xf429 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62506 0xf42a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62507 0xf42b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62508 0xf42c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62509 0xf42d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62510 0xf42e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62511 0xf42f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62512 0xf430 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62513 0xf431 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62514 0xf432 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62515 0xf433 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62516 0xf434 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62517 0xf435 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62518 0xf436 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62519 0xf437 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62520 0xf438 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62521 0xf439 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62522 0xf43a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62523 0xf43b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62524 0xf43c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62525 0xf43d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62526 0xf43e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62527 0xf43f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62528 0xf440 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62529 0xf441 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62530 0xf442 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62531 0xf443 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62532 0xf444 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62533 0xf445 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62534 0xf446 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62535 0xf447 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62536 0xf448 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62537 0xf449 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62538 0xf44a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62539 0xf44b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62540 0xf44c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62541 0xf44d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62542 0xf44e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62543 0xf44f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62544 0xf450 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62545 0xf451 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62546 0xf452 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62547 0xf453 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62548 0xf454 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62549 0xf455 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62550 0xf456 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62551 0xf457 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62552 0xf458 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62553 0xf459 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62554 0xf45a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62555 0xf45b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62556 0xf45c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62557 0xf45d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62558 0xf45e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62559 0xf45f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62560 0xf460 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62561 0xf461 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62562 0xf462 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62563 0xf463 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62564 0xf464 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62565 0xf465 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62566 0xf466 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62567 0xf467 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62568 0xf468 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62569 0xf469 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62570 0xf46a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62571 0xf46b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62572 0xf46c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62573 0xf46d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62574 0xf46e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62575 0xf46f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62576 0xf470 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62577 0xf471 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62578 0xf472 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62579 0xf473 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62580 0xf474 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62581 0xf475 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62582 0xf476 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62583 0xf477 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62584 0xf478 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62585 0xf479 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62586 0xf47a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62587 0xf47b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62588 0xf47c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62589 0xf47d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62590 0xf47e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62591 0xf47f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62592 0xf480 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62593 0xf481 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62594 0xf482 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62595 0xf483 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62596 0xf484 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62597 0xf485 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62598 0xf486 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62599 0xf487 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62600 0xf488 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62601 0xf489 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62602 0xf48a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62603 0xf48b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62604 0xf48c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62605 0xf48d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62606 0xf48e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62607 0xf48f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62608 0xf490 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62609 0xf491 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62610 0xf492 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62611 0xf493 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62612 0xf494 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62613 0xf495 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62614 0xf496 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62615 0xf497 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62616 0xf498 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62617 0xf499 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62618 0xf49a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62619 0xf49b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62620 0xf49c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62621 0xf49d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62622 0xf49e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62623 0xf49f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62624 0xf4a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62625 0xf4a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62626 0xf4a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62627 0xf4a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62628 0xf4a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62629 0xf4a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62630 0xf4a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62631 0xf4a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62632 0xf4a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62633 0xf4a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62634 0xf4aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62635 0xf4ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62636 0xf4ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62637 0xf4ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62638 0xf4ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62639 0xf4af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62640 0xf4b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62641 0xf4b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62642 0xf4b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62643 0xf4b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62644 0xf4b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62645 0xf4b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62646 0xf4b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62647 0xf4b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62648 0xf4b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62649 0xf4b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62650 0xf4ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62651 0xf4bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62652 0xf4bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62653 0xf4bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62654 0xf4be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62655 0xf4bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62656 0xf4c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62657 0xf4c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62658 0xf4c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62659 0xf4c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62660 0xf4c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62661 0xf4c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62662 0xf4c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62663 0xf4c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62664 0xf4c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62665 0xf4c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62666 0xf4ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62667 0xf4cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62668 0xf4cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62669 0xf4cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62670 0xf4ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62671 0xf4cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62672 0xf4d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62673 0xf4d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62674 0xf4d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62675 0xf4d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62676 0xf4d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62677 0xf4d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62678 0xf4d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62679 0xf4d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62680 0xf4d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62681 0xf4d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62682 0xf4da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62683 0xf4db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62684 0xf4dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62685 0xf4dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62686 0xf4de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62687 0xf4df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62688 0xf4e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62689 0xf4e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62690 0xf4e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62691 0xf4e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62692 0xf4e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62693 0xf4e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62694 0xf4e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62695 0xf4e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62696 0xf4e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62697 0xf4e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62698 0xf4ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62699 0xf4eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62700 0xf4ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62701 0xf4ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62702 0xf4ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62703 0xf4ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62704 0xf4f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62705 0xf4f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62706 0xf4f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62707 0xf4f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62708 0xf4f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62709 0xf4f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62710 0xf4f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62711 0xf4f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62712 0xf4f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62713 0xf4f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62714 0xf4fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62715 0xf4fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62716 0xf4fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62717 0xf4fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62718 0xf4fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62719 0xf4ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62720 0xf500 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62721 0xf501 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62722 0xf502 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62723 0xf503 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62724 0xf504 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62725 0xf505 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62726 0xf506 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62727 0xf507 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62728 0xf508 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62729 0xf509 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62730 0xf50a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62731 0xf50b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62732 0xf50c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62733 0xf50d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62734 0xf50e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62735 0xf50f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62736 0xf510 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62737 0xf511 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62738 0xf512 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62739 0xf513 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62740 0xf514 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62741 0xf515 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62742 0xf516 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62743 0xf517 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62744 0xf518 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62745 0xf519 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62746 0xf51a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62747 0xf51b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62748 0xf51c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62749 0xf51d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62750 0xf51e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62751 0xf51f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62752 0xf520 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62753 0xf521 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62754 0xf522 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62755 0xf523 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62756 0xf524 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62757 0xf525 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62758 0xf526 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62759 0xf527 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62760 0xf528 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62761 0xf529 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62762 0xf52a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62763 0xf52b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62764 0xf52c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62765 0xf52d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62766 0xf52e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62767 0xf52f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62768 0xf530 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62769 0xf531 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62770 0xf532 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62771 0xf533 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62772 0xf534 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62773 0xf535 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62774 0xf536 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62775 0xf537 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62776 0xf538 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62777 0xf539 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62778 0xf53a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62779 0xf53b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62780 0xf53c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62781 0xf53d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62782 0xf53e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62783 0xf53f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62784 0xf540 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62785 0xf541 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62786 0xf542 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62787 0xf543 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62788 0xf544 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62789 0xf545 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62790 0xf546 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62791 0xf547 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62792 0xf548 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62793 0xf549 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62794 0xf54a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62795 0xf54b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62796 0xf54c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62797 0xf54d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62798 0xf54e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62799 0xf54f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62800 0xf550 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62801 0xf551 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62802 0xf552 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62803 0xf553 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62804 0xf554 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62805 0xf555 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62806 0xf556 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62807 0xf557 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62808 0xf558 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62809 0xf559 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62810 0xf55a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62811 0xf55b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62812 0xf55c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62813 0xf55d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62814 0xf55e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62815 0xf55f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62816 0xf560 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62817 0xf561 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62818 0xf562 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62819 0xf563 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62820 0xf564 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62821 0xf565 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62822 0xf566 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62823 0xf567 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62824 0xf568 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62825 0xf569 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62826 0xf56a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62827 0xf56b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62828 0xf56c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62829 0xf56d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62830 0xf56e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62831 0xf56f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62832 0xf570 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62833 0xf571 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62834 0xf572 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62835 0xf573 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62836 0xf574 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62837 0xf575 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62838 0xf576 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62839 0xf577 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62840 0xf578 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62841 0xf579 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62842 0xf57a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62843 0xf57b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62844 0xf57c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62845 0xf57d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62846 0xf57e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62847 0xf57f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62848 0xf580 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62849 0xf581 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62850 0xf582 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62851 0xf583 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62852 0xf584 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62853 0xf585 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62854 0xf586 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62855 0xf587 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62856 0xf588 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62857 0xf589 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62858 0xf58a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62859 0xf58b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62860 0xf58c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62861 0xf58d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62862 0xf58e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62863 0xf58f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62864 0xf590 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62865 0xf591 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62866 0xf592 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62867 0xf593 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62868 0xf594 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62869 0xf595 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62870 0xf596 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62871 0xf597 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62872 0xf598 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62873 0xf599 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62874 0xf59a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62875 0xf59b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62876 0xf59c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62877 0xf59d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62878 0xf59e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62879 0xf59f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62880 0xf5a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62881 0xf5a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62882 0xf5a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62883 0xf5a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62884 0xf5a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62885 0xf5a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62886 0xf5a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62887 0xf5a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62888 0xf5a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62889 0xf5a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62890 0xf5aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62891 0xf5ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62892 0xf5ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62893 0xf5ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62894 0xf5ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62895 0xf5af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62896 0xf5b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62897 0xf5b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62898 0xf5b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62899 0xf5b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62900 0xf5b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62901 0xf5b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62902 0xf5b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62903 0xf5b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62904 0xf5b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62905 0xf5b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62906 0xf5ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62907 0xf5bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62908 0xf5bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62909 0xf5bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62910 0xf5be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62911 0xf5bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62912 0xf5c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62913 0xf5c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62914 0xf5c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62915 0xf5c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62916 0xf5c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62917 0xf5c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62918 0xf5c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62919 0xf5c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62920 0xf5c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62921 0xf5c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62922 0xf5ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62923 0xf5cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62924 0xf5cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62925 0xf5cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62926 0xf5ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62927 0xf5cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62928 0xf5d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62929 0xf5d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62930 0xf5d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62931 0xf5d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62932 0xf5d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62933 0xf5d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62934 0xf5d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62935 0xf5d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62936 0xf5d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62937 0xf5d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62938 0xf5da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62939 0xf5db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62940 0xf5dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62941 0xf5dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62942 0xf5de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62943 0xf5df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62944 0xf5e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62945 0xf5e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62946 0xf5e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62947 0xf5e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62948 0xf5e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62949 0xf5e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62950 0xf5e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62951 0xf5e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62952 0xf5e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62953 0xf5e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62954 0xf5ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62955 0xf5eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62956 0xf5ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62957 0xf5ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62958 0xf5ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62959 0xf5ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62960 0xf5f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62961 0xf5f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62962 0xf5f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62963 0xf5f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62964 0xf5f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62965 0xf5f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62966 0xf5f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62967 0xf5f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62968 0xf5f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62969 0xf5f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62970 0xf5fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62971 0xf5fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62972 0xf5fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62973 0xf5fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62974 0xf5fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62975 0xf5ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62976 0xf600 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62977 0xf601 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62978 0xf602 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62979 0xf603 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62980 0xf604 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62981 0xf605 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62982 0xf606 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62983 0xf607 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62984 0xf608 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62985 0xf609 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62986 0xf60a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62987 0xf60b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62988 0xf60c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62989 0xf60d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62990 0xf60e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62991 0xf60f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62992 0xf610 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62993 0xf611 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62994 0xf612 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62995 0xf613 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62996 0xf614 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62997 0xf615 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62998 0xf616 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 62999 0xf617 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63000 0xf618 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63001 0xf619 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63002 0xf61a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63003 0xf61b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63004 0xf61c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63005 0xf61d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63006 0xf61e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63007 0xf61f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63008 0xf620 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63009 0xf621 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63010 0xf622 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63011 0xf623 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63012 0xf624 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63013 0xf625 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63014 0xf626 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63015 0xf627 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63016 0xf628 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63017 0xf629 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63018 0xf62a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63019 0xf62b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63020 0xf62c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63021 0xf62d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63022 0xf62e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63023 0xf62f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63024 0xf630 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63025 0xf631 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63026 0xf632 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63027 0xf633 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63028 0xf634 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63029 0xf635 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63030 0xf636 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63031 0xf637 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63032 0xf638 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63033 0xf639 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63034 0xf63a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63035 0xf63b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63036 0xf63c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63037 0xf63d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63038 0xf63e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63039 0xf63f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63040 0xf640 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63041 0xf641 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63042 0xf642 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63043 0xf643 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63044 0xf644 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63045 0xf645 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63046 0xf646 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63047 0xf647 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63048 0xf648 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63049 0xf649 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63050 0xf64a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63051 0xf64b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63052 0xf64c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63053 0xf64d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63054 0xf64e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63055 0xf64f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63056 0xf650 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63057 0xf651 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63058 0xf652 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63059 0xf653 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63060 0xf654 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63061 0xf655 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63062 0xf656 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63063 0xf657 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63064 0xf658 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63065 0xf659 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63066 0xf65a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63067 0xf65b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63068 0xf65c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63069 0xf65d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63070 0xf65e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63071 0xf65f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63072 0xf660 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63073 0xf661 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63074 0xf662 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63075 0xf663 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63076 0xf664 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63077 0xf665 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63078 0xf666 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63079 0xf667 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63080 0xf668 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63081 0xf669 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63082 0xf66a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63083 0xf66b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63084 0xf66c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63085 0xf66d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63086 0xf66e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63087 0xf66f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63088 0xf670 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63089 0xf671 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63090 0xf672 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63091 0xf673 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63092 0xf674 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63093 0xf675 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63094 0xf676 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63095 0xf677 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63096 0xf678 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63097 0xf679 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63098 0xf67a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63099 0xf67b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63100 0xf67c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63101 0xf67d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63102 0xf67e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63103 0xf67f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63104 0xf680 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63105 0xf681 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63106 0xf682 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63107 0xf683 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63108 0xf684 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63109 0xf685 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63110 0xf686 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63111 0xf687 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63112 0xf688 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63113 0xf689 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63114 0xf68a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63115 0xf68b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63116 0xf68c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63117 0xf68d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63118 0xf68e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63119 0xf68f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63120 0xf690 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63121 0xf691 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63122 0xf692 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63123 0xf693 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63124 0xf694 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63125 0xf695 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63126 0xf696 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63127 0xf697 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63128 0xf698 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63129 0xf699 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63130 0xf69a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63131 0xf69b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63132 0xf69c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63133 0xf69d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63134 0xf69e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63135 0xf69f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63136 0xf6a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63137 0xf6a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63138 0xf6a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63139 0xf6a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63140 0xf6a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63141 0xf6a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63142 0xf6a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63143 0xf6a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63144 0xf6a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63145 0xf6a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63146 0xf6aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63147 0xf6ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63148 0xf6ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63149 0xf6ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63150 0xf6ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63151 0xf6af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63152 0xf6b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63153 0xf6b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63154 0xf6b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63155 0xf6b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63156 0xf6b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63157 0xf6b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63158 0xf6b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63159 0xf6b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63160 0xf6b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63161 0xf6b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63162 0xf6ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63163 0xf6bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63164 0xf6bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63165 0xf6bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63166 0xf6be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63167 0xf6bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63168 0xf6c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63169 0xf6c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63170 0xf6c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63171 0xf6c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63172 0xf6c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63173 0xf6c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63174 0xf6c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63175 0xf6c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63176 0xf6c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63177 0xf6c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63178 0xf6ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63179 0xf6cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63180 0xf6cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63181 0xf6cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63182 0xf6ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63183 0xf6cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63184 0xf6d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63185 0xf6d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63186 0xf6d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63187 0xf6d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63188 0xf6d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63189 0xf6d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63190 0xf6d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63191 0xf6d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63192 0xf6d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63193 0xf6d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63194 0xf6da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63195 0xf6db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63196 0xf6dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63197 0xf6dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63198 0xf6de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63199 0xf6df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63200 0xf6e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63201 0xf6e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63202 0xf6e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63203 0xf6e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63204 0xf6e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63205 0xf6e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63206 0xf6e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63207 0xf6e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63208 0xf6e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63209 0xf6e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63210 0xf6ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63211 0xf6eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63212 0xf6ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63213 0xf6ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63214 0xf6ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63215 0xf6ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63216 0xf6f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63217 0xf6f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63218 0xf6f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63219 0xf6f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63220 0xf6f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63221 0xf6f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63222 0xf6f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63223 0xf6f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63224 0xf6f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63225 0xf6f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63226 0xf6fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63227 0xf6fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63228 0xf6fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63229 0xf6fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63230 0xf6fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63231 0xf6ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63232 0xf700 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63233 0xf701 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63234 0xf702 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63235 0xf703 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63236 0xf704 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63237 0xf705 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63238 0xf706 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63239 0xf707 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63240 0xf708 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63241 0xf709 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63242 0xf70a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63243 0xf70b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63244 0xf70c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63245 0xf70d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63246 0xf70e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63247 0xf70f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63248 0xf710 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63249 0xf711 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63250 0xf712 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63251 0xf713 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63252 0xf714 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63253 0xf715 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63254 0xf716 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63255 0xf717 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63256 0xf718 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63257 0xf719 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63258 0xf71a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63259 0xf71b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63260 0xf71c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63261 0xf71d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63262 0xf71e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63263 0xf71f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63264 0xf720 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63265 0xf721 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63266 0xf722 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63267 0xf723 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63268 0xf724 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63269 0xf725 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63270 0xf726 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63271 0xf727 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63272 0xf728 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63273 0xf729 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63274 0xf72a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63275 0xf72b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63276 0xf72c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63277 0xf72d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63278 0xf72e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63279 0xf72f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63280 0xf730 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63281 0xf731 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63282 0xf732 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63283 0xf733 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63284 0xf734 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63285 0xf735 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63286 0xf736 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63287 0xf737 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63288 0xf738 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63289 0xf739 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63290 0xf73a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63291 0xf73b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63292 0xf73c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63293 0xf73d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63294 0xf73e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63295 0xf73f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63296 0xf740 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63297 0xf741 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63298 0xf742 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63299 0xf743 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63300 0xf744 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63301 0xf745 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63302 0xf746 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63303 0xf747 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63304 0xf748 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63305 0xf749 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63306 0xf74a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63307 0xf74b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63308 0xf74c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63309 0xf74d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63310 0xf74e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63311 0xf74f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63312 0xf750 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63313 0xf751 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63314 0xf752 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63315 0xf753 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63316 0xf754 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63317 0xf755 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63318 0xf756 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63319 0xf757 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63320 0xf758 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63321 0xf759 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63322 0xf75a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63323 0xf75b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63324 0xf75c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63325 0xf75d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63326 0xf75e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63327 0xf75f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63328 0xf760 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63329 0xf761 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63330 0xf762 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63331 0xf763 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63332 0xf764 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63333 0xf765 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63334 0xf766 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63335 0xf767 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63336 0xf768 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63337 0xf769 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63338 0xf76a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63339 0xf76b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63340 0xf76c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63341 0xf76d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63342 0xf76e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63343 0xf76f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63344 0xf770 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63345 0xf771 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63346 0xf772 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63347 0xf773 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63348 0xf774 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63349 0xf775 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63350 0xf776 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63351 0xf777 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63352 0xf778 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63353 0xf779 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63354 0xf77a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63355 0xf77b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63356 0xf77c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63357 0xf77d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63358 0xf77e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63359 0xf77f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63360 0xf780 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63361 0xf781 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63362 0xf782 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63363 0xf783 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63364 0xf784 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63365 0xf785 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63366 0xf786 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63367 0xf787 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63368 0xf788 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63369 0xf789 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63370 0xf78a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63371 0xf78b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63372 0xf78c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63373 0xf78d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63374 0xf78e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63375 0xf78f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63376 0xf790 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63377 0xf791 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63378 0xf792 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63379 0xf793 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63380 0xf794 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63381 0xf795 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63382 0xf796 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63383 0xf797 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63384 0xf798 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63385 0xf799 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63386 0xf79a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63387 0xf79b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63388 0xf79c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63389 0xf79d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63390 0xf79e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63391 0xf79f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63392 0xf7a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63393 0xf7a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63394 0xf7a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63395 0xf7a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63396 0xf7a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63397 0xf7a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63398 0xf7a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63399 0xf7a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63400 0xf7a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63401 0xf7a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63402 0xf7aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63403 0xf7ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63404 0xf7ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63405 0xf7ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63406 0xf7ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63407 0xf7af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63408 0xf7b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63409 0xf7b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63410 0xf7b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63411 0xf7b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63412 0xf7b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63413 0xf7b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63414 0xf7b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63415 0xf7b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63416 0xf7b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63417 0xf7b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63418 0xf7ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63419 0xf7bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63420 0xf7bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63421 0xf7bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63422 0xf7be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63423 0xf7bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63424 0xf7c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63425 0xf7c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63426 0xf7c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63427 0xf7c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63428 0xf7c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63429 0xf7c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63430 0xf7c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63431 0xf7c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63432 0xf7c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63433 0xf7c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63434 0xf7ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63435 0xf7cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63436 0xf7cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63437 0xf7cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63438 0xf7ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63439 0xf7cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63440 0xf7d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63441 0xf7d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63442 0xf7d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63443 0xf7d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63444 0xf7d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63445 0xf7d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63446 0xf7d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63447 0xf7d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63448 0xf7d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63449 0xf7d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63450 0xf7da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63451 0xf7db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63452 0xf7dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63453 0xf7dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63454 0xf7de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63455 0xf7df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63456 0xf7e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63457 0xf7e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63458 0xf7e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63459 0xf7e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63460 0xf7e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63461 0xf7e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63462 0xf7e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63463 0xf7e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63464 0xf7e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63465 0xf7e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63466 0xf7ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63467 0xf7eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63468 0xf7ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63469 0xf7ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63470 0xf7ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63471 0xf7ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63472 0xf7f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63473 0xf7f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63474 0xf7f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63475 0xf7f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63476 0xf7f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63477 0xf7f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63478 0xf7f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63479 0xf7f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63480 0xf7f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63481 0xf7f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63482 0xf7fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63483 0xf7fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63484 0xf7fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63485 0xf7fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63486 0xf7fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63487 0xf7ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63488 0xf800 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63489 0xf801 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63490 0xf802 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63491 0xf803 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63492 0xf804 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63493 0xf805 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63494 0xf806 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63495 0xf807 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63496 0xf808 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63497 0xf809 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63498 0xf80a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63499 0xf80b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63500 0xf80c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63501 0xf80d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63502 0xf80e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63503 0xf80f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63504 0xf810 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63505 0xf811 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63506 0xf812 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63507 0xf813 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63508 0xf814 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63509 0xf815 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63510 0xf816 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63511 0xf817 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63512 0xf818 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63513 0xf819 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63514 0xf81a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63515 0xf81b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63516 0xf81c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63517 0xf81d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63518 0xf81e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63519 0xf81f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63520 0xf820 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63521 0xf821 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63522 0xf822 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63523 0xf823 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63524 0xf824 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63525 0xf825 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63526 0xf826 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63527 0xf827 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63528 0xf828 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63529 0xf829 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63530 0xf82a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63531 0xf82b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63532 0xf82c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63533 0xf82d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63534 0xf82e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63535 0xf82f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63536 0xf830 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63537 0xf831 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63538 0xf832 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63539 0xf833 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63540 0xf834 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63541 0xf835 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63542 0xf836 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63543 0xf837 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63544 0xf838 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63545 0xf839 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63546 0xf83a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63547 0xf83b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63548 0xf83c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63549 0xf83d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63550 0xf83e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63551 0xf83f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63552 0xf840 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63553 0xf841 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63554 0xf842 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63555 0xf843 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63556 0xf844 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63557 0xf845 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63558 0xf846 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63559 0xf847 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63560 0xf848 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63561 0xf849 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63562 0xf84a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63563 0xf84b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63564 0xf84c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63565 0xf84d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63566 0xf84e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63567 0xf84f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63568 0xf850 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63569 0xf851 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63570 0xf852 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63571 0xf853 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63572 0xf854 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63573 0xf855 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63574 0xf856 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63575 0xf857 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63576 0xf858 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63577 0xf859 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63578 0xf85a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63579 0xf85b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63580 0xf85c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63581 0xf85d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63582 0xf85e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63583 0xf85f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63584 0xf860 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63585 0xf861 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63586 0xf862 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63587 0xf863 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63588 0xf864 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63589 0xf865 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63590 0xf866 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63591 0xf867 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63592 0xf868 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63593 0xf869 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63594 0xf86a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63595 0xf86b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63596 0xf86c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63597 0xf86d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63598 0xf86e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63599 0xf86f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63600 0xf870 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63601 0xf871 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63602 0xf872 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63603 0xf873 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63604 0xf874 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63605 0xf875 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63606 0xf876 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63607 0xf877 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63608 0xf878 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63609 0xf879 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63610 0xf87a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63611 0xf87b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63612 0xf87c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63613 0xf87d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63614 0xf87e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63615 0xf87f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63616 0xf880 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63617 0xf881 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63618 0xf882 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63619 0xf883 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63620 0xf884 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63621 0xf885 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63622 0xf886 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63623 0xf887 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63624 0xf888 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63625 0xf889 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63626 0xf88a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63627 0xf88b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63628 0xf88c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63629 0xf88d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63630 0xf88e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63631 0xf88f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63632 0xf890 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63633 0xf891 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63634 0xf892 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63635 0xf893 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63636 0xf894 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63637 0xf895 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63638 0xf896 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63639 0xf897 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63640 0xf898 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63641 0xf899 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63642 0xf89a */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63643 0xf89b */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63644 0xf89c */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63645 0xf89d */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63646 0xf89e */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63647 0xf89f */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63648 0xf8a0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63649 0xf8a1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63650 0xf8a2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63651 0xf8a3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63652 0xf8a4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63653 0xf8a5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63654 0xf8a6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63655 0xf8a7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63656 0xf8a8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63657 0xf8a9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63658 0xf8aa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63659 0xf8ab */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63660 0xf8ac */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63661 0xf8ad */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63662 0xf8ae */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63663 0xf8af */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63664 0xf8b0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63665 0xf8b1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63666 0xf8b2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63667 0xf8b3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63668 0xf8b4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63669 0xf8b5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63670 0xf8b6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63671 0xf8b7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63672 0xf8b8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63673 0xf8b9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63674 0xf8ba */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63675 0xf8bb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63676 0xf8bc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63677 0xf8bd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63678 0xf8be */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63679 0xf8bf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63680 0xf8c0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63681 0xf8c1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63682 0xf8c2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63683 0xf8c3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63684 0xf8c4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63685 0xf8c5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63686 0xf8c6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63687 0xf8c7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63688 0xf8c8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63689 0xf8c9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63690 0xf8ca */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63691 0xf8cb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63692 0xf8cc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63693 0xf8cd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63694 0xf8ce */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63695 0xf8cf */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63696 0xf8d0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63697 0xf8d1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63698 0xf8d2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63699 0xf8d3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63700 0xf8d4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63701 0xf8d5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63702 0xf8d6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63703 0xf8d7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63704 0xf8d8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63705 0xf8d9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63706 0xf8da */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63707 0xf8db */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63708 0xf8dc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63709 0xf8dd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63710 0xf8de */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63711 0xf8df */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63712 0xf8e0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63713 0xf8e1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63714 0xf8e2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63715 0xf8e3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63716 0xf8e4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63717 0xf8e5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63718 0xf8e6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63719 0xf8e7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63720 0xf8e8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63721 0xf8e9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63722 0xf8ea */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63723 0xf8eb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63724 0xf8ec */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63725 0xf8ed */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63726 0xf8ee */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63727 0xf8ef */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63728 0xf8f0 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63729 0xf8f1 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63730 0xf8f2 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63731 0xf8f3 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63732 0xf8f4 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63733 0xf8f5 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63734 0xf8f6 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63735 0xf8f7 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63736 0xf8f8 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63737 0xf8f9 */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63738 0xf8fa */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63739 0xf8fb */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63740 0xf8fc */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63741 0xf8fd */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63742 0xf8fe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63743 0xf8ff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 63744 0xf900 "豈" */
+0x00,0x10,0x10,0x1f,0x10,0x00,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x04,0x02,0x7f,0x00,
+0x80,0x88,0x88,0xf8,0x08,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0x20,0x44,0xfe,0x00,
+/* 63745 0xf901 "更" */
+0x00,0x7f,0x00,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x08,0x05,0x03,0x0c,0x70,0x00,
+0x04,0xfe,0x80,0x84,0xfe,0x84,0xfc,0x84,0xfc,0x84,0x80,0x00,0x00,0xc0,0x3e,0x00,
+/* 63746 0xf902 "車" */
+0x01,0x01,0x7f,0x01,0x11,0x1f,0x11,0x1f,0x11,0x1f,0x11,0x01,0x7f,0x01,0x01,0x00,
+0x00,0x04,0xfe,0x00,0x08,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x04,0xfe,0x00,0x00,0x00,
+/* 63747 0xf903 "賈" */
+0xff,0x04,0x3f,0x24,0x3f,0x00,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x0c,0xf0,0x00,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x60,0x1e,0x00,
+/* 63748 0xf904 "滑" */
+0x41,0x21,0x21,0x09,0x89,0x57,0x54,0x21,0x21,0xc1,0x41,0x41,0xc1,0xc1,0x41,0x00,
+0x08,0xfc,0x08,0x78,0x48,0xfe,0x04,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x38,0x10,0x00,
+/* 63749 0xf905 "串" */
+0x01,0x01,0x3f,0x21,0x21,0x3f,0x21,0x01,0x7f,0x41,0x41,0x7f,0x41,0x01,0x01,0x00,
+0x00,0x08,0xfc,0x08,0x08,0xf8,0x08,0x04,0xfe,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,
+/* 63750 0xf906 "句" */
+0x08,0x08,0x08,0x1f,0x20,0x40,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0xfe,0x04,0x04,0xc4,0x44,0x44,0x44,0xc4,0x44,0x44,0x38,0x10,0x00,
+/* 63751 0xf907 "龜" */
+0x08,0x0f,0x08,0x10,0x7f,0x11,0x7f,0x05,0x7f,0x05,0x7d,0x05,0x7f,0x05,0x7c,0x00,
+0x40,0xe0,0x40,0x80,0xfc,0x44,0x7c,0x44,0x6c,0x54,0x6c,0x44,0x7e,0x02,0xfc,0x00,
+/* 63752 0xf908 "龜" */
+0x08,0x0f,0x08,0x10,0x7f,0x11,0x7f,0x05,0x7f,0x05,0x7d,0x05,0x7f,0x05,0x7c,0x00,
+0x40,0xe0,0x40,0x80,0xfc,0x44,0x7c,0x44,0x6c,0x54,0x6c,0x44,0x7e,0x02,0xfc,0x00,
+/* 63753 0xf909 "契" */
+0x08,0x08,0x7f,0x08,0x7f,0x08,0x7f,0x08,0x09,0x01,0x7f,0x02,0x02,0x0c,0x70,0x00,
+0x00,0x02,0x7e,0x12,0x12,0x12,0x22,0x4e,0x84,0x00,0xfe,0x00,0xc0,0x30,0x0e,0x00,
+/* 63754 0xf90a "金" */
+0x00,0x01,0x02,0x04,0x08,0x10,0x6f,0x01,0x01,0x3f,0x01,0x11,0x09,0x09,0x7f,0x00,
+0x80,0x80,0x40,0x20,0x10,0x08,0xf6,0x00,0x08,0xfc,0x00,0x18,0x10,0x24,0xfe,0x00,
+/* 63755 0xf90b "喇" */
+0x01,0x91,0xff,0x91,0x91,0x97,0x95,0x95,0x97,0x95,0xf3,0x95,0x09,0x11,0x01,0x00,
+0x02,0x42,0xe2,0x12,0x12,0xd2,0x52,0x52,0xd2,0x52,0x92,0x42,0x22,0x1e,0x04,0x00,
+/* 63756 0xf90c "奈" */
+0x02,0x02,0x7f,0x02,0x04,0x18,0x67,0x00,0x00,0x3f,0x00,0x18,0x10,0x23,0x41,0x00,
+0x00,0x04,0xfe,0x40,0x20,0x18,0xe6,0x00,0x08,0xfc,0x80,0x90,0x8c,0x84,0x04,0x00,
+/* 63757 0xf90d "懶" */
+0x22,0x22,0x2f,0x22,0xb2,0xaf,0xaa,0xaa,0x2f,0x22,0x23,0x26,0x2a,0x22,0x22,0x20,
+0x14,0x1e,0xd4,0x24,0x7e,0xa2,0xbe,0xa2,0xbe,0x22,0x3e,0xa2,0x94,0x22,0x42,0x00,
+/* 63758 0xf90e "癩" */
+0x01,0x10,0x1f,0x92,0x5f,0x52,0x1f,0x12,0x32,0xdf,0x92,0x23,0x26,0x4a,0x92,0x00,
+0x00,0x84,0xfe,0x20,0xbc,0x48,0xbe,0xa2,0xbe,0xa2,0x3e,0x22,0xbe,0x94,0x22,0x00,
+/* 63759 0xf90f "羅" */
+0x3f,0x22,0x22,0x3f,0x08,0x10,0x24,0x79,0x0a,0x14,0x7e,0x00,0x34,0x2a,0x4a,0x00,
+0xfc,0x44,0x44,0xfc,0x44,0x90,0xfe,0x90,0x90,0xfc,0x90,0xfc,0x90,0x90,0xfe,0x00,
+/* 63760 0xf910 "蘿" */
+0x04,0x7f,0x04,0x1f,0x12,0x1f,0x08,0x12,0x3d,0x0a,0x14,0x7e,0x28,0x54,0x54,0x00,
+0x20,0xfe,0x20,0xf8,0x48,0xf8,0xa0,0x90,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x00,
+/* 63761 0xf911 "螺" */
+0x11,0x11,0x11,0x55,0x7f,0x55,0x54,0x55,0x7c,0x55,0x10,0x14,0x1a,0xe3,0x42,0x00,
+0x04,0xfe,0x24,0xfc,0x24,0xfc,0x44,0xf8,0x24,0xfe,0x92,0x10,0x94,0x72,0x22,0x00,
+/* 63762 0xf912 "裸" */
+0x41,0x21,0x29,0xfd,0x09,0x11,0x25,0x28,0x73,0xac,0x24,0x20,0x21,0x22,0x20,0x00,
+0xfc,0x24,0x24,0xfc,0x24,0xfc,0x24,0x20,0xfe,0x20,0x70,0xa8,0x26,0x22,0x20,0x00,
+/* 63763 0xf913 "邏" */
+0x07,0x44,0x34,0x17,0x02,0x04,0x17,0xfa,0x17,0x10,0x15,0x1a,0x30,0xc8,0x87,0x00,
+0xfe,0x92,0x92,0xfe,0x48,0xfe,0x48,0xfe,0xc8,0x7e,0x48,0xfe,0x40,0x00,0xfe,0x00,
+/* 63764 0xf914 "樂" */
+0x21,0x21,0x47,0x54,0xe7,0x24,0x54,0xff,0x45,0x01,0xff,0x05,0x09,0x31,0xc1,0x00,
+0x08,0x08,0xd0,0x54,0xf8,0x48,0x54,0xfe,0x50,0x04,0xfe,0x20,0x10,0x0e,0x04,0x00,
+/* 63765 0xf915 "洛" */
+0x21,0x11,0x11,0x01,0x42,0x2c,0x28,0x11,0x16,0x61,0x21,0x21,0x61,0x61,0x21,0x00,
+0x00,0x08,0xfc,0x08,0x90,0x90,0x60,0x98,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 63766 0xf916 "烙" */
+0x10,0x10,0x10,0x10,0x55,0x59,0x52,0x50,0x93,0x10,0x18,0x24,0x24,0x40,0x80,0x00,
+0x80,0x88,0xfc,0x88,0x50,0x20,0x30,0xc8,0x06,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 63767 0xf917 "珞" */
+0x00,0x08,0xfc,0x11,0x12,0x10,0x10,0xfd,0x12,0x11,0x15,0x19,0xe1,0x41,0x01,0x00,
+0x80,0x88,0xfc,0x08,0x90,0x60,0x60,0x98,0x06,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 63768 0xf918 "落" */
+0x04,0x7f,0x04,0x24,0x11,0x15,0x45,0x2a,0x08,0x11,0x17,0x61,0x21,0x21,0x61,0x00,
+0x40,0xfe,0x40,0x40,0xf8,0x08,0x90,0x60,0x90,0x08,0xfe,0x08,0x08,0xf8,0x08,0x00,
+/* 63769 0xf919 "酪" */
+0x04,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xce,0x82,0xfe,0x82,0x82,0xfe,0x82,0x00,
+0x20,0x24,0x3e,0x24,0x44,0xa8,0x10,0x28,0x44,0xfe,0x44,0x44,0x44,0x7c,0x44,0x00,
+/* 63770 0xf91a "駱" */
+0x44,0x7e,0x48,0x48,0x7f,0x48,0x7e,0x48,0x7e,0x43,0x02,0x56,0xaa,0xaa,0x0c,0x00,
+0x40,0x48,0x7c,0x88,0x48,0x30,0x30,0x48,0x86,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 63771 0xf91b "亂" */
+0x07,0xf9,0x91,0x4a,0xff,0x14,0xff,0x92,0xbd,0x80,0xbe,0x94,0x8c,0x92,0xa3,0x00,
+0x20,0x20,0x20,0x20,0x20,0x20,0xa0,0xa0,0xa0,0xa0,0xa0,0xa2,0xa2,0xa2,0x9e,0x00,
+/* 63772 0xf91c "卵" */
+0x02,0x27,0x38,0x22,0x32,0x2a,0x2a,0x22,0x22,0x26,0x3a,0x22,0x04,0x08,0x70,0x00,
+0x00,0x44,0x7e,0x44,0x44,0x54,0x54,0x4c,0x44,0x44,0x44,0x5c,0x48,0x40,0x40,0x00,
+/* 63773 0xf91d "欄" */
+0x13,0x12,0x13,0xfe,0x13,0x12,0x3b,0x56,0x53,0x92,0x93,0x12,0x12,0x12,0x13,0x00,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0x22,0xfe,0xaa,0xfe,0x22,0x72,0xaa,0x26,0x00,
+/* 63774 0xf91e "爛" */
+0x13,0x12,0x13,0x12,0x57,0x5a,0x53,0x52,0x93,0x12,0x1b,0x26,0x22,0x43,0x82,0x00,
+0xde,0x52,0xde,0x52,0xde,0x22,0xfe,0x22,0xfe,0xaa,0xfe,0x22,0xb2,0x2e,0x24,0x00,
+/* 63775 0xf91f "蘭" */
+0x04,0x7f,0x04,0x7e,0x42,0x7e,0x42,0x7e,0x41,0x5f,0x4a,0x4f,0x41,0x45,0x59,0x00,
+0x20,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x04,0xf4,0xa4,0xe4,0x04,0x44,0x3c,0x00,
+/* 63776 0xf920 "鸞" */
+0x12,0x11,0x27,0x78,0x27,0x78,0x2b,0x52,0x0f,0x08,0x0f,0x08,0x0f,0x29,0x44,0x00,
+0x08,0x08,0xd0,0x3c,0x92,0x3e,0xa8,0x94,0xe0,0x20,0xf8,0x00,0xfe,0x22,0x94,0x00,
+/* 63777 0xf921 "嵐" */
+0x00,0x20,0x20,0x3f,0x00,0x3f,0x20,0x2f,0x21,0x2f,0x29,0x2f,0x41,0x41,0x9f,0x00,
+0x80,0x84,0x84,0xfc,0x00,0xf8,0x28,0xc8,0x08,0xe8,0x28,0xea,0x0a,0x26,0xd2,0x00,
+/* 63778 0xf922 "濫" */
+0x47,0x25,0x25,0x07,0x84,0x57,0x55,0x25,0x27,0xc0,0x47,0x44,0xc4,0xc4,0x4f,0x00,
+0xd0,0x10,0x14,0xde,0x50,0xd8,0x24,0x24,0xc0,0x00,0xfc,0xa4,0xa4,0xa4,0xfe,0x00,
+/* 63779 0xf923 "藍" */
+0x04,0x7f,0x04,0x3f,0x24,0x3f,0x21,0x3f,0x24,0x3f,0x00,0x1f,0x12,0x12,0x7f,0x00,
+0x20,0xfe,0x20,0x00,0x24,0x3e,0x40,0x90,0x08,0x88,0x00,0xf8,0x48,0x48,0xfe,0x00,
+/* 63780 0xf924 "襤" */
+0x43,0x22,0x2a,0xff,0x0a,0x13,0x26,0x2a,0x73,0xa8,0x27,0x22,0x22,0x22,0x27,0x00,
+0xe8,0x88,0x88,0xce,0x50,0xe8,0x84,0x84,0xe0,0x00,0xf8,0xa8,0xa8,0xa8,0xfe,0x00,
+/* 63781 0xf925 "拉" */
+0x10,0x10,0x10,0xfc,0x13,0x10,0x14,0x19,0xf1,0x50,0x10,0x10,0x90,0x70,0x27,0x00,
+0x00,0x40,0x20,0x24,0xfe,0x00,0x0c,0x08,0x08,0x90,0x90,0x90,0x20,0x24,0xfe,0x00,
+/* 63782 0xf926 "臘" */
+0x49,0x7e,0x4a,0x49,0x4b,0x7a,0x4a,0x4b,0x48,0x7b,0x4a,0x4b,0x4a,0xbb,0x92,0x00,
+0x24,0x48,0x48,0x24,0xfc,0xa4,0x54,0xfc,0x40,0x68,0xd8,0x68,0xda,0x66,0x42,0x00,
+/* 63783 0xf927 "蠟" */
+0x21,0x22,0x22,0xa9,0xff,0xaa,0xaa,0xab,0xf8,0xab,0x22,0x2b,0x36,0xe2,0x43,0x00,
+0x24,0x48,0x48,0x24,0xfc,0xa4,0x54,0xfc,0x00,0x68,0xd8,0x68,0xda,0x66,0x42,0x00,
+/* 63784 0xf928 "廊" */
+0x01,0x20,0x3f,0x24,0x22,0x2f,0x28,0x2f,0x28,0x2f,0x28,0x29,0x2b,0x4c,0x88,0x00,
+0x00,0x84,0xfe,0x00,0xbe,0xe4,0xa4,0xa8,0xa8,0xa4,0xa2,0x32,0xac,0xa0,0x20,0x00,
+/* 63785 0xf929 "朗" */
+0x10,0x4a,0x7f,0x42,0x42,0x7e,0x42,0x42,0x7e,0x4a,0x44,0x4a,0x52,0xe1,0x42,0x00,
+0x44,0x7e,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0xa4,0x1c,0x08,0x00,
+/* 63786 0xf92a "浪" */
+0x20,0x12,0x13,0x02,0x42,0x2b,0x2a,0x12,0x13,0x62,0x22,0x22,0x62,0x67,0x22,0x00,
+0x80,0x48,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x44,0x48,0x30,0x90,0x08,0x06,0x00,
+/* 63787 0xf92b "狼" */
+0x00,0x4c,0x29,0x11,0x31,0x49,0x89,0x19,0x29,0x49,0x89,0x09,0x49,0x3b,0x11,0x00,
+0x40,0x20,0x24,0xfe,0x04,0xfc,0x04,0xfc,0x42,0x44,0x28,0x10,0x48,0x86,0x02,0x00,
+/* 63788 0xf92c "郎" */
+0x10,0x09,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x21,0x24,0x22,0x2d,0x71,0x20,0x00,
+0x24,0x3e,0xa4,0x24,0x28,0x28,0x28,0x24,0x24,0x22,0x22,0x32,0x2c,0x20,0x20,0x00,
+/* 63789 0xf92d "來" */
+0x01,0x01,0x7f,0x01,0x11,0x11,0x11,0x29,0x43,0x05,0x09,0x11,0x21,0x41,0x01,0x00,
+0x00,0x04,0xfe,0x00,0x10,0x10,0x10,0x28,0x84,0x40,0x20,0x10,0x0c,0x04,0x00,0x00,
+/* 63790 0xf92e "冷" */
+0x00,0x80,0x60,0x28,0x09,0x12,0x14,0x28,0x23,0xc0,0x40,0x40,0x41,0x40,0x00,0x00,
+0x40,0x40,0xa0,0x90,0x08,0x46,0x22,0x20,0xfc,0x08,0x10,0x20,0xc0,0x20,0x10,0x00,
+/* 63791 0xf92f "勞" */
+0x04,0x15,0x16,0x24,0x0a,0x11,0x3f,0x20,0x41,0x3f,0x01,0x02,0x04,0x08,0x30,0x00,
+0x10,0x54,0x58,0x90,0x28,0x44,0xfe,0x02,0x04,0xf8,0x08,0x08,0x88,0x70,0x20,0x00,
+/* 63792 0xf930 "擄" */
+0x10,0x12,0x13,0xfe,0x13,0x12,0x16,0x1a,0xf3,0x52,0x12,0x12,0x95,0x78,0x23,0x00,
+0x7c,0x40,0xfe,0x44,0xfa,0x42,0xfe,0xa4,0xfe,0xa4,0xfc,0x20,0xfe,0x42,0x9c,0x00,
+/* 63793 0xf931 "櫓" */
+0x10,0x10,0x11,0xff,0x11,0x11,0x39,0x55,0x55,0x92,0x91,0x11,0x11,0x11,0x11,0x00,
+0x90,0xf8,0x10,0xfc,0x24,0xfc,0x24,0xfc,0x54,0x4a,0xfc,0x04,0xfc,0x04,0xfc,0x00,
+/* 63794 0xf932 "爐" */
+0x10,0x12,0x13,0x12,0x57,0x5a,0x52,0x52,0x92,0x12,0x1a,0x24,0x25,0x49,0x97,0x00,
+0x7c,0x40,0xfe,0x44,0xfa,0x42,0xfe,0xa8,0xf8,0xa8,0xf8,0x00,0xfc,0x54,0xfe,0x00,
+/* 63795 0xf933 "盧" */
+0x01,0x01,0x21,0x3f,0x21,0x2f,0x21,0x23,0x22,0x23,0x22,0x2f,0x29,0x49,0x9f,0x00,
+0x10,0xf8,0x00,0xfe,0x04,0xf8,0x02,0xfe,0x48,0xf8,0x48,0xfc,0x24,0x24,0xfe,0x00,
+/* 63796 0xf934 "老" */
+0x01,0x01,0x01,0x3f,0x01,0x01,0x7f,0x00,0x01,0x06,0x0c,0x17,0x64,0x04,0x03,0x00,
+0x00,0x00,0x0c,0xe8,0x10,0x24,0xfe,0x80,0x00,0x30,0xc0,0x04,0x04,0x06,0xfc,0x00,
+/* 63797 0xf935 "蘆" */
+0x04,0x7f,0x04,0x10,0x1f,0x11,0x1f,0x11,0x13,0x12,0x13,0x12,0x17,0x25,0x5f,0x00,
+0x20,0xfe,0xa0,0xf8,0xfe,0x04,0xf8,0x02,0xfe,0x48,0xf8,0x48,0xf8,0x28,0xfe,0x00,
+/* 63798 0xf936 "虜" */
+0x01,0x01,0x3f,0x21,0x2f,0x21,0x27,0x24,0x3f,0x24,0x27,0x20,0x2f,0x41,0x8e,0x00,
+0xf8,0x00,0xfe,0x04,0xf0,0x02,0xfe,0x48,0xfe,0x48,0xf8,0x80,0xfc,0x04,0x38,0x00,
+/* 63799 0xf937 "路" */
+0x00,0x7c,0x44,0x44,0x45,0x7c,0x54,0x10,0x51,0x5c,0x50,0x50,0x5c,0xf0,0x40,0x00,
+0x40,0x44,0x7e,0x84,0x48,0x30,0x48,0x86,0x02,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 63800 0xf938 "露" */
+0x1f,0x41,0x7f,0x81,0x3d,0x01,0x3e,0x22,0x3e,0x2b,0x08,0x2e,0x28,0x7e,0x20,0x00,
+0xf8,0x02,0xfe,0x04,0x78,0x40,0x78,0x48,0xd0,0x30,0x4e,0xf8,0x88,0xf8,0x88,0x00,
+/* 63801 0xf939 "魯" */
+0x04,0x0f,0x10,0x3f,0x51,0x1f,0x11,0x1f,0x24,0x22,0x4f,0x08,0x0f,0x08,0x0f,0x00,
+0x40,0xe0,0x88,0xfc,0x08,0xf8,0x08,0xf8,0x44,0x22,0xf2,0x10,0xf0,0x10,0xf0,0x00,
+/* 63802 0xf93a "鷺" */
+0x3e,0x22,0x3e,0x08,0x2e,0x28,0x7f,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x29,0x44,0x00,
+0x7c,0x44,0xb8,0x44,0xfa,0x88,0xf8,0x10,0xf0,0x10,0xfc,0x00,0xfe,0x22,0x94,0x00,
+/* 63803 0xf93b "碌" */
+0x00,0x04,0xfe,0x10,0x11,0x20,0x3f,0x64,0xa5,0x24,0x24,0x27,0x3d,0x24,0x00,0x00,
+0x44,0x7c,0x88,0x88,0xf0,0x10,0xfe,0x20,0x22,0xb4,0x68,0xa4,0x22,0xe2,0x40,0x00,
+/* 63804 0xf93c "祿" */
+0x20,0x10,0x10,0xfd,0x05,0x08,0x13,0x30,0x59,0x94,0x14,0x10,0x17,0x12,0x10,0x00,
+0x84,0xfc,0x88,0x08,0xf0,0x10,0xfe,0x20,0x2c,0xa8,0x70,0xa8,0x26,0xe2,0x40,0x00,
+/* 63805 0xf93d "綠" */
+0x10,0x10,0x20,0x25,0x45,0xf8,0x13,0x28,0xfd,0x44,0x00,0x28,0x55,0x56,0x80,0x00,
+0x88,0xfc,0x88,0x08,0xf0,0x10,0xfe,0x20,0x2c,0xa8,0x70,0xa8,0x26,0xe2,0x40,0x00,
+/* 63806 0xf93e "菉" */
+0x04,0x04,0x7f,0x04,0x03,0x02,0x07,0x00,0x7f,0x10,0x08,0x06,0x08,0x73,0x21,0x00,
+0x20,0x20,0xfe,0x20,0xe0,0x20,0xe0,0x44,0xfe,0x88,0xd0,0xa0,0x90,0x8e,0x04,0x00,
+/* 63807 0xf93f "錄" */
+0x10,0x18,0x14,0x22,0x40,0xfc,0x11,0x10,0xff,0x94,0x58,0x51,0x1e,0xf0,0x40,0x00,
+0x44,0x7c,0x44,0x88,0xf8,0x10,0xfe,0x20,0x26,0xb4,0x68,0xa8,0x26,0xe2,0x40,0x00,
+/* 63808 0xf940 "鹿" */
+0x01,0x20,0x3f,0x22,0x22,0x3f,0x22,0x3f,0x28,0x28,0x2f,0x28,0x29,0x5e,0x88,0x00,
+0x00,0x84,0xfe,0x20,0x24,0xfe,0x24,0xfc,0x04,0x20,0xa4,0x38,0xa2,0x22,0x3e,0x00,
+/* 63809 0xf941 "論" */
+0x20,0x10,0x10,0xfc,0x01,0x02,0x78,0x03,0x7a,0x02,0x7b,0x4a,0x4a,0x7a,0x4a,0x00,
+0x20,0x20,0x50,0x88,0x06,0xfa,0x00,0xfe,0x52,0x52,0xfe,0x52,0x52,0x52,0x46,0x00,
+/* 63810 0xf942 "壟" */
+0x08,0x7f,0x14,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x2e,0x24,0x00,0x1f,0x00,0x7f,0x00,
+0x7e,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7e,0x42,0x3e,0x80,0xf8,0x84,0xfe,0x00,
+/* 63811 0xf943 "弄" */
+0x7f,0x01,0x01,0x3f,0x01,0x01,0x7f,0x08,0x08,0x7f,0x08,0x08,0x10,0x20,0x40,0x00,
+0xfc,0x00,0x10,0xf8,0x00,0x04,0xfe,0x20,0x24,0xfe,0x20,0x20,0x20,0x20,0x20,0x00,
+/* 63812 0xf944 "籠" */
+0x10,0x1f,0x28,0x45,0x3f,0x22,0x14,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x22,0x26,0x00,
+0x40,0x7e,0x90,0x48,0x7e,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x42,0x3e,0x00,
+/* 63813 0xf945 "聾" */
+0x08,0x7e,0x14,0x7f,0x22,0x3e,0x22,0x3e,0x22,0x7f,0x08,0x0f,0x08,0x7f,0x00,0x00,
+0x80,0xfc,0x80,0xfc,0x04,0xfc,0x80,0xfe,0x82,0xfe,0x10,0xf0,0x10,0xfe,0x10,0x00,
+/* 63814 0xf946 "牢" */
+0x01,0x20,0x3f,0x20,0x49,0x09,0x0f,0x11,0x21,0x01,0x7f,0x01,0x01,0x01,0x01,0x00,
+0x00,0x84,0xfe,0x04,0x08,0x10,0xf8,0x00,0x00,0x04,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 63815 0xf947 "磊" */
+0x00,0x7f,0x02,0x07,0x0c,0x14,0x67,0x02,0x7f,0x10,0x1e,0x32,0x52,0x1e,0x12,0x00,
+0x04,0xfe,0x00,0xf0,0x10,0x10,0xf0,0x04,0x7e,0x20,0x3c,0x64,0xa4,0x3c,0x24,0x00,
+/* 63816 0xf948 "賂" */
+0x44,0x7e,0x44,0x44,0x7d,0x46,0x44,0x7c,0x45,0x44,0x7c,0x44,0x28,0x44,0x84,0x00,
+0x80,0x84,0xfe,0x84,0x48,0x30,0x48,0x86,0x02,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 63817 0xf949 "雷" */
+0x1f,0x41,0x7f,0x81,0x3d,0x01,0x3d,0x01,0x20,0x3f,0x21,0x3f,0x21,0x3f,0x20,0x00,
+0xf8,0x02,0xfe,0x04,0x78,0x00,0x78,0x00,0x08,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x00,
+/* 63818 0xf94a "壘" */
+0x1f,0x11,0x1f,0x11,0x1f,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x01,0x3f,0x01,0xff,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x10,0xfe,0x92,0xfe,0x92,0xfe,0x10,0xf8,0x04,0xfe,0x00,
+/* 63819 0xf94b "屢" */
+0x3f,0x20,0x20,0x3f,0x24,0x3f,0x24,0x2f,0x28,0x2f,0x21,0x3f,0x22,0x41,0x9f,0x00,
+0xfc,0x04,0x04,0xfc,0x88,0xfe,0x88,0xfc,0x84,0xfc,0x00,0xfe,0x20,0x60,0x9e,0x00,
+/* 63820 0xf94c "樓" */
+0x10,0x11,0x11,0x13,0xfd,0x11,0x18,0x35,0x55,0x51,0x90,0x97,0x10,0x10,0x17,0x00,
+0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x24,0xfc,0x40,0xfe,0x90,0x70,0xce,0x00,
+/* 63821 0xf94d "淚" */
+0x20,0x12,0x13,0x02,0x42,0x2b,0x2a,0x12,0x12,0x63,0x22,0x24,0x64,0x69,0x32,0x00,
+0x80,0x44,0xfe,0x04,0x04,0xfc,0x04,0x28,0x24,0xfe,0x20,0x50,0x88,0x06,0x02,0x00,
+/* 63822 0xf94e "漏" */
+0x44,0x27,0x24,0x07,0x84,0x57,0x54,0x27,0x26,0xc7,0x46,0x4b,0xca,0xd2,0x62,0x00,
+0x04,0xfe,0x04,0xfc,0x00,0xfe,0x20,0xfe,0x22,0x32,0xaa,0x32,0xaa,0xaa,0x26,0x00,
+/* 63823 0xf94f "累" */
+0x1f,0x10,0x1f,0x10,0x1f,0x11,0x02,0x04,0x1f,0x02,0x3f,0x10,0x04,0x1b,0x61,0x00,
+0xfc,0x84,0xfc,0x84,0xfc,0x04,0x20,0x60,0x80,0x08,0xfc,0x84,0xa0,0x98,0x06,0x00,
+/* 63824 0xf950 "縷" */
+0x10,0x10,0x21,0x25,0x47,0xf9,0x13,0x2a,0xff,0x44,0x03,0x28,0x55,0x54,0x83,0x00,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfe,0x22,0xfe,0x20,0xfe,0x88,0x90,0x60,0x9e,0x00,
+/* 63825 0xf951 "陋" */
+0x88,0xf9,0x88,0x90,0xa2,0xa2,0x92,0x92,0x8a,0x8a,0xca,0xb2,0x82,0x82,0x83,0x00,
+0x04,0xfe,0x10,0x90,0xfe,0x92,0x92,0x92,0xaa,0xc6,0x82,0x9e,0x84,0x00,0xfe,0x00,
+/* 63826 0xf952 "勒" */
+0x22,0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x49,0x7f,0x08,0xff,0x08,0x08,0x09,0x00,
+0x20,0x20,0xa0,0x24,0xfe,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0xbc,0x08,0x00,
+/* 63827 0xf953 "肋" */
+0x24,0x3e,0x24,0x24,0x25,0x3c,0x24,0x24,0x24,0x3c,0x24,0x24,0x24,0x5d,0x88,0x00,
+0x20,0x20,0x20,0x24,0xfe,0x24,0x24,0x24,0x24,0x24,0x44,0x44,0xa4,0x1c,0x08,0x00,
+/* 63828 0xf954 "凜" */
+0x00,0x8f,0x60,0x2b,0x0a,0x12,0x12,0x23,0x20,0xc3,0x40,0x4f,0x42,0x44,0x08,0x00,
+0x40,0xfe,0x00,0xfc,0x94,0xf4,0x04,0xfc,0x00,0xf8,0x40,0xfe,0x48,0x44,0x42,0x00,
+/* 63829 0xf955 "凌" */
+0x00,0x80,0x63,0x28,0x08,0x17,0x11,0x22,0x24,0xc1,0x43,0x44,0x48,0x41,0x0e,0x00,
+0x40,0x48,0xfc,0x40,0x44,0xfe,0x08,0x04,0x8a,0xfc,0x08,0x90,0x60,0x9e,0x04,0x00,
+/* 63830 0xf956 "稜" */
+0x04,0x0e,0xf1,0x10,0x15,0xfe,0x10,0x19,0x36,0x50,0x91,0x12,0x10,0x11,0x16,0x00,
+0x20,0x28,0xfc,0x20,0xfe,0x48,0x86,0x42,0x78,0x88,0x48,0x30,0x50,0x8e,0x04,0x00,
+/* 63831 0xf957 "綾" */
+0x10,0x11,0x20,0x24,0x47,0xf8,0x11,0x2a,0xfc,0x45,0x02,0x28,0x54,0x55,0x86,0x00,
+0x20,0xfc,0x20,0x24,0xfe,0x88,0x04,0x82,0xf8,0x08,0x88,0x50,0x60,0x98,0x06,0x00,
+/* 63832 0xf958 "菱" */
+0x04,0x04,0x7f,0x05,0x1f,0x01,0x7f,0x04,0x1a,0x63,0x04,0x1a,0x01,0x06,0x78,0x00,
+0x20,0x20,0xfe,0x20,0xf8,0x00,0xfe,0x20,0x18,0xf6,0x20,0x40,0x80,0x70,0x0e,0x00,
+/* 63833 0xf959 "陵" */
+0x88,0xfb,0x88,0x90,0xa7,0xa0,0x91,0x92,0x88,0x89,0xca,0xb4,0x80,0x81,0x8e,0x00,
+0x48,0xfc,0x40,0x44,0xfe,0x90,0x0c,0x84,0xf8,0x88,0x90,0xa0,0x60,0x98,0x06,0x00,
+/* 63834 0xf95a "讀" */
+0x20,0x13,0xfc,0x01,0x00,0x7b,0x02,0x03,0x79,0x01,0x79,0x49,0x49,0x79,0x4b,0x00,
+0x20,0xfe,0x20,0xfc,0x00,0xfe,0x52,0xfe,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x06,0x00,
+/* 63835 0xf95b "拏" */
+0x08,0x08,0x7f,0x12,0x24,0x1a,0x11,0x60,0x1f,0x00,0x1f,0x00,0x7f,0x00,0x07,0x00,
+0x04,0xfe,0x44,0x28,0x10,0x28,0xc6,0x38,0xc0,0x88,0xfc,0x80,0xfe,0x80,0x80,0x00,
+/* 63836 0xf95c "樂" */
+0x21,0x21,0x47,0x54,0xe7,0x24,0x54,0xff,0x45,0x01,0xff,0x05,0x09,0x31,0xc1,0x00,
+0x08,0x08,0xd0,0x54,0xf8,0x48,0x54,0xfe,0x50,0x04,0xfe,0x20,0x10,0x0e,0x04,0x00,
+/* 63837 0xf95d "諾" */
+0x20,0x10,0x13,0xfc,0x00,0x00,0x78,0x03,0x78,0x00,0x79,0x4a,0x4c,0x78,0x48,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0x24,0xfe,0x40,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 63838 0xf95e "丹" */
+0x00,0x0f,0x08,0x08,0x09,0x08,0x08,0x08,0x7f,0x08,0x08,0x10,0x10,0x20,0x40,0x00,
+0x10,0xf8,0x10,0x10,0x10,0x90,0x90,0x10,0xfe,0x10,0x10,0x10,0x90,0x70,0x20,0x00,
+/* 63839 0xf95f "寧" */
+0x01,0x20,0x3f,0x25,0x54,0x27,0x00,0x1f,0x12,0x7f,0x00,0x3f,0x00,0x07,0x01,0x00,
+0x00,0x84,0xfe,0x04,0xa8,0xe4,0x00,0xf8,0x48,0xfe,0x00,0xfc,0x80,0x80,0x00,0x00,
+/* 63840 0xf960 "怒" */
+0x08,0x08,0x0b,0x7e,0x12,0x24,0x1c,0x0a,0x11,0x60,0x05,0x24,0x24,0x24,0x43,0x00,
+0x00,0x04,0xfe,0x44,0x44,0x48,0x30,0x48,0x86,0x02,0x00,0x88,0xa6,0x22,0xf0,0x00,
+/* 63841 0xf961 "率" */
+0x01,0x00,0x7f,0x01,0x22,0x17,0x01,0x1a,0x67,0x45,0x01,0x7f,0x01,0x01,0x01,0x00,
+0x00,0x84,0xfe,0x04,0x48,0x90,0x00,0x50,0xec,0x24,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 63842 0xf962 "異" */
+0x10,0x1f,0x11,0x1f,0x11,0x1f,0x14,0x04,0x3f,0x04,0x04,0x7f,0x04,0x18,0x60,0x00,
+0x08,0xfc,0x08,0xf8,0x08,0xf8,0x48,0x40,0xfc,0x40,0x44,0xfe,0x20,0x18,0x06,0x00,
+/* 63843 0xf963 "北" */
+0x08,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0x08,0x08,0x18,0xe8,0x48,0x08,0x00,
+0x80,0x80,0x80,0x8c,0x88,0x90,0xe0,0x80,0x80,0x80,0x80,0x84,0x84,0x86,0x7c,0x00,
+/* 63844 0xf964 "磻" */
+0x00,0x09,0xfc,0x21,0x20,0x23,0x3c,0x65,0xa6,0x25,0x25,0x25,0x3d,0x25,0x21,0x00,
+0x0e,0xf0,0x26,0x24,0xa8,0xfe,0xa8,0x24,0x22,0xfe,0x22,0xfe,0x22,0xfe,0x02,0x00,
+/* 63845 0xf965 "便" */
+0x10,0x17,0x10,0x24,0x27,0x24,0x67,0xa4,0x27,0x24,0x22,0x21,0x20,0x21,0x2e,0x00,
+0x04,0xfe,0x40,0x44,0xfe,0x44,0xfc,0x44,0xfc,0x44,0x40,0x40,0x80,0x40,0x3e,0x00,
+/* 63846 0xf966 "復" */
+0x19,0x11,0x22,0x45,0x99,0x11,0x21,0x61,0xa0,0x21,0x23,0x24,0x20,0x21,0x26,0x00,
+0x04,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfc,0x08,0x90,0x60,0x98,0x06,0x00,
+/* 63847 0xf967 "不" */
+0x00,0x7f,0x00,0x00,0x01,0x03,0x05,0x09,0x11,0x21,0x41,0x01,0x01,0x01,0x01,0x00,
+0x04,0xfe,0x80,0x80,0x00,0x00,0x20,0x10,0x0c,0x06,0x02,0x00,0x00,0x00,0x00,0x00,
+/* 63848 0xf968 "泌" */
+0x20,0x10,0x10,0x04,0x44,0x28,0x28,0x12,0x12,0x64,0x24,0x20,0x61,0x62,0x24,0x00,
+0x00,0x40,0x24,0x24,0x88,0x88,0x88,0x90,0x94,0xa2,0xa2,0xc0,0x84,0x84,0x7e,0x00,
+/* 63849 0xf969 "數" */
+0x08,0x7f,0x49,0xff,0x49,0x7f,0x08,0x7f,0x49,0x7f,0x10,0xff,0x22,0x1c,0xf3,0x00,
+0x40,0x40,0x40,0xc4,0x7e,0xc8,0x48,0x48,0x48,0x48,0x28,0x90,0x2c,0x46,0x82,0x00,
+/* 63850 0xf96a "索" */
+0x01,0x3f,0x01,0x21,0x3f,0x21,0x42,0x1f,0x01,0x02,0x3f,0x00,0x04,0x1b,0x61,0x00,
+0x08,0xfc,0x00,0x04,0xfe,0x04,0x28,0xc0,0x10,0x08,0xf4,0x84,0xa0,0x98,0x06,0x00,
+/* 63851 0xf96b "參" */
+0x01,0x02,0x07,0x10,0x24,0x7b,0x01,0x02,0x7c,0x03,0x1c,0x01,0x1e,0x01,0x1e,0x00,
+0x00,0x20,0xd0,0x10,0x24,0x7e,0x82,0x40,0xbc,0x00,0x40,0x98,0x60,0x80,0x00,0x00,
+/* 63852 0xf96c "塞" */
+0x01,0x20,0x3f,0x42,0x1f,0x02,0x1f,0x02,0x7f,0x04,0x08,0x17,0x20,0x00,0x7f,0x00,
+0x00,0x82,0xfe,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x90,0x88,0xf6,0x82,0x84,0xfe,0x00,
+/* 63853 0xf96d "省" */
+0x01,0x0d,0x09,0x11,0x21,0x40,0x01,0x0f,0x18,0x6f,0x08,0x0f,0x08,0x0f,0x08,0x00,
+0x00,0x10,0x08,0x66,0x42,0x80,0x08,0xfc,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,
+/* 63854 0xf96e "葉" */
+0x04,0x7f,0x04,0x09,0x7f,0x09,0x09,0x08,0x0f,0x00,0x7f,0x02,0x04,0x18,0x60,0x00,
+0x20,0xfe,0x20,0x10,0xfe,0x10,0xf0,0x00,0xfc,0x80,0xfe,0xc0,0xa0,0x98,0x86,0x00,
+/* 63855 0xf96f "說" */
+0x21,0x10,0x10,0xfe,0x01,0x01,0xfd,0x01,0xfd,0x01,0xfc,0x84,0x84,0xfd,0x86,0x00,
+0x08,0x88,0x90,0x20,0xfc,0x04,0x04,0x04,0xfc,0x54,0x50,0x50,0x92,0x12,0x0e,0x00,
+/* 63856 0xf970 "殺" */
+0x02,0x42,0x24,0x18,0x26,0x41,0x14,0x12,0xff,0x10,0x38,0x54,0x92,0x10,0x13,0x00,
+0x88,0xfc,0x88,0x88,0x88,0x0e,0x00,0xfc,0x84,0x48,0x48,0x30,0x28,0xc6,0x02,0x00,
+/* 63857 0xf971 "辰" */
+0x10,0x1f,0x10,0x10,0x17,0x10,0x10,0x1f,0x12,0x12,0x12,0x22,0x22,0x4f,0x84,0x00,
+0x04,0xfe,0x00,0x10,0xf8,0x00,0x04,0xfe,0x40,0x48,0x50,0x20,0x90,0x08,0x06,0x00,
+/* 63858 0xf972 "沈" */
+0x20,0x10,0x10,0x02,0x43,0x2a,0x2c,0x10,0x10,0x60,0x20,0x20,0x61,0x62,0x24,0x00,
+0x40,0x40,0x40,0x44,0xfe,0x44,0x48,0x40,0x40,0x40,0x40,0xa0,0x22,0x22,0x1e,0x00,
+/* 63859 0xf973 "拾" */
+0x10,0x10,0x10,0xfd,0x12,0x10,0x15,0x18,0xf1,0x51,0x11,0x11,0x91,0x71,0x21,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x06,0xfa,0x00,0x08,0xfc,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 63860 0xf974 "若" */
+0x04,0x04,0x7f,0x04,0x04,0x01,0x01,0x7f,0x02,0x04,0x0f,0x14,0x64,0x07,0x04,0x00,
+0x20,0x20,0xfe,0x20,0x20,0x00,0x04,0xfe,0x00,0x08,0xfc,0x08,0x08,0xf8,0x08,0x00,
+/* 63861 0xf975 "掠" */
+0x10,0x10,0x10,0xff,0x10,0x11,0x15,0x19,0xf1,0x51,0x10,0x11,0x91,0x72,0x24,0x00,
+0x40,0x20,0x24,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x24,0x20,0xa8,0x24,0xe2,0x42,0x00,
+/* 63862 0xf976 "略" */
+0x00,0x44,0x7e,0x54,0x55,0x54,0x54,0x7c,0x55,0x54,0x54,0x7c,0x44,0x00,0x00,0x00,
+0x80,0x84,0xfe,0x84,0x48,0x30,0x48,0x86,0x02,0xfc,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 63863 0xf977 "亮" */
+0x02,0x01,0x7f,0x00,0x0f,0x08,0x0f,0x00,0x3f,0x20,0x47,0x04,0x04,0x18,0x60,0x00,
+0x00,0x04,0xfe,0x00,0xf0,0x10,0xf0,0x00,0xfe,0x02,0xc4,0x40,0x42,0x42,0x3e,0x00,
+/* 63864 0xf978 "兩" */
+0x00,0x7f,0x01,0x01,0x7f,0x41,0x51,0x49,0x49,0x55,0x65,0x41,0x41,0x41,0x40,0x00,
+0x04,0xfe,0x00,0x04,0xfe,0x04,0x44,0x24,0x24,0x54,0x94,0x04,0x24,0x1c,0x08,0x00,
+/* 63865 0xf979 "凉" */
+0x00,0x80,0x60,0x27,0x08,0x13,0x12,0x22,0x23,0xc2,0x40,0x42,0x45,0x48,0x10,0x00,
+0x80,0x40,0x44,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x24,0x20,0x30,0x28,0xe4,0x44,0x00,
+/* 63866 0xf97a "梁" */
+0x10,0x0b,0x40,0x25,0x09,0x0a,0x30,0x13,0x10,0x7f,0x02,0x04,0x08,0x10,0x60,0x00,
+0x08,0xfc,0x48,0x4c,0x4a,0x4a,0xb8,0x10,0x84,0xfe,0xc0,0xa0,0x90,0x8e,0x84,0x00,
+/* 63867 0xf97b "糧" */
+0x11,0x11,0x95,0x55,0x59,0x10,0xfd,0x11,0x19,0x35,0x55,0x90,0x11,0x10,0x13,0x00,
+0xfc,0x04,0xfc,0x04,0xfc,0x00,0xfe,0x24,0xfc,0x24,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 63868 0xf97c "良" */
+0x01,0x08,0x0f,0x08,0x08,0x0f,0x08,0x08,0x0f,0x09,0x08,0x08,0x0b,0x3c,0x10,0x00,
+0x00,0x90,0xf8,0x10,0x10,0xf0,0x10,0x10,0xf0,0x00,0x8c,0x70,0x20,0x18,0x06,0x00,
+/* 63869 0xf97d "諒" */
+0x20,0x10,0x10,0xff,0x00,0x01,0x7d,0x01,0x7d,0x01,0x7c,0x44,0x45,0x7e,0x44,0x00,
+0x40,0x20,0x24,0xfe,0x00,0xfc,0x04,0x04,0xfc,0x24,0xa8,0xa4,0x22,0xe2,0x40,0x00,
+/* 63870 0xf97e "量" */
+0x1f,0x10,0x1f,0x10,0x1f,0x00,0x7f,0x11,0x1f,0x11,0x1f,0x01,0x3f,0x01,0x7f,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x04,0xfe,0x10,0xf0,0x10,0xf0,0x00,0xf8,0x00,0xfe,0x00,
+/* 63871 0xf97f "勵" */
+0x7f,0x49,0x7f,0x49,0x5f,0x52,0x5f,0x52,0x5f,0x42,0x5f,0x52,0x53,0x9c,0x90,0x00,
+0xd0,0x10,0xd0,0x12,0xfe,0x52,0xd2,0x52,0xd2,0x12,0xd2,0x52,0xd2,0x6e,0xc4,0x00,
+/* 63872 0xf980 "呂" */
+0x08,0x0f,0x08,0x08,0x08,0x0f,0x09,0x01,0x12,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x10,0xf8,0x10,0x10,0x10,0xf0,0x10,0x00,0x08,0xfc,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 63873 0xf981 "女" */
+0x02,0x03,0x02,0x02,0x02,0x7f,0x04,0x04,0x08,0x08,0x10,0x0e,0x01,0x06,0x78,0x00,
+0x00,0x00,0x00,0x00,0x04,0xfe,0x20,0x20,0x20,0x20,0x40,0x80,0x80,0x70,0x0e,0x00,
+/* 63874 0xf982 "廬" */
+0x21,0x3f,0x20,0x20,0x28,0x2f,0x28,0x2f,0x2a,0x2b,0x2a,0x2f,0x2d,0x55,0xaf,0x00,
+0x04,0xfe,0x80,0xf8,0x80,0xfe,0x84,0xf8,0x4a,0xfe,0x48,0xf8,0x28,0x28,0xfe,0x00,
+/* 63875 0xf983 "旅" */
+0x10,0x08,0x08,0xfe,0x20,0x25,0x3e,0x24,0x24,0x24,0x24,0x24,0x24,0x5d,0x88,0x00,
+0x40,0x40,0x44,0xfe,0x80,0x1c,0xe0,0xa6,0xa4,0x98,0x90,0x90,0xa8,0xc6,0x82,0x00,
+/* 63876 0xf984 "濾" */
+0x40,0x20,0x24,0x07,0x84,0x57,0x54,0x25,0x25,0xc5,0x45,0x45,0xca,0xca,0x44,0x00,
+0x48,0x7c,0x40,0xfe,0x44,0xfa,0x42,0xfe,0x24,0xfc,0x24,0xfc,0x94,0x8a,0xfa,0x00,
+/* 63877 0xf985 "礪" */
+0x03,0x0a,0xff,0x22,0x22,0x22,0x7a,0xca,0x4a,0x4a,0x4a,0x4a,0x7a,0x4c,0x08,0x00,
+0xfe,0x48,0xfe,0x48,0xfc,0x94,0xfc,0x94,0xfc,0x10,0xfe,0x92,0xfa,0x86,0x82,0x00,
+/* 63878 0xf986 "閭" */
+0x7e,0x42,0x7e,0x42,0x7e,0x40,0x47,0x44,0x47,0x41,0x4f,0x48,0x4f,0x48,0x40,0x00,
+0x7e,0x42,0x7e,0x42,0x7e,0x02,0xe2,0x22,0xe2,0x02,0xf2,0x12,0xf2,0x1e,0x04,0x00,
+/* 63879 0xf987 "驪" */
+0x89,0xfc,0x93,0x92,0xfe,0x90,0xfd,0x91,0xfd,0x85,0x05,0x55,0xae,0xa4,0x18,0x00,
+0xdc,0x00,0xfe,0xaa,0xaa,0x20,0xfe,0x50,0xfc,0x54,0xfc,0x94,0xd8,0x92,0xee,0x00,
+/* 63880 0xf988 "麗" */
+0x3e,0x00,0x3e,0x2a,0x2b,0x00,0x3f,0x22,0x3f,0x22,0x3f,0x28,0x2f,0x48,0x9f,0x00,
+0x7c,0x00,0x7c,0x54,0x54,0x80,0xfc,0x40,0xf8,0x48,0xf8,0x52,0x62,0x42,0x3e,0x00,
+/* 63881 0xf989 "黎" */
+0x0e,0x78,0x08,0x7e,0x0c,0x1a,0x29,0x4a,0x04,0x18,0x64,0x03,0x04,0x3b,0x11,0x00,
+0x40,0x42,0x7e,0x92,0x22,0x42,0x9e,0x44,0xa0,0x98,0x96,0xe0,0x90,0x8c,0x04,0x00,
+/* 63882 0xf98a "力" */
+0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x08,0xfc,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x70,0x20,0x00,
+/* 63883 0xf98b "曆" */
+0x3f,0x21,0x2e,0x22,0x3f,0x22,0x27,0x2a,0x32,0x27,0x24,0x27,0x24,0x47,0x84,0x00,
+0xfe,0x08,0x70,0x14,0xfe,0x10,0x38,0xd4,0x92,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,
+/* 63884 0xf98c "歷" */
+0x20,0x3f,0x20,0x2f,0x22,0x3f,0x22,0x27,0x2a,0x32,0x20,0x24,0x24,0x44,0x9f,0x00,
+0x04,0xfe,0x84,0x78,0x10,0xfe,0x10,0x38,0xd6,0x12,0x40,0x40,0x7c,0x40,0xfe,0x00,
+/* 63885 0xf98d "轢" */
+0x21,0x21,0xfd,0x22,0xfb,0xa9,0xfa,0xaf,0xf8,0xa8,0x23,0xfe,0x21,0x22,0x24,0x00,
+0x24,0x24,0x74,0xda,0x74,0x54,0xfa,0x56,0x20,0x24,0xfe,0xb0,0x28,0x26,0x22,0x00,
+/* 63886 0xf98e "年" */
+0x0c,0x08,0x0f,0x10,0x20,0x48,0x0f,0x08,0x08,0x08,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0xfc,0x80,0x80,0x88,0xfc,0x80,0x80,0x84,0xfe,0x80,0x80,0x80,0x80,0x00,
+/* 63887 0xf98f "憐" */
+0x12,0x11,0x11,0x17,0x58,0x55,0x52,0x92,0x13,0x14,0x1a,0x11,0x11,0x12,0x14,0x00,
+0x4c,0x48,0x50,0xfe,0xd0,0x48,0x46,0x08,0xbe,0x88,0xa8,0x7e,0x08,0x08,0x08,0x00,
+/* 63888 0xf990 "戀" */
+0x12,0x11,0x27,0x70,0x23,0x48,0xfb,0x52,0xaa,0xab,0x04,0x25,0x24,0x24,0x43,0x00,
+0x04,0x04,0xc8,0x1c,0xc8,0x12,0xfe,0x54,0x6a,0xaa,0x00,0x04,0x92,0x12,0xf8,0x00,
+/* 63889 0xf991 "撚" */
+0x12,0x12,0x13,0xfa,0x12,0x15,0x12,0x19,0xf1,0x52,0x1c,0x10,0x93,0x74,0x28,0x00,
+0x10,0x14,0xd2,0x90,0xfe,0x90,0x90,0x90,0x28,0x46,0x82,0x00,0x24,0x92,0x92,0x00,
+/* 63890 0xf992 "漣" */
+0x40,0x28,0x27,0x04,0x81,0x51,0x55,0x2f,0x25,0xc4,0x47,0x44,0xc4,0xda,0x51,0x00,
+0x20,0x24,0xfe,0x20,0xfc,0x24,0xfc,0x24,0xfc,0x20,0xfe,0x20,0x20,0x20,0xfe,0x00,
+/* 63891 0xf993 "煉" */
+0x10,0x10,0x13,0x10,0x57,0x5a,0x53,0x52,0x93,0x12,0x18,0x24,0x25,0x42,0x80,0x00,
+0x20,0x24,0xfe,0x20,0xfe,0x22,0x26,0xaa,0xfe,0x22,0x70,0xa8,0x26,0x22,0x20,0x00,
+/* 63892 0xf994 "璉" */
+0x00,0x14,0xfa,0x22,0x20,0x20,0x20,0xff,0x21,0x21,0x21,0x39,0xe1,0x46,0x04,0x00,
+0x10,0x10,0xfe,0x10,0x7e,0x52,0x7e,0x52,0x7e,0x52,0x10,0xfe,0x10,0x90,0x7e,0x00,
+/* 63893 0xf995 "秊" */
+0x00,0x00,0x3f,0x01,0xff,0x05,0x09,0x31,0xc0,0x1f,0x01,0xff,0x01,0x01,0x01,0x00,
+0x20,0xf0,0x00,0x04,0xfe,0x40,0x20,0x18,0x76,0x80,0x08,0xfc,0x00,0x00,0x00,0x00,
+/* 63894 0xf996 "練" */
+0x10,0x13,0x20,0x27,0x46,0xfb,0x12,0x2b,0xfa,0x44,0x00,0x28,0x55,0x56,0x80,0x00,
+0x24,0xfe,0x20,0xfe,0x22,0x26,0xaa,0xfe,0x22,0x20,0x70,0xa8,0x26,0x22,0x20,0x00,
+/* 63895 0xf997 "聯" */
+0x04,0xfe,0x25,0x27,0x3c,0x25,0x27,0x3c,0x25,0x27,0x2d,0xf5,0x44,0x04,0x05,0x00,
+0x88,0x88,0x52,0xbc,0x88,0x54,0xdc,0x22,0x54,0x54,0x54,0xdc,0x54,0x90,0x10,0x00,
+/* 63896 0xf998 "輦" */
+0x08,0x3f,0x08,0x7f,0x14,0x22,0x40,0x3f,0x08,0x0f,0x08,0x0f,0x00,0x7f,0x00,0x00,
+0x10,0x7c,0x10,0x7e,0x28,0xc4,0x82,0xfe,0x88,0xf8,0x88,0xf8,0x80,0xfe,0x80,0x00,
+/* 63897 0xf999 "蓮" */
+0x04,0x7f,0x04,0x20,0x17,0x10,0x03,0x02,0x73,0x12,0x13,0x10,0x17,0x68,0x47,0x00,
+0x20,0xfe,0x20,0x40,0xfc,0x40,0xf8,0x48,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0x00,
+/* 63898 0xf99a "連" */
+0x00,0x40,0x37,0x10,0x03,0x02,0x13,0xfa,0x13,0x12,0x10,0x17,0x30,0xc8,0x87,0x00,
+0x40,0x44,0xfe,0x40,0xfc,0x44,0xfc,0x44,0xfc,0x44,0x40,0xfe,0x40,0x40,0xfe,0x00,
+/* 63899 0xf99b "鍊" */
+0x10,0x18,0x15,0x22,0x41,0xfd,0x11,0x11,0xff,0x95,0x58,0x50,0x1f,0xf2,0x40,0x00,
+0x20,0x24,0xfe,0x20,0xfe,0x22,0xa6,0x6a,0xfe,0x22,0x70,0xa8,0x26,0x22,0x20,0x00,
+/* 63900 0xf99c "列" */
+0x01,0x7f,0x08,0x08,0x09,0x0f,0x11,0x31,0x49,0x0a,0x04,0x04,0x08,0x10,0x60,0x00,
+0x02,0x82,0x22,0x22,0x22,0xa2,0x22,0x22,0x22,0x22,0x22,0x02,0x12,0x0e,0x04,0x00,
+/* 63901 0xf99d "劣" */
+0x01,0x01,0x19,0x11,0x21,0x40,0x01,0x06,0x18,0x67,0x00,0x01,0x02,0x0c,0x30,0x00,
+0x00,0x00,0x18,0x06,0x1a,0x20,0xc0,0x80,0x84,0xfe,0x84,0x04,0x24,0x1c,0x08,0x00,
+/* 63902 0xf99e "咽" */
+0x02,0x93,0xfa,0x92,0x92,0x93,0x92,0x92,0x92,0x92,0xf2,0x93,0x02,0x03,0x02,0x00,
+0x02,0xfe,0x22,0x22,0x22,0xfa,0x22,0x22,0x62,0x52,0x8a,0x0a,0x02,0xfe,0x02,0x00,
+/* 63903 0xf99f "烈" */
+0x01,0x7f,0x08,0x08,0x0f,0x11,0x31,0x49,0x0a,0x04,0x78,0x00,0x24,0x22,0x42,0x00,
+0x04,0x84,0x24,0x24,0xa4,0x24,0x24,0x24,0x04,0x1c,0x08,0x00,0x44,0x22,0x22,0x00,
+/* 63904 0xf9a0 "裂" */
+0x01,0x7f,0x08,0x1f,0x31,0x0a,0x3d,0x00,0x7f,0x02,0x04,0x0c,0x74,0x07,0x0c,0x00,
+0x04,0xa4,0x24,0x24,0x24,0x24,0x1c,0x88,0xfe,0x80,0x48,0x50,0x20,0x18,0x06,0x00,
+/* 63905 0xf9a1 "說" */
+0x21,0x10,0x10,0xfe,0x01,0x01,0xfd,0x01,0xfd,0x01,0xfc,0x84,0x84,0xfd,0x86,0x00,
+0x08,0x88,0x90,0x20,0xfc,0x04,0x04,0x04,0xfc,0x54,0x50,0x50,0x92,0x12,0x0e,0x00,
+/* 63906 0xf9a2 "廉" */
+0x21,0x3f,0x22,0x21,0x2f,0x21,0x2f,0x21,0x3f,0x21,0x2f,0x21,0x23,0x45,0x99,0x00,
+0x04,0xfe,0x20,0x44,0xfe,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x40,0x60,0x50,0x4c,0x00,
+/* 63907 0xf9a3 "念" */
+0x01,0x02,0x04,0x08,0x11,0x60,0x00,0x0f,0x00,0x01,0x04,0x24,0x24,0x44,0x03,0x00,
+0x00,0x80,0x40,0x20,0x10,0x8c,0x00,0xe0,0x20,0x40,0x80,0x84,0x12,0x12,0xf8,0x00,
+/* 63908 0xf9a4 "捻" */
+0x10,0x10,0x10,0xfc,0x11,0x12,0x15,0x18,0xf0,0x50,0x12,0x12,0x92,0x74,0x20,0x00,
+0x20,0x20,0x50,0x88,0x26,0x12,0xfc,0x08,0x10,0x10,0xc4,0xa2,0x8a,0x88,0x7c,0x00,
+/* 63909 0xf9a5 "殮" */
+0x04,0xfe,0x20,0x20,0x25,0x3e,0x25,0x65,0x95,0x15,0x08,0x08,0x10,0x21,0xc2,0x00,
+0x20,0x20,0x50,0x88,0x76,0x02,0xdc,0x54,0x54,0xdc,0x00,0x88,0x88,0x56,0x22,0x00,
+/* 63910 0xf9a6 "簾" */
+0x10,0x1f,0x28,0x7f,0x24,0x2f,0x22,0x2f,0x22,0x3f,0x22,0x2f,0x26,0x4a,0xb2,0x00,
+0x40,0x7e,0x90,0xfe,0x20,0xfc,0x40,0xf8,0x48,0xfe,0x48,0xf8,0x50,0x48,0x46,0x00,
+/* 63911 0xf9a7 "獵" */
+0x01,0x4e,0x2a,0x11,0x33,0x4a,0x8a,0x1b,0x28,0x4b,0x8a,0x0b,0x4a,0x3b,0x12,0x00,
+0x24,0x48,0x48,0x24,0xfc,0x54,0xa4,0xfc,0x40,0x68,0xd8,0x6a,0x5a,0x66,0x42,0x00,
+/* 63912 0xf9a8 "令" */
+0x00,0x01,0x02,0x04,0x09,0x10,0x20,0x40,0x1f,0x00,0x00,0x06,0x01,0x00,0x00,0x00,
+0x80,0x80,0x40,0x20,0x10,0x88,0x86,0x12,0xf8,0x10,0x20,0x40,0x80,0xc0,0x40,0x00,
+/* 63913 0xf9a9 "囹" */
+0x20,0x3f,0x21,0x21,0x22,0x25,0x38,0x20,0x2f,0x20,0x23,0x20,0x20,0x3f,0x20,0x00,
+0x04,0xfe,0x04,0x84,0x44,0x24,0x9c,0x04,0xf4,0x44,0x84,0x84,0x84,0xfc,0x04,0x00,
+/* 63914 0xf9aa "寧" */
+0x01,0x20,0x3f,0x25,0x54,0x27,0x00,0x1f,0x12,0x7f,0x00,0x3f,0x00,0x07,0x01,0x00,
+0x00,0x84,0xfe,0x04,0xa8,0xe4,0x00,0xf8,0x48,0xfe,0x00,0xfc,0x80,0x80,0x00,0x00,
+/* 63915 0xf9ab "嶺" */
+0x10,0x10,0x1f,0x00,0x0b,0x14,0x22,0x49,0x04,0x7f,0x02,0x04,0x38,0x04,0x05,0x00,
+0x84,0x84,0xfc,0x00,0xfe,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x84,0xfc,0x48,0x86,0x00,
+/* 63916 0xf9ac "怜" */
+0x10,0x10,0x10,0x11,0x5a,0x54,0x54,0x90,0x13,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x40,0x40,0xa0,0x10,0x08,0x46,0x22,0x20,0xfc,0x08,0x10,0xa0,0x60,0x30,0x10,0x00,
+/* 63917 0xf9ad "玲" */
+0x00,0x08,0xfc,0x10,0x11,0x12,0x10,0xfc,0x10,0x11,0x14,0x18,0xe0,0x40,0x00,0x00,
+0x20,0x60,0x50,0x88,0x04,0x42,0x22,0x20,0x08,0xfc,0x08,0x10,0xe0,0x10,0x10,0x00,
+/* 63918 0xf9ae "瑩" */
+0x08,0x2a,0x2c,0x48,0x14,0x22,0x7f,0x40,0x3f,0x01,0x01,0x1f,0x01,0x01,0x7f,0x00,
+0x10,0x54,0x58,0x90,0x28,0x44,0xfe,0x04,0xf8,0x00,0x00,0xf8,0x20,0x14,0xfe,0x00,
+/* 63919 0xf9af "羚" */
+0x44,0x24,0x28,0xfe,0x10,0x10,0x7d,0x10,0x10,0xfe,0x10,0x10,0x20,0x40,0x80,0x00,
+0x20,0x20,0x50,0x50,0x88,0xa6,0x12,0x10,0xfc,0x04,0x08,0xd0,0x20,0x10,0x10,0x00,
+/* 63920 0xf9b0 "聆" */
+0x02,0xff,0x24,0x24,0x3c,0x25,0x26,0x3c,0x24,0x25,0x2e,0xf4,0x44,0x04,0x04,0x00,
+0x20,0x20,0x50,0x50,0x88,0x46,0x22,0x20,0x00,0xfc,0x08,0x48,0x30,0x10,0x10,0x00,
+/* 63921 0xf9b1 "鈴" */
+0x10,0x18,0x14,0x22,0x41,0xfe,0x10,0x10,0xfe,0x95,0x58,0x50,0x1e,0xf0,0x40,0x00,
+0x20,0x20,0x50,0x88,0x06,0x42,0x20,0x20,0x04,0xfe,0x08,0x50,0x20,0x10,0x10,0x00,
+/* 63922 0xf9b2 "零" */
+0x1f,0x41,0x7f,0x81,0x3d,0x01,0x3d,0x06,0x19,0xe0,0x0f,0x00,0x00,0x03,0x00,0x00,
+0xf8,0x02,0xfe,0x04,0x78,0x00,0x78,0xc0,0x30,0x8e,0xf0,0x20,0x40,0x80,0x60,0x00,
+/* 63923 0xf9b3 "靈" */
+0x1f,0x41,0x7f,0x81,0x3d,0x01,0x7b,0x4a,0x7b,0x00,0x7f,0x09,0x19,0x25,0xff,0x00,
+0xf8,0x02,0xfe,0x04,0x78,0x00,0xde,0x52,0xde,0x00,0xfc,0x10,0x30,0x48,0xfe,0x00,
+/* 63924 0xf9b4 "領" */
+0x08,0x09,0x08,0x14,0x22,0x49,0x84,0x04,0x7f,0x02,0x24,0x18,0x08,0x08,0x03,0x00,
+0x04,0xfe,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,0x58,0x86,0x00,
+/* 63925 0xf9b5 "例" */
+0x08,0x08,0x0f,0x12,0x12,0x33,0x54,0x96,0x19,0x10,0x10,0x11,0x11,0x12,0x14,0x00,
+0x00,0x42,0xe2,0x12,0x52,0xf2,0x52,0x52,0x52,0x92,0x92,0x12,0x02,0x1e,0x04,0x00,
+/* 63926 0xf9b6 "禮" */
+0x20,0x11,0x11,0xfd,0x05,0x09,0x10,0x33,0x58,0x95,0x15,0x11,0x10,0x10,0x13,0x00,
+0x50,0xfc,0x54,0xfc,0x54,0xfc,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x88,0x50,0xfe,0x00,
+/* 63927 0xf9b7 "醴" */
+0x04,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xab,0xce,0x82,0xfe,0x82,0x82,0xfe,0x83,0x00,
+0x28,0xfe,0xaa,0xfe,0xaa,0xfe,0x00,0xfe,0x00,0xfc,0x84,0xfc,0x84,0x48,0xfe,0x00,
+/* 63928 0xf9b8 "隸" */
+0x10,0x10,0xff,0x18,0x34,0xd3,0x10,0x7d,0x01,0xfe,0x10,0x58,0x97,0xb1,0x10,0x00,
+0x20,0x24,0xfe,0x24,0x24,0xfe,0x24,0xfc,0x24,0xa2,0xb4,0x68,0xa4,0x22,0x62,0x00,
+/* 63929 0xf9b9 "惡" */
+0x00,0x7f,0x02,0x3e,0x20,0x20,0x3e,0x02,0x7f,0x00,0x04,0x24,0x24,0x24,0x43,0x00,
+0x04,0xfe,0x40,0x7c,0x04,0x04,0x7c,0x40,0xfe,0x00,0x80,0x44,0x52,0x12,0xf8,0x00,
+/* 63930 0xf9ba "了" */
+0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x07,0x01,0x00,
+0x08,0xfc,0x08,0x10,0x20,0xc0,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 63931 0xf9bb "僚" */
+0x08,0x08,0x0f,0x10,0x15,0x33,0x56,0x9b,0x12,0x13,0x10,0x12,0x14,0x19,0x10,0x00,
+0x40,0x44,0xfe,0xa2,0x14,0xf8,0x0c,0xfa,0x08,0xf8,0x40,0x48,0x44,0xc2,0x42,0x00,
+/* 63932 0xf9bc "寮" */
+0x01,0x20,0x3f,0x21,0x5f,0x24,0x1f,0x28,0x4f,0x08,0x0f,0x00,0x0c,0x13,0x21,0x00,
+0x00,0x84,0xfe,0x04,0xfc,0x28,0xf0,0x18,0xf6,0x10,0xf0,0x80,0xb0,0x8c,0x04,0x00,
+/* 63933 0xf9bd "尿" */
+0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x12,0x12,0x12,0x24,0x24,0x49,0x40,0x00,
+0x04,0xfe,0x04,0x04,0xfc,0x44,0x40,0x4c,0x68,0x50,0x50,0x48,0x46,0xc2,0x80,0x00,
+/* 63934 0xf9be "料" */
+0x08,0x49,0x49,0x2a,0x28,0x0a,0xff,0x08,0x0c,0x1a,0x2a,0x49,0x88,0x08,0x08,0x00,
+0x08,0x08,0x48,0x28,0x28,0x08,0x48,0x28,0x28,0x0e,0x38,0xc8,0x88,0x08,0x08,0x00,
+/* 63935 0xf9bf "樂" */
+0x21,0x21,0x47,0x54,0xe7,0x24,0x54,0xff,0x45,0x01,0xff,0x05,0x09,0x31,0xc1,0x00,
+0x08,0x08,0xd0,0x54,0xf8,0x48,0x54,0xfe,0x50,0x04,0xfe,0x20,0x10,0x0e,0x04,0x00,
+/* 63936 0xf9c0 "燎" */
+0x10,0x10,0x17,0x14,0x53,0x55,0x5b,0x55,0x91,0x11,0x18,0x25,0x26,0x44,0x88,0x00,
+0x40,0x40,0xfe,0xa2,0x14,0xf8,0x0c,0xfa,0x08,0xf8,0x20,0x28,0x24,0xe2,0x42,0x00,
+/* 63937 0xf9c1 "療" */
+0x00,0x10,0x1f,0x90,0x5f,0x55,0x13,0x12,0x37,0xda,0x93,0x20,0x22,0x45,0x88,0x00,
+0x80,0x44,0xfe,0x40,0xfe,0x14,0xf8,0x0c,0xfa,0x08,0xf8,0x40,0x50,0xc8,0x86,0x00,
+/* 63938 0xf9c2 "蓼" */
+0x04,0x7f,0x04,0x00,0x7e,0x12,0x0e,0x32,0x03,0x0c,0x77,0x00,0x0f,0x00,0x3f,0x00,
+0x20,0xfe,0x20,0x00,0xfc,0x24,0x1c,0x64,0x80,0x60,0x1e,0x60,0x98,0x60,0x80,0x00,
+/* 63939 0xf9c3 "遼" */
+0x00,0x40,0x37,0x12,0x01,0x03,0x15,0xf9,0x11,0x11,0x11,0x12,0x34,0xc8,0x87,0x00,
+0x40,0x44,0xfe,0x94,0x08,0xfc,0x0a,0xf8,0x08,0xf8,0x28,0x26,0xe2,0x40,0xfe,0x00,
+/* 63940 0xf9c4 "龍" */
+0x10,0x08,0x7f,0x22,0x14,0x7f,0x00,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x2e,0x24,0x00,
+0x40,0x44,0x7e,0x40,0x7c,0x04,0x7c,0x40,0x7c,0x40,0x7c,0x40,0x7e,0x42,0x3e,0x00,
+/* 63941 0xf9c5 "暈" */
+0x10,0x1f,0x10,0x1f,0x50,0x7f,0x81,0x7f,0x11,0x1f,0x11,0x1f,0x01,0x7f,0x01,0x00,
+0x10,0xf8,0x10,0xf0,0x12,0xfe,0x04,0xfc,0x10,0xf0,0x10,0xf0,0x00,0xfe,0x00,0x00,
+/* 63942 0xf9c6 "阮" */
+0x44,0x7d,0x44,0x48,0x50,0x53,0x48,0x48,0x44,0x44,0x64,0x59,0x42,0x44,0x48,0x00,
+0x08,0xfc,0x00,0x00,0x04,0xfe,0x90,0x90,0x90,0x90,0x90,0x12,0x12,0x12,0x0e,0x00,
+/* 63943 0xf9c7 "劉" */
+0x18,0x67,0x42,0x4a,0x5a,0x65,0x9e,0x21,0xde,0x04,0x7f,0x24,0x15,0x17,0x7c,0x00,
+0x02,0xc2,0x52,0x52,0x52,0x92,0x12,0x12,0xd2,0x12,0x92,0x92,0x02,0xde,0x04,0x00,
+/* 63944 0xf9c8 "杻" */
+0x10,0x13,0x10,0x10,0xfc,0x10,0x18,0x37,0x54,0x50,0x90,0x90,0x10,0x10,0x17,0x00,
+0x08,0xfc,0x88,0x88,0x88,0x88,0x88,0xf8,0x88,0x88,0x88,0x88,0x88,0x88,0xfe,0x00,
+/* 63945 0xf9c9 "柳" */
+0x10,0x10,0x13,0x12,0xfe,0x12,0x1a,0x36,0x52,0x53,0x92,0x90,0x10,0x11,0x12,0x00,
+0x40,0xd2,0x1e,0x52,0x52,0x52,0x52,0x52,0x52,0xd2,0x52,0x56,0x92,0x10,0x10,0x00,
+/* 63946 0xf9ca "流" */
+0x20,0x10,0x17,0x00,0x40,0x29,0x2b,0x10,0x12,0x62,0x22,0x22,0x62,0x64,0x28,0x00,
+0x80,0x44,0xfe,0x40,0x90,0x08,0xfc,0x04,0x48,0x48,0x48,0x4a,0x4a,0x4a,0x46,0x00,
+/* 63947 0xf9cb "溜" */
+0x40,0x25,0x26,0x04,0x84,0x55,0x56,0x24,0x20,0xc7,0x44,0x47,0xc4,0xc7,0x44,0x00,
+0x80,0xfe,0x12,0x12,0x92,0x62,0x4e,0x84,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x04,0x00,
+/* 63948 0xf9cc "琉" */
+0x00,0x08,0xfd,0x10,0x10,0x10,0x11,0xfc,0x11,0x11,0x15,0x19,0xe2,0x44,0x08,0x00,
+0x40,0x24,0xfe,0x20,0x40,0x88,0xfc,0x04,0x28,0x28,0x28,0x28,0x2a,0x2a,0x26,0x00,
+/* 63949 0xf9cd "留" */
+0x02,0x27,0x38,0x20,0x22,0x7d,0x20,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x00,
+0x00,0x04,0xfe,0x44,0x44,0x5c,0x88,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x08,0x00,
+/* 63950 0xf9ce "硫" */
+0x00,0x04,0xff,0x10,0x10,0x23,0x3c,0x64,0xa4,0x24,0x24,0x24,0x3d,0x22,0x04,0x00,
+0x40,0x24,0xfe,0x40,0x88,0xfc,0x84,0x00,0xa8,0xa8,0xa8,0xa8,0x2a,0x2a,0x26,0x00,
+/* 63951 0xf9cf "紐" */
+0x10,0x10,0x23,0x24,0x44,0xf8,0x10,0x28,0xfd,0x44,0x00,0x28,0x54,0x54,0x87,0x00,
+0x00,0x04,0xfe,0x44,0x44,0x44,0x44,0x44,0xfc,0x84,0x84,0x84,0x84,0x84,0xfe,0x00,
+/* 63952 0xf9d0 "類" */
+0x49,0x2a,0x2a,0x08,0x7f,0x1c,0x2a,0x49,0x0a,0x09,0x7f,0x08,0x14,0x22,0x42,0x00,
+0x04,0xfe,0x10,0x7c,0x44,0x44,0x7c,0x44,0x7c,0x44,0x44,0x7c,0x44,0x28,0xc6,0x00,
+/* 63953 0xf9d1 "六" */
+0x02,0x01,0x01,0x00,0x00,0x7f,0x00,0x00,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x80,0x80,0x04,0xfe,0x00,0x00,0x20,0x20,0x10,0x10,0x08,0x06,0x02,0x00,
+/* 63954 0xf9d2 "戮" */
+0xf7,0x11,0x55,0x33,0x55,0x99,0x08,0x14,0xe3,0x08,0x72,0x0d,0x72,0x0c,0xf1,0x00,
+0x20,0x28,0x24,0x20,0x26,0xf8,0x20,0x22,0xa2,0x24,0x28,0x12,0x2a,0x46,0x82,0x00,
+/* 63955 0xf9d3 "陸" */
+0x88,0xf8,0x8b,0x90,0xa0,0xa7,0x90,0x91,0x8a,0x88,0xc8,0xb3,0x80,0x80,0x8f,0x00,
+0x40,0x48,0xfc,0x40,0x44,0xfe,0x90,0x0c,0x44,0x40,0x48,0xfc,0x40,0x44,0xfe,0x00,
+/* 63956 0xf9d4 "倫" */
+0x08,0x08,0x08,0x11,0x12,0x35,0x50,0x97,0x14,0x14,0x17,0x14,0x14,0x14,0x14,0x00,
+0x40,0x60,0x90,0x08,0x16,0xfa,0x00,0xfe,0x92,0x92,0xfe,0x92,0x92,0x92,0x86,0x00,
+/* 63957 0xf9d5 "崙" */
+0x01,0x21,0x21,0x3f,0x21,0x02,0x0c,0xf7,0x00,0x3f,0x24,0x3f,0x24,0x24,0x24,0x00,
+0x00,0x08,0x08,0xf8,0x08,0x80,0x60,0xde,0x00,0xf8,0x48,0xf8,0x48,0x48,0x18,0x00,
+/* 63958 0xf9d6 "淪" */
+0x20,0x10,0x10,0x01,0x42,0x2d,0x28,0x17,0x14,0x64,0x27,0x24,0x64,0x64,0x24,0x00,
+0x40,0xc0,0xa0,0x10,0x08,0xf6,0x00,0xfc,0xa4,0xa4,0xfc,0xa4,0xa4,0xbc,0x08,0x00,
+/* 63959 0xf9d7 "輪" */
+0x10,0x10,0xfe,0x10,0x7d,0x56,0x54,0x7d,0x55,0x7d,0x55,0x11,0xff,0x11,0x11,0x00,
+0x20,0x20,0x50,0x88,0x06,0xfa,0x00,0xfc,0x54,0x54,0xfc,0x54,0x54,0x54,0x0c,0x00,
+/* 63960 0xf9d8 "律" */
+0x18,0x13,0x20,0x40,0x9f,0x10,0x23,0x60,0xa0,0x23,0x20,0x20,0x27,0x20,0x20,0x00,
+0x48,0xfc,0x48,0x48,0xfe,0x48,0xf8,0x48,0x40,0xfc,0x40,0x44,0xfe,0x40,0x40,0x00,
+/* 63961 0xf9d9 "慄" */
+0x10,0x17,0x10,0x13,0x5a,0x56,0x53,0x92,0x10,0x17,0x10,0x11,0x11,0x12,0x14,0x00,
+0x04,0xfe,0x90,0xfe,0x92,0x92,0xfe,0x02,0x24,0xfe,0x20,0xb0,0x28,0x26,0x22,0x00,
+/* 63962 0xf9da "栗" */
+0x00,0x7f,0x02,0x1f,0x12,0x12,0x1f,0x10,0x00,0x7f,0x02,0x04,0x08,0x10,0x60,0x00,
+0x04,0xfe,0x40,0xf8,0x48,0x48,0xf8,0x88,0x84,0xfe,0xc0,0xa0,0x90,0x8e,0x84,0x00,
+/* 63963 0xf9db "率" */
+0x01,0x00,0x7f,0x01,0x22,0x17,0x01,0x1a,0x67,0x45,0x01,0x7f,0x01,0x01,0x01,0x00,
+0x00,0x84,0xfe,0x04,0x48,0x90,0x00,0x50,0xec,0x24,0x00,0xfe,0x00,0x00,0x00,0x00,
+/* 63964 0xf9dc "隆" */
+0x89,0xfd,0x8a,0x90,0xa0,0xa1,0x96,0x91,0x88,0x89,0xcb,0xb4,0x81,0x80,0x87,0x00,
+0x08,0xfc,0x08,0x90,0x60,0x98,0x06,0xf8,0x00,0x28,0xfc,0x20,0xfc,0x20,0xfe,0x00,
+/* 63965 0xf9dd "利" */
+0x01,0x07,0x7c,0x04,0x04,0xff,0x04,0x0e,0x15,0x24,0x44,0x84,0x04,0x04,0x04,0x00,
+0x02,0x82,0x12,0x12,0x92,0xd2,0x12,0x12,0x12,0x92,0x92,0x02,0x12,0x0e,0x04,0x00,
+/* 63966 0xf9de "吏" */
+0x00,0x00,0x7f,0x00,0x10,0x1f,0x10,0x10,0x1f,0x10,0x08,0x04,0x03,0x04,0x78,0x00,
+0x80,0x84,0xfe,0x80,0x84,0xfe,0x84,0x84,0xfc,0x84,0x80,0x80,0x00,0xc0,0x3e,0x00,
+/* 63967 0xf9df "履" */
+0x3f,0x20,0x3f,0x20,0x24,0x29,0x32,0x22,0x24,0x2c,0x34,0x24,0x25,0x44,0x85,0x00,
+0xfc,0x04,0xfc,0x80,0xfe,0x84,0xfc,0x84,0xfc,0x40,0x7c,0xc8,0x30,0x48,0x86,0x00,
+/* 63968 0xf9e0 "易" */
+0x08,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x04,0x0f,0x11,0x22,0x44,0x08,0x11,0x02,0x00,
+0x10,0xf8,0x10,0xf0,0x10,0xf0,0x10,0x04,0xfe,0x24,0x24,0x44,0x84,0x38,0x10,0x00,
+/* 63969 0xf9e1 "李" */
+0x01,0x01,0x7f,0x05,0x09,0x11,0x61,0x0f,0x00,0x00,0x7f,0x00,0x04,0x03,0x01,0x00,
+0x00,0x04,0xfe,0x40,0x20,0x18,0x06,0xf0,0x40,0x84,0xfe,0x80,0x80,0x80,0x00,0x00,
+/* 63970 0xf9e2 "梨" */
+0x03,0x3c,0x04,0x7f,0x0c,0x16,0x25,0x44,0x00,0x7f,0x02,0x04,0x08,0x10,0x20,0x00,
+0x04,0x24,0x24,0xa4,0x24,0x24,0x1c,0x88,0x84,0xfe,0xc0,0xa0,0x90,0x8e,0x84,0x00,
+/* 63971 0xf9e3 "泥" */
+0x22,0x13,0x12,0x02,0x43,0x2a,0x2a,0x12,0x12,0x62,0x22,0x24,0x64,0x68,0x30,0x00,
+0x04,0xfe,0x04,0x04,0xfc,0x04,0x40,0x4c,0x48,0x50,0x60,0x40,0x42,0x42,0x3e,0x00,
+/* 63972 0xf9e4 "理" */
+0x01,0x09,0xfd,0x11,0x11,0x11,0x11,0xfd,0x11,0x10,0x14,0x19,0xe0,0x40,0x07,0x00,
+0x04,0xfe,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x20,0x20,0xfc,0x20,0x24,0xfe,0x00,
+/* 63973 0xf9e5 "痢" */
+0x01,0x10,0x1f,0x90,0x51,0x57,0x11,0x17,0x31,0xd1,0x93,0x25,0x29,0x41,0x81,0x00,
+0x00,0x84,0xfe,0x80,0xc2,0x12,0x12,0xd2,0x12,0x92,0x52,0x52,0x02,0x1e,0x04,0x00,
+/* 63974 0xf9e6 "罹" */
+0x3f,0x22,0x22,0x3f,0x20,0x11,0x11,0x5b,0x55,0x91,0x11,0x11,0x11,0x11,0x11,0x00,
+0xfc,0x44,0x44,0xfc,0x44,0x20,0xfe,0x20,0x20,0xfc,0x20,0xfc,0x20,0x24,0xfe,0x00,
+/* 63975 0xf9e7 "裏" */
+0x01,0x7f,0x00,0x0f,0x08,0x0f,0x08,0x3f,0x00,0x7f,0x02,0x04,0x1c,0x65,0x06,0x00,
+0x04,0xfe,0x00,0xf8,0x88,0xf8,0x88,0xfc,0x80,0xfe,0x88,0x50,0xa0,0x18,0x06,0x00,
+/* 63976 0xf9e8 "裡" */
+0x41,0x21,0x29,0xfd,0x09,0x11,0x25,0x29,0x71,0xac,0x24,0x21,0x20,0x20,0x27,0x00,
+0x04,0xfe,0x24,0x24,0xfc,0x24,0x24,0xfc,0x24,0x20,0x20,0xfc,0x20,0x24,0xfe,0x00,
+/* 63977 0xf9e9 "里" */
+0x10,0x1f,0x11,0x11,0x1f,0x11,0x11,0x1f,0x11,0x01,0x01,0x3f,0x01,0x01,0x7f,0x00,
+0x08,0xfc,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,0x00,0x08,0xfc,0x00,0x04,0xfe,0x00,
+/* 63978 0xf9ea "離" */
+0x10,0x08,0xff,0x55,0x49,0x49,0x55,0x7f,0x08,0x7f,0x49,0x55,0x7b,0x41,0x47,0x00,
+0x50,0x48,0xc8,0x7e,0x48,0xc8,0x7e,0x48,0x48,0x48,0x7e,0x48,0x48,0x7e,0x40,0x00,
+/* 63979 0xf9eb "匿" */
+0x40,0x7f,0x42,0x42,0x5f,0x42,0x41,0x5f,0x42,0x47,0x4a,0x52,0x43,0x42,0x7f,0x00,
+0x04,0xfe,0x20,0x20,0xfc,0xa0,0x04,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0xfe,0x00,
+/* 63980 0xf9ec "溺" */
+0x40,0x27,0x20,0x00,0x87,0x54,0x54,0x27,0x28,0xc4,0x41,0x46,0xd8,0xc7,0x42,0x00,
+0x82,0xbe,0x82,0x82,0x9e,0x92,0x10,0xbe,0xa2,0x92,0x86,0x9a,0xe2,0x1c,0x08,0x00,
+/* 63981 0xf9ed "吝" */
+0x01,0x00,0x7f,0x08,0x04,0x02,0x01,0x0e,0x70,0x1f,0x10,0x10,0x10,0x1f,0x10,0x00,
+0x00,0x84,0xfe,0x10,0x20,0x40,0x80,0x70,0x0e,0xf8,0x08,0x08,0x08,0xf8,0x08,0x00,
+/* 63982 0xf9ee "燐" */
+0x12,0x11,0x10,0x13,0x54,0x59,0x52,0x51,0x91,0x12,0x19,0x24,0x25,0x42,0x84,0x00,
+0x22,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x08,0xde,0x48,0xa8,0xbe,0x08,0x08,0x08,0x00,
+/* 63983 0xf9ef "璘" */
+0x02,0x11,0xf8,0x23,0x20,0x21,0x22,0xfa,0x23,0x22,0x26,0x39,0xe1,0x42,0x04,0x00,
+0x22,0x24,0xa8,0xfe,0xa8,0x24,0x22,0x08,0xbe,0x88,0xa8,0xfe,0x08,0x08,0x08,0x00,
+/* 63984 0xf9f0 "藺" */
+0x04,0x7f,0x04,0x3e,0x22,0x3e,0x22,0x3e,0x27,0x2c,0x37,0x24,0x27,0x24,0x27,0x00,
+0x20,0xfe,0x20,0x7c,0x44,0x7c,0x44,0x7c,0xe4,0x84,0xe4,0x84,0xe4,0x9c,0xe8,0x00,
+/* 63985 0xf9f1 "隣" */
+0x8a,0xf9,0x89,0x97,0xa1,0xa2,0x9c,0x92,0x8b,0x8c,0xca,0xb1,0x82,0x84,0x88,0x00,
+0x4c,0x48,0x50,0xfe,0x50,0x48,0x46,0x08,0xbe,0x88,0xa8,0x3e,0x08,0x08,0x08,0x00,
+/* 63986 0xf9f2 "鱗" */
+0x21,0x3d,0x24,0x4b,0xfc,0x55,0x56,0x7d,0x55,0x55,0x7f,0x44,0x54,0xab,0xaa,0x00,
+0x24,0x24,0xa8,0xfc,0xa8,0x24,0x22,0x08,0xfe,0x48,0x48,0xe8,0xbe,0x08,0x08,0x00,
+/* 63987 0xf9f3 "麟" */
+0x08,0x44,0x7f,0x54,0x7f,0x55,0x55,0x7f,0x54,0x54,0x5d,0x56,0x54,0x5d,0x97,0x00,
+0xa4,0x64,0x28,0xfe,0x28,0x64,0xa2,0x04,0xee,0xa4,0x24,0xb4,0x5e,0x84,0x04,0x00,
+/* 63988 0xf9f4 "林" */
+0x08,0x08,0x08,0x08,0x7f,0x08,0x08,0x1c,0x2a,0x29,0x49,0x4a,0x0c,0x08,0x08,0x00,
+0x20,0x20,0x20,0x24,0xfe,0x20,0x20,0xb0,0xa8,0x28,0x24,0x24,0x22,0x22,0x20,0x00,
+/* 63989 0xf9f5 "淋" */
+0x42,0x22,0x22,0x02,0x8f,0x52,0x53,0x22,0x26,0xca,0x52,0x52,0xc2,0xc2,0x42,0x00,
+0x10,0x10,0x10,0x94,0xfe,0x10,0x10,0x90,0xb8,0x54,0x52,0x12,0x10,0x10,0x10,0x00,
+/* 63990 0xf9f6 "臨" */
+0x84,0xfe,0x90,0x91,0x92,0xfc,0x84,0x84,0x84,0xff,0x92,0x92,0x92,0xff,0x82,0x00,
+0x80,0x84,0xfe,0x00,0xf8,0x88,0x88,0xf8,0x00,0xde,0x52,0x52,0x52,0xde,0x52,0x00,
+/* 63991 0xf9f7 "立" */
+0x02,0x01,0x00,0x00,0x3f,0x00,0x08,0x08,0x04,0x04,0x02,0x02,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x80,0x88,0xfc,0x00,0x10,0x10,0x20,0x20,0x40,0x40,0x84,0xfe,0x00,0x00,
+/* 63992 0xf9f8 "笠" */
+0x10,0x10,0x1f,0x28,0x44,0x01,0x00,0x00,0x3f,0x04,0x04,0x02,0x02,0x00,0x7f,0x00,
+0x20,0x20,0x3e,0x50,0x88,0x00,0x80,0x88,0xfc,0x20,0x20,0x40,0x40,0x84,0xfe,0x00,
+/* 63993 0xf9f9 "粒" */
+0x10,0x92,0x92,0x54,0x55,0x10,0xfe,0x10,0x18,0x34,0x52,0x52,0x90,0x90,0x13,0x00,
+0x40,0x20,0x20,0x04,0xfe,0x00,0x84,0x84,0x88,0x48,0x48,0x50,0x10,0x10,0xfe,0x00,
+/* 63994 0xf9fa "狀" */
+0x04,0x24,0x24,0x24,0x24,0x3f,0x04,0x04,0x7c,0x24,0x24,0x24,0x24,0x45,0x86,0x00,
+0x40,0x50,0x48,0x48,0x40,0xfe,0x50,0x50,0x50,0x50,0x48,0x48,0x84,0x06,0x02,0x00,
+/* 63995 0xf9fb "炙" */
+0x02,0x02,0x07,0x0c,0x32,0x08,0x07,0x0c,0x70,0x08,0x08,0x11,0x02,0x0c,0x30,0x00,
+0x00,0x10,0xf8,0x20,0x40,0x80,0x00,0x80,0x98,0x90,0xa0,0x40,0x20,0x18,0x06,0x00,
+/* 63996 0xf9fc "識" */
+0x21,0x10,0x13,0xfd,0x01,0x00,0x7b,0x00,0x7b,0x02,0x7b,0x4a,0x4b,0x7a,0x48,0x00,
+0x10,0x90,0xf4,0x52,0x52,0x90,0xfe,0x10,0xd2,0x52,0xd4,0x48,0xca,0x56,0x22,0x00,
+/* 63997 0xf9fd "什" */
+0x08,0x08,0x08,0x10,0x10,0x30,0x57,0x90,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0xfe,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+/* 63998 0xf9fe "茶" */
+0x04,0x04,0x7f,0x04,0x05,0x02,0x04,0x18,0x60,0x1f,0x00,0x04,0x08,0x10,0x60,0x00,
+0x20,0x20,0xfe,0x20,0x80,0x40,0x20,0x98,0x86,0xf8,0x80,0xa0,0x90,0x8e,0x84,0x00,
+/* 63999 0xf9ff "刺" */
+0x08,0x08,0xff,0x08,0x88,0xff,0x88,0x88,0x8b,0x88,0x1c,0x2a,0x49,0x88,0x08,0x00,
+0x02,0x82,0xd2,0x12,0x92,0xd2,0x92,0x92,0x92,0x92,0x12,0x02,0x92,0x8e,0x04,0x00,
+/* 64000 0xfa00 "切" */
+0x20,0x20,0x23,0x20,0x24,0x2e,0xf0,0x20,0x22,0x24,0x28,0x30,0x21,0x02,0x04,0x00,
+0x00,0x04,0xfe,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x84,0x44,0x38,0x10,0x00,
+/* 64001 0xfa01 "度" */
+0x01,0x20,0x3f,0x22,0x22,0x3f,0x22,0x23,0x20,0x27,0x22,0x21,0x20,0x43,0x9c,0x00,
+0x00,0x84,0xfe,0x20,0x24,0xfe,0x20,0xe0,0x00,0xf8,0x10,0x20,0xc0,0x30,0x0e,0x00,
+/* 64002 0xfa02 "拓" */
+0x10,0x10,0x13,0xfc,0x10,0x10,0x14,0x19,0xf2,0x54,0x10,0x10,0x90,0x70,0x20,0x00,
+0x00,0x04,0xfe,0x40,0x40,0x40,0x84,0xfe,0x84,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 64003 0xfa03 "糖" */
+0x10,0x11,0x95,0x55,0x59,0x11,0xfd,0x11,0x19,0x35,0x55,0x92,0x12,0x14,0x18,0x00,
+0x40,0x24,0xfe,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0xfc,0x84,0x84,0xfc,0x84,0x00,
+/* 64004 0xfa04 "宅" */
+0x02,0x41,0x7f,0x40,0x80,0x01,0x7e,0x04,0x04,0x07,0xfc,0x04,0x04,0x04,0x03,0x00,
+0x00,0x08,0xfc,0x08,0x90,0xc0,0x00,0x10,0x38,0xc0,0x00,0x04,0x04,0x06,0xfc,0x00,
+/* 64005 0xfa05 "洞" */
+0x22,0x13,0x12,0x02,0x46,0x2a,0x2a,0x12,0x12,0x62,0x22,0x22,0x62,0x62,0x22,0x00,
+0x04,0xfe,0x04,0x04,0xf4,0x04,0x04,0xf4,0x94,0x94,0xf4,0x94,0x04,0x1c,0x08,0x00,
+/* 64006 0xfa06 "暴" */
+0x1f,0x10,0x1f,0x10,0x1f,0x04,0x3f,0x04,0x7f,0x11,0x29,0x47,0x05,0x19,0x63,0x00,
+0xf0,0x10,0xf0,0x10,0xf0,0x40,0xfc,0x40,0xfe,0x10,0x28,0x44,0xc0,0x30,0x0c,0x00,
+/* 64007 0xfa07 "輻" */
+0x11,0x10,0xfe,0x10,0x7c,0x54,0x7c,0x55,0x7d,0x55,0x11,0xff,0x11,0x11,0x11,0x00,
+0xfe,0x00,0xfc,0x84,0x84,0xfc,0x00,0xfe,0x22,0x22,0xfe,0x22,0x22,0xfe,0x02,0x00,
+/* 64008 0xfa08 "行" */
+0x18,0x11,0x20,0x40,0x0c,0x0b,0x10,0x30,0x50,0x90,0x10,0x10,0x10,0x10,0x10,0x00,
+0x08,0xfc,0x00,0x00,0x04,0xfe,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0x70,0x20,0x00,
+/* 64009 0xfa09 "降" */
+0x44,0x7c,0x44,0x49,0x50,0x50,0x4b,0x48,0x45,0x44,0x65,0x5b,0x40,0x40,0x40,0x00,
+0x88,0xfc,0x88,0x50,0x20,0x50,0x8e,0x20,0xfc,0xa0,0x24,0xfe,0x20,0x20,0x20,0x00,
+/* 64010 0xfa0a "見" */
+0x00,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x10,0x10,0x1f,0x14,0x08,0x30,0xc0,0x00,
+0x20,0xf0,0x20,0x20,0xe0,0x20,0x20,0xe0,0x20,0x20,0xe0,0xa4,0x84,0x86,0x7c,0x00,
+/* 64011 0xfa0b "廓" */
+0x20,0x3f,0x22,0x3f,0x20,0x2f,0x28,0x2f,0x20,0x3f,0x21,0x22,0x2f,0x42,0x8e,0x00,
+0x84,0xfe,0x00,0xde,0x12,0x94,0x94,0x98,0x14,0xd2,0x12,0x1a,0x94,0x10,0x10,0x00,
+/* 64012 0xfa0c "兀" */
+0x00,0xff,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,
+0x08,0xfc,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x84,0x84,0x86,0x7c,0x00,0x00,
+/* 64013 0xfa0d "嗀" */
+0x08,0x08,0x7f,0x08,0x3f,0x00,0x7f,0x82,0x3e,0x00,0x3e,0x22,0x22,0x3e,0x22,0x00,
+0x48,0x7c,0x48,0x48,0x48,0x8e,0x00,0xfe,0x44,0x44,0x28,0x10,0x28,0x46,0x82,0x00,
+/* 64014 0xfa0e "﨎" */
+0x10,0x08,0xfe,0x45,0x26,0x18,0x08,0x14,0x24,0xc0,0x3f,0x08,0x04,0x03,0x0c,0xf0,
+0x50,0x48,0xfe,0x90,0xfc,0x90,0xfc,0x90,0xfe,0x80,0xf0,0x20,0x40,0x80,0x60,0x1c,
+/* 64015 0xfa0f "﨏" */
+0x20,0x20,0x21,0x22,0xf8,0x20,0x20,0x21,0x22,0x25,0x21,0x39,0xc1,0x01,0x01,0x01,
+0x90,0x88,0x04,0x40,0x40,0xa0,0x90,0x08,0x04,0xfa,0x08,0x08,0x08,0x08,0xf8,0x08,
+/* 64016 0xfa10 "塚" */
+0x12,0x13,0x14,0x10,0x13,0xfc,0x10,0x17,0x12,0x11,0x1e,0xe0,0x41,0x06,0x00,0x00,
+0x02,0xfe,0x04,0x00,0xfe,0x40,0x86,0x44,0xa8,0x30,0xe8,0xa8,0x24,0x22,0xc0,0x00,
+/* 64017 0xfa11 "﨑" */
+0x20,0x20,0x2b,0xa8,0xa9,0xa8,0xaf,0xa8,0xab,0xaa,0xaa,0xbb,0xca,0x00,0x00,0x00,
+0x40,0x20,0xfe,0x00,0x08,0x90,0xfe,0x08,0xc8,0x48,0x48,0xc8,0x48,0x08,0x28,0x10,
+/* 64018 0xfa12 "晴" */
+0x00,0x4b,0x7c,0x49,0x48,0x4f,0x78,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,0x00,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x1c,0x08,0x00,
+/* 64019 0xfa13 "﨓" */
+0x10,0x10,0x13,0x10,0xfc,0x10,0x38,0x35,0x51,0x53,0x95,0x11,0x11,0x11,0x11,0x11,
+0x88,0x88,0xfe,0x88,0x88,0x44,0x84,0x7e,0x04,0x24,0x14,0x14,0x04,0x04,0x14,0x08,
+/* 64020 0xfa14 "﨔" */
+0x12,0x11,0x10,0x13,0xfc,0x11,0x3a,0x34,0x50,0x51,0x90,0x13,0x10,0x10,0x10,0x10,
+0x44,0x24,0x88,0xfe,0x90,0x08,0x14,0xe2,0x20,0xf8,0x20,0xfc,0x20,0x20,0xa0,0x40,
+/* 64021 0xfa15 "凞" */
+0x8b,0x6a,0x2a,0x0a,0x1b,0x2a,0x2a,0xcb,0x4a,0x52,0x63,0x00,0x24,0x22,0x42,0x00,
+0xd4,0x9e,0x94,0x94,0xd4,0x5c,0x54,0xd0,0x92,0x92,0xee,0x00,0x44,0x22,0x22,0x00,
+/* 64022 0xfa16 "猪" */
+0x00,0x4c,0x28,0x11,0x30,0x48,0x8b,0x18,0x29,0x4b,0x89,0x09,0x49,0x39,0x11,0x00,
+0x40,0x40,0x46,0xf4,0x48,0x50,0xfe,0x40,0xfc,0x04,0x04,0xfc,0x04,0xfc,0x04,0x00,
+/* 64023 0xfa17 "益" */
+0x08,0x04,0x02,0x02,0x7f,0x04,0x08,0x10,0x60,0x1f,0x12,0x12,0x12,0x12,0x7f,0x00,
+0x30,0x20,0x40,0x44,0xfe,0x20,0x10,0x0c,0x04,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 64024 0xfa18 "礼" */
+0x00,0x3e,0x00,0x00,0x7f,0x08,0x2a,0x2a,0x2a,0x2a,0x4a,0x4a,0x08,0x08,0x08,0x00,
+0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x3e,0x00,
+/* 64025 0xfa19 "神" */
+0x20,0x10,0x11,0xfd,0x05,0x09,0x11,0x31,0x59,0x95,0x15,0x11,0x10,0x10,0x10,0x00,
+0x20,0x20,0x24,0xfe,0x24,0x24,0xfc,0x24,0x24,0x24,0xfc,0x24,0x20,0x20,0x20,0x00,
+/* 64026 0xfa1a "祥" */
+0x21,0x10,0x10,0xff,0x04,0x08,0x10,0x31,0x58,0x94,0x14,0x13,0x10,0x10,0x10,0x00,
+0x0c,0x88,0x50,0xfe,0x20,0x20,0x20,0xfc,0x20,0x20,0x24,0xfe,0x20,0x20,0x20,0x00,
+/* 64027 0xfa1b "福" */
+0x20,0x13,0x10,0xfc,0x04,0x08,0x10,0x30,0x59,0x95,0x15,0x11,0x11,0x11,0x11,0x00,
+0x04,0xfe,0x00,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x24,0xfc,0x24,0x24,0xfc,0x04,0x00,
+/* 64028 0xfa1c "靖" */
+0x20,0x23,0x10,0x11,0xfc,0x03,0x44,0x45,0x29,0x29,0x11,0x1d,0xe1,0x41,0x01,0x00,
+0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x1c,0x08,0x00,
+/* 64029 0xfa1d "精" */
+0x10,0x13,0x92,0x54,0x54,0x11,0xfe,0x10,0x18,0x34,0x52,0x92,0x10,0x10,0x10,0x00,
+0x24,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x84,0xfc,0x84,0xfc,0x84,0x9c,0x88,0x00,
+/* 64030 0xfa1e "羽" */
+0x02,0x7f,0x0e,0x12,0x22,0x42,0x06,0x0a,0x12,0x22,0x42,0x02,0x12,0x0e,0x04,0x00,
+0x04,0xfe,0x1c,0x14,0x24,0x44,0x0c,0x14,0x24,0x44,0x84,0x04,0x24,0x1c,0x08,0x00,
+/* 64031 0xfa1f "﨟" */
+0x04,0xff,0x04,0x04,0x3e,0x22,0x22,0x3e,0x22,0x22,0x3e,0x23,0x22,0x42,0x4a,0x84,
+0x40,0xfe,0x40,0x40,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfe,0x22,0xd2,0x8a,0xf2,0x0c,
+/* 64032 0xfa20 "蘒" */
+0x08,0xff,0x08,0x1c,0xf1,0x12,0x10,0xfc,0x10,0x31,0x39,0x55,0x55,0x91,0x10,0x10,
+0x20,0xfe,0xa0,0xf0,0x10,0xf8,0xa8,0xf8,0xa8,0xfc,0x24,0xfc,0x24,0xfc,0x22,0x1e,
+/* 64033 0xfa21 "﨡" */
+0x20,0x21,0x21,0xf9,0xaa,0xac,0xa8,0xa8,0xa9,0xf8,0xa8,0x20,0x28,0x38,0xcb,0x00,
+0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,0xfe,0x00,
+/* 64034 0xfa22 "諸" */
+0x20,0x10,0x10,0xfd,0x00,0x00,0x7b,0x00,0x79,0x02,0x78,0x48,0x48,0x78,0x48,0x00,
+0x40,0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x00,
+/* 64035 0xfa23 "﨣" */
+0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0xfe,0x11,0x10,0x5c,0x50,0x50,0x70,0x8c,0x83,
+0x08,0x48,0x28,0x08,0x88,0x48,0x08,0x0e,0xf8,0x08,0x08,0x08,0x08,0x08,0x00,0xfe,
+/* 64036 0xfa24 "﨤" */
+0x00,0x23,0x10,0x08,0x40,0x20,0x10,0x00,0xf0,0x11,0x11,0x12,0x14,0x28,0x44,0x83,
+0x00,0xfc,0x88,0x88,0x90,0xbc,0x84,0x84,0xc4,0x48,0x28,0x10,0x28,0x44,0x82,0xfe,
+/* 64037 0xfa25 "逸" */
+0x01,0x41,0x31,0x12,0x07,0x02,0x12,0xfb,0x10,0x10,0x11,0x16,0x30,0xc8,0x87,0x00,
+0x10,0xf8,0x10,0x24,0xfe,0x44,0x44,0xfc,0x60,0xa8,0x26,0x22,0x1e,0x00,0xfe,0x00,
+/* 64038 0xfa26 "都" */
+0x08,0x08,0x3e,0x09,0x0a,0x7f,0x04,0x09,0x1f,0x31,0x5f,0x11,0x11,0x1f,0x11,0x00,
+0x24,0xbe,0xa4,0x24,0x28,0xe8,0x28,0x24,0xa4,0x22,0x22,0x32,0x2c,0x20,0x20,0x00,
+/* 64039 0xfa27 "﨧" */
+0x10,0x10,0x29,0x44,0xb8,0x13,0x10,0x7c,0x10,0x13,0x54,0x39,0x10,0x1c,0xe0,0x00,
+0x20,0x20,0xfe,0x24,0x28,0xfe,0x20,0x40,0xfc,0x08,0x10,0xfe,0x10,0x10,0x50,0x20,
+/* 64040 0xfa28 "﨨" */
+0x10,0x10,0x29,0x44,0xb8,0x17,0x11,0x7c,0x11,0x10,0x54,0x3b,0x10,0x1c,0xe0,0x00,
+0x20,0x20,0xfc,0x20,0x20,0xfe,0x04,0x88,0xfc,0x20,0x20,0xfe,0x20,0x20,0x20,0x20,
+/* 64041 0xfa29 "﨩" */
+0x00,0x7c,0x45,0x49,0x49,0x51,0x51,0x49,0x45,0x45,0x45,0x58,0x44,0x47,0x40,0x40,
+0x40,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfe,0x00,0xfc,0x84,0x94,0xf4,0x04,0x18,
+/* 64042 0xfa2a "飯" */
+0x10,0x18,0x14,0x2a,0x48,0xbe,0x22,0x3e,0x22,0x3e,0x20,0x24,0x26,0x7b,0x22,0x00,
+0x08,0x9c,0xe0,0x80,0x84,0xfe,0xa4,0xa4,0xa8,0xa8,0xa8,0x90,0xa8,0x46,0x82,0x00,
+/* 64043 0xfa2b "飼" */
+0x10,0x19,0x14,0x2a,0x48,0xbe,0x22,0x3e,0x22,0x3e,0x20,0x24,0x26,0x7a,0x20,0x00,
+0x00,0xfe,0x02,0x02,0xfa,0x02,0xf2,0x92,0x92,0x92,0xf2,0x92,0x02,0x1e,0x04,0x00,
+/* 64044 0xfa2c "館" */
+0x10,0x18,0x14,0x2a,0x49,0xbe,0x22,0x3e,0x22,0x3e,0x20,0x24,0x26,0x7a,0x20,0x00,
+0x20,0x10,0x92,0xfe,0x04,0xf8,0x88,0x88,0xf8,0x80,0xfc,0x84,0x84,0xfc,0x84,0x00,
+/* 64045 0xfa2d "鶴" */
+0x10,0x10,0x92,0xfe,0xa2,0x28,0x7e,0x48,0xfe,0x48,0x7e,0x48,0x48,0x7f,0x41,0x00,
+0x30,0x20,0xfc,0x84,0xfc,0x84,0xfc,0x80,0xfe,0x80,0xfe,0x02,0xaa,0x56,0x54,0x00,
+/* 64046 0xfa2e "郞" */
+0x08,0x08,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x51,0x4a,0x44,0x44,0x52,0x62,0x40,
+0x00,0x7c,0x44,0x48,0x48,0x50,0x48,0x48,0x44,0x44,0x44,0x68,0x50,0x40,0x40,0x40,
+/* 64047 0xfa2f "隷" */
+0x10,0x10,0xfc,0x10,0x11,0x7c,0x00,0x7c,0x01,0xfc,0x10,0x54,0x53,0x92,0x10,0x30,
+0x20,0x20,0xfc,0x24,0xfe,0x24,0xfc,0x20,0x24,0xa8,0x70,0xa8,0x24,0x22,0xa0,0x40,
+/* 64048 0xfa30 "侮" */
+0x09,0x09,0x0b,0x14,0x13,0x32,0x52,0x92,0x1f,0x12,0x12,0x12,0x17,0x10,0x10,0x00,
+0x00,0x04,0xfe,0x00,0xf8,0x88,0x48,0x08,0xfe,0x88,0x48,0x08,0xfe,0x08,0x70,0x00,
+/* 64049 0xfa31 "僧" */
+0x09,0x08,0x08,0x13,0x12,0x33,0x52,0x93,0x10,0x11,0x11,0x11,0x11,0x11,0x11,0x00,
+0x08,0x90,0x10,0xfe,0x22,0x26,0xaa,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,
+/* 64050 0xfa32 "免" */
+0x08,0x08,0x1f,0x10,0x21,0x7f,0xa2,0x22,0x22,0x3f,0x22,0x04,0x08,0x30,0xc0,0x00,
+0x00,0x80,0xc0,0x80,0x10,0xf8,0x10,0x10,0x10,0xf0,0x90,0x84,0x84,0x86,0x7c,0x00,
+/* 64051 0xfa33 "勉" */
+0x20,0x22,0x3f,0x22,0x44,0xff,0x49,0x49,0x7f,0x49,0x08,0x18,0x29,0x48,0x87,0x00,
+0x20,0x20,0x20,0x24,0xfe,0x24,0x24,0x24,0x24,0x44,0x44,0x84,0x1a,0x02,0xfe,0x00,
+/* 64052 0xfa34 "勤" */
+0x22,0xff,0x22,0x3e,0x08,0x7f,0x49,0x7f,0x08,0xff,0x08,0x7f,0x08,0x0f,0xf1,0x00,
+0x20,0xa0,0x20,0x24,0xfe,0x24,0x24,0x24,0x24,0xa4,0x44,0x44,0xa4,0x9c,0x08,0x00,
+/* 64053 0xfa35 "卑" */
+0x01,0x22,0x3f,0x20,0x20,0x3f,0x21,0x3f,0x22,0x04,0x08,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x08,0xfc,0x88,0x88,0xf8,0x08,0xf8,0x88,0x80,0x84,0xfe,0x80,0x80,0x80,0x00,
+/* 64054 0xfa36 "喝" */
+0x02,0x93,0xfa,0x93,0x92,0x93,0x92,0x91,0x93,0x96,0xfa,0x92,0x02,0x03,0x00,0x00,
+0x08,0xfc,0x08,0xf8,0x08,0xf8,0x88,0x02,0xfe,0x22,0x22,0x52,0x8a,0xf2,0x1c,0x00,
+/* 64055 0xfa37 "嘆" */
+0x01,0x97,0xf9,0x91,0x90,0x97,0x94,0x97,0x90,0x97,0xf0,0x9f,0x00,0x03,0x0c,0x00,
+0x10,0xfe,0x10,0xf0,0x40,0xfc,0x44,0xfc,0x40,0xfc,0x40,0xfe,0xa0,0x18,0x06,0x00,
+/* 64056 0xfa38 "器" */
+0x22,0x3f,0x22,0x22,0x3e,0x01,0x02,0x7f,0x08,0x12,0x7f,0x22,0x22,0x3e,0x22,0x00,
+0x44,0x7e,0x44,0x44,0x7c,0x20,0x14,0xfe,0x10,0x08,0x7e,0x44,0x44,0x7c,0x44,0x00,
+/* 64057 0xfa39 "塀" */
+0x11,0x11,0x11,0x11,0xfd,0x11,0x11,0x11,0x15,0x19,0xe2,0x42,0x04,0x09,0x00,0x00,
+0xfe,0x02,0x02,0xfe,0x44,0x28,0xfe,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,0x00,0x00,
+/* 64058 0xfa3a "墨" */
+0x10,0x1f,0x14,0x12,0x1f,0x00,0x1f,0x00,0x7f,0x14,0x12,0x20,0x1f,0x00,0x7f,0x00,
+0x08,0xfc,0xa8,0xa8,0xf8,0x80,0xfc,0x80,0xfe,0x48,0xa6,0x82,0xf8,0x84,0xfe,0x00,
+/* 64059 0xfa3b "層" */
+0x3f,0x20,0x20,0x3f,0x22,0x21,0x2f,0x2a,0x29,0x2f,0x24,0x27,0x44,0x47,0x84,0x00,
+0xfc,0x04,0x04,0xfc,0x24,0x40,0xfc,0x94,0x24,0xfc,0x08,0xf8,0x08,0xf8,0x08,0x00,
+/* 64060 0xfa3c "屮" */
+0x01,0x01,0x01,0x21,0x21,0x21,0x21,0x21,0x3f,0x21,0x01,0x01,0x02,0x0c,0x70,0x00,
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0xfc,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64061 0xfa3d "悔" */
+0x12,0x12,0x13,0x14,0x5b,0x52,0x52,0x92,0x1f,0x12,0x12,0x12,0x17,0x10,0x10,0x00,
+0x00,0x04,0xfe,0x00,0xf8,0x88,0x48,0x48,0xfe,0x88,0x48,0x48,0xfe,0x08,0x70,0x00,
+/* 64062 0xfa3e "慨" */
+0x20,0x24,0x27,0x24,0xb4,0xaf,0xa4,0x27,0x24,0x25,0x24,0x25,0x2e,0x24,0x21,0x00,
+0x04,0xbe,0x88,0xa8,0xa8,0xa8,0xa8,0xfe,0x10,0x18,0x98,0xa8,0x4a,0x8a,0x0e,0x00,
+/* 64063 0xfa3f "憎" */
+0x11,0x10,0x10,0x13,0x5a,0x57,0x52,0x93,0x12,0x11,0x11,0x11,0x11,0x11,0x11,0x00,
+0x0c,0x88,0x90,0xfe,0x22,0x26,0xaa,0xfe,0x02,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,
+/* 64064 0xfa40 "懲" */
+0x01,0x35,0x27,0x40,0x97,0x20,0x67,0xa1,0x27,0x21,0x2f,0x04,0x24,0x24,0x43,0x00,
+0x10,0x50,0xd4,0x5e,0xb4,0x14,0xd4,0x08,0xd4,0x26,0xc2,0x84,0x52,0x12,0xf8,0x00,
+/* 64065 0xfa41 "敏" */
+0x20,0x21,0x3f,0x20,0x40,0x3e,0x2a,0x2a,0xff,0x52,0x4a,0x4a,0x7f,0x02,0x0c,0x00,
+0x20,0x20,0xa0,0x24,0x7e,0xc8,0x48,0x48,0xc8,0x28,0x30,0x10,0xa8,0x46,0x82,0x00,
+/* 64066 0xfa42 "既" */
+0x44,0x7e,0x44,0x44,0x7c,0x44,0x44,0x7d,0x44,0x40,0x48,0x4c,0x54,0xe1,0x42,0x00,
+0x04,0xfe,0x10,0x50,0x50,0x90,0x94,0xfe,0x10,0x10,0x30,0x50,0x92,0x12,0x0e,0x00,
+/* 64067 0xfa43 "暑" */
+0x0f,0x08,0x0f,0x08,0x0f,0x09,0x1f,0x01,0x7f,0x00,0x07,0x7c,0x07,0x04,0x07,0x00,
+0xf0,0x10,0xf0,0x10,0xf4,0x08,0xf0,0x20,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x00,
+/* 64068 0xfa44 "梅" */
+0x11,0x11,0x13,0x10,0xfd,0x11,0x19,0x35,0x57,0x52,0x92,0x92,0x17,0x10,0x10,0x00,
+0x00,0x04,0xfe,0x00,0xfc,0x44,0x24,0x24,0xfe,0x88,0x48,0x48,0xfe,0x08,0x70,0x00,
+/* 64069 0xfa45 "海" */
+0x42,0x22,0x23,0x0c,0x8b,0x52,0x52,0x22,0x2f,0xc4,0x44,0x44,0xc7,0xc0,0x40,0x00,
+0x00,0x04,0xfe,0x00,0xf8,0x88,0x48,0x48,0xfe,0x88,0x48,0x48,0xfe,0x10,0xe0,0x00,
+/* 64070 0xfa46 "渚" */
+0x00,0x20,0x10,0x03,0x40,0x28,0x2f,0x10,0x11,0x23,0x6d,0x21,0x21,0x21,0x21,0x00,
+0x40,0x40,0x44,0xf8,0x50,0x64,0xfe,0x80,0xfc,0x04,0xfc,0x04,0x04,0xfc,0x04,0x00,
+/* 64071 0xfa47 "漢" */
+0x41,0x2f,0x21,0x01,0x80,0x57,0x54,0x27,0x20,0xc7,0x40,0x4f,0xc0,0xc3,0x4c,0x00,
+0x10,0xfe,0x10,0xf0,0x40,0xfc,0x44,0xfc,0x40,0xfc,0x40,0xfe,0x80,0x30,0x0e,0x00,
+/* 64072 0xfa48 "煮" */
+0x01,0x0f,0x01,0x01,0x7f,0x00,0x07,0x0c,0x17,0x64,0x07,0x04,0x24,0x22,0x42,0x00,
+0x00,0xec,0x08,0x10,0xfe,0x80,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x44,0x22,0x22,0x00,
+/* 64073 0xfa49 "爫" */
+0x00,0x00,0x3f,0x01,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x10,0xf8,0x00,0x0c,0x88,0x90,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64074 0xfa4a "琢" */
+0x00,0x0b,0xfc,0x10,0x11,0x12,0x12,0x7d,0x12,0x10,0x14,0x19,0xe2,0x45,0x08,0x00,
+0x04,0xfe,0x40,0x80,0x4c,0x48,0xb0,0x20,0xb0,0x68,0xa8,0x24,0x22,0x20,0xc0,0x00,
+/* 64075 0xfa4b "碑" */
+0x01,0x05,0xff,0x11,0x11,0x21,0x3d,0x65,0xa5,0x24,0x25,0x27,0x3c,0x24,0x00,0x00,
+0x24,0xfe,0x24,0x24,0xfc,0x24,0x24,0xfc,0x44,0x90,0x14,0xfe,0x10,0x10,0x10,0x00,
+/* 64076 0xfa4c "社" */
+0x20,0x10,0x10,0xfc,0x04,0x08,0x11,0x30,0x58,0x94,0x14,0x10,0x10,0x10,0x13,0x00,
+0x20,0x20,0x20,0x20,0x20,0x28,0xfc,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0xfe,0x00,
+/* 64077 0xfa4d "祉" */
+0x20,0x10,0x10,0xfc,0x05,0x09,0x11,0x31,0x59,0x95,0x15,0x11,0x11,0x11,0x17,0x00,
+0x20,0x20,0x20,0x20,0x20,0x24,0x3e,0x20,0x20,0x20,0x20,0x20,0x20,0x24,0xfe,0x00,
+/* 64078 0xfa4e "祈" */
+0x20,0x10,0x10,0xfc,0x04,0x08,0x10,0x30,0x58,0x94,0x14,0x11,0x11,0x12,0x14,0x00,
+0x08,0x9c,0xe0,0x80,0x80,0x84,0xfe,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x08,0x00,
+/* 64079 0xfa4f "祐" */
+0x20,0x10,0x10,0xfd,0x04,0x08,0x10,0x30,0x59,0x96,0x14,0x10,0x10,0x10,0x10,0x00,
+0x40,0x40,0x44,0xfe,0x40,0x40,0x80,0x84,0xfe,0x84,0x84,0x84,0x84,0xfc,0x84,0x00,
+/* 64080 0xfa50 "祖" */
+0x21,0x11,0x11,0xfd,0x05,0x09,0x11,0x31,0x59,0x95,0x15,0x11,0x11,0x11,0x17,0x00,
+0x08,0xfc,0x08,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xf8,0x08,0x08,0x08,0xfe,0x00,
+/* 64081 0xfa51 "祝" */
+0x21,0x11,0x11,0xfd,0x05,0x09,0x11,0x31,0x58,0x94,0x14,0x10,0x10,0x11,0x12,0x00,
+0x04,0xfe,0x04,0x04,0x04,0x04,0xfc,0x54,0x50,0x50,0x50,0x52,0x92,0x12,0x0e,0x00,
+/* 64082 0xfa52 "禍" */
+0x20,0x10,0x10,0xfc,0x04,0x08,0x10,0x33,0x5a,0x96,0x12,0x12,0x12,0x12,0x12,0x00,
+0x88,0xfc,0x88,0x88,0xb8,0xa8,0xa8,0xfe,0x02,0xf2,0x92,0xf2,0x92,0x0e,0x04,0x00,
+/* 64083 0xfa53 "禎" */
+0x20,0x10,0x10,0xfc,0x05,0x09,0x11,0x31,0x59,0x95,0x15,0x11,0x10,0x10,0x13,0x00,
+0x20,0x24,0x3e,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x50,0x88,0x06,0x00,
+/* 64084 0xfa54 "穀" */
+0x08,0xff,0x08,0x7f,0x00,0x7f,0x81,0x3e,0x00,0x7e,0x08,0x7f,0x2a,0x49,0x89,0x00,
+0x48,0xfc,0x48,0x48,0x48,0x8e,0x00,0xfc,0x48,0x48,0x48,0x30,0x30,0x48,0x86,0x00,
+/* 64085 0xfa55 "突" */
+0x01,0x20,0x3f,0x20,0x44,0x18,0x61,0x01,0x01,0x7f,0x01,0x02,0x04,0x18,0x60,0x00,
+0x00,0x84,0xfe,0x04,0x48,0x30,0x4c,0x20,0x04,0xfe,0x00,0x80,0x40,0x30,0x0e,0x00,
+/* 64086 0xfa56 "節" */
+0x10,0x10,0x1f,0x28,0x45,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x24,0x2e,0x73,0x21,0x00,
+0x40,0x40,0x7e,0x90,0x08,0x7c,0x44,0x44,0x44,0x44,0x44,0x44,0x5c,0x48,0x40,0x00,
+/* 64087 0xfa57 "練" */
+0x10,0x13,0x20,0x27,0x46,0xfb,0x12,0x2b,0xfa,0x44,0x00,0x28,0x55,0x56,0x80,0x00,
+0x24,0xfe,0x20,0xfe,0x22,0x26,0xaa,0xfe,0x22,0x20,0x70,0xa8,0x26,0x22,0x20,0x00,
+/* 64088 0xfa58 "縉" */
+0x10,0x13,0x20,0x24,0x45,0xfb,0x10,0x2b,0xfc,0x45,0x01,0x29,0x55,0x55,0x81,0x00,
+0x04,0xfe,0x88,0x88,0x52,0xde,0x00,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,
+/* 64089 0xfa59 "繁" */
+0x20,0x3f,0x55,0x3f,0x15,0x1f,0x01,0x02,0x1f,0x02,0x7f,0x20,0x00,0x1b,0x61,0x00,
+0x20,0xbe,0x44,0xa4,0x18,0xa6,0x42,0x10,0xe0,0x10,0xfc,0x84,0xa0,0x98,0x06,0x00,
+/* 64090 0xfa5a "署" */
+0x3f,0x22,0x22,0x3f,0x21,0x1f,0x01,0x7f,0x00,0x07,0x0c,0x37,0x04,0x07,0x04,0x00,
+0xfc,0x44,0x44,0xfc,0x04,0xe8,0x10,0xfe,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,
+/* 64091 0xfa5b "者" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x0f,0x18,0x28,0xcf,0x08,0x0f,0x08,0x00,
+0x00,0x08,0xc8,0x10,0x24,0xfe,0x00,0x10,0xf8,0x10,0x10,0xf0,0x10,0xf0,0x10,0x00,
+/* 64092 0xfa5c "臭" */
+0x09,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x0f,0x08,0x00,0x7f,0x01,0x02,0x0c,0x70,0x00,
+0x10,0xf8,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x20,0x94,0xfe,0x40,0x20,0x1e,0x04,0x00,
+/* 64093 0xfa5d "艹" */
+0x00,0x00,0x00,0x04,0x04,0x7f,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64094 0xfa5e "艹" */
+0x00,0x00,0x00,0x04,0x04,0x7f,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x20,0xfe,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64095 0xfa5f "著" */
+0x04,0x04,0x7f,0x05,0x01,0x1f,0x01,0x7f,0x01,0x07,0x1c,0x67,0x04,0x07,0x04,0x00,
+0x20,0x20,0xfe,0x20,0x08,0xd0,0x20,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x00,
+/* 64096 0xfa60 "褐" */
+0x41,0x21,0x29,0xfd,0x09,0x11,0x24,0x28,0x71,0xaf,0x25,0x21,0x21,0x21,0x20,0x00,
+0xfc,0x04,0xfc,0x04,0xfc,0x24,0x40,0xfe,0x22,0x22,0x52,0x8a,0x02,0xf2,0x0c,0x00,
+/* 64097 0xfa61 "視" */
+0x21,0x11,0x11,0x05,0x7f,0x09,0x11,0x39,0x55,0x95,0x11,0x10,0x10,0x10,0x17,0x00,
+0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x54,0x50,0x52,0x92,0x0e,0x00,
+/* 64098 0xfa62 "謁" */
+0x21,0x11,0x11,0xfd,0x01,0x01,0x79,0x00,0x79,0x03,0x79,0x49,0x49,0x79,0x48,0x00,
+0x04,0xfe,0x04,0xfc,0x04,0xfc,0x40,0xfe,0x22,0x22,0x52,0x8a,0x02,0xf2,0x0c,0x00,
+/* 64099 0xfa63 "謹" */
+0x20,0x10,0x13,0xfc,0x00,0x00,0x79,0x01,0x79,0x00,0x7b,0x48,0x49,0x78,0x4b,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 64100 0xfa64 "賓" */
+0x21,0x3f,0x20,0x5f,0x05,0x09,0x31,0x0f,0x78,0x0f,0x08,0x0f,0x08,0x0f,0x38,0x00,
+0x04,0xfe,0x04,0xf4,0x10,0x20,0x40,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x1c,0x00,
+/* 64101 0xfa65 "贈" */
+0x89,0xfc,0x88,0x8b,0xfa,0x8b,0x8a,0xfb,0x88,0x89,0xf9,0x89,0x51,0x89,0x89,0x00,
+0x0c,0x88,0x50,0xfe,0x22,0x26,0xaa,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x00,
+/* 64102 0xfa66 "辶" */
+0x40,0x30,0x10,0x00,0x00,0x10,0xf8,0x10,0x10,0x10,0x10,0x30,0xc8,0x87,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x00,0x00,
+/* 64103 0xfa67 "逸" */
+0x01,0x41,0x31,0x12,0x07,0x02,0x12,0xfb,0x10,0x10,0x11,0x16,0x30,0xc8,0x87,0x00,
+0x10,0xf8,0x10,0x24,0xfe,0x44,0x44,0xfc,0x60,0xa8,0x26,0x22,0x1e,0x00,0xfe,0x00,
+/* 64104 0xfa68 "難" */
+0x22,0xff,0x22,0x3e,0x09,0x7e,0x4a,0x7e,0x08,0x7e,0x08,0xff,0x14,0x22,0x42,0x00,
+0xa0,0x90,0x90,0xfe,0x90,0x90,0x90,0xfc,0x90,0x90,0xfc,0x90,0x94,0xfe,0x80,0x00,
+/* 64105 0xfa69 "響" */
+0x11,0x27,0x7a,0x13,0x2a,0x7a,0x13,0x60,0x1f,0x04,0x7f,0x08,0x0f,0x08,0x0f,0x00,
+0x1e,0xd2,0x54,0xd8,0x56,0x92,0x5c,0x90,0xf8,0x44,0xfe,0x10,0xf0,0x10,0xf0,0x00,
+/* 64106 0xfa6a "頻" */
+0x08,0x09,0x28,0x2e,0x28,0x28,0xff,0x08,0x28,0x28,0x49,0x8a,0x04,0x18,0x61,0x00,
+0x04,0xfe,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x84,0x58,0x86,0x00,
+/* 64107 0xfa6b "恵" */
+0x01,0x01,0xff,0x01,0x3f,0x21,0x21,0x3f,0x21,0x21,0x3f,0x01,0x25,0x24,0x66,0xc3,
+0x30,0x08,0xfe,0x00,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0x8c,0x96,0x32,0xe0,
+/* 64108 0xfa6c "𤋮" */
+0x00,0x7f,0x48,0x48,0x7f,0x41,0x41,0x7f,0x48,0x48,0x7f,0x00,0x24,0x22,0x42,0x80,
+0x00,0x7e,0x02,0x02,0x02,0x7e,0x40,0x40,0x42,0x42,0x7e,0x00,0x88,0x44,0x44,0x04,
+/* 64109 0xfa6d "舘" */
+0x10,0x38,0x2d,0x67,0x41,0xfc,0x10,0x10,0xfe,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,
+0x20,0x20,0xfe,0x02,0x02,0xf8,0x88,0x88,0xf8,0x80,0x80,0xfc,0x84,0x84,0x84,0xfc,
+/* 64110 0xfa6e "﩮" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64111 0xfa6f "﩯" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64112 0xfa70 "並" */
+0x10,0x08,0x04,0x7f,0x04,0x04,0x04,0x44,0x24,0x14,0x14,0x04,0x04,0x04,0xff,0x00,
+0x10,0x20,0x40,0xfc,0x40,0x40,0x40,0x44,0x44,0x48,0x50,0x40,0x40,0x40,0xfe,0x00,
+/* 64113 0xfa71 "况" */
+0x47,0x24,0x24,0x04,0x04,0x17,0x11,0x21,0xe1,0x21,0x22,0x22,0x24,0x28,0x10,0x00,
+0xf8,0x08,0x08,0x08,0x08,0xf8,0x20,0x20,0x20,0x20,0x20,0x22,0x22,0x1e,0x00,0x00,
+/* 64114 0xfa72 "全" */
+0x01,0x01,0x02,0x04,0x08,0x10,0x2f,0xc1,0x01,0x01,0x1f,0x01,0x01,0x01,0x7f,0x00,
+0x00,0x00,0x80,0x40,0x20,0x10,0xe8,0x06,0x00,0x00,0xf0,0x00,0x00,0x00,0xfc,0x00,
+/* 64115 0xfa73 "侀" */
+0x10,0x1f,0x14,0x24,0x24,0x64,0x64,0xaf,0x24,0x24,0x24,0x24,0x24,0x28,0x28,0x30,
+0x04,0xc4,0x84,0x94,0x94,0x94,0x94,0xd4,0x94,0x94,0x94,0x94,0x84,0x84,0x94,0x88,
+/* 64116 0xfa74 "充" */
+0x02,0x01,0xff,0x04,0x04,0x08,0x10,0x3f,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,
+0x00,0x00,0xfe,0x00,0x00,0x20,0x10,0xf8,0x48,0x40,0x40,0x40,0x44,0x44,0x44,0x3c,
+/* 64117 0xfa75 "冀" */
+0x04,0x7c,0x04,0x1c,0xe4,0x3f,0x21,0x3f,0x21,0x3f,0x04,0x3f,0x04,0xff,0x10,0x20,
+0x44,0x78,0x42,0x3e,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x40,0xf8,0x40,0xfe,0x10,0x08,
+/* 64118 0xfa76 "勇" */
+0x3f,0x06,0x01,0x3f,0x21,0x3f,0x21,0x3f,0x21,0x22,0x02,0x7f,0x04,0x08,0x10,0x60,
+0xf0,0x60,0x80,0xf8,0x08,0xf8,0x08,0xf8,0x08,0x08,0x00,0xf8,0x08,0x08,0x50,0x20,
+/* 64119 0xfa77 "勺" */
+0x08,0x08,0x10,0x1f,0x20,0x40,0x80,0x04,0x02,0x01,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x50,0x20,
+/* 64120 0xfa78 "喝" */
+0x03,0x7a,0x4b,0x4a,0x4b,0x49,0x4b,0x4c,0x4a,0x7a,0x4a,0x03,0x00,0x00,0x00,0x00,
+0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x44,0x44,0xa4,0x04,0xf4,0x04,0x28,0x10,0x00,
+/* 64121 0xfa79 "啕" */
+0x01,0x01,0x79,0x4a,0x4d,0x49,0x4a,0x48,0x4f,0x48,0x7a,0x4a,0x03,0x00,0x00,0x00,
+0x00,0x00,0xfc,0x04,0x04,0xe4,0x84,0x84,0xf4,0x84,0xa4,0xa4,0xe4,0x04,0x28,0x10,
+/* 64122 0xfa7a "喙" */
+0x01,0x01,0xf2,0x93,0x90,0x97,0x90,0x91,0x96,0x90,0xf1,0x96,0x00,0x01,0x06,0x00,
+0x00,0xf8,0x08,0xf0,0x10,0xfe,0x80,0x44,0x68,0xb0,0x28,0x68,0xa4,0x22,0xa0,0x40,
+/* 64123 0xfa7b "嗢" */
+0x01,0x79,0x49,0x49,0x49,0x49,0x49,0x48,0x4b,0x7a,0x4a,0x02,0x02,0x07,0x00,0x00,
+0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x00,0xfc,0x94,0x94,0x94,0x94,0xfe,0x00,0x00,
+/* 64124 0xfa7c "塚" */
+0x20,0x27,0x24,0x28,0x27,0xf8,0x21,0x22,0x26,0x21,0x3a,0xe4,0x41,0x02,0x0c,0x00,
+0x00,0xfe,0x02,0x04,0xfe,0x80,0x84,0x44,0xa8,0x30,0xf0,0xa8,0x28,0x24,0xa2,0x40,
+/* 64125 0xfa7d "墳" */
+0x10,0x11,0x10,0x10,0x13,0xfc,0x11,0x11,0x11,0x11,0x11,0x1d,0xe1,0x40,0x01,0x02,
+0x20,0xfc,0x20,0x88,0xfe,0x88,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x88,0x04,0x02,
+/* 64126 0xfa7e "奄" */
+0x02,0x02,0x7f,0x04,0x09,0x31,0xdf,0x11,0x11,0x1f,0x11,0x11,0x1f,0x01,0x01,0x00,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xf6,0x10,0x10,0xf0,0x10,0x10,0xf4,0x04,0x04,0xfc,
+/* 64127 0xfa7f "奔" */
+0x02,0x02,0x7f,0x04,0x09,0x31,0xcf,0x01,0x09,0x08,0x7f,0x08,0x08,0x10,0x10,0x20,
+0x00,0x00,0xfc,0x40,0x20,0x18,0xe6,0x00,0x20,0x20,0xfc,0x20,0x20,0x20,0x20,0x20,
+/* 64128 0xfa80 "婢" */
+0x10,0x10,0x11,0x11,0xfd,0x25,0x25,0x25,0x25,0x48,0x29,0x13,0x28,0x44,0x84,0x00,
+0x40,0x80,0xfc,0x24,0x24,0xfc,0x24,0x44,0xfc,0x90,0x10,0xfe,0x10,0x10,0x10,0x10,
+/* 64129 0xfa81 "嬨" */
+0x21,0x20,0x23,0x21,0xf9,0x4a,0x4b,0x49,0x8a,0x4b,0x30,0x10,0x2a,0x4a,0x84,0x00,
+0x08,0x90,0xfe,0x08,0x08,0x52,0x9c,0x08,0x52,0xde,0x40,0xa4,0xaa,0x8a,0x78,0x00,
+/* 64130 0xfa82 "廒" */
+0x01,0x00,0x3f,0x22,0x2f,0x22,0x2f,0x22,0x3f,0x24,0x27,0x24,0x44,0x48,0x8a,0x11,
+0x00,0x80,0xfe,0x10,0x90,0x1e,0xa4,0x24,0xd4,0x14,0x94,0x88,0x88,0x94,0xa4,0x42,
+/* 64131 0xfa83 "廙" */
+0x01,0x00,0x3f,0x20,0x27,0x24,0x27,0x24,0x27,0x21,0x27,0x21,0x2f,0x40,0x42,0x84,
+0x00,0x80,0xfe,0x00,0xfc,0x44,0xfc,0x44,0xfc,0x10,0xfc,0x10,0xfe,0x00,0x08,0x04,
+/* 64132 0xfa84 "彩" */
+0x01,0x07,0x78,0x08,0x44,0x25,0x20,0x04,0x7f,0x0c,0x16,0x15,0x24,0x44,0x84,0x04,
+0x00,0x84,0x04,0x88,0x90,0x22,0x02,0x04,0x88,0x10,0x22,0x02,0x84,0x08,0x10,0x60,
+/* 64133 0xfa85 "徭" */
+0x08,0x08,0x13,0x20,0x4a,0x09,0x11,0x32,0x50,0x93,0x10,0x11,0x11,0x11,0x11,0x10,
+0x08,0x3c,0xc0,0x04,0x44,0x28,0xfc,0x20,0x20,0xfe,0x20,0x24,0x24,0x24,0xfc,0x04,
+/* 64134 0xfa86 "惘" */
+0x10,0x13,0x12,0x12,0x1a,0x57,0x52,0x52,0x93,0x12,0x12,0x12,0x12,0x12,0x12,0x12,
+0x00,0xfe,0x02,0x8a,0x52,0xfe,0x42,0x22,0xfe,0x82,0x82,0x82,0xfa,0x02,0x0a,0x04,
+/* 64135 0xfa87 "慎" */
+0x20,0x20,0x27,0x20,0x33,0xaa,0xa3,0xa2,0xa3,0x22,0x23,0x22,0x2f,0x21,0x22,0x24,
+0x40,0x40,0xfc,0x40,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xf8,0x08,0xfe,0x10,0x08,0x04,
+/* 64136 0xfa88 "愈" */
+0x01,0x02,0x0c,0x37,0xc0,0x3e,0x22,0x3e,0x22,0x3e,0x22,0x26,0x01,0x48,0x48,0x87,
+0x00,0x80,0x60,0xd8,0x06,0x08,0x48,0x48,0x48,0x48,0x08,0x18,0x00,0x84,0x12,0xf2,
+/* 64137 0xfa89 "憎" */
+0x11,0x10,0x10,0x13,0x1a,0x56,0x52,0x52,0x93,0x10,0x11,0x11,0x11,0x11,0x11,0x11,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 64138 0xfa8a "慠" */
+0x21,0x21,0x21,0x27,0x31,0xaf,0xa1,0xaf,0xa2,0x23,0x22,0x22,0x22,0x24,0x24,0x28,
+0x08,0x08,0x08,0xd0,0x1e,0x94,0x24,0xd4,0x14,0xd4,0x54,0x48,0x48,0xd4,0x24,0x42,
+/* 64139 0xfa8b "懲" */
+0x22,0x4a,0x8a,0x1f,0x20,0x6f,0xa0,0x2f,0x22,0x2f,0x22,0x2f,0x01,0x48,0x48,0x87,
+0x20,0xa0,0xbe,0xc4,0xa4,0x24,0x28,0xa8,0x10,0xa8,0x44,0x82,0x00,0x84,0x12,0xf2,
+/* 64140 0xfa8c "戴" */
+0x08,0x7f,0x08,0xff,0x00,0x7f,0x49,0x7f,0x49,0x7f,0x22,0x7f,0x22,0xff,0x22,0x41,
+0x20,0x28,0x24,0xfe,0x20,0x20,0x24,0x24,0x24,0x28,0x28,0x10,0x12,0xaa,0x46,0x82,
+/* 64141 0xfa8d "揄" */
+0x20,0x20,0x21,0x22,0xfd,0x20,0x23,0x2a,0x32,0xe3,0x22,0x22,0x23,0x22,0xa2,0x42,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 64142 0xfa8e "搜" */
+0x10,0x11,0x11,0x11,0xfd,0x11,0x11,0x15,0x18,0x31,0xd0,0x10,0x10,0x10,0x50,0x23,
+0xa0,0x2c,0x24,0x24,0xac,0x24,0x24,0xfc,0x20,0xfc,0x88,0x50,0x20,0x50,0x88,0x06,
+/* 64143 0xfa8f "摒" */
+0x20,0x23,0x22,0x22,0xfb,0x22,0x22,0x2a,0x32,0xe2,0x22,0x23,0x24,0x24,0xa8,0x51,
+0x00,0xfc,0x04,0x04,0xfc,0x00,0x84,0x48,0xfc,0x48,0x48,0xfe,0x48,0x48,0x88,0x08,
+/* 64144 0xfa90 "敖" */
+0x08,0x08,0x08,0x7f,0x08,0x3e,0x08,0xff,0x10,0x1e,0x12,0x12,0x22,0x2a,0x44,0x81,
+0x20,0x20,0x20,0x3e,0x44,0x44,0x44,0xa4,0x28,0x28,0x10,0x10,0x28,0x48,0x84,0x02,
+/* 64145 0xfa91 "晴" */
+0x00,0x00,0x7b,0x48,0x49,0x48,0x4b,0x78,0x49,0x49,0x49,0x49,0x79,0x49,0x01,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 64146 0xfa92 "朗" */
+0x10,0x08,0x7e,0x42,0x42,0x7e,0x42,0x42,0x7e,0x40,0x48,0x44,0x5a,0x62,0x41,0x02,
+0x00,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x44,0x7c,0x44,0x44,0x84,0x84,0x14,0x08,
+/* 64147 0xfa93 "望" */
+0x10,0x08,0xff,0x20,0x20,0x26,0x38,0x20,0x01,0x7f,0x01,0x01,0x3f,0x01,0x01,0xff,
+0x00,0x7c,0x44,0x7c,0x44,0x7c,0x44,0x94,0x08,0xfc,0x00,0x00,0xf8,0x00,0x00,0xfe,
+/* 64148 0xfa94 "杖" */
+0x10,0x10,0x10,0x10,0xfd,0x10,0x30,0x39,0x55,0x54,0x90,0x10,0x10,0x10,0x11,0x16,
+0x10,0x10,0x10,0x10,0xfe,0x10,0x10,0x10,0x10,0x90,0x90,0x50,0x20,0x50,0x88,0x06,
+/* 64149 0xfa95 "歹" */
+0xff,0x02,0x02,0x04,0x07,0x08,0x10,0x24,0x42,0x01,0x00,0x01,0x02,0x0c,0x70,0x00,
+0xfe,0x00,0x00,0x00,0xf8,0x08,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 64150 0xfa96 "殺" */
+0x04,0x44,0x28,0x10,0x28,0x44,0x92,0x10,0xfe,0x10,0x58,0x54,0x92,0x12,0x50,0x21,
+0x00,0x78,0x48,0x48,0x48,0x86,0x00,0xfc,0x44,0x44,0x28,0x28,0x10,0x28,0x44,0x82,
+/* 64151 0xfa97 "流" */
+0x00,0x20,0x17,0x10,0x81,0x42,0x47,0x10,0x10,0x22,0xe2,0x22,0x22,0x22,0x24,0x08,
+0x80,0x40,0xfe,0x80,0x10,0x08,0xfc,0x04,0x00,0x48,0x48,0x48,0x48,0x4a,0x4a,0x46,
+/* 64152 0xfa98 "滛" */
+0x00,0x20,0x17,0x12,0x81,0x41,0x42,0x13,0x14,0x20,0xef,0x20,0x24,0x24,0x27,0x00,
+0x04,0x3e,0xc0,0x44,0x24,0x28,0x00,0xfc,0x40,0x40,0xfe,0x40,0x44,0x44,0xfc,0x04,
+/* 64153 0xfa99 "滋" */
+0x01,0x20,0x10,0x17,0x81,0x41,0x42,0x12,0x14,0x27,0xe1,0x22,0x22,0x24,0x27,0x00,
+0x08,0x88,0x90,0xfe,0x08,0x08,0x10,0x94,0xa4,0x38,0x08,0x10,0x10,0xa4,0xbc,0x84,
+/* 64154 0xfa9a "漢" */
+0x01,0x21,0x17,0x11,0x81,0x40,0x4b,0x0a,0x13,0x10,0xe7,0x20,0x2f,0x20,0x21,0x06,
+0x10,0x10,0xfe,0x10,0xf0,0x40,0xf8,0x48,0xf8,0x40,0xfc,0x40,0xfe,0xa0,0x10,0x0c,
+/* 64155 0xfa9b "瀞" */
+0x02,0x42,0x2f,0x22,0x0f,0x82,0x4f,0x50,0x1f,0x28,0xef,0x28,0x2f,0x28,0x2a,0x09,
+0x20,0x20,0xb8,0x48,0x90,0x7c,0x94,0x14,0xfe,0x94,0x94,0xfc,0x94,0x90,0x90,0x30,
+/* 64156 0xfa9c "煮" */
+0x02,0x02,0x3f,0x02,0xff,0x01,0x0f,0x38,0xcf,0x08,0x08,0x0f,0x00,0x48,0x44,0x84,
+0x00,0x08,0xd0,0x20,0xfe,0x00,0xf0,0x10,0xf0,0x10,0x10,0xf0,0x00,0x88,0x44,0x44,
+/* 64157 0xfa9d "瞧" */
+0x00,0x00,0x79,0x49,0x4b,0x7d,0x49,0x49,0x79,0x49,0x49,0x49,0x79,0x4a,0x02,0x04,
+0xa0,0x90,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x10,0x10,0xfe,0x00,0xa4,0x52,0x52,
+/* 64158 0xfa9e "爵" */
+0x00,0x7f,0x22,0x11,0x7f,0x44,0x7f,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x48,0x74,0x42,
+0xfc,0x00,0x08,0x10,0xfc,0x44,0xfc,0x08,0x08,0xfe,0x08,0x48,0x28,0x08,0x28,0x10,
+/* 64159 0xfa9f "犯" */
+0x44,0x29,0x11,0x29,0x49,0x89,0x09,0x19,0x29,0x49,0x89,0x09,0x09,0x50,0x20,0x00,
+0x00,0xf8,0x08,0x08,0x08,0x08,0x08,0x28,0x10,0x00,0x02,0x02,0x02,0xfe,0x00,0x00,
+/* 64160 0xfaa0 "猪" */
+0x00,0x88,0x53,0x20,0x50,0x97,0x10,0x10,0x31,0x53,0x95,0x11,0x11,0x11,0xa1,0x41,
+0x40,0x44,0xf4,0x48,0x50,0xfe,0x40,0x80,0xf8,0x08,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 64161 0xfaa1 "瑱" */
+0x00,0x00,0xfb,0x20,0x21,0x21,0x21,0xf9,0x21,0x21,0x21,0x39,0xe3,0x40,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 64162 0xfaa2 "甆" */
+0x08,0x04,0x7f,0x12,0x3c,0x08,0x14,0x3e,0x00,0x7f,0x08,0x0f,0x09,0x10,0x16,0x18,
+0x20,0x40,0xfc,0x48,0xf0,0x20,0x50,0xf8,0x00,0xfc,0x00,0xe0,0x20,0xa4,0x24,0x1c,
+/* 64163 0xfaa3 "画" */
+0xff,0x00,0x00,0x4f,0x49,0x49,0x4f,0x49,0x49,0x49,0x4f,0x40,0x40,0x7f,0x00,0x00,
+0xfe,0x00,0x00,0xe4,0x24,0x24,0xe4,0x24,0x24,0x24,0xe4,0x04,0x04,0xfc,0x04,0x00,
+/* 64164 0xfaa4 "瘝" */
+0x00,0x00,0x1f,0x10,0x97,0x54,0x54,0x17,0x30,0x51,0x92,0x14,0x21,0x22,0x44,0x80,
+0x80,0x40,0xfe,0x00,0xfc,0xa4,0xa4,0xfc,0x40,0x50,0x48,0x44,0x50,0x48,0x44,0x40,
+/* 64165 0xfaa5 "瘟" */
+0x01,0x00,0x3f,0x20,0x27,0xa4,0x67,0x24,0x27,0x60,0xaf,0x29,0x29,0x49,0x7f,0x80,
+0x00,0x80,0xfe,0x00,0xf8,0x08,0xf8,0x08,0xf8,0x00,0xfc,0x24,0x24,0x24,0xfe,0x00,
+/* 64166 0xfaa6 "益" */
+0x10,0x08,0x00,0xff,0x00,0x08,0x10,0x20,0x40,0x3f,0x24,0x24,0x24,0x24,0xff,0x00,
+0x10,0x20,0x00,0xfe,0x00,0x20,0x10,0x08,0x04,0xf8,0x48,0x48,0x48,0x48,0xfe,0x00,
+/* 64167 0xfaa7 "盛" */
+0x00,0x00,0x3f,0x20,0x20,0x3e,0x22,0x22,0x4a,0x44,0x81,0x3f,0x24,0x24,0xff,0x00,
+0x90,0x88,0xfc,0x80,0x88,0x48,0x50,0x24,0x54,0x8c,0x04,0xf8,0x48,0x48,0xfe,0x00,
+/* 64168 0xfaa8 "直" */
+0x01,0x01,0x7f,0x01,0x1f,0x10,0x10,0x1f,0x10,0x1f,0x10,0x1f,0x10,0x10,0xff,0x00,
+0x00,0x00,0xfc,0x00,0xf0,0x10,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,0x10,0xfe,0x00,
+/* 64169 0xfaa9 "睊" */
+0x00,0x7c,0x44,0x44,0x7c,0x45,0x45,0x7d,0x45,0x45,0x45,0x7d,0x45,0x01,0x01,0x00,
+0xfc,0x84,0x84,0xfc,0x00,0xfe,0x02,0x02,0xfe,0x02,0x02,0xfe,0x02,0x0a,0x04,0x00,
+/* 64170 0xfaaa "着" */
+0x08,0x04,0x7f,0x01,0x3f,0x02,0xff,0x04,0x0f,0x18,0x2f,0xc8,0x0f,0x08,0x0f,0x08,
+0x20,0x40,0xfc,0x00,0xf8,0x00,0xfe,0x00,0xf0,0x10,0xf0,0x10,0xf0,0x10,0xf0,0x10,
+/* 64171 0xfaab "磌" */
+0x00,0x00,0xfb,0x20,0x21,0x41,0x79,0x49,0xc9,0x49,0x49,0x49,0x7b,0x48,0x01,0x02,
+0x20,0x20,0xfe,0x20,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfc,0x04,0xfe,0x88,0x04,0x02,
+/* 64172 0xfaac "窱" */
+0x02,0x01,0x7f,0x48,0x90,0x11,0x22,0x68,0xab,0x28,0x29,0x28,0x28,0x29,0x22,0x20,
+0x00,0x00,0xfe,0x22,0x94,0xf8,0x88,0x70,0xae,0x20,0xfc,0x20,0xa8,0x24,0xa4,0x40,
+/* 64173 0xfaad "節" */
+0x10,0x10,0x3f,0x48,0x85,0x00,0x7e,0x42,0x7e,0x42,0x7e,0x48,0x44,0x5a,0x62,0x40,
+0x40,0x40,0x7e,0x90,0x08,0x00,0x7c,0x44,0x44,0x44,0x44,0x44,0x54,0x48,0x40,0x40,
+/* 64174 0xfaae "类" */
+0x01,0x11,0x09,0x01,0x7f,0x05,0x09,0x11,0x60,0x01,0xff,0x02,0x04,0x08,0x30,0xc0,
+0x00,0x10,0x20,0x00,0xfc,0x40,0x20,0x10,0x08,0x00,0xfe,0x80,0x40,0x20,0x18,0x06,
+/* 64175 0xfaaf "絛" */
+0x10,0x10,0x11,0x22,0x20,0x65,0x66,0xa4,0x25,0x24,0x24,0x25,0x20,0x21,0x22,0x20,
+0x80,0xf8,0x08,0x90,0x60,0x98,0x46,0x88,0xf0,0x20,0x48,0xfc,0x20,0x24,0xa2,0x40,
+/* 64176 0xfab0 "練" */
+0x10,0x10,0x23,0x24,0x45,0xf9,0x11,0x21,0x49,0xfd,0x04,0x00,0x54,0x55,0x82,0x00,
+0x20,0x20,0xfe,0x20,0xfc,0x24,0xac,0x74,0x24,0xfc,0x20,0x70,0xa8,0x24,0x22,0x20,
+/* 64177 0xfab1 "缾" */
+0x20,0x20,0x3c,0x50,0x90,0x10,0xfe,0x10,0x11,0x54,0x54,0x54,0x5c,0x64,0x04,0x01,
+0x84,0x48,0x00,0xfc,0x48,0x48,0x48,0x48,0xfe,0x48,0x48,0x48,0x48,0x88,0x88,0x08,
+/* 64178 0xfab2 "者" */
+0x02,0x02,0x3f,0x02,0x02,0xff,0x01,0x02,0x0f,0x18,0x28,0x4f,0x88,0x08,0x0f,0x08,
+0x00,0x08,0xd0,0x20,0x40,0xfe,0x00,0x00,0xf0,0x10,0x10,0xf0,0x10,0x10,0xf0,0x10,
+/* 64179 0xfab3 "荒" */
+0x08,0x08,0xff,0x0a,0x01,0xff,0x10,0x10,0x1f,0x00,0x11,0x11,0x11,0x21,0x41,0x81,
+0x20,0x20,0xfe,0x20,0x00,0xfe,0x00,0x00,0xf8,0x00,0x10,0x10,0x10,0x12,0x12,0x0e,
+/* 64180 0xfab4 "華" */
+0x04,0x04,0xff,0x04,0x7f,0x11,0x11,0xff,0x11,0x11,0x7f,0x01,0xff,0x01,0x01,0x01,
+0x40,0x40,0xfe,0x40,0xfc,0x10,0x10,0xfe,0x10,0x10,0xfc,0x00,0xfe,0x00,0x00,0x00,
+/* 64181 0xfab5 "蝹" */
+0x10,0x10,0x10,0x7c,0x54,0x54,0x54,0x54,0x7c,0x51,0x11,0x15,0x1d,0xe5,0x43,0x00,
+0x00,0xf8,0x88,0x88,0xf8,0x88,0x88,0xf8,0x00,0xfc,0x54,0x54,0x54,0x54,0xfe,0x00,
+/* 64182 0xfab6 "襁" */
+0x20,0x13,0x00,0xf0,0x10,0x23,0x22,0x6a,0xb2,0x2b,0x20,0x20,0x20,0x20,0x25,0x22,
+0x00,0xbe,0xa2,0xa2,0xbe,0x88,0x08,0x3e,0x2a,0xaa,0xaa,0xbe,0x88,0x8a,0x7e,0x02,
+/* 64183 0xfab7 "覆" */
+0xff,0x04,0x3f,0x24,0x3f,0x12,0x27,0x42,0x8b,0x12,0x33,0x51,0x93,0x15,0x10,0x17,
+0xfe,0x40,0xf8,0x48,0xf8,0x00,0xfc,0x08,0xf8,0x08,0xf8,0x00,0xf8,0x10,0xe0,0x1e,
+/* 64184 0xfab8 "視" */
+0x20,0x11,0x11,0xf9,0x09,0x11,0x11,0x39,0x55,0x95,0x11,0x10,0x10,0x10,0x11,0x12,
+0x00,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x04,0x04,0xfc,0x50,0x90,0x92,0x12,0x0e,
+/* 64185 0xfab9 "調" */
+0x20,0x11,0x01,0xfd,0x01,0x79,0x01,0x79,0x01,0x79,0x49,0x49,0x49,0x7a,0x4a,0x04,
+0x00,0xfc,0x24,0x24,0x74,0x24,0xfc,0x04,0x74,0x54,0x54,0x74,0x04,0x04,0x14,0x08,
+/* 64186 0xfaba "諸" */
+0x20,0x10,0x01,0xfc,0x00,0x7b,0x00,0x78,0x00,0x79,0x4a,0x48,0x48,0x78,0x48,0x00,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 64187 0xfabb "請" */
+0x20,0x10,0x03,0xfc,0x01,0x78,0x03,0x78,0x01,0x79,0x49,0x49,0x49,0x79,0x49,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 64188 0xfabc "謁" */
+0x20,0x11,0x11,0xfd,0x01,0x7d,0x00,0x7d,0x02,0x7d,0x45,0x45,0x45,0x7c,0x44,0x00,
+0x00,0xfc,0x04,0xfc,0x04,0xfc,0x80,0xfe,0x22,0x22,0x52,0x02,0xfa,0x02,0x14,0x08,
+/* 64189 0xfabd "諾" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x03,0x78,0x00,0x78,0x49,0x4a,0x48,0x78,0x48,0x00,
+0x88,0x88,0xfe,0x88,0xa8,0x20,0xfe,0x40,0x80,0xfc,0x84,0x84,0x84,0x84,0xfc,0x84,
+/* 64190 0xfabe "諭" */
+0x20,0x10,0x01,0xfa,0x05,0x78,0x03,0x7a,0x02,0x7b,0x4a,0x4a,0x4b,0x7a,0x4a,0x02,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 64191 0xfabf "謹" */
+0x20,0x10,0x03,0xfc,0x00,0x78,0x01,0x79,0x01,0x78,0x4b,0x48,0x49,0x78,0x4b,0x00,
+0x88,0x88,0xfe,0x88,0xf8,0x20,0xfc,0x24,0xfc,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,
+/* 64192 0xfac0 "變" */
+0x21,0x47,0x88,0xf3,0x20,0x4b,0xf8,0x03,0xaa,0xab,0x08,0x1f,0x28,0x07,0x18,0xe0,
+0x04,0xc8,0x12,0xbc,0x08,0x92,0x3e,0x80,0xaa,0xaa,0x00,0xf8,0x20,0xc0,0x30,0x0e,
+/* 64193 0xfac1 "贈" */
+0x01,0x78,0x48,0x4b,0x7a,0x4a,0x4a,0x7a,0x4b,0x48,0x79,0x01,0x51,0x49,0x89,0x01,
+0x04,0x88,0x00,0xfe,0x22,0xaa,0x72,0x22,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,
+/* 64194 0xfac2 "輸" */
+0x20,0x20,0x21,0xfa,0x25,0xf8,0xab,0xfa,0xaa,0xfb,0x22,0xfa,0x23,0x22,0x22,0x22,
+0x40,0xa0,0x10,0x08,0xf6,0x00,0xc4,0x54,0x54,0xd4,0x54,0x54,0xd4,0x44,0x54,0xc8,
+/* 64195 0xfac3 "遲" */
+0x07,0x44,0x27,0x24,0x04,0x04,0xe4,0x25,0x24,0x24,0x25,0x24,0x2b,0x28,0x50,0x8f,
+0xfc,0x04,0xfc,0x20,0xa8,0x70,0xa8,0x04,0xa0,0xfc,0x20,0x20,0xfe,0x20,0x20,0xfe,
+/* 64196 0xfac4 "醙" */
+0x00,0xfe,0x28,0x28,0xfe,0xaa,0xaa,0xaa,0xae,0xc2,0x82,0xfe,0x82,0x82,0xfe,0x82,
+0x50,0x96,0x92,0x92,0xd6,0x92,0x92,0xfe,0x10,0xfc,0x44,0x44,0x28,0x10,0x28,0xc6,
+/* 64197 0xfac5 "鉶" */
+0x10,0x13,0x29,0x25,0x41,0xb9,0x11,0x13,0xfd,0x11,0x95,0x59,0x51,0x1e,0xe2,0x44,
+0x02,0xe2,0x42,0x4a,0x4a,0x4a,0x4a,0xea,0x4a,0x4a,0x4a,0x4a,0x42,0x42,0x4a,0x44,
+/* 64198 0xfac6 "陼" */
+0x00,0x7c,0x45,0x48,0x48,0x53,0x48,0x48,0x44,0x45,0x46,0x68,0x50,0x40,0x40,0x40,
+0x20,0x22,0xfa,0x24,0x28,0xfe,0x20,0x40,0xfc,0x84,0x84,0xfc,0x84,0x84,0xfc,0x84,
+/* 64199 0xfac7 "難" */
+0x22,0x22,0xff,0x22,0x3e,0x09,0x7f,0x49,0x7f,0x08,0x7f,0x08,0xff,0x14,0x22,0x41,
+0x28,0x24,0x40,0x7e,0xc8,0x48,0x7e,0x48,0x48,0x7e,0x48,0x48,0x48,0x7e,0x40,0x40,
+/* 64200 0xfac8 "靖" */
+0x20,0x10,0x13,0xfc,0x01,0x08,0x8b,0x88,0x49,0x49,0x51,0x51,0x1d,0xe1,0x41,0x01,
+0x20,0x20,0xfe,0x20,0xfc,0x20,0xfe,0x00,0xfc,0x04,0xfc,0x04,0xfc,0x04,0x14,0x08,
+/* 64201 0xfac9 "韛" */
+0x10,0x10,0x7d,0x24,0xfe,0x01,0x7c,0x44,0x7d,0x12,0x7c,0x10,0x50,0x7c,0x10,0x10,
+0x44,0x44,0xfe,0x44,0x44,0xfe,0x40,0xfe,0x92,0xfe,0x92,0xfe,0x92,0x92,0x92,0x86,
+/* 64202 0xfaca "響" */
+0x11,0x23,0x7a,0x13,0x2a,0x7b,0x12,0x23,0x01,0x3f,0x04,0xff,0x10,0x1f,0x10,0x1f,
+0x00,0xde,0x52,0xd4,0x52,0xda,0x94,0x50,0x00,0xf8,0x40,0xfe,0x10,0xf0,0x10,0xf0,
+/* 64203 0xfacb "頋" */
+0x7e,0x40,0x40,0x5e,0x52,0x52,0x52,0x5a,0x54,0x50,0x52,0x54,0x58,0x50,0x81,0x00,
+0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,0x00,
+/* 64204 0xfacc "頻" */
+0x08,0x08,0x28,0x2e,0x28,0x28,0xff,0x00,0x08,0x2a,0x2a,0x4c,0x84,0x08,0x30,0xc1,
+0x00,0xfe,0x10,0x20,0xfc,0x84,0x84,0xfc,0x84,0xfc,0x84,0x84,0xfc,0x48,0x84,0x02,
+/* 64205 0xfacd "鬒" */
+0x3f,0x20,0xff,0x22,0x7f,0x01,0x7f,0x01,0x1f,0x10,0x11,0x11,0xff,0x08,0x10,0x20,
+0x04,0x18,0x62,0x0c,0x70,0x00,0xfc,0x00,0xf0,0x10,0x10,0x10,0xfe,0x20,0x10,0x08,
+/* 64206 0xface "龜" */
+0x04,0x3f,0x20,0x3e,0x02,0x7a,0x0a,0xfe,0x0a,0x7a,0x02,0x7a,0x0a,0xfe,0x0a,0x79,
+0x00,0xf8,0x08,0xf8,0x80,0x80,0xfc,0x94,0xd4,0xa4,0xa4,0xd4,0x94,0xfc,0x82,0xfe,
+/* 64207 0xfacf "𢡊" */
+0x20,0x27,0x21,0x31,0xaf,0xa1,0xa2,0x24,0x28,0x21,0x22,0x2a,0x2a,0x32,0x22,0x21,
+0xcc,0x30,0x10,0x10,0xfe,0x10,0xa8,0x28,0x44,0x02,0x90,0x48,0x54,0x14,0x10,0xf0,
+/* 64208 0xfad0 "𢡄" */
+0x20,0x27,0x21,0x31,0xaf,0xa1,0xa2,0x24,0x28,0x23,0x22,0x23,0x22,0x22,0x23,0x22,
+0xcc,0x30,0x10,0x10,0xfe,0x10,0xa8,0x28,0x44,0xfa,0x08,0xf8,0x08,0x08,0xf8,0x08,
+/* 64209 0xfad1 "𣏕" */
+0x10,0x10,0x10,0x13,0xfc,0x10,0x38,0x34,0x50,0x50,0x91,0x11,0x12,0x14,0x10,0x10,
+0x28,0x24,0x20,0xfe,0x20,0xa8,0xa8,0xa8,0xa8,0xa8,0x28,0x2a,0x2a,0x26,0x20,0x20,
+/* 64210 0xfad2 "㮝" */
+0x20,0x22,0x22,0x22,0xf5,0x21,0x22,0x72,0x6c,0xa3,0xa2,0x22,0x22,0x22,0x23,0x22,
+0x00,0x9e,0x52,0x52,0x52,0x12,0x92,0x52,0x32,0xd2,0x5a,0x54,0x50,0x50,0xd0,0x50,
+/* 64211 0xfad3 "䀘" */
+0x03,0x78,0x48,0x48,0x78,0x48,0x4f,0x78,0x48,0x48,0x48,0x79,0x49,0x02,0x04,0x00,
+0xfc,0x90,0x90,0x90,0x90,0x90,0xfe,0x90,0x90,0x90,0x90,0x10,0x10,0x10,0x10,0x00,
+/* 64212 0xfad4 "䀹" */
+0x00,0x00,0x78,0x4b,0x48,0x78,0x49,0x49,0x79,0x4a,0x48,0x48,0x78,0x48,0x01,0x02,
+0x20,0x20,0x20,0xfe,0x20,0x20,0x24,0x24,0x24,0xaa,0x20,0x50,0x50,0x88,0x04,0x02,
+/* 64213 0xfad5 "𥉉" */
+0x02,0x02,0xf4,0x94,0x9d,0xf5,0x95,0x95,0xf5,0x95,0x95,0x95,0xf4,0x94,0x04,0x04,
+0x20,0x20,0x7c,0x44,0xa8,0x10,0x28,0xd6,0x10,0xfe,0x10,0x38,0x54,0x92,0x10,0x10,
+/* 64214 0xfad6 "𥳐" */
+0x10,0x1f,0x28,0x45,0xbe,0x22,0x3e,0x22,0x3e,0x20,0x2e,0x24,0x2e,0x24,0x28,0x20,
+0x40,0x7e,0x90,0x08,0xf8,0x88,0xf8,0x88,0xf8,0x08,0xe8,0x48,0xe8,0x48,0x48,0x18,
+/* 64215 0xfad7 "𧻓" */
+0x10,0x10,0x13,0xfc,0x10,0x10,0x13,0xfc,0x10,0x10,0x5c,0x51,0x52,0x70,0x8c,0x83,
+0x44,0x88,0xde,0x88,0x88,0x88,0xde,0x88,0x88,0x88,0x88,0x08,0x08,0x00,0x00,0xfe,
+/* 64216 0xfad8 "齃" */
+0x20,0x7c,0x44,0x7c,0x44,0x7c,0x00,0xfe,0x93,0xfe,0x92,0xfe,0x00,0xfe,0x44,0x84,
+0x00,0xfc,0x84,0xfc,0x84,0xfc,0x40,0xfe,0x12,0x92,0xaa,0x82,0xfa,0x02,0x14,0x08,
+/* 64217 0xfad9 "龎" */
+0x3f,0x22,0x2f,0x25,0x22,0x3f,0x20,0x2f,0x28,0x2f,0x28,0x2f,0x48,0x48,0x89,0x00,
+0xfe,0x20,0xbc,0x20,0x3c,0x84,0x3c,0xa0,0xbc,0xa0,0xbc,0xa0,0xbc,0xa2,0x9e,0x00,
+/* 64218 0xfada "﫚" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64219 0xfadb "﫛" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64220 0xfadc "﫜" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64221 0xfadd "﫝" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64222 0xfade "﫞" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64223 0xfadf "﫟" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64224 0xfae0 "﫠" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 64225 0xfae1 "﫡" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 64226 0xfae2 "﫢" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 64227 0xfae3 "﫣" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 64228 0xfae4 "﫤" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 64229 0xfae5 "﫥" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 64230 0xfae6 "﫦" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 64231 0xfae7 "﫧" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 64232 0xfae8 "﫨" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 64233 0xfae9 "﫩" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 64234 0xfaea "﫪" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64235 0xfaeb "﫫" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64236 0xfaec "﫬" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64237 0xfaed "﫭" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64238 0xfaee "﫮" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64239 0xfaef "﫯" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64240 0xfaf0 "﫰" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 64241 0xfaf1 "﫱" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 64242 0xfaf2 "﫲" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 64243 0xfaf3 "﫳" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 64244 0xfaf4 "﫴" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 64245 0xfaf5 "﫵" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 64246 0xfaf6 "﫶" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 64247 0xfaf7 "﫷" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 64248 0xfaf8 "﫸" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 64249 0xfaf9 "﫹" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 64250 0xfafa "﫺" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64251 0xfafb "﫻" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64252 0xfafc "﫼" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64253 0xfafd "﫽" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64254 0xfafe "﫾" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64255 0xfaff "﫿" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64256 0xfb00 "ﬀ" */
+0x00,0x00,0x00,0x1b,0x24,0x24,0x24,0x7e,0x24,0x24,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64257 0xfb01 "ﬁ" */
+0x00,0x00,0x00,0x1c,0x22,0x20,0x20,0x7e,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64258 0xfb02 "ﬂ" */
+0x00,0x00,0x00,0x1e,0x22,0x22,0x22,0x7a,0x22,0x22,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64259 0xfb03 "ﬃ" */
+0x00,0x00,0x00,0x16,0x2a,0x28,0x28,0x7e,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64260 0xfb04 "ﬄ" */
+0x00,0x00,0x00,0x1e,0x2a,0x2a,0x2a,0x7e,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64261 0xfb05 "ﬅ" */
+0x00,0x00,0x00,0x38,0x48,0x48,0x48,0x5e,0x48,0x48,0x48,0x48,0x48,0x46,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64262 0xfb06 "ﬆ" */
+0x00,0x00,0x00,0x1c,0x24,0x24,0x24,0x36,0x44,0x44,0x24,0x14,0x14,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64263 0xfb07 "﬇" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 64264 0xfb08 "﬈" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 64265 0xfb09 "﬉" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 64266 0xfb0a "﬊" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64267 0xfb0b "﬋" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64268 0xfb0c "﬌" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64269 0xfb0d "﬍" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64270 0xfb0e "﬎" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64271 0xfb0f "﬏" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64272 0xfb10 "﬐" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 64273 0xfb11 "﬑" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 64274 0xfb12 "﬒" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 64275 0xfb13 "ﬓ" */
+0x00,0x00,0x00,0x00,0x08,0x14,0x30,0x5d,0x55,0x55,0x55,0x55,0x55,0x33,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64276 0xfb14 "ﬔ" */
+0x00,0x00,0x00,0x00,0x0c,0x14,0x14,0x57,0x54,0x54,0x55,0x55,0x55,0x36,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64277 0xfb15 "ﬕ" */
+0x00,0x00,0x00,0x00,0x0c,0x14,0x14,0x56,0x55,0x55,0x55,0x55,0x55,0x35,0x04,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64278 0xfb16 "ﬖ" */
+0x00,0x00,0x00,0x00,0x50,0x3c,0x14,0x55,0x55,0x55,0x55,0x55,0x55,0x33,0x10,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64279 0xfb17 "ﬗ" */
+0x00,0x00,0x00,0x00,0x18,0x28,0x28,0xad,0xad,0xad,0xad,0xad,0xad,0x6a,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64280 0xfb18 "﬘" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 64281 0xfb19 "﬙" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 64282 0xfb1a "﬚" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64283 0xfb1b "﬛" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64284 0xfb1c "﬜" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64285 0xfb1d "יִ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x04,0x04,0x04,0x00,0x04,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64286 0xfb1e "ﬞ" */
+0x00,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64287 0xfb1f "ײַ" */
+0x00,0x00,0x00,0x00,0x00,0x77,0x11,0x11,0x11,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64288 0xfb20 "ﬠ" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0x12,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64289 0xfb21 "ﬡ" */
+0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x30,0x0c,0x33,0x40,0x40,0x40,0x40,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x8c,0x70,0x0c,0x02,0x02,0x00,0x00,
+/* 64290 0xfb22 "ﬢ" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x00,
+/* 64291 0xfb23 "ﬣ" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+/* 64292 0xfb24 "ﬤ" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfc,0x00,0x00,
+/* 64293 0xfb25 "ﬥ" */
+0x00,0x00,0x00,0x20,0x20,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x04,0x08,0x30,0xc0,0x00,0x00,
+/* 64294 0xfb26 "ﬦ" */
+0x00,0x00,0x00,0x00,0x00,0xff,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,
+/* 64295 0xfb27 "ﬧ" */
+0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+/* 64296 0xfb28 "ﬨ" */
+0x00,0x00,0x00,0x00,0x00,0x3f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x60,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x00,0x00,
+/* 64297 0xfb29 "﬩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x7f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64298 0xfb2a "שׁ" */
+0x00,0x00,0x00,0x01,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64299 0xfb2b "שׂ" */
+0x00,0x00,0x00,0x40,0x00,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64300 0xfb2c "שּׁ" */
+0x00,0x00,0x00,0x01,0x00,0x49,0x49,0x49,0x49,0x4d,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64301 0xfb2d "שּׂ" */
+0x00,0x00,0x00,0x40,0x00,0x49,0x49,0x49,0x49,0x4d,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64302 0xfb2e "אַ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x12,0x2c,0x48,0x44,0x42,0x42,0x00,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64303 0xfb2f "אָ" */
+0x00,0x00,0x00,0x00,0x00,0x46,0x42,0x22,0x12,0x2c,0x48,0x44,0x42,0x41,0x1c,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64304 0xfb30 "אּ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x22,0x12,0x2c,0x48,0x44,0x42,0x41,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64305 0xfb31 "בּ" */
+0x00,0x00,0x00,0x00,0x00,0x7c,0x04,0x04,0x04,0x24,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64306 0xfb32 "גּ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x08,0x08,0x08,0x44,0x0c,0x14,0x22,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64307 0xfb33 "דּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x04,0x04,0x04,0x24,0x04,0x04,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64308 0xfb34 "הּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x22,0x2a,0x22,0x22,0x22,0x22,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64309 0xfb35 "וּ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x28,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64310 0xfb36 "זּ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x0c,0x0a,0x08,0x28,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64311 0xfb37 "﬷" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 64312 0xfb38 "טּ" */
+0x00,0x00,0x00,0x00,0x00,0x46,0x4a,0x42,0x42,0x52,0x42,0x42,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64313 0xfb39 "יּ" */
+0x00,0x00,0x00,0x00,0x00,0x38,0x08,0x08,0x08,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64314 0xfb3a "ךּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x12,0x02,0x02,0x02,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64315 0xfb3b "כּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x12,0x02,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64316 0xfb3c "לּ" */
+0x00,0x00,0x00,0x20,0x20,0x3e,0x02,0x02,0x02,0x12,0x04,0x04,0x08,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64317 0xfb3d "﬽" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64318 0xfb3e "מּ" */
+0x00,0x00,0x00,0x00,0x00,0x4e,0x31,0x21,0x41,0x49,0x41,0x41,0x41,0x47,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64319 0xfb3f "﬿" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x7d,0x71,0x7d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64320 0xfb40 "נּ" */
+0x00,0x00,0x00,0x00,0x00,0x1c,0x04,0x04,0x04,0x24,0x04,0x04,0x04,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64321 0xfb41 "סּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x52,0x42,0x42,0x44,0x78,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64322 0xfb42 "﭂" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 64323 0xfb43 "ףּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x72,0x02,0x02,0x12,0x02,0x02,0x02,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64324 0xfb44 "פּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x72,0x02,0x12,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64325 0xfb45 "﭅" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x6d,0x6d,0x61,0x7d,0x7d,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 64326 0xfb46 "צּ" */
+0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x24,0x18,0x08,0x44,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64327 0xfb47 "קּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x22,0x2a,0x22,0x24,0x28,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64328 0xfb48 "רּ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x12,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64329 0xfb49 "שּ" */
+0x00,0x00,0x00,0x00,0x00,0x49,0x49,0x49,0x49,0x4d,0x49,0x49,0x49,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64330 0xfb4a "תּ" */
+0x00,0x00,0x00,0x00,0x00,0x3e,0x22,0x22,0x22,0x2a,0x22,0x22,0x22,0x62,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64331 0xfb4b "וֹ" */
+0x00,0x00,0x00,0x20,0x00,0x38,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64332 0xfb4c "בֿ" */
+0x00,0x00,0x00,0x3c,0x00,0x7c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64333 0xfb4d "כֿ" */
+0x00,0x00,0x00,0x3c,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64334 0xfb4e "פֿ" */
+0x00,0x00,0x00,0x3c,0x00,0x7e,0x42,0x42,0x42,0x72,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64335 0xfb4f "ﭏ" */
+0x00,0x00,0x60,0x20,0x20,0x46,0x42,0x22,0x12,0x2c,0x48,0x44,0x42,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64336 0xfb50 "ﭐ" */
+0x04,0x0a,0x1e,0x20,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64337 0xfb51 "ﭑ" */
+0x10,0x28,0x78,0x80,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64338 0xfb52 "ﭒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64339 0xfb53 "ﭓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64340 0xfb54 "ﭔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64341 0xfb55 "ﭕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64342 0xfb56 "ﭖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64343 0xfb57 "ﭗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64344 0xfb58 "ﭘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64345 0xfb59 "ﭙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x14,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64346 0xfb5a "ﭚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x14,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64347 0xfb5b "ﭛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x14,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64348 0xfb5c "ﭜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x14,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64349 0xfb5d "ﭝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x14,0x00,0x14,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64350 0xfb5e "ﭞ" */
+0x00,0x00,0x08,0x00,0x08,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64351 0xfb5f "ﭟ" */
+0x00,0x00,0x08,0x00,0x08,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64352 0xfb60 "ﭠ" */
+0x00,0x00,0x08,0x00,0x08,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64353 0xfb61 "ﭡ" */
+0x00,0x00,0x08,0x00,0x08,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64354 0xfb62 "ﭢ" */
+0x00,0x00,0x14,0x00,0x14,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64355 0xfb63 "ﭣ" */
+0x00,0x00,0x14,0x00,0x14,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64356 0xfb64 "ﭤ" */
+0x00,0x00,0x14,0x00,0x14,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64357 0xfb65 "ﭥ" */
+0x00,0x00,0x14,0x00,0x14,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64358 0xfb66 "ﭦ" */
+0x00,0x00,0x20,0x20,0x38,0x38,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64359 0xfb67 "ﭧ" */
+0x00,0x00,0x20,0x20,0x38,0x38,0x00,0x04,0x22,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64360 0xfb68 "ﭨ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64361 0xfb69 "ﭩ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x08,0x04,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64362 0xfb6a "ﭪ" */
+0x00,0x08,0x00,0x12,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64363 0xfb6b "ﭫ" */
+0x00,0x08,0x00,0x12,0x00,0x06,0x0a,0x06,0x42,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64364 0xfb6c "ﭬ" */
+0x00,0x10,0x00,0x24,0x00,0x00,0x38,0x24,0x14,0x0c,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64365 0xfb6d "ﭭ" */
+0x00,0x10,0x00,0x24,0x00,0x00,0x38,0x24,0x14,0x0c,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64366 0xfb6e "ﭮ" */
+0x00,0x0a,0x00,0x0a,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64367 0xfb6f "ﭯ" */
+0x00,0x0a,0x00,0x0a,0x00,0x06,0x0a,0x06,0x42,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64368 0xfb70 "ﭰ" */
+0x00,0x28,0x00,0x28,0x00,0x00,0x38,0x24,0x14,0x0c,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64369 0xfb71 "ﭱ" */
+0x00,0x28,0x00,0x28,0x00,0x00,0x38,0x24,0x14,0x0c,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64370 0xfb72 "ﭲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x48,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64371 0xfb73 "ﭳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x14,0x23,0x48,0x40,0x48,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64372 0xfb74 "ﭴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xfc,0x00,0x20,0x00,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64373 0xfb75 "ﭵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x20,0x00,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64374 0xfb76 "ﭶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x54,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64375 0xfb77 "ﭷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x14,0x23,0x40,0x54,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64376 0xfb78 "ﭸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xfc,0x00,0x50,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64377 0xfb79 "ﭹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x50,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64378 0xfb7a "ﭺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x40,0x54,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64379 0xfb7b "ﭻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x22,0x41,0x54,0x40,0x48,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64380 0xfb7c "ﭼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xfc,0x00,0x28,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64381 0xfb7d "ﭽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x28,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64382 0xfb7e "ﭾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x20,0x40,0x54,0x40,0x54,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64383 0xfb7f "ﭿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x43,0x54,0x40,0x54,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64384 0xfb80 "ﮀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xfc,0x00,0x50,0x00,0x50,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64385 0xfb81 "ﮁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x50,0x00,0x50,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64386 0xfb82 "ﮂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64387 0xfb83 "ﮃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7f,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64388 0xfb84 "ﮄ" */
+0x00,0x00,0x00,0x28,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64389 0xfb85 "ﮅ" */
+0x00,0x00,0x00,0x28,0x00,0x00,0x08,0x04,0x02,0x42,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64390 0xfb86 "ﮆ" */
+0x00,0x00,0x10,0x00,0x28,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64391 0xfb87 "ﮇ" */
+0x00,0x00,0x10,0x00,0x28,0x00,0x08,0x04,0x02,0x42,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64392 0xfb88 "ﮈ" */
+0x00,0x20,0x20,0x38,0x38,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64393 0xfb89 "ﮉ" */
+0x00,0x20,0x20,0x38,0x38,0x00,0x08,0x04,0x02,0x42,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64394 0xfb8a "ﮊ" */
+0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64395 0xfb8b "ﮋ" */
+0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x00,0x04,0x02,0x03,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64396 0xfb8c "ﮌ" */
+0x00,0x00,0x00,0x08,0x08,0x0e,0x0e,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64397 0xfb8d "ﮍ" */
+0x00,0x00,0x00,0x08,0x08,0x0e,0x0e,0x00,0x04,0x02,0x03,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64398 0xfb8e "ﮎ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64399 0xfb8f "ﮏ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x82,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64400 0xfb90 "ﮐ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64401 0xfb91 "ﮑ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x02,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64402 0xfb92 "ﮒ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64403 0xfb93 "ﮓ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64404 0xfb94 "ﮔ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64405 0xfb95 "ﮕ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x02,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64406 0xfb96 "ﮖ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7e,0x00,0x10,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64407 0xfb97 "ﮗ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x82,0x7f,0x00,0x10,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64408 0xfb98 "ﮘ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x02,0xfe,0x00,0x10,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64409 0xfb99 "ﮙ" */
+0x00,0x08,0x10,0x24,0x48,0x10,0x20,0x40,0x3c,0x02,0xff,0x00,0x10,0x00,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64410 0xfb9a "ﮚ" */
+0x00,0x50,0x06,0x18,0x62,0x0c,0x30,0x40,0x3c,0x82,0x7e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64411 0xfb9b "ﮛ" */
+0x00,0x50,0x06,0x18,0x62,0x0c,0x30,0x40,0x3c,0x82,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64412 0xfb9c "ﮜ" */
+0x00,0x50,0x06,0x18,0x62,0x0c,0x30,0x40,0x3c,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64413 0xfb9d "ﮝ" */
+0x00,0x50,0x06,0x18,0x62,0x0c,0x30,0x40,0x3c,0x02,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64414 0xfb9e "ﮞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64415 0xfb9f "ﮟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x43,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64416 0xfba0 "ﮠ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64417 0xfba1 "ﮡ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x00,0x04,0x22,0x43,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64418 0xfba2 "ﮢ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64419 0xfba3 "ﮣ" */
+0x00,0x00,0x10,0x10,0x1c,0x1c,0x00,0x08,0x04,0x04,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64420 0xfba4 "ﮤ" */
+0x00,0x18,0x20,0x18,0x20,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64421 0xfba5 "ﮥ" */
+0x18,0x20,0x18,0x20,0x04,0x04,0x0c,0x14,0x24,0x3c,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64422 0xfba6 "ﮦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64423 0xfba7 "ﮧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2f,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64424 0xfba8 "ﮨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xf0,0x10,0x10,0x14,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64425 0xfba9 "ﮩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xf3,0x14,0x14,0x14,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64426 0xfbaa "ﮪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2c,0x2a,0x1a,0x24,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64427 0xfbab "ﮫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2c,0x2a,0x1a,0x27,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64428 0xfbac "ﮬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2c,0x2a,0x1a,0xe4,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64429 0xfbad "ﮭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x2c,0x2a,0x1a,0xe7,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64430 0xfbae "ﮮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64431 0xfbaf "ﮯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64432 0xfbb0 "ﮰ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x30,0x40,0x08,0x14,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64433 0xfbb1 "ﮱ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x30,0x40,0x00,0x0f,0x10,0x20,0x40,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64434 0xfbb2 "﮲" */
+0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64435 0xfbb3 "﮳" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64436 0xfbb4 "﮴" */
+0x00,0x00,0x0c,0x6c,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64437 0xfbb5 "﮵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x6c,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64438 0xfbb6 "﮶" */
+0x00,0x30,0x30,0x00,0x6c,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64439 0xfbb7 "﮷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x6c,0x6c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64440 0xfbb8 "﮸" */
+0x00,0x6c,0x6c,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64441 0xfbb9 "﮹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x6c,0x00,0x18,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64442 0xfbba "﮺" */
+0x00,0x0c,0x6c,0x60,0x03,0x1b,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64443 0xfbbb "﮻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x6c,0x60,0x03,0x1b,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64444 0xfbbc "﮼" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x12,0x12,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64445 0xfbbd "﮽" */
+0x00,0x30,0x30,0x00,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64446 0xfbbe "﮾" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x0c,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64447 0xfbbf "﮿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x24,0x28,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64448 0xfbc0 "﯀" */
+0x00,0x10,0x10,0x1c,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64449 0xfbc1 "﯁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x1c,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64450 0xfbc2 "﯂" */
+0x04,0x0a,0x1e,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64451 0xfbc3 "﯃" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 64452 0xfbc4 "﯄" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 64453 0xfbc5 "﯅" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 64454 0xfbc6 "﯆" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 64455 0xfbc7 "﯇" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 64456 0xfbc8 "﯈" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 64457 0xfbc9 "﯉" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 64458 0xfbca "﯊" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64459 0xfbcb "﯋" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64460 0xfbcc "﯌" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64461 0xfbcd "﯍" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64462 0xfbce "﯎" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64463 0xfbcf "﯏" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 64464 0xfbd0 "﯐" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 64465 0xfbd1 "﯑" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 64466 0xfbd2 "﯒" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 64467 0xfbd3 "ﯓ" */
+0x10,0x00,0x28,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64468 0xfbd4 "ﯔ" */
+0x10,0x00,0x28,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64469 0xfbd5 "ﯕ" */
+0x20,0x00,0x50,0x04,0x08,0x10,0x20,0x40,0x3c,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64470 0xfbd6 "ﯖ" */
+0x20,0x00,0x50,0x04,0x08,0x10,0x20,0x40,0x3c,0x02,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64471 0xfbd7 "ﯗ" */
+0x00,0x00,0x18,0x18,0x08,0x10,0x20,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64472 0xfbd8 "ﯘ" */
+0x00,0x00,0x18,0x18,0x08,0x10,0x20,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64473 0xfbd9 "ﯙ" */
+0x00,0x00,0x00,0x22,0x14,0x08,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64474 0xfbda "ﯚ" */
+0x00,0x00,0x00,0x22,0x14,0x08,0x00,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64475 0xfbdb "ﯛ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64476 0xfbdc "ﯜ" */
+0x00,0x00,0x00,0x08,0x04,0x04,0x00,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64477 0xfbdd "ﯝ" */
+0x00,0x00,0x30,0x33,0x14,0x23,0x44,0x10,0x28,0x28,0x38,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64478 0xfbde "ﯞ" */
+0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64479 0xfbdf "ﯟ" */
+0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64480 0xfbe0 "ﯠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x3c,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64481 0xfbe1 "ﯡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1f,0x02,0x3c,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64482 0xfbe2 "ﯢ" */
+0x00,0x00,0x00,0x08,0x14,0x22,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64483 0xfbe3 "ﯣ" */
+0x00,0x00,0x00,0x08,0x14,0x22,0x00,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64484 0xfbe4 "ﯤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0x48,0x44,0x38,0x00,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64485 0xfbe5 "ﯥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x52,0x49,0x30,0x00,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64486 0xfbe6 "ﯦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xf8,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64487 0xfbe7 "ﯧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xfb,0x00,0x08,0x00,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64488 0xfbe8 "ﯨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64489 0xfbe9 "ﯩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64490 0xfbea "ﯪ" */
+0x00,0x00,0x00,0x4c,0x50,0x4c,0x50,0x40,0x44,0x44,0x38,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64491 0xfbeb "ﯫ" */
+0x00,0x00,0x00,0x4c,0x50,0x4c,0x50,0x40,0x44,0x44,0x3b,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64492 0xfbec "ﯬ" */
+0x00,0x00,0x00,0x06,0x08,0x06,0x08,0x00,0x02,0x12,0x2c,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64493 0xfbed "ﯭ" */
+0x00,0x00,0x00,0x06,0x08,0x06,0x08,0x00,0x02,0x12,0x2d,0x40,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64494 0xfbee "ﯮ" */
+0x00,0x00,0x00,0x03,0x04,0x03,0x04,0x10,0x2a,0x2a,0x3c,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64495 0xfbef "ﯯ" */
+0x00,0x00,0x00,0x03,0x04,0x03,0x04,0x10,0x2a,0x2a,0x3d,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64496 0xfbf0 "ﯰ" */
+0x00,0x00,0x30,0x33,0x14,0x23,0x44,0x10,0x2a,0x2a,0x3c,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64497 0xfbf1 "ﯱ" */
+0x00,0x00,0x30,0x33,0x14,0x23,0x44,0x10,0x2a,0x2a,0x3d,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64498 0xfbf2 "ﯲ" */
+0x00,0x00,0x88,0x53,0x24,0x23,0x04,0x10,0x2a,0x2a,0x3c,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64499 0xfbf3 "ﯳ" */
+0x00,0x00,0x88,0x53,0x24,0x23,0x04,0x10,0x2a,0x2a,0x3d,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64500 0xfbf4 "ﯴ" */
+0x00,0x00,0x00,0x23,0x14,0x13,0x04,0x10,0x2a,0x2a,0x3c,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64501 0xfbf5 "ﯵ" */
+0x00,0x00,0x00,0x23,0x14,0x13,0x04,0x10,0x2a,0x2a,0x3d,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64502 0xfbf6 "ﯶ" */
+0x00,0x0c,0x10,0x0c,0x10,0x04,0x04,0x0c,0x50,0x48,0x44,0x38,0x00,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64503 0xfbf7 "ﯷ" */
+0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x04,0x4c,0x52,0x49,0x30,0x00,0x10,0x00,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64504 0xfbf8 "ﯸ" */
+0x00,0x00,0x06,0x08,0x06,0x08,0x00,0x22,0x22,0x12,0xec,0x00,0x20,0x00,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64505 0xfbf9 "ﯹ" */
+0x00,0x00,0x06,0x08,0x06,0x08,0x02,0x02,0x02,0x06,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64506 0xfbfa "ﯺ" */
+0x00,0x00,0x06,0x08,0x06,0x08,0x00,0x02,0x02,0x05,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64507 0xfbfb "ﯻ" */
+0x00,0x00,0x06,0x08,0x06,0x08,0x00,0x22,0x22,0x12,0xec,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64508 0xfbfc "ﯼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64509 0xfbfd "ﯽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x43,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64510 0xfbfe "ﯾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xf8,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64511 0xfbff "ﯿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xfb,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64512 0xfc00 "ﰀ" */
+0x00,0x00,0x00,0x60,0x80,0x60,0x8c,0x30,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64513 0xfc01 "ﰁ" */
+0x00,0x00,0x00,0x60,0x80,0x60,0x8c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64514 0xfc02 "ﰂ" */
+0x00,0x00,0x00,0x18,0x20,0x18,0x23,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64515 0xfc03 "ﰃ" */
+0x00,0x00,0x00,0x30,0x40,0x30,0x44,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64516 0xfc04 "ﰄ" */
+0x00,0x00,0x00,0x30,0x40,0x30,0x44,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64517 0xfc05 "ﰅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x7e,0x20,0x42,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64518 0xfc06 "ﰆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x7e,0x20,0x42,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64519 0xfc07 "ﰇ" */
+0x00,0x00,0x00,0x00,0x20,0x00,0x0c,0x30,0x40,0x7e,0x20,0x42,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64520 0xfc08 "ﰈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x3c,0x41,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64521 0xfc09 "ﰉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64522 0xfc0a "ﰊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x01,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64523 0xfc0b "ﰋ" */
+0x00,0x00,0x00,0x00,0x28,0x00,0x0c,0x30,0x40,0x7e,0x20,0x42,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64524 0xfc0c "ﰌ" */
+0x00,0x00,0x00,0x00,0x28,0x00,0x0c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64525 0xfc0d "ﰍ" */
+0x00,0x00,0x00,0x00,0x28,0x00,0x8c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64526 0xfc0e "ﰎ" */
+0x00,0x00,0x00,0x05,0x00,0x00,0x03,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64527 0xfc0f "ﰏ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64528 0xfc10 "ﰐ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64529 0xfc11 "ﰑ" */
+0x00,0x00,0x00,0x40,0x00,0xa0,0x0c,0x30,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64530 0xfc12 "ﰒ" */
+0x00,0x00,0x00,0x10,0x00,0x28,0x03,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64531 0xfc13 "ﰓ" */
+0x00,0x00,0x00,0x20,0x00,0x50,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64532 0xfc14 "ﰔ" */
+0x00,0x00,0x00,0x20,0x00,0x50,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64533 0xfc15 "ﰕ" */
+0x00,0x00,0x00,0x70,0x0c,0x02,0x0c,0x30,0x40,0x78,0x22,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64534 0xfc16 "ﰖ" */
+0x00,0x00,0x00,0x30,0x0c,0x02,0x03,0x04,0x08,0x08,0x3c,0x41,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64535 0xfc17 "ﰗ" */
+0x00,0x00,0x00,0x70,0x0c,0x02,0x0c,0x30,0x40,0x7e,0x20,0x42,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64536 0xfc18 "ﰘ" */
+0x00,0x00,0x00,0x30,0x0c,0x02,0x03,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64537 0xfc19 "ﰙ" */
+0x00,0x00,0x04,0x70,0x0c,0x02,0x0c,0x30,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64538 0xfc1a "ﰚ" */
+0x00,0x00,0x04,0x70,0x0c,0x02,0x0c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64539 0xfc1b "ﰛ" */
+0x00,0x00,0x00,0x31,0x0c,0x02,0x03,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64540 0xfc1c "ﰜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x25,0x5a,0x40,0x7e,0x20,0x42,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64541 0xfc1d "ﰝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x25,0x5a,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64542 0xfc1e "ﰞ" */
+0x00,0x00,0x00,0x00,0x40,0x00,0x25,0x5a,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64543 0xfc1f "ﰟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x94,0x68,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64544 0xfc20 "ﰠ" */
+0x00,0x00,0x00,0x00,0x06,0x09,0x1e,0x28,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64545 0xfc21 "ﰡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x38,0x44,0xf8,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64546 0xfc22 "ﰢ" */
+0x00,0x00,0x00,0x00,0x26,0x09,0x1e,0x28,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64547 0xfc23 "ﰣ" */
+0x00,0x00,0x00,0x00,0x26,0x09,0x1e,0x28,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64548 0xfc24 "ﰤ" */
+0x00,0x00,0x00,0x00,0x26,0x89,0x1e,0x28,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64549 0xfc25 "ﰥ" */
+0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x02,0x04,0x04,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x38,0x44,0xf8,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64550 0xfc26 "ﰦ" */
+0x00,0x00,0x00,0x20,0x2c,0x32,0x3c,0x20,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64551 0xfc27 "ﰧ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x0e,0x09,0x16,0x10,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64552 0xfc28 "ﰨ" */
+0x00,0x00,0x00,0x08,0x0a,0x08,0x0e,0x09,0x16,0x10,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64553 0xfc29 "ﰩ" */
+0x00,0x00,0x00,0x30,0x40,0x38,0x10,0x20,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64554 0xfc2a "ﰪ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x0f,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64555 0xfc2b "ﰫ" */
+0x00,0x00,0x80,0x30,0x40,0x38,0x10,0x20,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64556 0xfc2c "ﰬ" */
+0x00,0x00,0x08,0x00,0x0c,0x10,0x0f,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64557 0xfc2d "ﰭ" */
+0x00,0x00,0x80,0x20,0x50,0x30,0x10,0x20,0x7e,0x10,0x20,0x40,0x48,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64558 0xfc2e "ﰮ" */
+0x00,0x00,0x80,0x20,0x50,0x30,0x10,0x20,0x7e,0x10,0x20,0x40,0x40,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64559 0xfc2f "ﰯ" */
+0x00,0x00,0x80,0x20,0x50,0x30,0x90,0x20,0x7e,0x10,0x20,0x40,0x40,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64560 0xfc30 "ﰰ" */
+0x00,0x00,0x00,0x40,0x10,0x28,0x18,0x08,0x10,0x20,0x10,0x38,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64561 0xfc31 "ﰱ" */
+0x00,0x00,0x04,0x00,0x00,0x0c,0x0a,0x06,0x02,0x46,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64562 0xfc32 "ﰲ" */
+0x00,0x00,0x04,0x00,0x00,0x0c,0x0a,0x06,0x02,0x46,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64563 0xfc33 "ﰳ" */
+0x00,0x00,0x00,0x50,0x00,0x20,0x50,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64564 0xfc34 "ﰴ" */
+0x00,0x00,0x28,0x00,0x10,0x28,0x18,0x08,0x10,0x20,0x10,0x38,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64565 0xfc35 "ﰵ" */
+0x00,0x00,0x14,0x00,0x00,0x0c,0x0a,0x06,0x02,0x46,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64566 0xfc36 "ﰶ" */
+0x00,0x00,0x14,0x00,0x00,0x0c,0x0a,0x06,0x02,0x46,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64567 0xfc37 "ﰷ" */
+0x00,0x00,0x00,0x04,0x88,0x90,0xa0,0xc0,0xbc,0x82,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64568 0xfc38 "ﰸ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x10,0x20,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64569 0xfc39 "ﰹ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x10,0x20,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64570 0xfc3a "ﰺ" */
+0x00,0x00,0x00,0x00,0x08,0x10,0x20,0x90,0x20,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64571 0xfc3b "ﰻ" */
+0x00,0x00,0x00,0x10,0x10,0x12,0x14,0x18,0x14,0x12,0x1c,0x90,0x90,0x90,0x90,0x60,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64572 0xfc3c "ﰼ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x10,0x08,0x10,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64573 0xfc3d "ﰽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x11,0x11,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x80,0x40,0x80,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 64574 0xfc3e "ﰾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x11,0x11,0x08,0x07,0x00,0x05,
+0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x80,0x40,0x80,0x00,0x80,0x80,0x00,0x00,0x00,
+/* 64575 0xfc3f "ﰿ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0x7e,0x10,0x20,0x40,0x48,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64576 0xfc40 "ﱀ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0x7e,0x10,0x20,0x40,0x40,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64577 0xfc41 "ﱁ" */
+0x00,0x00,0x10,0x10,0x10,0x50,0x10,0x20,0x7e,0x10,0x20,0x40,0x40,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64578 0xfc42 "ﱂ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64579 0xfc43 "ﱃ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x06,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64580 0xfc44 "ﱄ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x06,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64581 0xfc45 "ﱅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64582 0xfc46 "ﱆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64583 0xfc47 "ﱇ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x0c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64584 0xfc48 "ﱈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64585 0xfc49 "ﱉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x08,0x44,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64586 0xfc4a "ﱊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x04,0x08,0x44,0x42,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64587 0xfc4b "ﱋ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x0c,0x30,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64588 0xfc4c "ﱌ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x0c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64589 0xfc4d "ﱍ" */
+0x00,0x00,0x00,0x00,0x08,0x20,0x0c,0x30,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64590 0xfc4e "ﱎ" */
+0x00,0x00,0x00,0x02,0x00,0x00,0x03,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64591 0xfc4f "ﱏ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64592 0xfc50 "ﱐ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x04,0x02,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64593 0xfc51 "ﱑ" */
+0x00,0x00,0x00,0x10,0x38,0x54,0x52,0x3c,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64594 0xfc52 "ﱒ" */
+0x00,0x00,0x00,0x20,0x18,0x34,0x54,0x38,0x08,0x10,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64595 0xfc53 "ﱓ" */
+0x00,0x00,0x00,0x00,0x06,0x0d,0x15,0x0e,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64596 0xfc54 "ﱔ" */
+0x00,0x00,0x00,0x00,0x06,0x0d,0x15,0x0e,0x02,0x22,0x44,0x46,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64597 0xfc55 "ﱕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x7e,0x20,0x4a,0x40,0x48,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64598 0xfc56 "ﱖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x40,0x7e,0x20,0x4a,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64599 0xfc57 "ﱗ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x0c,0x30,0x40,0x7e,0x20,0x4a,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64600 0xfc58 "ﱘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x3c,0x41,0x44,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64601 0xfc59 "ﱙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x22,0x44,0x46,0x22,0x1c,0x01,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64602 0xfc5a "ﱚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x22,0x44,0x46,0x22,0x1c,0x01,0x04,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64603 0xfc5b "ﱛ" */
+0x10,0x10,0x10,0x00,0x20,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64604 0xfc5c "ﱜ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64605 0xfc5d "ﱝ" */
+0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x00,0x04,0x0a,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64606 0xfc5e "ﱞ" */
+0x00,0x04,0x6a,0x24,0x18,0x00,0x54,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64607 0xfc5f "ﱟ" */
+0x00,0x54,0x54,0x7c,0x06,0x18,0x66,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64608 0xfc60 "ﱠ" */
+0x00,0x00,0x06,0x18,0x60,0x00,0x54,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64609 0xfc61 "ﱡ" */
+0x00,0x04,0x0a,0x04,0x7a,0x00,0x54,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64610 0xfc62 "ﱢ" */
+0x00,0x54,0x54,0x7c,0x00,0x06,0x18,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64611 0xfc63 "ﱣ" */
+0x00,0x00,0x08,0x08,0x08,0x00,0x54,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64612 0xfc64 "ﱤ" */
+0x00,0x00,0x18,0x20,0x18,0x22,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64613 0xfc65 "ﱥ" */
+0x00,0x00,0x18,0x20,0x98,0x22,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64614 0xfc66 "ﱦ" */
+0x00,0x00,0x00,0x18,0x20,0x18,0x23,0x04,0x08,0x08,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64615 0xfc67 "ﱧ" */
+0x00,0x00,0x00,0x18,0x20,0x98,0x02,0x06,0x0a,0x2a,0x45,0x44,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64616 0xfc68 "ﱨ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64617 0xfc69 "ﱩ" */
+0x00,0x00,0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64618 0xfc6a "ﱪ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x12,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64619 0xfc6b "ﱫ" */
+0x00,0x00,0x00,0x00,0x00,0x12,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x12,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64620 0xfc6c "ﱬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x3d,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64621 0xfc6d "ﱭ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x02,0x06,0x0a,0x2a,0x45,0x44,0x48,0x32,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64622 0xfc6e "ﱮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64623 0xfc6f "ﱯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x01,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64624 0xfc70 "ﱰ" */
+0x00,0x00,0x05,0x00,0x00,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64625 0xfc71 "ﱱ" */
+0x00,0x00,0x05,0x00,0x20,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64626 0xfc72 "ﱲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x0c,0x12,0x39,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64627 0xfc73 "ﱳ" */
+0x00,0x00,0x00,0x05,0x00,0x10,0x02,0x06,0x0a,0x2a,0x45,0x44,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64628 0xfc74 "ﱴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64629 0xfc75 "ﱵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64630 0xfc76 "ﱶ" */
+0x00,0x02,0x00,0x05,0x00,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64631 0xfc77 "ﱷ" */
+0x00,0x02,0x00,0x05,0x00,0x22,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64632 0xfc78 "ﱸ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x0c,0x12,0x39,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64633 0xfc79 "ﱹ" */
+0x00,0x00,0x02,0x00,0x05,0x00,0x12,0x06,0x0a,0x2a,0x45,0x44,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64634 0xfc7a "ﱺ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x05,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64635 0xfc7b "ﱻ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x05,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64636 0xfc7c "ﱼ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x0c,0x0a,0x46,0x89,0x8c,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64637 0xfc7d "ﱽ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x0c,0x0a,0x46,0x89,0x8c,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64638 0xfc7e "ﱾ" */
+0x00,0x00,0x00,0x00,0x0a,0x00,0x04,0x0a,0x07,0x22,0x44,0x46,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64639 0xfc7f "ﱿ" */
+0x00,0x00,0x00,0x00,0x0a,0x00,0x04,0x0a,0x07,0x22,0x44,0x46,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64640 0xfc80 "ﲀ" */
+0x00,0x00,0x21,0x22,0x24,0x28,0x30,0x28,0x2c,0x12,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64641 0xfc81 "ﲁ" */
+0x00,0x00,0x21,0x22,0x24,0x28,0x30,0xa8,0xac,0xb2,0x41,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64642 0xfc82 "ﲂ" */
+0x00,0x01,0x02,0x04,0x08,0x10,0x08,0x04,0x0a,0x11,0x08,0x1c,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64643 0xfc83 "ﲃ" */
+0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x08,0x04,0x46,0x89,0x8c,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64644 0xfc84 "ﲄ" */
+0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x08,0x04,0x46,0x89,0x8c,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64645 0xfc85 "ﲅ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x0f,0x08,0x0c,0x10,0x10,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64646 0xfc86 "ﲆ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x42,0x85,0x88,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64647 0xfc87 "ﲇ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x42,0x85,0x88,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64648 0xfc88 "ﲈ" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x20,0x27,0x18,0x0e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64649 0xfc89 "ﲉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x47,0xb8,0xae,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64650 0xfc8a "ﲊ" */
+0x00,0x00,0x00,0x02,0x00,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64651 0xfc8b "ﲋ" */
+0x00,0x00,0x00,0x02,0x10,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64652 0xfc8c "ﲌ" */
+0x00,0x00,0x00,0x00,0x02,0x00,0x02,0x06,0x0a,0x12,0x79,0x80,0x80,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64653 0xfc8d "ﲍ" */
+0x00,0x00,0x00,0x02,0x10,0x00,0x02,0x06,0x0a,0x2a,0x45,0x44,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64654 0xfc8e "ﲎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64655 0xfc8f "ﲏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64656 0xfc90 "ﲐ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x00,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64657 0xfc91 "ﲑ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x65,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64658 0xfc92 "ﲒ" */
+0x00,0x00,0x00,0x00,0x20,0x02,0x06,0x0a,0x12,0x0a,0x09,0x08,0x08,0x10,0x65,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64659 0xfc93 "ﲓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x3c,0x40,0x4a,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64660 0xfc94 "ﲔ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x02,0x06,0x0a,0x2a,0x45,0x44,0x48,0x30,0x05,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64661 0xfc95 "ﲕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x01,0x04,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64662 0xfc96 "ﲖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x49,0x44,0x42,0x3c,0x01,0x54,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64663 0xfc97 "ﲗ" */
+0x02,0x04,0x06,0x08,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64664 0xfc98 "ﲘ" */
+0x02,0x04,0x06,0x08,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64665 0xfc99 "ﲙ" */
+0x02,0x04,0x06,0x08,0x00,0x4c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64666 0xfc9a "ﲚ" */
+0x00,0x02,0x04,0x06,0x08,0x00,0x06,0x08,0x10,0x10,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64667 0xfc9b "ﲛ" */
+0x00,0x00,0x00,0x04,0x08,0x0c,0x10,0x00,0x26,0x69,0xe8,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64668 0xfc9c "ﲜ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x04,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64669 0xfc9d "ﲝ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64670 0xfc9e "ﲞ" */
+0x00,0x00,0x00,0x00,0x20,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64671 0xfc9f "ﲟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x08,0x10,0x10,0xf8,0x00,0x04,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64672 0xfca0 "ﲠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x26,0x69,0xe8,0x28,0x25,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64673 0xfca1 "ﲡ" */
+0x00,0x00,0x0a,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64674 0xfca2 "ﲢ" */
+0x00,0x00,0x0a,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64675 0xfca3 "ﲣ" */
+0x00,0x00,0x0a,0x00,0x20,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64676 0xfca4 "ﲤ" */
+0x00,0x00,0x00,0x0a,0x00,0x00,0x06,0x08,0x10,0x10,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64677 0xfca5 "ﲥ" */
+0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x26,0x69,0xe8,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64678 0xfca6 "ﲦ" */
+0x00,0x04,0x00,0x0a,0x00,0x00,0x06,0x08,0x10,0x10,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64679 0xfca7 "ﲧ" */
+0x00,0x60,0x58,0x04,0x1e,0x20,0x40,0x7e,0x18,0x62,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64680 0xfca8 "ﲨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x02,0x1f,0x28,0xd8,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64681 0xfca9 "ﲩ" */
+0x00,0x60,0x58,0x04,0x1e,0x20,0x40,0x7e,0x18,0x60,0x80,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64682 0xfcaa "ﲪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x03,0x1f,0x28,0xd8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64683 0xfcab "ﲫ" */
+0x08,0x60,0x58,0x04,0x1e,0x20,0x40,0x7e,0x18,0x60,0x80,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64684 0xfcac "ﲬ" */
+0x00,0x00,0x00,0x08,0x00,0x00,0x1c,0x03,0x1f,0x28,0xd8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64685 0xfcad "ﲭ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x7e,0x18,0x60,0x80,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x94,0x94,0x68,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64686 0xfcae "ﲮ" */
+0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x94,0x94,0x68,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64687 0xfcaf "ﲯ" */
+0x00,0x00,0x00,0x40,0x1f,0x20,0x40,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x94,0x94,0x68,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64688 0xfcb0 "ﲰ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x15,0x15,0x3e,0x40,0xe0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64689 0xfcb1 "ﲱ" */
+0x00,0x00,0x04,0x0a,0x11,0x20,0x40,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x14,0x24,0x48,0xf0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64690 0xfcb2 "ﲲ" */
+0x00,0x00,0x44,0x0a,0x11,0x20,0x40,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x08,0x14,0x24,0x48,0xf0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64691 0xfcb3 "ﲳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x2f,0x21,0x40,0xe0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x50,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64692 0xfcb4 "ﲴ" */
+0x00,0x00,0x04,0x0a,0x11,0x20,0x40,0x7e,0x18,0x60,0x80,0x08,0x00,0x00,0x00,0x00,
+0x80,0x08,0x14,0x24,0x48,0xf0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64693 0xfcb5 "ﲵ" */
+0x00,0x00,0x04,0x0a,0x11,0x20,0x40,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x80,0x08,0x14,0x24,0x48,0xf0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64694 0xfcb6 "ﲶ" */
+0x00,0x00,0x44,0x0a,0x11,0x20,0x40,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x80,0x08,0x14,0x24,0x48,0xf0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64695 0xfcb7 "ﲷ" */
+0x00,0x00,0x00,0x04,0x00,0x00,0x11,0x2f,0x21,0x40,0xe0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x20,0x50,0x90,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64696 0xfcb8 "ﲸ" */
+0x10,0x10,0x16,0x19,0x1e,0x20,0x78,0x06,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64697 0xfcb9 "ﲹ" */
+0x00,0x00,0x00,0x00,0x12,0x10,0x16,0x19,0x3e,0x40,0xf0,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64698 0xfcba "ﲺ" */
+0x00,0x00,0x30,0x42,0x4c,0x30,0x40,0x7e,0x18,0x60,0x80,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64699 0xfcbb "ﲻ" */
+0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x4c,0x30,0x40,0xf0,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64700 0xfcbc "ﲼ" */
+0x20,0x00,0x30,0x42,0x4c,0x30,0x40,0x7e,0x18,0x60,0x80,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64701 0xfcbd "ﲽ" */
+0x00,0x00,0x00,0x20,0x00,0x30,0x40,0x4c,0x30,0x40,0xf0,0x48,0x30,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64702 0xfcbe "ﲾ" */
+0x40,0x10,0x28,0x38,0x08,0x10,0x20,0x3e,0x0c,0x30,0xc0,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64703 0xfcbf "ﲿ" */
+0x40,0x10,0x28,0x38,0x08,0x10,0x20,0x3e,0x0c,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64704 0xfcc0 "ﳀ" */
+0x00,0x40,0x10,0x28,0x38,0x88,0x10,0x20,0x3e,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64705 0xfcc1 "ﳁ" */
+0x00,0x10,0x00,0x10,0x28,0x38,0x08,0x10,0x20,0x20,0xf0,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64706 0xfcc2 "ﳂ" */
+0x28,0x00,0x10,0x28,0x38,0x08,0x10,0x20,0x3e,0x0c,0xf0,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64707 0xfcc3 "ﳃ" */
+0x00,0x28,0x00,0x10,0x28,0x38,0x08,0x10,0x20,0x20,0xf0,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64708 0xfcc4 "ﳄ" */
+0x02,0x04,0x08,0x10,0x30,0x08,0x10,0x7e,0x18,0x60,0x80,0x08,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64709 0xfcc5 "ﳅ" */
+0x02,0x04,0x08,0x10,0x30,0x08,0x10,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64710 0xfcc6 "ﳆ" */
+0x02,0x04,0x08,0x10,0x30,0x88,0x10,0x7e,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64711 0xfcc7 "ﳇ" */
+0x00,0x02,0x44,0x48,0x50,0x60,0x78,0x44,0x44,0x24,0xd8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64712 0xfcc8 "ﳈ" */
+0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x10,0x20,0xf0,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64713 0xfcc9 "ﳉ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0x78,0x0c,0xf0,0x00,0x00,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64714 0xfcca "ﳊ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64715 0xfccb "ﳋ" */
+0x00,0x00,0x10,0x10,0x50,0x10,0x10,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64716 0xfccc "ﳌ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0xfc,0x02,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64717 0xfccd "ﳍ" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x1c,0x2a,0x3a,0xf6,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64718 0xfcce "ﳎ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x1c,0x20,0x78,0x0c,0xf0,0x00,0x00,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64719 0xfccf "ﳏ" */
+0x00,0x00,0x00,0x00,0x04,0x0a,0x1c,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64720 0xfcd0 "ﳐ" */
+0x00,0x00,0x00,0x00,0x24,0x0a,0x1c,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64721 0xfcd1 "ﳑ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x1e,0x20,0x20,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64722 0xfcd2 "ﳒ" */
+0x00,0x00,0x04,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64723 0xfcd3 "ﳓ" */
+0x00,0x00,0x04,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64724 0xfcd4 "ﳔ" */
+0x00,0x00,0x04,0x00,0x20,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64725 0xfcd5 "ﳕ" */
+0x00,0x00,0x00,0x04,0x00,0x00,0x06,0x08,0x10,0x10,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64726 0xfcd6 "ﳖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x26,0x6a,0xe8,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64727 0xfcd7 "ﳗ" */
+0x00,0x3c,0x12,0x29,0x29,0x3e,0x40,0x7e,0x18,0x60,0x80,0x10,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64728 0xfcd8 "ﳘ" */
+0x00,0x3c,0x12,0x29,0x29,0x1e,0x08,0x10,0x20,0x40,0xe0,0x50,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64729 0xfcd9 "ﳙ" */
+0x20,0x20,0x00,0x78,0x24,0x52,0x52,0x3c,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64730 0xfcda "ﳚ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x0a,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64731 0xfcdb "ﳛ" */
+0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64732 0xfcdc "ﳜ" */
+0x00,0x00,0x00,0x00,0x20,0x0c,0x14,0x20,0x78,0x0c,0xf0,0x00,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64733 0xfcdd "ﳝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x08,0x10,0x10,0xf8,0x00,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64734 0xfcde "ﳞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x50,0xd5,0x50,0x48,0x28,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64735 0xfcdf "ﳟ" */
+0x00,0x00,0x0c,0x10,0x0c,0x30,0x00,0x10,0x28,0x24,0xd3,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64736 0xfce0 "ﳠ" */
+0x00,0x00,0x00,0x06,0x08,0x06,0x18,0x00,0x24,0x6a,0xe9,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64737 0xfce1 "ﳡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x24,0xd3,0x00,0x08,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64738 0xfce2 "ﳢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x6a,0xe9,0x28,0x25,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64739 0xfce3 "ﳣ" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x10,0x28,0x24,0xd3,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64740 0xfce4 "ﳤ" */
+0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x24,0x6a,0xe9,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64741 0xfce5 "ﳥ" */
+0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x10,0x28,0x24,0xd3,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64742 0xfce6 "ﳦ" */
+0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x00,0x24,0x6a,0xe9,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64743 0xfce7 "ﳧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x22,0xd1,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64744 0xfce8 "ﳨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x26,0x69,0xe8,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64745 0xfce9 "ﳩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x22,0xd1,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64746 0xfcea "ﳪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x6a,0xe9,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64747 0xfceb "ﳫ" */
+0x00,0x02,0x44,0x48,0x50,0x60,0x70,0x48,0x4c,0x4a,0xb1,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64748 0xfcec "ﳬ" */
+0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x18,0x24,0xf3,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64749 0xfced "ﳭ" */
+0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x18,0x24,0xf3,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64750 0xfcee "ﳮ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x10,0x28,0x24,0xd3,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64751 0xfcef "ﳯ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x0c,0x12,0x52,0xd1,0x50,0x48,0x28,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64752 0xfcf0 "ﳰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x24,0xd3,0x00,0x0a,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64753 0xfcf1 "ﳱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x56,0xd1,0x50,0x48,0x2b,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64754 0xfcf2 "ﳲ" */
+0x00,0x0c,0x30,0x02,0x2a,0x14,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64755 0xfcf3 "ﳳ" */
+0x04,0x0a,0x04,0x0a,0x30,0x02,0x2a,0x14,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64756 0xfcf4 "ﳴ" */
+0x00,0x0a,0x54,0x20,0x0c,0x30,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64757 0xfcf5 "ﳵ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0e,0x09,0x0e,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64758 0xfcf6 "ﳶ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0e,0x09,0x0e,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64759 0xfcf7 "ﳷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x08,0x06,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64760 0xfcf8 "ﳸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x08,0x06,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64761 0xfcf9 "ﳹ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x06,0x08,0x06,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64762 0xfcfa "ﳺ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x06,0x08,0x06,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64763 0xfcfb "ﳻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0xec,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64764 0xfcfc "ﳼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0xec,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64765 0xfcfd "ﳽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x12,0x12,0xec,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64766 0xfcfe "ﳾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x12,0x12,0xec,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64767 0xfcff "ﳿ" */
+0x00,0x00,0x00,0x00,0x60,0x58,0x04,0x0e,0x10,0x38,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64768 0xfd00 "ﴀ" */
+0x00,0x00,0x00,0x00,0x60,0x58,0x04,0x0e,0x38,0x08,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64769 0xfd01 "ﴁ" */
+0x00,0x00,0x00,0x00,0x60,0x58,0x04,0x0e,0x38,0x09,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64770 0xfd02 "ﴂ" */
+0x00,0x00,0x00,0x00,0x60,0x58,0x04,0x0e,0x38,0x09,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64771 0xfd03 "ﴃ" */
+0x00,0x00,0x00,0x04,0x60,0x58,0x04,0x0e,0x38,0x08,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64772 0xfd04 "ﴄ" */
+0x00,0x00,0x00,0x02,0x60,0x58,0x04,0x0e,0x38,0x08,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64773 0xfd05 "ﴅ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x1e,0x14,0x10,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64774 0xfd06 "ﴆ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x05,0x1e,0x14,0x10,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64775 0xfd07 "ﴇ" */
+0x00,0x00,0x00,0x08,0x02,0x05,0x05,0x1e,0x14,0x10,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64776 0xfd08 "ﴈ" */
+0x00,0x00,0x00,0x08,0x02,0x05,0x05,0x1e,0x14,0x10,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64777 0xfd09 "ﴉ" */
+0x00,0x00,0x04,0x00,0x0a,0x00,0x25,0x5a,0x40,0x7e,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64778 0xfd0a "ﴊ" */
+0x00,0x00,0x04,0x00,0x0a,0x00,0x25,0x5a,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64779 0xfd0b "ﴋ" */
+0x00,0x00,0x04,0x00,0x0a,0x80,0x25,0x5a,0x40,0x7e,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64780 0xfd0c "ﴌ" */
+0x00,0x00,0x04,0x00,0x0a,0x00,0x25,0x5a,0x40,0x60,0x3c,0x40,0x40,0x40,0x40,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64781 0xfd0d "ﴍ" */
+0x00,0x00,0x00,0x04,0x00,0x0a,0x00,0x15,0x2a,0x20,0x20,0x20,0x20,0x40,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64782 0xfd0e "ﴎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,0x2a,0x20,0x20,0x20,0x20,0x40,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64783 0xfd0f "ﴏ" */
+0x00,0x00,0x00,0x00,0x02,0x05,0x0d,0x16,0x24,0x24,0x20,0x20,0x20,0x40,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64784 0xfd10 "ﴐ" */
+0x00,0x00,0x00,0x08,0x02,0x05,0x0d,0x16,0x24,0x24,0x20,0x20,0x20,0x40,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64785 0xfd11 "ﴑ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0e,0x09,0x0e,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64786 0xfd12 "ﴒ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x0e,0x09,0x0e,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64787 0xfd13 "ﴓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64788 0xfd14 "ﴔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x06,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64789 0xfd15 "ﴕ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x02,0x05,0x06,0x49,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64790 0xfd16 "ﴖ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x02,0x05,0x06,0x49,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64791 0xfd17 "ﴗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64792 0xfd18 "ﴘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64793 0xfd19 "ﴙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x48,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64794 0xfd1a "ﴚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x00,0x12,0x12,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64795 0xfd1b "ﴛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64796 0xfd1c "ﴜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64797 0xfd1d "ﴝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x20,0x00,0x00,0x00,
+/* 64798 0xfd1e "ﴞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x20,0x00,0x00,0x00,
+/* 64799 0xfd1f "ﴟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x44,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x70,0x0c,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64800 0xfd20 "ﴠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x09,0x08,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x70,0x0c,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64801 0xfd21 "ﴡ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x3e,0x29,0x20,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64802 0xfd22 "ﴢ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x0a,0x3e,0x29,0x20,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64803 0xfd23 "ﴣ" */
+0x00,0x00,0x00,0x00,0x10,0x04,0x0a,0x0a,0x3e,0x29,0x20,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64804 0xfd24 "ﴤ" */
+0x00,0x00,0x00,0x00,0x10,0x04,0x0a,0x0a,0x3e,0x29,0x20,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64805 0xfd25 "ﴥ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x54,0xaa,0x81,0xfc,0x40,0x90,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64806 0xfd26 "ﴦ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x54,0xaa,0x81,0xfc,0x40,0x80,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64807 0xfd27 "ﴧ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0xa8,0x00,0x54,0xaa,0x81,0xfc,0x40,0x80,0x44,0x38,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64808 0xfd28 "ﴨ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x4a,0xb5,0x80,0xc0,0x70,0x80,0x80,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64809 0xfd29 "ﴩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x0a,0x00,0x15,0x2a,0x20,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64810 0xfd2a "ﴪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,0x2a,0x20,0x20,0x40,0x80,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64811 0xfd2b "ﴫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x0d,0x16,0x24,0x24,0x40,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64812 0xfd2c "ﴬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x05,0x0d,0x16,0x24,0x24,0x40,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64813 0xfd2d "ﴭ" */
+0x00,0x00,0x00,0x04,0x0a,0x11,0x20,0x7f,0x18,0x60,0x80,0x08,0x00,0x00,0x00,0x00,
+0x20,0x00,0x50,0x00,0x24,0xd8,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64814 0xfd2e "ﴮ" */
+0x00,0x00,0x00,0x04,0x0a,0x11,0x20,0x7f,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x20,0x00,0x50,0x00,0x24,0xd8,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64815 0xfd2f "ﴯ" */
+0x00,0x00,0x00,0x24,0x0a,0x11,0x20,0x7f,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,
+0x20,0x00,0x50,0x00,0x24,0xd8,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64816 0xfd30 "ﴰ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x0a,0x11,0x20,0x70,0x88,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x00,0x50,0x00,0x24,0xd8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64817 0xfd31 "ﴱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x64,0xe8,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0xd8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64818 0xfd32 "ﴲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0x64,0xe8,0x28,0x24,0x14,0x0c,0x00,
+0x00,0x00,0x00,0x20,0x00,0x50,0x00,0x24,0xd8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64819 0xfd33 "ﴳ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x16,0x19,0x1e,0x20,0xd0,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64820 0xfd34 "ﴴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0xff,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64821 0xfd35 "ﴵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64822 0xfd36 "ﴶ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x10,0x28,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x92,0x92,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64823 0xfd37 "ﴷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0xff,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x92,0x92,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64824 0xfd38 "ﴸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x92,0x92,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64825 0xfd39 "ﴹ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x10,0x28,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x10,0x00,0x28,0x00,0x92,0x92,0xed,0x00,0x00,0x00,0x00,0x00,
+/* 64826 0xfd3a "ﴺ" */
+0x00,0x00,0x00,0x10,0x10,0x10,0x16,0x19,0x1e,0x22,0xd1,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64827 0xfd3b "ﴻ" */
+0x00,0x00,0x00,0x10,0x12,0x10,0x16,0x19,0x1e,0x22,0xd1,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64828 0xfd3c "ﴼ" */
+0x01,0x02,0x04,0x11,0x12,0x14,0x10,0x10,0x10,0x10,0x0f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64829 0xfd3d "ﴽ" */
+0x01,0x02,0x04,0x11,0x12,0x14,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 64830 0xfd3e "﴾" */
+0x00,0x00,0x01,0x02,0x04,0x0f,0x0a,0x35,0x6a,0x35,0x0a,0x0f,0x04,0x02,0x01,0x00,
+0x00,0x7e,0x8c,0x30,0xc0,0x00,0x00,0x80,0xc0,0x80,0x00,0x00,0xc0,0x30,0x8c,0x7e,
+/* 64831 0xfd3f "﴿" */
+0x00,0x7e,0x31,0x0c,0x03,0x00,0x00,0x01,0x03,0x01,0x00,0x00,0x03,0x0c,0x31,0x7e,
+0x00,0x00,0x80,0x40,0x20,0xf0,0x50,0xac,0x56,0xac,0x50,0xf0,0x20,0x40,0x80,0x00,
+/* 64832 0xfd40 "﵀" */
+0x00,0x09,0x19,0x29,0x19,0x06,0x00,0x00,0x10,0x30,0x51,0x32,0x0d,0x00,0x00,0x00,
+0x00,0x24,0x24,0x24,0x24,0xc4,0x00,0x00,0xc0,0x24,0xf2,0x82,0xa4,0x18,0x00,0x00,
+/* 64833 0xfd41 "﵁" */
+0x09,0x19,0x29,0x19,0x06,0x10,0x32,0x50,0x33,0x0c,0x00,0x06,0x49,0x48,0x44,0x38,
+0x20,0x24,0x24,0x24,0xc4,0x04,0x34,0x40,0xe8,0x00,0x38,0x44,0xf9,0x02,0x24,0x18,
+/* 64834 0xfd42 "﵂" */
+0x09,0x19,0x29,0x19,0x46,0x50,0x4d,0x54,0x38,0x07,0x00,0x06,0x49,0x48,0x44,0x38,
+0x24,0x24,0x24,0x24,0xc4,0x00,0x0c,0x50,0xf8,0x02,0x38,0x44,0xf9,0x02,0x24,0x18,
+/* 64835 0xfd43 "﵃" */
+0x09,0x19,0x29,0x19,0x06,0x10,0x0d,0x14,0x38,0xe7,0x80,0x86,0x09,0x48,0x44,0x38,
+0x24,0x24,0x24,0x24,0xc4,0x00,0x0c,0x50,0xf8,0x02,0x38,0x44,0xf9,0x02,0x24,0x18,
+/* 64836 0xfd44 "﵄" */
+0x09,0x19,0x29,0x19,0x46,0x50,0x4d,0x54,0x58,0x37,0x10,0x06,0x49,0x48,0x44,0x38,
+0x24,0x24,0x24,0x24,0xc4,0x00,0x0c,0x50,0xf8,0x02,0x38,0x44,0xf9,0x02,0x24,0x18,
+/* 64837 0xfd45 "﵅" */
+0x09,0x19,0x29,0x19,0x06,0x10,0x4c,0x0a,0x9c,0x93,0x60,0x06,0x49,0x48,0x44,0x38,
+0x24,0x24,0x24,0x24,0xc0,0x06,0x88,0x2e,0xf0,0x02,0x38,0x44,0xf9,0x02,0x24,0x18,
+/* 64838 0xfd46 "﵆" */
+0x2a,0x6a,0xaa,0x6a,0x14,0x80,0x80,0x7f,0x00,0x20,0x5f,0x80,0x02,0x02,0x32,0x4c,
+0xa0,0xa0,0xaa,0x2d,0x56,0xc0,0x28,0xc8,0x09,0x2a,0xd7,0x04,0x4a,0x46,0x42,0x4c,
+/* 64839 0xfd47 "﵇" */
+0x00,0x01,0x00,0x09,0x49,0x28,0x1a,0x17,0x60,0x08,0x18,0x28,0x19,0x06,0x00,0x02,
+0x00,0x80,0xc0,0x0a,0x0a,0x2a,0xaa,0xd2,0x00,0x20,0x20,0x26,0x28,0xde,0x00,0x80,
+/* 64840 0xfd48 "﵈" */
+0x00,0x01,0x00,0x09,0x49,0x28,0x1a,0x17,0x60,0x00,0x06,0x6a,0x3f,0x4a,0x46,0x00,
+0x00,0x80,0xca,0x0a,0x0a,0x2a,0xb2,0xc2,0x10,0x10,0x12,0x54,0xae,0x00,0xa0,0x00,
+/* 64841 0xfd49 "﵉" */
+0x00,0x01,0x00,0x49,0x29,0x18,0x1a,0x67,0x40,0x40,0x40,0x5a,0x3e,0x03,0x02,0x00,
+0x00,0x80,0xca,0x0a,0x0a,0x2a,0xb2,0xc2,0x10,0x10,0x12,0x54,0xae,0x00,0x50,0x00,
+/* 64842 0xfd4a "﵊" */
+0x21,0xa7,0xa0,0x6a,0x5f,0x80,0x14,0x4d,0xa5,0xe5,0x0a,0x10,0x00,0x19,0x26,0x40,
+0xa8,0xab,0x2b,0xa1,0x46,0x00,0x0a,0x4a,0xaa,0x72,0x02,0x20,0x26,0x28,0xde,0x00,
+/* 64843 0xfd4b "﵋" */
+0x00,0x00,0x20,0x31,0x49,0x79,0x02,0x24,0x18,0x02,0x2a,0xbc,0x90,0x92,0x63,0x00,
+0x00,0x00,0x02,0x2a,0xfc,0x00,0x00,0x00,0x14,0x00,0x8c,0x4a,0x26,0x22,0xfc,0x00,
+/* 64844 0xfd4c "﵌" */
+0x2a,0x6a,0xaa,0x74,0x01,0x14,0x54,0xd6,0x22,0x0c,0x00,0x04,0x04,0x25,0x5b,0xa0,
+0xa0,0xaa,0x35,0x46,0x20,0xc4,0x04,0x45,0xd6,0x6f,0x00,0x52,0x05,0x53,0xe1,0x06,
+/* 64845 0xfd4d "﵍" */
+0x00,0x01,0x00,0x49,0x29,0x18,0x1a,0x67,0x00,0x40,0x40,0x46,0x4a,0x3f,0x0a,0x06,
+0x00,0x80,0xc0,0x0a,0x0a,0x2a,0xaa,0xd2,0x00,0x20,0x20,0x26,0xa8,0x5e,0x00,0xa0,
+/* 64846 0xfd4e "﵎" */
+0x00,0x00,0x13,0x4e,0x40,0x4c,0x44,0x3b,0x00,0x28,0x48,0x28,0x8a,0x72,0x02,0x0c,
+0x40,0x40,0xc0,0x00,0xa4,0x0a,0x46,0x82,0x0c,0x80,0x85,0x80,0x92,0x6c,0x00,0x10,
+/* 64847 0xfd4f "﵏" */
+0x00,0x09,0x19,0x29,0x19,0x06,0x00,0x00,0x00,0x00,0x04,0x3d,0x75,0x42,0x40,0x00,
+0x00,0x24,0x24,0x24,0x24,0xc4,0x00,0x60,0x10,0x7a,0xa2,0x62,0x04,0x18,0x00,0x00,
+/* 64848 0xfd50 "ﵐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0xff,0x50,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x04,0x84,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 64849 0xfd51 "ﵑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x29,0x04,0x0b,0x10,0x24,0x20,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x80,0x42,0x22,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64850 0xfd52 "ﵒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x84,0x44,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 64851 0xfd53 "ﵓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0xff,0x50,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x04,0x84,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 64852 0xfd54 "ﵔ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x02,0x05,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x04,0x84,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 64853 0xfd55 "ﵕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x04,0x04,0xfc,0x80,0x00,0x00,0x00,0x00,
+/* 64854 0xfd56 "ﵖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x04,0x04,0xfc,0x80,0x00,0x00,0x00,0x00,
+/* 64855 0xfd57 "ﵗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x00,0x04,0x04,0xfc,0x80,0x00,0x00,0x00,0x00,
+/* 64856 0xfd58 "ﵘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x17,0x21,0x40,0x40,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0xff,0x40,0x88,0x00,0x00,0x00,
+/* 64857 0xfd59 "ﵙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0xfc,0x80,0x10,0x00,0x00,0x00,
+/* 64858 0xfd5a "ﵚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0xff,0xa0,0x40,0x00,0x00,0x00,
+/* 64859 0xfd5b "ﵛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0xff,0xa0,0x40,0x00,0x00,0x00,
+/* 64860 0xfd5c "ﵜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64861 0xfd5d "ﵝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64862 0xfd5e "ﵞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x89,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64863 0xfd5f "ﵟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xa0,0x10,0x2f,0x45,0x82,0x80,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64864 0xfd60 "ﵠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0xfe,0x80,0x00,0x00,0x00,0x00,
+/* 64865 0xfd61 "ﵡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0xfe,0x80,0x00,0x00,0x00,0x00,
+/* 64866 0xfd62 "ﵢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x7f,0x42,0x41,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0xff,0x80,0x00,0x00,0x00,0x00,
+/* 64867 0xfd63 "ﵣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x2a,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x2a,0xfe,0x80,0x00,0x00,0x00,0x00,
+/* 64868 0xfd64 "ﵤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0xa5,0x10,0x2f,0x40,0x80,0x80,0x48,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x2a,0xaa,0xd7,0x00,0x00,0x00,0x00,0x00,
+/* 64869 0xfd65 "ﵥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x95,0x55,0xee,0x00,0x00,0x00,0x00,0x00,
+/* 64870 0xfd66 "ﵦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x7f,0x42,0x41,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x2a,0x2a,0xd7,0x80,0x00,0x00,0x00,0x00,
+/* 64871 0xfd67 "ﵧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0xa5,0x10,0xff,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x2a,0xaa,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64872 0xfd68 "ﵨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x2a,0xaa,0xfe,0x00,0x00,0x00,0x00,0x00,
+/* 64873 0xfd69 "ﵩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x89,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x04,0x00,0x0a,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64874 0xfd6a "ﵪ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x20,0x50,0x08,0x17,0x22,0x41,0x40,0x24,0x18,
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x2a,0x2a,0xff,0x80,0x00,0x00,0x00,0x00,
+/* 64875 0xfd6b "ﵫ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x2a,0x2a,0xfe,0x80,0x00,0x00,0x00,0x00,
+/* 64876 0xfd6c "ﵬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x7f,0x42,0x41,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x2a,0x2a,0xff,0x80,0x00,0x00,0x00,0x00,
+/* 64877 0xfd6d "ﵭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x2a,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x00,0x14,0x00,0x2a,0x2a,0xfe,0x80,0x00,0x00,0x00,0x00,
+/* 64878 0xfd6e "ﵮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x02,0x95,0x55,0xeb,0x00,0x00,0x00,0x00,0x00,
+/* 64879 0xfd6f "ﵯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0xa5,0x10,0xff,0x80,0x80,0x80,0x80,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x2a,0xaa,0xd7,0x00,0x00,0x00,0x00,0x00,
+/* 64880 0xfd70 "ﵰ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x02,0x05,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x2a,0xaa,0xd4,0x00,0x00,0x00,0x00,0x00,
+/* 64881 0xfd71 "ﵱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x17,0x22,0x41,0x40,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x2c,0x32,0xff,0x80,0x00,0x00,0x00,0x00,
+/* 64882 0xfd72 "ﵲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x2c,0x32,0xfc,0x80,0x00,0x00,0x00,0x00,
+/* 64883 0xfd73 "ﵳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x2a,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x2c,0x32,0xfc,0x80,0x00,0x00,0x00,0x00,
+/* 64884 0xfd74 "ﵴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x92,0x89,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x2c,0x32,0xff,0x80,0x00,0x00,0x00,0x00,
+/* 64885 0xfd75 "ﵵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0x7f,0x40,0x41,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x92,0x4c,0xf3,0x00,0x00,0x00,0x00,0x00,
+/* 64886 0xfd76 "ﵶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0x3f,0x21,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x0c,0xf3,0x40,0x80,0x00,0x00,0x00,
+/* 64887 0xfd77 "ﵷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x52,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x10,0xfe,0x80,0x00,0x00,0x00,0x00,
+/* 64888 0xfd78 "ﵸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x91,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x0c,0xf3,0x40,0x80,0x00,0x00,0x00,
+/* 64889 0xfd79 "ﵹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0x3f,0x21,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1e,0x12,0x0c,0xf3,0x40,0x80,0x00,0x00,0x00,
+/* 64890 0xfd7a "ﵺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x91,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1e,0x12,0x0c,0xf3,0x40,0x80,0x00,0x00,0x00,
+/* 64891 0xfd7b "ﵻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x91,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1e,0x12,0x0c,0xf3,0x40,0x80,0x00,0x00,0x00,
+/* 64892 0xfd7c "ﵼ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x21,0x52,0x08,0x7f,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x08,0x94,0x54,0xef,0x00,0x00,0x00,0x00,0x00,
+/* 64893 0xfd7d "ﵽ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x02,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x08,0x00,0x08,0x14,0x8c,0x44,0xfc,0x00,0x00,0x00,0x00,0x00,
+/* 64894 0xfd7e "ﵾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x17,0x21,0x40,0x40,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x04,0x0a,0x0a,0xf7,0x40,0x80,0x00,0x00,0x00,
+/* 64895 0xfd7f "ﵿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x7f,0x42,0x41,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x08,0x14,0x14,0xef,0x80,0x00,0x00,0x00,0x00,
+/* 64896 0xfd80 "ﶀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0x1f,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x42,0xa2,0x12,0xfd,0x00,0x00,0x00,0x00,0x00,
+/* 64897 0xfd81 "ﶁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x2a,0x29,0x24,0x22,0x1c,0x00,0x14,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x42,0xa2,0x12,0xfd,0x00,0x00,0x00,0x00,0x00,
+/* 64898 0xfd82 "ﶂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x2a,0x29,0x24,0x22,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x42,0xa2,0x12,0xfd,0x00,0x00,0x00,0x00,0x00,
+/* 64899 0xfd83 "ﶃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x88,0x48,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 64900 0xfd84 "ﶄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x51,0x08,0x17,0x20,0x48,0x40,0x24,0x18,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x82,0x42,0x22,0xfd,0x00,0x80,0x00,0x00,0x00,
+/* 64901 0xfd85 "ﶅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x51,0x08,0x7f,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x82,0x02,0x82,0x42,0x22,0xfd,0x00,0x00,0x00,0x00,0x00,
+/* 64902 0xfd86 "ﶆ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x02,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x84,0x44,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 64903 0xfd87 "ﶇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0x0b,0x10,0x20,0x20,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0xfd,0xa0,0x40,0x00,0x00,0x00,
+/* 64904 0xfd88 "ﶈ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0xf0,0x80,0x00,0x00,0x00,0x00,
+/* 64905 0xfd89 "ﶉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64906 0xfd8a "ﶊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x05,0x00,0xff,0x50,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x88,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64907 0xfd8b "ﶋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xff,0x14,0x08,0x00,0x00,0x00,
+/* 64908 0xfd8c "ﶌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64909 0xfd8d "ﶍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0xff,0x28,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64910 0xfd8e "ﶎ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x21,0x52,0x08,0xff,0x00,0x20,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64911 0xfd8f "ﶏ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x02,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64912 0xfd90 "﶐" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 64913 0xfd91 "﶑" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x71,0x7d,0x73,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 64914 0xfd92 "ﶒ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x21,0x52,0x08,0xff,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x48,0xf4,0x14,0x08,0x00,0x00,0x00,
+/* 64915 0xfd93 "ﶓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x21,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x12,0x2a,0x2a,0xdc,0x80,0x00,0x00,0x00,0x00,
+/* 64916 0xfd94 "ﶔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x2a,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x18,0x04,0x12,0x2a,0x2a,0xdc,0x80,0x00,0x00,0x00,0x00,
+/* 64917 0xfd95 "ﶕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x88,0x48,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 64918 0xfd96 "ﶖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x54,0x53,0x48,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x80,0x44,0x24,0xfb,0x00,0x00,0x00,0x00,0x00,
+/* 64919 0xfd97 "ﶗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x51,0x08,0x7f,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x80,0x44,0x24,0xfb,0x00,0x80,0x00,0x00,0x00,
+/* 64920 0xfd98 "ﶘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0xff,0x28,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x88,0x48,0xf0,0x00,0x00,0x00,0x00,0x00,
+/* 64921 0xfd99 "ﶙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x80,0x44,0x24,0xfb,0x00,0x80,0x00,0x00,0x00,
+/* 64922 0xfd9a "ﶚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x04,0xfb,0xa0,0x40,0x00,0x00,0x00,
+/* 64923 0xfd9b "ﶛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x04,0xfb,0xa0,0x40,0x00,0x00,0x00,
+/* 64924 0xfd9c "ﶜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0x1f,0x10,0x10,0x10,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0xfb,0xa0,0x4a,0x00,0x00,0x00,
+/* 64925 0xfd9d "ﶝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x29,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0xfc,0x40,0x94,0x00,0x00,0x00,
+/* 64926 0xfd9e "ﶞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x42,0x22,0xfd,0x00,0x04,0x00,0x00,0x00,
+/* 64927 0xfd9f "ﶟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x80,0x42,0x22,0xfd,0x00,0x40,0x00,0x00,0x00,
+/* 64928 0xfda0 "ﶠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x80,0x42,0x22,0xfd,0x00,0x80,0x00,0x00,0x00,
+/* 64929 0xfda1 "ﶡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x80,0x0a,0x80,0x42,0x22,0xfd,0x00,0x00,0x00,0x00,0x00,
+/* 64930 0xfda2 "ﶢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x0a,0x80,0x42,0x22,0xfd,0x00,0x00,0x00,0x00,0x00,
+/* 64931 0xfda3 "ﶣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x02,0x02,0xfd,0xa0,0x40,0x00,0x00,0x00,
+/* 64932 0xfda4 "ﶤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x02,0x02,0xfd,0xa0,0x40,0x00,0x00,0x00,
+/* 64933 0xfda5 "ﶥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x91,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0xff,0x40,0x88,0x00,0x00,0x00,
+/* 64934 0xfda6 "ﶦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x94,0x42,0xff,0x00,0x08,0x00,0x00,0x00,
+/* 64935 0xfda7 "ﶧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x91,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x02,0xff,0x40,0x88,0x00,0x00,0x00,
+/* 64936 0xfda8 "ﶨ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64937 0xfda9 "ﶩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x95,0x55,0xef,0x00,0x00,0x00,0x00,0x00,
+/* 64938 0xfdaa "ﶪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x04,0x00,0x0a,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64939 0xfdab "ﶫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x02,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64940 0xfdac "ﶬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x84,0x44,0x24,0xfb,0x00,0x80,0x00,0x00,0x00,
+/* 64941 0xfdad "ﶭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0xfb,0xa0,0x40,0x00,0x00,0x00,
+/* 64942 0xfdae "ﶮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x44,0x24,0xfb,0x00,0x0a,0x00,0x00,0x00,
+/* 64943 0xfdaf "ﶯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x44,0x24,0xfb,0x00,0x8a,0x00,0x00,0x00,
+/* 64944 0xfdb0 "ﶰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0xfb,0xa0,0x4a,0x00,0x00,0x00,
+/* 64945 0xfdb1 "ﶱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xaa,0x44,0x00,0x00,0x00,
+/* 64946 0xfdb2 "ﶲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x04,0x0a,0x0a,0xf7,0xa0,0x40,0x00,0x00,0x00,
+/* 64947 0xfdb3 "ﶳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x80,0x44,0x24,0xfb,0x00,0x00,0x00,0x00,0x00,
+/* 64948 0xfdb4 "ﶴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0xff,0x02,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x14,0x00,0x08,0x14,0x0c,0x04,0xfc,0x80,0x00,0x00,0x00,0x00,
+/* 64949 0xfdb5 "ﶵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0xff,0x28,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x88,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 64950 0xfdb6 "ﶶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x91,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x12,0x0c,0xf3,0x40,0x80,0x00,0x00,0x00,
+/* 64951 0xfdb7 "ﶷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xa8,0xa7,0x92,0x89,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x20,0x18,0x0e,0xf1,0x80,0x00,0x00,0x00,0x00,
+/* 64952 0xfdb8 "ﶸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x52,0x08,0xff,0x00,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x88,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 64953 0xfdb9 "ﶹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x40,0x20,0xff,0x0a,0x04,0x00,0x00,0x00,
+/* 64954 0xfdba "ﶺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0xff,0x28,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x88,0x48,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 64955 0xfdbb "ﶻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x50,0x08,0x7f,0x42,0x41,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x06,0x18,0x20,0x18,0x0e,0xf1,0x80,0x00,0x00,0x00,0x00,
+/* 64956 0xfdbc "ﶼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x51,0x08,0x7f,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x84,0x44,0x24,0xfb,0x00,0x80,0x00,0x00,0x00,
+/* 64957 0xfdbd "ﶽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x28,0x04,0x0b,0x10,0x20,0x20,0x12,0x0c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x40,0xa2,0x12,0xfd,0x00,0x40,0x00,0x00,0x00,
+/* 64958 0xfdbe "ﶾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x94,0x42,0xff,0x00,0x08,0x00,0x00,0x00,
+/* 64959 0xfdbf "ﶿ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x92,0xa8,0xa7,0x90,0x89,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x94,0x42,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64960 0xfdc0 "ﷀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0xff,0x0a,0x44,0x00,0x00,0x00,
+/* 64961 0xfdc1 "ﷁ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x54,0x53,0x48,0x44,0x38,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x0a,0x0a,0xf7,0xa0,0x40,0x00,0x00,0x00,
+/* 64962 0xfdc2 "ﷂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x42,0x22,0xff,0x00,0x04,0x00,0x00,0x00,
+/* 64963 0xfdc3 "ﷃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x29,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x08,0x04,0xf8,0x40,0x80,0x00,0x00,0x00,
+/* 64964 0xfdc4 "ﷄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0xff,0x28,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x86,0x48,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64965 0xfdc5 "ﷅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x55,0x22,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x2a,0x2a,0xdc,0x00,0x00,0x00,0x00,0x00,
+/* 64966 0xfdc6 "ﷆ" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x92,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0x55,0xff,0x00,0x00,0x00,0x00,0x00,
+/* 64967 0xfdc7 "ﷇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xa8,0xa7,0x90,0x88,0x70,0x00,0x50,
+0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x80,0x44,0x24,0xfb,0x00,0x80,0x00,0x00,0x00,
+/* 64968 0xfdc8 "﷈" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 64969 0xfdc9 "﷉" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 64970 0xfdca "﷊" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 64971 0xfdcb "﷋" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 64972 0xfdcc "﷌" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 64973 0xfdcd "﷍" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 64974 0xfdce "﷎" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 64975 0xfdcf "﷏" */
+0x00,0x00,0x02,0x01,0x2c,0x5c,0x81,0x00,0x40,0x48,0x40,0x49,0x36,0x00,0x02,0x00,
+0x00,0x40,0x40,0x41,0xd5,0xbe,0x00,0x00,0x20,0x20,0x26,0x28,0xde,0x00,0x80,0x00,
+/* 64976 0xfdd0 "﷐" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xb7,0xb7,0xcf,0xff,0xff,
+/* 64977 0xfdd1 "﷑" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xdf,0x9f,0xdf,0xdf,0x8f,0xff,0xff,
+/* 64978 0xfdd2 "﷒" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xf7,0x87,0xbf,0x87,0xff,0xff,
+/* 64979 0xfdd3 "﷓" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x8f,0xf7,0xc7,0xf7,0x8f,0xff,0xff,
+/* 64980 0xfdd4 "﷔" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xaf,0xaf,0x87,0xef,0xef,0xff,0xff,
+/* 64981 0xfdd5 "﷕" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xbf,0x87,0xf7,0x87,0xff,0xff,
+/* 64982 0xfdd6 "﷖" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xbf,0x8f,0xb7,0xcf,0xff,0xff,
+/* 64983 0xfdd7 "﷗" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xf7,0xef,0xdf,0xdf,0xff,0xff,
+/* 64984 0xfdd8 "﷘" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xcf,0xb7,0xcf,0xff,0xff,
+/* 64985 0xfdd9 "﷙" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xc7,0xf7,0xcf,0xff,0xff,
+/* 64986 0xfdda "﷚" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0x87,0xb7,0xb7,0xff,0xff,
+/* 64987 0xfddb "﷛" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x8f,0xb7,0x8f,0xb7,0x8f,0xff,0xff,
+/* 64988 0xfddc "﷜" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xbf,0xb7,0xcf,0xff,0xff,
+/* 64989 0xfddd "﷝" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,
+/* 64990 0xfdde "﷞" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xbf,0x8f,0xbf,0x87,0xff,0xff,
+/* 64991 0xfddf "﷟" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe3,0xed,0xed,0xed,0xe3,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xbf,0x8f,0xbf,0xbf,0xff,0xff,
+/* 64992 0xfde0 "﷠" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xb7,0xb7,0xcf,0xff,0xff,
+/* 64993 0xfde1 "﷡" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xdf,0x9f,0xdf,0xdf,0x8f,0xff,0xff,
+/* 64994 0xfde2 "﷢" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xf7,0x87,0xbf,0x87,0xff,0xff,
+/* 64995 0xfde3 "﷣" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x8f,0xf7,0xc7,0xf7,0x8f,0xff,0xff,
+/* 64996 0xfde4 "﷤" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xaf,0xaf,0x87,0xef,0xef,0xff,0xff,
+/* 64997 0xfde5 "﷥" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xbf,0x87,0xf7,0x87,0xff,0xff,
+/* 64998 0xfde6 "﷦" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xbf,0x8f,0xb7,0xcf,0xff,0xff,
+/* 64999 0xfde7 "﷧" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xf7,0xef,0xdf,0xdf,0xff,0xff,
+/* 65000 0xfde8 "﷨" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xcf,0xb7,0xcf,0xff,0xff,
+/* 65001 0xfde9 "﷩" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xc7,0xf7,0xcf,0xff,0xff,
+/* 65002 0xfdea "﷪" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0x87,0xb7,0xb7,0xff,0xff,
+/* 65003 0xfdeb "﷫" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x8f,0xb7,0x8f,0xb7,0x8f,0xff,0xff,
+/* 65004 0xfdec "﷬" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0xcf,0xb7,0xbf,0xb7,0xcf,0xff,0xff,
+/* 65005 0xfded "﷭" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,
+/* 65006 0xfdee "﷮" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xbf,0x8f,0xbf,0x87,0xff,0xff,
+/* 65007 0xfdef "﷯" */
+0xff,0xff,0xe1,0xef,0xe3,0xef,0xef,0xff,0xff,0xe1,0xef,0xe3,0xef,0xe1,0xff,0xff,
+0xff,0xff,0x8f,0xb7,0xb7,0xb7,0x8f,0xff,0xff,0x87,0xbf,0x8f,0xbf,0xbf,0xff,0xff,
+/* 65008 0xfdf0 "ﷰ" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x0b,0x30,0x40,0x40,0x3f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x92,0xa2,0x7c,0x20,0x00,0x00,0xf0,0x00,0x00,0x00,
+/* 65009 0xfdf1 "ﷱ" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x05,0x18,0x20,0x20,0x1f,0x00,0x00,0x00,
+0x00,0x00,0x50,0x00,0x20,0x50,0x30,0x10,0xe0,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,
+/* 65010 0xfdf2 "ﷲ" */
+0x02,0x02,0x02,0x01,0x05,0x06,0x00,0x08,0x18,0x28,0x18,0x0f,0x00,0x00,0x00,0x00,
+0x00,0x00,0x40,0x42,0x82,0x02,0x92,0x92,0x92,0x92,0x92,0x60,0x00,0x00,0x00,0x00,
+/* 65011 0xfdf3 "ﷳ" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x12,0x1e,0x12,0x11,0x24,0x40,0x00,0x00,0x00,
+0x00,0x0c,0x30,0xc4,0x04,0x04,0xc4,0x24,0x14,0x14,0xe4,0x00,0x00,0x00,0x00,0x00,
+/* 65012 0xfdf4 "ﷴ" */
+0x06,0x18,0x01,0x15,0x0a,0x00,0x01,0x06,0x00,0x08,0x09,0x05,0x24,0x1a,0x01,0x00,
+0x08,0x14,0x08,0x14,0x60,0x00,0x88,0x14,0x38,0xc0,0x00,0xfc,0x18,0x60,0x80,0x60,
+/* 65013 0xfdf5 "ﷵ" */
+0x00,0x00,0x04,0x04,0x04,0x24,0x54,0x34,0x2b,0x40,0x38,0x14,0x28,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x92,0xa2,0x7c,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65014 0xfdf6 "ﷶ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x92,0x95,0x63,0x01,0x0e,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x55,0xa9,0x02,0x1c,0x00,0x00,0x00,0x00,0x00,
+/* 65015 0xfdf7 "ﷷ" */
+0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x33,0x0c,0x00,0x05,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x20,0x20,0x20,0x26,0x28,0xde,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65016 0xfdf8 "ﷸ" */
+0x00,0x00,0x10,0x10,0x10,0x10,0x12,0x12,0x2d,0x40,0x30,0x28,0x50,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa4,0xaa,0x46,0x02,0x04,0x18,0x00,0x00,0x00,0x00,
+/* 65017 0xfdf9 "ﷹ" */
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x0b,0x08,0x50,0x4c,0x42,0x24,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x0c,0x92,0xa2,0x7c,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65018 0xfdfa "ﷺ" */
+0x2a,0x6a,0xaa,0x6a,0x14,0x80,0x80,0x7f,0x20,0x60,0xbf,0x44,0x04,0x3d,0x53,0xa0,
+0xa0,0xa0,0xaa,0x2d,0x56,0xc4,0x28,0xc8,0x29,0x2a,0xd7,0x02,0x55,0x03,0x51,0xa6,
+/* 65019 0xfdfb "ﷻ" */
+0x00,0x08,0x08,0x48,0x48,0x37,0x00,0x02,0x12,0x32,0x52,0x32,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x04,0x0a,0x01,0xff,0x00,0xa4,0xa0,0xa4,0xaa,0x21,0xdf,0x00,0x04,0x00,
+/* 65020 0xfdfc "﷼" */
+0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x22,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x80,0x80,0x80,0x80,0xa0,0xa0,0x42,0x02,0xa2,0x0c,0x00,0x00,0x00,0x00,0x00,
+/* 65021 0xfdfd "﷽" */
+0x70,0x5f,0x70,0xc5,0x14,0x15,0x55,0x75,0xc0,0x50,0x5f,0x70,0x75,0x54,0x7f,0xc0,
+0xa9,0xff,0x00,0xd5,0x55,0xd5,0x7d,0xc0,0x3b,0x29,0xff,0x00,0x85,0x95,0x9d,0x30,
+/* 65022 0xfdfe "﷾" */
+0x00,0x00,0x13,0x4e,0x40,0x4c,0x44,0x3b,0x00,0x0a,0x22,0x5a,0x82,0x02,0x02,0x01,
+0x40,0x40,0xc0,0x04,0xaa,0x0e,0x42,0x8c,0x00,0x01,0x55,0xfe,0x80,0xf0,0x40,0x90,
+/* 65023 0xfdff "﷿" */
+0x00,0x20,0x00,0x08,0x0f,0x08,0x10,0x64,0x04,0x04,0x04,0x24,0x47,0x44,0x38,0x00,
+0x00,0x30,0x48,0x40,0xfc,0x00,0x00,0x00,0x00,0x00,0xc4,0x2a,0xee,0x02,0x8c,0x00,
+/* 65024 0xfe00 "︀" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x00,0x81,0x02,0x80,0x03,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x81,0x80,0x81,0x80,0xe1,0x00,0x55,
+/* 65025 0xfe01 "︁" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x03,0x80,0x01,0x82,0x03,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x81,0x40,0x81,0x00,0xc1,0x00,0x55,
+/* 65026 0xfe02 "︂" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x03,0x80,0x01,0x80,0x03,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x81,0x40,0x81,0x40,0x81,0x00,0x55,
+/* 65027 0xfe03 "︃" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x02,0x82,0x03,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x41,0x40,0xc1,0x40,0x41,0x00,0x55,
+/* 65028 0xfe04 "︄" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x03,0x82,0x03,0x80,0x03,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0xc1,0x00,0x81,0x40,0x81,0x00,0x55,
+/* 65029 0xfe05 "︅" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x01,0x82,0x03,0x82,0x01,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0xc1,0x00,0x81,0x40,0x81,0x00,0x55,
+/* 65030 0xfe06 "︆" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x03,0x80,0x00,0x81,0x01,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0xc1,0x40,0x81,0x00,0x01,0x00,0x55,
+/* 65031 0xfe07 "︇" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x01,0x82,0x01,0x82,0x01,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x81,0x40,0x81,0x40,0x81,0x00,0x55,
+/* 65032 0xfe08 "︈" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x01,0x82,0x01,0x80,0x03,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x81,0x40,0xc1,0x40,0x81,0x00,0x55,
+/* 65033 0xfe09 "︉" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x31,0x48,0x49,0x48,0x31,0x00,0x55,
+/* 65034 0xfe0a "︊" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x11,0x30,0x51,0x10,0x7d,0x00,0x55,
+/* 65035 0xfe0b "︋" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x71,0x08,0x31,0x40,0x79,0x00,0x55,
+/* 65036 0xfe0c "︌" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x71,0x08,0x31,0x08,0x71,0x00,0x55,
+/* 65037 0xfe0d "︍" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x49,0x48,0x79,0x08,0x09,0x00,0x55,
+/* 65038 0xfe0e "︎" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x79,0x40,0x71,0x08,0x71,0x00,0x55,
+/* 65039 0xfe0f "️" */
+0xaa,0x00,0x80,0x22,0xa2,0x22,0x94,0x08,0x80,0x08,0x98,0x28,0x88,0x3e,0x80,0x55,
+0xaa,0x01,0x00,0x3d,0x40,0x39,0x04,0x79,0x00,0x39,0x40,0x71,0x48,0x31,0x00,0x55,
+/* 65040 0xfe10 "︐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0c,0x04,0x04,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65041 0xfe11 "︑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x20,0x10,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65042 0xfe12 "︒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65043 0xfe13 "︓" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65044 0xfe14 "︔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x0c,0x0c,0x00,0x00,0x00,0x0c,0x04,0x04,0x08,0x00,0x00,0x00,0x00,0x00,
+/* 65045 0xfe15 "︕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0x00,0x00,0x00,0x00,
+/* 65046 0xfe16 "︖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x78,0x84,0x84,0x04,0x08,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,
+/* 65047 0xfe17 "︗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x47,0x58,0x60,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0xe2,0x1a,0x06,0x02,0x00,0x00,0x00,
+/* 65048 0xfe18 "︘" */
+0x00,0x00,0x00,0x40,0x60,0x58,0x47,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x06,0x1a,0xe2,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65049 0xfe19 "︙" */
+0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x00,0x00,
+/* 65050 0xfe1a "︚" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xb6,0x86,0xb6,0xb6,0xfe,0x00,
+/* 65051 0xfe1b "︛" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0x8e,0xb6,0x8e,0xfe,0x00,
+/* 65052 0xfe1c "︜" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 65053 0xfe1d "︝" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 65054 0xfe1e "︞" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 65055 0xfe1f "︟" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x7b,0x73,0x7b,0x7b,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 65056 0xfe20 "︠" */
+0x00,0x0f,0x30,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65057 0xfe21 "︡" */
+0x00,0xf0,0x0c,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65058 0xfe22 "︢" */
+0x00,0x1e,0x21,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65059 0xfe23 "︣" */
+0x00,0x02,0x84,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65060 0xfe24 "︤" */
+0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65061 0xfe25 "︥" */
+0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65062 0xfe26 "︦" */
+0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65063 0xfe27 "︧" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x30,0x0f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65064 0xfe28 "︨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x0c,0xf0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65065 0xfe29 "︩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65066 0xfe2a "︪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xf0,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65067 0xfe2b "︫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65068 0xfe2c "︬" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65069 0xfe2d "︭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65070 0xfe2e "︮" */
+0x00,0x1f,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65071 0xfe2f "︯" */
+0x00,0x18,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65072 0xfe30 "︰" */
+0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 65073 0xfe31 "︱" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 65074 0xfe32 "︲" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 65075 0xfe33 "︳" */
+0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65076 0xfe34 "︴" */
+0x20,0x40,0x40,0x20,0x10,0x10,0x20,0x40,0x40,0x20,0x10,0x10,0x20,0x40,0x40,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65077 0xfe35 "︵" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0c,0x10,0x20,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x30,0x08,0x04,0x02,0x00,0x00,0x00,
+/* 65078 0xfe36 "︶" */
+0x00,0x00,0x00,0x40,0x20,0x10,0x0c,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x04,0x08,0x30,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65079 0xfe37 "︷" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x3e,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x7c,0x02,0x00,0x00,0x00,
+/* 65080 0xfe38 "︸" */
+0x00,0x00,0x00,0x40,0x3e,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x7c,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65081 0xfe39 "︹" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x20,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x04,0x02,0x00,0x00,0x00,
+/* 65082 0xfe3a "︺" */
+0x00,0x00,0x00,0x40,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65083 0xfe3b "︻" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x7f,0x78,0x60,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xfe,0x1e,0x06,0x02,0x00,0x00,0x00,
+/* 65084 0xfe3c "︼" */
+0x00,0x00,0x00,0x40,0x60,0x78,0x7f,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x06,0x1e,0xfe,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65085 0xfe3d "︽" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x61,0x06,0x18,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x86,0x60,0x18,0x06,0x00,0x00,0x00,
+/* 65086 0xfe3e "︾" */
+0x00,0x00,0x00,0x60,0x18,0x06,0x61,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x06,0x18,0x60,0x86,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65087 0xfe3f "︿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x18,0x60,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x06,0x00,0x00,0x00,
+/* 65088 0xfe40 "﹀" */
+0x00,0x00,0x00,0x60,0x18,0x06,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x06,0x18,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65089 0xfe41 "﹁" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 65090 0xfe42 "﹂" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65091 0xfe43 "﹃" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0xfa,0x0a,0x0a,0x0e,0x00,0x00,0x00,
+/* 65092 0xfe44 "﹄" */
+0x00,0x00,0x00,0x70,0x50,0x50,0x5f,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x10,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65093 0xfe45 "﹅" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x70,0x38,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65094 0xfe46 "﹆" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x78,0x24,0x14,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65095 0xfe47 "﹇" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x40,0x40,0x40,0x40,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0x02,0x02,0x02,0x02,0x00,0x00,0x00,
+/* 65096 0xfe48 "﹈" */
+0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65097 0xfe49 "﹉" */
+0x00,0x39,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xce,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65098 0xfe4a "﹊" */
+0x00,0x7d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xbe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65099 0xfe4b "﹋" */
+0x0c,0x92,0x61,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x49,0x86,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65100 0xfe4c "﹌" */
+0x0c,0x92,0x61,0x0c,0x92,0x61,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x30,0x49,0x86,0x30,0x49,0x86,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65101 0xfe4d "﹍" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xce,0x00,
+/* 65102 0xfe4e "﹎" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbe,0x00,
+/* 65103 0xfe4f "﹏" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x92,0x61,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x49,0x86,
+/* 65104 0xfe50 "﹐" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,
+/* 65105 0xfe51 "﹑" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,
+/* 65106 0xfe52 "﹒" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,
+/* 65107 0xfe53 "﹓" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x61,0x7d,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 65108 0xfe54 "﹔" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x01,0x02,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,0x00,0x00,
+/* 65109 0xfe55 "﹕" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x80,0x00,0x00,
+/* 65110 0xfe56 "﹖" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x01,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 65111 0xfe57 "﹗" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x80,0x00,0x00,
+/* 65112 0xfe58 "﹘" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 65113 0xfe59 "﹙" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 65114 0xfe5a "﹚" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,
+/* 65115 0xfe5b "﹛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x80,0x80,0x80,0x40,0x00,0x00,
+/* 65116 0xfe5c "﹜" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x01,0x01,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,
+/* 65117 0xfe5d "﹝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 65118 0xfe5e "﹞" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
+/* 65119 0xfe5f "﹟" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x07,0x02,0x07,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xc0,0x80,0xc0,0x80,0x00,0x00,
+/* 65120 0xfe60 "﹠" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x01,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x40,0x00,0x00,
+/* 65121 0xfe61 "﹡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x03,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x00,0x00,
+/* 65122 0xfe62 "﹢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 65123 0xfe63 "﹣" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,
+/* 65124 0xfe64 "﹤" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x80,0x40,0x00,0x00,
+/* 65125 0xfe65 "﹥" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x01,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,
+/* 65126 0xfe66 "﹦" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x03,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0xc0,0x00,0x00,0x00,
+/* 65127 0xfe67 "﹧" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 65128 0xfe68 "﹨" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,
+/* 65129 0xfe69 "﹩" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x05,0x03,0x01,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x40,0x80,0x00,0x00,
+/* 65130 0xfe6a "﹪" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x00,0x01,0x02,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x80,0x00,0x40,0x40,0x00,0x00,
+/* 65131 0xfe6b "﹫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0xc0,0xc0,0x00,0x80,0x00,0x00,
+/* 65132 0xfe6c "﹬" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0xc6,0xbe,0xbe,0xbe,0xc6,0xfe,0x00,
+/* 65133 0xfe6d "﹭" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 65134 0xfe6e "﹮" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 65135 0xfe6f "﹯" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6f,0x63,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 65136 0xfe70 "ﹰ" */
+0x00,0x0c,0x30,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65137 0xfe71 "ﹱ" */
+0x00,0x0c,0x30,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65138 0xfe72 "ﹲ" */
+0x0c,0x0c,0x64,0x28,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65139 0xfe73 "ﹳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x04,0x04,0x03,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65140 0xfe74 "ﹴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,0x0c,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65141 0xfe75 "﹵" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x7d,0x7b,0x77,0x77,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 65142 0xfe76 "ﹶ" */
+0x00,0x00,0x00,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65143 0xfe77 "ﹷ" */
+0x00,0x00,0x00,0x0c,0x30,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65144 0xfe78 "ﹸ" */
+0x0c,0x0e,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65145 0xfe79 "ﹹ" */
+0x0c,0x0e,0x08,0x10,0x20,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65146 0xfe7a "ﹺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65147 0xfe7b "ﹻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x0c,0x30,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65148 0xfe7c "ﹼ" */
+0x00,0x00,0x00,0x04,0x14,0x58,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65149 0xfe7d "ﹽ" */
+0x00,0x00,0x00,0x04,0x14,0x58,0x60,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65150 0xfe7e "ﹾ" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65151 0xfe7f "ﹿ" */
+0x00,0x00,0x00,0x18,0x24,0x24,0x18,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65152 0xfe80 "ﺀ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x20,0x3c,0x10,0x20,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65153 0xfe81 "ﺁ" */
+0x00,0x01,0x3e,0x40,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65154 0xfe82 "ﺂ" */
+0x00,0x08,0x70,0x80,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65155 0xfe83 "ﺃ" */
+0x18,0x20,0x18,0x20,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65156 0xfe84 "ﺄ" */
+0x30,0x40,0x30,0x40,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65157 0xfe85 "ﺅ" */
+0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65158 0xfe86 "ﺆ" */
+0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65159 0xfe87 "ﺇ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x0c,0x10,0x0c,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65160 0xfe88 "ﺈ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x30,0x40,0x30,0x40,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65161 0xfe89 "ﺉ" */
+0x00,0x00,0x00,0x00,0x30,0x40,0x30,0x40,0x00,0x46,0x48,0x48,0x46,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65162 0xfe8a "ﺊ" */
+0x00,0x00,0x00,0x00,0x30,0x40,0x30,0x40,0x00,0x40,0x43,0x42,0x42,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65163 0xfe8b "ﺋ" */
+0x00,0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65164 0xfe8c "ﺌ" */
+0x00,0x00,0x00,0x0c,0x10,0x0c,0x10,0x00,0x04,0x04,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65165 0xfe8d "ﺍ" */
+0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65166 0xfe8e "ﺎ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65167 0xfe8f "ﺏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65168 0xfe90 "ﺐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x00,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65169 0xfe91 "ﺑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xfc,0x00,0x00,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65170 0xfe92 "ﺒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x00,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65171 0xfe93 "ﺓ" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65172 0xfe94 "ﺔ" */
+0x00,0x00,0x00,0x12,0x00,0x04,0x0c,0x14,0x24,0x3c,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65173 0xfe95 "ﺕ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65174 0xfe96 "ﺖ" */
+0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65175 0xfe97 "ﺗ" */
+0x00,0x00,0x00,0x00,0x28,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65176 0xfe98 "ﺘ" */
+0x00,0x00,0x00,0x00,0x28,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65177 0xfe99 "ﺙ" */
+0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x04,0x22,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65178 0xfe9a "ﺚ" */
+0x00,0x00,0x10,0x00,0x24,0x00,0x00,0x04,0x22,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65179 0xfe9b "ﺛ" */
+0x00,0x00,0x20,0x00,0x48,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65180 0xfe9c "ﺜ" */
+0x00,0x00,0x20,0x00,0x48,0x00,0x00,0x08,0x04,0x04,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65181 0xfe9d "ﺝ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x48,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65182 0xfe9e "ﺞ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x14,0x23,0x40,0x48,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65183 0xfe9f "ﺟ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x06,0xfe,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65184 0xfea0 "ﺠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x06,0xff,0x00,0x10,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65185 0xfea1 "ﺡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65186 0xfea2 "ﺢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x14,0x23,0x40,0x40,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65187 0xfea3 "ﺣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65188 0xfea4 "ﺤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x0c,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65189 0xfea5 "ﺥ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x7e,0x10,0x20,0x40,0x40,0x40,0x22,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65190 0xfea6 "ﺦ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x7e,0x14,0x23,0x40,0x40,0x40,0x21,0x1e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65191 0xfea7 "ﺧ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x70,0x0c,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65192 0xfea8 "ﺨ" */
+0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x70,0x0c,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65193 0xfea9 "ﺩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65194 0xfeaa "ﺪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x42,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65195 0xfeab "ﺫ" */
+0x00,0x00,0x00,0x00,0x20,0x00,0x08,0x04,0x02,0x42,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65196 0xfeac "ﺬ" */
+0x00,0x00,0x00,0x00,0x20,0x00,0x08,0x04,0x02,0x42,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65197 0xfead "ﺭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65198 0xfeae "ﺮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,0x03,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65199 0xfeaf "ﺯ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65200 0xfeb0 "ﺰ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x04,0x02,0x03,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65201 0xfeb1 "ﺱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65202 0xfeb2 "ﺲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x15,0x15,0x5f,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65203 0xfeb3 "ﺳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x2a,0x2a,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65204 0xfeb4 "ﺴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x2a,0x2a,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65205 0xfeb5 "ﺵ" */
+0x00,0x00,0x00,0x08,0x00,0x12,0x00,0x00,0x01,0x15,0x15,0x5e,0x48,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65206 0xfeb6 "ﺶ" */
+0x00,0x00,0x00,0x08,0x00,0x12,0x00,0x01,0x15,0x15,0x5f,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65207 0xfeb7 "ﺷ" */
+0x00,0x00,0x00,0x10,0x00,0x24,0x00,0x02,0x2a,0x2a,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65208 0xfeb8 "ﺸ" */
+0x00,0x00,0x00,0x10,0x00,0x24,0x00,0x02,0x2a,0x2a,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65209 0xfeb9 "ﺹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x19,0x4e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65210 0xfeba "ﺺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x19,0x4f,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65211 0xfebb "ﺻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65212 0xfebc "ﺼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x52,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65213 0xfebd "ﺽ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x06,0x19,0x4e,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65214 0xfebe "ﺾ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x06,0x19,0x4f,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65215 0xfebf "ﺿ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x0c,0x52,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65216 0xfec0 "ﻀ" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x0c,0x52,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65217 0xfec1 "ﻁ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65218 0xfec2 "ﻂ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65219 0xfec3 "ﻃ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65220 0xfec4 "ﻄ" */
+0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x2c,0x32,0x22,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65221 0xfec5 "ﻅ" */
+0x00,0x00,0x00,0x20,0x24,0x20,0x20,0x2c,0x32,0x22,0x7c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65222 0xfec6 "ﻆ" */
+0x00,0x00,0x00,0x20,0x24,0x20,0x20,0x2c,0x32,0x22,0x7f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65223 0xfec7 "ﻇ" */
+0x00,0x00,0x00,0x20,0x24,0x20,0x20,0x2c,0x32,0x22,0xfc,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65224 0xfec8 "ﻈ" */
+0x00,0x00,0x00,0x20,0x24,0x20,0x20,0x2c,0x32,0x22,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65225 0xfec9 "ﻉ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65226 0xfeca "ﻊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x1f,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65227 0xfecb "ﻋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65228 0xfecc "ﻌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x08,0xf7,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65229 0xfecd "ﻍ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x18,0x24,0x20,0x1c,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65230 0xfece "ﻎ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x30,0x30,0x1f,0x20,0x40,0x40,0x42,0x3c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65231 0xfecf "ﻏ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x18,0x24,0x20,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65232 0xfed0 "ﻐ" */
+0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x18,0x18,0x08,0xf7,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65233 0xfed1 "ﻑ" */
+0x00,0x00,0x00,0x08,0x00,0x06,0x0a,0x06,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65234 0xfed2 "ﻒ" */
+0x00,0x00,0x00,0x08,0x00,0x06,0x0a,0x06,0x42,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65235 0xfed3 "ﻓ" */
+0x00,0x00,0x00,0x10,0x00,0x00,0x38,0x24,0x14,0x0c,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65236 0xfed4 "ﻔ" */
+0x00,0x00,0x00,0x10,0x00,0x00,0x38,0x24,0x14,0x0c,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65237 0xfed5 "ﻕ" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x00,0x1c,0x12,0x0a,0x26,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65238 0xfed6 "ﻖ" */
+0x00,0x00,0x00,0x00,0x24,0x00,0x00,0x1c,0x12,0x0a,0x27,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65239 0xfed7 "ﻗ" */
+0x00,0x00,0x00,0x48,0x00,0x00,0x38,0x24,0x14,0x0c,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65240 0xfed8 "ﻘ" */
+0x00,0x00,0x00,0x48,0x00,0x00,0x38,0x24,0x14,0x0c,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65241 0xfed9 "ﻙ" */
+0x00,0x00,0x00,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65242 0xfeda "ﻚ" */
+0x00,0x00,0x00,0x02,0x0a,0x12,0x0a,0x22,0x42,0x42,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65243 0xfedb "ﻛ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x02,0xfe,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65244 0xfedc "ﻜ" */
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x3c,0x02,0xff,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65245 0xfedd "ﻝ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x22,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65246 0xfede "ﻞ" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x23,0x42,0x42,0x44,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65247 0xfedf "ﻟ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65248 0xfee0 "ﻠ" */
+0x00,0x00,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65249 0xfee1 "ﻡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x06,0x1e,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65250 0xfee2 "ﻢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x06,0x1f,0x20,0x20,0x20,0x20,0x20,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65251 0xfee3 "ﻣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x32,0xee,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65252 0xfee4 "ﻤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x14,0x32,0xef,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65253 0xfee5 "ﻥ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x04,0x22,0x42,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65254 0xfee6 "ﻦ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x04,0x22,0x43,0x42,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65255 0xfee7 "ﻧ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x08,0x04,0x04,0xf8,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65256 0xfee8 "ﻨ" */
+0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x08,0x04,0x04,0xfb,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65257 0xfee9 "ﻩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x18,0x24,0x24,0x3c,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65258 0xfeea "ﻪ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x0c,0x14,0x24,0x3c,0x07,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65259 0xfeeb "ﻫ" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x08,0x3c,0x2a,0x3a,0xf6,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65260 0xfeec "ﻬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x14,0x14,0xff,0x14,0x0c,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65261 0xfeed "ﻭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1e,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65262 0xfeee "ﻮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x12,0x12,0x1f,0x02,0x04,0x48,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65263 0xfeef "ﻯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4a,0x48,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65264 0xfef0 "ﻰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x43,0x44,0x42,0x42,0x3c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65265 0xfef1 "ﻱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x4a,0x48,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65266 0xfef2 "ﻲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x43,0x44,0x42,0x3c,0x00,0x28,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65267 0xfef3 "ﻳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xf8,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65268 0xfef4 "ﻴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04,0xfb,0x00,0x28,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65269 0xfef5 "ﻵ" */
+0x00,0x00,0x08,0x72,0x82,0x22,0x12,0x0a,0x04,0x0c,0x14,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65270 0xfef6 "ﻶ" */
+0x00,0x00,0x08,0x72,0x82,0x22,0x12,0x0a,0x0e,0x0a,0x13,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65271 0xfef7 "ﻷ" */
+0x00,0x00,0x30,0x42,0x32,0x42,0x12,0x0a,0x04,0x0c,0x14,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65272 0xfef8 "ﻸ" */
+0x00,0x00,0x30,0x42,0x32,0x42,0x12,0x0a,0x0e,0x0a,0x13,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65273 0xfef9 "ﻹ" */
+0x00,0x00,0x02,0x02,0x22,0x12,0x0a,0x04,0x0c,0x14,0x1c,0x00,0x0c,0x10,0x0c,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65274 0xfefa "ﻺ" */
+0x00,0x00,0x00,0x02,0x02,0x22,0x12,0x0a,0x0e,0x0a,0x13,0x60,0x0c,0x10,0x0c,0x10,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65275 0xfefb "ﻻ" */
+0x00,0x00,0x00,0x02,0x02,0x22,0x12,0x0a,0x04,0x0c,0x14,0x1c,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65276 0xfefc "ﻼ" */
+0x00,0x00,0x00,0x02,0x02,0x22,0x12,0x0a,0x0e,0x0a,0x13,0x60,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65277 0xfefd "﻽" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 65278 0xfefe "﻾" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 65279 0xfeff "﻿" */
+0xaa,0x00,0xf4,0x14,0xa5,0x46,0xf4,0x00,0xf1,0x4a,0xf1,0x48,0xf3,0x00,0x80,0x55,
+0xaa,0x01,0x51,0x58,0x55,0xd2,0x51,0x01,0xde,0x10,0x9e,0x51,0x90,0x01,0x00,0x55,
+/* 65280 0xff00 "＀" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x73,0x6d,0x6d,0x6d,0x73,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 65281 0xff01 "！" */
+0x00,0x00,0x02,0x07,0x07,0x07,0x07,0x02,0x02,0x02,0x00,0x00,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65282 0xff02 "＂" */
+0x00,0x02,0x02,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x40,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65283 0xff03 "＃" */
+0x00,0x00,0x00,0x02,0x02,0x02,0x1f,0x04,0x04,0x04,0x04,0x3f,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x20,0x20,0x20,0xf8,0x40,0x40,0x40,0x40,0xf0,0x80,0x80,0x80,0x80,
+/* 65284 0xff04 "＄" */
+0x00,0x00,0x00,0x01,0x07,0x09,0x11,0x11,0x0d,0x03,0x01,0x11,0x11,0x09,0x07,0x01,
+0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x00,0x80,0x60,0x10,0x10,0x20,0xc0,0x00,
+/* 65285 0xff05 "％" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0e,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x70,0x88,0x88,0x88,0x70,0x00,
+/* 65286 0xff06 "＆" */
+0x00,0x00,0x00,0x0e,0x11,0x11,0x11,0x0a,0x04,0x0a,0x11,0x20,0x20,0x11,0x0e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x20,0xc0,0xc0,0x20,0x18,0x00,
+/* 65287 0xff07 "＇" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65288 0xff08 "（" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x10,0x20,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x20,0x10,0x00,
+/* 65289 0xff09 "）" */
+0x00,0x10,0x08,0x04,0x02,0x02,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65290 0xff0a "＊" */
+0x00,0x00,0x00,0x00,0x01,0x11,0x09,0x05,0x03,0x03,0x05,0x09,0x11,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x80,0x40,0x20,0x10,0x00,0x00,0x00,
+/* 65291 0xff0b "＋" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x3f,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65292 0xff0c "，" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x04,0x04,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65293 0xff0d "－" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65294 0xff0e "．" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65295 0xff0f "／" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,
+0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65296 0xff10 "０" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x09,0x0a,0x0c,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x20,0x60,0xa0,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 65297 0xff11 "１" */
+0x00,0x00,0x00,0x01,0x03,0x05,0x09,0x01,0x01,0x01,0x01,0x01,0x01,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,
+/* 65298 0xff12 "２" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x00,0x00,0x01,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0xf0,0x00,0x00,
+/* 65299 0xff13 "３" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x00,0x00,0x01,0x00,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65300 0xff14 "４" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x1f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x40,0xc0,0x40,0x40,0x40,0x40,0x40,0xf0,0x40,0x40,0xe0,0x00,0x00,
+/* 65301 0xff15 "５" */
+0x00,0x00,0x00,0x0f,0x08,0x08,0x08,0x0b,0x0c,0x00,0x00,0x00,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65302 0xff16 "６" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x13,0x14,0x18,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65303 0xff17 "７" */
+0x00,0x00,0x00,0x0f,0x08,0x10,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x20,0x40,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65304 0xff18 "８" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x04,0x03,0x04,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65305 0xff19 "９" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x04,0x03,0x00,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x30,0xd0,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65306 0xff1a "：" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65307 0xff1b "；" */
+0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00,0x00,0x06,0x06,0x02,0x02,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65308 0xff1c "＜" */
+0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x0c,0x10,0x0c,0x02,0x01,0x00,0x00,0x00,0x00,
+0x00,0x00,0x08,0x30,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x30,0x08,0x00,
+/* 65309 0xff1d "＝" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0xf8,0x00,0x00,0x00,0x00,0x00,
+/* 65310 0xff1e "＞" */
+0x00,0x00,0x10,0x0c,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x0c,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x30,0x08,0x30,0x40,0x80,0x00,0x00,0x00,0x00,
+/* 65311 0xff1f "？" */
+0x00,0x00,0x07,0x08,0x10,0x00,0x00,0x00,0x01,0x01,0x00,0x00,0x01,0x01,0x00,0x00,
+0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65312 0xff20 "＠" */
+0x00,0x00,0x00,0x03,0x0c,0x10,0x21,0x22,0x24,0x24,0x24,0x13,0x10,0x0c,0x03,0x00,
+0x00,0x00,0x00,0xc0,0x30,0x08,0xc4,0x44,0x44,0x44,0xc8,0x30,0x04,0x18,0xe0,0x00,
+/* 65313 0xff21 "Ａ" */
+0x00,0x00,0x00,0x01,0x01,0x02,0x02,0x04,0x04,0x08,0x0f,0x10,0x10,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x40,0x40,0x20,0xe0,0x10,0x10,0x38,0x00,0x00,
+/* 65314 0xff22 "Ｂ" */
+0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xe0,0x10,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 65315 0xff23 "Ｃ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xe8,0x18,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x10,0xe0,0x00,0x00,
+/* 65316 0xff24 "Ｄ" */
+0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x80,0x60,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x60,0x80,0x00,0x00,
+/* 65317 0xff25 "Ｅ" */
+0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x00,0x00,0x20,0xe0,0x20,0x00,0x00,0x10,0xf0,0x00,0x00,
+/* 65318 0xff26 "Ｆ" */
+0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0xf0,0x10,0x00,0x00,0x40,0xc0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65319 0xff27 "Ｇ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xd0,0x30,0x10,0x00,0x00,0x7c,0x10,0x10,0x10,0x30,0xd0,0x00,0x00,
+/* 65320 0xff28 "Ｈ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x38,0x10,0x10,0x10,0x10,0xf0,0x10,0x10,0x10,0x10,0x38,0x00,0x00,
+/* 65321 0xff29 "Ｉ" */
+0x00,0x00,0x00,0x07,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 65322 0xff2a "Ｊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 65323 0xff2b "Ｋ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x0b,0x0d,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x70,0x20,0x40,0x80,0x00,0x00,0x80,0x40,0x20,0x10,0x38,0x00,0x00,
+/* 65324 0xff2c "Ｌ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xf0,0x00,0x00,
+/* 65325 0xff2d "Ｍ" */
+0x00,0x00,0x00,0x30,0x18,0x18,0x14,0x14,0x12,0x12,0x11,0x11,0x10,0x38,0x00,0x00,
+0x00,0x00,0x00,0x0c,0x18,0x28,0x28,0x48,0x48,0x88,0x08,0x08,0x08,0x1c,0x00,0x00,
+/* 65326 0xff2e "Ｎ" */
+0x00,0x00,0x00,0x18,0x0c,0x0c,0x0a,0x09,0x08,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x38,0x10,0x10,0x10,0x10,0x90,0x90,0x50,0x30,0x30,0x10,0x00,0x00,
+/* 65327 0xff2f "Ｏ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x10,0x20,0xc0,0x00,0x00,
+/* 65328 0xff30 "Ｐ" */
+0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65329 0xff31 "Ｑ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x10,0x10,0x10,0x10,0x17,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x08,0x08,0x08,0x08,0x08,0x90,0x60,0xe0,0x18,0x00,
+/* 65330 0xff32 "Ｒ" */
+0x00,0x00,0x00,0x1f,0x08,0x08,0x08,0x08,0x0f,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x20,0xc0,0x80,0x40,0x20,0x10,0x38,0x00,0x00,
+/* 65331 0xff33 "Ｓ" */
+0x00,0x00,0x00,0x03,0x04,0x08,0x04,0x03,0x00,0x00,0x08,0x08,0x0c,0x0b,0x00,0x00,
+0x00,0x00,0x00,0xd0,0x30,0x10,0x00,0x00,0xc0,0x30,0x08,0x08,0x10,0xe0,0x00,0x00,
+/* 65332 0xff34 "Ｔ" */
+0x00,0x00,0x00,0x3f,0x21,0x21,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x03,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x08,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 65333 0xff35 "Ｕ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x38,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65334 0xff36 "Ｖ" */
+0x00,0x00,0x00,0x38,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x38,0x10,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 65335 0xff37 "Ｗ" */
+0x00,0x00,0x00,0x71,0x21,0x21,0x21,0x12,0x12,0x14,0x14,0x0c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x90,0x90,0x50,0x50,0x60,0x20,0x20,0x00,0x00,
+/* 65336 0xff38 "Ｘ" */
+0x00,0x00,0x00,0x38,0x10,0x08,0x04,0x02,0x01,0x02,0x04,0x08,0x10,0x38,0x00,0x00,
+0x00,0x00,0x00,0x38,0x10,0x20,0x40,0x80,0x00,0x80,0x40,0x20,0x10,0x38,0x00,0x00,
+/* 65337 0xff39 "Ｙ" */
+0x00,0x00,0x00,0x38,0x10,0x08,0x04,0x02,0x01,0x01,0x01,0x01,0x01,0x03,0x00,0x00,
+0x00,0x00,0x00,0x38,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 65338 0xff3a "Ｚ" */
+0x00,0x00,0x00,0x1f,0x10,0x10,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x1f,0x00,0x00,
+0x00,0x00,0x00,0xf8,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x08,0x08,0xf8,0x00,0x00,
+/* 65339 0xff3b "［" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x00,
+/* 65340 0xff3c "＼" */
+0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x04,0x02,0x00,
+/* 65341 0xff3d "］" */
+0x00,0x1f,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x1f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65342 0xff3e "＾" */
+0x00,0x01,0x06,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0xc0,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65343 0xff3f "＿" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
+/* 65344 0xff40 "｀" */
+0x00,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x80,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65345 0xff41 "ａ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x01,0x06,0x08,0x08,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0xe0,0x20,0x20,0x60,0x90,0x00,0x00,
+/* 65346 0xff42 "ｂ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x09,0x0a,0x0c,0x08,0x08,0x08,0x0c,0x1b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65347 0xff43 "ｃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x00,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 65348 0xff44 "ｄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x18,0x10,0x10,0x90,0x50,0x30,0x10,0x10,0x10,0x30,0xd8,0x00,0x00,
+/* 65349 0xff45 "ｅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x0f,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0xf0,0x00,0x00,0x10,0xe0,0x00,0x00,
+/* 65350 0xff46 "ｆ" */
+0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x1f,0x04,0x04,0x04,0x04,0x04,0x0e,0x00,0x00,
+0x00,0x00,0x00,0xe0,0x10,0x00,0x00,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65351 0xff47 "ｇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x04,0x04,0x03,0x04,0x07,0x08,0x08,0x07,
+0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x60,0x20,0x40,0x80,0x00,0xe0,0x10,0x10,0xe0,
+/* 65352 0xff48 "ｈ" */
+0x00,0x00,0x00,0x18,0x08,0x08,0x09,0x0a,0x0c,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x10,0x38,0x00,0x00,
+/* 65353 0xff49 "ｉ" */
+0x00,0x00,0x01,0x01,0x00,0x00,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 65354 0xff4a "ｊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x07,
+0x00,0x00,0x20,0x20,0x00,0x00,0x60,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x80,
+/* 65355 0xff4b "ｋ" */
+0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x09,0x0b,0x0c,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x70,0x40,0x80,0x00,0x00,0x80,0x40,0x20,0x70,0x00,0x00,
+/* 65356 0xff4c "ｌ" */
+0x00,0x00,0x00,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x07,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,
+/* 65357 0xff4d "ｍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x19,0x11,0x11,0x11,0x11,0x11,0x3b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x90,0x10,0x10,0x10,0x10,0x10,0xb8,0x00,0x00,
+/* 65358 0xff4e "ｎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x19,0x0a,0x0c,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
+/* 65359 0xff4f "ｏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x10,0x10,0x10,0x10,0x20,0xc0,0x00,0x00,
+/* 65360 0xff50 "ｐ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0x0c,0x08,0x08,0x08,0x08,0x0c,0x0b,0x08,0x1c,
+0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x20,0x20,0x20,0x40,0x80,0x00,0x00,
+/* 65361 0xff51 "ｑ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0x60,0x20,0x20,0x20,0x20,0x60,0xa0,0x20,0x70,
+/* 65362 0xff52 "ｒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x19,0x0a,0x0c,0x08,0x08,0x08,0x08,0x1c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x20,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65363 0xff53 "ｓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x08,0x08,0x07,0x00,0x00,0x0c,0x0b,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xd0,0x30,0x00,0x00,0xe0,0x10,0x10,0xe0,0x00,0x00,
+/* 65364 0xff54 "ｔ" */
+0x00,0x00,0x00,0x00,0x04,0x04,0x04,0x1f,0x04,0x04,0x04,0x04,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x20,0x20,0xc0,0x00,0x00,
+/* 65365 0xff55 "ｕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x08,0x08,0x08,0x08,0x08,0x04,0x03,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x20,0x20,0x20,0x20,0x20,0x60,0xb0,0x00,0x00,
+/* 65366 0xff56 "ｖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x20,0x20,0x40,0x40,0x80,0x80,0x00,0x00,
+/* 65367 0xff57 "ｗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x11,0x11,0x0a,0x0a,0x0a,0x04,0x04,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x10,0x10,0x90,0xa0,0xa0,0x40,0x40,0x00,0x00,
+/* 65368 0xff58 "ｘ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x04,0x02,0x01,0x01,0x02,0x04,0x0c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x20,0x40,0x80,0x80,0x40,0x20,0x30,0x00,0x00,
+/* 65369 0xff59 "ｙ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x08,0x04,0x04,0x02,0x02,0x01,0x01,0x01,0x0e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x20,0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
+/* 65370 0xff5a "ｚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x08,0x00,0x01,0x02,0x04,0x08,0x0f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x40,0x80,0x00,0x00,0x00,0x20,0xe0,0x00,0x00,
+/* 65371 0xff5b "｛" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x30,0x40,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x80,0x80,0x80,0x40,0x30,0x00,
+/* 65372 0xff5c "｜" */
+0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65373 0xff5d "｝" */
+0x00,0x18,0x04,0x02,0x02,0x02,0x02,0x01,0x02,0x02,0x02,0x02,0x02,0x04,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65374 0xff5e "～" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x84,0x78,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65375 0xff5f "｟" */
+0x00,0x00,0x00,0x01,0x02,0x04,0x04,0x08,0x08,0x08,0x08,0x04,0x04,0x02,0x01,0x00,
+0x00,0x00,0x88,0x10,0x20,0x40,0x40,0x80,0x80,0x80,0x80,0x40,0x40,0x20,0x10,0x88,
+/* 65376 0xff60 "｠" */
+0x00,0x00,0x22,0x11,0x08,0x04,0x04,0x02,0x02,0x02,0x02,0x04,0x04,0x08,0x11,0x22,
+0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x20,0x20,0x40,0x40,0x80,0x00,0x00,
+/* 65377 0xff61 "｡" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65378 0xff62 "｢" */
+0x3e,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65379 0xff63 "｣" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x3e,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65380 0xff64 "､" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x30,0x18,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65381 0xff65 "･" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65382 0xff66 "ｦ" */
+0x00,0x00,0x7e,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65383 0xff67 "ｧ" */
+0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x04,0x14,0x08,0x08,0x08,0x10,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65384 0xff68 "ｨ" */
+0x00,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x18,0x68,0x08,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65385 0xff69 "ｩ" */
+0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x7f,0x41,0x41,0x01,0x02,0x02,0x04,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65386 0xff6a "ｪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65387 0xff6b "ｫ" */
+0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x7f,0x04,0x0c,0x14,0x24,0x44,0x04,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65388 0xff6c "ｬ" */
+0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x7f,0x11,0x12,0x10,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65389 0xff6d "ｭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x04,0x04,0x7f,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65390 0xff6e "ｮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x7e,0x02,0x02,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65391 0xff6f "ｯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x29,0x29,0x29,0x02,0x02,0x04,0x08,0x30,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65392 0xff70 "ｰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65393 0xff71 "ｱ" */
+0x00,0x00,0x7f,0x01,0x09,0x0a,0x0a,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65394 0xff72 "ｲ" */
+0x00,0x01,0x01,0x01,0x02,0x02,0x04,0x0c,0x14,0x64,0x04,0x04,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65395 0xff73 "ｳ" */
+0x00,0x08,0x08,0x08,0x7f,0x41,0x41,0x41,0x01,0x01,0x01,0x02,0x02,0x04,0x18,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65396 0xff74 "ｴ" */
+0x00,0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65397 0xff75 "ｵ" */
+0x00,0x04,0x04,0x7f,0x04,0x0c,0x0c,0x14,0x14,0x14,0x24,0x24,0x44,0x04,0x0c,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65398 0xff76 "ｶ" */
+0x00,0x08,0x08,0x08,0x7f,0x09,0x09,0x09,0x09,0x11,0x11,0x12,0x22,0x22,0x44,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65399 0xff77 "ｷ" */
+0x00,0x10,0x10,0x10,0x1e,0x70,0x08,0x08,0x0f,0x78,0x08,0x08,0x04,0x04,0x04,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65400 0xff78 "ｸ" */
+0x00,0x08,0x08,0x0f,0x11,0x11,0x21,0x41,0x02,0x02,0x04,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65401 0xff79 "ｹ" */
+0x00,0x20,0x20,0x20,0x3f,0x24,0x24,0x44,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65402 0xff7a "ｺ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65403 0xff7b "ｻ" */
+0x00,0x12,0x12,0x12,0x7f,0x12,0x12,0x12,0x12,0x04,0x04,0x04,0x08,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65404 0xff7c "ｼ" */
+0x00,0x00,0x38,0x00,0x00,0x00,0x71,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65405 0xff7d "ｽ" */
+0x00,0x00,0x00,0x7e,0x02,0x04,0x04,0x04,0x08,0x08,0x14,0x12,0x22,0x21,0x41,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65406 0xff7e "ｾ" */
+0x00,0x10,0x10,0x10,0x10,0x17,0x79,0x11,0x12,0x12,0x10,0x10,0x10,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65407 0xff7f "ｿ" */
+0x00,0x01,0x41,0x41,0x21,0x01,0x02,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65408 0xff80 "ﾀ" */
+0x00,0x08,0x08,0x0f,0x11,0x11,0x29,0x45,0x02,0x02,0x04,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65409 0xff81 "ﾁ" */
+0x00,0x02,0x0c,0x38,0x48,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x10,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65410 0xff82 "ﾂ" */
+0x00,0x00,0x52,0x52,0x52,0x42,0x02,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65411 0xff83 "ﾃ" */
+0x00,0x00,0x3e,0x00,0x00,0x00,0x7f,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65412 0xff84 "ﾄ" */
+0x00,0x20,0x20,0x20,0x20,0x20,0x38,0x24,0x22,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65413 0xff85 "ﾅ" */
+0x00,0x08,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65414 0xff86 "ﾆ" */
+0x00,0x00,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65415 0xff87 "ﾇ" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x22,0x1a,0x04,0x06,0x0a,0x09,0x11,0x21,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65416 0xff88 "ﾈ" */
+0x00,0x08,0x08,0x08,0x7f,0x02,0x04,0x04,0x0a,0x19,0x29,0x48,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65417 0xff89 "ﾉ" */
+0x00,0x00,0x02,0x02,0x02,0x02,0x02,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65418 0xff8a "ﾊ" */
+0x00,0x00,0x12,0x12,0x12,0x12,0x12,0x11,0x11,0x21,0x21,0x21,0x21,0x41,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65419 0xff8b "ﾋ" */
+0x00,0x40,0x40,0x40,0x40,0x40,0x46,0x78,0x40,0x40,0x40,0x40,0x40,0x20,0x1e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65420 0xff8c "ﾌ" */
+0x00,0x00,0x7f,0x01,0x01,0x01,0x02,0x02,0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65421 0xff8d "ﾍ" */
+0x00,0x00,0x10,0x28,0x28,0x44,0x44,0x04,0x02,0x02,0x02,0x01,0x01,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65422 0xff8e "ﾎ" */
+0x00,0x08,0x08,0x08,0x7f,0x08,0x08,0x2a,0x2a,0x2a,0x49,0x49,0x49,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65423 0xff8f "ﾏ" */
+0x00,0x00,0x7e,0x02,0x02,0x02,0x04,0x24,0x24,0x18,0x18,0x10,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65424 0xff90 "ﾐ" */
+0x00,0x00,0x38,0x06,0x01,0x00,0x30,0x0c,0x02,0x00,0x70,0x0c,0x02,0x01,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65425 0xff91 "ﾑ" */
+0x00,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x10,0x12,0x22,0x21,0x27,0x39,0x41,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65426 0xff92 "ﾒ" */
+0x00,0x01,0x01,0x01,0x02,0x32,0x0a,0x04,0x06,0x0a,0x09,0x11,0x11,0x20,0x40,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65427 0xff93 "ﾓ" */
+0x00,0x00,0x3e,0x08,0x08,0x08,0x08,0x7f,0x08,0x08,0x08,0x08,0x08,0x08,0x07,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65428 0xff94 "ﾔ" */
+0x00,0x20,0x20,0x20,0x27,0x79,0x21,0x12,0x12,0x10,0x10,0x08,0x08,0x08,0x08,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65429 0xff95 "ﾕ" */
+0x00,0x00,0x00,0x00,0x3c,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x7f,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65430 0xff96 "ﾖ" */
+0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x7e,0x02,0x02,0x02,0x02,0x02,0x7e,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65431 0xff97 "ﾗ" */
+0x00,0x00,0x3c,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x04,0x04,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65432 0xff98 "ﾘ" */
+0x00,0x02,0x22,0x22,0x22,0x22,0x22,0x22,0x02,0x04,0x04,0x04,0x08,0x08,0x10,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65433 0xff99 "ﾙ" */
+0x00,0x00,0x08,0x28,0x28,0x28,0x28,0x29,0x29,0x29,0x2a,0x2a,0x4c,0x4c,0x48,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65434 0xff9a "ﾚ" */
+0x00,0x00,0x40,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x44,0x44,0x48,0x50,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65435 0xff9b "ﾛ" */
+0x00,0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7e,0x42,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65436 0xff9c "ﾜ" */
+0x00,0x00,0x7e,0x42,0x42,0x42,0x42,0x02,0x04,0x04,0x04,0x08,0x08,0x10,0x20,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65437 0xff9d "ﾝ" */
+0x00,0x00,0x60,0x10,0x00,0x01,0x01,0x01,0x01,0x02,0x02,0x04,0x08,0x10,0x60,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65438 0xff9e "ﾞ" */
+0x00,0x00,0x10,0x48,0x24,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65439 0xff9f "ﾟ" */
+0x00,0x00,0x30,0x48,0x48,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65440 0xffa0 "ﾠ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65441 0xffa1 "ﾡ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x02,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65442 0xffa2 "ﾢ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x24,0x24,0x24,0x24,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65443 0xffa3 "ﾣ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0x14,0x14,0x1a,0x11,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65444 0xffa4 "ﾤ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65445 0xffa5 "ﾥ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x2a,0x39,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65446 0xffa6 "ﾦ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x27,0x22,0x25,0x3a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65447 0xffa7 "ﾧ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x40,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65448 0xffa8 "ﾨ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x48,0x48,0x48,0x6c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65449 0xffa9 "ﾩ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0x04,0x3c,0x20,0x3c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65450 0xffaa "ﾪ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x12,0x72,0x42,0x72,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65451 0xffab "ﾫ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0x2a,0xea,0x8a,0xee,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65452 0xffac "ﾬ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xea,0x2a,0xee,0x8a,0xee,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65453 0xffad "ﾭ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe4,0x24,0xe4,0x8a,0xea,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65454 0xffae "ﾮ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0x28,0xee,0x88,0xee,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65455 0xffaf "ﾯ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x2a,0xea,0x8a,0xff,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65456 0xffb0 "ﾰ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe4,0x2e,0xe4,0x8a,0xe4,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65457 0xffb1 "ﾱ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x44,0x44,0x44,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65458 0xffb2 "ﾲ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x42,0x7e,0x42,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65459 0xffb3 "ﾳ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0xaa,0xee,0xaa,0xee,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65460 0xffb4 "ﾴ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0x54,0x74,0x5a,0x71,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65461 0xffb5 "ﾵ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x28,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65462 0xffb6 "ﾶ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0x24,0x24,0x5a,0x91,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65463 0xffb7 "ﾷ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x38,0x44,0x44,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65464 0xffb8 "ﾸ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x28,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65465 0xffb9 "ﾹ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x5a,0x91,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65466 0xffba "ﾺ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x00,0x7c,0x10,0x28,0x44,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65467 0xffbb "ﾻ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x02,0x7e,0x02,0x02,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65468 0xffbc "ﾼ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x40,0x7e,0x40,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65469 0xffbd "ﾽ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x24,0x24,0x24,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65470 0xffbe "ﾾ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xfe,0x38,0x44,0x38,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65471 0xffbf "﾿" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x63,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 65472 0xffc0 "￀" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 65473 0xffc1 "￁" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 65474 0xffc2 "ￂ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x38,0x20,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65475 0xffc3 "ￃ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x28,0x38,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65476 0xffc4 "ￄ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x38,0x20,0x38,0x20,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65477 0xffc5 "ￅ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x38,0x28,0x38,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65478 0xffc6 "ￆ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x38,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65479 0xffc7 "ￇ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x14,0x74,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65480 0xffc8 "￈" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 65481 0xffc9 "￉" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x71,0x6f,0x6f,0x6f,0x71,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 65482 0xffca "ￊ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x38,0x08,0x38,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65483 0xffcb "ￋ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x74,0x14,0x74,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65484 0xffcc "ￌ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65485 0xffcd "ￍ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x14,0x14,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65486 0xffce "ￎ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x2a,0x2a,0xfe,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65487 0xffcf "ￏ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x14,0x14,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65488 0xffd0 "￐" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 65489 0xffd1 "￑" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 65490 0xffd2 "ￒ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x28,0x28,0x28,0x7c,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65491 0xffd3 "ￓ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x10,0x10,0x10,0x10,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65492 0xffd4 "ￔ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3c,0x14,0x1c,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65493 0xffd5 "ￕ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x0a,0x7a,0x2a,0x3a,0x2a,0x2a,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65494 0xffd6 "ￖ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x04,0x3c,0x14,0x14,0x14,0x14,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65495 0xffd7 "ￗ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7c,0x28,0x28,0x28,0x28,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65496 0xffd8 "￘" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 65497 0xffd9 "￙" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xc6,0xf6,0xce,0xfe,0x00,
+/* 65498 0xffda "ￚ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65499 0xffdb "ￛ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x18,0x28,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65500 0xffdc "ￜ" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65501 0xffdd "￝" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xb6,0xb6,0xb6,0x8e,0xfe,0x00,
+/* 65502 0xffde "￞" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0x86,0xfe,0x00,
+/* 65503 0xffdf "￟" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x63,0x6d,0x6d,0x6d,0x63,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 65504 0xffe0 "￠" */
+0x00,0x00,0x00,0x00,0x03,0x04,0x08,0x08,0x08,0x09,0x09,0x06,0x02,0x05,0x08,0x00,
+0x00,0x00,0x00,0x10,0xa0,0x60,0x50,0x90,0x80,0x00,0x00,0x10,0x20,0xc0,0x00,0x00,
+/* 65505 0xffe1 "￡" */
+0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x02,0x3f,0x01,0x1d,0x23,0x22,0x1c,0x00,0x00,
+0x00,0x00,0xf0,0x08,0x08,0x08,0x00,0x00,0xf0,0x00,0x00,0x04,0xc4,0x38,0x00,0x00,
+/* 65506 0xffe2 "￢" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf8,0x08,0x08,0x08,0x08,0x00,0x00,0x00,
+/* 65507 0xffe3 "￣" */
+0x00,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65508 0xffe4 "￤" */
+0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65509 0xffe5 "￥" */
+0x00,0x00,0x38,0x10,0x08,0x3f,0x04,0x02,0x3f,0x01,0x01,0x01,0x01,0x03,0x00,0x00,
+0x00,0x00,0x38,0x10,0x20,0xf8,0x40,0x80,0xf8,0x00,0x00,0x00,0x00,0x80,0x00,0x00,
+/* 65510 0xffe6 "￦" */
+0x00,0x00,0x71,0x21,0x21,0x7f,0x21,0x12,0x7f,0x14,0x14,0x0c,0x08,0x08,0x00,0x00,
+0x00,0x00,0x1c,0x08,0x08,0xfc,0x08,0x90,0xfc,0x50,0x50,0x60,0x20,0x20,0x00,0x00,
+/* 65511 0xffe7 "￧" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 65512 0xffe8 "￨" */
+0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65513 0xffe9 "￩" */
+0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x7e,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65514 0xffea "￪" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x1c,0x2a,0x08,0x08,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65515 0xffeb "￫" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x7e,0x04,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65516 0xffec "￬" */
+0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x2a,0x1c,0x08,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65517 0xffed "￭" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x7e,0x7e,0x7e,0x7e,0x7e,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65518 0xffee "￮" */
+0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x24,0x18,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65519 0xffef "￯" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x61,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0x00,
+/* 65520 0xfff0 "￰" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xb6,0xb6,0xce,0xfe,0x00,
+/* 65521 0xfff1 "￱" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xee,0xce,0xee,0xee,0xc6,0xfe,0x00,
+/* 65522 0xfff2 "￲" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0x86,0xbe,0x86,0xfe,0x00,
+/* 65523 0xfff3 "￳" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x8e,0xf6,0xc6,0xf6,0x8e,0xfe,0x00,
+/* 65524 0xfff4 "￴" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xb6,0xb6,0x86,0xf6,0xf6,0xfe,0x00,
+/* 65525 0xfff5 "￵" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xbe,0x86,0xf6,0x86,0xfe,0x00,
+/* 65526 0xfff6 "￶" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xbe,0x8e,0xb6,0xce,0xfe,0x00,
+/* 65527 0xfff7 "￷" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0x86,0xf6,0xee,0xde,0xde,0xfe,0x00,
+/* 65528 0xfff8 "￸" */
+0x00,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x7f,0x61,0x6f,0x63,0x6f,0x6f,0x7f,0x00,
+0x00,0xfe,0x86,0xbe,0x8e,0xbe,0xbe,0xfe,0xfe,0xce,0xb6,0xce,0xb6,0xce,0xfe,0x00,
+/* 65529 0xfff9 "￹" */
+0xaa,0x00,0x80,0x3e,0x88,0x08,0x88,0x3e,0x80,0x00,0x81,0x01,0x82,0x02,0x80,0x55,
+0xaa,0x01,0x00,0x11,0x28,0x39,0x44,0x45,0x00,0x81,0x40,0xc1,0x20,0x21,0x00,0x55,
+/* 65530 0xfffa "￺" */
+0xaa,0x00,0x80,0x3e,0x88,0x08,0x88,0x3e,0x80,0x01,0x82,0x01,0x80,0x03,0x80,0x55,
+0xaa,0x01,0x00,0x11,0x28,0x39,0x44,0x45,0x00,0xe1,0x00,0xc1,0x20,0xc1,0x00,0x55,
+/* 65531 0xfffb "￻" */
+0xaa,0x00,0x80,0x3e,0x88,0x08,0x88,0x3e,0x80,0x03,0x80,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x11,0x28,0x39,0x44,0x45,0x00,0xe1,0x80,0x81,0x80,0x81,0x00,0x55,
+/* 65532 0xfffc "￼" */
+0xaa,0x00,0x80,0x00,0x80,0x00,0x91,0x29,0xa9,0x29,0x91,0x00,0x80,0x00,0x80,0x55,
+0xaa,0x01,0x00,0x01,0x00,0x01,0x84,0x45,0x84,0x45,0x98,0x01,0x00,0x01,0x00,0x55,
+/* 65533 0xfffd "�" */
+0x00,0x00,0x00,0x7e,0x66,0x5a,0x5a,0x7a,0x76,0x76,0x7e,0x76,0x76,0x7e,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65534 0xfffe */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+/* 65535 0xffff */
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
+0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
diff --git a/lib/fonts/font_cjk_32x32.c b/lib/fonts/font_cjk_32x32.c
new file mode 100644
index 0000000..88ba3f2
--- /dev/null
+++ b/lib/fonts/font_cjk_32x32.c
@@ -0,0 +1,27 @@
+// SPDX-License-Identifier: GPL-2.0
+/***************************************************************/
+/*                                                             */
+/* Font file modified from                                     */
+/* http://blog.chinaunix.net/u/13265/showart.php?id=1008020    */
+/* microcaicai@gmail modifiy it to use in-kernel font solution */
+/*                                                             */
+/***************************************************************/
+
+#include <linux/font.h>
+
+#define FONTDATAMAX (65536 * 128)
+
+static const struct font_data fontdata_cjk_32x32 = {
+	{ 0, 0, FONTDATAMAX, 0 }, {
+	#include "font_cjk_32x32.h"
+}};
+
+const struct font_desc font_cjk_32x32 = {
+	.idx	= CJK32x32_IDX,
+	.name	= "CJK32x32",
+	.width	= 16,
+	.height	= 32,
+	.charcount	= 65536 * 2,
+	.data	= fontdata_cjk_32x32.data,
+	.pref	= -1,
+};
diff --git a/lib/fonts/font_cjk_32x32.h b/lib/fonts/font_cjk_32x32.h
new file mode 100644
index 0000000..e69de29
diff --git a/lib/fonts/fonts.c b/lib/fonts/fonts.c
index 9738664..16b414a 100644
--- a/lib/fonts/fonts.c
+++ b/lib/fonts/fonts.c
@@ -60,6 +60,12 @@ static const struct font_desc *fonts[] = {
 #ifdef CONFIG_FONT_6x8
 	&font_6x8,
 #endif
+#ifdef CONFIG_FONT_CJK_16x16
+	&font_cjk_16x16,
+#endif
+#ifdef CONFIG_FONT_CJK_32x32
+	&font_cjk_32x32,
+#endif
 };
 
 #define num_fonts ARRAY_SIZE(fonts)
